/* Automatically @generated by tree-sitter */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 12671
#define LARGE_STATE_COUNT 3868
#define SYMBOL_COUNT 767
#define ALIAS_COUNT 2
#define TOKEN_COUNT 385
#define EXTERNAL_TOKEN_COUNT 9
#define FIELD_COUNT 73
#define MAX_ALIAS_SEQUENCE_LENGTH 17
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 268
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  sym_identifier = 1,
  anon_sym_SEMI = 2,
  anon_sym_DOT = 3,
  anon_sym_LBRACE = 4,
  anon_sym_RBRACE = 5,
  aux_sym_interface_declaration_token1 = 6,
  anon_sym_EQ = 7,
  aux_sym_interface_declaration_token2 = 8,
  anon_sym_COMMA = 9,
  anon_sym_COLON = 10,
  anon_sym_DASH = 11,
  aux_sym_boolean_token1 = 12,
  aux_sym_boolean_token2 = 13,
  sym_decimal = 14,
  aux_sym_ml_value_list_token1 = 15,
  aux_sym_lookup_formula_token1 = 16,
  anon_sym_LPAREN = 17,
  anon_sym_RPAREN = 18,
  aux_sym_where_clause_token1 = 19,
  aux_sym_where_condition_token1 = 20,
  aux_sym_where_condition_token2 = 21,
  aux_sym_where_condition_token3 = 22,
  anon_sym_DOT_DOT = 23,
  aux_sym_filter_value_token1 = 24,
  aux_sym_sorting_value_token1 = 25,
  aux_sym_sorting_value_token2 = 26,
  aux_sym_sorting_value_token3 = 27,
  aux_sym_sorting_value_token4 = 28,
  aux_sym_if_table_relation_token1 = 29,
  aux_sym_if_table_relation_token2 = 30,
  aux_sym_tabledata_permission_token1 = 31,
  aux_sym_tabledata_permission_token2 = 32,
  anon_sym_STAR = 33,
  sym_permission_type = 34,
  aux_sym_order_by_item_token1 = 35,
  aux_sym_order_by_item_token2 = 36,
  aux_sym_addlast_fieldgroup_modification_token1 = 37,
  aux_sym_addfirst_fieldgroup_modification_token1 = 38,
  aux_sym_text_type_token1 = 39,
  anon_sym_LBRACK = 40,
  anon_sym_RBRACK = 41,
  aux_sym_code_type_token1 = 42,
  aux_sym_option_type_token1 = 43,
  aux_sym_record_type_token1 = 44,
  aux_sym_object_reference_type_token1 = 45,
  aux_sym_object_reference_type_token2 = 46,
  aux_sym_array_type_token1 = 47,
  aux_sym_array_type_token2 = 48,
  aux_sym_list_type_token1 = 49,
  aux_sym_dictionary_type_token1 = 50,
  aux_sym_basic_type_token1 = 51,
  aux_sym_basic_type_token2 = 52,
  aux_sym_basic_type_token3 = 53,
  aux_sym_basic_type_token4 = 54,
  aux_sym_basic_type_token5 = 55,
  aux_sym_basic_type_token6 = 56,
  aux_sym_basic_type_token7 = 57,
  aux_sym_basic_type_token8 = 58,
  aux_sym_basic_type_token9 = 59,
  aux_sym_basic_type_token10 = 60,
  aux_sym_basic_type_token11 = 61,
  aux_sym_basic_type_token12 = 62,
  aux_sym_basic_type_token13 = 63,
  aux_sym_basic_type_token14 = 64,
  aux_sym_basic_type_token15 = 65,
  aux_sym_basic_type_token16 = 66,
  aux_sym_basic_type_token17 = 67,
  aux_sym_basic_type_token18 = 68,
  aux_sym_basic_type_token19 = 69,
  aux_sym_basic_type_token20 = 70,
  aux_sym_basic_type_token21 = 71,
  aux_sym_basic_type_token22 = 72,
  aux_sym_basic_type_token23 = 73,
  aux_sym_basic_type_token24 = 74,
  aux_sym_basic_type_token25 = 75,
  aux_sym_basic_type_token26 = 76,
  aux_sym_basic_type_token27 = 77,
  aux_sym_basic_type_token28 = 78,
  aux_sym_basic_type_token29 = 79,
  aux_sym_basic_type_token30 = 80,
  aux_sym_basic_type_token31 = 81,
  aux_sym_basic_type_token32 = 82,
  aux_sym_basic_type_token33 = 83,
  aux_sym_basic_type_token34 = 84,
  aux_sym_basic_type_token35 = 85,
  aux_sym_basic_type_token36 = 86,
  aux_sym_basic_type_token37 = 87,
  aux_sym_basic_type_token38 = 88,
  aux_sym_basic_type_token39 = 89,
  aux_sym_basic_type_token40 = 90,
  aux_sym_basic_type_token41 = 91,
  aux_sym_basic_type_token42 = 92,
  aux_sym_basic_type_token43 = 93,
  aux_sym_basic_type_token44 = 94,
  aux_sym_basic_type_token45 = 95,
  aux_sym_basic_type_token46 = 96,
  aux_sym_basic_type_token47 = 97,
  aux_sym_basic_type_token48 = 98,
  aux_sym_basic_type_token49 = 99,
  aux_sym_basic_type_token50 = 100,
  aux_sym_basic_type_token51 = 101,
  aux_sym_basic_type_token52 = 102,
  aux_sym_basic_type_token53 = 103,
  aux_sym_basic_type_token54 = 104,
  aux_sym_enum_value_declaration_token1 = 105,
  aux_sym_label_declaration_token1 = 106,
  aux_sym_label_declaration_token2 = 107,
  aux_sym_area_section_token1 = 108,
  aux_sym_area_section_token2 = 109,
  aux_sym_area_section_token3 = 110,
  aux_sym_area_section_token4 = 111,
  aux_sym_area_section_token5 = 112,
  aux_sym_area_section_token6 = 113,
  aux_sym_area_section_token7 = 114,
  aux_sym_area_section_token8 = 115,
  aux_sym_addafter_modification_token1 = 116,
  aux_sym_addbefore_modification_token1 = 117,
  aux_sym_modify_modification_token1 = 118,
  aux_sym_movefirst_modification_token1 = 119,
  aux_sym_movelast_modification_token1 = 120,
  aux_sym_moveafter_modification_token1 = 121,
  aux_sym_movebefore_modification_token1 = 122,
  aux_sym_action_area_section_token1 = 123,
  aux_sym_action_area_section_token2 = 124,
  aux_sym_action_area_section_token3 = 125,
  aux_sym_action_area_section_token4 = 126,
  aux_sym_action_area_section_token5 = 127,
  aux_sym_action_area_section_token6 = 128,
  aux_sym_action_area_section_token7 = 129,
  aux_sym_separator_action_token1 = 130,
  aux_sym_actionref_declaration_token1 = 131,
  aux_sym_systemaction_declaration_token1 = 132,
  aux_sym_fileuploadaction_declaration_token1 = 133,
  aux_sym_customaction_declaration_token1 = 134,
  aux_sym_add_dataset_modification_token1 = 135,
  aux_sym_xmlport_element_token1 = 136,
  aux_sym_xmlport_element_token2 = 137,
  aux_sym_xmlport_element_token3 = 138,
  aux_sym_xmlport_attribute_token1 = 139,
  aux_sym_xmlport_attribute_token2 = 140,
  aux_sym_assembly_declaration_token1 = 141,
  sym_dotnet_assembly_name = 142,
  aux_sym_type_declaration_token1 = 143,
  aux_sym_preproc_split_procedure_body_token1 = 144,
  aux_sym_preproc_split_procedure_body_token2 = 145,
  anon_sym_COLON_COLON = 146,
  anon_sym_POUNDif = 147,
  anon_sym_POUNDIF = 148,
  anon_sym_POUNDIf = 149,
  anon_sym_not = 150,
  anon_sym_NOT = 151,
  anon_sym_Not = 152,
  anon_sym_POUNDelif = 153,
  anon_sym_POUNDELIF = 154,
  anon_sym_POUNDElif = 155,
  anon_sym_POUNDelse = 156,
  anon_sym_POUNDELSE = 157,
  anon_sym_POUNDElse = 158,
  anon_sym_POUNDendif = 159,
  anon_sym_POUNDENDIF = 160,
  anon_sym_POUNDEndif = 161,
  sym_pragma = 162,
  sym_preproc_region = 163,
  sym_preproc_endregion = 164,
  sym__assignment_operator = 165,
  anon_sym_COLON_EQ = 166,
  anon_sym_LPAREN2 = 167,
  aux_sym__expression_token1 = 168,
  aux_sym__expression_token2 = 169,
  aux_sym_keyword_identifier_token1 = 170,
  aux_sym_keyword_identifier_token2 = 171,
  anon_sym_SLASH = 172,
  anon_sym_div = 173,
  anon_sym_DIV = 174,
  anon_sym_Div = 175,
  anon_sym_mod = 176,
  anon_sym_MOD = 177,
  anon_sym_Mod = 178,
  anon_sym_PLUS = 179,
  anon_sym_GT_EQ = 180,
  anon_sym_LT_EQ = 181,
  anon_sym_GT = 182,
  anon_sym_LT = 183,
  anon_sym_LT_GT = 184,
  anon_sym_and = 185,
  anon_sym_AND = 186,
  anon_sym_And = 187,
  anon_sym_or = 188,
  anon_sym_OR = 189,
  anon_sym_Or = 190,
  anon_sym_xor = 191,
  anon_sym_XOR = 192,
  anon_sym_Xor = 193,
  anon_sym_QMARK = 194,
  sym_datetime_literal = 195,
  sym_date_literal = 196,
  sym_time_literal = 197,
  sym_biginteger_literal = 198,
  anon_sym_if = 199,
  anon_sym_IF = 200,
  anon_sym_If = 201,
  anon_sym_then = 202,
  anon_sym_THEN = 203,
  anon_sym_Then = 204,
  anon_sym_else = 205,
  anon_sym_ELSE = 206,
  anon_sym_Else = 207,
  anon_sym_case = 208,
  anon_sym_CASE = 209,
  anon_sym_Case = 210,
  anon_sym_of = 211,
  anon_sym_OF = 212,
  anon_sym_Of = 213,
  anon_sym_for = 214,
  anon_sym_FOR = 215,
  anon_sym_For = 216,
  anon_sym_foreach = 217,
  anon_sym_FOREACH = 218,
  anon_sym_Foreach = 219,
  anon_sym_while = 220,
  anon_sym_WHILE = 221,
  anon_sym_While = 222,
  anon_sym_do = 223,
  anon_sym_DO = 224,
  anon_sym_Do = 225,
  anon_sym_repeat = 226,
  anon_sym_REPEAT = 227,
  anon_sym_Repeat = 228,
  anon_sym_until = 229,
  anon_sym_UNTIL = 230,
  anon_sym_Until = 231,
  anon_sym_exit = 232,
  anon_sym_EXIT = 233,
  anon_sym_Exit = 234,
  anon_sym_continue = 235,
  anon_sym_CONTINUE = 236,
  anon_sym_Continue = 237,
  anon_sym_break = 238,
  anon_sym_BREAK = 239,
  anon_sym_Break = 240,
  anon_sym_with = 241,
  anon_sym_WITH = 242,
  anon_sym_With = 243,
  sym_asserterror_keyword = 244,
  anon_sym_in = 245,
  anon_sym_IN = 246,
  anon_sym_In = 247,
  anon_sym_to = 248,
  anon_sym_TO = 249,
  anon_sym_To = 250,
  anon_sym_downto = 251,
  anon_sym_DOWNTO = 252,
  anon_sym_Downto = 253,
  sym_table_keyword = 254,
  anon_sym_tableextension = 255,
  anon_sym_TABLEEXTENSION = 256,
  anon_sym_Tableextension = 257,
  anon_sym_TableExtension = 258,
  anon_sym_tableExtension = 259,
  sym_page_keyword = 260,
  anon_sym_pageextension = 261,
  anon_sym_PAGEEXTENSION = 262,
  anon_sym_Pageextension = 263,
  anon_sym_PageExtension = 264,
  anon_sym_pageExtension = 265,
  anon_sym_codeunit = 266,
  anon_sym_CODEUNIT = 267,
  anon_sym_Codeunit = 268,
  anon_sym_CodeUnit = 269,
  anon_sym_COdeunit = 270,
  anon_sym_codeUnit = 271,
  sym_report_keyword = 272,
  anon_sym_reportextension = 273,
  anon_sym_REPORTEXTENSION = 274,
  anon_sym_Reportextension = 275,
  anon_sym_ReportExtension = 276,
  anon_sym_reportExtension = 277,
  sym_query_keyword = 278,
  anon_sym_xmlport = 279,
  anon_sym_XMLPORT = 280,
  anon_sym_Xmlport = 281,
  anon_sym_XMLport = 282,
  anon_sym_XMLPort = 283,
  anon_sym_XmlPort = 284,
  anon_sym_enum = 285,
  anon_sym_ENUM = 286,
  anon_sym_Enum = 287,
  anon_sym_eNUM = 288,
  anon_sym_eNum = 289,
  anon_sym_ENum = 290,
  anon_sym_enumextension = 291,
  anon_sym_ENUMEXTENSION = 292,
  anon_sym_Enumextension = 293,
  anon_sym_EnumExtension = 294,
  anon_sym_enumExtension = 295,
  sym_interface_keyword = 296,
  anon_sym_controladdin = 297,
  anon_sym_CONTROLADDIN = 298,
  anon_sym_Controladdin = 299,
  anon_sym_ControlAddIn = 300,
  anon_sym_ControlAddin = 301,
  anon_sym_controlAddIn = 302,
  anon_sym_controlAddin = 303,
  anon_sym_dotnet = 304,
  anon_sym_DOTNET = 305,
  anon_sym_Dotnet = 306,
  anon_sym_DotNet = 307,
  anon_sym_dotNet = 308,
  sym_profile_keyword = 309,
  anon_sym_profileextension = 310,
  anon_sym_PROFILEEXTENSION = 311,
  anon_sym_Profileextension = 312,
  anon_sym_ProfileExtension = 313,
  anon_sym_profileExtension = 314,
  anon_sym_permissionset = 315,
  anon_sym_PERMISSIONSET = 316,
  anon_sym_Permissionset = 317,
  anon_sym_PermissionSet = 318,
  anon_sym_permissionSet = 319,
  anon_sym_permissionsetextension = 320,
  anon_sym_PERMISSIONSETEXTENSION = 321,
  anon_sym_Permissionsetextension = 322,
  anon_sym_PermissionSetExtension = 323,
  anon_sym_permissionSetExtension = 324,
  sym_entitlement_keyword = 325,
  anon_sym_pagecustomization = 326,
  anon_sym_PAGECUSTOMIZATION = 327,
  anon_sym_Pagecustomization = 328,
  anon_sym_PageCustomization = 329,
  anon_sym_pageCustomization = 330,
  sym_namespace_keyword = 331,
  sym_using_keyword = 332,
  sym_implements_keyword = 333,
  sym_extends_keyword = 334,
  sym_customizes_keyword = 335,
  sym_procedure_keyword = 336,
  sym_trigger_keyword = 337,
  sym_var_keyword = 338,
  sym_local_keyword = 339,
  sym_internal_keyword = 340,
  sym_protected_keyword = 341,
  sym_event_keyword = 342,
  sym_temporary_keyword = 343,
  sym_fields_keyword = 344,
  sym_keys_keyword = 345,
  sym_key_keyword = 346,
  sym_fieldgroups_keyword = 347,
  sym_fieldgroup_keyword = 348,
  sym_actions_keyword = 349,
  sym_layout_keyword = 350,
  sym_area_keyword = 351,
  sym_group_keyword = 352,
  sym_repeater_keyword = 353,
  sym_cuegroup_keyword = 354,
  sym_fixed_keyword = 355,
  sym_grid_keyword = 356,
  sym_part_keyword = 357,
  sym_systempart_keyword = 358,
  sym_usercontrol_keyword = 359,
  sym_dataset_keyword = 360,
  sym_elements_keyword = 361,
  sym_dataitem_keyword = 362,
  sym_column_keyword = 363,
  sym_filter_keyword = 364,
  sym_labels_keyword = 365,
  sym_rendering_keyword = 366,
  sym_requestpage_keyword = 367,
  sym_schema_keyword = 368,
  sym_views_keyword = 369,
  sym_view_keyword = 370,
  sym_quoted_identifier = 371,
  sym_comment = 372,
  sym_multiline_comment = 373,
  sym_string_literal = 374,
  sym_integer = 375,
  sym_property_name = 376,
  sym_continue_as_identifier = 377,
  sym_preproc_open = 378,
  sym_preproc_close = 379,
  sym_begin_keyword = 380,
  sym_end_keyword = 381,
  sym_preproc_split_begin = 382,
  sym_preproc_split_end = 383,
  sym_var_attribute_open = 384,
  sym_source_file = 385,
  sym_preproc_conditional_object = 386,
  sym_namespace_declaration = 387,
  sym_using_statement = 388,
  sym_namespace_name = 389,
  sym__object = 390,
  sym_preproc_split_declaration = 391,
  sym__object_header = 392,
  sym_table_declaration = 393,
  sym_page_declaration = 394,
  sym_report_declaration = 395,
  sym_query_declaration = 396,
  sym_xmlport_declaration = 397,
  sym_permissionset_declaration = 398,
  sym_codeunit_declaration = 399,
  sym_enum_declaration = 400,
  sym_tableextension_declaration = 401,
  sym_pageextension_declaration = 402,
  sym_reportextension_declaration = 403,
  sym_enumextension_declaration = 404,
  sym_permissionsetextension_declaration = 405,
  sym_controladdin_declaration = 406,
  sym_preproc_conditional_controladdin = 407,
  sym_profile_declaration = 408,
  sym_entitlement_declaration = 409,
  sym_profileextension_declaration = 410,
  sym_interface_declaration = 411,
  sym_pagecustomization_declaration = 412,
  sym_dotnet_declaration = 413,
  sym_implements_clause = 414,
  sym__body_element = 415,
  sym_empty_statement = 416,
  sym_property = 417,
  sym__property_value = 418,
  sym_decimal_range_value = 419,
  sym_signed_integer_list = 420,
  sym__signed_integer = 421,
  sym_object_reference_value = 422,
  sym_property_expression = 423,
  sym_boolean = 424,
  sym_caption_value = 425,
  sym_ml_value_list = 426,
  sym_ml_value_pair = 427,
  sym__calc_formula_expression = 428,
  sym_lookup_formula = 429,
  sym_aggregate_formula = 430,
  sym_calc_field_reference = 431,
  sym_where_clause = 432,
  sym_where_conditions = 433,
  sym_preproc_conditional_where = 434,
  sym_where_condition = 435,
  sym_filter_value = 436,
  sym_sorting_value = 437,
  sym_link_value_list = 438,
  sym_preproc_conditional_link_values = 439,
  sym_link_value = 440,
  sym_table_relation_value = 441,
  sym_preproc_conditional_table_relation = 442,
  sym_table_relation_expression = 443,
  sym_if_table_relation = 444,
  sym_simple_table_relation = 445,
  sym_tabledata_permission_list = 446,
  sym_preproc_conditional_permissions = 447,
  sym_tabledata_permission = 448,
  sym_order_by_list = 449,
  sym_order_by_item = 450,
  sym_implementation_value_list = 451,
  sym_preproc_conditional_impl_values = 452,
  sym_implementation_value = 453,
  sym_option_member_list = 454,
  sym_option_member = 455,
  sym_fields_section = 456,
  sym_preproc_conditional_fields = 457,
  sym_field_declaration = 458,
  sym_keys_section = 459,
  sym_preproc_conditional_keys = 460,
  sym_key_declaration = 461,
  sym_field_list = 462,
  sym_fieldgroups_section = 463,
  sym_addlast_fieldgroup_modification = 464,
  sym_addfirst_fieldgroup_modification = 465,
  sym_preproc_conditional_fieldgroups = 466,
  sym_fieldgroup_declaration = 467,
  sym_type_specification = 468,
  sym_text_type = 469,
  sym_code_type = 470,
  sym_option_type = 471,
  sym_record_type = 472,
  sym_dotnet_type = 473,
  sym_object_reference_type = 474,
  sym__namespaced_or_simple_ref = 475,
  sym_array_type = 476,
  sym_list_type = 477,
  sym_dictionary_type = 478,
  sym_basic_type = 479,
  sym_enum_value_declaration = 480,
  sym_labels_section = 481,
  sym_label_declaration = 482,
  sym_layout_section = 483,
  sym__layout_element = 484,
  sym_area_section = 485,
  sym_preproc_split_brace_close = 486,
  sym_group_section = 487,
  sym_repeater_section = 488,
  sym_cuegroup_section = 489,
  sym_fixed_section = 490,
  sym_grid_section = 491,
  sym_page_field = 492,
  sym__field_source = 493,
  sym_part_section = 494,
  sym_systempart_section = 495,
  sym_usercontrol_section = 496,
  sym_preproc_split_field = 497,
  sym__field_header = 498,
  sym_label_section = 499,
  sym_addfirst_modification = 500,
  sym_addlast_modification = 501,
  sym_addafter_modification = 502,
  sym_addbefore_modification = 503,
  sym_modify_modification = 504,
  sym_movefirst_modification = 505,
  sym_movelast_modification = 506,
  sym_moveafter_modification = 507,
  sym_movebefore_modification = 508,
  sym_actions_section = 509,
  sym__action_element = 510,
  sym_action_area_section = 511,
  sym_action_group_section = 512,
  sym_action_declaration = 513,
  sym_separator_action = 514,
  sym_actionref_declaration = 515,
  sym_systemaction_declaration = 516,
  sym_fileuploadaction_declaration = 517,
  sym_customaction_declaration = 518,
  sym_addfirst_action_modification = 519,
  sym_addlast_action_modification = 520,
  sym_addafter_action_modification = 521,
  sym_addbefore_action_modification = 522,
  sym_modify_action_modification = 523,
  sym_views_section = 524,
  sym_addfirst_views_modification = 525,
  sym_addlast_views_modification = 526,
  sym_addafter_views_modification = 527,
  sym_addbefore_views_modification = 528,
  sym_view_definition = 529,
  sym_dataset_section = 530,
  sym_preproc_conditional_dataset = 531,
  sym_report_dataitem = 532,
  sym__report_body_element = 533,
  sym_preproc_conditional_report = 534,
  sym_report_column = 535,
  sym_add_dataset_modification = 536,
  sym_addfirst_dataset_modification = 537,
  sym_addlast_dataset_modification = 538,
  sym_addafter_dataset_modification = 539,
  sym_addbefore_dataset_modification = 540,
  sym_requestpage_section = 541,
  sym_rendering_section = 542,
  sym_rendering_layout = 543,
  sym_elements_section = 544,
  sym_query_dataitem = 545,
  sym__query_body_element = 546,
  sym_preproc_conditional_query = 547,
  sym_query_column = 548,
  sym_query_filter = 549,
  sym_schema_section = 550,
  sym_xmlport_element = 551,
  sym__xmlport_body_element = 552,
  sym_preproc_conditional_xmlport = 553,
  sym_xmlport_attribute = 554,
  sym_assembly_declaration = 555,
  sym_type_declaration = 556,
  sym_event_declaration = 557,
  sym_procedure = 558,
  sym_preproc_split_procedure_body = 559,
  sym_preproc_split_procedure = 560,
  sym__procedure_header = 561,
  sym_interface_procedure = 562,
  sym_interface_procedure_suffix = 563,
  sym_procedure_modifier = 564,
  sym__procedure_return_specification = 565,
  sym__procedure_named_return = 566,
  sym_parameter_list = 567,
  sym_parameter = 568,
  sym_code_block = 569,
  sym_trigger_declaration = 570,
  sym_preproc_conditional_var_block = 571,
  sym__trigger_name = 572,
  sym_var_section = 573,
  sym_var_attribute_item = 574,
  sym_preproc_conditional_var = 575,
  sym_variable_declaration = 576,
  sym_label_attribute = 577,
  sym_attribute_item = 578,
  sym_attribute_content = 579,
  sym_attribute_arguments = 580,
  sym_attribute_argument_list = 581,
  sym__attribute_argument = 582,
  sym_preproc_conditional = 583,
  sym_preproc_if = 584,
  sym_preproc_not_expression = 585,
  sym_preproc_elif = 586,
  sym_preproc_else = 587,
  sym_preproc_endif = 588,
  sym_preproc_split_if_statement = 589,
  sym__preproc_if_header = 590,
  sym_preproc_guarded_statement = 591,
  sym__preproc_guard_block = 592,
  sym_preproc_split_if_else_statement = 593,
  sym_preproc_split_if_then_begin = 594,
  sym_preproc_split_code_block_end = 595,
  sym_preproc_fragmented_else_tail = 596,
  sym_preproc_conditional_statement = 597,
  sym_preproc_conditional_actions = 598,
  sym_preproc_conditional_layout = 599,
  sym_preproc_conditional_layout_mixed = 600,
  sym__statement = 601,
  sym__expression_statement = 602,
  sym_assignment_statement = 603,
  sym_assignment_expression = 604,
  sym_if_statement = 605,
  sym__if_statement_no_else = 606,
  sym_case_statement = 607,
  sym_preproc_conditional_case = 608,
  sym_case_branch = 609,
  sym_preproc_split_case_branch = 610,
  aux_sym__case_pattern = 611,
  sym_preproc_conditional_case_patterns = 612,
  sym__single_pattern = 613,
  sym_case_else_branch = 614,
  sym_for_statement = 615,
  sym_foreach_statement = 616,
  sym_while_statement = 617,
  sym_repeat_statement = 618,
  sym_with_statement = 619,
  sym_exit_statement = 620,
  sym_continue_statement = 621,
  sym_break_statement = 622,
  sym_asserterror_statement = 623,
  sym__expression = 624,
  sym_keyword_identifier = 625,
  sym_range_expression = 626,
  sym_multiplicative_expression = 627,
  sym_additive_expression = 628,
  sym_comparison_expression = 629,
  sym_comparison_operator = 630,
  sym_logical_expression = 631,
  sym_ternary_expression = 632,
  sym_unary_expression = 633,
  sym_call_expression = 634,
  sym_argument_list = 635,
  sym_member_expression = 636,
  sym_subscript_expression = 637,
  sym_parenthesized_expression = 638,
  sym_list_literal = 639,
  sym_qualified_enum_value = 640,
  sym_database_reference = 641,
  sym__literal_value = 642,
  sym_if_keyword = 643,
  sym_then_keyword = 644,
  sym_else_keyword = 645,
  sym_case_keyword = 646,
  sym_of_keyword = 647,
  sym_for_keyword = 648,
  sym_foreach_keyword = 649,
  sym_while_keyword = 650,
  sym_do_keyword = 651,
  sym_repeat_keyword = 652,
  sym_until_keyword = 653,
  sym_exit_keyword = 654,
  sym_continue_keyword = 655,
  sym_break_keyword = 656,
  sym_with_keyword = 657,
  sym_in_keyword = 658,
  sym_to_keyword = 659,
  sym_downto_keyword = 660,
  sym_tableextension_keyword = 661,
  sym_pageextension_keyword = 662,
  sym_codeunit_keyword = 663,
  sym_reportextension_keyword = 664,
  sym_xmlport_keyword = 665,
  sym_enum_keyword = 666,
  sym_enumextension_keyword = 667,
  sym_controladdin_keyword = 668,
  sym_dotnet_keyword = 669,
  sym_profileextension_keyword = 670,
  sym_permissionset_keyword = 671,
  sym_permissionsetextension_keyword = 672,
  sym_pagecustomization_keyword = 673,
  sym__identifier_or_quoted = 674,
  sym_keyword_as_identifier = 675,
  aux_sym_source_file_repeat1 = 676,
  aux_sym_preproc_conditional_object_repeat1 = 677,
  aux_sym_namespace_name_repeat1 = 678,
  aux_sym_preproc_split_declaration_repeat1 = 679,
  aux_sym_preproc_split_declaration_repeat2 = 680,
  aux_sym_controladdin_declaration_repeat1 = 681,
  aux_sym_preproc_conditional_controladdin_repeat1 = 682,
  aux_sym_interface_declaration_repeat1 = 683,
  aux_sym_dotnet_declaration_repeat1 = 684,
  aux_sym_implements_clause_repeat1 = 685,
  aux_sym_signed_integer_list_repeat1 = 686,
  aux_sym_caption_value_repeat1 = 687,
  aux_sym_ml_value_list_repeat1 = 688,
  aux_sym_calc_field_reference_repeat1 = 689,
  aux_sym_where_conditions_repeat1 = 690,
  aux_sym_preproc_conditional_where_repeat1 = 691,
  aux_sym_preproc_conditional_where_repeat2 = 692,
  aux_sym_filter_value_repeat1 = 693,
  aux_sym_sorting_value_repeat1 = 694,
  aux_sym_link_value_list_repeat1 = 695,
  aux_sym_preproc_conditional_link_values_repeat1 = 696,
  aux_sym_preproc_conditional_link_values_repeat2 = 697,
  aux_sym_preproc_conditional_table_relation_repeat1 = 698,
  aux_sym_tabledata_permission_list_repeat1 = 699,
  aux_sym_preproc_conditional_permissions_repeat1 = 700,
  aux_sym_order_by_list_repeat1 = 701,
  aux_sym_implementation_value_list_repeat1 = 702,
  aux_sym_preproc_conditional_impl_values_repeat1 = 703,
  aux_sym_preproc_conditional_impl_values_repeat2 = 704,
  aux_sym_option_member_list_repeat1 = 705,
  aux_sym_option_member_list_repeat2 = 706,
  aux_sym_fields_section_repeat1 = 707,
  aux_sym_preproc_conditional_fields_repeat1 = 708,
  aux_sym_preproc_conditional_fields_repeat2 = 709,
  aux_sym_keys_section_repeat1 = 710,
  aux_sym_preproc_conditional_keys_repeat1 = 711,
  aux_sym_preproc_conditional_keys_repeat2 = 712,
  aux_sym_fieldgroups_section_repeat1 = 713,
  aux_sym_preproc_conditional_fieldgroups_repeat1 = 714,
  aux_sym_preproc_conditional_fieldgroups_repeat2 = 715,
  aux_sym__namespaced_or_simple_ref_repeat1 = 716,
  aux_sym_array_type_repeat1 = 717,
  aux_sym_labels_section_repeat1 = 718,
  aux_sym_label_declaration_repeat1 = 719,
  aux_sym_layout_section_repeat1 = 720,
  aux_sym_group_section_repeat1 = 721,
  aux_sym_preproc_split_field_repeat1 = 722,
  aux_sym_actions_section_repeat1 = 723,
  aux_sym_action_group_section_repeat1 = 724,
  aux_sym_views_section_repeat1 = 725,
  aux_sym_addfirst_views_modification_repeat1 = 726,
  aux_sym_dataset_section_repeat1 = 727,
  aux_sym_preproc_conditional_dataset_repeat1 = 728,
  aux_sym_preproc_conditional_dataset_repeat2 = 729,
  aux_sym_report_dataitem_repeat1 = 730,
  aux_sym_preproc_conditional_report_repeat1 = 731,
  aux_sym_add_dataset_modification_repeat1 = 732,
  aux_sym_rendering_section_repeat1 = 733,
  aux_sym_elements_section_repeat1 = 734,
  aux_sym_query_dataitem_repeat1 = 735,
  aux_sym_preproc_conditional_query_repeat1 = 736,
  aux_sym_schema_section_repeat1 = 737,
  aux_sym_xmlport_element_repeat1 = 738,
  aux_sym_preproc_conditional_xmlport_repeat1 = 739,
  aux_sym_assembly_declaration_repeat1 = 740,
  aux_sym_preproc_split_procedure_body_repeat1 = 741,
  aux_sym_preproc_split_procedure_repeat1 = 742,
  aux_sym__procedure_header_repeat1 = 743,
  aux_sym_parameter_list_repeat1 = 744,
  aux_sym_preproc_conditional_var_block_repeat1 = 745,
  aux_sym_var_section_repeat1 = 746,
  aux_sym_preproc_conditional_var_repeat1 = 747,
  aux_sym_preproc_conditional_var_repeat2 = 748,
  aux_sym_variable_declaration_repeat1 = 749,
  aux_sym_variable_declaration_repeat2 = 750,
  aux_sym_attribute_argument_list_repeat1 = 751,
  aux_sym_preproc_conditional_repeat1 = 752,
  aux_sym_preproc_split_if_statement_repeat1 = 753,
  aux_sym__preproc_guard_block_repeat1 = 754,
  aux_sym_preproc_split_if_else_statement_repeat1 = 755,
  aux_sym_preproc_conditional_statement_repeat1 = 756,
  aux_sym_preproc_conditional_actions_repeat1 = 757,
  aux_sym_preproc_conditional_layout_repeat1 = 758,
  aux_sym_preproc_conditional_layout_mixed_repeat1 = 759,
  aux_sym_preproc_conditional_layout_mixed_repeat2 = 760,
  aux_sym_case_statement_repeat1 = 761,
  aux_sym_preproc_conditional_case_repeat1 = 762,
  aux_sym_preproc_conditional_case_repeat2 = 763,
  aux_sym_preproc_split_case_branch_repeat1 = 764,
  aux_sym_preproc_split_case_branch_repeat2 = 765,
  aux_sym_argument_list_repeat1 = 766,
  alias_sym_aggregate_function = 767,
  alias_sym_object_type_keyword = 768,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_SEMI] = ";",
  [anon_sym_DOT] = ".",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [aux_sym_interface_declaration_token1] = "interface_declaration_token1",
  [anon_sym_EQ] = "=",
  [aux_sym_interface_declaration_token2] = "interface_declaration_token2",
  [anon_sym_COMMA] = ",",
  [anon_sym_COLON] = ":",
  [anon_sym_DASH] = "-",
  [aux_sym_boolean_token1] = "boolean_token1",
  [aux_sym_boolean_token2] = "boolean_token2",
  [sym_decimal] = "decimal",
  [aux_sym_ml_value_list_token1] = "ml_value_list_token1",
  [aux_sym_lookup_formula_token1] = "lookup_formula_token1",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [aux_sym_where_clause_token1] = "where_clause_token1",
  [aux_sym_where_condition_token1] = "where_condition_token1",
  [aux_sym_where_condition_token2] = "where_condition_token2",
  [aux_sym_where_condition_token3] = "where_condition_token3",
  [anon_sym_DOT_DOT] = "..",
  [aux_sym_filter_value_token1] = "filter_value_token1",
  [aux_sym_sorting_value_token1] = "sorting_value_token1",
  [aux_sym_sorting_value_token2] = "sorting_value_token2",
  [aux_sym_sorting_value_token3] = "sorting_value_token3",
  [aux_sym_sorting_value_token4] = "sorting_value_token4",
  [aux_sym_if_table_relation_token1] = "if_table_relation_token1",
  [aux_sym_if_table_relation_token2] = "if_table_relation_token2",
  [aux_sym_tabledata_permission_token1] = "tabledata_permission_token1",
  [aux_sym_tabledata_permission_token2] = "tabledata_permission_token2",
  [anon_sym_STAR] = "*",
  [sym_permission_type] = "permission_type",
  [aux_sym_order_by_item_token1] = "order_by_item_token1",
  [aux_sym_order_by_item_token2] = "order_by_item_token2",
  [aux_sym_addlast_fieldgroup_modification_token1] = "addlast_fieldgroup_modification_token1",
  [aux_sym_addfirst_fieldgroup_modification_token1] = "addfirst_fieldgroup_modification_token1",
  [aux_sym_text_type_token1] = "text_type_token1",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [aux_sym_code_type_token1] = "code_type_token1",
  [aux_sym_option_type_token1] = "option_type_token1",
  [aux_sym_record_type_token1] = "record_type_token1",
  [aux_sym_object_reference_type_token1] = "object_reference_type_token1",
  [aux_sym_object_reference_type_token2] = "object_reference_type_token2",
  [aux_sym_array_type_token1] = "array_type_token1",
  [aux_sym_array_type_token2] = "array_type_token2",
  [aux_sym_list_type_token1] = "list_type_token1",
  [aux_sym_dictionary_type_token1] = "dictionary_type_token1",
  [aux_sym_basic_type_token1] = "basic_type_token1",
  [aux_sym_basic_type_token2] = "basic_type_token2",
  [aux_sym_basic_type_token3] = "basic_type_token3",
  [aux_sym_basic_type_token4] = "basic_type_token4",
  [aux_sym_basic_type_token5] = "basic_type_token5",
  [aux_sym_basic_type_token6] = "basic_type_token6",
  [aux_sym_basic_type_token7] = "basic_type_token7",
  [aux_sym_basic_type_token8] = "basic_type_token8",
  [aux_sym_basic_type_token9] = "basic_type_token9",
  [aux_sym_basic_type_token10] = "basic_type_token10",
  [aux_sym_basic_type_token11] = "basic_type_token11",
  [aux_sym_basic_type_token12] = "basic_type_token12",
  [aux_sym_basic_type_token13] = "basic_type_token13",
  [aux_sym_basic_type_token14] = "basic_type_token14",
  [aux_sym_basic_type_token15] = "basic_type_token15",
  [aux_sym_basic_type_token16] = "basic_type_token16",
  [aux_sym_basic_type_token17] = "basic_type_token17",
  [aux_sym_basic_type_token18] = "basic_type_token18",
  [aux_sym_basic_type_token19] = "basic_type_token19",
  [aux_sym_basic_type_token20] = "basic_type_token20",
  [aux_sym_basic_type_token21] = "basic_type_token21",
  [aux_sym_basic_type_token22] = "basic_type_token22",
  [aux_sym_basic_type_token23] = "basic_type_token23",
  [aux_sym_basic_type_token24] = "basic_type_token24",
  [aux_sym_basic_type_token25] = "basic_type_token25",
  [aux_sym_basic_type_token26] = "basic_type_token26",
  [aux_sym_basic_type_token27] = "basic_type_token27",
  [aux_sym_basic_type_token28] = "basic_type_token28",
  [aux_sym_basic_type_token29] = "basic_type_token29",
  [aux_sym_basic_type_token30] = "basic_type_token30",
  [aux_sym_basic_type_token31] = "basic_type_token31",
  [aux_sym_basic_type_token32] = "basic_type_token32",
  [aux_sym_basic_type_token33] = "basic_type_token33",
  [aux_sym_basic_type_token34] = "basic_type_token34",
  [aux_sym_basic_type_token35] = "basic_type_token35",
  [aux_sym_basic_type_token36] = "basic_type_token36",
  [aux_sym_basic_type_token37] = "basic_type_token37",
  [aux_sym_basic_type_token38] = "basic_type_token38",
  [aux_sym_basic_type_token39] = "basic_type_token39",
  [aux_sym_basic_type_token40] = "basic_type_token40",
  [aux_sym_basic_type_token41] = "basic_type_token41",
  [aux_sym_basic_type_token42] = "basic_type_token42",
  [aux_sym_basic_type_token43] = "basic_type_token43",
  [aux_sym_basic_type_token44] = "basic_type_token44",
  [aux_sym_basic_type_token45] = "basic_type_token45",
  [aux_sym_basic_type_token46] = "basic_type_token46",
  [aux_sym_basic_type_token47] = "basic_type_token47",
  [aux_sym_basic_type_token48] = "basic_type_token48",
  [aux_sym_basic_type_token49] = "basic_type_token49",
  [aux_sym_basic_type_token50] = "basic_type_token50",
  [aux_sym_basic_type_token51] = "basic_type_token51",
  [aux_sym_basic_type_token52] = "basic_type_token52",
  [aux_sym_basic_type_token53] = "basic_type_token53",
  [aux_sym_basic_type_token54] = "basic_type_token54",
  [aux_sym_enum_value_declaration_token1] = "enum_value_declaration_token1",
  [aux_sym_label_declaration_token1] = "label_declaration_token1",
  [aux_sym_label_declaration_token2] = "label_declaration_token2",
  [aux_sym_area_section_token1] = "area_section_token1",
  [aux_sym_area_section_token2] = "area_section_token2",
  [aux_sym_area_section_token3] = "area_section_token3",
  [aux_sym_area_section_token4] = "area_section_token4",
  [aux_sym_area_section_token5] = "area_section_token5",
  [aux_sym_area_section_token6] = "area_section_token6",
  [aux_sym_area_section_token7] = "area_section_token7",
  [aux_sym_area_section_token8] = "area_section_token8",
  [aux_sym_addafter_modification_token1] = "addafter_modification_token1",
  [aux_sym_addbefore_modification_token1] = "addbefore_modification_token1",
  [aux_sym_modify_modification_token1] = "modify_modification_token1",
  [aux_sym_movefirst_modification_token1] = "movefirst_modification_token1",
  [aux_sym_movelast_modification_token1] = "movelast_modification_token1",
  [aux_sym_moveafter_modification_token1] = "moveafter_modification_token1",
  [aux_sym_movebefore_modification_token1] = "movebefore_modification_token1",
  [aux_sym_action_area_section_token1] = "action_area_section_token1",
  [aux_sym_action_area_section_token2] = "action_area_section_token2",
  [aux_sym_action_area_section_token3] = "action_area_section_token3",
  [aux_sym_action_area_section_token4] = "action_area_section_token4",
  [aux_sym_action_area_section_token5] = "action_area_section_token5",
  [aux_sym_action_area_section_token6] = "action_area_section_token6",
  [aux_sym_action_area_section_token7] = "action_area_section_token7",
  [aux_sym_separator_action_token1] = "separator_action_token1",
  [aux_sym_actionref_declaration_token1] = "actionref_declaration_token1",
  [aux_sym_systemaction_declaration_token1] = "systemaction_declaration_token1",
  [aux_sym_fileuploadaction_declaration_token1] = "fileuploadaction_declaration_token1",
  [aux_sym_customaction_declaration_token1] = "customaction_declaration_token1",
  [aux_sym_add_dataset_modification_token1] = "add_dataset_modification_token1",
  [aux_sym_xmlport_element_token1] = "xmlport_element_token1",
  [aux_sym_xmlport_element_token2] = "xmlport_element_token2",
  [aux_sym_xmlport_element_token3] = "xmlport_element_token3",
  [aux_sym_xmlport_attribute_token1] = "xmlport_attribute_token1",
  [aux_sym_xmlport_attribute_token2] = "xmlport_attribute_token2",
  [aux_sym_assembly_declaration_token1] = "assembly_declaration_token1",
  [sym_dotnet_assembly_name] = "dotnet_assembly_name",
  [aux_sym_type_declaration_token1] = "type_declaration_token1",
  [aux_sym_preproc_split_procedure_body_token1] = "preproc_split_procedure_body_token1",
  [aux_sym_preproc_split_procedure_body_token2] = "preproc_split_procedure_body_token2",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_POUNDif] = "#if",
  [anon_sym_POUNDIF] = "#IF",
  [anon_sym_POUNDIf] = "#If",
  [anon_sym_not] = "not",
  [anon_sym_NOT] = "NOT",
  [anon_sym_Not] = "Not",
  [anon_sym_POUNDelif] = "#elif",
  [anon_sym_POUNDELIF] = "#ELIF",
  [anon_sym_POUNDElif] = "#Elif",
  [anon_sym_POUNDelse] = "#else",
  [anon_sym_POUNDELSE] = "#ELSE",
  [anon_sym_POUNDElse] = "#Else",
  [anon_sym_POUNDendif] = "#endif",
  [anon_sym_POUNDENDIF] = "#ENDIF",
  [anon_sym_POUNDEndif] = "#Endif",
  [sym_pragma] = "pragma",
  [sym_preproc_region] = "preproc_region",
  [sym_preproc_endregion] = "preproc_endregion",
  [sym__assignment_operator] = "_assignment_operator",
  [anon_sym_COLON_EQ] = ":=",
  [anon_sym_LPAREN2] = "(",
  [aux_sym__expression_token1] = "_expression_token1",
  [aux_sym__expression_token2] = "_expression_token2",
  [aux_sym_keyword_identifier_token1] = "keyword_identifier_token1",
  [aux_sym_keyword_identifier_token2] = "keyword_identifier_token2",
  [anon_sym_SLASH] = "/",
  [anon_sym_div] = "div",
  [anon_sym_DIV] = "DIV",
  [anon_sym_Div] = "Div",
  [anon_sym_mod] = "mod",
  [anon_sym_MOD] = "MOD",
  [anon_sym_Mod] = "Mod",
  [anon_sym_PLUS] = "+",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_GT] = ">",
  [anon_sym_LT] = "<",
  [anon_sym_LT_GT] = "<>",
  [anon_sym_and] = "and",
  [anon_sym_AND] = "AND",
  [anon_sym_And] = "And",
  [anon_sym_or] = "or",
  [anon_sym_OR] = "OR",
  [anon_sym_Or] = "Or",
  [anon_sym_xor] = "xor",
  [anon_sym_XOR] = "XOR",
  [anon_sym_Xor] = "Xor",
  [anon_sym_QMARK] = "\?",
  [sym_datetime_literal] = "datetime_literal",
  [sym_date_literal] = "date_literal",
  [sym_time_literal] = "time_literal",
  [sym_biginteger_literal] = "biginteger_literal",
  [anon_sym_if] = "if",
  [anon_sym_IF] = "IF",
  [anon_sym_If] = "If",
  [anon_sym_then] = "then",
  [anon_sym_THEN] = "THEN",
  [anon_sym_Then] = "Then",
  [anon_sym_else] = "else",
  [anon_sym_ELSE] = "ELSE",
  [anon_sym_Else] = "Else",
  [anon_sym_case] = "case",
  [anon_sym_CASE] = "CASE",
  [anon_sym_Case] = "Case",
  [anon_sym_of] = "of",
  [anon_sym_OF] = "OF",
  [anon_sym_Of] = "Of",
  [anon_sym_for] = "for",
  [anon_sym_FOR] = "FOR",
  [anon_sym_For] = "For",
  [anon_sym_foreach] = "foreach",
  [anon_sym_FOREACH] = "FOREACH",
  [anon_sym_Foreach] = "Foreach",
  [anon_sym_while] = "while",
  [anon_sym_WHILE] = "WHILE",
  [anon_sym_While] = "While",
  [anon_sym_do] = "do",
  [anon_sym_DO] = "DO",
  [anon_sym_Do] = "Do",
  [anon_sym_repeat] = "repeat",
  [anon_sym_REPEAT] = "REPEAT",
  [anon_sym_Repeat] = "Repeat",
  [anon_sym_until] = "until",
  [anon_sym_UNTIL] = "UNTIL",
  [anon_sym_Until] = "Until",
  [anon_sym_exit] = "exit",
  [anon_sym_EXIT] = "EXIT",
  [anon_sym_Exit] = "Exit",
  [anon_sym_continue] = "continue",
  [anon_sym_CONTINUE] = "CONTINUE",
  [anon_sym_Continue] = "Continue",
  [anon_sym_break] = "break",
  [anon_sym_BREAK] = "BREAK",
  [anon_sym_Break] = "Break",
  [anon_sym_with] = "with",
  [anon_sym_WITH] = "WITH",
  [anon_sym_With] = "With",
  [sym_asserterror_keyword] = "asserterror_keyword",
  [anon_sym_in] = "in",
  [anon_sym_IN] = "IN",
  [anon_sym_In] = "In",
  [anon_sym_to] = "to",
  [anon_sym_TO] = "TO",
  [anon_sym_To] = "To",
  [anon_sym_downto] = "downto",
  [anon_sym_DOWNTO] = "DOWNTO",
  [anon_sym_Downto] = "Downto",
  [sym_table_keyword] = "table_keyword",
  [anon_sym_tableextension] = "tableextension",
  [anon_sym_TABLEEXTENSION] = "TABLEEXTENSION",
  [anon_sym_Tableextension] = "Tableextension",
  [anon_sym_TableExtension] = "TableExtension",
  [anon_sym_tableExtension] = "tableExtension",
  [sym_page_keyword] = "page_keyword",
  [anon_sym_pageextension] = "pageextension",
  [anon_sym_PAGEEXTENSION] = "PAGEEXTENSION",
  [anon_sym_Pageextension] = "Pageextension",
  [anon_sym_PageExtension] = "PageExtension",
  [anon_sym_pageExtension] = "pageExtension",
  [anon_sym_codeunit] = "codeunit",
  [anon_sym_CODEUNIT] = "CODEUNIT",
  [anon_sym_Codeunit] = "Codeunit",
  [anon_sym_CodeUnit] = "CodeUnit",
  [anon_sym_COdeunit] = "COdeunit",
  [anon_sym_codeUnit] = "codeUnit",
  [sym_report_keyword] = "report_keyword",
  [anon_sym_reportextension] = "reportextension",
  [anon_sym_REPORTEXTENSION] = "REPORTEXTENSION",
  [anon_sym_Reportextension] = "Reportextension",
  [anon_sym_ReportExtension] = "ReportExtension",
  [anon_sym_reportExtension] = "reportExtension",
  [sym_query_keyword] = "query_keyword",
  [anon_sym_xmlport] = "xmlport",
  [anon_sym_XMLPORT] = "XMLPORT",
  [anon_sym_Xmlport] = "Xmlport",
  [anon_sym_XMLport] = "XMLport",
  [anon_sym_XMLPort] = "XMLPort",
  [anon_sym_XmlPort] = "XmlPort",
  [anon_sym_enum] = "enum",
  [anon_sym_ENUM] = "ENUM",
  [anon_sym_Enum] = "Enum",
  [anon_sym_eNUM] = "eNUM",
  [anon_sym_eNum] = "eNum",
  [anon_sym_ENum] = "ENum",
  [anon_sym_enumextension] = "enumextension",
  [anon_sym_ENUMEXTENSION] = "ENUMEXTENSION",
  [anon_sym_Enumextension] = "Enumextension",
  [anon_sym_EnumExtension] = "EnumExtension",
  [anon_sym_enumExtension] = "enumExtension",
  [sym_interface_keyword] = "interface_keyword",
  [anon_sym_controladdin] = "controladdin",
  [anon_sym_CONTROLADDIN] = "CONTROLADDIN",
  [anon_sym_Controladdin] = "Controladdin",
  [anon_sym_ControlAddIn] = "ControlAddIn",
  [anon_sym_ControlAddin] = "ControlAddin",
  [anon_sym_controlAddIn] = "controlAddIn",
  [anon_sym_controlAddin] = "controlAddin",
  [anon_sym_dotnet] = "dotnet",
  [anon_sym_DOTNET] = "DOTNET",
  [anon_sym_Dotnet] = "Dotnet",
  [anon_sym_DotNet] = "DotNet",
  [anon_sym_dotNet] = "dotNet",
  [sym_profile_keyword] = "profile_keyword",
  [anon_sym_profileextension] = "profileextension",
  [anon_sym_PROFILEEXTENSION] = "PROFILEEXTENSION",
  [anon_sym_Profileextension] = "Profileextension",
  [anon_sym_ProfileExtension] = "ProfileExtension",
  [anon_sym_profileExtension] = "profileExtension",
  [anon_sym_permissionset] = "permissionset",
  [anon_sym_PERMISSIONSET] = "PERMISSIONSET",
  [anon_sym_Permissionset] = "Permissionset",
  [anon_sym_PermissionSet] = "PermissionSet",
  [anon_sym_permissionSet] = "permissionSet",
  [anon_sym_permissionsetextension] = "permissionsetextension",
  [anon_sym_PERMISSIONSETEXTENSION] = "PERMISSIONSETEXTENSION",
  [anon_sym_Permissionsetextension] = "Permissionsetextension",
  [anon_sym_PermissionSetExtension] = "PermissionSetExtension",
  [anon_sym_permissionSetExtension] = "permissionSetExtension",
  [sym_entitlement_keyword] = "entitlement_keyword",
  [anon_sym_pagecustomization] = "pagecustomization",
  [anon_sym_PAGECUSTOMIZATION] = "PAGECUSTOMIZATION",
  [anon_sym_Pagecustomization] = "Pagecustomization",
  [anon_sym_PageCustomization] = "PageCustomization",
  [anon_sym_pageCustomization] = "pageCustomization",
  [sym_namespace_keyword] = "namespace_keyword",
  [sym_using_keyword] = "using_keyword",
  [sym_implements_keyword] = "implements_keyword",
  [sym_extends_keyword] = "extends_keyword",
  [sym_customizes_keyword] = "customizes_keyword",
  [sym_procedure_keyword] = "procedure_keyword",
  [sym_trigger_keyword] = "trigger_keyword",
  [sym_var_keyword] = "var_keyword",
  [sym_local_keyword] = "local_keyword",
  [sym_internal_keyword] = "internal_keyword",
  [sym_protected_keyword] = "protected_keyword",
  [sym_event_keyword] = "event_keyword",
  [sym_temporary_keyword] = "temporary_keyword",
  [sym_fields_keyword] = "fields_keyword",
  [sym_keys_keyword] = "keys_keyword",
  [sym_key_keyword] = "key_keyword",
  [sym_fieldgroups_keyword] = "fieldgroups_keyword",
  [sym_fieldgroup_keyword] = "fieldgroup_keyword",
  [sym_actions_keyword] = "actions_keyword",
  [sym_layout_keyword] = "layout_keyword",
  [sym_area_keyword] = "area_keyword",
  [sym_group_keyword] = "group_keyword",
  [sym_repeater_keyword] = "repeater_keyword",
  [sym_cuegroup_keyword] = "cuegroup_keyword",
  [sym_fixed_keyword] = "fixed_keyword",
  [sym_grid_keyword] = "grid_keyword",
  [sym_part_keyword] = "part_keyword",
  [sym_systempart_keyword] = "systempart_keyword",
  [sym_usercontrol_keyword] = "usercontrol_keyword",
  [sym_dataset_keyword] = "dataset_keyword",
  [sym_elements_keyword] = "elements_keyword",
  [sym_dataitem_keyword] = "dataitem_keyword",
  [sym_column_keyword] = "column_keyword",
  [sym_filter_keyword] = "filter_keyword",
  [sym_labels_keyword] = "labels_keyword",
  [sym_rendering_keyword] = "rendering_keyword",
  [sym_requestpage_keyword] = "requestpage_keyword",
  [sym_schema_keyword] = "schema_keyword",
  [sym_views_keyword] = "views_keyword",
  [sym_view_keyword] = "view_keyword",
  [sym_quoted_identifier] = "quoted_identifier",
  [sym_comment] = "comment",
  [sym_multiline_comment] = "multiline_comment",
  [sym_string_literal] = "string_literal",
  [sym_integer] = "integer",
  [sym_property_name] = "property_name",
  [sym_continue_as_identifier] = "identifier",
  [sym_preproc_open] = "preproc_open",
  [sym_preproc_close] = "preproc_close",
  [sym_begin_keyword] = "begin_keyword",
  [sym_end_keyword] = "end_keyword",
  [sym_preproc_split_begin] = "preproc_split_begin",
  [sym_preproc_split_end] = "preproc_split_end",
  [sym_var_attribute_open] = "var_attribute_open",
  [sym_source_file] = "source_file",
  [sym_preproc_conditional_object] = "preproc_conditional_object",
  [sym_namespace_declaration] = "namespace_declaration",
  [sym_using_statement] = "using_statement",
  [sym_namespace_name] = "namespace_name",
  [sym__object] = "_object",
  [sym_preproc_split_declaration] = "preproc_split_declaration",
  [sym__object_header] = "_object_header",
  [sym_table_declaration] = "table_declaration",
  [sym_page_declaration] = "page_declaration",
  [sym_report_declaration] = "report_declaration",
  [sym_query_declaration] = "query_declaration",
  [sym_xmlport_declaration] = "xmlport_declaration",
  [sym_permissionset_declaration] = "permissionset_declaration",
  [sym_codeunit_declaration] = "codeunit_declaration",
  [sym_enum_declaration] = "enum_declaration",
  [sym_tableextension_declaration] = "tableextension_declaration",
  [sym_pageextension_declaration] = "pageextension_declaration",
  [sym_reportextension_declaration] = "reportextension_declaration",
  [sym_enumextension_declaration] = "enumextension_declaration",
  [sym_permissionsetextension_declaration] = "permissionsetextension_declaration",
  [sym_controladdin_declaration] = "controladdin_declaration",
  [sym_preproc_conditional_controladdin] = "preproc_conditional_controladdin",
  [sym_profile_declaration] = "profile_declaration",
  [sym_entitlement_declaration] = "entitlement_declaration",
  [sym_profileextension_declaration] = "profileextension_declaration",
  [sym_interface_declaration] = "interface_declaration",
  [sym_pagecustomization_declaration] = "pagecustomization_declaration",
  [sym_dotnet_declaration] = "dotnet_declaration",
  [sym_implements_clause] = "implements_clause",
  [sym__body_element] = "_body_element",
  [sym_empty_statement] = "empty_statement",
  [sym_property] = "property",
  [sym__property_value] = "_property_value",
  [sym_decimal_range_value] = "decimal_range_value",
  [sym_signed_integer_list] = "signed_integer_list",
  [sym__signed_integer] = "_signed_integer",
  [sym_object_reference_value] = "object_reference_value",
  [sym_property_expression] = "property_expression",
  [sym_boolean] = "boolean",
  [sym_caption_value] = "caption_value",
  [sym_ml_value_list] = "ml_value_list",
  [sym_ml_value_pair] = "ml_value_pair",
  [sym__calc_formula_expression] = "_calc_formula_expression",
  [sym_lookup_formula] = "lookup_formula",
  [sym_aggregate_formula] = "aggregate_formula",
  [sym_calc_field_reference] = "calc_field_reference",
  [sym_where_clause] = "where_clause",
  [sym_where_conditions] = "where_conditions",
  [sym_preproc_conditional_where] = "preproc_conditional_where",
  [sym_where_condition] = "where_condition",
  [sym_filter_value] = "filter_value",
  [sym_sorting_value] = "sorting_value",
  [sym_link_value_list] = "link_value_list",
  [sym_preproc_conditional_link_values] = "preproc_conditional_link_values",
  [sym_link_value] = "link_value",
  [sym_table_relation_value] = "table_relation_value",
  [sym_preproc_conditional_table_relation] = "preproc_conditional_table_relation",
  [sym_table_relation_expression] = "table_relation_expression",
  [sym_if_table_relation] = "if_table_relation",
  [sym_simple_table_relation] = "simple_table_relation",
  [sym_tabledata_permission_list] = "tabledata_permission_list",
  [sym_preproc_conditional_permissions] = "preproc_conditional_permissions",
  [sym_tabledata_permission] = "tabledata_permission",
  [sym_order_by_list] = "order_by_list",
  [sym_order_by_item] = "order_by_item",
  [sym_implementation_value_list] = "implementation_value_list",
  [sym_preproc_conditional_impl_values] = "preproc_conditional_impl_values",
  [sym_implementation_value] = "implementation_value",
  [sym_option_member_list] = "option_member_list",
  [sym_option_member] = "option_member",
  [sym_fields_section] = "fields_section",
  [sym_preproc_conditional_fields] = "preproc_conditional_fields",
  [sym_field_declaration] = "field_declaration",
  [sym_keys_section] = "keys_section",
  [sym_preproc_conditional_keys] = "preproc_conditional_keys",
  [sym_key_declaration] = "key_declaration",
  [sym_field_list] = "field_list",
  [sym_fieldgroups_section] = "fieldgroups_section",
  [sym_addlast_fieldgroup_modification] = "addlast_fieldgroup_modification",
  [sym_addfirst_fieldgroup_modification] = "addfirst_fieldgroup_modification",
  [sym_preproc_conditional_fieldgroups] = "preproc_conditional_fieldgroups",
  [sym_fieldgroup_declaration] = "fieldgroup_declaration",
  [sym_type_specification] = "type_specification",
  [sym_text_type] = "text_type",
  [sym_code_type] = "code_type",
  [sym_option_type] = "option_type",
  [sym_record_type] = "record_type",
  [sym_dotnet_type] = "dotnet_type",
  [sym_object_reference_type] = "object_reference_type",
  [sym__namespaced_or_simple_ref] = "_namespaced_or_simple_ref",
  [sym_array_type] = "array_type",
  [sym_list_type] = "list_type",
  [sym_dictionary_type] = "dictionary_type",
  [sym_basic_type] = "basic_type",
  [sym_enum_value_declaration] = "enum_value_declaration",
  [sym_labels_section] = "labels_section",
  [sym_label_declaration] = "label_declaration",
  [sym_layout_section] = "layout_section",
  [sym__layout_element] = "_layout_element",
  [sym_area_section] = "area_section",
  [sym_preproc_split_brace_close] = "preproc_split_brace_close",
  [sym_group_section] = "group_section",
  [sym_repeater_section] = "repeater_section",
  [sym_cuegroup_section] = "cuegroup_section",
  [sym_fixed_section] = "fixed_section",
  [sym_grid_section] = "grid_section",
  [sym_page_field] = "page_field",
  [sym__field_source] = "_field_source",
  [sym_part_section] = "part_section",
  [sym_systempart_section] = "systempart_section",
  [sym_usercontrol_section] = "usercontrol_section",
  [sym_preproc_split_field] = "preproc_split_field",
  [sym__field_header] = "_field_header",
  [sym_label_section] = "label_section",
  [sym_addfirst_modification] = "addfirst_modification",
  [sym_addlast_modification] = "addlast_modification",
  [sym_addafter_modification] = "addafter_modification",
  [sym_addbefore_modification] = "addbefore_modification",
  [sym_modify_modification] = "modify_modification",
  [sym_movefirst_modification] = "movefirst_modification",
  [sym_movelast_modification] = "movelast_modification",
  [sym_moveafter_modification] = "moveafter_modification",
  [sym_movebefore_modification] = "movebefore_modification",
  [sym_actions_section] = "actions_section",
  [sym__action_element] = "_action_element",
  [sym_action_area_section] = "action_area_section",
  [sym_action_group_section] = "action_group_section",
  [sym_action_declaration] = "action_declaration",
  [sym_separator_action] = "separator_action",
  [sym_actionref_declaration] = "actionref_declaration",
  [sym_systemaction_declaration] = "systemaction_declaration",
  [sym_fileuploadaction_declaration] = "fileuploadaction_declaration",
  [sym_customaction_declaration] = "customaction_declaration",
  [sym_addfirst_action_modification] = "addfirst_action_modification",
  [sym_addlast_action_modification] = "addlast_action_modification",
  [sym_addafter_action_modification] = "addafter_action_modification",
  [sym_addbefore_action_modification] = "addbefore_action_modification",
  [sym_modify_action_modification] = "modify_action_modification",
  [sym_views_section] = "views_section",
  [sym_addfirst_views_modification] = "addfirst_views_modification",
  [sym_addlast_views_modification] = "addlast_views_modification",
  [sym_addafter_views_modification] = "addafter_views_modification",
  [sym_addbefore_views_modification] = "addbefore_views_modification",
  [sym_view_definition] = "view_definition",
  [sym_dataset_section] = "dataset_section",
  [sym_preproc_conditional_dataset] = "preproc_conditional_dataset",
  [sym_report_dataitem] = "report_dataitem",
  [sym__report_body_element] = "_report_body_element",
  [sym_preproc_conditional_report] = "preproc_conditional_report",
  [sym_report_column] = "report_column",
  [sym_add_dataset_modification] = "add_dataset_modification",
  [sym_addfirst_dataset_modification] = "addfirst_dataset_modification",
  [sym_addlast_dataset_modification] = "addlast_dataset_modification",
  [sym_addafter_dataset_modification] = "addafter_dataset_modification",
  [sym_addbefore_dataset_modification] = "addbefore_dataset_modification",
  [sym_requestpage_section] = "requestpage_section",
  [sym_rendering_section] = "rendering_section",
  [sym_rendering_layout] = "rendering_layout",
  [sym_elements_section] = "elements_section",
  [sym_query_dataitem] = "query_dataitem",
  [sym__query_body_element] = "_query_body_element",
  [sym_preproc_conditional_query] = "preproc_conditional_query",
  [sym_query_column] = "query_column",
  [sym_query_filter] = "query_filter",
  [sym_schema_section] = "schema_section",
  [sym_xmlport_element] = "xmlport_element",
  [sym__xmlport_body_element] = "_xmlport_body_element",
  [sym_preproc_conditional_xmlport] = "preproc_conditional_xmlport",
  [sym_xmlport_attribute] = "xmlport_attribute",
  [sym_assembly_declaration] = "assembly_declaration",
  [sym_type_declaration] = "type_declaration",
  [sym_event_declaration] = "event_declaration",
  [sym_procedure] = "procedure",
  [sym_preproc_split_procedure_body] = "preproc_split_procedure_body",
  [sym_preproc_split_procedure] = "preproc_split_procedure",
  [sym__procedure_header] = "_procedure_header",
  [sym_interface_procedure] = "interface_procedure",
  [sym_interface_procedure_suffix] = "interface_procedure_suffix",
  [sym_procedure_modifier] = "procedure_modifier",
  [sym__procedure_return_specification] = "_procedure_return_specification",
  [sym__procedure_named_return] = "_procedure_named_return",
  [sym_parameter_list] = "parameter_list",
  [sym_parameter] = "parameter",
  [sym_code_block] = "code_block",
  [sym_trigger_declaration] = "trigger_declaration",
  [sym_preproc_conditional_var_block] = "preproc_conditional_var_block",
  [sym__trigger_name] = "_trigger_name",
  [sym_var_section] = "var_section",
  [sym_var_attribute_item] = "var_attribute_item",
  [sym_preproc_conditional_var] = "preproc_conditional_var",
  [sym_variable_declaration] = "variable_declaration",
  [sym_label_attribute] = "label_attribute",
  [sym_attribute_item] = "attribute_item",
  [sym_attribute_content] = "attribute_content",
  [sym_attribute_arguments] = "attribute_arguments",
  [sym_attribute_argument_list] = "attribute_argument_list",
  [sym__attribute_argument] = "_attribute_argument",
  [sym_preproc_conditional] = "preproc_conditional",
  [sym_preproc_if] = "preproc_if",
  [sym_preproc_not_expression] = "preproc_not_expression",
  [sym_preproc_elif] = "preproc_elif",
  [sym_preproc_else] = "preproc_else",
  [sym_preproc_endif] = "preproc_endif",
  [sym_preproc_split_if_statement] = "preproc_split_if_statement",
  [sym__preproc_if_header] = "_preproc_if_header",
  [sym_preproc_guarded_statement] = "preproc_guarded_statement",
  [sym__preproc_guard_block] = "_preproc_guard_block",
  [sym_preproc_split_if_else_statement] = "preproc_split_if_else_statement",
  [sym_preproc_split_if_then_begin] = "preproc_split_if_then_begin",
  [sym_preproc_split_code_block_end] = "preproc_split_code_block_end",
  [sym_preproc_fragmented_else_tail] = "preproc_fragmented_else_tail",
  [sym_preproc_conditional_statement] = "preproc_conditional_statement",
  [sym_preproc_conditional_actions] = "preproc_conditional_actions",
  [sym_preproc_conditional_layout] = "preproc_conditional_layout",
  [sym_preproc_conditional_layout_mixed] = "preproc_conditional_layout_mixed",
  [sym__statement] = "_statement",
  [sym__expression_statement] = "_expression_statement",
  [sym_assignment_statement] = "assignment_statement",
  [sym_assignment_expression] = "assignment_expression",
  [sym_if_statement] = "if_statement",
  [sym__if_statement_no_else] = "if_statement",
  [sym_case_statement] = "case_statement",
  [sym_preproc_conditional_case] = "preproc_conditional_case",
  [sym_case_branch] = "case_branch",
  [sym_preproc_split_case_branch] = "preproc_split_case_branch",
  [aux_sym__case_pattern] = "_case_pattern",
  [sym_preproc_conditional_case_patterns] = "preproc_conditional_case_patterns",
  [sym__single_pattern] = "_single_pattern",
  [sym_case_else_branch] = "case_else_branch",
  [sym_for_statement] = "for_statement",
  [sym_foreach_statement] = "foreach_statement",
  [sym_while_statement] = "while_statement",
  [sym_repeat_statement] = "repeat_statement",
  [sym_with_statement] = "with_statement",
  [sym_exit_statement] = "exit_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_break_statement] = "break_statement",
  [sym_asserterror_statement] = "asserterror_statement",
  [sym__expression] = "_expression",
  [sym_keyword_identifier] = "keyword_identifier",
  [sym_range_expression] = "range_expression",
  [sym_multiplicative_expression] = "multiplicative_expression",
  [sym_additive_expression] = "additive_expression",
  [sym_comparison_expression] = "comparison_expression",
  [sym_comparison_operator] = "comparison_operator",
  [sym_logical_expression] = "logical_expression",
  [sym_ternary_expression] = "ternary_expression",
  [sym_unary_expression] = "unary_expression",
  [sym_call_expression] = "call_expression",
  [sym_argument_list] = "argument_list",
  [sym_member_expression] = "member_expression",
  [sym_subscript_expression] = "subscript_expression",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_list_literal] = "list_literal",
  [sym_qualified_enum_value] = "qualified_enum_value",
  [sym_database_reference] = "database_reference",
  [sym__literal_value] = "_literal_value",
  [sym_if_keyword] = "if_keyword",
  [sym_then_keyword] = "then_keyword",
  [sym_else_keyword] = "else_keyword",
  [sym_case_keyword] = "case_keyword",
  [sym_of_keyword] = "of_keyword",
  [sym_for_keyword] = "for_keyword",
  [sym_foreach_keyword] = "foreach_keyword",
  [sym_while_keyword] = "while_keyword",
  [sym_do_keyword] = "do_keyword",
  [sym_repeat_keyword] = "repeat_keyword",
  [sym_until_keyword] = "until_keyword",
  [sym_exit_keyword] = "exit_keyword",
  [sym_continue_keyword] = "continue_keyword",
  [sym_break_keyword] = "break_keyword",
  [sym_with_keyword] = "with_keyword",
  [sym_in_keyword] = "in_keyword",
  [sym_to_keyword] = "to_keyword",
  [sym_downto_keyword] = "downto_keyword",
  [sym_tableextension_keyword] = "tableextension_keyword",
  [sym_pageextension_keyword] = "pageextension_keyword",
  [sym_codeunit_keyword] = "codeunit_keyword",
  [sym_reportextension_keyword] = "reportextension_keyword",
  [sym_xmlport_keyword] = "xmlport_keyword",
  [sym_enum_keyword] = "enum_keyword",
  [sym_enumextension_keyword] = "enumextension_keyword",
  [sym_controladdin_keyword] = "controladdin_keyword",
  [sym_dotnet_keyword] = "dotnet_keyword",
  [sym_profileextension_keyword] = "profileextension_keyword",
  [sym_permissionset_keyword] = "permissionset_keyword",
  [sym_permissionsetextension_keyword] = "permissionsetextension_keyword",
  [sym_pagecustomization_keyword] = "pagecustomization_keyword",
  [sym__identifier_or_quoted] = "_identifier_or_quoted",
  [sym_keyword_as_identifier] = "identifier",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_preproc_conditional_object_repeat1] = "preproc_conditional_object_repeat1",
  [aux_sym_namespace_name_repeat1] = "namespace_name_repeat1",
  [aux_sym_preproc_split_declaration_repeat1] = "preproc_split_declaration_repeat1",
  [aux_sym_preproc_split_declaration_repeat2] = "preproc_split_declaration_repeat2",
  [aux_sym_controladdin_declaration_repeat1] = "controladdin_declaration_repeat1",
  [aux_sym_preproc_conditional_controladdin_repeat1] = "preproc_conditional_controladdin_repeat1",
  [aux_sym_interface_declaration_repeat1] = "interface_declaration_repeat1",
  [aux_sym_dotnet_declaration_repeat1] = "dotnet_declaration_repeat1",
  [aux_sym_implements_clause_repeat1] = "implements_clause_repeat1",
  [aux_sym_signed_integer_list_repeat1] = "signed_integer_list_repeat1",
  [aux_sym_caption_value_repeat1] = "caption_value_repeat1",
  [aux_sym_ml_value_list_repeat1] = "ml_value_list_repeat1",
  [aux_sym_calc_field_reference_repeat1] = "calc_field_reference_repeat1",
  [aux_sym_where_conditions_repeat1] = "where_conditions_repeat1",
  [aux_sym_preproc_conditional_where_repeat1] = "preproc_conditional_where_repeat1",
  [aux_sym_preproc_conditional_where_repeat2] = "preproc_conditional_where_repeat2",
  [aux_sym_filter_value_repeat1] = "filter_value_repeat1",
  [aux_sym_sorting_value_repeat1] = "sorting_value_repeat1",
  [aux_sym_link_value_list_repeat1] = "link_value_list_repeat1",
  [aux_sym_preproc_conditional_link_values_repeat1] = "preproc_conditional_link_values_repeat1",
  [aux_sym_preproc_conditional_link_values_repeat2] = "preproc_conditional_link_values_repeat2",
  [aux_sym_preproc_conditional_table_relation_repeat1] = "preproc_conditional_table_relation_repeat1",
  [aux_sym_tabledata_permission_list_repeat1] = "tabledata_permission_list_repeat1",
  [aux_sym_preproc_conditional_permissions_repeat1] = "preproc_conditional_permissions_repeat1",
  [aux_sym_order_by_list_repeat1] = "order_by_list_repeat1",
  [aux_sym_implementation_value_list_repeat1] = "implementation_value_list_repeat1",
  [aux_sym_preproc_conditional_impl_values_repeat1] = "preproc_conditional_impl_values_repeat1",
  [aux_sym_preproc_conditional_impl_values_repeat2] = "preproc_conditional_impl_values_repeat2",
  [aux_sym_option_member_list_repeat1] = "option_member_list_repeat1",
  [aux_sym_option_member_list_repeat2] = "option_member_list_repeat2",
  [aux_sym_fields_section_repeat1] = "fields_section_repeat1",
  [aux_sym_preproc_conditional_fields_repeat1] = "preproc_conditional_fields_repeat1",
  [aux_sym_preproc_conditional_fields_repeat2] = "preproc_conditional_fields_repeat2",
  [aux_sym_keys_section_repeat1] = "keys_section_repeat1",
  [aux_sym_preproc_conditional_keys_repeat1] = "preproc_conditional_keys_repeat1",
  [aux_sym_preproc_conditional_keys_repeat2] = "preproc_conditional_keys_repeat2",
  [aux_sym_fieldgroups_section_repeat1] = "fieldgroups_section_repeat1",
  [aux_sym_preproc_conditional_fieldgroups_repeat1] = "preproc_conditional_fieldgroups_repeat1",
  [aux_sym_preproc_conditional_fieldgroups_repeat2] = "preproc_conditional_fieldgroups_repeat2",
  [aux_sym__namespaced_or_simple_ref_repeat1] = "_namespaced_or_simple_ref_repeat1",
  [aux_sym_array_type_repeat1] = "array_type_repeat1",
  [aux_sym_labels_section_repeat1] = "labels_section_repeat1",
  [aux_sym_label_declaration_repeat1] = "label_declaration_repeat1",
  [aux_sym_layout_section_repeat1] = "layout_section_repeat1",
  [aux_sym_group_section_repeat1] = "group_section_repeat1",
  [aux_sym_preproc_split_field_repeat1] = "preproc_split_field_repeat1",
  [aux_sym_actions_section_repeat1] = "actions_section_repeat1",
  [aux_sym_action_group_section_repeat1] = "action_group_section_repeat1",
  [aux_sym_views_section_repeat1] = "views_section_repeat1",
  [aux_sym_addfirst_views_modification_repeat1] = "addfirst_views_modification_repeat1",
  [aux_sym_dataset_section_repeat1] = "dataset_section_repeat1",
  [aux_sym_preproc_conditional_dataset_repeat1] = "preproc_conditional_dataset_repeat1",
  [aux_sym_preproc_conditional_dataset_repeat2] = "preproc_conditional_dataset_repeat2",
  [aux_sym_report_dataitem_repeat1] = "report_dataitem_repeat1",
  [aux_sym_preproc_conditional_report_repeat1] = "preproc_conditional_report_repeat1",
  [aux_sym_add_dataset_modification_repeat1] = "add_dataset_modification_repeat1",
  [aux_sym_rendering_section_repeat1] = "rendering_section_repeat1",
  [aux_sym_elements_section_repeat1] = "elements_section_repeat1",
  [aux_sym_query_dataitem_repeat1] = "query_dataitem_repeat1",
  [aux_sym_preproc_conditional_query_repeat1] = "preproc_conditional_query_repeat1",
  [aux_sym_schema_section_repeat1] = "schema_section_repeat1",
  [aux_sym_xmlport_element_repeat1] = "xmlport_element_repeat1",
  [aux_sym_preproc_conditional_xmlport_repeat1] = "preproc_conditional_xmlport_repeat1",
  [aux_sym_assembly_declaration_repeat1] = "assembly_declaration_repeat1",
  [aux_sym_preproc_split_procedure_body_repeat1] = "preproc_split_procedure_body_repeat1",
  [aux_sym_preproc_split_procedure_repeat1] = "preproc_split_procedure_repeat1",
  [aux_sym__procedure_header_repeat1] = "_procedure_header_repeat1",
  [aux_sym_parameter_list_repeat1] = "parameter_list_repeat1",
  [aux_sym_preproc_conditional_var_block_repeat1] = "preproc_conditional_var_block_repeat1",
  [aux_sym_var_section_repeat1] = "var_section_repeat1",
  [aux_sym_preproc_conditional_var_repeat1] = "preproc_conditional_var_repeat1",
  [aux_sym_preproc_conditional_var_repeat2] = "preproc_conditional_var_repeat2",
  [aux_sym_variable_declaration_repeat1] = "variable_declaration_repeat1",
  [aux_sym_variable_declaration_repeat2] = "variable_declaration_repeat2",
  [aux_sym_attribute_argument_list_repeat1] = "attribute_argument_list_repeat1",
  [aux_sym_preproc_conditional_repeat1] = "preproc_conditional_repeat1",
  [aux_sym_preproc_split_if_statement_repeat1] = "preproc_split_if_statement_repeat1",
  [aux_sym__preproc_guard_block_repeat1] = "_preproc_guard_block_repeat1",
  [aux_sym_preproc_split_if_else_statement_repeat1] = "preproc_split_if_else_statement_repeat1",
  [aux_sym_preproc_conditional_statement_repeat1] = "preproc_conditional_statement_repeat1",
  [aux_sym_preproc_conditional_actions_repeat1] = "preproc_conditional_actions_repeat1",
  [aux_sym_preproc_conditional_layout_repeat1] = "preproc_conditional_layout_repeat1",
  [aux_sym_preproc_conditional_layout_mixed_repeat1] = "preproc_conditional_layout_mixed_repeat1",
  [aux_sym_preproc_conditional_layout_mixed_repeat2] = "preproc_conditional_layout_mixed_repeat2",
  [aux_sym_case_statement_repeat1] = "case_statement_repeat1",
  [aux_sym_preproc_conditional_case_repeat1] = "preproc_conditional_case_repeat1",
  [aux_sym_preproc_conditional_case_repeat2] = "preproc_conditional_case_repeat2",
  [aux_sym_preproc_split_case_branch_repeat1] = "preproc_split_case_branch_repeat1",
  [aux_sym_preproc_split_case_branch_repeat2] = "preproc_split_case_branch_repeat2",
  [aux_sym_argument_list_repeat1] = "argument_list_repeat1",
  [alias_sym_aggregate_function] = "aggregate_function",
  [alias_sym_object_type_keyword] = "object_type_keyword",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [aux_sym_interface_declaration_token1] = aux_sym_interface_declaration_token1,
  [anon_sym_EQ] = anon_sym_EQ,
  [aux_sym_interface_declaration_token2] = aux_sym_interface_declaration_token2,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_DASH] = anon_sym_DASH,
  [aux_sym_boolean_token1] = aux_sym_boolean_token1,
  [aux_sym_boolean_token2] = aux_sym_boolean_token2,
  [sym_decimal] = sym_decimal,
  [aux_sym_ml_value_list_token1] = aux_sym_ml_value_list_token1,
  [aux_sym_lookup_formula_token1] = aux_sym_lookup_formula_token1,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [aux_sym_where_clause_token1] = aux_sym_where_clause_token1,
  [aux_sym_where_condition_token1] = aux_sym_where_condition_token1,
  [aux_sym_where_condition_token2] = aux_sym_where_condition_token2,
  [aux_sym_where_condition_token3] = aux_sym_where_condition_token3,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [aux_sym_filter_value_token1] = aux_sym_filter_value_token1,
  [aux_sym_sorting_value_token1] = aux_sym_sorting_value_token1,
  [aux_sym_sorting_value_token2] = aux_sym_sorting_value_token2,
  [aux_sym_sorting_value_token3] = aux_sym_sorting_value_token3,
  [aux_sym_sorting_value_token4] = aux_sym_sorting_value_token4,
  [aux_sym_if_table_relation_token1] = aux_sym_if_table_relation_token1,
  [aux_sym_if_table_relation_token2] = aux_sym_if_table_relation_token2,
  [aux_sym_tabledata_permission_token1] = aux_sym_tabledata_permission_token1,
  [aux_sym_tabledata_permission_token2] = aux_sym_tabledata_permission_token2,
  [anon_sym_STAR] = anon_sym_STAR,
  [sym_permission_type] = sym_permission_type,
  [aux_sym_order_by_item_token1] = aux_sym_order_by_item_token1,
  [aux_sym_order_by_item_token2] = aux_sym_order_by_item_token2,
  [aux_sym_addlast_fieldgroup_modification_token1] = aux_sym_addlast_fieldgroup_modification_token1,
  [aux_sym_addfirst_fieldgroup_modification_token1] = aux_sym_addfirst_fieldgroup_modification_token1,
  [aux_sym_text_type_token1] = aux_sym_text_type_token1,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [aux_sym_code_type_token1] = aux_sym_code_type_token1,
  [aux_sym_option_type_token1] = aux_sym_option_type_token1,
  [aux_sym_record_type_token1] = aux_sym_record_type_token1,
  [aux_sym_object_reference_type_token1] = aux_sym_object_reference_type_token1,
  [aux_sym_object_reference_type_token2] = aux_sym_object_reference_type_token2,
  [aux_sym_array_type_token1] = aux_sym_array_type_token1,
  [aux_sym_array_type_token2] = aux_sym_array_type_token2,
  [aux_sym_list_type_token1] = aux_sym_list_type_token1,
  [aux_sym_dictionary_type_token1] = aux_sym_dictionary_type_token1,
  [aux_sym_basic_type_token1] = aux_sym_basic_type_token1,
  [aux_sym_basic_type_token2] = aux_sym_basic_type_token2,
  [aux_sym_basic_type_token3] = aux_sym_basic_type_token3,
  [aux_sym_basic_type_token4] = aux_sym_basic_type_token4,
  [aux_sym_basic_type_token5] = aux_sym_basic_type_token5,
  [aux_sym_basic_type_token6] = aux_sym_basic_type_token6,
  [aux_sym_basic_type_token7] = aux_sym_basic_type_token7,
  [aux_sym_basic_type_token8] = aux_sym_basic_type_token8,
  [aux_sym_basic_type_token9] = aux_sym_basic_type_token9,
  [aux_sym_basic_type_token10] = aux_sym_basic_type_token10,
  [aux_sym_basic_type_token11] = aux_sym_basic_type_token11,
  [aux_sym_basic_type_token12] = aux_sym_basic_type_token12,
  [aux_sym_basic_type_token13] = aux_sym_basic_type_token13,
  [aux_sym_basic_type_token14] = aux_sym_basic_type_token14,
  [aux_sym_basic_type_token15] = aux_sym_basic_type_token15,
  [aux_sym_basic_type_token16] = aux_sym_basic_type_token16,
  [aux_sym_basic_type_token17] = aux_sym_basic_type_token17,
  [aux_sym_basic_type_token18] = aux_sym_basic_type_token18,
  [aux_sym_basic_type_token19] = aux_sym_basic_type_token19,
  [aux_sym_basic_type_token20] = aux_sym_basic_type_token20,
  [aux_sym_basic_type_token21] = aux_sym_basic_type_token21,
  [aux_sym_basic_type_token22] = aux_sym_basic_type_token22,
  [aux_sym_basic_type_token23] = aux_sym_basic_type_token23,
  [aux_sym_basic_type_token24] = aux_sym_basic_type_token24,
  [aux_sym_basic_type_token25] = aux_sym_basic_type_token25,
  [aux_sym_basic_type_token26] = aux_sym_basic_type_token26,
  [aux_sym_basic_type_token27] = aux_sym_basic_type_token27,
  [aux_sym_basic_type_token28] = aux_sym_basic_type_token28,
  [aux_sym_basic_type_token29] = aux_sym_basic_type_token29,
  [aux_sym_basic_type_token30] = aux_sym_basic_type_token30,
  [aux_sym_basic_type_token31] = aux_sym_basic_type_token31,
  [aux_sym_basic_type_token32] = aux_sym_basic_type_token32,
  [aux_sym_basic_type_token33] = aux_sym_basic_type_token33,
  [aux_sym_basic_type_token34] = aux_sym_basic_type_token34,
  [aux_sym_basic_type_token35] = aux_sym_basic_type_token35,
  [aux_sym_basic_type_token36] = aux_sym_basic_type_token36,
  [aux_sym_basic_type_token37] = aux_sym_basic_type_token37,
  [aux_sym_basic_type_token38] = aux_sym_basic_type_token38,
  [aux_sym_basic_type_token39] = aux_sym_basic_type_token39,
  [aux_sym_basic_type_token40] = aux_sym_basic_type_token40,
  [aux_sym_basic_type_token41] = aux_sym_basic_type_token41,
  [aux_sym_basic_type_token42] = aux_sym_basic_type_token42,
  [aux_sym_basic_type_token43] = aux_sym_basic_type_token43,
  [aux_sym_basic_type_token44] = aux_sym_basic_type_token44,
  [aux_sym_basic_type_token45] = aux_sym_basic_type_token45,
  [aux_sym_basic_type_token46] = aux_sym_basic_type_token46,
  [aux_sym_basic_type_token47] = aux_sym_basic_type_token47,
  [aux_sym_basic_type_token48] = aux_sym_basic_type_token48,
  [aux_sym_basic_type_token49] = aux_sym_basic_type_token49,
  [aux_sym_basic_type_token50] = aux_sym_basic_type_token50,
  [aux_sym_basic_type_token51] = aux_sym_basic_type_token51,
  [aux_sym_basic_type_token52] = aux_sym_basic_type_token52,
  [aux_sym_basic_type_token53] = aux_sym_basic_type_token53,
  [aux_sym_basic_type_token54] = aux_sym_basic_type_token54,
  [aux_sym_enum_value_declaration_token1] = aux_sym_enum_value_declaration_token1,
  [aux_sym_label_declaration_token1] = aux_sym_label_declaration_token1,
  [aux_sym_label_declaration_token2] = aux_sym_label_declaration_token2,
  [aux_sym_area_section_token1] = aux_sym_area_section_token1,
  [aux_sym_area_section_token2] = aux_sym_area_section_token2,
  [aux_sym_area_section_token3] = aux_sym_area_section_token3,
  [aux_sym_area_section_token4] = aux_sym_area_section_token4,
  [aux_sym_area_section_token5] = aux_sym_area_section_token5,
  [aux_sym_area_section_token6] = aux_sym_area_section_token6,
  [aux_sym_area_section_token7] = aux_sym_area_section_token7,
  [aux_sym_area_section_token8] = aux_sym_area_section_token8,
  [aux_sym_addafter_modification_token1] = aux_sym_addafter_modification_token1,
  [aux_sym_addbefore_modification_token1] = aux_sym_addbefore_modification_token1,
  [aux_sym_modify_modification_token1] = aux_sym_modify_modification_token1,
  [aux_sym_movefirst_modification_token1] = aux_sym_movefirst_modification_token1,
  [aux_sym_movelast_modification_token1] = aux_sym_movelast_modification_token1,
  [aux_sym_moveafter_modification_token1] = aux_sym_moveafter_modification_token1,
  [aux_sym_movebefore_modification_token1] = aux_sym_movebefore_modification_token1,
  [aux_sym_action_area_section_token1] = aux_sym_action_area_section_token1,
  [aux_sym_action_area_section_token2] = aux_sym_action_area_section_token2,
  [aux_sym_action_area_section_token3] = aux_sym_action_area_section_token3,
  [aux_sym_action_area_section_token4] = aux_sym_action_area_section_token4,
  [aux_sym_action_area_section_token5] = aux_sym_action_area_section_token5,
  [aux_sym_action_area_section_token6] = aux_sym_action_area_section_token6,
  [aux_sym_action_area_section_token7] = aux_sym_action_area_section_token7,
  [aux_sym_separator_action_token1] = aux_sym_separator_action_token1,
  [aux_sym_actionref_declaration_token1] = aux_sym_actionref_declaration_token1,
  [aux_sym_systemaction_declaration_token1] = aux_sym_systemaction_declaration_token1,
  [aux_sym_fileuploadaction_declaration_token1] = aux_sym_fileuploadaction_declaration_token1,
  [aux_sym_customaction_declaration_token1] = aux_sym_customaction_declaration_token1,
  [aux_sym_add_dataset_modification_token1] = aux_sym_add_dataset_modification_token1,
  [aux_sym_xmlport_element_token1] = aux_sym_xmlport_element_token1,
  [aux_sym_xmlport_element_token2] = aux_sym_xmlport_element_token2,
  [aux_sym_xmlport_element_token3] = aux_sym_xmlport_element_token3,
  [aux_sym_xmlport_attribute_token1] = aux_sym_xmlport_attribute_token1,
  [aux_sym_xmlport_attribute_token2] = aux_sym_xmlport_attribute_token2,
  [aux_sym_assembly_declaration_token1] = aux_sym_assembly_declaration_token1,
  [sym_dotnet_assembly_name] = sym_dotnet_assembly_name,
  [aux_sym_type_declaration_token1] = aux_sym_type_declaration_token1,
  [aux_sym_preproc_split_procedure_body_token1] = aux_sym_preproc_split_procedure_body_token1,
  [aux_sym_preproc_split_procedure_body_token2] = aux_sym_preproc_split_procedure_body_token2,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_POUNDif] = anon_sym_POUNDif,
  [anon_sym_POUNDIF] = anon_sym_POUNDIF,
  [anon_sym_POUNDIf] = anon_sym_POUNDIf,
  [anon_sym_not] = anon_sym_not,
  [anon_sym_NOT] = anon_sym_NOT,
  [anon_sym_Not] = anon_sym_Not,
  [anon_sym_POUNDelif] = anon_sym_POUNDelif,
  [anon_sym_POUNDELIF] = anon_sym_POUNDELIF,
  [anon_sym_POUNDElif] = anon_sym_POUNDElif,
  [anon_sym_POUNDelse] = anon_sym_POUNDelse,
  [anon_sym_POUNDELSE] = anon_sym_POUNDELSE,
  [anon_sym_POUNDElse] = anon_sym_POUNDElse,
  [anon_sym_POUNDendif] = anon_sym_POUNDendif,
  [anon_sym_POUNDENDIF] = anon_sym_POUNDENDIF,
  [anon_sym_POUNDEndif] = anon_sym_POUNDEndif,
  [sym_pragma] = sym_pragma,
  [sym_preproc_region] = sym_preproc_region,
  [sym_preproc_endregion] = sym_preproc_endregion,
  [sym__assignment_operator] = sym__assignment_operator,
  [anon_sym_COLON_EQ] = anon_sym_COLON_EQ,
  [anon_sym_LPAREN2] = anon_sym_LPAREN,
  [aux_sym__expression_token1] = aux_sym__expression_token1,
  [aux_sym__expression_token2] = aux_sym__expression_token2,
  [aux_sym_keyword_identifier_token1] = aux_sym_keyword_identifier_token1,
  [aux_sym_keyword_identifier_token2] = aux_sym_keyword_identifier_token2,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_div] = anon_sym_div,
  [anon_sym_DIV] = anon_sym_DIV,
  [anon_sym_Div] = anon_sym_Div,
  [anon_sym_mod] = anon_sym_mod,
  [anon_sym_MOD] = anon_sym_MOD,
  [anon_sym_Mod] = anon_sym_Mod,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_GT] = anon_sym_LT_GT,
  [anon_sym_and] = anon_sym_and,
  [anon_sym_AND] = anon_sym_AND,
  [anon_sym_And] = anon_sym_And,
  [anon_sym_or] = anon_sym_or,
  [anon_sym_OR] = anon_sym_OR,
  [anon_sym_Or] = anon_sym_Or,
  [anon_sym_xor] = anon_sym_xor,
  [anon_sym_XOR] = anon_sym_XOR,
  [anon_sym_Xor] = anon_sym_Xor,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [sym_datetime_literal] = sym_datetime_literal,
  [sym_date_literal] = sym_date_literal,
  [sym_time_literal] = sym_time_literal,
  [sym_biginteger_literal] = sym_biginteger_literal,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_IF] = anon_sym_IF,
  [anon_sym_If] = anon_sym_If,
  [anon_sym_then] = anon_sym_then,
  [anon_sym_THEN] = anon_sym_THEN,
  [anon_sym_Then] = anon_sym_Then,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_ELSE] = anon_sym_ELSE,
  [anon_sym_Else] = anon_sym_Else,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_CASE] = anon_sym_CASE,
  [anon_sym_Case] = anon_sym_Case,
  [anon_sym_of] = anon_sym_of,
  [anon_sym_OF] = anon_sym_OF,
  [anon_sym_Of] = anon_sym_Of,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_FOR] = anon_sym_FOR,
  [anon_sym_For] = anon_sym_For,
  [anon_sym_foreach] = anon_sym_foreach,
  [anon_sym_FOREACH] = anon_sym_FOREACH,
  [anon_sym_Foreach] = anon_sym_Foreach,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_WHILE] = anon_sym_WHILE,
  [anon_sym_While] = anon_sym_While,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_DO] = anon_sym_DO,
  [anon_sym_Do] = anon_sym_Do,
  [anon_sym_repeat] = anon_sym_repeat,
  [anon_sym_REPEAT] = anon_sym_REPEAT,
  [anon_sym_Repeat] = anon_sym_Repeat,
  [anon_sym_until] = anon_sym_until,
  [anon_sym_UNTIL] = anon_sym_UNTIL,
  [anon_sym_Until] = anon_sym_Until,
  [anon_sym_exit] = anon_sym_exit,
  [anon_sym_EXIT] = anon_sym_EXIT,
  [anon_sym_Exit] = anon_sym_Exit,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_CONTINUE] = anon_sym_CONTINUE,
  [anon_sym_Continue] = anon_sym_Continue,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_BREAK] = anon_sym_BREAK,
  [anon_sym_Break] = anon_sym_Break,
  [anon_sym_with] = anon_sym_with,
  [anon_sym_WITH] = anon_sym_WITH,
  [anon_sym_With] = anon_sym_With,
  [sym_asserterror_keyword] = sym_asserterror_keyword,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_IN] = anon_sym_IN,
  [anon_sym_In] = anon_sym_In,
  [anon_sym_to] = anon_sym_to,
  [anon_sym_TO] = anon_sym_TO,
  [anon_sym_To] = anon_sym_To,
  [anon_sym_downto] = anon_sym_downto,
  [anon_sym_DOWNTO] = anon_sym_DOWNTO,
  [anon_sym_Downto] = anon_sym_Downto,
  [sym_table_keyword] = sym_table_keyword,
  [anon_sym_tableextension] = anon_sym_tableextension,
  [anon_sym_TABLEEXTENSION] = anon_sym_TABLEEXTENSION,
  [anon_sym_Tableextension] = anon_sym_Tableextension,
  [anon_sym_TableExtension] = anon_sym_TableExtension,
  [anon_sym_tableExtension] = anon_sym_tableExtension,
  [sym_page_keyword] = sym_page_keyword,
  [anon_sym_pageextension] = anon_sym_pageextension,
  [anon_sym_PAGEEXTENSION] = anon_sym_PAGEEXTENSION,
  [anon_sym_Pageextension] = anon_sym_Pageextension,
  [anon_sym_PageExtension] = anon_sym_PageExtension,
  [anon_sym_pageExtension] = anon_sym_pageExtension,
  [anon_sym_codeunit] = anon_sym_codeunit,
  [anon_sym_CODEUNIT] = anon_sym_CODEUNIT,
  [anon_sym_Codeunit] = anon_sym_Codeunit,
  [anon_sym_CodeUnit] = anon_sym_CodeUnit,
  [anon_sym_COdeunit] = anon_sym_COdeunit,
  [anon_sym_codeUnit] = anon_sym_codeUnit,
  [sym_report_keyword] = sym_report_keyword,
  [anon_sym_reportextension] = anon_sym_reportextension,
  [anon_sym_REPORTEXTENSION] = anon_sym_REPORTEXTENSION,
  [anon_sym_Reportextension] = anon_sym_Reportextension,
  [anon_sym_ReportExtension] = anon_sym_ReportExtension,
  [anon_sym_reportExtension] = anon_sym_reportExtension,
  [sym_query_keyword] = sym_query_keyword,
  [anon_sym_xmlport] = anon_sym_xmlport,
  [anon_sym_XMLPORT] = anon_sym_XMLPORT,
  [anon_sym_Xmlport] = anon_sym_Xmlport,
  [anon_sym_XMLport] = anon_sym_XMLport,
  [anon_sym_XMLPort] = anon_sym_XMLPort,
  [anon_sym_XmlPort] = anon_sym_XmlPort,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_ENUM] = anon_sym_ENUM,
  [anon_sym_Enum] = anon_sym_Enum,
  [anon_sym_eNUM] = anon_sym_eNUM,
  [anon_sym_eNum] = anon_sym_eNum,
  [anon_sym_ENum] = anon_sym_ENum,
  [anon_sym_enumextension] = anon_sym_enumextension,
  [anon_sym_ENUMEXTENSION] = anon_sym_ENUMEXTENSION,
  [anon_sym_Enumextension] = anon_sym_Enumextension,
  [anon_sym_EnumExtension] = anon_sym_EnumExtension,
  [anon_sym_enumExtension] = anon_sym_enumExtension,
  [sym_interface_keyword] = sym_interface_keyword,
  [anon_sym_controladdin] = anon_sym_controladdin,
  [anon_sym_CONTROLADDIN] = anon_sym_CONTROLADDIN,
  [anon_sym_Controladdin] = anon_sym_Controladdin,
  [anon_sym_ControlAddIn] = anon_sym_ControlAddIn,
  [anon_sym_ControlAddin] = anon_sym_ControlAddin,
  [anon_sym_controlAddIn] = anon_sym_controlAddIn,
  [anon_sym_controlAddin] = anon_sym_controlAddin,
  [anon_sym_dotnet] = anon_sym_dotnet,
  [anon_sym_DOTNET] = anon_sym_DOTNET,
  [anon_sym_Dotnet] = anon_sym_Dotnet,
  [anon_sym_DotNet] = anon_sym_DotNet,
  [anon_sym_dotNet] = anon_sym_dotNet,
  [sym_profile_keyword] = sym_profile_keyword,
  [anon_sym_profileextension] = anon_sym_profileextension,
  [anon_sym_PROFILEEXTENSION] = anon_sym_PROFILEEXTENSION,
  [anon_sym_Profileextension] = anon_sym_Profileextension,
  [anon_sym_ProfileExtension] = anon_sym_ProfileExtension,
  [anon_sym_profileExtension] = anon_sym_profileExtension,
  [anon_sym_permissionset] = anon_sym_permissionset,
  [anon_sym_PERMISSIONSET] = anon_sym_PERMISSIONSET,
  [anon_sym_Permissionset] = anon_sym_Permissionset,
  [anon_sym_PermissionSet] = anon_sym_PermissionSet,
  [anon_sym_permissionSet] = anon_sym_permissionSet,
  [anon_sym_permissionsetextension] = anon_sym_permissionsetextension,
  [anon_sym_PERMISSIONSETEXTENSION] = anon_sym_PERMISSIONSETEXTENSION,
  [anon_sym_Permissionsetextension] = anon_sym_Permissionsetextension,
  [anon_sym_PermissionSetExtension] = anon_sym_PermissionSetExtension,
  [anon_sym_permissionSetExtension] = anon_sym_permissionSetExtension,
  [sym_entitlement_keyword] = sym_entitlement_keyword,
  [anon_sym_pagecustomization] = anon_sym_pagecustomization,
  [anon_sym_PAGECUSTOMIZATION] = anon_sym_PAGECUSTOMIZATION,
  [anon_sym_Pagecustomization] = anon_sym_Pagecustomization,
  [anon_sym_PageCustomization] = anon_sym_PageCustomization,
  [anon_sym_pageCustomization] = anon_sym_pageCustomization,
  [sym_namespace_keyword] = sym_namespace_keyword,
  [sym_using_keyword] = sym_using_keyword,
  [sym_implements_keyword] = sym_implements_keyword,
  [sym_extends_keyword] = sym_extends_keyword,
  [sym_customizes_keyword] = sym_customizes_keyword,
  [sym_procedure_keyword] = sym_procedure_keyword,
  [sym_trigger_keyword] = sym_trigger_keyword,
  [sym_var_keyword] = sym_var_keyword,
  [sym_local_keyword] = sym_local_keyword,
  [sym_internal_keyword] = sym_internal_keyword,
  [sym_protected_keyword] = sym_protected_keyword,
  [sym_event_keyword] = sym_event_keyword,
  [sym_temporary_keyword] = sym_temporary_keyword,
  [sym_fields_keyword] = sym_fields_keyword,
  [sym_keys_keyword] = sym_keys_keyword,
  [sym_key_keyword] = sym_key_keyword,
  [sym_fieldgroups_keyword] = sym_fieldgroups_keyword,
  [sym_fieldgroup_keyword] = sym_fieldgroup_keyword,
  [sym_actions_keyword] = sym_actions_keyword,
  [sym_layout_keyword] = sym_layout_keyword,
  [sym_area_keyword] = sym_area_keyword,
  [sym_group_keyword] = sym_group_keyword,
  [sym_repeater_keyword] = sym_repeater_keyword,
  [sym_cuegroup_keyword] = sym_cuegroup_keyword,
  [sym_fixed_keyword] = sym_fixed_keyword,
  [sym_grid_keyword] = sym_grid_keyword,
  [sym_part_keyword] = sym_part_keyword,
  [sym_systempart_keyword] = sym_systempart_keyword,
  [sym_usercontrol_keyword] = sym_usercontrol_keyword,
  [sym_dataset_keyword] = sym_dataset_keyword,
  [sym_elements_keyword] = sym_elements_keyword,
  [sym_dataitem_keyword] = sym_dataitem_keyword,
  [sym_column_keyword] = sym_column_keyword,
  [sym_filter_keyword] = sym_filter_keyword,
  [sym_labels_keyword] = sym_labels_keyword,
  [sym_rendering_keyword] = sym_rendering_keyword,
  [sym_requestpage_keyword] = sym_requestpage_keyword,
  [sym_schema_keyword] = sym_schema_keyword,
  [sym_views_keyword] = sym_views_keyword,
  [sym_view_keyword] = sym_view_keyword,
  [sym_quoted_identifier] = sym_quoted_identifier,
  [sym_comment] = sym_comment,
  [sym_multiline_comment] = sym_multiline_comment,
  [sym_string_literal] = sym_string_literal,
  [sym_integer] = sym_integer,
  [sym_property_name] = sym_property_name,
  [sym_continue_as_identifier] = sym_identifier,
  [sym_preproc_open] = sym_preproc_open,
  [sym_preproc_close] = sym_preproc_close,
  [sym_begin_keyword] = sym_begin_keyword,
  [sym_end_keyword] = sym_end_keyword,
  [sym_preproc_split_begin] = sym_preproc_split_begin,
  [sym_preproc_split_end] = sym_preproc_split_end,
  [sym_var_attribute_open] = sym_var_attribute_open,
  [sym_source_file] = sym_source_file,
  [sym_preproc_conditional_object] = sym_preproc_conditional_object,
  [sym_namespace_declaration] = sym_namespace_declaration,
  [sym_using_statement] = sym_using_statement,
  [sym_namespace_name] = sym_namespace_name,
  [sym__object] = sym__object,
  [sym_preproc_split_declaration] = sym_preproc_split_declaration,
  [sym__object_header] = sym__object_header,
  [sym_table_declaration] = sym_table_declaration,
  [sym_page_declaration] = sym_page_declaration,
  [sym_report_declaration] = sym_report_declaration,
  [sym_query_declaration] = sym_query_declaration,
  [sym_xmlport_declaration] = sym_xmlport_declaration,
  [sym_permissionset_declaration] = sym_permissionset_declaration,
  [sym_codeunit_declaration] = sym_codeunit_declaration,
  [sym_enum_declaration] = sym_enum_declaration,
  [sym_tableextension_declaration] = sym_tableextension_declaration,
  [sym_pageextension_declaration] = sym_pageextension_declaration,
  [sym_reportextension_declaration] = sym_reportextension_declaration,
  [sym_enumextension_declaration] = sym_enumextension_declaration,
  [sym_permissionsetextension_declaration] = sym_permissionsetextension_declaration,
  [sym_controladdin_declaration] = sym_controladdin_declaration,
  [sym_preproc_conditional_controladdin] = sym_preproc_conditional_controladdin,
  [sym_profile_declaration] = sym_profile_declaration,
  [sym_entitlement_declaration] = sym_entitlement_declaration,
  [sym_profileextension_declaration] = sym_profileextension_declaration,
  [sym_interface_declaration] = sym_interface_declaration,
  [sym_pagecustomization_declaration] = sym_pagecustomization_declaration,
  [sym_dotnet_declaration] = sym_dotnet_declaration,
  [sym_implements_clause] = sym_implements_clause,
  [sym__body_element] = sym__body_element,
  [sym_empty_statement] = sym_empty_statement,
  [sym_property] = sym_property,
  [sym__property_value] = sym__property_value,
  [sym_decimal_range_value] = sym_decimal_range_value,
  [sym_signed_integer_list] = sym_signed_integer_list,
  [sym__signed_integer] = sym__signed_integer,
  [sym_object_reference_value] = sym_object_reference_value,
  [sym_property_expression] = sym_property_expression,
  [sym_boolean] = sym_boolean,
  [sym_caption_value] = sym_caption_value,
  [sym_ml_value_list] = sym_ml_value_list,
  [sym_ml_value_pair] = sym_ml_value_pair,
  [sym__calc_formula_expression] = sym__calc_formula_expression,
  [sym_lookup_formula] = sym_lookup_formula,
  [sym_aggregate_formula] = sym_aggregate_formula,
  [sym_calc_field_reference] = sym_calc_field_reference,
  [sym_where_clause] = sym_where_clause,
  [sym_where_conditions] = sym_where_conditions,
  [sym_preproc_conditional_where] = sym_preproc_conditional_where,
  [sym_where_condition] = sym_where_condition,
  [sym_filter_value] = sym_filter_value,
  [sym_sorting_value] = sym_sorting_value,
  [sym_link_value_list] = sym_link_value_list,
  [sym_preproc_conditional_link_values] = sym_preproc_conditional_link_values,
  [sym_link_value] = sym_link_value,
  [sym_table_relation_value] = sym_table_relation_value,
  [sym_preproc_conditional_table_relation] = sym_preproc_conditional_table_relation,
  [sym_table_relation_expression] = sym_table_relation_expression,
  [sym_if_table_relation] = sym_if_table_relation,
  [sym_simple_table_relation] = sym_simple_table_relation,
  [sym_tabledata_permission_list] = sym_tabledata_permission_list,
  [sym_preproc_conditional_permissions] = sym_preproc_conditional_permissions,
  [sym_tabledata_permission] = sym_tabledata_permission,
  [sym_order_by_list] = sym_order_by_list,
  [sym_order_by_item] = sym_order_by_item,
  [sym_implementation_value_list] = sym_implementation_value_list,
  [sym_preproc_conditional_impl_values] = sym_preproc_conditional_impl_values,
  [sym_implementation_value] = sym_implementation_value,
  [sym_option_member_list] = sym_option_member_list,
  [sym_option_member] = sym_option_member,
  [sym_fields_section] = sym_fields_section,
  [sym_preproc_conditional_fields] = sym_preproc_conditional_fields,
  [sym_field_declaration] = sym_field_declaration,
  [sym_keys_section] = sym_keys_section,
  [sym_preproc_conditional_keys] = sym_preproc_conditional_keys,
  [sym_key_declaration] = sym_key_declaration,
  [sym_field_list] = sym_field_list,
  [sym_fieldgroups_section] = sym_fieldgroups_section,
  [sym_addlast_fieldgroup_modification] = sym_addlast_fieldgroup_modification,
  [sym_addfirst_fieldgroup_modification] = sym_addfirst_fieldgroup_modification,
  [sym_preproc_conditional_fieldgroups] = sym_preproc_conditional_fieldgroups,
  [sym_fieldgroup_declaration] = sym_fieldgroup_declaration,
  [sym_type_specification] = sym_type_specification,
  [sym_text_type] = sym_text_type,
  [sym_code_type] = sym_code_type,
  [sym_option_type] = sym_option_type,
  [sym_record_type] = sym_record_type,
  [sym_dotnet_type] = sym_dotnet_type,
  [sym_object_reference_type] = sym_object_reference_type,
  [sym__namespaced_or_simple_ref] = sym__namespaced_or_simple_ref,
  [sym_array_type] = sym_array_type,
  [sym_list_type] = sym_list_type,
  [sym_dictionary_type] = sym_dictionary_type,
  [sym_basic_type] = sym_basic_type,
  [sym_enum_value_declaration] = sym_enum_value_declaration,
  [sym_labels_section] = sym_labels_section,
  [sym_label_declaration] = sym_label_declaration,
  [sym_layout_section] = sym_layout_section,
  [sym__layout_element] = sym__layout_element,
  [sym_area_section] = sym_area_section,
  [sym_preproc_split_brace_close] = sym_preproc_split_brace_close,
  [sym_group_section] = sym_group_section,
  [sym_repeater_section] = sym_repeater_section,
  [sym_cuegroup_section] = sym_cuegroup_section,
  [sym_fixed_section] = sym_fixed_section,
  [sym_grid_section] = sym_grid_section,
  [sym_page_field] = sym_page_field,
  [sym__field_source] = sym__field_source,
  [sym_part_section] = sym_part_section,
  [sym_systempart_section] = sym_systempart_section,
  [sym_usercontrol_section] = sym_usercontrol_section,
  [sym_preproc_split_field] = sym_preproc_split_field,
  [sym__field_header] = sym__field_header,
  [sym_label_section] = sym_label_section,
  [sym_addfirst_modification] = sym_addfirst_modification,
  [sym_addlast_modification] = sym_addlast_modification,
  [sym_addafter_modification] = sym_addafter_modification,
  [sym_addbefore_modification] = sym_addbefore_modification,
  [sym_modify_modification] = sym_modify_modification,
  [sym_movefirst_modification] = sym_movefirst_modification,
  [sym_movelast_modification] = sym_movelast_modification,
  [sym_moveafter_modification] = sym_moveafter_modification,
  [sym_movebefore_modification] = sym_movebefore_modification,
  [sym_actions_section] = sym_actions_section,
  [sym__action_element] = sym__action_element,
  [sym_action_area_section] = sym_action_area_section,
  [sym_action_group_section] = sym_action_group_section,
  [sym_action_declaration] = sym_action_declaration,
  [sym_separator_action] = sym_separator_action,
  [sym_actionref_declaration] = sym_actionref_declaration,
  [sym_systemaction_declaration] = sym_systemaction_declaration,
  [sym_fileuploadaction_declaration] = sym_fileuploadaction_declaration,
  [sym_customaction_declaration] = sym_customaction_declaration,
  [sym_addfirst_action_modification] = sym_addfirst_action_modification,
  [sym_addlast_action_modification] = sym_addlast_action_modification,
  [sym_addafter_action_modification] = sym_addafter_action_modification,
  [sym_addbefore_action_modification] = sym_addbefore_action_modification,
  [sym_modify_action_modification] = sym_modify_action_modification,
  [sym_views_section] = sym_views_section,
  [sym_addfirst_views_modification] = sym_addfirst_views_modification,
  [sym_addlast_views_modification] = sym_addlast_views_modification,
  [sym_addafter_views_modification] = sym_addafter_views_modification,
  [sym_addbefore_views_modification] = sym_addbefore_views_modification,
  [sym_view_definition] = sym_view_definition,
  [sym_dataset_section] = sym_dataset_section,
  [sym_preproc_conditional_dataset] = sym_preproc_conditional_dataset,
  [sym_report_dataitem] = sym_report_dataitem,
  [sym__report_body_element] = sym__report_body_element,
  [sym_preproc_conditional_report] = sym_preproc_conditional_report,
  [sym_report_column] = sym_report_column,
  [sym_add_dataset_modification] = sym_add_dataset_modification,
  [sym_addfirst_dataset_modification] = sym_addfirst_dataset_modification,
  [sym_addlast_dataset_modification] = sym_addlast_dataset_modification,
  [sym_addafter_dataset_modification] = sym_addafter_dataset_modification,
  [sym_addbefore_dataset_modification] = sym_addbefore_dataset_modification,
  [sym_requestpage_section] = sym_requestpage_section,
  [sym_rendering_section] = sym_rendering_section,
  [sym_rendering_layout] = sym_rendering_layout,
  [sym_elements_section] = sym_elements_section,
  [sym_query_dataitem] = sym_query_dataitem,
  [sym__query_body_element] = sym__query_body_element,
  [sym_preproc_conditional_query] = sym_preproc_conditional_query,
  [sym_query_column] = sym_query_column,
  [sym_query_filter] = sym_query_filter,
  [sym_schema_section] = sym_schema_section,
  [sym_xmlport_element] = sym_xmlport_element,
  [sym__xmlport_body_element] = sym__xmlport_body_element,
  [sym_preproc_conditional_xmlport] = sym_preproc_conditional_xmlport,
  [sym_xmlport_attribute] = sym_xmlport_attribute,
  [sym_assembly_declaration] = sym_assembly_declaration,
  [sym_type_declaration] = sym_type_declaration,
  [sym_event_declaration] = sym_event_declaration,
  [sym_procedure] = sym_procedure,
  [sym_preproc_split_procedure_body] = sym_preproc_split_procedure_body,
  [sym_preproc_split_procedure] = sym_preproc_split_procedure,
  [sym__procedure_header] = sym__procedure_header,
  [sym_interface_procedure] = sym_interface_procedure,
  [sym_interface_procedure_suffix] = sym_interface_procedure_suffix,
  [sym_procedure_modifier] = sym_procedure_modifier,
  [sym__procedure_return_specification] = sym__procedure_return_specification,
  [sym__procedure_named_return] = sym__procedure_named_return,
  [sym_parameter_list] = sym_parameter_list,
  [sym_parameter] = sym_parameter,
  [sym_code_block] = sym_code_block,
  [sym_trigger_declaration] = sym_trigger_declaration,
  [sym_preproc_conditional_var_block] = sym_preproc_conditional_var_block,
  [sym__trigger_name] = sym__trigger_name,
  [sym_var_section] = sym_var_section,
  [sym_var_attribute_item] = sym_var_attribute_item,
  [sym_preproc_conditional_var] = sym_preproc_conditional_var,
  [sym_variable_declaration] = sym_variable_declaration,
  [sym_label_attribute] = sym_label_attribute,
  [sym_attribute_item] = sym_attribute_item,
  [sym_attribute_content] = sym_attribute_content,
  [sym_attribute_arguments] = sym_attribute_arguments,
  [sym_attribute_argument_list] = sym_attribute_argument_list,
  [sym__attribute_argument] = sym__attribute_argument,
  [sym_preproc_conditional] = sym_preproc_conditional,
  [sym_preproc_if] = sym_preproc_if,
  [sym_preproc_not_expression] = sym_preproc_not_expression,
  [sym_preproc_elif] = sym_preproc_elif,
  [sym_preproc_else] = sym_preproc_else,
  [sym_preproc_endif] = sym_preproc_endif,
  [sym_preproc_split_if_statement] = sym_preproc_split_if_statement,
  [sym__preproc_if_header] = sym__preproc_if_header,
  [sym_preproc_guarded_statement] = sym_preproc_guarded_statement,
  [sym__preproc_guard_block] = sym__preproc_guard_block,
  [sym_preproc_split_if_else_statement] = sym_preproc_split_if_else_statement,
  [sym_preproc_split_if_then_begin] = sym_preproc_split_if_then_begin,
  [sym_preproc_split_code_block_end] = sym_preproc_split_code_block_end,
  [sym_preproc_fragmented_else_tail] = sym_preproc_fragmented_else_tail,
  [sym_preproc_conditional_statement] = sym_preproc_conditional_statement,
  [sym_preproc_conditional_actions] = sym_preproc_conditional_actions,
  [sym_preproc_conditional_layout] = sym_preproc_conditional_layout,
  [sym_preproc_conditional_layout_mixed] = sym_preproc_conditional_layout_mixed,
  [sym__statement] = sym__statement,
  [sym__expression_statement] = sym__expression_statement,
  [sym_assignment_statement] = sym_assignment_statement,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym_if_statement] = sym_if_statement,
  [sym__if_statement_no_else] = sym_if_statement,
  [sym_case_statement] = sym_case_statement,
  [sym_preproc_conditional_case] = sym_preproc_conditional_case,
  [sym_case_branch] = sym_case_branch,
  [sym_preproc_split_case_branch] = sym_preproc_split_case_branch,
  [aux_sym__case_pattern] = aux_sym__case_pattern,
  [sym_preproc_conditional_case_patterns] = sym_preproc_conditional_case_patterns,
  [sym__single_pattern] = sym__single_pattern,
  [sym_case_else_branch] = sym_case_else_branch,
  [sym_for_statement] = sym_for_statement,
  [sym_foreach_statement] = sym_foreach_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_repeat_statement] = sym_repeat_statement,
  [sym_with_statement] = sym_with_statement,
  [sym_exit_statement] = sym_exit_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_asserterror_statement] = sym_asserterror_statement,
  [sym__expression] = sym__expression,
  [sym_keyword_identifier] = sym_keyword_identifier,
  [sym_range_expression] = sym_range_expression,
  [sym_multiplicative_expression] = sym_multiplicative_expression,
  [sym_additive_expression] = sym_additive_expression,
  [sym_comparison_expression] = sym_comparison_expression,
  [sym_comparison_operator] = sym_comparison_operator,
  [sym_logical_expression] = sym_logical_expression,
  [sym_ternary_expression] = sym_ternary_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym_call_expression] = sym_call_expression,
  [sym_argument_list] = sym_argument_list,
  [sym_member_expression] = sym_member_expression,
  [sym_subscript_expression] = sym_subscript_expression,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_list_literal] = sym_list_literal,
  [sym_qualified_enum_value] = sym_qualified_enum_value,
  [sym_database_reference] = sym_database_reference,
  [sym__literal_value] = sym__literal_value,
  [sym_if_keyword] = sym_if_keyword,
  [sym_then_keyword] = sym_then_keyword,
  [sym_else_keyword] = sym_else_keyword,
  [sym_case_keyword] = sym_case_keyword,
  [sym_of_keyword] = sym_of_keyword,
  [sym_for_keyword] = sym_for_keyword,
  [sym_foreach_keyword] = sym_foreach_keyword,
  [sym_while_keyword] = sym_while_keyword,
  [sym_do_keyword] = sym_do_keyword,
  [sym_repeat_keyword] = sym_repeat_keyword,
  [sym_until_keyword] = sym_until_keyword,
  [sym_exit_keyword] = sym_exit_keyword,
  [sym_continue_keyword] = sym_continue_keyword,
  [sym_break_keyword] = sym_break_keyword,
  [sym_with_keyword] = sym_with_keyword,
  [sym_in_keyword] = sym_in_keyword,
  [sym_to_keyword] = sym_to_keyword,
  [sym_downto_keyword] = sym_downto_keyword,
  [sym_tableextension_keyword] = sym_tableextension_keyword,
  [sym_pageextension_keyword] = sym_pageextension_keyword,
  [sym_codeunit_keyword] = sym_codeunit_keyword,
  [sym_reportextension_keyword] = sym_reportextension_keyword,
  [sym_xmlport_keyword] = sym_xmlport_keyword,
  [sym_enum_keyword] = sym_enum_keyword,
  [sym_enumextension_keyword] = sym_enumextension_keyword,
  [sym_controladdin_keyword] = sym_controladdin_keyword,
  [sym_dotnet_keyword] = sym_dotnet_keyword,
  [sym_profileextension_keyword] = sym_profileextension_keyword,
  [sym_permissionset_keyword] = sym_permissionset_keyword,
  [sym_permissionsetextension_keyword] = sym_permissionsetextension_keyword,
  [sym_pagecustomization_keyword] = sym_pagecustomization_keyword,
  [sym__identifier_or_quoted] = sym__identifier_or_quoted,
  [sym_keyword_as_identifier] = sym_identifier,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_preproc_conditional_object_repeat1] = aux_sym_preproc_conditional_object_repeat1,
  [aux_sym_namespace_name_repeat1] = aux_sym_namespace_name_repeat1,
  [aux_sym_preproc_split_declaration_repeat1] = aux_sym_preproc_split_declaration_repeat1,
  [aux_sym_preproc_split_declaration_repeat2] = aux_sym_preproc_split_declaration_repeat2,
  [aux_sym_controladdin_declaration_repeat1] = aux_sym_controladdin_declaration_repeat1,
  [aux_sym_preproc_conditional_controladdin_repeat1] = aux_sym_preproc_conditional_controladdin_repeat1,
  [aux_sym_interface_declaration_repeat1] = aux_sym_interface_declaration_repeat1,
  [aux_sym_dotnet_declaration_repeat1] = aux_sym_dotnet_declaration_repeat1,
  [aux_sym_implements_clause_repeat1] = aux_sym_implements_clause_repeat1,
  [aux_sym_signed_integer_list_repeat1] = aux_sym_signed_integer_list_repeat1,
  [aux_sym_caption_value_repeat1] = aux_sym_caption_value_repeat1,
  [aux_sym_ml_value_list_repeat1] = aux_sym_ml_value_list_repeat1,
  [aux_sym_calc_field_reference_repeat1] = aux_sym_calc_field_reference_repeat1,
  [aux_sym_where_conditions_repeat1] = aux_sym_where_conditions_repeat1,
  [aux_sym_preproc_conditional_where_repeat1] = aux_sym_preproc_conditional_where_repeat1,
  [aux_sym_preproc_conditional_where_repeat2] = aux_sym_preproc_conditional_where_repeat2,
  [aux_sym_filter_value_repeat1] = aux_sym_filter_value_repeat1,
  [aux_sym_sorting_value_repeat1] = aux_sym_sorting_value_repeat1,
  [aux_sym_link_value_list_repeat1] = aux_sym_link_value_list_repeat1,
  [aux_sym_preproc_conditional_link_values_repeat1] = aux_sym_preproc_conditional_link_values_repeat1,
  [aux_sym_preproc_conditional_link_values_repeat2] = aux_sym_preproc_conditional_link_values_repeat2,
  [aux_sym_preproc_conditional_table_relation_repeat1] = aux_sym_preproc_conditional_table_relation_repeat1,
  [aux_sym_tabledata_permission_list_repeat1] = aux_sym_tabledata_permission_list_repeat1,
  [aux_sym_preproc_conditional_permissions_repeat1] = aux_sym_preproc_conditional_permissions_repeat1,
  [aux_sym_order_by_list_repeat1] = aux_sym_order_by_list_repeat1,
  [aux_sym_implementation_value_list_repeat1] = aux_sym_implementation_value_list_repeat1,
  [aux_sym_preproc_conditional_impl_values_repeat1] = aux_sym_preproc_conditional_impl_values_repeat1,
  [aux_sym_preproc_conditional_impl_values_repeat2] = aux_sym_preproc_conditional_impl_values_repeat2,
  [aux_sym_option_member_list_repeat1] = aux_sym_option_member_list_repeat1,
  [aux_sym_option_member_list_repeat2] = aux_sym_option_member_list_repeat2,
  [aux_sym_fields_section_repeat1] = aux_sym_fields_section_repeat1,
  [aux_sym_preproc_conditional_fields_repeat1] = aux_sym_preproc_conditional_fields_repeat1,
  [aux_sym_preproc_conditional_fields_repeat2] = aux_sym_preproc_conditional_fields_repeat2,
  [aux_sym_keys_section_repeat1] = aux_sym_keys_section_repeat1,
  [aux_sym_preproc_conditional_keys_repeat1] = aux_sym_preproc_conditional_keys_repeat1,
  [aux_sym_preproc_conditional_keys_repeat2] = aux_sym_preproc_conditional_keys_repeat2,
  [aux_sym_fieldgroups_section_repeat1] = aux_sym_fieldgroups_section_repeat1,
  [aux_sym_preproc_conditional_fieldgroups_repeat1] = aux_sym_preproc_conditional_fieldgroups_repeat1,
  [aux_sym_preproc_conditional_fieldgroups_repeat2] = aux_sym_preproc_conditional_fieldgroups_repeat2,
  [aux_sym__namespaced_or_simple_ref_repeat1] = aux_sym__namespaced_or_simple_ref_repeat1,
  [aux_sym_array_type_repeat1] = aux_sym_array_type_repeat1,
  [aux_sym_labels_section_repeat1] = aux_sym_labels_section_repeat1,
  [aux_sym_label_declaration_repeat1] = aux_sym_label_declaration_repeat1,
  [aux_sym_layout_section_repeat1] = aux_sym_layout_section_repeat1,
  [aux_sym_group_section_repeat1] = aux_sym_group_section_repeat1,
  [aux_sym_preproc_split_field_repeat1] = aux_sym_preproc_split_field_repeat1,
  [aux_sym_actions_section_repeat1] = aux_sym_actions_section_repeat1,
  [aux_sym_action_group_section_repeat1] = aux_sym_action_group_section_repeat1,
  [aux_sym_views_section_repeat1] = aux_sym_views_section_repeat1,
  [aux_sym_addfirst_views_modification_repeat1] = aux_sym_addfirst_views_modification_repeat1,
  [aux_sym_dataset_section_repeat1] = aux_sym_dataset_section_repeat1,
  [aux_sym_preproc_conditional_dataset_repeat1] = aux_sym_preproc_conditional_dataset_repeat1,
  [aux_sym_preproc_conditional_dataset_repeat2] = aux_sym_preproc_conditional_dataset_repeat2,
  [aux_sym_report_dataitem_repeat1] = aux_sym_report_dataitem_repeat1,
  [aux_sym_preproc_conditional_report_repeat1] = aux_sym_preproc_conditional_report_repeat1,
  [aux_sym_add_dataset_modification_repeat1] = aux_sym_add_dataset_modification_repeat1,
  [aux_sym_rendering_section_repeat1] = aux_sym_rendering_section_repeat1,
  [aux_sym_elements_section_repeat1] = aux_sym_elements_section_repeat1,
  [aux_sym_query_dataitem_repeat1] = aux_sym_query_dataitem_repeat1,
  [aux_sym_preproc_conditional_query_repeat1] = aux_sym_preproc_conditional_query_repeat1,
  [aux_sym_schema_section_repeat1] = aux_sym_schema_section_repeat1,
  [aux_sym_xmlport_element_repeat1] = aux_sym_xmlport_element_repeat1,
  [aux_sym_preproc_conditional_xmlport_repeat1] = aux_sym_preproc_conditional_xmlport_repeat1,
  [aux_sym_assembly_declaration_repeat1] = aux_sym_assembly_declaration_repeat1,
  [aux_sym_preproc_split_procedure_body_repeat1] = aux_sym_preproc_split_procedure_body_repeat1,
  [aux_sym_preproc_split_procedure_repeat1] = aux_sym_preproc_split_procedure_repeat1,
  [aux_sym__procedure_header_repeat1] = aux_sym__procedure_header_repeat1,
  [aux_sym_parameter_list_repeat1] = aux_sym_parameter_list_repeat1,
  [aux_sym_preproc_conditional_var_block_repeat1] = aux_sym_preproc_conditional_var_block_repeat1,
  [aux_sym_var_section_repeat1] = aux_sym_var_section_repeat1,
  [aux_sym_preproc_conditional_var_repeat1] = aux_sym_preproc_conditional_var_repeat1,
  [aux_sym_preproc_conditional_var_repeat2] = aux_sym_preproc_conditional_var_repeat2,
  [aux_sym_variable_declaration_repeat1] = aux_sym_variable_declaration_repeat1,
  [aux_sym_variable_declaration_repeat2] = aux_sym_variable_declaration_repeat2,
  [aux_sym_attribute_argument_list_repeat1] = aux_sym_attribute_argument_list_repeat1,
  [aux_sym_preproc_conditional_repeat1] = aux_sym_preproc_conditional_repeat1,
  [aux_sym_preproc_split_if_statement_repeat1] = aux_sym_preproc_split_if_statement_repeat1,
  [aux_sym__preproc_guard_block_repeat1] = aux_sym__preproc_guard_block_repeat1,
  [aux_sym_preproc_split_if_else_statement_repeat1] = aux_sym_preproc_split_if_else_statement_repeat1,
  [aux_sym_preproc_conditional_statement_repeat1] = aux_sym_preproc_conditional_statement_repeat1,
  [aux_sym_preproc_conditional_actions_repeat1] = aux_sym_preproc_conditional_actions_repeat1,
  [aux_sym_preproc_conditional_layout_repeat1] = aux_sym_preproc_conditional_layout_repeat1,
  [aux_sym_preproc_conditional_layout_mixed_repeat1] = aux_sym_preproc_conditional_layout_mixed_repeat1,
  [aux_sym_preproc_conditional_layout_mixed_repeat2] = aux_sym_preproc_conditional_layout_mixed_repeat2,
  [aux_sym_case_statement_repeat1] = aux_sym_case_statement_repeat1,
  [aux_sym_preproc_conditional_case_repeat1] = aux_sym_preproc_conditional_case_repeat1,
  [aux_sym_preproc_conditional_case_repeat2] = aux_sym_preproc_conditional_case_repeat2,
  [aux_sym_preproc_split_case_branch_repeat1] = aux_sym_preproc_split_case_branch_repeat1,
  [aux_sym_preproc_split_case_branch_repeat2] = aux_sym_preproc_split_case_branch_repeat2,
  [aux_sym_argument_list_repeat1] = aux_sym_argument_list_repeat1,
  [alias_sym_aggregate_function] = alias_sym_aggregate_function,
  [alias_sym_object_type_keyword] = alias_sym_object_type_keyword,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_interface_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_interface_declaration_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_boolean_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_boolean_token2] = {
    .visible = false,
    .named = false,
  },
  [sym_decimal] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_ml_value_list_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_lookup_formula_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_where_clause_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_where_condition_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_where_condition_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_where_condition_token3] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_filter_value_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sorting_value_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sorting_value_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sorting_value_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sorting_value_token4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_table_relation_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_table_relation_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tabledata_permission_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tabledata_permission_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [sym_permission_type] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_order_by_item_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_order_by_item_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_addlast_fieldgroup_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_addfirst_fieldgroup_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_text_type_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_code_type_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_option_type_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_record_type_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_reference_type_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_reference_type_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_type_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_type_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_type_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dictionary_type_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token5] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token6] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token7] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token8] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token9] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token10] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token11] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token12] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token13] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token14] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token15] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token16] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token17] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token18] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token19] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token20] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token21] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token22] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token23] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token24] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token25] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token26] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token27] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token28] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token29] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token30] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token31] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token32] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token33] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token34] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token35] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token36] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token37] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token38] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token39] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token40] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token41] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token42] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token43] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token44] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token45] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token46] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token47] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token48] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token49] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token50] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token51] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token52] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token53] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token54] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_value_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_label_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_label_declaration_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_area_section_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_area_section_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_area_section_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_area_section_token4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_area_section_token5] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_area_section_token6] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_area_section_token7] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_area_section_token8] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_addafter_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_addbefore_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_modify_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_movefirst_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_movelast_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_moveafter_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_movebefore_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_action_area_section_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_action_area_section_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_action_area_section_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_action_area_section_token4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_action_area_section_token5] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_action_area_section_token6] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_action_area_section_token7] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_separator_action_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_actionref_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_systemaction_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_fileuploadaction_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_customaction_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_add_dataset_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_xmlport_element_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_xmlport_element_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_xmlport_element_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_xmlport_attribute_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_xmlport_attribute_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_assembly_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_dotnet_assembly_name] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_type_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_procedure_body_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_procedure_body_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDIF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDIf] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_not] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_NOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Not] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDelif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDELIF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDElif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDelse] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDELSE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDElse] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDendif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDENDIF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDEndif] = {
    .visible = true,
    .named = false,
  },
  [sym_pragma] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_region] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_endregion] = {
    .visible = true,
    .named = true,
  },
  [sym__assignment_operator] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__expression_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__expression_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_keyword_identifier_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_keyword_identifier_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_div] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DIV] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Div] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mod] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_MOD] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Mod] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_and] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AND] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_And] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_OR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Or] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_XOR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Xor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [sym_datetime_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_date_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_time_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_biginteger_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_IF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_If] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_then] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_THEN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Then] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ELSE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CASE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_of] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_OF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Of] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_FOR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_For] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_foreach] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_FOREACH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Foreach] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_WHILE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_While] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DO] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_repeat] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_REPEAT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Repeat] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_until] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_UNTIL] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Until] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_exit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EXIT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Exit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CONTINUE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BREAK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_with] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_WITH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_With] = {
    .visible = true,
    .named = false,
  },
  [sym_asserterror_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_IN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_In] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_to] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TO] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_To] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_downto] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOWNTO] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Downto] = {
    .visible = true,
    .named = false,
  },
  [sym_table_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_tableextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TABLEEXTENSION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Tableextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TableExtension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_tableExtension] = {
    .visible = true,
    .named = false,
  },
  [sym_page_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_pageextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PAGEEXTENSION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Pageextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PageExtension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pageExtension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_codeunit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CODEUNIT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Codeunit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CodeUnit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COdeunit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_codeUnit] = {
    .visible = true,
    .named = false,
  },
  [sym_report_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_reportextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_REPORTEXTENSION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Reportextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ReportExtension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_reportExtension] = {
    .visible = true,
    .named = false,
  },
  [sym_query_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_xmlport] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_XMLPORT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Xmlport] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_XMLport] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_XMLPort] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_XmlPort] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ENUM] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_eNUM] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_eNum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ENum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enumextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ENUMEXTENSION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Enumextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EnumExtension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enumExtension] = {
    .visible = true,
    .named = false,
  },
  [sym_interface_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_controladdin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CONTROLADDIN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Controladdin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ControlAddIn] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ControlAddin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_controlAddIn] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_controlAddin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_dotnet] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOTNET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Dotnet] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DotNet] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_dotNet] = {
    .visible = true,
    .named = false,
  },
  [sym_profile_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_profileextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PROFILEEXTENSION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Profileextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ProfileExtension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_profileExtension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_permissionset] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERMISSIONSET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Permissionset] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PermissionSet] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_permissionSet] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_permissionsetextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERMISSIONSETEXTENSION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Permissionsetextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PermissionSetExtension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_permissionSetExtension] = {
    .visible = true,
    .named = false,
  },
  [sym_entitlement_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_pagecustomization] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PAGECUSTOMIZATION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Pagecustomization] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PageCustomization] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pageCustomization] = {
    .visible = true,
    .named = false,
  },
  [sym_namespace_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_using_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_implements_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_extends_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_customizes_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_procedure_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_trigger_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_var_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_local_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_internal_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_protected_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_event_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_temporary_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_fields_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_keys_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_key_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_fieldgroups_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_fieldgroup_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_actions_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_layout_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_area_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_group_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_repeater_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_cuegroup_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_fixed_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_grid_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_part_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_systempart_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_usercontrol_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_dataset_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_elements_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_dataitem_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_column_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_filter_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_labels_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_rendering_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_requestpage_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_schema_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_views_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_view_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_quoted_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_multiline_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_integer] = {
    .visible = true,
    .named = true,
  },
  [sym_property_name] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_as_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_open] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_close] = {
    .visible = true,
    .named = true,
  },
  [sym_begin_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_end_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_begin] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_end] = {
    .visible = true,
    .named = true,
  },
  [sym_var_attribute_open] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_object] = {
    .visible = true,
    .named = true,
  },
  [sym_namespace_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_using_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_namespace_name] = {
    .visible = true,
    .named = true,
  },
  [sym__object] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_split_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__object_header] = {
    .visible = false,
    .named = true,
  },
  [sym_table_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_page_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_report_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_query_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_xmlport_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_permissionset_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_codeunit_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_tableextension_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_pageextension_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_reportextension_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_enumextension_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_permissionsetextension_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_controladdin_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_controladdin] = {
    .visible = true,
    .named = true,
  },
  [sym_profile_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_entitlement_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_profileextension_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_pagecustomization_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_dotnet_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_implements_clause] = {
    .visible = true,
    .named = true,
  },
  [sym__body_element] = {
    .visible = false,
    .named = true,
  },
  [sym_empty_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_property] = {
    .visible = true,
    .named = true,
  },
  [sym__property_value] = {
    .visible = false,
    .named = true,
  },
  [sym_decimal_range_value] = {
    .visible = true,
    .named = true,
  },
  [sym_signed_integer_list] = {
    .visible = true,
    .named = true,
  },
  [sym__signed_integer] = {
    .visible = false,
    .named = true,
  },
  [sym_object_reference_value] = {
    .visible = true,
    .named = true,
  },
  [sym_property_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym_caption_value] = {
    .visible = true,
    .named = true,
  },
  [sym_ml_value_list] = {
    .visible = true,
    .named = true,
  },
  [sym_ml_value_pair] = {
    .visible = true,
    .named = true,
  },
  [sym__calc_formula_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_lookup_formula] = {
    .visible = true,
    .named = true,
  },
  [sym_aggregate_formula] = {
    .visible = true,
    .named = true,
  },
  [sym_calc_field_reference] = {
    .visible = true,
    .named = true,
  },
  [sym_where_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_where_conditions] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_where] = {
    .visible = true,
    .named = true,
  },
  [sym_where_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_filter_value] = {
    .visible = true,
    .named = true,
  },
  [sym_sorting_value] = {
    .visible = true,
    .named = true,
  },
  [sym_link_value_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_link_values] = {
    .visible = true,
    .named = true,
  },
  [sym_link_value] = {
    .visible = true,
    .named = true,
  },
  [sym_table_relation_value] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_table_relation] = {
    .visible = true,
    .named = true,
  },
  [sym_table_relation_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_if_table_relation] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_table_relation] = {
    .visible = true,
    .named = true,
  },
  [sym_tabledata_permission_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_permissions] = {
    .visible = true,
    .named = true,
  },
  [sym_tabledata_permission] = {
    .visible = true,
    .named = true,
  },
  [sym_order_by_list] = {
    .visible = true,
    .named = true,
  },
  [sym_order_by_item] = {
    .visible = true,
    .named = true,
  },
  [sym_implementation_value_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_impl_values] = {
    .visible = true,
    .named = true,
  },
  [sym_implementation_value] = {
    .visible = true,
    .named = true,
  },
  [sym_option_member_list] = {
    .visible = true,
    .named = true,
  },
  [sym_option_member] = {
    .visible = true,
    .named = true,
  },
  [sym_fields_section] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_fields] = {
    .visible = true,
    .named = true,
  },
  [sym_field_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_keys_section] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_keys] = {
    .visible = true,
    .named = true,
  },
  [sym_key_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_field_list] = {
    .visible = true,
    .named = true,
  },
  [sym_fieldgroups_section] = {
    .visible = true,
    .named = true,
  },
  [sym_addlast_fieldgroup_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addfirst_fieldgroup_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_fieldgroups] = {
    .visible = true,
    .named = true,
  },
  [sym_fieldgroup_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_type_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_text_type] = {
    .visible = true,
    .named = true,
  },
  [sym_code_type] = {
    .visible = true,
    .named = true,
  },
  [sym_option_type] = {
    .visible = true,
    .named = true,
  },
  [sym_record_type] = {
    .visible = true,
    .named = true,
  },
  [sym_dotnet_type] = {
    .visible = true,
    .named = true,
  },
  [sym_object_reference_type] = {
    .visible = true,
    .named = true,
  },
  [sym__namespaced_or_simple_ref] = {
    .visible = false,
    .named = true,
  },
  [sym_array_type] = {
    .visible = true,
    .named = true,
  },
  [sym_list_type] = {
    .visible = true,
    .named = true,
  },
  [sym_dictionary_type] = {
    .visible = true,
    .named = true,
  },
  [sym_basic_type] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_value_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_labels_section] = {
    .visible = true,
    .named = true,
  },
  [sym_label_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_layout_section] = {
    .visible = true,
    .named = true,
  },
  [sym__layout_element] = {
    .visible = false,
    .named = true,
  },
  [sym_area_section] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_brace_close] = {
    .visible = true,
    .named = true,
  },
  [sym_group_section] = {
    .visible = true,
    .named = true,
  },
  [sym_repeater_section] = {
    .visible = true,
    .named = true,
  },
  [sym_cuegroup_section] = {
    .visible = true,
    .named = true,
  },
  [sym_fixed_section] = {
    .visible = true,
    .named = true,
  },
  [sym_grid_section] = {
    .visible = true,
    .named = true,
  },
  [sym_page_field] = {
    .visible = true,
    .named = true,
  },
  [sym__field_source] = {
    .visible = false,
    .named = true,
  },
  [sym_part_section] = {
    .visible = true,
    .named = true,
  },
  [sym_systempart_section] = {
    .visible = true,
    .named = true,
  },
  [sym_usercontrol_section] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_field] = {
    .visible = true,
    .named = true,
  },
  [sym__field_header] = {
    .visible = false,
    .named = true,
  },
  [sym_label_section] = {
    .visible = true,
    .named = true,
  },
  [sym_addfirst_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addlast_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addafter_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addbefore_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_modify_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_movefirst_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_movelast_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_moveafter_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_movebefore_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_actions_section] = {
    .visible = true,
    .named = true,
  },
  [sym__action_element] = {
    .visible = false,
    .named = true,
  },
  [sym_action_area_section] = {
    .visible = true,
    .named = true,
  },
  [sym_action_group_section] = {
    .visible = true,
    .named = true,
  },
  [sym_action_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_separator_action] = {
    .visible = true,
    .named = true,
  },
  [sym_actionref_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_systemaction_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_fileuploadaction_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_customaction_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_addfirst_action_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addlast_action_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addafter_action_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addbefore_action_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_modify_action_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_views_section] = {
    .visible = true,
    .named = true,
  },
  [sym_addfirst_views_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addlast_views_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addafter_views_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addbefore_views_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_view_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_dataset_section] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_dataset] = {
    .visible = true,
    .named = true,
  },
  [sym_report_dataitem] = {
    .visible = true,
    .named = true,
  },
  [sym__report_body_element] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_conditional_report] = {
    .visible = true,
    .named = true,
  },
  [sym_report_column] = {
    .visible = true,
    .named = true,
  },
  [sym_add_dataset_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addfirst_dataset_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addlast_dataset_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addafter_dataset_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addbefore_dataset_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_requestpage_section] = {
    .visible = true,
    .named = true,
  },
  [sym_rendering_section] = {
    .visible = true,
    .named = true,
  },
  [sym_rendering_layout] = {
    .visible = true,
    .named = true,
  },
  [sym_elements_section] = {
    .visible = true,
    .named = true,
  },
  [sym_query_dataitem] = {
    .visible = true,
    .named = true,
  },
  [sym__query_body_element] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_conditional_query] = {
    .visible = true,
    .named = true,
  },
  [sym_query_column] = {
    .visible = true,
    .named = true,
  },
  [sym_query_filter] = {
    .visible = true,
    .named = true,
  },
  [sym_schema_section] = {
    .visible = true,
    .named = true,
  },
  [sym_xmlport_element] = {
    .visible = true,
    .named = true,
  },
  [sym__xmlport_body_element] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_conditional_xmlport] = {
    .visible = true,
    .named = true,
  },
  [sym_xmlport_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_assembly_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_type_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_event_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_procedure] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_procedure_body] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_procedure] = {
    .visible = true,
    .named = true,
  },
  [sym__procedure_header] = {
    .visible = false,
    .named = true,
  },
  [sym_interface_procedure] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_procedure_suffix] = {
    .visible = true,
    .named = true,
  },
  [sym_procedure_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym__procedure_return_specification] = {
    .visible = false,
    .named = true,
  },
  [sym__procedure_named_return] = {
    .visible = false,
    .named = true,
  },
  [sym_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_code_block] = {
    .visible = true,
    .named = true,
  },
  [sym_trigger_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_var_block] = {
    .visible = true,
    .named = true,
  },
  [sym__trigger_name] = {
    .visible = false,
    .named = true,
  },
  [sym_var_section] = {
    .visible = true,
    .named = true,
  },
  [sym_var_attribute_item] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_var] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_label_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_item] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_content] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym__attribute_argument] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_conditional] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_if] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_not_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elif] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_else] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_endif] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__preproc_if_header] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_guarded_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__preproc_guard_block] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_split_if_else_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_if_then_begin] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_code_block_end] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_fragmented_else_tail] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_actions] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_layout] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_layout_mixed] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym__expression_statement] = {
    .visible = false,
    .named = true,
  },
  [sym_assignment_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__if_statement_no_else] = {
    .visible = true,
    .named = true,
  },
  [sym_case_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_case] = {
    .visible = true,
    .named = true,
  },
  [sym_case_branch] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_case_branch] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__case_pattern] = {
    .visible = false,
    .named = false,
  },
  [sym_preproc_conditional_case_patterns] = {
    .visible = true,
    .named = true,
  },
  [sym__single_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym_case_else_branch] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_foreach_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_repeat_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_with_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_exit_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_asserterror_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
  },
  [sym_keyword_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_range_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_multiplicative_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_additive_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_comparison_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_comparison_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_logical_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_ternary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_member_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_list_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_qualified_enum_value] = {
    .visible = true,
    .named = true,
  },
  [sym_database_reference] = {
    .visible = true,
    .named = true,
  },
  [sym__literal_value] = {
    .visible = false,
    .named = true,
  },
  [sym_if_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_then_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_else_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_case_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_of_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_for_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_foreach_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_while_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_do_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_repeat_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_until_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_exit_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_break_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_with_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_in_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_to_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_downto_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_tableextension_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_pageextension_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_codeunit_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_reportextension_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_xmlport_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_enumextension_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_controladdin_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_dotnet_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_profileextension_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_permissionset_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_permissionsetextension_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_pagecustomization_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym__identifier_or_quoted] = {
    .visible = false,
    .named = true,
  },
  [sym_keyword_as_identifier] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_object_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_namespace_name_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_declaration_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_controladdin_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_controladdin_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_interface_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dotnet_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_implements_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_signed_integer_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_caption_value_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_ml_value_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_calc_field_reference_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_where_conditions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_where_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_where_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_filter_value_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sorting_value_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_link_value_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_link_values_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_link_values_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_table_relation_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tabledata_permission_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_permissions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_order_by_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_implementation_value_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_impl_values_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_impl_values_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_option_member_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_option_member_list_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_fields_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_fields_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_fields_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_keys_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_keys_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_keys_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_fieldgroups_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_fieldgroups_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_fieldgroups_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__namespaced_or_simple_ref_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_labels_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_label_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_layout_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_group_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_field_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_actions_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_action_group_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_views_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_addfirst_views_modification_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dataset_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_dataset_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_dataset_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_report_dataitem_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_report_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_add_dataset_modification_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_rendering_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_elements_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_query_dataitem_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_query_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_schema_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_xmlport_element_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_xmlport_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_assembly_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_procedure_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_procedure_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__procedure_header_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_var_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_var_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_var_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_var_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_declaration_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attribute_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__preproc_guard_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_if_else_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_actions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_layout_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_layout_mixed_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_layout_mixed_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_case_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_case_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_case_branch_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_case_branch_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_aggregate_function] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_object_type_keyword] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_access_value = 1,
  field_action_name = 2,
  field_al_name = 3,
  field_arguments = 4,
  field_attribute = 5,
  field_attribute_type = 6,
  field_base_object = 7,
  field_body = 8,
  field_comment = 9,
  field_condition = 10,
  field_direction = 11,
  field_dotnet_type = 12,
  field_element = 13,
  field_element_type = 14,
  field_else_branch = 15,
  field_else_relation = 16,
  field_else_value = 17,
  field_end = 18,
  field_enum_type = 19,
  field_expression = 20,
  field_extends_interface = 21,
  field_field = 22,
  field_field_name = 23,
  field_fields = 24,
  field_function = 25,
  field_id = 26,
  field_implementation = 27,
  field_index = 28,
  field_interface = 29,
  field_iterable = 30,
  field_key_type = 31,
  field_keyword = 32,
  field_language = 33,
  field_left = 34,
  field_length = 35,
  field_locked = 36,
  field_max = 37,
  field_maxlength = 38,
  field_member = 39,
  field_min = 40,
  field_modifier = 41,
  field_name = 42,
  field_namespace = 43,
  field_object = 44,
  field_object_id = 45,
  field_object_name = 46,
  field_object_type = 47,
  field_operand = 48,
  field_operator = 49,
  field_pattern = 50,
  field_permission = 51,
  field_promoted_name = 52,
  field_record = 53,
  field_reference = 54,
  field_return_type = 55,
  field_return_value = 56,
  field_right = 57,
  field_sizes = 58,
  field_source = 59,
  field_start = 60,
  field_table = 61,
  field_table_name = 62,
  field_target = 63,
  field_target_page = 64,
  field_then_branch = 65,
  field_then_relation = 66,
  field_then_value = 67,
  field_type = 68,
  field_value = 69,
  field_value_id = 70,
  field_value_name = 71,
  field_value_type = 72,
  field_variable = 73,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_access_value] = "access_value",
  [field_action_name] = "action_name",
  [field_al_name] = "al_name",
  [field_arguments] = "arguments",
  [field_attribute] = "attribute",
  [field_attribute_type] = "attribute_type",
  [field_base_object] = "base_object",
  [field_body] = "body",
  [field_comment] = "comment",
  [field_condition] = "condition",
  [field_direction] = "direction",
  [field_dotnet_type] = "dotnet_type",
  [field_element] = "element",
  [field_element_type] = "element_type",
  [field_else_branch] = "else_branch",
  [field_else_relation] = "else_relation",
  [field_else_value] = "else_value",
  [field_end] = "end",
  [field_enum_type] = "enum_type",
  [field_expression] = "expression",
  [field_extends_interface] = "extends_interface",
  [field_field] = "field",
  [field_field_name] = "field_name",
  [field_fields] = "fields",
  [field_function] = "function",
  [field_id] = "id",
  [field_implementation] = "implementation",
  [field_index] = "index",
  [field_interface] = "interface",
  [field_iterable] = "iterable",
  [field_key_type] = "key_type",
  [field_keyword] = "keyword",
  [field_language] = "language",
  [field_left] = "left",
  [field_length] = "length",
  [field_locked] = "locked",
  [field_max] = "max",
  [field_maxlength] = "maxlength",
  [field_member] = "member",
  [field_min] = "min",
  [field_modifier] = "modifier",
  [field_name] = "name",
  [field_namespace] = "namespace",
  [field_object] = "object",
  [field_object_id] = "object_id",
  [field_object_name] = "object_name",
  [field_object_type] = "object_type",
  [field_operand] = "operand",
  [field_operator] = "operator",
  [field_pattern] = "pattern",
  [field_permission] = "permission",
  [field_promoted_name] = "promoted_name",
  [field_record] = "record",
  [field_reference] = "reference",
  [field_return_type] = "return_type",
  [field_return_value] = "return_value",
  [field_right] = "right",
  [field_sizes] = "sizes",
  [field_source] = "source",
  [field_start] = "start",
  [field_table] = "table",
  [field_table_name] = "table_name",
  [field_target] = "target",
  [field_target_page] = "target_page",
  [field_then_branch] = "then_branch",
  [field_then_relation] = "then_relation",
  [field_then_value] = "then_value",
  [field_type] = "type",
  [field_value] = "value",
  [field_value_id] = "value_id",
  [field_value_name] = "value_name",
  [field_value_type] = "value_type",
  [field_variable] = "variable",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 1},
  [5] = {.index = 4, .length = 2},
  [6] = {.index = 6, .length = 3},
  [7] = {.index = 9, .length = 6},
  [8] = {.index = 15, .length = 1},
  [9] = {.index = 16, .length = 1},
  [10] = {.index = 17, .length = 1},
  [11] = {.index = 18, .length = 2},
  [12] = {.index = 20, .length = 1},
  [13] = {.index = 21, .length = 2},
  [14] = {.index = 23, .length = 6},
  [15] = {.index = 29, .length = 3},
  [16] = {.index = 32, .length = 2},
  [17] = {.index = 34, .length = 2},
  [18] = {.index = 36, .length = 2},
  [19] = {.index = 38, .length = 5},
  [20] = {.index = 43, .length = 2},
  [21] = {.index = 45, .length = 1},
  [22] = {.index = 46, .length = 2},
  [23] = {.index = 48, .length = 2},
  [24] = {.index = 50, .length = 4},
  [25] = {.index = 54, .length = 8},
  [26] = {.index = 62, .length = 2},
  [27] = {.index = 64, .length = 6},
  [28] = {.index = 70, .length = 2},
  [29] = {.index = 72, .length = 3},
  [30] = {.index = 75, .length = 2},
  [31] = {.index = 77, .length = 2},
  [32] = {.index = 79, .length = 2},
  [33] = {.index = 81, .length = 5},
  [34] = {.index = 86, .length = 9},
  [35] = {.index = 95, .length = 8},
  [36] = {.index = 103, .length = 6},
  [37] = {.index = 109, .length = 2},
  [38] = {.index = 111, .length = 2},
  [39] = {.index = 113, .length = 2},
  [40] = {.index = 115, .length = 1},
  [41] = {.index = 116, .length = 2},
  [42] = {.index = 118, .length = 1},
  [43] = {.index = 119, .length = 2},
  [44] = {.index = 121, .length = 2},
  [45] = {.index = 123, .length = 3},
  [46] = {.index = 126, .length = 8},
  [47] = {.index = 134, .length = 9},
  [48] = {.index = 143, .length = 1},
  [49] = {.index = 144, .length = 1},
  [50] = {.index = 145, .length = 2},
  [51] = {.index = 147, .length = 6},
  [52] = {.index = 153, .length = 6},
  [53] = {.index = 159, .length = 2},
  [54] = {.index = 161, .length = 8},
  [55] = {.index = 169, .length = 1},
  [56] = {.index = 170, .length = 2},
  [57] = {.index = 172, .length = 3},
  [58] = {.index = 175, .length = 2},
  [59] = {.index = 177, .length = 3},
  [60] = {.index = 180, .length = 3},
  [61] = {.index = 183, .length = 2},
  [62] = {.index = 185, .length = 8},
  [63] = {.index = 193, .length = 1},
  [64] = {.index = 194, .length = 4},
  [65] = {.index = 198, .length = 3},
  [66] = {.index = 201, .length = 6},
  [67] = {.index = 207, .length = 1},
  [68] = {.index = 208, .length = 11},
  [69] = {.index = 219, .length = 12},
  [70] = {.index = 231, .length = 1},
  [71] = {.index = 232, .length = 4},
  [72] = {.index = 236, .length = 3},
  [73] = {.index = 239, .length = 2},
  [74] = {.index = 241, .length = 3},
  [75] = {.index = 244, .length = 1},
  [76] = {.index = 245, .length = 6},
  [77] = {.index = 251, .length = 5},
  [78] = {.index = 256, .length = 6},
  [79] = {.index = 262, .length = 3},
  [80] = {.index = 265, .length = 4},
  [81] = {.index = 269, .length = 7},
  [82] = {.index = 276, .length = 4},
  [83] = {.index = 280, .length = 12},
  [84] = {.index = 292, .length = 2},
  [85] = {.index = 294, .length = 3},
  [86] = {.index = 297, .length = 2},
  [87] = {.index = 299, .length = 9},
  [88] = {.index = 308, .length = 9},
  [89] = {.index = 317, .length = 2},
  [90] = {.index = 319, .length = 2},
  [91] = {.index = 321, .length = 1},
  [92] = {.index = 322, .length = 2},
  [93] = {.index = 324, .length = 2},
  [94] = {.index = 326, .length = 1},
  [95] = {.index = 327, .length = 5},
  [96] = {.index = 332, .length = 2},
  [97] = {.index = 334, .length = 9},
  [98] = {.index = 343, .length = 2},
  [99] = {.index = 345, .length = 3},
  [100] = {.index = 348, .length = 4},
  [101] = {.index = 352, .length = 3},
  [102] = {.index = 355, .length = 4},
  [103] = {.index = 359, .length = 5},
  [104] = {.index = 364, .length = 8},
  [105] = {.index = 372, .length = 8},
  [106] = {.index = 380, .length = 4},
  [107] = {.index = 384, .length = 5},
  [108] = {.index = 389, .length = 8},
  [109] = {.index = 397, .length = 4},
  [110] = {.index = 401, .length = 5},
  [111] = {.index = 406, .length = 8},
  [112] = {.index = 414, .length = 7},
  [113] = {.index = 421, .length = 4},
  [114] = {.index = 425, .length = 5},
  [115] = {.index = 430, .length = 8},
  [116] = {.index = 438, .length = 2},
  [117] = {.index = 440, .length = 3},
  [118] = {.index = 443, .length = 3},
  [119] = {.index = 446, .length = 4},
  [120] = {.index = 450, .length = 9},
  [121] = {.index = 459, .length = 12},
  [122] = {.index = 471, .length = 2},
  [123] = {.index = 473, .length = 2},
  [124] = {.index = 475, .length = 3},
  [125] = {.index = 478, .length = 1},
  [126] = {.index = 479, .length = 1},
  [127] = {.index = 480, .length = 1},
  [128] = {.index = 481, .length = 9},
  [129] = {.index = 490, .length = 12},
  [130] = {.index = 502, .length = 3},
  [131] = {.index = 505, .length = 4},
  [132] = {.index = 509, .length = 12},
  [133] = {.index = 521, .length = 12},
  [134] = {.index = 533, .length = 3},
  [135] = {.index = 536, .length = 2},
  [136] = {.index = 538, .length = 3},
  [137] = {.index = 541, .length = 2},
  [138] = {.index = 543, .length = 2},
  [139] = {.index = 545, .length = 2},
  [140] = {.index = 547, .length = 6},
  [141] = {.index = 553, .length = 9},
  [142] = {.index = 562, .length = 12},
  [143] = {.index = 574, .length = 6},
  [144] = {.index = 580, .length = 9},
  [145] = {.index = 589, .length = 9},
  [146] = {.index = 598, .length = 12},
  [147] = {.index = 610, .length = 6},
  [148] = {.index = 616, .length = 9},
  [149] = {.index = 625, .length = 9},
  [150] = {.index = 634, .length = 12},
  [151] = {.index = 646, .length = 5},
  [152] = {.index = 651, .length = 8},
  [153] = {.index = 659, .length = 10},
  [154] = {.index = 669, .length = 6},
  [155] = {.index = 675, .length = 9},
  [156] = {.index = 684, .length = 15},
  [157] = {.index = 699, .length = 2},
  [158] = {.index = 701, .length = 3},
  [159] = {.index = 704, .length = 4},
  [160] = {.index = 708, .length = 13},
  [161] = {.index = 721, .length = 16},
  [162] = {.index = 737, .length = 10},
  [163] = {.index = 747, .length = 13},
  [164] = {.index = 760, .length = 13},
  [165] = {.index = 773, .length = 16},
  [166] = {.index = 789, .length = 5},
  [167] = {.index = 794, .length = 8},
  [168] = {.index = 802, .length = 3},
  [169] = {.index = 805, .length = 7},
  [170] = {.index = 812, .length = 6},
  [171] = {.index = 818, .length = 7},
  [172] = {.index = 825, .length = 4},
  [173] = {.index = 829, .length = 3},
  [174] = {.index = 832, .length = 10},
  [175] = {.index = 842, .length = 13},
  [176] = {.index = 855, .length = 13},
  [177] = {.index = 868, .length = 16},
  [178] = {.index = 884, .length = 6},
  [179] = {.index = 890, .length = 9},
  [180] = {.index = 899, .length = 10},
  [181] = {.index = 909, .length = 9},
  [182] = {.index = 918, .length = 12},
  [183] = {.index = 930, .length = 5},
  [184] = {.index = 935, .length = 8},
  [185] = {.index = 943, .length = 10},
  [186] = {.index = 953, .length = 11},
  [187] = {.index = 964, .length = 14},
  [188] = {.index = 978, .length = 2},
  [189] = {.index = 980, .length = 7},
  [190] = {.index = 987, .length = 6},
  [191] = {.index = 993, .length = 10},
  [192] = {.index = 1003, .length = 3},
  [193] = {.index = 1006, .length = 7},
  [194] = {.index = 1013, .length = 6},
  [195] = {.index = 1019, .length = 7},
  [196] = {.index = 1026, .length = 2},
  [197] = {.index = 1028, .length = 14},
  [198] = {.index = 1042, .length = 17},
  [199] = {.index = 1059, .length = 17},
  [200] = {.index = 1076, .length = 20},
  [201] = {.index = 1096, .length = 11},
  [202] = {.index = 1107, .length = 14},
  [203] = {.index = 1121, .length = 14},
  [204] = {.index = 1135, .length = 17},
  [205] = {.index = 1152, .length = 5},
  [206] = {.index = 1157, .length = 8},
  [207] = {.index = 1165, .length = 10},
  [208] = {.index = 1175, .length = 8},
  [209] = {.index = 1183, .length = 11},
  [210] = {.index = 1194, .length = 13},
  [211] = {.index = 1207, .length = 2},
  [212] = {.index = 1209, .length = 10},
  [213] = {.index = 1219, .length = 7},
  [214] = {.index = 1226, .length = 6},
  [215] = {.index = 1232, .length = 10},
  [216] = {.index = 1242, .length = 7},
  [217] = {.index = 1249, .length = 7},
  [218] = {.index = 1256, .length = 8},
  [219] = {.index = 1264, .length = 11},
  [220] = {.index = 1275, .length = 13},
  [221] = {.index = 1288, .length = 8},
  [222] = {.index = 1296, .length = 11},
  [223] = {.index = 1307, .length = 13},
  [224] = {.index = 1320, .length = 11},
  [225] = {.index = 1331, .length = 14},
  [226] = {.index = 1345, .length = 16},
  [227] = {.index = 1361, .length = 10},
  [228] = {.index = 1371, .length = 6},
  [229] = {.index = 1377, .length = 6},
  [230] = {.index = 1383, .length = 10},
  [231] = {.index = 1393, .length = 10},
  [232] = {.index = 1403, .length = 10},
  [233] = {.index = 1413, .length = 11},
  [234] = {.index = 1424, .length = 14},
  [235] = {.index = 1438, .length = 16},
  [236] = {.index = 1454, .length = 11},
  [237] = {.index = 1465, .length = 14},
  [238] = {.index = 1479, .length = 16},
  [239] = {.index = 1495, .length = 13},
  [240] = {.index = 1508, .length = 14},
  [241] = {.index = 1522, .length = 17},
  [242] = {.index = 1539, .length = 19},
  [243] = {.index = 1558, .length = 2},
  [244] = {.index = 1560, .length = 7},
  [245] = {.index = 1567, .length = 10},
  [246] = {.index = 1577, .length = 10},
  [247] = {.index = 1587, .length = 11},
  [248] = {.index = 1598, .length = 14},
  [249] = {.index = 1612, .length = 14},
  [250] = {.index = 1626, .length = 17},
  [251] = {.index = 1643, .length = 14},
  [252] = {.index = 1657, .length = 17},
  [253] = {.index = 1674, .length = 17},
  [254] = {.index = 1691, .length = 20},
  [255] = {.index = 1711, .length = 10},
  [256] = {.index = 1721, .length = 13},
  [257] = {.index = 1734, .length = 16},
  [258] = {.index = 1750, .length = 19},
  [259] = {.index = 1769, .length = 19},
  [260] = {.index = 1788, .length = 22},
  [261] = {.index = 1810, .length = 19},
  [262] = {.index = 1829, .length = 22},
  [263] = {.index = 1851, .length = 22},
  [264] = {.index = 1873, .length = 25},
  [265] = {.index = 1898, .length = 13},
  [266] = {.index = 1911, .length = 13},
  [267] = {.index = 1924, .length = 16},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_condition, 1},
  [1] =
    {field_name, 1},
  [2] =
    {field_namespace, 1},
  [3] =
    {field_object_name, 1},
  [4] =
    {field_object_id, 1},
    {field_object_name, 2},
  [6] =
    {field_base_object, 1, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_name, 1, .inherited = true},
  [9] =
    {field_base_object, 0, .inherited = true},
    {field_base_object, 1, .inherited = true},
    {field_object_id, 0, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_name, 0, .inherited = true},
    {field_object_name, 1, .inherited = true},
  [15] =
    {field_name, 0},
  [16] =
    {field_interface, 1},
  [17] =
    {field_table, 0},
  [18] =
    {field_arguments, 1},
    {field_name, 0},
  [20] =
    {field_attribute, 1},
  [21] =
    {field_extends_interface, 3},
    {field_object_name, 1},
  [23] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 2, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 2, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 2, .inherited = true},
  [29] =
    {field_base_object, 4},
    {field_object_id, 1},
    {field_object_name, 2},
  [32] =
    {field_interface, 1},
    {field_interface, 2, .inherited = true},
  [34] =
    {field_base_object, 3},
    {field_object_name, 1},
  [36] =
    {field_object_name, 1},
    {field_target_page, 3},
  [38] =
    {field_left, 1, .inherited = true},
    {field_operand, 1},
    {field_operator, 0},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [43] =
    {field_arguments, 1},
    {field_function, 0},
  [45] =
    {field_min, 0},
  [46] =
    {field_name, 0},
    {field_value, 2},
  [48] =
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
  [50] =
    {field_modifier, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_return_type, 1, .inherited = true},
    {field_return_value, 1, .inherited = true},
  [54] =
    {field_modifier, 0, .inherited = true},
    {field_modifier, 1, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_return_type, 0, .inherited = true},
    {field_return_type, 1, .inherited = true},
    {field_return_value, 0, .inherited = true},
    {field_return_value, 1, .inherited = true},
  [62] =
    {field_access_value, 4},
    {field_object_name, 1},
  [64] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 3, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 3, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 3, .inherited = true},
  [70] =
    {field_interface, 0, .inherited = true},
    {field_interface, 1, .inherited = true},
  [72] =
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [75] =
    {field_keyword, 0},
    {field_table_name, 2},
  [77] =
    {field_enum_type, 0},
    {field_value, 2},
  [79] =
    {field_max, 2},
    {field_min, 0},
  [81] =
    {field_left, 0, .inherited = true},
    {field_member, 2},
    {field_object, 0},
    {field_operator, 0, .inherited = true},
    {field_right, 0, .inherited = true},
  [86] =
    {field_left, 0},
    {field_left, 0, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 1},
    {field_operator, 2, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 2},
    {field_right, 2, .inherited = true},
  [95] =
    {field_left, 0},
    {field_left, 0, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 2},
    {field_right, 2, .inherited = true},
  [103] =
    {field_left, 0},
    {field_left, 0, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 1},
    {field_right, 0, .inherited = true},
    {field_right, 2},
  [109] =
    {field_language, 0},
    {field_value, 2},
  [111] =
    {field_field, 0},
    {field_value, 2},
  [113] =
    {field_implementation, 2},
    {field_interface, 0},
  [115] =
    {field_return_type, 0, .inherited = true},
  [116] =
    {field_return_type, 0, .inherited = true},
    {field_return_value, 0, .inherited = true},
  [118] =
    {field_reference, 1},
  [119] =
    {field_object_type, 0},
    {field_reference, 1},
  [121] =
    {field_name, 0},
    {field_type, 2},
  [123] =
    {field_left, 0, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_right, 0, .inherited = true},
  [126] =
    {field_modifier, 1, .inherited = true},
    {field_modifier, 2, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_return_type, 1, .inherited = true},
    {field_return_type, 2, .inherited = true},
    {field_return_value, 1, .inherited = true},
    {field_return_value, 2, .inherited = true},
  [134] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 2, .inherited = true},
    {field_base_object, 4, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 2, .inherited = true},
    {field_object_id, 4, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 2, .inherited = true},
    {field_object_name, 4, .inherited = true},
  [143] =
    {field_name, 2},
  [144] =
    {field_target, 2},
  [145] =
    {field_permission, 3},
    {field_table_name, 1},
  [147] =
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
  [153] =
    {field_left, 0, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 1, .inherited = true},
  [159] =
    {field_function, 0},
    {field_target, 2},
  [161] =
    {field_index, 2},
    {field_left, 0, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_object, 0},
    {field_operator, 0, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 2, .inherited = true},
  [169] =
    {field_return_type, 1},
  [170] =
    {field_name, 1},
    {field_return_type, 4, .inherited = true},
  [172] =
    {field_name, 1},
    {field_return_type, 4, .inherited = true},
    {field_return_value, 4, .inherited = true},
  [175] =
    {field_return_type, 1, .inherited = true},
    {field_return_value, 0},
  [177] =
    {field_name, 0},
    {field_type, 2},
    {field_value, 3},
  [180] =
    {field_name, 0},
    {field_name, 1, .inherited = true},
    {field_type, 3},
  [183] =
    {field_modifier, 0},
    {field_name, 2},
  [185] =
    {field_modifier, 1, .inherited = true},
    {field_modifier, 3, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 3, .inherited = true},
    {field_return_type, 1, .inherited = true},
    {field_return_type, 3, .inherited = true},
    {field_return_value, 1, .inherited = true},
    {field_return_value, 3, .inherited = true},
  [193] =
    {field_body, 1},
  [194] =
    {field_body, 1},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [198] =
    {field_access_value, 6},
    {field_extends_interface, 3},
    {field_object_name, 1},
  [201] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 4, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 4, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 4, .inherited = true},
  [207] =
    {field_then_relation, 4},
  [208] =
    {field_index, 2},
    {field_left, 0, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_object, 0},
    {field_operator, 0, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 3, .inherited = true},
  [219] =
    {field_condition, 0},
    {field_else_value, 4},
    {field_left, 0, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_value, 2},
  [231] =
    {field_field, 0},
  [232] =
    {field_field, 0},
    {field_value, 2},
    {field_value, 3},
    {field_value, 4},
  [236] =
    {field_modifier, 0},
    {field_name, 1},
    {field_type, 3},
  [239] =
    {field_name, 1},
    {field_return_type, 5, .inherited = true},
  [241] =
    {field_name, 1},
    {field_return_type, 5, .inherited = true},
    {field_return_value, 5, .inherited = true},
  [244] =
    {field_length, 2},
  [245] =
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
  [251] =
    {field_comment, 3, .inherited = true},
    {field_locked, 3, .inherited = true},
    {field_maxlength, 3, .inherited = true},
    {field_name, 0},
    {field_value, 2},
  [256] =
    {field_comment, 0, .inherited = true},
    {field_comment, 1, .inherited = true},
    {field_locked, 0, .inherited = true},
    {field_locked, 1, .inherited = true},
    {field_maxlength, 0, .inherited = true},
    {field_maxlength, 1, .inherited = true},
  [262] =
    {field_modifier, 0},
    {field_name, 2},
    {field_return_type, 5, .inherited = true},
  [265] =
    {field_modifier, 0},
    {field_name, 2},
    {field_return_type, 5, .inherited = true},
    {field_return_value, 5, .inherited = true},
  [269] =
    {field_condition, 1, .inherited = true},
    {field_left, 0, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 1, .inherited = true},
  [276] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 2, .inherited = true},
  [280] =
    {field_modifier, 1, .inherited = true},
    {field_modifier, 2, .inherited = true},
    {field_modifier, 4, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_name, 4, .inherited = true},
    {field_return_type, 1, .inherited = true},
    {field_return_type, 2, .inherited = true},
    {field_return_type, 4, .inherited = true},
    {field_return_value, 1, .inherited = true},
    {field_return_value, 2, .inherited = true},
    {field_return_value, 4, .inherited = true},
  [292] =
    {field_name, 2},
    {field_return_type, 5, .inherited = true},
  [294] =
    {field_name, 2},
    {field_return_type, 5, .inherited = true},
    {field_return_value, 5, .inherited = true},
  [297] =
    {field_modifier, 1},
    {field_name, 3},
  [299] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 4, .inherited = true},
    {field_base_object, 5, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 4, .inherited = true},
    {field_object_id, 5, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 4, .inherited = true},
    {field_object_name, 5, .inherited = true},
  [308] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 2, .inherited = true},
    {field_base_object, 5, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 2, .inherited = true},
    {field_object_id, 5, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 2, .inherited = true},
    {field_object_name, 5, .inherited = true},
  [317] =
    {field_field, 0},
    {field_value, 4},
  [319] =
    {field_value_id, 2},
    {field_value_name, 4},
  [321] =
    {field_element_type, 3},
  [322] =
    {field_fields, 4},
    {field_name, 2},
  [324] =
    {field_fields, 4},
    {field_target, 2},
  [326] =
    {field_type, 2},
  [327] =
    {field_left, 4, .inherited = true},
    {field_name, 2},
    {field_operator, 4, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_source, 4},
  [332] =
    {field_element, 4},
    {field_target, 2},
  [334] =
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
  [343] =
    {field_element_type, 0},
    {field_name, 2},
  [345] =
    {field_modifier, 0},
    {field_name, 2},
    {field_return_type, 6, .inherited = true},
  [348] =
    {field_modifier, 0},
    {field_name, 2},
    {field_return_type, 6, .inherited = true},
    {field_return_value, 6, .inherited = true},
  [352] =
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 2, .inherited = true},
  [355] =
    {field_condition, 1, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [359] =
    {field_condition, 1, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_then_branch, 3},
  [364] =
    {field_condition, 1, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_then_branch, 3},
  [372] =
    {field_condition, 0, .inherited = true},
    {field_condition, 1, .inherited = true},
    {field_left, 0, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 1, .inherited = true},
  [380] =
    {field_condition, 1},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [384] =
    {field_condition, 1},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_then_branch, 3},
  [389] =
    {field_condition, 1},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_then_branch, 3},
  [397] =
    {field_expression, 1},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [401] =
    {field_body, 3},
    {field_condition, 1},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [406] =
    {field_body, 3},
    {field_condition, 1},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
  [414] =
    {field_condition, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
  [421] =
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_return_value, 2},
    {field_right, 2, .inherited = true},
  [425] =
    {field_body, 3},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_record, 1},
    {field_right, 1, .inherited = true},
  [430] =
    {field_body, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_record, 1},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
  [438] =
    {field_name, 2},
    {field_return_type, 6, .inherited = true},
  [440] =
    {field_name, 2},
    {field_return_type, 6, .inherited = true},
    {field_return_value, 6, .inherited = true},
  [443] =
    {field_modifier, 1},
    {field_name, 3},
    {field_return_type, 6, .inherited = true},
  [446] =
    {field_modifier, 1},
    {field_name, 3},
    {field_return_type, 6, .inherited = true},
    {field_return_value, 6, .inherited = true},
  [450] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 4, .inherited = true},
    {field_base_object, 6, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 4, .inherited = true},
    {field_object_id, 6, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 4, .inherited = true},
    {field_object_name, 6, .inherited = true},
  [459] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 2, .inherited = true},
    {field_base_object, 5, .inherited = true},
    {field_base_object, 6, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 2, .inherited = true},
    {field_object_id, 5, .inherited = true},
    {field_object_id, 6, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 2, .inherited = true},
    {field_object_name, 5, .inherited = true},
    {field_object_name, 6, .inherited = true},
  [471] =
    {field_else_relation, 6},
    {field_then_relation, 4},
  [473] =
    {field_element_type, 5},
    {field_sizes, 2},
  [475] =
    {field_left, 4, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 4, .inherited = true},
  [478] =
    {field_locked, 3},
  [479] =
    {field_comment, 3},
  [480] =
    {field_maxlength, 3},
  [481] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_then_branch, 4},
  [490] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_branch, 4},
  [502] =
    {field_modifier, 1},
    {field_name, 3},
    {field_return_type, 7, .inherited = true},
  [505] =
    {field_modifier, 1},
    {field_name, 3},
    {field_return_type, 7, .inherited = true},
    {field_return_value, 7, .inherited = true},
  [509] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 4, .inherited = true},
    {field_base_object, 5, .inherited = true},
    {field_base_object, 7, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 4, .inherited = true},
    {field_object_id, 5, .inherited = true},
    {field_object_id, 7, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 4, .inherited = true},
    {field_object_name, 5, .inherited = true},
    {field_object_name, 7, .inherited = true},
  [521] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 2, .inherited = true},
    {field_base_object, 5, .inherited = true},
    {field_base_object, 7, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 2, .inherited = true},
    {field_object_id, 5, .inherited = true},
    {field_object_id, 7, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 2, .inherited = true},
    {field_object_name, 5, .inherited = true},
    {field_object_name, 7, .inherited = true},
  [533] =
    {field_element_type, 6},
    {field_sizes, 2},
    {field_sizes, 3},
  [536] =
    {field_key_type, 3},
    {field_value_type, 5},
  [538] =
    {field_id, 2},
    {field_name, 4},
    {field_type, 6},
  [541] =
    {field_action_name, 4},
    {field_promoted_name, 2},
  [543] =
    {field_name, 2},
    {field_source, 4},
  [545] =
    {field_name, 2},
    {field_table_name, 4},
  [547] =
    {field_element_type, 0},
    {field_left, 4, .inherited = true},
    {field_name, 2},
    {field_operator, 4, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_source, 4},
  [553] =
    {field_condition, 1, .inherited = true},
    {field_condition, 3, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_then_branch, 5},
  [562] =
    {field_condition, 1, .inherited = true},
    {field_condition, 3, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 5},
  [574] =
    {field_condition, 1, .inherited = true},
    {field_else_branch, 5},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_then_branch, 3},
  [580] =
    {field_condition, 1, .inherited = true},
    {field_else_branch, 5},
    {field_left, 1, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 3},
  [589] =
    {field_condition, 1, .inherited = true},
    {field_else_branch, 5},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_then_branch, 3},
  [598] =
    {field_condition, 1, .inherited = true},
    {field_else_branch, 5},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 3},
  [610] =
    {field_condition, 1},
    {field_else_branch, 5},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_then_branch, 3},
  [616] =
    {field_condition, 1},
    {field_else_branch, 5},
    {field_left, 1, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 3},
  [625] =
    {field_condition, 1},
    {field_else_branch, 5},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_then_branch, 3},
  [634] =
    {field_condition, 1},
    {field_else_branch, 5},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 3},
  [646] =
    {field_body, 2},
    {field_left, 0, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_pattern, 0},
    {field_right, 0, .inherited = true},
  [651] =
    {field_body, 2},
    {field_left, 0, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_pattern, 0},
    {field_right, 0, .inherited = true},
    {field_right, 2, .inherited = true},
  [659] =
    {field_body, 2},
    {field_condition, 2, .inherited = true},
    {field_left, 0, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_pattern, 0},
    {field_right, 0, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_then_branch, 2, .inherited = true},
  [669] =
    {field_body, 5},
    {field_iterable, 3},
    {field_left, 3, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_variable, 1},
  [675] =
    {field_body, 5},
    {field_iterable, 3},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_variable, 1},
  [684] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 2, .inherited = true},
    {field_base_object, 5, .inherited = true},
    {field_base_object, 6, .inherited = true},
    {field_base_object, 8, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 2, .inherited = true},
    {field_object_id, 5, .inherited = true},
    {field_object_id, 6, .inherited = true},
    {field_object_id, 8, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 2, .inherited = true},
    {field_object_name, 5, .inherited = true},
    {field_object_name, 6, .inherited = true},
    {field_object_name, 8, .inherited = true},
  [699] =
    {field_field, 0},
    {field_value, 6},
  [701] =
    {field_left, 5, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 5, .inherited = true},
  [704] =
    {field_condition, 2, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 2, .inherited = true},
  [708] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_condition, 4, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_branch, 6},
  [721] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_condition, 4, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 6},
  [737] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_else_branch, 6},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_then_branch, 4},
  [747] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_else_branch, 6},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 4},
  [760] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_else_branch, 6},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_branch, 4},
  [773] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_else_branch, 6},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 4},
  [789] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_then_branch, 4},
  [794] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_branch, 4},
  [802] =
    {field_left, 6, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 6, .inherited = true},
  [805] =
    {field_condition, 2, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
  [812] =
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
  [818] =
    {field_condition, 3, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 3, .inherited = true},
  [825] =
    {field_condition, 3, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 3, .inherited = true},
  [829] =
    {field_left, 3, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 3, .inherited = true},
  [832] =
    {field_condition, 1, .inherited = true},
    {field_condition, 3, .inherited = true},
    {field_else_branch, 7},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_then_branch, 5},
  [842] =
    {field_condition, 1, .inherited = true},
    {field_condition, 3, .inherited = true},
    {field_else_branch, 7},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_then_branch, 5},
  [855] =
    {field_condition, 1, .inherited = true},
    {field_condition, 3, .inherited = true},
    {field_else_branch, 7},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 5},
  [868] =
    {field_condition, 1, .inherited = true},
    {field_condition, 3, .inherited = true},
    {field_else_branch, 7},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_then_branch, 5},
  [884] =
    {field_condition, 2},
    {field_else_branch, 7},
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_then_branch, 4},
  [890] =
    {field_condition, 2},
    {field_else_branch, 7},
    {field_left, 2, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_then_branch, 4},
  [899] =
    {field_condition, 0, .inherited = true},
    {field_condition, 1, .inherited = true},
    {field_left, 0, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_then_branch, 0, .inherited = true},
    {field_then_branch, 1, .inherited = true},
  [909] =
    {field_condition, 2},
    {field_else_branch, 7},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_branch, 4},
  [918] =
    {field_condition, 2},
    {field_else_branch, 7},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_then_branch, 4},
  [930] =
    {field_body, 4},
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_pattern, 2},
    {field_right, 2, .inherited = true},
  [935] =
    {field_body, 4},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_pattern, 2},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
  [943] =
    {field_body, 4},
    {field_condition, 4, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_pattern, 2},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_branch, 4, .inherited = true},
  [953] =
    {field_body, 7},
    {field_direction, 4},
    {field_end, 5},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_start, 3},
    {field_variable, 1},
  [964] =
    {field_body, 7},
    {field_direction, 4},
    {field_end, 5},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_start, 3},
    {field_variable, 1},
  [978] =
    {field_al_name, 4},
    {field_dotnet_type, 2},
  [980] =
    {field_condition, 2, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 7, .inherited = true},
  [987] =
    {field_left, 2, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 7, .inherited = true},
  [993] =
    {field_condition, 3, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
  [1003] =
    {field_left, 7, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 7, .inherited = true},
  [1006] =
    {field_condition, 3, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
  [1013] =
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
  [1019] =
    {field_condition, 4, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 4, .inherited = true},
  [1026] =
    {field_attribute_type, 0},
    {field_name, 2},
  [1028] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_condition, 4, .inherited = true},
    {field_else_branch, 8},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_branch, 6},
  [1042] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_condition, 4, .inherited = true},
    {field_else_branch, 8},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 6},
  [1059] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_condition, 4, .inherited = true},
    {field_else_branch, 8},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 6},
  [1076] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_condition, 4, .inherited = true},
    {field_else_branch, 8},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 6},
  [1096] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_else_branch, 8},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
  [1107] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_else_branch, 8},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
  [1121] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_else_branch, 8},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
  [1135] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_else_branch, 8},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
  [1152] =
    {field_body, 5},
    {field_left, 3, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_pattern, 3},
    {field_right, 3, .inherited = true},
  [1157] =
    {field_body, 5},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 3},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
  [1165] =
    {field_body, 5},
    {field_condition, 5, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 3},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 5, .inherited = true},
  [1175] =
    {field_body, 5},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_pattern, 3},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
  [1183] =
    {field_body, 5},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 3},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
  [1194] =
    {field_body, 5},
    {field_condition, 5, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 3},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 5, .inherited = true},
  [1207] =
    {field_field, 0},
    {field_value, 8},
  [1209] =
    {field_condition, 3, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 8, .inherited = true},
  [1219] =
    {field_condition, 3, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 8, .inherited = true},
  [1226] =
    {field_left, 3, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 8, .inherited = true},
  [1232] =
    {field_condition, 4, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 8, .inherited = true},
  [1242] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 7, .inherited = true},
  [1249] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
  [1256] =
    {field_body, 6},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_pattern, 4},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
  [1264] =
    {field_body, 6},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 4},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
  [1275] =
    {field_body, 6},
    {field_condition, 6, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 4},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 6, .inherited = true},
  [1288] =
    {field_body, 6},
    {field_left, 1, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_pattern, 4},
    {field_right, 1, .inherited = true},
    {field_right, 4, .inherited = true},
  [1296] =
    {field_body, 6},
    {field_left, 1, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 4},
    {field_right, 1, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
  [1307] =
    {field_body, 6},
    {field_condition, 6, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 4},
    {field_right, 1, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 6, .inherited = true},
  [1320] =
    {field_body, 6},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_pattern, 4},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
  [1331] =
    {field_body, 6},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 4},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
  [1345] =
    {field_body, 6},
    {field_condition, 6, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 4},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 6, .inherited = true},
  [1361] =
    {field_condition, 4, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 9, .inherited = true},
  [1371] =
    {field_attribute_type, 0},
    {field_left, 4, .inherited = true},
    {field_name, 2},
    {field_operator, 4, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_source, 4},
  [1377] =
    {field_left, 4, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 8, .inherited = true},
  [1383] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
  [1393] =
    {field_condition, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 8, .inherited = true},
  [1403] =
    {field_condition, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
  [1413] =
    {field_body, 7},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
  [1424] =
    {field_body, 7},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 7, .inherited = true},
  [1438] =
    {field_body, 7},
    {field_condition, 7, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_then_branch, 7, .inherited = true},
  [1454] =
    {field_body, 7},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
  [1465] =
    {field_body, 7},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 7, .inherited = true},
  [1479] =
    {field_body, 7},
    {field_condition, 7, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_then_branch, 7, .inherited = true},
  [1495] =
    {field_condition, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_right, 9, .inherited = true},
  [1508] =
    {field_body, 8},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 6},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
  [1522] =
    {field_body, 8},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_pattern, 6},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
  [1539] =
    {field_body, 8},
    {field_condition, 8, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_pattern, 6},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 8, .inherited = true},
  [1558] =
    {field_field_name, 4},
    {field_name, 2},
  [1560] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_left, 10, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 10, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 10, .inherited = true},
  [1567] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_right, 11, .inherited = true},
  [1577] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 11, .inherited = true},
  [1587] =
    {field_condition, 2},
    {field_condition, 8},
    {field_else_branch, 13},
    {field_left, 2, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 10},
  [1598] =
    {field_condition, 2},
    {field_condition, 8},
    {field_else_branch, 13},
    {field_left, 2, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 13, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 13, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 13, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 10},
  [1612] =
    {field_condition, 2},
    {field_condition, 8},
    {field_else_branch, 13},
    {field_left, 2, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 10, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 10, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 10, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 10},
  [1626] =
    {field_condition, 2},
    {field_condition, 8},
    {field_else_branch, 13},
    {field_left, 2, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 10, .inherited = true},
    {field_left, 13, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 10, .inherited = true},
    {field_operator, 13, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 10, .inherited = true},
    {field_right, 13, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 10},
  [1643] =
    {field_condition, 2},
    {field_condition, 8},
    {field_else_branch, 13},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 10},
  [1657] =
    {field_condition, 2},
    {field_condition, 8},
    {field_else_branch, 13},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 13, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 13, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 13, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 10},
  [1674] =
    {field_condition, 2},
    {field_condition, 8},
    {field_else_branch, 13},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 10, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 10, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 10, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 10},
  [1691] =
    {field_condition, 2},
    {field_condition, 8},
    {field_else_branch, 13},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 10, .inherited = true},
    {field_left, 13, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 10, .inherited = true},
    {field_operator, 13, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 10, .inherited = true},
    {field_right, 13, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 10},
  [1711] =
    {field_condition, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 11, .inherited = true},
  [1721] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 12, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 12, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 12, .inherited = true},
  [1734] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_condition, 9},
    {field_else_branch, 14},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
    {field_then_branch, 11},
  [1750] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_condition, 9},
    {field_else_branch, 14},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 14, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 14, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 14, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
    {field_then_branch, 11},
  [1769] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_condition, 9},
    {field_else_branch, 14},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 11, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
    {field_then_branch, 11},
  [1788] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_condition, 9},
    {field_else_branch, 14},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_left, 14, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_operator, 14, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 11, .inherited = true},
    {field_right, 14, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
    {field_then_branch, 11},
  [1810] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_condition, 9},
    {field_else_branch, 14},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
    {field_then_branch, 11},
  [1829] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_condition, 9},
    {field_else_branch, 14},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 14, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 14, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 14, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
    {field_then_branch, 11},
  [1851] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_condition, 9},
    {field_else_branch, 14},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 11, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
    {field_then_branch, 11},
  [1873] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_condition, 9},
    {field_else_branch, 14},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_left, 14, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_operator, 14, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 11, .inherited = true},
    {field_right, 14, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
    {field_then_branch, 11},
  [1898] =
    {field_condition, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 12, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 12, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 12, .inherited = true},
  [1911] =
    {field_condition, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_left, 12, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_operator, 12, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_right, 12, .inherited = true},
  [1924] =
    {field_condition, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 13, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 13, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 13, .inherited = true},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [30] = {
    [0] = alias_sym_object_type_keyword,
  },
  [53] = {
    [0] = alias_sym_aggregate_function,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_codeunit_keyword, 2,
    sym_codeunit_keyword,
    alias_sym_object_type_keyword,
  sym_xmlport_keyword, 2,
    sym_xmlport_keyword,
    alias_sym_object_type_keyword,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 2,
  [11] = 3,
  [12] = 4,
  [13] = 3,
  [14] = 4,
  [15] = 3,
  [16] = 4,
  [17] = 3,
  [18] = 4,
  [19] = 3,
  [20] = 4,
  [21] = 21,
  [22] = 5,
  [23] = 6,
  [24] = 7,
  [25] = 8,
  [26] = 21,
  [27] = 21,
  [28] = 5,
  [29] = 6,
  [30] = 7,
  [31] = 8,
  [32] = 9,
  [33] = 2,
  [34] = 5,
  [35] = 6,
  [36] = 7,
  [37] = 8,
  [38] = 9,
  [39] = 2,
  [40] = 21,
  [41] = 21,
  [42] = 21,
  [43] = 21,
  [44] = 21,
  [45] = 21,
  [46] = 21,
  [47] = 21,
  [48] = 21,
  [49] = 21,
  [50] = 21,
  [51] = 21,
  [52] = 21,
  [53] = 21,
  [54] = 21,
  [55] = 21,
  [56] = 9,
  [57] = 57,
  [58] = 57,
  [59] = 57,
  [60] = 57,
  [61] = 57,
  [62] = 57,
  [63] = 63,
  [64] = 63,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 66,
  [69] = 66,
  [70] = 67,
  [71] = 65,
  [72] = 65,
  [73] = 63,
  [74] = 67,
  [75] = 63,
  [76] = 67,
  [77] = 66,
  [78] = 65,
  [79] = 79,
  [80] = 79,
  [81] = 79,
  [82] = 79,
  [83] = 83,
  [84] = 83,
  [85] = 83,
  [86] = 83,
  [87] = 87,
  [88] = 83,
  [89] = 83,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 90,
  [98] = 91,
  [99] = 92,
  [100] = 96,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 105,
  [111] = 101,
  [112] = 102,
  [113] = 103,
  [114] = 104,
  [115] = 106,
  [116] = 102,
  [117] = 103,
  [118] = 118,
  [119] = 104,
  [120] = 120,
  [121] = 121,
  [122] = 106,
  [123] = 123,
  [124] = 108,
  [125] = 101,
  [126] = 105,
  [127] = 101,
  [128] = 102,
  [129] = 103,
  [130] = 104,
  [131] = 108,
  [132] = 109,
  [133] = 123,
  [134] = 120,
  [135] = 121,
  [136] = 107,
  [137] = 123,
  [138] = 120,
  [139] = 121,
  [140] = 107,
  [141] = 123,
  [142] = 120,
  [143] = 121,
  [144] = 107,
  [145] = 123,
  [146] = 120,
  [147] = 121,
  [148] = 107,
  [149] = 105,
  [150] = 106,
  [151] = 108,
  [152] = 109,
  [153] = 109,
  [154] = 154,
  [155] = 155,
  [156] = 87,
  [157] = 155,
  [158] = 155,
  [159] = 154,
  [160] = 155,
  [161] = 155,
  [162] = 154,
  [163] = 154,
  [164] = 154,
  [165] = 155,
  [166] = 154,
  [167] = 167,
  [168] = 168,
  [169] = 169,
  [170] = 170,
  [171] = 171,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 172,
  [176] = 171,
  [177] = 171,
  [178] = 172,
  [179] = 172,
  [180] = 180,
  [181] = 171,
  [182] = 172,
  [183] = 171,
  [184] = 172,
  [185] = 171,
  [186] = 172,
  [187] = 171,
  [188] = 172,
  [189] = 171,
  [190] = 172,
  [191] = 171,
  [192] = 172,
  [193] = 173,
  [194] = 171,
  [195] = 172,
  [196] = 171,
  [197] = 172,
  [198] = 180,
  [199] = 199,
  [200] = 200,
  [201] = 171,
  [202] = 172,
  [203] = 171,
  [204] = 204,
  [205] = 171,
  [206] = 172,
  [207] = 171,
  [208] = 172,
  [209] = 171,
  [210] = 210,
  [211] = 171,
  [212] = 212,
  [213] = 213,
  [214] = 168,
  [215] = 215,
  [216] = 216,
  [217] = 204,
  [218] = 204,
  [219] = 204,
  [220] = 210,
  [221] = 216,
  [222] = 169,
  [223] = 170,
  [224] = 174,
  [225] = 212,
  [226] = 213,
  [227] = 171,
  [228] = 215,
  [229] = 171,
  [230] = 172,
  [231] = 199,
  [232] = 172,
  [233] = 200,
  [234] = 172,
  [235] = 90,
  [236] = 172,
  [237] = 237,
  [238] = 238,
  [239] = 239,
  [240] = 240,
  [241] = 241,
  [242] = 242,
  [243] = 243,
  [244] = 244,
  [245] = 245,
  [246] = 237,
  [247] = 247,
  [248] = 248,
  [249] = 91,
  [250] = 250,
  [251] = 251,
  [252] = 252,
  [253] = 253,
  [254] = 254,
  [255] = 255,
  [256] = 256,
  [257] = 257,
  [258] = 258,
  [259] = 259,
  [260] = 260,
  [261] = 261,
  [262] = 262,
  [263] = 263,
  [264] = 264,
  [265] = 265,
  [266] = 266,
  [267] = 267,
  [268] = 268,
  [269] = 269,
  [270] = 270,
  [271] = 271,
  [272] = 238,
  [273] = 239,
  [274] = 240,
  [275] = 241,
  [276] = 242,
  [277] = 243,
  [278] = 244,
  [279] = 245,
  [280] = 237,
  [281] = 247,
  [282] = 248,
  [283] = 250,
  [284] = 251,
  [285] = 252,
  [286] = 253,
  [287] = 254,
  [288] = 255,
  [289] = 256,
  [290] = 257,
  [291] = 258,
  [292] = 259,
  [293] = 260,
  [294] = 261,
  [295] = 262,
  [296] = 263,
  [297] = 264,
  [298] = 265,
  [299] = 266,
  [300] = 267,
  [301] = 268,
  [302] = 269,
  [303] = 270,
  [304] = 271,
  [305] = 238,
  [306] = 239,
  [307] = 240,
  [308] = 241,
  [309] = 242,
  [310] = 243,
  [311] = 244,
  [312] = 245,
  [313] = 237,
  [314] = 247,
  [315] = 248,
  [316] = 250,
  [317] = 251,
  [318] = 252,
  [319] = 253,
  [320] = 254,
  [321] = 255,
  [322] = 256,
  [323] = 257,
  [324] = 258,
  [325] = 259,
  [326] = 260,
  [327] = 261,
  [328] = 262,
  [329] = 263,
  [330] = 264,
  [331] = 265,
  [332] = 266,
  [333] = 267,
  [334] = 268,
  [335] = 269,
  [336] = 270,
  [337] = 271,
  [338] = 240,
  [339] = 247,
  [340] = 248,
  [341] = 92,
  [342] = 238,
  [343] = 239,
  [344] = 240,
  [345] = 241,
  [346] = 242,
  [347] = 347,
  [348] = 243,
  [349] = 349,
  [350] = 350,
  [351] = 351,
  [352] = 352,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 357,
  [358] = 358,
  [359] = 359,
  [360] = 360,
  [361] = 361,
  [362] = 362,
  [363] = 363,
  [364] = 364,
  [365] = 365,
  [366] = 366,
  [367] = 367,
  [368] = 368,
  [369] = 369,
  [370] = 370,
  [371] = 371,
  [372] = 372,
  [373] = 373,
  [374] = 374,
  [375] = 375,
  [376] = 376,
  [377] = 377,
  [378] = 347,
  [379] = 379,
  [380] = 238,
  [381] = 239,
  [382] = 240,
  [383] = 241,
  [384] = 242,
  [385] = 243,
  [386] = 244,
  [387] = 245,
  [388] = 237,
  [389] = 247,
  [390] = 248,
  [391] = 250,
  [392] = 251,
  [393] = 252,
  [394] = 253,
  [395] = 254,
  [396] = 255,
  [397] = 256,
  [398] = 257,
  [399] = 258,
  [400] = 259,
  [401] = 260,
  [402] = 261,
  [403] = 262,
  [404] = 263,
  [405] = 264,
  [406] = 265,
  [407] = 266,
  [408] = 267,
  [409] = 268,
  [410] = 269,
  [411] = 270,
  [412] = 271,
  [413] = 238,
  [414] = 239,
  [415] = 241,
  [416] = 242,
  [417] = 243,
  [418] = 244,
  [419] = 245,
  [420] = 237,
  [421] = 250,
  [422] = 251,
  [423] = 252,
  [424] = 253,
  [425] = 254,
  [426] = 255,
  [427] = 256,
  [428] = 257,
  [429] = 258,
  [430] = 259,
  [431] = 260,
  [432] = 261,
  [433] = 262,
  [434] = 263,
  [435] = 264,
  [436] = 265,
  [437] = 266,
  [438] = 267,
  [439] = 268,
  [440] = 269,
  [441] = 270,
  [442] = 271,
  [443] = 244,
  [444] = 245,
  [445] = 271,
  [446] = 248,
  [447] = 250,
  [448] = 349,
  [449] = 347,
  [450] = 350,
  [451] = 349,
  [452] = 350,
  [453] = 351,
  [454] = 352,
  [455] = 351,
  [456] = 352,
  [457] = 353,
  [458] = 354,
  [459] = 355,
  [460] = 356,
  [461] = 357,
  [462] = 358,
  [463] = 359,
  [464] = 360,
  [465] = 361,
  [466] = 362,
  [467] = 363,
  [468] = 364,
  [469] = 365,
  [470] = 366,
  [471] = 367,
  [472] = 368,
  [473] = 369,
  [474] = 370,
  [475] = 371,
  [476] = 373,
  [477] = 374,
  [478] = 375,
  [479] = 376,
  [480] = 377,
  [481] = 379,
  [482] = 251,
  [483] = 252,
  [484] = 253,
  [485] = 347,
  [486] = 349,
  [487] = 350,
  [488] = 351,
  [489] = 352,
  [490] = 353,
  [491] = 354,
  [492] = 355,
  [493] = 356,
  [494] = 357,
  [495] = 358,
  [496] = 359,
  [497] = 360,
  [498] = 361,
  [499] = 362,
  [500] = 363,
  [501] = 364,
  [502] = 365,
  [503] = 366,
  [504] = 367,
  [505] = 368,
  [506] = 369,
  [507] = 370,
  [508] = 371,
  [509] = 373,
  [510] = 374,
  [511] = 375,
  [512] = 376,
  [513] = 377,
  [514] = 379,
  [515] = 353,
  [516] = 354,
  [517] = 347,
  [518] = 349,
  [519] = 350,
  [520] = 351,
  [521] = 352,
  [522] = 355,
  [523] = 356,
  [524] = 353,
  [525] = 354,
  [526] = 355,
  [527] = 356,
  [528] = 357,
  [529] = 358,
  [530] = 359,
  [531] = 360,
  [532] = 361,
  [533] = 362,
  [534] = 363,
  [535] = 364,
  [536] = 365,
  [537] = 366,
  [538] = 367,
  [539] = 368,
  [540] = 369,
  [541] = 370,
  [542] = 371,
  [543] = 373,
  [544] = 374,
  [545] = 375,
  [546] = 376,
  [547] = 377,
  [548] = 379,
  [549] = 357,
  [550] = 358,
  [551] = 359,
  [552] = 360,
  [553] = 361,
  [554] = 254,
  [555] = 255,
  [556] = 256,
  [557] = 257,
  [558] = 258,
  [559] = 259,
  [560] = 362,
  [561] = 363,
  [562] = 364,
  [563] = 365,
  [564] = 366,
  [565] = 367,
  [566] = 368,
  [567] = 369,
  [568] = 370,
  [569] = 371,
  [570] = 260,
  [571] = 261,
  [572] = 262,
  [573] = 263,
  [574] = 372,
  [575] = 373,
  [576] = 374,
  [577] = 375,
  [578] = 376,
  [579] = 377,
  [580] = 379,
  [581] = 581,
  [582] = 582,
  [583] = 583,
  [584] = 582,
  [585] = 583,
  [586] = 586,
  [587] = 587,
  [588] = 582,
  [589] = 583,
  [590] = 586,
  [591] = 587,
  [592] = 582,
  [593] = 583,
  [594] = 586,
  [595] = 587,
  [596] = 582,
  [597] = 583,
  [598] = 586,
  [599] = 587,
  [600] = 582,
  [601] = 583,
  [602] = 586,
  [603] = 587,
  [604] = 586,
  [605] = 587,
  [606] = 264,
  [607] = 265,
  [608] = 266,
  [609] = 267,
  [610] = 268,
  [611] = 269,
  [612] = 270,
  [613] = 247,
  [614] = 614,
  [615] = 615,
  [616] = 616,
  [617] = 614,
  [618] = 618,
  [619] = 619,
  [620] = 616,
  [621] = 94,
  [622] = 622,
  [623] = 96,
  [624] = 624,
  [625] = 625,
  [626] = 626,
  [627] = 627,
  [628] = 628,
  [629] = 622,
  [630] = 624,
  [631] = 625,
  [632] = 626,
  [633] = 633,
  [634] = 627,
  [635] = 628,
  [636] = 633,
  [637] = 637,
  [638] = 638,
  [639] = 639,
  [640] = 640,
  [641] = 641,
  [642] = 642,
  [643] = 643,
  [644] = 644,
  [645] = 645,
  [646] = 646,
  [647] = 647,
  [648] = 648,
  [649] = 649,
  [650] = 650,
  [651] = 651,
  [652] = 652,
  [653] = 615,
  [654] = 622,
  [655] = 624,
  [656] = 625,
  [657] = 626,
  [658] = 627,
  [659] = 628,
  [660] = 633,
  [661] = 637,
  [662] = 662,
  [663] = 637,
  [664] = 638,
  [665] = 639,
  [666] = 640,
  [667] = 641,
  [668] = 642,
  [669] = 643,
  [670] = 644,
  [671] = 645,
  [672] = 646,
  [673] = 647,
  [674] = 648,
  [675] = 649,
  [676] = 650,
  [677] = 651,
  [678] = 652,
  [679] = 615,
  [680] = 624,
  [681] = 625,
  [682] = 626,
  [683] = 627,
  [684] = 628,
  [685] = 633,
  [686] = 637,
  [687] = 638,
  [688] = 638,
  [689] = 639,
  [690] = 640,
  [691] = 641,
  [692] = 642,
  [693] = 643,
  [694] = 644,
  [695] = 645,
  [696] = 646,
  [697] = 647,
  [698] = 648,
  [699] = 649,
  [700] = 650,
  [701] = 651,
  [702] = 652,
  [703] = 615,
  [704] = 622,
  [705] = 624,
  [706] = 625,
  [707] = 626,
  [708] = 627,
  [709] = 628,
  [710] = 633,
  [711] = 637,
  [712] = 622,
  [713] = 624,
  [714] = 625,
  [715] = 626,
  [716] = 627,
  [717] = 628,
  [718] = 633,
  [719] = 637,
  [720] = 622,
  [721] = 624,
  [722] = 625,
  [723] = 626,
  [724] = 627,
  [725] = 628,
  [726] = 633,
  [727] = 637,
  [728] = 622,
  [729] = 624,
  [730] = 625,
  [731] = 626,
  [732] = 627,
  [733] = 628,
  [734] = 633,
  [735] = 637,
  [736] = 622,
  [737] = 624,
  [738] = 625,
  [739] = 626,
  [740] = 627,
  [741] = 628,
  [742] = 633,
  [743] = 637,
  [744] = 622,
  [745] = 624,
  [746] = 625,
  [747] = 626,
  [748] = 627,
  [749] = 628,
  [750] = 633,
  [751] = 637,
  [752] = 622,
  [753] = 624,
  [754] = 625,
  [755] = 626,
  [756] = 627,
  [757] = 628,
  [758] = 633,
  [759] = 637,
  [760] = 622,
  [761] = 624,
  [762] = 625,
  [763] = 626,
  [764] = 627,
  [765] = 628,
  [766] = 633,
  [767] = 637,
  [768] = 622,
  [769] = 624,
  [770] = 625,
  [771] = 626,
  [772] = 627,
  [773] = 628,
  [774] = 633,
  [775] = 637,
  [776] = 622,
  [777] = 624,
  [778] = 625,
  [779] = 626,
  [780] = 627,
  [781] = 628,
  [782] = 633,
  [783] = 637,
  [784] = 622,
  [785] = 624,
  [786] = 625,
  [787] = 626,
  [788] = 627,
  [789] = 628,
  [790] = 633,
  [791] = 637,
  [792] = 622,
  [793] = 624,
  [794] = 625,
  [795] = 626,
  [796] = 627,
  [797] = 628,
  [798] = 633,
  [799] = 637,
  [800] = 622,
  [801] = 624,
  [802] = 625,
  [803] = 626,
  [804] = 627,
  [805] = 628,
  [806] = 633,
  [807] = 637,
  [808] = 622,
  [809] = 624,
  [810] = 625,
  [811] = 626,
  [812] = 627,
  [813] = 628,
  [814] = 633,
  [815] = 637,
  [816] = 622,
  [817] = 624,
  [818] = 625,
  [819] = 626,
  [820] = 627,
  [821] = 628,
  [822] = 633,
  [823] = 637,
  [824] = 639,
  [825] = 640,
  [826] = 641,
  [827] = 642,
  [828] = 643,
  [829] = 644,
  [830] = 645,
  [831] = 646,
  [832] = 647,
  [833] = 648,
  [834] = 649,
  [835] = 650,
  [836] = 662,
  [837] = 614,
  [838] = 618,
  [839] = 619,
  [840] = 651,
  [841] = 662,
  [842] = 614,
  [843] = 618,
  [844] = 619,
  [845] = 652,
  [846] = 662,
  [847] = 614,
  [848] = 618,
  [849] = 619,
  [850] = 662,
  [851] = 614,
  [852] = 618,
  [853] = 619,
  [854] = 662,
  [855] = 614,
  [856] = 618,
  [857] = 619,
  [858] = 662,
  [859] = 614,
  [860] = 618,
  [861] = 619,
  [862] = 662,
  [863] = 618,
  [864] = 619,
  [865] = 662,
  [866] = 614,
  [867] = 618,
  [868] = 619,
  [869] = 662,
  [870] = 614,
  [871] = 618,
  [872] = 619,
  [873] = 662,
  [874] = 614,
  [875] = 618,
  [876] = 619,
  [877] = 662,
  [878] = 614,
  [879] = 618,
  [880] = 619,
  [881] = 662,
  [882] = 614,
  [883] = 618,
  [884] = 619,
  [885] = 662,
  [886] = 614,
  [887] = 618,
  [888] = 619,
  [889] = 662,
  [890] = 614,
  [891] = 618,
  [892] = 619,
  [893] = 662,
  [894] = 614,
  [895] = 618,
  [896] = 619,
  [897] = 662,
  [898] = 614,
  [899] = 618,
  [900] = 619,
  [901] = 662,
  [902] = 614,
  [903] = 618,
  [904] = 619,
  [905] = 662,
  [906] = 614,
  [907] = 618,
  [908] = 619,
  [909] = 622,
  [910] = 910,
  [911] = 911,
  [912] = 912,
  [913] = 910,
  [914] = 914,
  [915] = 915,
  [916] = 916,
  [917] = 167,
  [918] = 911,
  [919] = 912,
  [920] = 915,
  [921] = 916,
  [922] = 911,
  [923] = 912,
  [924] = 910,
  [925] = 914,
  [926] = 915,
  [927] = 916,
  [928] = 911,
  [929] = 912,
  [930] = 910,
  [931] = 914,
  [932] = 915,
  [933] = 916,
  [934] = 914,
  [935] = 935,
  [936] = 936,
  [937] = 937,
  [938] = 937,
  [939] = 936,
  [940] = 935,
  [941] = 941,
  [942] = 941,
  [943] = 941,
  [944] = 941,
  [945] = 941,
  [946] = 941,
  [947] = 941,
  [948] = 948,
  [949] = 941,
  [950] = 167,
  [951] = 951,
  [952] = 952,
  [953] = 953,
  [954] = 954,
  [955] = 955,
  [956] = 956,
  [957] = 957,
  [958] = 958,
  [959] = 959,
  [960] = 960,
  [961] = 961,
  [962] = 962,
  [963] = 963,
  [964] = 964,
  [965] = 965,
  [966] = 966,
  [967] = 967,
  [968] = 968,
  [969] = 969,
  [970] = 970,
  [971] = 971,
  [972] = 972,
  [973] = 973,
  [974] = 974,
  [975] = 975,
  [976] = 976,
  [977] = 977,
  [978] = 978,
  [979] = 979,
  [980] = 980,
  [981] = 981,
  [982] = 982,
  [983] = 983,
  [984] = 984,
  [985] = 985,
  [986] = 986,
  [987] = 987,
  [988] = 988,
  [989] = 989,
  [990] = 990,
  [991] = 991,
  [992] = 992,
  [993] = 993,
  [994] = 994,
  [995] = 995,
  [996] = 996,
  [997] = 997,
  [998] = 998,
  [999] = 999,
  [1000] = 1000,
  [1001] = 1001,
  [1002] = 1002,
  [1003] = 1003,
  [1004] = 1004,
  [1005] = 1005,
  [1006] = 1006,
  [1007] = 1007,
  [1008] = 1008,
  [1009] = 1009,
  [1010] = 1010,
  [1011] = 1011,
  [1012] = 1012,
  [1013] = 1013,
  [1014] = 1014,
  [1015] = 1015,
  [1016] = 1016,
  [1017] = 1017,
  [1018] = 1018,
  [1019] = 1019,
  [1020] = 1020,
  [1021] = 1021,
  [1022] = 1022,
  [1023] = 1023,
  [1024] = 1024,
  [1025] = 1025,
  [1026] = 1026,
  [1027] = 1027,
  [1028] = 1028,
  [1029] = 1029,
  [1030] = 1030,
  [1031] = 1031,
  [1032] = 1032,
  [1033] = 1033,
  [1034] = 1034,
  [1035] = 1035,
  [1036] = 1036,
  [1037] = 1037,
  [1038] = 1038,
  [1039] = 1039,
  [1040] = 1040,
  [1041] = 1041,
  [1042] = 951,
  [1043] = 1043,
  [1044] = 1044,
  [1045] = 1043,
  [1046] = 1041,
  [1047] = 1047,
  [1048] = 1047,
  [1049] = 1044,
  [1050] = 991,
  [1051] = 962,
  [1052] = 963,
  [1053] = 964,
  [1054] = 965,
  [1055] = 966,
  [1056] = 967,
  [1057] = 968,
  [1058] = 969,
  [1059] = 970,
  [1060] = 971,
  [1061] = 997,
  [1062] = 973,
  [1063] = 974,
  [1064] = 975,
  [1065] = 976,
  [1066] = 952,
  [1067] = 977,
  [1068] = 978,
  [1069] = 961,
  [1070] = 959,
  [1071] = 987,
  [1072] = 960,
  [1073] = 981,
  [1074] = 982,
  [1075] = 983,
  [1076] = 995,
  [1077] = 985,
  [1078] = 979,
  [1079] = 988,
  [1080] = 989,
  [1081] = 990,
  [1082] = 986,
  [1083] = 957,
  [1084] = 992,
  [1085] = 993,
  [1086] = 984,
  [1087] = 972,
  [1088] = 953,
  [1089] = 954,
  [1090] = 956,
  [1091] = 980,
  [1092] = 1005,
  [1093] = 1093,
  [1094] = 1094,
  [1095] = 1095,
  [1096] = 1096,
  [1097] = 1097,
  [1098] = 1098,
  [1099] = 1001,
  [1100] = 1007,
  [1101] = 1009,
  [1102] = 1002,
  [1103] = 1098,
  [1104] = 1003,
  [1105] = 1096,
  [1106] = 1011,
  [1107] = 1008,
  [1108] = 1094,
  [1109] = 1010,
  [1110] = 1110,
  [1111] = 1014,
  [1112] = 998,
  [1113] = 999,
  [1114] = 1006,
  [1115] = 1115,
  [1116] = 1013,
  [1117] = 1117,
  [1118] = 1000,
  [1119] = 1004,
  [1120] = 1093,
  [1121] = 1115,
  [1122] = 1095,
  [1123] = 1110,
  [1124] = 1097,
  [1125] = 1117,
  [1126] = 1012,
  [1127] = 1015,
  [1128] = 1019,
  [1129] = 1025,
  [1130] = 1021,
  [1131] = 1029,
  [1132] = 1034,
  [1133] = 1026,
  [1134] = 1022,
  [1135] = 1024,
  [1136] = 1027,
  [1137] = 1028,
  [1138] = 1040,
  [1139] = 1030,
  [1140] = 1023,
  [1141] = 1031,
  [1142] = 1032,
  [1143] = 1033,
  [1144] = 1035,
  [1145] = 1037,
  [1146] = 1036,
  [1147] = 1038,
  [1148] = 1020,
  [1149] = 1016,
  [1150] = 1017,
  [1151] = 1039,
  [1152] = 1018,
  [1153] = 951,
  [1154] = 962,
  [1155] = 1155,
  [1156] = 978,
  [1157] = 991,
  [1158] = 982,
  [1159] = 1159,
  [1160] = 987,
  [1161] = 979,
  [1162] = 995,
  [1163] = 986,
  [1164] = 1164,
  [1165] = 980,
  [1166] = 983,
  [1167] = 992,
  [1168] = 985,
  [1169] = 993,
  [1170] = 996,
  [1171] = 969,
  [1172] = 970,
  [1173] = 953,
  [1174] = 954,
  [1175] = 956,
  [1176] = 959,
  [1177] = 971,
  [1178] = 963,
  [1179] = 1179,
  [1180] = 964,
  [1181] = 965,
  [1182] = 966,
  [1183] = 967,
  [1184] = 968,
  [1185] = 997,
  [1186] = 973,
  [1187] = 984,
  [1188] = 961,
  [1189] = 974,
  [1190] = 981,
  [1191] = 975,
  [1192] = 976,
  [1193] = 957,
  [1194] = 952,
  [1195] = 977,
  [1196] = 960,
  [1197] = 988,
  [1198] = 989,
  [1199] = 990,
  [1200] = 972,
  [1201] = 1013,
  [1202] = 1003,
  [1203] = 1004,
  [1204] = 998,
  [1205] = 1012,
  [1206] = 999,
  [1207] = 1010,
  [1208] = 1011,
  [1209] = 1000,
  [1210] = 1006,
  [1211] = 1009,
  [1212] = 1005,
  [1213] = 1014,
  [1214] = 1001,
  [1215] = 1002,
  [1216] = 1007,
  [1217] = 1008,
  [1218] = 1037,
  [1219] = 1025,
  [1220] = 1034,
  [1221] = 1022,
  [1222] = 1024,
  [1223] = 1027,
  [1224] = 1038,
  [1225] = 1021,
  [1226] = 1029,
  [1227] = 1026,
  [1228] = 1019,
  [1229] = 1028,
  [1230] = 1023,
  [1231] = 1036,
  [1232] = 1020,
  [1233] = 1039,
  [1234] = 1040,
  [1235] = 1031,
  [1236] = 1032,
  [1237] = 1033,
  [1238] = 1035,
  [1239] = 1016,
  [1240] = 1017,
  [1241] = 1018,
  [1242] = 1015,
  [1243] = 1030,
  [1244] = 1244,
  [1245] = 1245,
  [1246] = 90,
  [1247] = 1155,
  [1248] = 92,
  [1249] = 1249,
  [1250] = 1249,
  [1251] = 96,
  [1252] = 1252,
  [1253] = 1253,
  [1254] = 1252,
  [1255] = 1255,
  [1256] = 1256,
  [1257] = 1257,
  [1258] = 1258,
  [1259] = 1256,
  [1260] = 1260,
  [1261] = 1255,
  [1262] = 1256,
  [1263] = 1253,
  [1264] = 1252,
  [1265] = 1253,
  [1266] = 1253,
  [1267] = 1267,
  [1268] = 1252,
  [1269] = 1252,
  [1270] = 1270,
  [1271] = 1271,
  [1272] = 1253,
  [1273] = 1273,
  [1274] = 1273,
  [1275] = 1270,
  [1276] = 1258,
  [1277] = 1255,
  [1278] = 1270,
  [1279] = 1255,
  [1280] = 1256,
  [1281] = 1273,
  [1282] = 1253,
  [1283] = 1270,
  [1284] = 1252,
  [1285] = 1258,
  [1286] = 1271,
  [1287] = 1270,
  [1288] = 1270,
  [1289] = 1270,
  [1290] = 1270,
  [1291] = 1270,
  [1292] = 1270,
  [1293] = 1270,
  [1294] = 1270,
  [1295] = 1295,
  [1296] = 1260,
  [1297] = 1273,
  [1298] = 1295,
  [1299] = 1273,
  [1300] = 1252,
  [1301] = 1301,
  [1302] = 1295,
  [1303] = 1258,
  [1304] = 1256,
  [1305] = 1253,
  [1306] = 1258,
  [1307] = 1252,
  [1308] = 1273,
  [1309] = 1255,
  [1310] = 1256,
  [1311] = 1295,
  [1312] = 1271,
  [1313] = 1295,
  [1314] = 1271,
  [1315] = 1253,
  [1316] = 1273,
  [1317] = 1253,
  [1318] = 1260,
  [1319] = 1271,
  [1320] = 1273,
  [1321] = 1258,
  [1322] = 1255,
  [1323] = 1256,
  [1324] = 1270,
  [1325] = 1253,
  [1326] = 1252,
  [1327] = 1271,
  [1328] = 1295,
  [1329] = 1258,
  [1330] = 1260,
  [1331] = 1255,
  [1332] = 1252,
  [1333] = 1252,
  [1334] = 1252,
  [1335] = 1273,
  [1336] = 1295,
  [1337] = 1301,
  [1338] = 1273,
  [1339] = 1273,
  [1340] = 1258,
  [1341] = 1273,
  [1342] = 1258,
  [1343] = 1258,
  [1344] = 1258,
  [1345] = 1258,
  [1346] = 1273,
  [1347] = 1273,
  [1348] = 1258,
  [1349] = 1271,
  [1350] = 1255,
  [1351] = 1253,
  [1352] = 1273,
  [1353] = 1353,
  [1354] = 1258,
  [1355] = 1252,
  [1356] = 1260,
  [1357] = 1256,
  [1358] = 1258,
  [1359] = 1253,
  [1360] = 1271,
  [1361] = 1295,
  [1362] = 1271,
  [1363] = 1253,
  [1364] = 1295,
  [1365] = 1155,
  [1366] = 1366,
  [1367] = 1367,
  [1368] = 167,
  [1369] = 90,
  [1370] = 1370,
  [1371] = 1371,
  [1372] = 90,
  [1373] = 92,
  [1374] = 1374,
  [1375] = 1375,
  [1376] = 92,
  [1377] = 1377,
  [1378] = 1378,
  [1379] = 96,
  [1380] = 96,
  [1381] = 1381,
  [1382] = 1382,
  [1383] = 1383,
  [1384] = 1383,
  [1385] = 1385,
  [1386] = 1386,
  [1387] = 1385,
  [1388] = 1388,
  [1389] = 1389,
  [1390] = 1390,
  [1391] = 1391,
  [1392] = 1392,
  [1393] = 1393,
  [1394] = 1393,
  [1395] = 90,
  [1396] = 952,
  [1397] = 92,
  [1398] = 1398,
  [1399] = 992,
  [1400] = 993,
  [1401] = 972,
  [1402] = 953,
  [1403] = 954,
  [1404] = 956,
  [1405] = 959,
  [1406] = 962,
  [1407] = 963,
  [1408] = 964,
  [1409] = 965,
  [1410] = 966,
  [1411] = 967,
  [1412] = 968,
  [1413] = 969,
  [1414] = 970,
  [1415] = 971,
  [1416] = 997,
  [1417] = 973,
  [1418] = 974,
  [1419] = 975,
  [1420] = 976,
  [1421] = 977,
  [1422] = 978,
  [1423] = 957,
  [1424] = 167,
  [1425] = 951,
  [1426] = 995,
  [1427] = 985,
  [1428] = 167,
  [1429] = 1003,
  [1430] = 1430,
  [1431] = 1431,
  [1432] = 1014,
  [1433] = 998,
  [1434] = 1007,
  [1435] = 1008,
  [1436] = 1000,
  [1437] = 988,
  [1438] = 989,
  [1439] = 990,
  [1440] = 991,
  [1441] = 984,
  [1442] = 1010,
  [1443] = 1006,
  [1444] = 1444,
  [1445] = 1013,
  [1446] = 1011,
  [1447] = 960,
  [1448] = 999,
  [1449] = 961,
  [1450] = 986,
  [1451] = 1451,
  [1452] = 987,
  [1453] = 1453,
  [1454] = 1454,
  [1455] = 1455,
  [1456] = 1456,
  [1457] = 1457,
  [1458] = 1458,
  [1459] = 1444,
  [1460] = 1457,
  [1461] = 1451,
  [1462] = 1430,
  [1463] = 1431,
  [1464] = 1454,
  [1465] = 1455,
  [1466] = 1456,
  [1467] = 1467,
  [1468] = 1458,
  [1469] = 1444,
  [1470] = 1457,
  [1471] = 1451,
  [1472] = 1430,
  [1473] = 1431,
  [1474] = 1454,
  [1475] = 1455,
  [1476] = 1456,
  [1477] = 1467,
  [1478] = 1458,
  [1479] = 1444,
  [1480] = 1457,
  [1481] = 1451,
  [1482] = 1430,
  [1483] = 1431,
  [1484] = 1012,
  [1485] = 96,
  [1486] = 1454,
  [1487] = 1455,
  [1488] = 1456,
  [1489] = 1467,
  [1490] = 1458,
  [1491] = 1467,
  [1492] = 1032,
  [1493] = 1025,
  [1494] = 1026,
  [1495] = 981,
  [1496] = 1009,
  [1497] = 982,
  [1498] = 1005,
  [1499] = 983,
  [1500] = 1029,
  [1501] = 1030,
  [1502] = 1019,
  [1503] = 1503,
  [1504] = 1504,
  [1505] = 1028,
  [1506] = 1023,
  [1507] = 1036,
  [1508] = 1020,
  [1509] = 1039,
  [1510] = 1001,
  [1511] = 1002,
  [1512] = 1040,
  [1513] = 1027,
  [1514] = 1004,
  [1515] = 1033,
  [1516] = 1035,
  [1517] = 1037,
  [1518] = 1016,
  [1519] = 1017,
  [1520] = 1018,
  [1521] = 1015,
  [1522] = 1522,
  [1523] = 1034,
  [1524] = 979,
  [1525] = 1022,
  [1526] = 1024,
  [1527] = 980,
  [1528] = 1038,
  [1529] = 1021,
  [1530] = 1031,
  [1531] = 1531,
  [1532] = 1532,
  [1533] = 1533,
  [1534] = 1534,
  [1535] = 1535,
  [1536] = 1536,
  [1537] = 1537,
  [1538] = 1538,
  [1539] = 1539,
  [1540] = 1540,
  [1541] = 1541,
  [1542] = 1542,
  [1543] = 1543,
  [1544] = 1544,
  [1545] = 1545,
  [1546] = 1546,
  [1547] = 1547,
  [1548] = 1548,
  [1549] = 1531,
  [1550] = 1532,
  [1551] = 1551,
  [1552] = 1552,
  [1553] = 1553,
  [1554] = 1554,
  [1555] = 1555,
  [1556] = 1556,
  [1557] = 1557,
  [1558] = 1558,
  [1559] = 1559,
  [1560] = 1560,
  [1561] = 1561,
  [1562] = 1562,
  [1563] = 1563,
  [1564] = 1564,
  [1565] = 1565,
  [1566] = 1566,
  [1567] = 1567,
  [1568] = 1568,
  [1569] = 1569,
  [1570] = 1570,
  [1571] = 1571,
  [1572] = 1572,
  [1573] = 1573,
  [1574] = 1574,
  [1575] = 1575,
  [1576] = 1576,
  [1577] = 1577,
  [1578] = 1578,
  [1579] = 1579,
  [1580] = 1580,
  [1581] = 1581,
  [1582] = 1582,
  [1583] = 1583,
  [1584] = 1584,
  [1585] = 1585,
  [1586] = 1586,
  [1587] = 1587,
  [1588] = 1588,
  [1589] = 1589,
  [1590] = 1590,
  [1591] = 1591,
  [1592] = 1592,
  [1593] = 1593,
  [1594] = 1594,
  [1595] = 1595,
  [1596] = 1596,
  [1597] = 1597,
  [1598] = 1598,
  [1599] = 1599,
  [1600] = 1600,
  [1601] = 1601,
  [1602] = 1602,
  [1603] = 1603,
  [1604] = 1604,
  [1605] = 1605,
  [1606] = 1606,
  [1607] = 1607,
  [1608] = 1608,
  [1609] = 1609,
  [1610] = 1610,
  [1611] = 1611,
  [1612] = 1612,
  [1613] = 1613,
  [1614] = 1614,
  [1615] = 1615,
  [1616] = 1616,
  [1617] = 1617,
  [1618] = 1618,
  [1619] = 1619,
  [1620] = 1620,
  [1621] = 1621,
  [1622] = 1622,
  [1623] = 1623,
  [1624] = 1624,
  [1625] = 1625,
  [1626] = 1626,
  [1627] = 1627,
  [1628] = 1628,
  [1629] = 1629,
  [1630] = 1630,
  [1631] = 1631,
  [1632] = 1632,
  [1633] = 1633,
  [1634] = 1634,
  [1635] = 1635,
  [1636] = 1636,
  [1637] = 1637,
  [1638] = 1638,
  [1639] = 1639,
  [1640] = 1640,
  [1641] = 1641,
  [1642] = 1642,
  [1643] = 1643,
  [1644] = 1644,
  [1645] = 1645,
  [1646] = 1646,
  [1647] = 1647,
  [1648] = 1648,
  [1649] = 1649,
  [1650] = 1244,
  [1651] = 1651,
  [1652] = 1652,
  [1653] = 1653,
  [1654] = 167,
  [1655] = 1531,
  [1656] = 1532,
  [1657] = 1657,
  [1658] = 1658,
  [1659] = 1659,
  [1660] = 1660,
  [1661] = 1661,
  [1662] = 1662,
  [1663] = 1663,
  [1664] = 1664,
  [1665] = 1665,
  [1666] = 1666,
  [1667] = 1531,
  [1668] = 1532,
  [1669] = 1531,
  [1670] = 1532,
  [1671] = 1671,
  [1672] = 1672,
  [1673] = 1673,
  [1674] = 1531,
  [1675] = 1532,
  [1676] = 1676,
  [1677] = 1677,
  [1678] = 1678,
  [1679] = 1679,
  [1680] = 1680,
  [1681] = 1681,
  [1682] = 1682,
  [1683] = 1683,
  [1684] = 1684,
  [1685] = 1685,
  [1686] = 1686,
  [1687] = 1687,
  [1688] = 1688,
  [1689] = 1689,
  [1690] = 1690,
  [1691] = 1691,
  [1692] = 1692,
  [1693] = 1693,
  [1694] = 1694,
  [1695] = 1695,
  [1696] = 1696,
  [1697] = 1697,
  [1698] = 1698,
  [1699] = 1699,
  [1700] = 1700,
  [1701] = 1701,
  [1702] = 1702,
  [1703] = 1703,
  [1704] = 1704,
  [1705] = 1705,
  [1706] = 1706,
  [1707] = 1707,
  [1708] = 1708,
  [1709] = 1709,
  [1710] = 1710,
  [1711] = 1711,
  [1712] = 1712,
  [1713] = 1713,
  [1714] = 1714,
  [1715] = 1715,
  [1716] = 1716,
  [1717] = 1717,
  [1718] = 1718,
  [1719] = 1719,
  [1720] = 1720,
  [1721] = 1721,
  [1722] = 1722,
  [1723] = 1723,
  [1724] = 1724,
  [1725] = 1725,
  [1726] = 1726,
  [1727] = 1727,
  [1728] = 1728,
  [1729] = 1729,
  [1730] = 1730,
  [1731] = 1731,
  [1732] = 1732,
  [1733] = 1733,
  [1734] = 1734,
  [1735] = 1735,
  [1736] = 1735,
  [1737] = 1737,
  [1738] = 1738,
  [1739] = 90,
  [1740] = 1740,
  [1741] = 1741,
  [1742] = 1742,
  [1743] = 1541,
  [1744] = 1623,
  [1745] = 1543,
  [1746] = 1534,
  [1747] = 1537,
  [1748] = 1244,
  [1749] = 1749,
  [1750] = 1731,
  [1751] = 1540,
  [1752] = 1749,
  [1753] = 1753,
  [1754] = 1538,
  [1755] = 1539,
  [1756] = 1753,
  [1757] = 1757,
  [1758] = 1533,
  [1759] = 1535,
  [1760] = 1760,
  [1761] = 1544,
  [1762] = 1622,
  [1763] = 1760,
  [1764] = 1623,
  [1765] = 1765,
  [1766] = 1766,
  [1767] = 1765,
  [1768] = 1536,
  [1769] = 92,
  [1770] = 1770,
  [1771] = 1542,
  [1772] = 1622,
  [1773] = 1649,
  [1774] = 1705,
  [1775] = 1706,
  [1776] = 1707,
  [1777] = 1708,
  [1778] = 1709,
  [1779] = 1710,
  [1780] = 1693,
  [1781] = 1694,
  [1782] = 1711,
  [1783] = 1712,
  [1784] = 1713,
  [1785] = 1714,
  [1786] = 1715,
  [1787] = 1716,
  [1788] = 1704,
  [1789] = 1718,
  [1790] = 1719,
  [1791] = 1557,
  [1792] = 1720,
  [1793] = 1721,
  [1794] = 1722,
  [1795] = 1723,
  [1796] = 1724,
  [1797] = 1725,
  [1798] = 1726,
  [1799] = 1727,
  [1800] = 1728,
  [1801] = 1729,
  [1802] = 1546,
  [1803] = 1551,
  [1804] = 1662,
  [1805] = 1548,
  [1806] = 1645,
  [1807] = 1646,
  [1808] = 1647,
  [1809] = 1648,
  [1810] = 1690,
  [1811] = 1652,
  [1812] = 1545,
  [1813] = 1663,
  [1814] = 1547,
  [1815] = 1730,
  [1816] = 1552,
  [1817] = 1553,
  [1818] = 1554,
  [1819] = 1555,
  [1820] = 1556,
  [1821] = 1558,
  [1822] = 1559,
  [1823] = 1560,
  [1824] = 1561,
  [1825] = 1562,
  [1826] = 1563,
  [1827] = 1564,
  [1828] = 1565,
  [1829] = 1566,
  [1830] = 1567,
  [1831] = 1568,
  [1832] = 1569,
  [1833] = 1570,
  [1834] = 1571,
  [1835] = 1572,
  [1836] = 1573,
  [1837] = 1574,
  [1838] = 1597,
  [1839] = 1598,
  [1840] = 1599,
  [1841] = 1600,
  [1842] = 1601,
  [1843] = 1602,
  [1844] = 1604,
  [1845] = 1605,
  [1846] = 1606,
  [1847] = 1607,
  [1848] = 1608,
  [1849] = 1609,
  [1850] = 1610,
  [1851] = 1611,
  [1852] = 1612,
  [1853] = 1613,
  [1854] = 1614,
  [1855] = 1615,
  [1856] = 1616,
  [1857] = 1617,
  [1858] = 1618,
  [1859] = 1619,
  [1860] = 1620,
  [1861] = 1575,
  [1862] = 1691,
  [1863] = 1576,
  [1864] = 1577,
  [1865] = 1578,
  [1866] = 1579,
  [1867] = 1580,
  [1868] = 1581,
  [1869] = 1582,
  [1870] = 1583,
  [1871] = 1584,
  [1872] = 1585,
  [1873] = 96,
  [1874] = 1586,
  [1875] = 1587,
  [1876] = 1695,
  [1877] = 1588,
  [1878] = 1589,
  [1879] = 1590,
  [1880] = 1591,
  [1881] = 1592,
  [1882] = 1593,
  [1883] = 1594,
  [1884] = 1595,
  [1885] = 1596,
  [1886] = 1244,
  [1887] = 1603,
  [1888] = 1621,
  [1889] = 1624,
  [1890] = 1625,
  [1891] = 1626,
  [1892] = 90,
  [1893] = 1627,
  [1894] = 1628,
  [1895] = 1629,
  [1896] = 1630,
  [1897] = 1631,
  [1898] = 1632,
  [1899] = 1633,
  [1900] = 1657,
  [1901] = 1658,
  [1902] = 1659,
  [1903] = 1634,
  [1904] = 1635,
  [1905] = 1636,
  [1906] = 1637,
  [1907] = 1660,
  [1908] = 1638,
  [1909] = 1661,
  [1910] = 1664,
  [1911] = 1665,
  [1912] = 1666,
  [1913] = 1639,
  [1914] = 1640,
  [1915] = 1671,
  [1916] = 1672,
  [1917] = 1673,
  [1918] = 1676,
  [1919] = 1677,
  [1920] = 1641,
  [1921] = 1642,
  [1922] = 1678,
  [1923] = 1679,
  [1924] = 1643,
  [1925] = 1644,
  [1926] = 1696,
  [1927] = 1680,
  [1928] = 1697,
  [1929] = 1651,
  [1930] = 1681,
  [1931] = 1682,
  [1932] = 1698,
  [1933] = 1683,
  [1934] = 1653,
  [1935] = 1699,
  [1936] = 1685,
  [1937] = 1700,
  [1938] = 1692,
  [1939] = 1939,
  [1940] = 1686,
  [1941] = 1687,
  [1942] = 1688,
  [1943] = 1689,
  [1944] = 1701,
  [1945] = 1702,
  [1946] = 1703,
  [1947] = 1717,
  [1948] = 1948,
  [1949] = 973,
  [1950] = 1950,
  [1951] = 1951,
  [1952] = 1952,
  [1953] = 1953,
  [1954] = 974,
  [1955] = 1955,
  [1956] = 1956,
  [1957] = 1957,
  [1958] = 1958,
  [1959] = 1959,
  [1960] = 1960,
  [1961] = 1961,
  [1962] = 1962,
  [1963] = 1963,
  [1964] = 1964,
  [1965] = 1965,
  [1966] = 1966,
  [1967] = 1967,
  [1968] = 1968,
  [1969] = 1969,
  [1970] = 1970,
  [1971] = 1971,
  [1972] = 1972,
  [1973] = 1973,
  [1974] = 1974,
  [1975] = 975,
  [1976] = 976,
  [1977] = 952,
  [1978] = 1978,
  [1979] = 1979,
  [1980] = 1980,
  [1981] = 977,
  [1982] = 957,
  [1983] = 951,
  [1984] = 957,
  [1985] = 1985,
  [1986] = 1986,
  [1987] = 995,
  [1988] = 1988,
  [1989] = 1989,
  [1990] = 1990,
  [1991] = 1991,
  [1992] = 1992,
  [1993] = 1993,
  [1994] = 1994,
  [1995] = 1995,
  [1996] = 1996,
  [1997] = 1997,
  [1998] = 985,
  [1999] = 951,
  [2000] = 2000,
  [2001] = 2001,
  [2002] = 2002,
  [2003] = 2003,
  [2004] = 2004,
  [2005] = 2005,
  [2006] = 2006,
  [2007] = 2007,
  [2008] = 2008,
  [2009] = 2009,
  [2010] = 2010,
  [2011] = 2011,
  [2012] = 2012,
  [2013] = 2013,
  [2014] = 995,
  [2015] = 985,
  [2016] = 92,
  [2017] = 978,
  [2018] = 992,
  [2019] = 993,
  [2020] = 2020,
  [2021] = 2021,
  [2022] = 2022,
  [2023] = 971,
  [2024] = 997,
  [2025] = 956,
  [2026] = 2026,
  [2027] = 2027,
  [2028] = 2028,
  [2029] = 2029,
  [2030] = 972,
  [2031] = 953,
  [2032] = 1684,
  [2033] = 978,
  [2034] = 2034,
  [2035] = 2035,
  [2036] = 2036,
  [2037] = 954,
  [2038] = 2038,
  [2039] = 2039,
  [2040] = 2040,
  [2041] = 2041,
  [2042] = 956,
  [2043] = 959,
  [2044] = 962,
  [2045] = 963,
  [2046] = 992,
  [2047] = 993,
  [2048] = 2048,
  [2049] = 2049,
  [2050] = 2050,
  [2051] = 2051,
  [2052] = 964,
  [2053] = 965,
  [2054] = 2054,
  [2055] = 2055,
  [2056] = 2056,
  [2057] = 2057,
  [2058] = 966,
  [2059] = 967,
  [2060] = 972,
  [2061] = 953,
  [2062] = 954,
  [2063] = 959,
  [2064] = 962,
  [2065] = 963,
  [2066] = 964,
  [2067] = 965,
  [2068] = 966,
  [2069] = 967,
  [2070] = 968,
  [2071] = 969,
  [2072] = 970,
  [2073] = 971,
  [2074] = 997,
  [2075] = 2075,
  [2076] = 2076,
  [2077] = 2077,
  [2078] = 973,
  [2079] = 974,
  [2080] = 975,
  [2081] = 976,
  [2082] = 952,
  [2083] = 977,
  [2084] = 2084,
  [2085] = 968,
  [2086] = 969,
  [2087] = 970,
  [2088] = 2088,
  [2089] = 1008,
  [2090] = 1012,
  [2091] = 1010,
  [2092] = 1013,
  [2093] = 1014,
  [2094] = 90,
  [2095] = 988,
  [2096] = 989,
  [2097] = 990,
  [2098] = 991,
  [2099] = 1000,
  [2100] = 998,
  [2101] = 984,
  [2102] = 1000,
  [2103] = 1006,
  [2104] = 1003,
  [2105] = 1011,
  [2106] = 999,
  [2107] = 999,
  [2108] = 2108,
  [2109] = 96,
  [2110] = 984,
  [2111] = 960,
  [2112] = 1734,
  [2113] = 961,
  [2114] = 986,
  [2115] = 1012,
  [2116] = 1006,
  [2117] = 1014,
  [2118] = 987,
  [2119] = 1003,
  [2120] = 998,
  [2121] = 988,
  [2122] = 989,
  [2123] = 990,
  [2124] = 991,
  [2125] = 960,
  [2126] = 1007,
  [2127] = 961,
  [2128] = 986,
  [2129] = 1008,
  [2130] = 1007,
  [2131] = 987,
  [2132] = 1010,
  [2133] = 1013,
  [2134] = 1011,
  [2135] = 2135,
  [2136] = 1032,
  [2137] = 1033,
  [2138] = 1035,
  [2139] = 1037,
  [2140] = 1016,
  [2141] = 1017,
  [2142] = 1018,
  [2143] = 1015,
  [2144] = 1027,
  [2145] = 1024,
  [2146] = 1027,
  [2147] = 1034,
  [2148] = 1038,
  [2149] = 1021,
  [2150] = 92,
  [2151] = 2151,
  [2152] = 1025,
  [2153] = 1004,
  [2154] = 2154,
  [2155] = 1005,
  [2156] = 1737,
  [2157] = 979,
  [2158] = 980,
  [2159] = 1009,
  [2160] = 2160,
  [2161] = 1029,
  [2162] = 981,
  [2163] = 982,
  [2164] = 1030,
  [2165] = 983,
  [2166] = 1019,
  [2167] = 1028,
  [2168] = 1023,
  [2169] = 1036,
  [2170] = 1741,
  [2171] = 1020,
  [2172] = 1039,
  [2173] = 2173,
  [2174] = 1001,
  [2175] = 2175,
  [2176] = 1031,
  [2177] = 2177,
  [2178] = 1034,
  [2179] = 1005,
  [2180] = 1002,
  [2181] = 1155,
  [2182] = 1040,
  [2183] = 1031,
  [2184] = 1032,
  [2185] = 1022,
  [2186] = 1024,
  [2187] = 1033,
  [2188] = 1035,
  [2189] = 1037,
  [2190] = 1016,
  [2191] = 1017,
  [2192] = 1018,
  [2193] = 2193,
  [2194] = 1015,
  [2195] = 1029,
  [2196] = 1030,
  [2197] = 1038,
  [2198] = 1021,
  [2199] = 1019,
  [2200] = 1009,
  [2201] = 1028,
  [2202] = 1004,
  [2203] = 1026,
  [2204] = 2151,
  [2205] = 1023,
  [2206] = 1036,
  [2207] = 1020,
  [2208] = 1025,
  [2209] = 1039,
  [2210] = 1001,
  [2211] = 1026,
  [2212] = 1770,
  [2213] = 1002,
  [2214] = 1040,
  [2215] = 1022,
  [2216] = 2216,
  [2217] = 1533,
  [2218] = 2218,
  [2219] = 1544,
  [2220] = 1535,
  [2221] = 1540,
  [2222] = 1537,
  [2223] = 1534,
  [2224] = 1542,
  [2225] = 1543,
  [2226] = 1536,
  [2227] = 1541,
  [2228] = 1539,
  [2229] = 96,
  [2230] = 1538,
  [2231] = 2218,
  [2232] = 1615,
  [2233] = 1607,
  [2234] = 1720,
  [2235] = 1725,
  [2236] = 1726,
  [2237] = 1727,
  [2238] = 1728,
  [2239] = 1545,
  [2240] = 1663,
  [2241] = 1610,
  [2242] = 1608,
  [2243] = 1548,
  [2244] = 1547,
  [2245] = 1730,
  [2246] = 1688,
  [2247] = 1689,
  [2248] = 1645,
  [2249] = 1721,
  [2250] = 1646,
  [2251] = 1714,
  [2252] = 1715,
  [2253] = 1552,
  [2254] = 1553,
  [2255] = 1554,
  [2256] = 1555,
  [2257] = 1556,
  [2258] = 1647,
  [2259] = 1558,
  [2260] = 1657,
  [2261] = 1559,
  [2262] = 1560,
  [2263] = 1658,
  [2264] = 1611,
  [2265] = 1561,
  [2266] = 1659,
  [2267] = 1562,
  [2268] = 1664,
  [2269] = 1563,
  [2270] = 1665,
  [2271] = 1612,
  [2272] = 1716,
  [2273] = 1564,
  [2274] = 2216,
  [2275] = 1613,
  [2276] = 1614,
  [2277] = 1690,
  [2278] = 1604,
  [2279] = 1616,
  [2280] = 1651,
  [2281] = 1565,
  [2282] = 1691,
  [2283] = 1666,
  [2284] = 1617,
  [2285] = 1653,
  [2286] = 1692,
  [2287] = 1557,
  [2288] = 1618,
  [2289] = 1619,
  [2290] = 1566,
  [2291] = 1620,
  [2292] = 1605,
  [2293] = 1567,
  [2294] = 1693,
  [2295] = 1694,
  [2296] = 1648,
  [2297] = 1711,
  [2298] = 1606,
  [2299] = 1568,
  [2300] = 1569,
  [2301] = 1677,
  [2302] = 1570,
  [2303] = 1571,
  [2304] = 1572,
  [2305] = 1573,
  [2306] = 1574,
  [2307] = 1575,
  [2308] = 1722,
  [2309] = 1660,
  [2310] = 1661,
  [2311] = 1719,
  [2312] = 1576,
  [2313] = 1695,
  [2314] = 1696,
  [2315] = 1577,
  [2316] = 1578,
  [2317] = 1579,
  [2318] = 1580,
  [2319] = 1697,
  [2320] = 1698,
  [2321] = 1581,
  [2322] = 1713,
  [2323] = 1700,
  [2324] = 1582,
  [2325] = 1583,
  [2326] = 1701,
  [2327] = 1671,
  [2328] = 1584,
  [2329] = 1585,
  [2330] = 1586,
  [2331] = 1587,
  [2332] = 1588,
  [2333] = 1702,
  [2334] = 1589,
  [2335] = 1590,
  [2336] = 1703,
  [2337] = 1704,
  [2338] = 1705,
  [2339] = 1706,
  [2340] = 1707,
  [2341] = 1591,
  [2342] = 1592,
  [2343] = 1593,
  [2344] = 1594,
  [2345] = 1595,
  [2346] = 1596,
  [2347] = 1603,
  [2348] = 1712,
  [2349] = 1621,
  [2350] = 1624,
  [2351] = 1625,
  [2352] = 1626,
  [2353] = 1627,
  [2354] = 1628,
  [2355] = 1672,
  [2356] = 1629,
  [2357] = 1630,
  [2358] = 1708,
  [2359] = 1709,
  [2360] = 1710,
  [2361] = 1631,
  [2362] = 1673,
  [2363] = 1632,
  [2364] = 1633,
  [2365] = 1634,
  [2366] = 1635,
  [2367] = 1636,
  [2368] = 1637,
  [2369] = 1638,
  [2370] = 1639,
  [2371] = 1640,
  [2372] = 1641,
  [2373] = 1642,
  [2374] = 1733,
  [2375] = 1643,
  [2376] = 1644,
  [2377] = 1649,
  [2378] = 1678,
  [2379] = 1679,
  [2380] = 1680,
  [2381] = 1729,
  [2382] = 1546,
  [2383] = 1681,
  [2384] = 1682,
  [2385] = 1717,
  [2386] = 1551,
  [2387] = 1662,
  [2388] = 1718,
  [2389] = 1652,
  [2390] = 1723,
  [2391] = 1683,
  [2392] = 1685,
  [2393] = 1597,
  [2394] = 1598,
  [2395] = 1686,
  [2396] = 1687,
  [2397] = 1724,
  [2398] = 1599,
  [2399] = 1676,
  [2400] = 1600,
  [2401] = 1601,
  [2402] = 1602,
  [2403] = 1609,
  [2404] = 1244,
  [2405] = 1699,
  [2406] = 1684,
  [2407] = 2407,
  [2408] = 2407,
  [2409] = 2409,
  [2410] = 2407,
  [2411] = 2407,
  [2412] = 2409,
  [2413] = 2409,
  [2414] = 2409,
  [2415] = 167,
  [2416] = 1734,
  [2417] = 1733,
  [2418] = 2418,
  [2419] = 2418,
  [2420] = 2418,
  [2421] = 2421,
  [2422] = 2418,
  [2423] = 2418,
  [2424] = 2418,
  [2425] = 2418,
  [2426] = 2418,
  [2427] = 1735,
  [2428] = 2428,
  [2429] = 2429,
  [2430] = 1741,
  [2431] = 2429,
  [2432] = 2432,
  [2433] = 2433,
  [2434] = 2432,
  [2435] = 2435,
  [2436] = 2428,
  [2437] = 2428,
  [2438] = 2432,
  [2439] = 2439,
  [2440] = 2440,
  [2441] = 2441,
  [2442] = 1244,
  [2443] = 2443,
  [2444] = 1770,
  [2445] = 1737,
  [2446] = 2446,
  [2447] = 2216,
  [2448] = 2448,
  [2449] = 2448,
  [2450] = 2448,
  [2451] = 2448,
  [2452] = 2448,
  [2453] = 2448,
  [2454] = 2448,
  [2455] = 2448,
  [2456] = 2446,
  [2457] = 1948,
  [2458] = 2038,
  [2459] = 2000,
  [2460] = 2001,
  [2461] = 2002,
  [2462] = 1957,
  [2463] = 2003,
  [2464] = 1988,
  [2465] = 2054,
  [2466] = 2055,
  [2467] = 2056,
  [2468] = 2057,
  [2469] = 1989,
  [2470] = 1990,
  [2471] = 1991,
  [2472] = 1992,
  [2473] = 1993,
  [2474] = 1994,
  [2475] = 2475,
  [2476] = 2048,
  [2477] = 1995,
  [2478] = 1996,
  [2479] = 1997,
  [2480] = 2049,
  [2481] = 2050,
  [2482] = 2004,
  [2483] = 2051,
  [2484] = 2005,
  [2485] = 2006,
  [2486] = 2007,
  [2487] = 2008,
  [2488] = 2009,
  [2489] = 2010,
  [2490] = 2011,
  [2491] = 2012,
  [2492] = 2013,
  [2493] = 1958,
  [2494] = 2475,
  [2495] = 1951,
  [2496] = 1959,
  [2497] = 1952,
  [2498] = 2075,
  [2499] = 2040,
  [2500] = 2076,
  [2501] = 2041,
  [2502] = 2077,
  [2503] = 1955,
  [2504] = 2020,
  [2505] = 2039,
  [2506] = 2022,
  [2507] = 1956,
  [2508] = 2088,
  [2509] = 2026,
  [2510] = 2027,
  [2511] = 2028,
  [2512] = 2029,
  [2513] = 1960,
  [2514] = 1961,
  [2515] = 1962,
  [2516] = 1971,
  [2517] = 1972,
  [2518] = 1973,
  [2519] = 1963,
  [2520] = 1964,
  [2521] = 1965,
  [2522] = 1953,
  [2523] = 2034,
  [2524] = 2035,
  [2525] = 2036,
  [2526] = 2526,
  [2527] = 167,
  [2528] = 1966,
  [2529] = 1974,
  [2530] = 1967,
  [2531] = 1978,
  [2532] = 1968,
  [2533] = 1979,
  [2534] = 1969,
  [2535] = 1980,
  [2536] = 1985,
  [2537] = 1986,
  [2538] = 2084,
  [2539] = 1950,
  [2540] = 1970,
  [2541] = 2021,
  [2542] = 999,
  [2543] = 988,
  [2544] = 989,
  [2545] = 990,
  [2546] = 991,
  [2547] = 1011,
  [2548] = 951,
  [2549] = 2549,
  [2550] = 2550,
  [2551] = 90,
  [2552] = 2552,
  [2553] = 92,
  [2554] = 1155,
  [2555] = 2555,
  [2556] = 1009,
  [2557] = 2557,
  [2558] = 2557,
  [2559] = 2559,
  [2560] = 2560,
  [2561] = 2561,
  [2562] = 2562,
  [2563] = 1027,
  [2564] = 2564,
  [2565] = 2565,
  [2566] = 96,
  [2567] = 2567,
  [2568] = 2568,
  [2569] = 2568,
  [2570] = 2570,
  [2571] = 2565,
  [2572] = 2572,
  [2573] = 2573,
  [2574] = 2574,
  [2575] = 2574,
  [2576] = 2576,
  [2577] = 2577,
  [2578] = 2578,
  [2579] = 2579,
  [2580] = 2580,
  [2581] = 2581,
  [2582] = 2582,
  [2583] = 2583,
  [2584] = 2584,
  [2585] = 2576,
  [2586] = 2586,
  [2587] = 2587,
  [2588] = 2578,
  [2589] = 2589,
  [2590] = 2590,
  [2591] = 2591,
  [2592] = 2581,
  [2593] = 2593,
  [2594] = 2594,
  [2595] = 2595,
  [2596] = 2582,
  [2597] = 2597,
  [2598] = 2598,
  [2599] = 2599,
  [2600] = 2583,
  [2601] = 2601,
  [2602] = 2602,
  [2603] = 2584,
  [2604] = 2593,
  [2605] = 2586,
  [2606] = 2594,
  [2607] = 2598,
  [2608] = 2608,
  [2609] = 2601,
  [2610] = 2602,
  [2611] = 2611,
  [2612] = 2611,
  [2613] = 2577,
  [2614] = 2614,
  [2615] = 2216,
  [2616] = 2599,
  [2617] = 2589,
  [2618] = 2614,
  [2619] = 2619,
  [2620] = 2579,
  [2621] = 2590,
  [2622] = 2591,
  [2623] = 2580,
  [2624] = 2587,
  [2625] = 2608,
  [2626] = 2626,
  [2627] = 2627,
  [2628] = 2628,
  [2629] = 2629,
  [2630] = 2630,
  [2631] = 2631,
  [2632] = 2632,
  [2633] = 2633,
  [2634] = 2629,
  [2635] = 2633,
  [2636] = 2636,
  [2637] = 2637,
  [2638] = 2638,
  [2639] = 2637,
  [2640] = 2640,
  [2641] = 2641,
  [2642] = 2642,
  [2643] = 1155,
  [2644] = 2644,
  [2645] = 2645,
  [2646] = 2646,
  [2647] = 2647,
  [2648] = 2648,
  [2649] = 2649,
  [2650] = 2650,
  [2651] = 2636,
  [2652] = 2652,
  [2653] = 2653,
  [2654] = 2654,
  [2655] = 2655,
  [2656] = 2656,
  [2657] = 2657,
  [2658] = 2658,
  [2659] = 2659,
  [2660] = 2638,
  [2661] = 2654,
  [2662] = 2648,
  [2663] = 2650,
  [2664] = 2653,
  [2665] = 2665,
  [2666] = 2666,
  [2667] = 2665,
  [2668] = 2668,
  [2669] = 2669,
  [2670] = 2670,
  [2671] = 2671,
  [2672] = 2666,
  [2673] = 2665,
  [2674] = 2668,
  [2675] = 2670,
  [2676] = 2666,
  [2677] = 2665,
  [2678] = 2668,
  [2679] = 2669,
  [2680] = 2680,
  [2681] = 2670,
  [2682] = 2671,
  [2683] = 2671,
  [2684] = 2666,
  [2685] = 2665,
  [2686] = 2666,
  [2687] = 2668,
  [2688] = 2669,
  [2689] = 2669,
  [2690] = 2670,
  [2691] = 2671,
  [2692] = 2666,
  [2693] = 2665,
  [2694] = 2669,
  [2695] = 2668,
  [2696] = 2670,
  [2697] = 2671,
  [2698] = 2666,
  [2699] = 2665,
  [2700] = 2668,
  [2701] = 2668,
  [2702] = 2669,
  [2703] = 2670,
  [2704] = 2671,
  [2705] = 2666,
  [2706] = 2665,
  [2707] = 2668,
  [2708] = 2669,
  [2709] = 2670,
  [2710] = 2671,
  [2711] = 2670,
  [2712] = 2671,
  [2713] = 2713,
  [2714] = 2714,
  [2715] = 2669,
  [2716] = 167,
  [2717] = 2717,
  [2718] = 2718,
  [2719] = 2719,
  [2720] = 2719,
  [2721] = 2721,
  [2722] = 2722,
  [2723] = 2723,
  [2724] = 2722,
  [2725] = 90,
  [2726] = 2721,
  [2727] = 2727,
  [2728] = 2728,
  [2729] = 2729,
  [2730] = 2728,
  [2731] = 2731,
  [2732] = 2732,
  [2733] = 2722,
  [2734] = 2734,
  [2735] = 2735,
  [2736] = 2736,
  [2737] = 2735,
  [2738] = 92,
  [2739] = 2739,
  [2740] = 2739,
  [2741] = 1731,
  [2742] = 2742,
  [2743] = 2743,
  [2744] = 1623,
  [2745] = 2745,
  [2746] = 2739,
  [2747] = 2743,
  [2748] = 2748,
  [2749] = 2749,
  [2750] = 1622,
  [2751] = 2742,
  [2752] = 2748,
  [2753] = 2753,
  [2754] = 2749,
  [2755] = 2739,
  [2756] = 2745,
  [2757] = 96,
  [2758] = 2739,
  [2759] = 2753,
  [2760] = 2760,
  [2761] = 2761,
  [2762] = 2762,
  [2763] = 2763,
  [2764] = 2764,
  [2765] = 2762,
  [2766] = 2762,
  [2767] = 2767,
  [2768] = 2768,
  [2769] = 2769,
  [2770] = 2760,
  [2771] = 2760,
  [2772] = 2764,
  [2773] = 2764,
  [2774] = 2768,
  [2775] = 2775,
  [2776] = 2776,
  [2777] = 2762,
  [2778] = 2767,
  [2779] = 2779,
  [2780] = 2764,
  [2781] = 2781,
  [2782] = 2782,
  [2783] = 2767,
  [2784] = 2760,
  [2785] = 2762,
  [2786] = 2760,
  [2787] = 2767,
  [2788] = 2788,
  [2789] = 2781,
  [2790] = 2776,
  [2791] = 2760,
  [2792] = 2775,
  [2793] = 2782,
  [2794] = 2760,
  [2795] = 2782,
  [2796] = 2788,
  [2797] = 2797,
  [2798] = 2797,
  [2799] = 2763,
  [2800] = 2769,
  [2801] = 2762,
  [2802] = 2762,
  [2803] = 2803,
  [2804] = 2803,
  [2805] = 2805,
  [2806] = 2806,
  [2807] = 2760,
  [2808] = 2762,
  [2809] = 2779,
  [2810] = 2810,
  [2811] = 2811,
  [2812] = 2812,
  [2813] = 2813,
  [2814] = 2814,
  [2815] = 2815,
  [2816] = 2816,
  [2817] = 2817,
  [2818] = 2818,
  [2819] = 2819,
  [2820] = 2820,
  [2821] = 2821,
  [2822] = 2822,
  [2823] = 2823,
  [2824] = 2824,
  [2825] = 2825,
  [2826] = 2826,
  [2827] = 2827,
  [2828] = 2828,
  [2829] = 2829,
  [2830] = 2830,
  [2831] = 2831,
  [2832] = 2832,
  [2833] = 2833,
  [2834] = 2834,
  [2835] = 2835,
  [2836] = 2836,
  [2837] = 2811,
  [2838] = 2838,
  [2839] = 2839,
  [2840] = 2812,
  [2841] = 2813,
  [2842] = 2814,
  [2843] = 2843,
  [2844] = 2815,
  [2845] = 2816,
  [2846] = 2829,
  [2847] = 2817,
  [2848] = 2818,
  [2849] = 2819,
  [2850] = 2820,
  [2851] = 2821,
  [2852] = 2834,
  [2853] = 2822,
  [2854] = 2823,
  [2855] = 2824,
  [2856] = 2825,
  [2857] = 2831,
  [2858] = 2832,
  [2859] = 2833,
  [2860] = 2826,
  [2861] = 2827,
  [2862] = 2835,
  [2863] = 2811,
  [2864] = 2812,
  [2865] = 2813,
  [2866] = 2835,
  [2867] = 2834,
  [2868] = 2828,
  [2869] = 2814,
  [2870] = 2870,
  [2871] = 2871,
  [2872] = 2872,
  [2873] = 2815,
  [2874] = 2874,
  [2875] = 2875,
  [2876] = 2876,
  [2877] = 2816,
  [2878] = 2817,
  [2879] = 2879,
  [2880] = 2880,
  [2881] = 2818,
  [2882] = 2832,
  [2883] = 2819,
  [2884] = 2820,
  [2885] = 2885,
  [2886] = 2838,
  [2887] = 2839,
  [2888] = 2829,
  [2889] = 2821,
  [2890] = 2822,
  [2891] = 2823,
  [2892] = 2824,
  [2893] = 2825,
  [2894] = 2826,
  [2895] = 2827,
  [2896] = 2828,
  [2897] = 2833,
  [2898] = 2843,
  [2899] = 2813,
  [2900] = 2814,
  [2901] = 2835,
  [2902] = 2834,
  [2903] = 1604,
  [2904] = 2815,
  [2905] = 2811,
  [2906] = 1605,
  [2907] = 2829,
  [2908] = 2838,
  [2909] = 2816,
  [2910] = 2910,
  [2911] = 2839,
  [2912] = 2912,
  [2913] = 2913,
  [2914] = 2914,
  [2915] = 2915,
  [2916] = 2817,
  [2917] = 2834,
  [2918] = 2831,
  [2919] = 2919,
  [2920] = 2832,
  [2921] = 2833,
  [2922] = 2835,
  [2923] = 2843,
  [2924] = 2924,
  [2925] = 2925,
  [2926] = 2811,
  [2927] = 2812,
  [2928] = 2813,
  [2929] = 2814,
  [2930] = 2838,
  [2931] = 2839,
  [2932] = 2843,
  [2933] = 2815,
  [2934] = 2829,
  [2935] = 2831,
  [2936] = 2832,
  [2937] = 2833,
  [2938] = 2835,
  [2939] = 2811,
  [2940] = 2812,
  [2941] = 2813,
  [2942] = 2814,
  [2943] = 2815,
  [2944] = 2816,
  [2945] = 2817,
  [2946] = 2818,
  [2947] = 2819,
  [2948] = 2820,
  [2949] = 2821,
  [2950] = 2822,
  [2951] = 2823,
  [2952] = 2824,
  [2953] = 2825,
  [2954] = 2826,
  [2955] = 2827,
  [2956] = 2828,
  [2957] = 2957,
  [2958] = 2958,
  [2959] = 2816,
  [2960] = 2817,
  [2961] = 2829,
  [2962] = 2818,
  [2963] = 2819,
  [2964] = 2812,
  [2965] = 2820,
  [2966] = 2966,
  [2967] = 2821,
  [2968] = 2968,
  [2969] = 2969,
  [2970] = 2970,
  [2971] = 2822,
  [2972] = 2823,
  [2973] = 1244,
  [2974] = 2813,
  [2975] = 2975,
  [2976] = 2824,
  [2977] = 2977,
  [2978] = 2814,
  [2979] = 2979,
  [2980] = 2980,
  [2981] = 2815,
  [2982] = 2816,
  [2983] = 2817,
  [2984] = 2825,
  [2985] = 2818,
  [2986] = 2826,
  [2987] = 2831,
  [2988] = 2832,
  [2989] = 2833,
  [2990] = 2811,
  [2991] = 2812,
  [2992] = 2813,
  [2993] = 2814,
  [2994] = 2815,
  [2995] = 2819,
  [2996] = 2827,
  [2997] = 2816,
  [2998] = 2817,
  [2999] = 2999,
  [3000] = 2818,
  [3001] = 2828,
  [3002] = 2819,
  [3003] = 2838,
  [3004] = 2839,
  [3005] = 2875,
  [3006] = 2820,
  [3007] = 3007,
  [3008] = 3008,
  [3009] = 3009,
  [3010] = 3010,
  [3011] = 2821,
  [3012] = 3012,
  [3013] = 3013,
  [3014] = 2822,
  [3015] = 1606,
  [3016] = 2823,
  [3017] = 2824,
  [3018] = 3018,
  [3019] = 3019,
  [3020] = 2820,
  [3021] = 2825,
  [3022] = 2821,
  [3023] = 2822,
  [3024] = 2975,
  [3025] = 2977,
  [3026] = 2823,
  [3027] = 2826,
  [3028] = 1607,
  [3029] = 3029,
  [3030] = 1608,
  [3031] = 1609,
  [3032] = 1610,
  [3033] = 1611,
  [3034] = 1612,
  [3035] = 3035,
  [3036] = 1613,
  [3037] = 1614,
  [3038] = 3038,
  [3039] = 3039,
  [3040] = 1615,
  [3041] = 1616,
  [3042] = 2827,
  [3043] = 2824,
  [3044] = 2825,
  [3045] = 2826,
  [3046] = 2827,
  [3047] = 2828,
  [3048] = 2831,
  [3049] = 2829,
  [3050] = 2832,
  [3051] = 2833,
  [3052] = 2835,
  [3053] = 2875,
  [3054] = 3007,
  [3055] = 3008,
  [3056] = 2834,
  [3057] = 3009,
  [3058] = 3010,
  [3059] = 2819,
  [3060] = 3012,
  [3061] = 2820,
  [3062] = 1617,
  [3063] = 2811,
  [3064] = 3018,
  [3065] = 2821,
  [3066] = 2812,
  [3067] = 2813,
  [3068] = 2975,
  [3069] = 2977,
  [3070] = 2814,
  [3071] = 1618,
  [3072] = 2822,
  [3073] = 2834,
  [3074] = 3074,
  [3075] = 3075,
  [3076] = 3076,
  [3077] = 2815,
  [3078] = 2816,
  [3079] = 2817,
  [3080] = 2818,
  [3081] = 2838,
  [3082] = 2839,
  [3083] = 2875,
  [3084] = 3007,
  [3085] = 3008,
  [3086] = 3009,
  [3087] = 3010,
  [3088] = 3012,
  [3089] = 1619,
  [3090] = 3018,
  [3091] = 2975,
  [3092] = 2977,
  [3093] = 2819,
  [3094] = 2820,
  [3095] = 3095,
  [3096] = 3096,
  [3097] = 2875,
  [3098] = 3007,
  [3099] = 3008,
  [3100] = 3009,
  [3101] = 3010,
  [3102] = 3012,
  [3103] = 3018,
  [3104] = 2821,
  [3105] = 2822,
  [3106] = 2975,
  [3107] = 2977,
  [3108] = 2823,
  [3109] = 2824,
  [3110] = 2825,
  [3111] = 2875,
  [3112] = 3007,
  [3113] = 3008,
  [3114] = 3009,
  [3115] = 3010,
  [3116] = 3012,
  [3117] = 1620,
  [3118] = 3018,
  [3119] = 2843,
  [3120] = 2826,
  [3121] = 2827,
  [3122] = 2975,
  [3123] = 2977,
  [3124] = 2828,
  [3125] = 1597,
  [3126] = 2875,
  [3127] = 3127,
  [3128] = 3007,
  [3129] = 3008,
  [3130] = 3009,
  [3131] = 3131,
  [3132] = 2875,
  [3133] = 3007,
  [3134] = 3008,
  [3135] = 3135,
  [3136] = 3136,
  [3137] = 3010,
  [3138] = 2823,
  [3139] = 3012,
  [3140] = 1598,
  [3141] = 2810,
  [3142] = 2829,
  [3143] = 3143,
  [3144] = 2831,
  [3145] = 3145,
  [3146] = 2828,
  [3147] = 3147,
  [3148] = 2832,
  [3149] = 3149,
  [3150] = 3150,
  [3151] = 3151,
  [3152] = 3008,
  [3153] = 3131,
  [3154] = 3154,
  [3155] = 2834,
  [3156] = 2833,
  [3157] = 3029,
  [3158] = 3158,
  [3159] = 3007,
  [3160] = 2835,
  [3161] = 3161,
  [3162] = 3162,
  [3163] = 2811,
  [3164] = 2812,
  [3165] = 2835,
  [3166] = 2834,
  [3167] = 2829,
  [3168] = 2831,
  [3169] = 3008,
  [3170] = 3131,
  [3171] = 2832,
  [3172] = 2833,
  [3173] = 3131,
  [3174] = 2811,
  [3175] = 2812,
  [3176] = 2813,
  [3177] = 2824,
  [3178] = 2825,
  [3179] = 2814,
  [3180] = 2815,
  [3181] = 3181,
  [3182] = 2816,
  [3183] = 2826,
  [3184] = 2817,
  [3185] = 2818,
  [3186] = 2819,
  [3187] = 2820,
  [3188] = 2821,
  [3189] = 2822,
  [3190] = 2823,
  [3191] = 2824,
  [3192] = 2827,
  [3193] = 3008,
  [3194] = 2825,
  [3195] = 3181,
  [3196] = 2828,
  [3197] = 2826,
  [3198] = 2827,
  [3199] = 3181,
  [3200] = 2828,
  [3201] = 2831,
  [3202] = 3181,
  [3203] = 3181,
  [3204] = 2834,
  [3205] = 3013,
  [3206] = 2999,
  [3207] = 3181,
  [3208] = 3018,
  [3209] = 2810,
  [3210] = 3158,
  [3211] = 2919,
  [3212] = 2925,
  [3213] = 2999,
  [3214] = 3214,
  [3215] = 1599,
  [3216] = 2829,
  [3217] = 2810,
  [3218] = 3158,
  [3219] = 2919,
  [3220] = 2925,
  [3221] = 2999,
  [3222] = 1600,
  [3223] = 2810,
  [3224] = 3158,
  [3225] = 2919,
  [3226] = 2925,
  [3227] = 2999,
  [3228] = 1601,
  [3229] = 2843,
  [3230] = 2810,
  [3231] = 3158,
  [3232] = 2919,
  [3233] = 2925,
  [3234] = 2999,
  [3235] = 2831,
  [3236] = 3158,
  [3237] = 2919,
  [3238] = 2925,
  [3239] = 2832,
  [3240] = 2833,
  [3241] = 2835,
  [3242] = 1602,
  [3243] = 3135,
  [3244] = 3135,
  [3245] = 3135,
  [3246] = 3135,
  [3247] = 3135,
  [3248] = 3149,
  [3249] = 3149,
  [3250] = 3149,
  [3251] = 2818,
  [3252] = 3252,
  [3253] = 2627,
  [3254] = 3254,
  [3255] = 3255,
  [3256] = 3256,
  [3257] = 3257,
  [3258] = 2628,
  [3259] = 3255,
  [3260] = 3252,
  [3261] = 3261,
  [3262] = 3261,
  [3263] = 2632,
  [3264] = 3257,
  [3265] = 2630,
  [3266] = 3254,
  [3267] = 1244,
  [3268] = 3268,
  [3269] = 2626,
  [3270] = 3268,
  [3271] = 3256,
  [3272] = 3272,
  [3273] = 1604,
  [3274] = 1622,
  [3275] = 1600,
  [3276] = 3276,
  [3277] = 1605,
  [3278] = 3278,
  [3279] = 3279,
  [3280] = 3280,
  [3281] = 3281,
  [3282] = 3279,
  [3283] = 1601,
  [3284] = 3284,
  [3285] = 1610,
  [3286] = 1611,
  [3287] = 1612,
  [3288] = 1613,
  [3289] = 1614,
  [3290] = 3290,
  [3291] = 3291,
  [3292] = 3292,
  [3293] = 1615,
  [3294] = 1616,
  [3295] = 1617,
  [3296] = 1618,
  [3297] = 1619,
  [3298] = 3298,
  [3299] = 3299,
  [3300] = 3300,
  [3301] = 3301,
  [3302] = 3302,
  [3303] = 3303,
  [3304] = 3304,
  [3305] = 3305,
  [3306] = 3306,
  [3307] = 1602,
  [3308] = 1620,
  [3309] = 3276,
  [3310] = 1606,
  [3311] = 3311,
  [3312] = 1609,
  [3313] = 1599,
  [3314] = 3314,
  [3315] = 3315,
  [3316] = 3316,
  [3317] = 3317,
  [3318] = 3318,
  [3319] = 3319,
  [3320] = 3320,
  [3321] = 3321,
  [3322] = 3322,
  [3323] = 3323,
  [3324] = 3324,
  [3325] = 3278,
  [3326] = 3326,
  [3327] = 3327,
  [3328] = 3328,
  [3329] = 3329,
  [3330] = 2652,
  [3331] = 1623,
  [3332] = 1731,
  [3333] = 3276,
  [3334] = 3334,
  [3335] = 3335,
  [3336] = 3278,
  [3337] = 3279,
  [3338] = 3281,
  [3339] = 1597,
  [3340] = 3281,
  [3341] = 1598,
  [3342] = 1607,
  [3343] = 1608,
  [3344] = 3344,
  [3345] = 1535,
  [3346] = 1540,
  [3347] = 3347,
  [3348] = 3348,
  [3349] = 3349,
  [3350] = 990,
  [3351] = 3351,
  [3352] = 2713,
  [3353] = 988,
  [3354] = 1533,
  [3355] = 1538,
  [3356] = 1539,
  [3357] = 1541,
  [3358] = 1542,
  [3359] = 1543,
  [3360] = 1544,
  [3361] = 1534,
  [3362] = 989,
  [3363] = 90,
  [3364] = 3347,
  [3365] = 3348,
  [3366] = 3348,
  [3367] = 3347,
  [3368] = 167,
  [3369] = 2216,
  [3370] = 3370,
  [3371] = 3370,
  [3372] = 951,
  [3373] = 3373,
  [3374] = 3370,
  [3375] = 3373,
  [3376] = 92,
  [3377] = 3370,
  [3378] = 3378,
  [3379] = 3379,
  [3380] = 3380,
  [3381] = 3379,
  [3382] = 3382,
  [3383] = 3383,
  [3384] = 3384,
  [3385] = 3385,
  [3386] = 3386,
  [3387] = 3383,
  [3388] = 3388,
  [3389] = 3389,
  [3390] = 3390,
  [3391] = 3391,
  [3392] = 3392,
  [3393] = 3393,
  [3394] = 3394,
  [3395] = 3395,
  [3396] = 3396,
  [3397] = 3397,
  [3398] = 3398,
  [3399] = 3399,
  [3400] = 3400,
  [3401] = 3401,
  [3402] = 96,
  [3403] = 3403,
  [3404] = 3403,
  [3405] = 3403,
  [3406] = 3403,
  [3407] = 3384,
  [3408] = 3408,
  [3409] = 3409,
  [3410] = 3383,
  [3411] = 3411,
  [3412] = 3379,
  [3413] = 3413,
  [3414] = 3414,
  [3415] = 3415,
  [3416] = 3416,
  [3417] = 3390,
  [3418] = 3418,
  [3419] = 3396,
  [3420] = 3420,
  [3421] = 3421,
  [3422] = 3383,
  [3423] = 3423,
  [3424] = 3379,
  [3425] = 2729,
  [3426] = 3426,
  [3427] = 3409,
  [3428] = 3418,
  [3429] = 3429,
  [3430] = 3388,
  [3431] = 3431,
  [3432] = 3432,
  [3433] = 3433,
  [3434] = 3434,
  [3435] = 3435,
  [3436] = 3436,
  [3437] = 2216,
  [3438] = 3438,
  [3439] = 3439,
  [3440] = 3440,
  [3441] = 3441,
  [3442] = 3442,
  [3443] = 3443,
  [3444] = 3444,
  [3445] = 3445,
  [3446] = 3445,
  [3447] = 3447,
  [3448] = 3448,
  [3449] = 3449,
  [3450] = 3450,
  [3451] = 3451,
  [3452] = 3452,
  [3453] = 3448,
  [3454] = 3454,
  [3455] = 3447,
  [3456] = 3449,
  [3457] = 3454,
  [3458] = 3445,
  [3459] = 3452,
  [3460] = 3451,
  [3461] = 3461,
  [3462] = 3445,
  [3463] = 90,
  [3464] = 3464,
  [3465] = 3465,
  [3466] = 3466,
  [3467] = 3467,
  [3468] = 3468,
  [3469] = 3464,
  [3470] = 3470,
  [3471] = 3471,
  [3472] = 3472,
  [3473] = 3464,
  [3474] = 3464,
  [3475] = 3472,
  [3476] = 3476,
  [3477] = 3468,
  [3478] = 3478,
  [3479] = 3479,
  [3480] = 3479,
  [3481] = 3481,
  [3482] = 3476,
  [3483] = 3483,
  [3484] = 3466,
  [3485] = 3466,
  [3486] = 3476,
  [3487] = 3468,
  [3488] = 3488,
  [3489] = 3489,
  [3490] = 3476,
  [3491] = 3491,
  [3492] = 3464,
  [3493] = 3472,
  [3494] = 3479,
  [3495] = 1623,
  [3496] = 3479,
  [3497] = 3497,
  [3498] = 3472,
  [3499] = 3479,
  [3500] = 92,
  [3501] = 3501,
  [3502] = 3502,
  [3503] = 3503,
  [3504] = 1731,
  [3505] = 3476,
  [3506] = 3468,
  [3507] = 3472,
  [3508] = 3468,
  [3509] = 3509,
  [3510] = 3510,
  [3511] = 3511,
  [3512] = 2915,
  [3513] = 2924,
  [3514] = 3214,
  [3515] = 3515,
  [3516] = 3516,
  [3517] = 3517,
  [3518] = 3518,
  [3519] = 3161,
  [3520] = 3520,
  [3521] = 3521,
  [3522] = 3522,
  [3523] = 3523,
  [3524] = 3524,
  [3525] = 3525,
  [3526] = 3526,
  [3527] = 3527,
  [3528] = 3528,
  [3529] = 3529,
  [3530] = 3530,
  [3531] = 3531,
  [3532] = 3532,
  [3533] = 3533,
  [3534] = 3534,
  [3535] = 3535,
  [3536] = 3536,
  [3537] = 3537,
  [3538] = 3538,
  [3539] = 3539,
  [3540] = 3540,
  [3541] = 3541,
  [3542] = 3542,
  [3543] = 3543,
  [3544] = 3544,
  [3545] = 3545,
  [3546] = 3546,
  [3547] = 3547,
  [3548] = 3548,
  [3549] = 3549,
  [3550] = 3550,
  [3551] = 3551,
  [3552] = 3552,
  [3553] = 3553,
  [3554] = 3554,
  [3555] = 3555,
  [3556] = 3556,
  [3557] = 3557,
  [3558] = 3558,
  [3559] = 3559,
  [3560] = 3560,
  [3561] = 3561,
  [3562] = 3562,
  [3563] = 3563,
  [3564] = 3564,
  [3565] = 3565,
  [3566] = 3566,
  [3567] = 3567,
  [3568] = 3568,
  [3569] = 1557,
  [3570] = 3570,
  [3571] = 3571,
  [3572] = 3572,
  [3573] = 2979,
  [3574] = 3574,
  [3575] = 3575,
  [3576] = 2980,
  [3577] = 3577,
  [3578] = 3578,
  [3579] = 3579,
  [3580] = 3580,
  [3581] = 3581,
  [3582] = 3582,
  [3583] = 3583,
  [3584] = 3584,
  [3585] = 3585,
  [3586] = 3586,
  [3587] = 3587,
  [3588] = 3588,
  [3589] = 3589,
  [3590] = 3590,
  [3591] = 3591,
  [3592] = 3592,
  [3593] = 3593,
  [3594] = 2216,
  [3595] = 3595,
  [3596] = 3596,
  [3597] = 3597,
  [3598] = 3598,
  [3599] = 3599,
  [3600] = 3600,
  [3601] = 3601,
  [3602] = 3602,
  [3603] = 3603,
  [3604] = 3604,
  [3605] = 3605,
  [3606] = 3606,
  [3607] = 3607,
  [3608] = 3608,
  [3609] = 3609,
  [3610] = 3610,
  [3611] = 3611,
  [3612] = 3612,
  [3613] = 3613,
  [3614] = 2966,
  [3615] = 3615,
  [3616] = 2969,
  [3617] = 3617,
  [3618] = 3618,
  [3619] = 3619,
  [3620] = 3620,
  [3621] = 3621,
  [3622] = 3622,
  [3623] = 2871,
  [3624] = 2879,
  [3625] = 2880,
  [3626] = 3626,
  [3627] = 3627,
  [3628] = 3628,
  [3629] = 3629,
  [3630] = 2912,
  [3631] = 2913,
  [3632] = 2970,
  [3633] = 3633,
  [3634] = 3634,
  [3635] = 3635,
  [3636] = 3636,
  [3637] = 3637,
  [3638] = 3638,
  [3639] = 3639,
  [3640] = 3640,
  [3641] = 3641,
  [3642] = 3642,
  [3643] = 3643,
  [3644] = 3644,
  [3645] = 3645,
  [3646] = 2870,
  [3647] = 3647,
  [3648] = 3648,
  [3649] = 3649,
  [3650] = 3650,
  [3651] = 3651,
  [3652] = 3652,
  [3653] = 3653,
  [3654] = 3654,
  [3655] = 2914,
  [3656] = 3656,
  [3657] = 3657,
  [3658] = 3658,
  [3659] = 3659,
  [3660] = 3660,
  [3661] = 2627,
  [3662] = 2632,
  [3663] = 2630,
  [3664] = 3664,
  [3665] = 3665,
  [3666] = 3666,
  [3667] = 2626,
  [3668] = 3668,
  [3669] = 2628,
  [3670] = 3670,
  [3671] = 3671,
  [3672] = 3672,
  [3673] = 3673,
  [3674] = 3674,
  [3675] = 3675,
  [3676] = 3676,
  [3677] = 3677,
  [3678] = 3678,
  [3679] = 3679,
  [3680] = 3680,
  [3681] = 3681,
  [3682] = 3682,
  [3683] = 3683,
  [3684] = 3684,
  [3685] = 3685,
  [3686] = 3686,
  [3687] = 3687,
  [3688] = 3688,
  [3689] = 3689,
  [3690] = 3690,
  [3691] = 3691,
  [3692] = 3692,
  [3693] = 3693,
  [3694] = 3694,
  [3695] = 3695,
  [3696] = 3696,
  [3697] = 3697,
  [3698] = 3698,
  [3699] = 3699,
  [3700] = 3700,
  [3701] = 3701,
  [3702] = 3702,
  [3703] = 3703,
  [3704] = 3704,
  [3705] = 3705,
  [3706] = 3706,
  [3707] = 3707,
  [3708] = 3708,
  [3709] = 3709,
  [3710] = 3710,
  [3711] = 3711,
  [3712] = 3712,
  [3713] = 3713,
  [3714] = 3714,
  [3715] = 3715,
  [3716] = 3716,
  [3717] = 3717,
  [3718] = 3718,
  [3719] = 3719,
  [3720] = 3720,
  [3721] = 3721,
  [3722] = 3722,
  [3723] = 3723,
  [3724] = 3724,
  [3725] = 3725,
  [3726] = 3726,
  [3727] = 3727,
  [3728] = 3728,
  [3729] = 3729,
  [3730] = 96,
  [3731] = 3731,
  [3732] = 3732,
  [3733] = 3733,
  [3734] = 3734,
  [3735] = 3735,
  [3736] = 3736,
  [3737] = 3737,
  [3738] = 3738,
  [3739] = 3739,
  [3740] = 3740,
  [3741] = 3741,
  [3742] = 3742,
  [3743] = 3743,
  [3744] = 3744,
  [3745] = 3745,
  [3746] = 3746,
  [3747] = 3747,
  [3748] = 3748,
  [3749] = 3749,
  [3750] = 3750,
  [3751] = 3751,
  [3752] = 3752,
  [3753] = 3753,
  [3754] = 3754,
  [3755] = 3755,
  [3756] = 3143,
  [3757] = 3145,
  [3758] = 3151,
  [3759] = 2830,
  [3760] = 3760,
  [3761] = 3761,
  [3762] = 3154,
  [3763] = 3763,
  [3764] = 3764,
  [3765] = 3765,
  [3766] = 3766,
  [3767] = 3767,
  [3768] = 3768,
  [3769] = 3769,
  [3770] = 3770,
  [3771] = 3771,
  [3772] = 3772,
  [3773] = 3773,
  [3774] = 2836,
  [3775] = 2876,
  [3776] = 3776,
  [3777] = 3777,
  [3778] = 3778,
  [3779] = 3779,
  [3780] = 2872,
  [3781] = 3781,
  [3782] = 3782,
  [3783] = 3783,
  [3784] = 3784,
  [3785] = 3785,
  [3786] = 3786,
  [3787] = 3787,
  [3788] = 3788,
  [3789] = 3789,
  [3790] = 3790,
  [3791] = 3791,
  [3792] = 3792,
  [3793] = 3793,
  [3794] = 3794,
  [3795] = 3795,
  [3796] = 3796,
  [3797] = 3797,
  [3798] = 3038,
  [3799] = 1609,
  [3800] = 2910,
  [3801] = 2871,
  [3802] = 3802,
  [3803] = 3095,
  [3804] = 3802,
  [3805] = 3076,
  [3806] = 3161,
  [3807] = 2880,
  [3808] = 3808,
  [3809] = 2924,
  [3810] = 2979,
  [3811] = 2980,
  [3812] = 1604,
  [3813] = 3813,
  [3814] = 1620,
  [3815] = 2966,
  [3816] = 2969,
  [3817] = 2872,
  [3818] = 3151,
  [3819] = 2970,
  [3820] = 2957,
  [3821] = 1605,
  [3822] = 3074,
  [3823] = 2958,
  [3824] = 3147,
  [3825] = 2912,
  [3826] = 1606,
  [3827] = 1597,
  [3828] = 3828,
  [3829] = 1613,
  [3830] = 1608,
  [3831] = 1607,
  [3832] = 1611,
  [3833] = 2913,
  [3834] = 3096,
  [3835] = 1614,
  [3836] = 2914,
  [3837] = 3837,
  [3838] = 2830,
  [3839] = 3839,
  [3840] = 3154,
  [3841] = 1610,
  [3842] = 3214,
  [3843] = 2836,
  [3844] = 1612,
  [3845] = 3136,
  [3846] = 1599,
  [3847] = 3039,
  [3848] = 2915,
  [3849] = 1600,
  [3850] = 1615,
  [3851] = 2870,
  [3852] = 3852,
  [3853] = 1601,
  [3854] = 3808,
  [3855] = 1617,
  [3856] = 1244,
  [3857] = 1616,
  [3858] = 3143,
  [3859] = 3145,
  [3860] = 1598,
  [3861] = 1602,
  [3862] = 1618,
  [3863] = 1619,
  [3864] = 2876,
  [3865] = 3075,
  [3866] = 2879,
  [3867] = 2885,
  [3868] = 3868,
  [3869] = 3869,
  [3870] = 3870,
  [3871] = 3871,
  [3872] = 3872,
  [3873] = 3868,
  [3874] = 3869,
  [3875] = 3875,
  [3876] = 3876,
  [3877] = 3877,
  [3878] = 3871,
  [3879] = 3879,
  [3880] = 3880,
  [3881] = 3876,
  [3882] = 3882,
  [3883] = 3883,
  [3884] = 951,
  [3885] = 3885,
  [3886] = 3886,
  [3887] = 3877,
  [3888] = 1244,
  [3889] = 3870,
  [3890] = 3890,
  [3891] = 3886,
  [3892] = 3882,
  [3893] = 3893,
  [3894] = 3526,
  [3895] = 3521,
  [3896] = 3896,
  [3897] = 3522,
  [3898] = 3523,
  [3899] = 3524,
  [3900] = 3525,
  [3901] = 3527,
  [3902] = 3528,
  [3903] = 3530,
  [3904] = 3904,
  [3905] = 3905,
  [3906] = 3906,
  [3907] = 3907,
  [3908] = 3908,
  [3909] = 3909,
  [3910] = 3910,
  [3911] = 3911,
  [3912] = 3912,
  [3913] = 3913,
  [3914] = 3914,
  [3915] = 3915,
  [3916] = 3916,
  [3917] = 3917,
  [3918] = 3918,
  [3919] = 3919,
  [3920] = 3683,
  [3921] = 3533,
  [3922] = 3534,
  [3923] = 3535,
  [3924] = 3536,
  [3925] = 3925,
  [3926] = 3926,
  [3927] = 3927,
  [3928] = 3928,
  [3929] = 3929,
  [3930] = 3930,
  [3931] = 3931,
  [3932] = 3932,
  [3933] = 3933,
  [3934] = 3537,
  [3935] = 3935,
  [3936] = 3936,
  [3937] = 3937,
  [3938] = 3938,
  [3939] = 3939,
  [3940] = 3940,
  [3941] = 3538,
  [3942] = 3539,
  [3943] = 3943,
  [3944] = 3944,
  [3945] = 3945,
  [3946] = 3946,
  [3947] = 3947,
  [3948] = 3540,
  [3949] = 3541,
  [3950] = 3950,
  [3951] = 3314,
  [3952] = 3315,
  [3953] = 3316,
  [3954] = 3317,
  [3955] = 3318,
  [3956] = 3956,
  [3957] = 3319,
  [3958] = 3320,
  [3959] = 3321,
  [3960] = 3960,
  [3961] = 3322,
  [3962] = 3323,
  [3963] = 3324,
  [3964] = 3693,
  [3965] = 3965,
  [3966] = 3966,
  [3967] = 3967,
  [3968] = 3968,
  [3969] = 3969,
  [3970] = 3970,
  [3971] = 3971,
  [3972] = 3972,
  [3973] = 3699,
  [3974] = 3974,
  [3975] = 3975,
  [3976] = 3708,
  [3977] = 3977,
  [3978] = 3978,
  [3979] = 3710,
  [3980] = 3980,
  [3981] = 3763,
  [3982] = 3553,
  [3983] = 3554,
  [3984] = 3555,
  [3985] = 3556,
  [3986] = 3557,
  [3987] = 3558,
  [3988] = 3559,
  [3989] = 3560,
  [3990] = 3561,
  [3991] = 3562,
  [3992] = 3563,
  [3993] = 3993,
  [3994] = 3994,
  [3995] = 3995,
  [3996] = 3996,
  [3997] = 3997,
  [3998] = 3998,
  [3999] = 3564,
  [4000] = 3565,
  [4001] = 2915,
  [4002] = 2924,
  [4003] = 3711,
  [4004] = 3715,
  [4005] = 3717,
  [4006] = 3719,
  [4007] = 3720,
  [4008] = 3723,
  [4009] = 4009,
  [4010] = 3161,
  [4011] = 3729,
  [4012] = 4012,
  [4013] = 4013,
  [4014] = 4014,
  [4015] = 4015,
  [4016] = 4016,
  [4017] = 3680,
  [4018] = 3515,
  [4019] = 4019,
  [4020] = 3516,
  [4021] = 4021,
  [4022] = 3517,
  [4023] = 4023,
  [4024] = 3518,
  [4025] = 4025,
  [4026] = 2966,
  [4027] = 2969,
  [4028] = 2970,
  [4029] = 4029,
  [4030] = 4030,
  [4031] = 4031,
  [4032] = 4032,
  [4033] = 3520,
  [4034] = 4034,
  [4035] = 4035,
  [4036] = 3579,
  [4037] = 3580,
  [4038] = 3581,
  [4039] = 3582,
  [4040] = 3583,
  [4041] = 4041,
  [4042] = 3584,
  [4043] = 3585,
  [4044] = 3586,
  [4045] = 3587,
  [4046] = 3588,
  [4047] = 3589,
  [4048] = 3590,
  [4049] = 3591,
  [4050] = 3326,
  [4051] = 3327,
  [4052] = 3328,
  [4053] = 3329,
  [4054] = 4054,
  [4055] = 4055,
  [4056] = 4056,
  [4057] = 3529,
  [4058] = 4058,
  [4059] = 4059,
  [4060] = 4060,
  [4061] = 4061,
  [4062] = 4062,
  [4063] = 3531,
  [4064] = 4064,
  [4065] = 4065,
  [4066] = 4066,
  [4067] = 3532,
  [4068] = 4068,
  [4069] = 4069,
  [4070] = 3595,
  [4071] = 3596,
  [4072] = 3597,
  [4073] = 3598,
  [4074] = 3599,
  [4075] = 3600,
  [4076] = 3601,
  [4077] = 3602,
  [4078] = 3603,
  [4079] = 3604,
  [4080] = 3605,
  [4081] = 3606,
  [4082] = 3607,
  [4083] = 3608,
  [4084] = 3609,
  [4085] = 3610,
  [4086] = 3611,
  [4087] = 3551,
  [4088] = 3552,
  [4089] = 4089,
  [4090] = 3566,
  [4091] = 2979,
  [4092] = 2980,
  [4093] = 4093,
  [4094] = 4094,
  [4095] = 4095,
  [4096] = 3637,
  [4097] = 3638,
  [4098] = 3639,
  [4099] = 4099,
  [4100] = 167,
  [4101] = 3640,
  [4102] = 3641,
  [4103] = 4103,
  [4104] = 4104,
  [4105] = 4105,
  [4106] = 4106,
  [4107] = 4099,
  [4108] = 4108,
  [4109] = 4109,
  [4110] = 4110,
  [4111] = 4111,
  [4112] = 3642,
  [4113] = 3643,
  [4114] = 3645,
  [4115] = 3647,
  [4116] = 3648,
  [4117] = 4117,
  [4118] = 3649,
  [4119] = 3650,
  [4120] = 3651,
  [4121] = 3652,
  [4122] = 3653,
  [4123] = 3797,
  [4124] = 3654,
  [4125] = 3567,
  [4126] = 4126,
  [4127] = 3760,
  [4128] = 4128,
  [4129] = 3280,
  [4130] = 3571,
  [4131] = 4131,
  [4132] = 4132,
  [4133] = 4133,
  [4134] = 3543,
  [4135] = 3544,
  [4136] = 4136,
  [4137] = 4137,
  [4138] = 4138,
  [4139] = 3685,
  [4140] = 3686,
  [4141] = 3687,
  [4142] = 3688,
  [4143] = 3689,
  [4144] = 3690,
  [4145] = 4145,
  [4146] = 4146,
  [4147] = 4147,
  [4148] = 4148,
  [4149] = 4009,
  [4150] = 4016,
  [4151] = 4151,
  [4152] = 3691,
  [4153] = 4128,
  [4154] = 4154,
  [4155] = 4013,
  [4156] = 4137,
  [4157] = 4157,
  [4158] = 4158,
  [4159] = 3692,
  [4160] = 4160,
  [4161] = 4161,
  [4162] = 3977,
  [4163] = 4012,
  [4164] = 4014,
  [4165] = 4165,
  [4166] = 1597,
  [4167] = 4015,
  [4168] = 4034,
  [4169] = 4132,
  [4170] = 4133,
  [4171] = 4147,
  [4172] = 4172,
  [4173] = 4173,
  [4174] = 4174,
  [4175] = 4175,
  [4176] = 4176,
  [4177] = 4177,
  [4178] = 4117,
  [4179] = 4089,
  [4180] = 4180,
  [4181] = 4181,
  [4182] = 4182,
  [4183] = 4183,
  [4184] = 4184,
  [4185] = 4185,
  [4186] = 4186,
  [4187] = 4187,
  [4188] = 4188,
  [4189] = 4189,
  [4190] = 4190,
  [4191] = 4191,
  [4192] = 4157,
  [4193] = 4172,
  [4194] = 4173,
  [4195] = 4180,
  [4196] = 1598,
  [4197] = 3694,
  [4198] = 3700,
  [4199] = 3965,
  [4200] = 3701,
  [4201] = 3702,
  [4202] = 4181,
  [4203] = 4182,
  [4204] = 4019,
  [4205] = 4021,
  [4206] = 4023,
  [4207] = 4025,
  [4208] = 4031,
  [4209] = 4041,
  [4210] = 4183,
  [4211] = 4060,
  [4212] = 4184,
  [4213] = 4126,
  [4214] = 4185,
  [4215] = 4165,
  [4216] = 4136,
  [4217] = 4186,
  [4218] = 4187,
  [4219] = 4175,
  [4220] = 3143,
  [4221] = 4221,
  [4222] = 4222,
  [4223] = 3145,
  [4224] = 3151,
  [4225] = 3154,
  [4226] = 4226,
  [4227] = 3704,
  [4228] = 4228,
  [4229] = 4158,
  [4230] = 4176,
  [4231] = 4231,
  [4232] = 4232,
  [4233] = 4233,
  [4234] = 4177,
  [4235] = 4235,
  [4236] = 4236,
  [4237] = 4237,
  [4238] = 4238,
  [4239] = 4239,
  [4240] = 4240,
  [4241] = 4241,
  [4242] = 4242,
  [4243] = 4221,
  [4244] = 4151,
  [4245] = 4222,
  [4246] = 4188,
  [4247] = 4154,
  [4248] = 4248,
  [4249] = 4249,
  [4250] = 4189,
  [4251] = 4190,
  [4252] = 4252,
  [4253] = 4253,
  [4254] = 4254,
  [4255] = 4255,
  [4256] = 3896,
  [4257] = 3966,
  [4258] = 3967,
  [4259] = 3968,
  [4260] = 3969,
  [4261] = 3970,
  [4262] = 3971,
  [4263] = 3972,
  [4264] = 3974,
  [4265] = 3975,
  [4266] = 4266,
  [4267] = 3726,
  [4268] = 4029,
  [4269] = 4030,
  [4270] = 4032,
  [4271] = 4035,
  [4272] = 3727,
  [4273] = 4054,
  [4274] = 4055,
  [4275] = 4056,
  [4276] = 3728,
  [4277] = 4058,
  [4278] = 3731,
  [4279] = 4064,
  [4280] = 4065,
  [4281] = 4066,
  [4282] = 4068,
  [4283] = 4069,
  [4284] = 3732,
  [4285] = 3733,
  [4286] = 3734,
  [4287] = 3735,
  [4288] = 3736,
  [4289] = 3737,
  [4290] = 3738,
  [4291] = 4093,
  [4292] = 4094,
  [4293] = 4095,
  [4294] = 3739,
  [4295] = 3740,
  [4296] = 3741,
  [4297] = 4103,
  [4298] = 4104,
  [4299] = 4105,
  [4300] = 4106,
  [4301] = 3742,
  [4302] = 4108,
  [4303] = 4109,
  [4304] = 4110,
  [4305] = 4111,
  [4306] = 3743,
  [4307] = 3744,
  [4308] = 3745,
  [4309] = 3746,
  [4310] = 3747,
  [4311] = 4138,
  [4312] = 3748,
  [4313] = 3749,
  [4314] = 3750,
  [4315] = 4174,
  [4316] = 4191,
  [4317] = 3751,
  [4318] = 4318,
  [4319] = 4319,
  [4320] = 4320,
  [4321] = 4321,
  [4322] = 4318,
  [4323] = 4319,
  [4324] = 4321,
  [4325] = 3682,
  [4326] = 4326,
  [4327] = 4327,
  [4328] = 1606,
  [4329] = 4329,
  [4330] = 4330,
  [4331] = 4331,
  [4332] = 4226,
  [4333] = 3546,
  [4334] = 4334,
  [4335] = 4335,
  [4336] = 4336,
  [4337] = 4337,
  [4338] = 4338,
  [4339] = 4339,
  [4340] = 3547,
  [4341] = 3548,
  [4342] = 3549,
  [4343] = 3550,
  [4344] = 3290,
  [4345] = 3291,
  [4346] = 3292,
  [4347] = 1557,
  [4348] = 3334,
  [4349] = 3572,
  [4350] = 4228,
  [4351] = 4351,
  [4352] = 3765,
  [4353] = 3766,
  [4354] = 3767,
  [4355] = 3768,
  [4356] = 3769,
  [4357] = 3770,
  [4358] = 3771,
  [4359] = 3772,
  [4360] = 3773,
  [4361] = 3777,
  [4362] = 3779,
  [4363] = 3781,
  [4364] = 3509,
  [4365] = 3783,
  [4366] = 3784,
  [4367] = 3785,
  [4368] = 3786,
  [4369] = 3787,
  [4370] = 3788,
  [4371] = 3789,
  [4372] = 3790,
  [4373] = 3791,
  [4374] = 4165,
  [4375] = 3792,
  [4376] = 3793,
  [4377] = 4089,
  [4378] = 3794,
  [4379] = 3795,
  [4380] = 3796,
  [4381] = 3724,
  [4382] = 3713,
  [4383] = 3511,
  [4384] = 3568,
  [4385] = 3721,
  [4386] = 3725,
  [4387] = 3752,
  [4388] = 3753,
  [4389] = 3754,
  [4390] = 3755,
  [4391] = 4327,
  [4392] = 3965,
  [4393] = 4126,
  [4394] = 4136,
  [4395] = 4226,
  [4396] = 4228,
  [4397] = 3574,
  [4398] = 4235,
  [4399] = 4236,
  [4400] = 4238,
  [4401] = 4239,
  [4402] = 4240,
  [4403] = 4241,
  [4404] = 4242,
  [4405] = 4329,
  [4406] = 4248,
  [4407] = 4249,
  [4408] = 1607,
  [4409] = 1608,
  [4410] = 1609,
  [4411] = 3896,
  [4412] = 3966,
  [4413] = 3968,
  [4414] = 3969,
  [4415] = 3970,
  [4416] = 3971,
  [4417] = 3972,
  [4418] = 3214,
  [4419] = 1599,
  [4420] = 3974,
  [4421] = 3975,
  [4422] = 4056,
  [4423] = 4058,
  [4424] = 4064,
  [4425] = 4065,
  [4426] = 4066,
  [4427] = 4068,
  [4428] = 4069,
  [4429] = 3311,
  [4430] = 4146,
  [4431] = 4105,
  [4432] = 4106,
  [4433] = 4108,
  [4434] = 4109,
  [4435] = 4110,
  [4436] = 4111,
  [4437] = 4165,
  [4438] = 4089,
  [4439] = 4126,
  [4440] = 4226,
  [4441] = 4228,
  [4442] = 3776,
  [4443] = 3510,
  [4444] = 4235,
  [4445] = 4242,
  [4446] = 3542,
  [4447] = 3570,
  [4448] = 3592,
  [4449] = 3593,
  [4450] = 3613,
  [4451] = 4248,
  [4452] = 4249,
  [4453] = 3633,
  [4454] = 3657,
  [4455] = 3660,
  [4456] = 3706,
  [4457] = 3896,
  [4458] = 3972,
  [4459] = 3707,
  [4460] = 3712,
  [4461] = 3716,
  [4462] = 3778,
  [4463] = 3974,
  [4464] = 3975,
  [4465] = 4058,
  [4466] = 4064,
  [4467] = 4065,
  [4468] = 4066,
  [4469] = 4068,
  [4470] = 4069,
  [4471] = 4106,
  [4472] = 4108,
  [4473] = 4109,
  [4474] = 4110,
  [4475] = 4111,
  [4476] = 3782,
  [4477] = 3612,
  [4478] = 3618,
  [4479] = 3619,
  [4480] = 3620,
  [4481] = 3622,
  [4482] = 3627,
  [4483] = 3628,
  [4484] = 4165,
  [4485] = 3634,
  [4486] = 3684,
  [4487] = 3764,
  [4488] = 3695,
  [4489] = 4089,
  [4490] = 3696,
  [4491] = 3697,
  [4492] = 3698,
  [4493] = 1600,
  [4494] = 1601,
  [4495] = 4126,
  [4496] = 4226,
  [4497] = 4235,
  [4498] = 3896,
  [4499] = 4330,
  [4500] = 4126,
  [4501] = 4059,
  [4502] = 4226,
  [4503] = 4126,
  [4504] = 4226,
  [4505] = 1602,
  [4506] = 4331,
  [4507] = 1610,
  [4508] = 1611,
  [4509] = 1612,
  [4510] = 1613,
  [4511] = 4126,
  [4512] = 1614,
  [4513] = 1615,
  [4514] = 4226,
  [4515] = 2830,
  [4516] = 2836,
  [4517] = 2870,
  [4518] = 2871,
  [4519] = 4126,
  [4520] = 2872,
  [4521] = 4226,
  [4522] = 3644,
  [4523] = 4160,
  [4524] = 3575,
  [4525] = 3577,
  [4526] = 3578,
  [4527] = 3617,
  [4528] = 3621,
  [4529] = 3626,
  [4530] = 3629,
  [4531] = 3635,
  [4532] = 3636,
  [4533] = 3656,
  [4534] = 3658,
  [4535] = 3659,
  [4536] = 4334,
  [4537] = 4335,
  [4538] = 1616,
  [4539] = 1617,
  [4540] = 1618,
  [4541] = 1619,
  [4542] = 4231,
  [4543] = 4232,
  [4544] = 4233,
  [4545] = 4145,
  [4546] = 3615,
  [4547] = 3761,
  [4548] = 4336,
  [4549] = 4337,
  [4550] = 1620,
  [4551] = 4338,
  [4552] = 4339,
  [4553] = 4161,
  [4554] = 4235,
  [4555] = 3665,
  [4556] = 3666,
  [4557] = 3668,
  [4558] = 3670,
  [4559] = 3671,
  [4560] = 3672,
  [4561] = 3673,
  [4562] = 3674,
  [4563] = 3675,
  [4564] = 3676,
  [4565] = 3677,
  [4566] = 3678,
  [4567] = 3679,
  [4568] = 3298,
  [4569] = 3299,
  [4570] = 3300,
  [4571] = 3301,
  [4572] = 3302,
  [4573] = 3303,
  [4574] = 3304,
  [4575] = 3305,
  [4576] = 3306,
  [4577] = 4236,
  [4578] = 4237,
  [4579] = 4238,
  [4580] = 4239,
  [4581] = 4240,
  [4582] = 4241,
  [4583] = 4242,
  [4584] = 3284,
  [4585] = 4248,
  [4586] = 4249,
  [4587] = 4587,
  [4588] = 4588,
  [4589] = 3703,
  [4590] = 3705,
  [4591] = 3709,
  [4592] = 3714,
  [4593] = 3718,
  [4594] = 2876,
  [4595] = 2879,
  [4596] = 2880,
  [4597] = 4148,
  [4598] = 3344,
  [4599] = 90,
  [4600] = 1604,
  [4601] = 1605,
  [4602] = 2912,
  [4603] = 2913,
  [4604] = 2914,
  [4605] = 4605,
  [4606] = 4252,
  [4607] = 4253,
  [4608] = 4254,
  [4609] = 4255,
  [4610] = 4610,
  [4611] = 3681,
  [4612] = 4612,
  [4613] = 4326,
  [4614] = 4614,
  [4615] = 1622,
  [4616] = 3351,
  [4617] = 3349,
  [4618] = 2627,
  [4619] = 2632,
  [4620] = 2630,
  [4621] = 2626,
  [4622] = 1623,
  [4623] = 2628,
  [4624] = 92,
  [4625] = 1731,
  [4626] = 1533,
  [4627] = 1535,
  [4628] = 1538,
  [4629] = 1539,
  [4630] = 1540,
  [4631] = 1541,
  [4632] = 1542,
  [4633] = 1543,
  [4634] = 1544,
  [4635] = 1534,
  [4636] = 96,
  [4637] = 3395,
  [4638] = 3429,
  [4639] = 3397,
  [4640] = 3385,
  [4641] = 4641,
  [4642] = 991,
  [4643] = 1004,
  [4644] = 3400,
  [4645] = 3401,
  [4646] = 3439,
  [4647] = 3399,
  [4648] = 3413,
  [4649] = 3414,
  [4650] = 3416,
  [4651] = 3444,
  [4652] = 3411,
  [4653] = 4653,
  [4654] = 3434,
  [4655] = 3421,
  [4656] = 3380,
  [4657] = 3389,
  [4658] = 4658,
  [4659] = 3426,
  [4660] = 3394,
  [4661] = 3398,
  [4662] = 3435,
  [4663] = 3423,
  [4664] = 3441,
  [4665] = 3442,
  [4666] = 3391,
  [4667] = 3392,
  [4668] = 3393,
  [4669] = 167,
  [4670] = 3420,
  [4671] = 4671,
  [4672] = 3436,
  [4673] = 4673,
  [4674] = 3440,
  [4675] = 3382,
  [4676] = 4676,
  [4677] = 3431,
  [4678] = 3432,
  [4679] = 3438,
  [4680] = 3408,
  [4681] = 3415,
  [4682] = 3433,
  [4683] = 3443,
  [4684] = 3378,
  [4685] = 4685,
  [4686] = 3386,
  [4687] = 4687,
  [4688] = 1008,
  [4689] = 4689,
  [4690] = 4687,
  [4691] = 4691,
  [4692] = 4692,
  [4693] = 4692,
  [4694] = 4689,
  [4695] = 4695,
  [4696] = 999,
  [4697] = 4697,
  [4698] = 4687,
  [4699] = 4699,
  [4700] = 4700,
  [4701] = 4692,
  [4702] = 4689,
  [4703] = 4695,
  [4704] = 4689,
  [4705] = 4697,
  [4706] = 4687,
  [4707] = 4699,
  [4708] = 4695,
  [4709] = 4700,
  [4710] = 4700,
  [4711] = 4692,
  [4712] = 1013,
  [4713] = 4700,
  [4714] = 4697,
  [4715] = 4697,
  [4716] = 4691,
  [4717] = 1007,
  [4718] = 2836,
  [4719] = 2870,
  [4720] = 2871,
  [4721] = 2872,
  [4722] = 2876,
  [4723] = 2879,
  [4724] = 2880,
  [4725] = 2912,
  [4726] = 2913,
  [4727] = 2914,
  [4728] = 2915,
  [4729] = 2924,
  [4730] = 2966,
  [4731] = 2969,
  [4732] = 2970,
  [4733] = 2979,
  [4734] = 2980,
  [4735] = 985,
  [4736] = 1003,
  [4737] = 1597,
  [4738] = 1598,
  [4739] = 1599,
  [4740] = 1600,
  [4741] = 1601,
  [4742] = 1602,
  [4743] = 1604,
  [4744] = 1605,
  [4745] = 1606,
  [4746] = 1607,
  [4747] = 1608,
  [4748] = 1609,
  [4749] = 1610,
  [4750] = 1611,
  [4751] = 1612,
  [4752] = 1613,
  [4753] = 1614,
  [4754] = 1615,
  [4755] = 1616,
  [4756] = 1617,
  [4757] = 2830,
  [4758] = 1619,
  [4759] = 1620,
  [4760] = 1244,
  [4761] = 4761,
  [4762] = 957,
  [4763] = 1014,
  [4764] = 1622,
  [4765] = 998,
  [4766] = 2910,
  [4767] = 2957,
  [4768] = 2958,
  [4769] = 3154,
  [4770] = 3038,
  [4771] = 3039,
  [4772] = 3074,
  [4773] = 3075,
  [4774] = 3076,
  [4775] = 3095,
  [4776] = 3096,
  [4777] = 3136,
  [4778] = 3147,
  [4779] = 1000,
  [4780] = 4780,
  [4781] = 1010,
  [4782] = 4782,
  [4783] = 3214,
  [4784] = 995,
  [4785] = 4785,
  [4786] = 4786,
  [4787] = 3151,
  [4788] = 1019,
  [4789] = 1028,
  [4790] = 1023,
  [4791] = 3161,
  [4792] = 3143,
  [4793] = 3145,
  [4794] = 1618,
  [4795] = 1005,
  [4796] = 4796,
  [4797] = 4797,
  [4798] = 4798,
  [4799] = 1002,
  [4800] = 1026,
  [4801] = 993,
  [4802] = 3545,
  [4803] = 1034,
  [4804] = 1033,
  [4805] = 1040,
  [4806] = 4806,
  [4807] = 4807,
  [4808] = 4808,
  [4809] = 4809,
  [4810] = 1006,
  [4811] = 1016,
  [4812] = 2627,
  [4813] = 2632,
  [4814] = 2630,
  [4815] = 2626,
  [4816] = 2628,
  [4817] = 1017,
  [4818] = 1009,
  [4819] = 1020,
  [4820] = 4820,
  [4821] = 4821,
  [4822] = 4822,
  [4823] = 1039,
  [4824] = 1022,
  [4825] = 1024,
  [4826] = 1027,
  [4827] = 1031,
  [4828] = 1032,
  [4829] = 1001,
  [4830] = 4830,
  [4831] = 1025,
  [4832] = 4832,
  [4833] = 4833,
  [4834] = 1038,
  [4835] = 1021,
  [4836] = 1011,
  [4837] = 3664,
  [4838] = 1035,
  [4839] = 1037,
  [4840] = 1029,
  [4841] = 1030,
  [4842] = 1036,
  [4843] = 1018,
  [4844] = 1015,
  [4845] = 4845,
  [4846] = 4846,
  [4847] = 4846,
  [4848] = 4848,
  [4849] = 4849,
  [4850] = 4849,
  [4851] = 4849,
  [4852] = 4852,
  [4853] = 4853,
  [4854] = 4854,
  [4855] = 4849,
  [4856] = 4780,
  [4857] = 4846,
  [4858] = 4858,
  [4859] = 3813,
  [4860] = 3839,
  [4861] = 4861,
  [4862] = 2216,
  [4863] = 4863,
  [4864] = 4864,
  [4865] = 4846,
  [4866] = 970,
  [4867] = 4861,
  [4868] = 4868,
  [4869] = 1000,
  [4870] = 977,
  [4871] = 4868,
  [4872] = 1012,
  [4873] = 4873,
  [4874] = 3883,
  [4875] = 4875,
  [4876] = 4876,
  [4877] = 4868,
  [4878] = 4878,
  [4879] = 4879,
  [4880] = 3872,
  [4881] = 4881,
  [4882] = 4882,
  [4883] = 4883,
  [4884] = 4884,
  [4885] = 4885,
  [4886] = 4886,
  [4887] = 4887,
  [4888] = 4888,
  [4889] = 4889,
  [4890] = 4882,
  [4891] = 4883,
  [4892] = 4888,
  [4893] = 4889,
  [4894] = 4884,
  [4895] = 4885,
  [4896] = 4886,
  [4897] = 4897,
  [4898] = 4882,
  [4899] = 4873,
  [4900] = 4875,
  [4901] = 4876,
  [4902] = 3880,
  [4903] = 4868,
  [4904] = 4878,
  [4905] = 4883,
  [4906] = 4906,
  [4907] = 4878,
  [4908] = 4879,
  [4909] = 4884,
  [4910] = 4885,
  [4911] = 4882,
  [4912] = 4883,
  [4913] = 4888,
  [4914] = 4889,
  [4915] = 3875,
  [4916] = 951,
  [4917] = 3885,
  [4918] = 4879,
  [4919] = 4888,
  [4920] = 4889,
  [4921] = 4878,
  [4922] = 975,
  [4923] = 984,
  [4924] = 992,
  [4925] = 4876,
  [4926] = 4879,
  [4927] = 987,
  [4928] = 4887,
  [4929] = 4878,
  [4930] = 4873,
  [4931] = 972,
  [4932] = 953,
  [4933] = 956,
  [4934] = 4934,
  [4935] = 3852,
  [4936] = 954,
  [4937] = 959,
  [4938] = 978,
  [4939] = 961,
  [4940] = 962,
  [4941] = 963,
  [4942] = 4884,
  [4943] = 4885,
  [4944] = 4886,
  [4945] = 4884,
  [4946] = 4885,
  [4947] = 4887,
  [4948] = 4886,
  [4949] = 4887,
  [4950] = 976,
  [4951] = 964,
  [4952] = 965,
  [4953] = 966,
  [4954] = 4875,
  [4955] = 967,
  [4956] = 167,
  [4957] = 4879,
  [4958] = 1004,
  [4959] = 4882,
  [4960] = 4883,
  [4961] = 968,
  [4962] = 969,
  [4963] = 974,
  [4964] = 4888,
  [4965] = 4889,
  [4966] = 4876,
  [4967] = 971,
  [4968] = 986,
  [4969] = 952,
  [4970] = 4873,
  [4971] = 960,
  [4972] = 997,
  [4973] = 973,
  [4974] = 4875,
  [4975] = 3916,
  [4976] = 1597,
  [4977] = 2957,
  [4978] = 1598,
  [4979] = 4605,
  [4980] = 4980,
  [4981] = 2958,
  [4982] = 1599,
  [4983] = 1600,
  [4984] = 4059,
  [4985] = 4610,
  [4986] = 3994,
  [4987] = 1601,
  [4988] = 1602,
  [4989] = 1604,
  [4990] = 1605,
  [4991] = 1606,
  [4992] = 1607,
  [4993] = 1608,
  [4994] = 1609,
  [4995] = 4995,
  [4996] = 1610,
  [4997] = 1611,
  [4998] = 3038,
  [4999] = 3039,
  [5000] = 3074,
  [5001] = 1612,
  [5002] = 3075,
  [5003] = 3076,
  [5004] = 3095,
  [5005] = 4612,
  [5006] = 4320,
  [5007] = 3096,
  [5008] = 3161,
  [5009] = 3904,
  [5010] = 3905,
  [5011] = 3906,
  [5012] = 3907,
  [5013] = 3908,
  [5014] = 3909,
  [5015] = 3910,
  [5016] = 3911,
  [5017] = 3912,
  [5018] = 3913,
  [5019] = 3914,
  [5020] = 3915,
  [5021] = 3917,
  [5022] = 3918,
  [5023] = 3919,
  [5024] = 3136,
  [5025] = 1613,
  [5026] = 3143,
  [5027] = 3145,
  [5028] = 3151,
  [5029] = 3154,
  [5030] = 1244,
  [5031] = 5031,
  [5032] = 3147,
  [5033] = 3214,
  [5034] = 2830,
  [5035] = 5035,
  [5036] = 2870,
  [5037] = 2871,
  [5038] = 1614,
  [5039] = 2872,
  [5040] = 3925,
  [5041] = 3926,
  [5042] = 3927,
  [5043] = 3928,
  [5044] = 3929,
  [5045] = 3930,
  [5046] = 3931,
  [5047] = 3932,
  [5048] = 3933,
  [5049] = 1615,
  [5050] = 2876,
  [5051] = 2879,
  [5052] = 2880,
  [5053] = 2912,
  [5054] = 2913,
  [5055] = 2914,
  [5056] = 1616,
  [5057] = 2915,
  [5058] = 3935,
  [5059] = 3936,
  [5060] = 3937,
  [5061] = 3938,
  [5062] = 3939,
  [5063] = 2924,
  [5064] = 2966,
  [5065] = 2969,
  [5066] = 2970,
  [5067] = 3995,
  [5068] = 2979,
  [5069] = 2980,
  [5070] = 3940,
  [5071] = 3996,
  [5072] = 1617,
  [5073] = 1618,
  [5074] = 1619,
  [5075] = 3943,
  [5076] = 3944,
  [5077] = 3945,
  [5078] = 3946,
  [5079] = 3947,
  [5080] = 3950,
  [5081] = 5081,
  [5082] = 3956,
  [5083] = 3960,
  [5084] = 5084,
  [5085] = 3997,
  [5086] = 1620,
  [5087] = 3993,
  [5088] = 3998,
  [5089] = 951,
  [5090] = 5090,
  [5091] = 2910,
  [5092] = 2836,
  [5093] = 3681,
  [5094] = 3315,
  [5095] = 3316,
  [5096] = 3317,
  [5097] = 3318,
  [5098] = 3319,
  [5099] = 3320,
  [5100] = 3321,
  [5101] = 3322,
  [5102] = 3323,
  [5103] = 3324,
  [5104] = 3566,
  [5105] = 3545,
  [5106] = 3546,
  [5107] = 3547,
  [5108] = 3548,
  [5109] = 3644,
  [5110] = 3549,
  [5111] = 3550,
  [5112] = 3290,
  [5113] = 3291,
  [5114] = 3292,
  [5115] = 3567,
  [5116] = 3572,
  [5117] = 3571,
  [5118] = 3664,
  [5119] = 3760,
  [5120] = 3553,
  [5121] = 3554,
  [5122] = 3555,
  [5123] = 3556,
  [5124] = 3557,
  [5125] = 3558,
  [5126] = 3559,
  [5127] = 3560,
  [5128] = 3561,
  [5129] = 3562,
  [5130] = 3563,
  [5131] = 3564,
  [5132] = 3565,
  [5133] = 3280,
  [5134] = 3665,
  [5135] = 3334,
  [5136] = 3666,
  [5137] = 3668,
  [5138] = 3670,
  [5139] = 3671,
  [5140] = 1557,
  [5141] = 3672,
  [5142] = 3673,
  [5143] = 3674,
  [5144] = 3675,
  [5145] = 3676,
  [5146] = 3677,
  [5147] = 5147,
  [5148] = 3579,
  [5149] = 3580,
  [5150] = 3581,
  [5151] = 3582,
  [5152] = 3583,
  [5153] = 3584,
  [5154] = 3585,
  [5155] = 3586,
  [5156] = 3587,
  [5157] = 3588,
  [5158] = 3589,
  [5159] = 3678,
  [5160] = 3590,
  [5161] = 3591,
  [5162] = 3326,
  [5163] = 3327,
  [5164] = 3328,
  [5165] = 3329,
  [5166] = 3679,
  [5167] = 3298,
  [5168] = 3299,
  [5169] = 3300,
  [5170] = 3301,
  [5171] = 3302,
  [5172] = 3303,
  [5173] = 3304,
  [5174] = 3305,
  [5175] = 3306,
  [5176] = 3595,
  [5177] = 3596,
  [5178] = 3597,
  [5179] = 3598,
  [5180] = 3599,
  [5181] = 3600,
  [5182] = 3601,
  [5183] = 3602,
  [5184] = 3603,
  [5185] = 3604,
  [5186] = 3605,
  [5187] = 3606,
  [5188] = 3607,
  [5189] = 3608,
  [5190] = 3609,
  [5191] = 3610,
  [5192] = 3611,
  [5193] = 3311,
  [5194] = 3574,
  [5195] = 3543,
  [5196] = 3544,
  [5197] = 3703,
  [5198] = 3705,
  [5199] = 3637,
  [5200] = 3638,
  [5201] = 3639,
  [5202] = 3640,
  [5203] = 3641,
  [5204] = 3709,
  [5205] = 3714,
  [5206] = 3718,
  [5207] = 3344,
  [5208] = 3515,
  [5209] = 3516,
  [5210] = 3517,
  [5211] = 3518,
  [5212] = 3704,
  [5213] = 3521,
  [5214] = 3522,
  [5215] = 3523,
  [5216] = 3524,
  [5217] = 3642,
  [5218] = 3643,
  [5219] = 3645,
  [5220] = 3647,
  [5221] = 3648,
  [5222] = 3649,
  [5223] = 3650,
  [5224] = 3651,
  [5225] = 3652,
  [5226] = 3653,
  [5227] = 3797,
  [5228] = 3654,
  [5229] = 3525,
  [5230] = 5230,
  [5231] = 3526,
  [5232] = 3527,
  [5233] = 3685,
  [5234] = 3686,
  [5235] = 3687,
  [5236] = 3688,
  [5237] = 3689,
  [5238] = 3690,
  [5239] = 3691,
  [5240] = 3692,
  [5241] = 3528,
  [5242] = 3530,
  [5243] = 3533,
  [5244] = 3520,
  [5245] = 3529,
  [5246] = 3694,
  [5247] = 3700,
  [5248] = 3701,
  [5249] = 3702,
  [5250] = 3726,
  [5251] = 3727,
  [5252] = 3728,
  [5253] = 3731,
  [5254] = 3732,
  [5255] = 3733,
  [5256] = 3734,
  [5257] = 3735,
  [5258] = 3736,
  [5259] = 3737,
  [5260] = 3738,
  [5261] = 3739,
  [5262] = 3741,
  [5263] = 3742,
  [5264] = 3743,
  [5265] = 3744,
  [5266] = 3745,
  [5267] = 3746,
  [5268] = 3747,
  [5269] = 3748,
  [5270] = 3749,
  [5271] = 3750,
  [5272] = 3751,
  [5273] = 3534,
  [5274] = 3531,
  [5275] = 3765,
  [5276] = 3766,
  [5277] = 3767,
  [5278] = 3768,
  [5279] = 3769,
  [5280] = 3770,
  [5281] = 3771,
  [5282] = 3772,
  [5283] = 3773,
  [5284] = 3777,
  [5285] = 3779,
  [5286] = 3781,
  [5287] = 3509,
  [5288] = 3783,
  [5289] = 3784,
  [5290] = 3785,
  [5291] = 3786,
  [5292] = 3787,
  [5293] = 3788,
  [5294] = 3789,
  [5295] = 3790,
  [5296] = 3791,
  [5297] = 3792,
  [5298] = 3793,
  [5299] = 3794,
  [5300] = 3795,
  [5301] = 3796,
  [5302] = 3724,
  [5303] = 3713,
  [5304] = 3511,
  [5305] = 3568,
  [5306] = 3721,
  [5307] = 3725,
  [5308] = 3752,
  [5309] = 3753,
  [5310] = 3754,
  [5311] = 3755,
  [5312] = 3532,
  [5313] = 3776,
  [5314] = 3510,
  [5315] = 3542,
  [5316] = 3570,
  [5317] = 3592,
  [5318] = 3593,
  [5319] = 3613,
  [5320] = 3633,
  [5321] = 3657,
  [5322] = 3660,
  [5323] = 3706,
  [5324] = 3707,
  [5325] = 3712,
  [5326] = 3716,
  [5327] = 3778,
  [5328] = 3782,
  [5329] = 3612,
  [5330] = 3618,
  [5331] = 3619,
  [5332] = 3620,
  [5333] = 3622,
  [5334] = 3627,
  [5335] = 3628,
  [5336] = 3634,
  [5337] = 3684,
  [5338] = 3764,
  [5339] = 3695,
  [5340] = 3696,
  [5341] = 3697,
  [5342] = 3698,
  [5343] = 3551,
  [5344] = 3682,
  [5345] = 3683,
  [5346] = 3575,
  [5347] = 3577,
  [5348] = 3578,
  [5349] = 3617,
  [5350] = 3621,
  [5351] = 3626,
  [5352] = 3629,
  [5353] = 3635,
  [5354] = 3636,
  [5355] = 3656,
  [5356] = 3658,
  [5357] = 3659,
  [5358] = 3693,
  [5359] = 3699,
  [5360] = 3615,
  [5361] = 3761,
  [5362] = 3708,
  [5363] = 3710,
  [5364] = 3711,
  [5365] = 3715,
  [5366] = 3717,
  [5367] = 3719,
  [5368] = 3552,
  [5369] = 3720,
  [5370] = 3723,
  [5371] = 3729,
  [5372] = 1622,
  [5373] = 1623,
  [5374] = 1731,
  [5375] = 3535,
  [5376] = 3536,
  [5377] = 3537,
  [5378] = 5378,
  [5379] = 3538,
  [5380] = 3539,
  [5381] = 3540,
  [5382] = 3541,
  [5383] = 3314,
  [5384] = 3763,
  [5385] = 5031,
  [5386] = 3680,
  [5387] = 5387,
  [5388] = 3740,
  [5389] = 957,
  [5390] = 5390,
  [5391] = 5391,
  [5392] = 5392,
  [5393] = 5393,
  [5394] = 5394,
  [5395] = 5395,
  [5396] = 995,
  [5397] = 5397,
  [5398] = 5398,
  [5399] = 5399,
  [5400] = 5400,
  [5401] = 1000,
  [5402] = 985,
  [5403] = 5403,
  [5404] = 5404,
  [5405] = 5405,
  [5406] = 5406,
  [5407] = 5407,
  [5408] = 5408,
  [5409] = 5409,
  [5410] = 5410,
  [5411] = 5411,
  [5412] = 5412,
  [5413] = 5413,
  [5414] = 5414,
  [5415] = 5415,
  [5416] = 5416,
  [5417] = 5417,
  [5418] = 5418,
  [5419] = 5419,
  [5420] = 5420,
  [5421] = 1006,
  [5422] = 1004,
  [5423] = 5423,
  [5424] = 5423,
  [5425] = 5425,
  [5426] = 5426,
  [5427] = 5427,
  [5428] = 5428,
  [5429] = 5429,
  [5430] = 5430,
  [5431] = 5425,
  [5432] = 5426,
  [5433] = 5427,
  [5434] = 5428,
  [5435] = 5429,
  [5436] = 5430,
  [5437] = 5425,
  [5438] = 5423,
  [5439] = 5426,
  [5440] = 5427,
  [5441] = 5428,
  [5442] = 5429,
  [5443] = 5423,
  [5444] = 5423,
  [5445] = 5423,
  [5446] = 3634,
  [5447] = 3145,
  [5448] = 3151,
  [5449] = 3154,
  [5450] = 3585,
  [5451] = 3590,
  [5452] = 3214,
  [5453] = 2830,
  [5454] = 3543,
  [5455] = 2836,
  [5456] = 3544,
  [5457] = 3704,
  [5458] = 3586,
  [5459] = 2870,
  [5460] = 2871,
  [5461] = 2872,
  [5462] = 3591,
  [5463] = 2876,
  [5464] = 3606,
  [5465] = 3607,
  [5466] = 3546,
  [5467] = 3547,
  [5468] = 3548,
  [5469] = 3549,
  [5470] = 2957,
  [5471] = 2958,
  [5472] = 3550,
  [5473] = 3572,
  [5474] = 1597,
  [5475] = 1598,
  [5476] = 1599,
  [5477] = 1600,
  [5478] = 3574,
  [5479] = 1601,
  [5480] = 1602,
  [5481] = 1604,
  [5482] = 1605,
  [5483] = 1606,
  [5484] = 1607,
  [5485] = 1608,
  [5486] = 1609,
  [5487] = 1610,
  [5488] = 1611,
  [5489] = 1612,
  [5490] = 3280,
  [5491] = 3038,
  [5492] = 1613,
  [5493] = 3039,
  [5494] = 1614,
  [5495] = 1615,
  [5496] = 3290,
  [5497] = 3291,
  [5498] = 1616,
  [5499] = 3292,
  [5500] = 3074,
  [5501] = 3075,
  [5502] = 3076,
  [5503] = 1617,
  [5504] = 1618,
  [5505] = 1619,
  [5506] = 1620,
  [5507] = 2879,
  [5508] = 1244,
  [5509] = 3644,
  [5510] = 3298,
  [5511] = 2880,
  [5512] = 1244,
  [5513] = 3299,
  [5514] = 3300,
  [5515] = 3301,
  [5516] = 3302,
  [5517] = 3303,
  [5518] = 3608,
  [5519] = 3609,
  [5520] = 3610,
  [5521] = 3304,
  [5522] = 3305,
  [5523] = 3306,
  [5524] = 3095,
  [5525] = 3096,
  [5526] = 3314,
  [5527] = 3315,
  [5528] = 3316,
  [5529] = 3317,
  [5530] = 3318,
  [5531] = 3611,
  [5532] = 3566,
  [5533] = 3319,
  [5534] = 3637,
  [5535] = 3638,
  [5536] = 3639,
  [5537] = 3640,
  [5538] = 3320,
  [5539] = 3641,
  [5540] = 3567,
  [5541] = 3642,
  [5542] = 3643,
  [5543] = 3645,
  [5544] = 3647,
  [5545] = 3321,
  [5546] = 3648,
  [5547] = 3649,
  [5548] = 3650,
  [5549] = 3322,
  [5550] = 3651,
  [5551] = 3323,
  [5552] = 3652,
  [5553] = 3653,
  [5554] = 3324,
  [5555] = 3136,
  [5556] = 3326,
  [5557] = 3797,
  [5558] = 3327,
  [5559] = 2912,
  [5560] = 3654,
  [5561] = 3328,
  [5562] = 3329,
  [5563] = 3147,
  [5564] = 3665,
  [5565] = 3666,
  [5566] = 3668,
  [5567] = 3685,
  [5568] = 2913,
  [5569] = 3670,
  [5570] = 3671,
  [5571] = 2914,
  [5572] = 3672,
  [5573] = 3686,
  [5574] = 3687,
  [5575] = 3673,
  [5576] = 3688,
  [5577] = 3689,
  [5578] = 3690,
  [5579] = 3674,
  [5580] = 3311,
  [5581] = 3675,
  [5582] = 3691,
  [5583] = 3692,
  [5584] = 3694,
  [5585] = 3700,
  [5586] = 3701,
  [5587] = 3702,
  [5588] = 3557,
  [5589] = 3558,
  [5590] = 2915,
  [5591] = 5591,
  [5592] = 993,
  [5593] = 3726,
  [5594] = 3727,
  [5595] = 2924,
  [5596] = 3728,
  [5597] = 2966,
  [5598] = 2969,
  [5599] = 3334,
  [5600] = 3676,
  [5601] = 2970,
  [5602] = 3731,
  [5603] = 3732,
  [5604] = 3733,
  [5605] = 3734,
  [5606] = 3735,
  [5607] = 3736,
  [5608] = 3737,
  [5609] = 3738,
  [5610] = 3739,
  [5611] = 3740,
  [5612] = 3741,
  [5613] = 3742,
  [5614] = 3743,
  [5615] = 3744,
  [5616] = 3745,
  [5617] = 995,
  [5618] = 3677,
  [5619] = 3531,
  [5620] = 3532,
  [5621] = 3678,
  [5622] = 3679,
  [5623] = 3515,
  [5624] = 3703,
  [5625] = 3705,
  [5626] = 3709,
  [5627] = 3714,
  [5628] = 3718,
  [5629] = 5629,
  [5630] = 5630,
  [5631] = 3516,
  [5632] = 3746,
  [5633] = 3747,
  [5634] = 2979,
  [5635] = 3748,
  [5636] = 3749,
  [5637] = 3750,
  [5638] = 3517,
  [5639] = 3751,
  [5640] = 3765,
  [5641] = 3766,
  [5642] = 3521,
  [5643] = 3767,
  [5644] = 3768,
  [5645] = 3769,
  [5646] = 3770,
  [5647] = 3771,
  [5648] = 3772,
  [5649] = 3773,
  [5650] = 3777,
  [5651] = 3779,
  [5652] = 3781,
  [5653] = 3509,
  [5654] = 2980,
  [5655] = 3559,
  [5656] = 3560,
  [5657] = 3561,
  [5658] = 1622,
  [5659] = 3551,
  [5660] = 3522,
  [5661] = 1623,
  [5662] = 3552,
  [5663] = 3595,
  [5664] = 3523,
  [5665] = 3783,
  [5666] = 3784,
  [5667] = 3785,
  [5668] = 3786,
  [5669] = 5669,
  [5670] = 957,
  [5671] = 3787,
  [5672] = 3788,
  [5673] = 3789,
  [5674] = 3524,
  [5675] = 3790,
  [5676] = 3791,
  [5677] = 3792,
  [5678] = 3525,
  [5679] = 3793,
  [5680] = 3794,
  [5681] = 3795,
  [5682] = 3796,
  [5683] = 3526,
  [5684] = 3527,
  [5685] = 985,
  [5686] = 3724,
  [5687] = 3587,
  [5688] = 3713,
  [5689] = 3511,
  [5690] = 3568,
  [5691] = 3721,
  [5692] = 3725,
  [5693] = 3752,
  [5694] = 3753,
  [5695] = 3754,
  [5696] = 3755,
  [5697] = 3143,
  [5698] = 3510,
  [5699] = 3542,
  [5700] = 3570,
  [5701] = 3592,
  [5702] = 3593,
  [5703] = 3613,
  [5704] = 3161,
  [5705] = 3633,
  [5706] = 3583,
  [5707] = 3657,
  [5708] = 3660,
  [5709] = 3706,
  [5710] = 3707,
  [5711] = 3712,
  [5712] = 3716,
  [5713] = 5713,
  [5714] = 3778,
  [5715] = 3782,
  [5716] = 3612,
  [5717] = 3618,
  [5718] = 3619,
  [5719] = 3620,
  [5720] = 3622,
  [5721] = 3627,
  [5722] = 3628,
  [5723] = 1620,
  [5724] = 3684,
  [5725] = 3764,
  [5726] = 3695,
  [5727] = 5727,
  [5728] = 3696,
  [5729] = 5729,
  [5730] = 3697,
  [5731] = 3698,
  [5732] = 3571,
  [5733] = 5733,
  [5734] = 3575,
  [5735] = 3577,
  [5736] = 3578,
  [5737] = 3617,
  [5738] = 3621,
  [5739] = 5739,
  [5740] = 3626,
  [5741] = 3629,
  [5742] = 3635,
  [5743] = 3636,
  [5744] = 3656,
  [5745] = 3658,
  [5746] = 3659,
  [5747] = 3615,
  [5748] = 3761,
  [5749] = 3528,
  [5750] = 3530,
  [5751] = 990,
  [5752] = 3533,
  [5753] = 3596,
  [5754] = 991,
  [5755] = 3597,
  [5756] = 3681,
  [5757] = 3682,
  [5758] = 3598,
  [5759] = 3599,
  [5760] = 5760,
  [5761] = 3683,
  [5762] = 3693,
  [5763] = 3699,
  [5764] = 3708,
  [5765] = 3534,
  [5766] = 3710,
  [5767] = 3535,
  [5768] = 3536,
  [5769] = 3161,
  [5770] = 3711,
  [5771] = 3715,
  [5772] = 3717,
  [5773] = 3719,
  [5774] = 3720,
  [5775] = 5775,
  [5776] = 3723,
  [5777] = 3600,
  [5778] = 988,
  [5779] = 989,
  [5780] = 5780,
  [5781] = 3729,
  [5782] = 3601,
  [5783] = 5783,
  [5784] = 3602,
  [5785] = 3603,
  [5786] = 3555,
  [5787] = 3588,
  [5788] = 3589,
  [5789] = 3562,
  [5790] = 3604,
  [5791] = 3763,
  [5792] = 3563,
  [5793] = 3564,
  [5794] = 3565,
  [5795] = 3680,
  [5796] = 3579,
  [5797] = 3580,
  [5798] = 3581,
  [5799] = 3537,
  [5800] = 3143,
  [5801] = 3145,
  [5802] = 3151,
  [5803] = 3154,
  [5804] = 3545,
  [5805] = 3214,
  [5806] = 2830,
  [5807] = 2836,
  [5808] = 2870,
  [5809] = 2871,
  [5810] = 2872,
  [5811] = 3664,
  [5812] = 2876,
  [5813] = 2879,
  [5814] = 2880,
  [5815] = 1731,
  [5816] = 2912,
  [5817] = 2913,
  [5818] = 2914,
  [5819] = 3538,
  [5820] = 2915,
  [5821] = 2924,
  [5822] = 3556,
  [5823] = 5823,
  [5824] = 3582,
  [5825] = 1597,
  [5826] = 2966,
  [5827] = 1598,
  [5828] = 1599,
  [5829] = 1600,
  [5830] = 3760,
  [5831] = 2969,
  [5832] = 2970,
  [5833] = 2979,
  [5834] = 2980,
  [5835] = 1601,
  [5836] = 1602,
  [5837] = 1604,
  [5838] = 1605,
  [5839] = 3605,
  [5840] = 951,
  [5841] = 3584,
  [5842] = 3539,
  [5843] = 1557,
  [5844] = 3722,
  [5845] = 3540,
  [5846] = 1606,
  [5847] = 3344,
  [5848] = 1607,
  [5849] = 3541,
  [5850] = 5850,
  [5851] = 5851,
  [5852] = 3518,
  [5853] = 1608,
  [5854] = 1609,
  [5855] = 1610,
  [5856] = 1611,
  [5857] = 1612,
  [5858] = 3520,
  [5859] = 3529,
  [5860] = 3553,
  [5861] = 1613,
  [5862] = 3554,
  [5863] = 1614,
  [5864] = 1615,
  [5865] = 1616,
  [5866] = 1617,
  [5867] = 1618,
  [5868] = 1619,
  [5869] = 2910,
  [5870] = 3776,
  [5871] = 966,
  [5872] = 984,
  [5873] = 978,
  [5874] = 987,
  [5875] = 5875,
  [5876] = 1006,
  [5877] = 987,
  [5878] = 999,
  [5879] = 1008,
  [5880] = 986,
  [5881] = 956,
  [5882] = 972,
  [5883] = 953,
  [5884] = 954,
  [5885] = 959,
  [5886] = 962,
  [5887] = 963,
  [5888] = 964,
  [5889] = 965,
  [5890] = 1013,
  [5891] = 986,
  [5892] = 968,
  [5893] = 992,
  [5894] = 969,
  [5895] = 970,
  [5896] = 971,
  [5897] = 997,
  [5898] = 973,
  [5899] = 974,
  [5900] = 975,
  [5901] = 961,
  [5902] = 976,
  [5903] = 952,
  [5904] = 977,
  [5905] = 984,
  [5906] = 960,
  [5907] = 961,
  [5908] = 4861,
  [5909] = 1011,
  [5910] = 960,
  [5911] = 967,
  [5912] = 5912,
  [5913] = 5913,
  [5914] = 5914,
  [5915] = 5915,
  [5916] = 5916,
  [5917] = 1010,
  [5918] = 5918,
  [5919] = 1002,
  [5920] = 1003,
  [5921] = 5921,
  [5922] = 5922,
  [5923] = 993,
  [5924] = 5924,
  [5925] = 5925,
  [5926] = 1012,
  [5927] = 5927,
  [5928] = 4854,
  [5929] = 1004,
  [5930] = 1005,
  [5931] = 1009,
  [5932] = 5932,
  [5933] = 5933,
  [5934] = 4864,
  [5935] = 5935,
  [5936] = 5936,
  [5937] = 5937,
  [5938] = 5938,
  [5939] = 5939,
  [5940] = 5940,
  [5941] = 5941,
  [5942] = 5942,
  [5943] = 5943,
  [5944] = 5944,
  [5945] = 5945,
  [5946] = 5946,
  [5947] = 5947,
  [5948] = 1014,
  [5949] = 1005,
  [5950] = 5950,
  [5951] = 5951,
  [5952] = 4845,
  [5953] = 5953,
  [5954] = 5954,
  [5955] = 1001,
  [5956] = 5956,
  [5957] = 5957,
  [5958] = 5958,
  [5959] = 1002,
  [5960] = 1003,
  [5961] = 5961,
  [5962] = 5958,
  [5963] = 5963,
  [5964] = 5964,
  [5965] = 1007,
  [5966] = 4848,
  [5967] = 988,
  [5968] = 2216,
  [5969] = 989,
  [5970] = 990,
  [5971] = 5971,
  [5972] = 1009,
  [5973] = 991,
  [5974] = 5916,
  [5975] = 5975,
  [5976] = 5976,
  [5977] = 5977,
  [5978] = 5978,
  [5979] = 5979,
  [5980] = 5980,
  [5981] = 5981,
  [5982] = 5982,
  [5983] = 5983,
  [5984] = 5984,
  [5985] = 4858,
  [5986] = 1001,
  [5987] = 4863,
  [5988] = 998,
  [5989] = 5989,
  [5990] = 5990,
  [5991] = 1015,
  [5992] = 5992,
  [5993] = 5993,
  [5994] = 5994,
  [5995] = 5995,
  [5996] = 5996,
  [5997] = 1034,
  [5998] = 5998,
  [5999] = 5999,
  [6000] = 6000,
  [6001] = 1040,
  [6002] = 6002,
  [6003] = 1031,
  [6004] = 1032,
  [6005] = 5993,
  [6006] = 6006,
  [6007] = 1033,
  [6008] = 6008,
  [6009] = 1027,
  [6010] = 5998,
  [6011] = 6011,
  [6012] = 6012,
  [6013] = 6013,
  [6014] = 5994,
  [6015] = 6015,
  [6016] = 6016,
  [6017] = 6017,
  [6018] = 6018,
  [6019] = 6012,
  [6020] = 6013,
  [6021] = 1029,
  [6022] = 972,
  [6023] = 954,
  [6024] = 956,
  [6025] = 959,
  [6026] = 962,
  [6027] = 963,
  [6028] = 964,
  [6029] = 965,
  [6030] = 1029,
  [6031] = 966,
  [6032] = 967,
  [6033] = 1030,
  [6034] = 5995,
  [6035] = 1030,
  [6036] = 1019,
  [6037] = 1028,
  [6038] = 1038,
  [6039] = 1023,
  [6040] = 1036,
  [6041] = 1020,
  [6042] = 1039,
  [6043] = 6043,
  [6044] = 1011,
  [6045] = 6018,
  [6046] = 960,
  [6047] = 961,
  [6048] = 1021,
  [6049] = 1019,
  [6050] = 986,
  [6051] = 5994,
  [6052] = 5995,
  [6053] = 5998,
  [6054] = 6054,
  [6055] = 6018,
  [6056] = 1028,
  [6057] = 6012,
  [6058] = 6013,
  [6059] = 6059,
  [6060] = 6018,
  [6061] = 6061,
  [6062] = 6012,
  [6063] = 968,
  [6064] = 969,
  [6065] = 970,
  [6066] = 971,
  [6067] = 997,
  [6068] = 973,
  [6069] = 6013,
  [6070] = 987,
  [6071] = 5995,
  [6072] = 5998,
  [6073] = 5992,
  [6074] = 6074,
  [6075] = 6018,
  [6076] = 6002,
  [6077] = 5992,
  [6078] = 6078,
  [6079] = 1040,
  [6080] = 1031,
  [6081] = 992,
  [6082] = 1032,
  [6083] = 979,
  [6084] = 6084,
  [6085] = 974,
  [6086] = 1033,
  [6087] = 980,
  [6088] = 6059,
  [6089] = 6089,
  [6090] = 6090,
  [6091] = 6091,
  [6092] = 1035,
  [6093] = 6093,
  [6094] = 975,
  [6095] = 976,
  [6096] = 952,
  [6097] = 977,
  [6098] = 6059,
  [6099] = 1025,
  [6100] = 5994,
  [6101] = 5995,
  [6102] = 5999,
  [6103] = 5998,
  [6104] = 978,
  [6105] = 5994,
  [6106] = 1026,
  [6107] = 6074,
  [6108] = 6108,
  [6109] = 6109,
  [6110] = 5995,
  [6111] = 6111,
  [6112] = 6112,
  [6113] = 6108,
  [6114] = 6114,
  [6115] = 6109,
  [6116] = 6116,
  [6117] = 6078,
  [6118] = 5998,
  [6119] = 6119,
  [6120] = 6002,
  [6121] = 6121,
  [6122] = 6002,
  [6123] = 6074,
  [6124] = 6108,
  [6125] = 6109,
  [6126] = 6111,
  [6127] = 6127,
  [6128] = 6112,
  [6129] = 6111,
  [6130] = 6112,
  [6131] = 5990,
  [6132] = 981,
  [6133] = 982,
  [6134] = 6134,
  [6135] = 6135,
  [6136] = 6018,
  [6137] = 6012,
  [6138] = 953,
  [6139] = 6078,
  [6140] = 1016,
  [6141] = 1023,
  [6142] = 6142,
  [6143] = 6012,
  [6144] = 6013,
  [6145] = 1036,
  [6146] = 5993,
  [6147] = 1022,
  [6148] = 6135,
  [6149] = 6089,
  [6150] = 6114,
  [6151] = 6116,
  [6152] = 6142,
  [6153] = 6002,
  [6154] = 6142,
  [6155] = 5999,
  [6156] = 6135,
  [6157] = 6089,
  [6158] = 6114,
  [6159] = 6116,
  [6160] = 6142,
  [6161] = 6135,
  [6162] = 6089,
  [6163] = 6114,
  [6164] = 6116,
  [6165] = 6142,
  [6166] = 6135,
  [6167] = 6089,
  [6168] = 6114,
  [6169] = 6116,
  [6170] = 6142,
  [6171] = 6135,
  [6172] = 6089,
  [6173] = 6114,
  [6174] = 6116,
  [6175] = 983,
  [6176] = 5993,
  [6177] = 1035,
  [6178] = 5994,
  [6179] = 1017,
  [6180] = 5990,
  [6181] = 984,
  [6182] = 1037,
  [6183] = 5990,
  [6184] = 1016,
  [6185] = 1018,
  [6186] = 1017,
  [6187] = 1015,
  [6188] = 1020,
  [6189] = 4881,
  [6190] = 1039,
  [6191] = 1024,
  [6192] = 6013,
  [6193] = 6193,
  [6194] = 6194,
  [6195] = 1018,
  [6196] = 6006,
  [6197] = 5990,
  [6198] = 5031,
  [6199] = 6084,
  [6200] = 6084,
  [6201] = 5996,
  [6202] = 5996,
  [6203] = 5996,
  [6204] = 1037,
  [6205] = 6205,
  [6206] = 6206,
  [6207] = 6207,
  [6208] = 6206,
  [6209] = 6209,
  [6210] = 6210,
  [6211] = 6209,
  [6212] = 1012,
  [6213] = 1004,
  [6214] = 6209,
  [6215] = 6215,
  [6216] = 6206,
  [6217] = 6217,
  [6218] = 6209,
  [6219] = 6219,
  [6220] = 6205,
  [6221] = 6206,
  [6222] = 6209,
  [6223] = 6205,
  [6224] = 6215,
  [6225] = 6205,
  [6226] = 6209,
  [6227] = 6206,
  [6228] = 6206,
  [6229] = 6229,
  [6230] = 6229,
  [6231] = 6231,
  [6232] = 6229,
  [6233] = 6210,
  [6234] = 6205,
  [6235] = 6209,
  [6236] = 6205,
  [6237] = 6205,
  [6238] = 6231,
  [6239] = 6210,
  [6240] = 6231,
  [6241] = 6205,
  [6242] = 6209,
  [6243] = 6215,
  [6244] = 6206,
  [6245] = 6206,
  [6246] = 6246,
  [6247] = 6247,
  [6248] = 6248,
  [6249] = 6249,
  [6250] = 6250,
  [6251] = 6251,
  [6252] = 6252,
  [6253] = 6247,
  [6254] = 6254,
  [6255] = 6247,
  [6256] = 6256,
  [6257] = 6257,
  [6258] = 6247,
  [6259] = 6259,
  [6260] = 6247,
  [6261] = 6247,
  [6262] = 6249,
  [6263] = 6263,
  [6264] = 6264,
  [6265] = 6265,
  [6266] = 5147,
  [6267] = 6259,
  [6268] = 6268,
  [6269] = 6269,
  [6270] = 970,
  [6271] = 6271,
  [6272] = 963,
  [6273] = 2216,
  [6274] = 975,
  [6275] = 6275,
  [6276] = 6276,
  [6277] = 6277,
  [6278] = 971,
  [6279] = 969,
  [6280] = 6277,
  [6281] = 6281,
  [6282] = 959,
  [6283] = 6283,
  [6284] = 952,
  [6285] = 6285,
  [6286] = 973,
  [6287] = 6285,
  [6288] = 6277,
  [6289] = 972,
  [6290] = 978,
  [6291] = 6291,
  [6292] = 6277,
  [6293] = 6277,
  [6294] = 997,
  [6295] = 6291,
  [6296] = 6285,
  [6297] = 6291,
  [6298] = 6285,
  [6299] = 6285,
  [6300] = 968,
  [6301] = 6285,
  [6302] = 6302,
  [6303] = 6277,
  [6304] = 964,
  [6305] = 6285,
  [6306] = 6306,
  [6307] = 974,
  [6308] = 954,
  [6309] = 956,
  [6310] = 6285,
  [6311] = 6285,
  [6312] = 6285,
  [6313] = 962,
  [6314] = 976,
  [6315] = 992,
  [6316] = 967,
  [6317] = 6317,
  [6318] = 953,
  [6319] = 965,
  [6320] = 6291,
  [6321] = 6277,
  [6322] = 5387,
  [6323] = 977,
  [6324] = 6324,
  [6325] = 993,
  [6326] = 966,
  [6327] = 6277,
  [6328] = 6328,
  [6329] = 1000,
  [6330] = 951,
  [6331] = 6331,
  [6332] = 5404,
  [6333] = 5413,
  [6334] = 5411,
  [6335] = 5414,
  [6336] = 5410,
  [6337] = 6337,
  [6338] = 6338,
  [6339] = 6338,
  [6340] = 6340,
  [6341] = 5403,
  [6342] = 5407,
  [6343] = 5408,
  [6344] = 6344,
  [6345] = 6337,
  [6346] = 6337,
  [6347] = 6337,
  [6348] = 6348,
  [6349] = 6348,
  [6350] = 5420,
  [6351] = 5405,
  [6352] = 6352,
  [6353] = 6353,
  [6354] = 6338,
  [6355] = 6337,
  [6356] = 6356,
  [6357] = 6344,
  [6358] = 6358,
  [6359] = 6340,
  [6360] = 6340,
  [6361] = 6340,
  [6362] = 6340,
  [6363] = 6340,
  [6364] = 6364,
  [6365] = 3883,
  [6366] = 1244,
  [6367] = 6367,
  [6368] = 3880,
  [6369] = 3875,
  [6370] = 3872,
  [6371] = 6371,
  [6372] = 1012,
  [6373] = 3885,
  [6374] = 6374,
  [6375] = 6375,
  [6376] = 6374,
  [6377] = 6377,
  [6378] = 6364,
  [6379] = 6375,
  [6380] = 6377,
  [6381] = 3769,
  [6382] = 4605,
  [6383] = 5629,
  [6384] = 5630,
  [6385] = 3637,
  [6386] = 3638,
  [6387] = 3639,
  [6388] = 3718,
  [6389] = 3640,
  [6390] = 5850,
  [6391] = 3641,
  [6392] = 3590,
  [6393] = 5851,
  [6394] = 3161,
  [6395] = 3521,
  [6396] = 985,
  [6397] = 3943,
  [6398] = 3143,
  [6399] = 3145,
  [6400] = 3151,
  [6401] = 3154,
  [6402] = 3522,
  [6403] = 3214,
  [6404] = 2830,
  [6405] = 2836,
  [6406] = 2870,
  [6407] = 2871,
  [6408] = 2872,
  [6409] = 3944,
  [6410] = 3945,
  [6411] = 2876,
  [6412] = 2879,
  [6413] = 2880,
  [6414] = 2912,
  [6415] = 2913,
  [6416] = 2914,
  [6417] = 3946,
  [6418] = 3947,
  [6419] = 2915,
  [6420] = 4610,
  [6421] = 2924,
  [6422] = 2966,
  [6423] = 2969,
  [6424] = 2970,
  [6425] = 3523,
  [6426] = 2979,
  [6427] = 2980,
  [6428] = 1622,
  [6429] = 1623,
  [6430] = 5760,
  [6431] = 3524,
  [6432] = 3525,
  [6433] = 3526,
  [6434] = 3527,
  [6435] = 957,
  [6436] = 3642,
  [6437] = 3596,
  [6438] = 3643,
  [6439] = 3645,
  [6440] = 3647,
  [6441] = 3648,
  [6442] = 3763,
  [6443] = 3649,
  [6444] = 3650,
  [6445] = 3651,
  [6446] = 3652,
  [6447] = 3653,
  [6448] = 3797,
  [6449] = 3654,
  [6450] = 3528,
  [6451] = 3280,
  [6452] = 3530,
  [6453] = 3290,
  [6454] = 3950,
  [6455] = 3291,
  [6456] = 3292,
  [6457] = 3685,
  [6458] = 3686,
  [6459] = 3687,
  [6460] = 3688,
  [6461] = 3298,
  [6462] = 3299,
  [6463] = 3300,
  [6464] = 3301,
  [6465] = 3302,
  [6466] = 3303,
  [6467] = 3304,
  [6468] = 3305,
  [6469] = 3306,
  [6470] = 3689,
  [6471] = 3314,
  [6472] = 3315,
  [6473] = 3316,
  [6474] = 3317,
  [6475] = 3318,
  [6476] = 3319,
  [6477] = 3320,
  [6478] = 3321,
  [6479] = 3322,
  [6480] = 3323,
  [6481] = 3324,
  [6482] = 4612,
  [6483] = 3690,
  [6484] = 3680,
  [6485] = 3326,
  [6486] = 3327,
  [6487] = 3328,
  [6488] = 3329,
  [6489] = 4320,
  [6490] = 3691,
  [6491] = 3692,
  [6492] = 3533,
  [6493] = 3993,
  [6494] = 3994,
  [6495] = 3534,
  [6496] = 3535,
  [6497] = 3536,
  [6498] = 3537,
  [6499] = 3311,
  [6500] = 3694,
  [6501] = 3700,
  [6502] = 3701,
  [6503] = 3702,
  [6504] = 3538,
  [6505] = 3334,
  [6506] = 3591,
  [6507] = 3597,
  [6508] = 3598,
  [6509] = 3553,
  [6510] = 1597,
  [6511] = 1598,
  [6512] = 1599,
  [6513] = 1600,
  [6514] = 1601,
  [6515] = 5733,
  [6516] = 1602,
  [6517] = 1604,
  [6518] = 1605,
  [6519] = 1606,
  [6520] = 1607,
  [6521] = 1608,
  [6522] = 1609,
  [6523] = 1610,
  [6524] = 1611,
  [6525] = 1612,
  [6526] = 1613,
  [6527] = 1614,
  [6528] = 1615,
  [6529] = 1616,
  [6530] = 1617,
  [6531] = 1618,
  [6532] = 1619,
  [6533] = 1620,
  [6534] = 3554,
  [6535] = 3555,
  [6536] = 6536,
  [6537] = 3726,
  [6538] = 3727,
  [6539] = 3728,
  [6540] = 3731,
  [6541] = 3732,
  [6542] = 3733,
  [6543] = 3734,
  [6544] = 3935,
  [6545] = 3735,
  [6546] = 3736,
  [6547] = 3737,
  [6548] = 3738,
  [6549] = 3599,
  [6550] = 1244,
  [6551] = 3739,
  [6552] = 3740,
  [6553] = 3995,
  [6554] = 3996,
  [6555] = 3997,
  [6556] = 3998,
  [6557] = 3741,
  [6558] = 3742,
  [6559] = 3743,
  [6560] = 3744,
  [6561] = 3936,
  [6562] = 3745,
  [6563] = 3746,
  [6564] = 3747,
  [6565] = 3748,
  [6566] = 3749,
  [6567] = 3937,
  [6568] = 3750,
  [6569] = 3600,
  [6570] = 3904,
  [6571] = 3905,
  [6572] = 3906,
  [6573] = 3907,
  [6574] = 3908,
  [6575] = 3545,
  [6576] = 3751,
  [6577] = 3556,
  [6578] = 3938,
  [6579] = 3909,
  [6580] = 3939,
  [6581] = 3910,
  [6582] = 3911,
  [6583] = 3912,
  [6584] = 3913,
  [6585] = 3914,
  [6586] = 3915,
  [6587] = 3956,
  [6588] = 3664,
  [6589] = 5775,
  [6590] = 3557,
  [6591] = 3558,
  [6592] = 5823,
  [6593] = 3559,
  [6594] = 3589,
  [6595] = 3917,
  [6596] = 3560,
  [6597] = 3940,
  [6598] = 3918,
  [6599] = 3561,
  [6600] = 3765,
  [6601] = 3766,
  [6602] = 3767,
  [6603] = 3768,
  [6604] = 3709,
  [6605] = 3770,
  [6606] = 3771,
  [6607] = 3772,
  [6608] = 3773,
  [6609] = 3777,
  [6610] = 3919,
  [6611] = 5669,
  [6612] = 3779,
  [6613] = 3781,
  [6614] = 3509,
  [6615] = 3783,
  [6616] = 3784,
  [6617] = 3785,
  [6618] = 3786,
  [6619] = 5783,
  [6620] = 3787,
  [6621] = 3788,
  [6622] = 3789,
  [6623] = 3790,
  [6624] = 3791,
  [6625] = 3792,
  [6626] = 3793,
  [6627] = 3794,
  [6628] = 3795,
  [6629] = 5739,
  [6630] = 3601,
  [6631] = 3796,
  [6632] = 3724,
  [6633] = 3713,
  [6634] = 3511,
  [6635] = 3568,
  [6636] = 3721,
  [6637] = 5727,
  [6638] = 3725,
  [6639] = 3752,
  [6640] = 3753,
  [6641] = 3754,
  [6642] = 3755,
  [6643] = 3562,
  [6644] = 3563,
  [6645] = 3564,
  [6646] = 3565,
  [6647] = 3776,
  [6648] = 3510,
  [6649] = 3542,
  [6650] = 3570,
  [6651] = 3592,
  [6652] = 3593,
  [6653] = 3613,
  [6654] = 3633,
  [6655] = 3602,
  [6656] = 3603,
  [6657] = 3657,
  [6658] = 3660,
  [6659] = 3706,
  [6660] = 3707,
  [6661] = 3712,
  [6662] = 3716,
  [6663] = 3778,
  [6664] = 3782,
  [6665] = 3612,
  [6666] = 3618,
  [6667] = 3619,
  [6668] = 3604,
  [6669] = 3620,
  [6670] = 3622,
  [6671] = 995,
  [6672] = 3960,
  [6673] = 3627,
  [6674] = 3628,
  [6675] = 3634,
  [6676] = 3684,
  [6677] = 3925,
  [6678] = 3764,
  [6679] = 3605,
  [6680] = 3606,
  [6681] = 3695,
  [6682] = 3696,
  [6683] = 3607,
  [6684] = 3608,
  [6685] = 3609,
  [6686] = 3697,
  [6687] = 3698,
  [6688] = 3539,
  [6689] = 3540,
  [6690] = 951,
  [6691] = 3545,
  [6692] = 3541,
  [6693] = 3926,
  [6694] = 3927,
  [6695] = 3928,
  [6696] = 3929,
  [6697] = 3930,
  [6698] = 3515,
  [6699] = 3516,
  [6700] = 3517,
  [6701] = 3518,
  [6702] = 3520,
  [6703] = 3529,
  [6704] = 3531,
  [6705] = 3532,
  [6706] = 3551,
  [6707] = 3575,
  [6708] = 3552,
  [6709] = 3566,
  [6710] = 3567,
  [6711] = 3571,
  [6712] = 3577,
  [6713] = 3578,
  [6714] = 3617,
  [6715] = 3621,
  [6716] = 3626,
  [6717] = 3931,
  [6718] = 3664,
  [6719] = 3629,
  [6720] = 3932,
  [6721] = 3933,
  [6722] = 3635,
  [6723] = 3636,
  [6724] = 3656,
  [6725] = 3658,
  [6726] = 3659,
  [6727] = 5713,
  [6728] = 3714,
  [6729] = 3610,
  [6730] = 3615,
  [6731] = 3761,
  [6732] = 3579,
  [6733] = 3681,
  [6734] = 3682,
  [6735] = 3580,
  [6736] = 3683,
  [6737] = 3581,
  [6738] = 3693,
  [6739] = 3699,
  [6740] = 3708,
  [6741] = 3710,
  [6742] = 3711,
  [6743] = 3715,
  [6744] = 3717,
  [6745] = 3719,
  [6746] = 3720,
  [6747] = 3723,
  [6748] = 3729,
  [6749] = 3582,
  [6750] = 3583,
  [6751] = 3584,
  [6752] = 3585,
  [6753] = 3611,
  [6754] = 3586,
  [6755] = 3587,
  [6756] = 3760,
  [6757] = 3595,
  [6758] = 3543,
  [6759] = 3544,
  [6760] = 3704,
  [6761] = 3546,
  [6762] = 3547,
  [6763] = 3548,
  [6764] = 3549,
  [6765] = 3550,
  [6766] = 3572,
  [6767] = 5729,
  [6768] = 3574,
  [6769] = 1557,
  [6770] = 3644,
  [6771] = 3588,
  [6772] = 3665,
  [6773] = 3666,
  [6774] = 3668,
  [6775] = 3670,
  [6776] = 3671,
  [6777] = 3672,
  [6778] = 3673,
  [6779] = 3344,
  [6780] = 3674,
  [6781] = 3675,
  [6782] = 3676,
  [6783] = 3677,
  [6784] = 3678,
  [6785] = 3679,
  [6786] = 3703,
  [6787] = 3705,
  [6788] = 3916,
  [6789] = 1731,
  [6790] = 984,
  [6791] = 1006,
  [6792] = 960,
  [6793] = 2627,
  [6794] = 2632,
  [6795] = 2630,
  [6796] = 986,
  [6797] = 2626,
  [6798] = 2628,
  [6799] = 961,
  [6800] = 987,
  [6801] = 6801,
  [6802] = 6802,
  [6803] = 1001,
  [6804] = 5925,
  [6805] = 5971,
  [6806] = 1003,
  [6807] = 6807,
  [6808] = 1009,
  [6809] = 6809,
  [6810] = 5913,
  [6811] = 1244,
  [6812] = 1244,
  [6813] = 6807,
  [6814] = 5918,
  [6815] = 5956,
  [6816] = 5957,
  [6817] = 5950,
  [6818] = 5951,
  [6819] = 6819,
  [6820] = 5989,
  [6821] = 989,
  [6822] = 5963,
  [6823] = 6823,
  [6824] = 1005,
  [6825] = 6825,
  [6826] = 6826,
  [6827] = 6802,
  [6828] = 991,
  [6829] = 1002,
  [6830] = 6830,
  [6831] = 6823,
  [6832] = 5937,
  [6833] = 5953,
  [6834] = 6834,
  [6835] = 988,
  [6836] = 6825,
  [6837] = 990,
  [6838] = 6809,
  [6839] = 5954,
  [6840] = 6840,
  [6841] = 1004,
  [6842] = 5922,
  [6843] = 6843,
  [6844] = 6830,
  [6845] = 6845,
  [6846] = 6194,
  [6847] = 1040,
  [6848] = 6193,
  [6849] = 6008,
  [6850] = 6121,
  [6851] = 6134,
  [6852] = 1019,
  [6853] = 1028,
  [6854] = 1023,
  [6855] = 1036,
  [6856] = 1031,
  [6857] = 1032,
  [6858] = 1020,
  [6859] = 1039,
  [6860] = 6860,
  [6861] = 1016,
  [6862] = 6054,
  [6863] = 6091,
  [6864] = 1037,
  [6865] = 6015,
  [6866] = 6119,
  [6867] = 1622,
  [6868] = 1623,
  [6869] = 1731,
  [6870] = 1018,
  [6871] = 5147,
  [6872] = 1017,
  [6873] = 1029,
  [6874] = 1015,
  [6875] = 1030,
  [6876] = 6876,
  [6877] = 1033,
  [6878] = 6016,
  [6879] = 6017,
  [6880] = 6043,
  [6881] = 6881,
  [6882] = 6882,
  [6883] = 1035,
  [6884] = 6884,
  [6885] = 1601,
  [6886] = 1597,
  [6887] = 1600,
  [6888] = 5921,
  [6889] = 6889,
  [6890] = 6890,
  [6891] = 6250,
  [6892] = 6892,
  [6893] = 5961,
  [6894] = 5915,
  [6895] = 1598,
  [6896] = 6256,
  [6897] = 6892,
  [6898] = 6890,
  [6899] = 6899,
  [6900] = 5935,
  [6901] = 5936,
  [6902] = 5938,
  [6903] = 5939,
  [6904] = 5940,
  [6905] = 6905,
  [6906] = 5941,
  [6907] = 5942,
  [6908] = 5943,
  [6909] = 5944,
  [6910] = 5945,
  [6911] = 5946,
  [6912] = 5947,
  [6913] = 3314,
  [6914] = 3315,
  [6915] = 3316,
  [6916] = 3317,
  [6917] = 3318,
  [6918] = 1622,
  [6919] = 1623,
  [6920] = 3319,
  [6921] = 3320,
  [6922] = 3321,
  [6923] = 3322,
  [6924] = 3323,
  [6925] = 3324,
  [6926] = 6268,
  [6927] = 1731,
  [6928] = 6892,
  [6929] = 6251,
  [6930] = 1599,
  [6931] = 6899,
  [6932] = 6899,
  [6933] = 6889,
  [6934] = 1602,
  [6935] = 6935,
  [6936] = 3298,
  [6937] = 3299,
  [6938] = 6890,
  [6939] = 6263,
  [6940] = 3326,
  [6941] = 3344,
  [6942] = 6889,
  [6943] = 3327,
  [6944] = 5933,
  [6945] = 3328,
  [6946] = 3329,
  [6947] = 1604,
  [6948] = 1605,
  [6949] = 6264,
  [6950] = 5924,
  [6951] = 5927,
  [6952] = 3300,
  [6953] = 3301,
  [6954] = 1606,
  [6955] = 1607,
  [6956] = 1608,
  [6957] = 1609,
  [6958] = 1610,
  [6959] = 6257,
  [6960] = 1611,
  [6961] = 1612,
  [6962] = 1613,
  [6963] = 1614,
  [6964] = 1615,
  [6965] = 5975,
  [6966] = 5976,
  [6967] = 5912,
  [6968] = 5977,
  [6969] = 5978,
  [6970] = 1616,
  [6971] = 6971,
  [6972] = 1617,
  [6973] = 3280,
  [6974] = 5979,
  [6975] = 5980,
  [6976] = 5981,
  [6977] = 5982,
  [6978] = 5983,
  [6979] = 5984,
  [6980] = 1618,
  [6981] = 6892,
  [6982] = 1619,
  [6983] = 6248,
  [6984] = 1620,
  [6985] = 6899,
  [6986] = 6889,
  [6987] = 6890,
  [6988] = 3302,
  [6989] = 3303,
  [6990] = 3304,
  [6991] = 3290,
  [6992] = 3291,
  [6993] = 3292,
  [6994] = 3305,
  [6995] = 3306,
  [6996] = 6889,
  [6997] = 3334,
  [6998] = 1244,
  [6999] = 6892,
  [7000] = 3311,
  [7001] = 6890,
  [7002] = 6899,
  [7003] = 5914,
  [7004] = 7004,
  [7005] = 7005,
  [7006] = 6302,
  [7007] = 7004,
  [7008] = 7004,
  [7009] = 7005,
  [7010] = 7010,
  [7011] = 7004,
  [7012] = 7005,
  [7013] = 7005,
  [7014] = 7005,
  [7015] = 7004,
  [7016] = 7004,
  [7017] = 7005,
  [7018] = 7005,
  [7019] = 7004,
  [7020] = 7020,
  [7021] = 7021,
  [7022] = 7022,
  [7023] = 3545,
  [7024] = 7024,
  [7025] = 2216,
  [7026] = 7026,
  [7027] = 3664,
  [7028] = 7028,
  [7029] = 1600,
  [7030] = 1622,
  [7031] = 1623,
  [7032] = 1601,
  [7033] = 1597,
  [7034] = 3151,
  [7035] = 3096,
  [7036] = 2970,
  [7037] = 3147,
  [7038] = 2979,
  [7039] = 2980,
  [7040] = 3161,
  [7041] = 2830,
  [7042] = 2912,
  [7043] = 3875,
  [7044] = 2836,
  [7045] = 3883,
  [7046] = 2870,
  [7047] = 1731,
  [7048] = 2913,
  [7049] = 2871,
  [7050] = 1244,
  [7051] = 3136,
  [7052] = 3880,
  [7053] = 2872,
  [7054] = 3872,
  [7055] = 2914,
  [7056] = 2969,
  [7057] = 1598,
  [7058] = 1599,
  [7059] = 1602,
  [7060] = 2957,
  [7061] = 2958,
  [7062] = 1604,
  [7063] = 1605,
  [7064] = 2876,
  [7065] = 1606,
  [7066] = 1607,
  [7067] = 1608,
  [7068] = 1609,
  [7069] = 3038,
  [7070] = 3039,
  [7071] = 1610,
  [7072] = 1611,
  [7073] = 2879,
  [7074] = 1612,
  [7075] = 1613,
  [7076] = 1614,
  [7077] = 2216,
  [7078] = 1615,
  [7079] = 1616,
  [7080] = 1617,
  [7081] = 1618,
  [7082] = 1619,
  [7083] = 1620,
  [7084] = 3074,
  [7085] = 3075,
  [7086] = 3076,
  [7087] = 3143,
  [7088] = 3145,
  [7089] = 3214,
  [7090] = 3154,
  [7091] = 2880,
  [7092] = 3885,
  [7093] = 2915,
  [7094] = 2924,
  [7095] = 2966,
  [7096] = 3095,
  [7097] = 2910,
  [7098] = 3927,
  [7099] = 3940,
  [7100] = 7100,
  [7101] = 7101,
  [7102] = 3907,
  [7103] = 3908,
  [7104] = 4610,
  [7105] = 7105,
  [7106] = 7106,
  [7107] = 7107,
  [7108] = 7108,
  [7109] = 3913,
  [7110] = 3909,
  [7111] = 4612,
  [7112] = 4320,
  [7113] = 7113,
  [7114] = 3994,
  [7115] = 7115,
  [7116] = 2627,
  [7117] = 7105,
  [7118] = 2632,
  [7119] = 3914,
  [7120] = 3915,
  [7121] = 3995,
  [7122] = 7100,
  [7123] = 7101,
  [7124] = 3996,
  [7125] = 4605,
  [7126] = 2630,
  [7127] = 7105,
  [7128] = 7128,
  [7129] = 7129,
  [7130] = 7130,
  [7131] = 7131,
  [7132] = 7113,
  [7133] = 7115,
  [7134] = 7134,
  [7135] = 7106,
  [7136] = 7107,
  [7137] = 7137,
  [7138] = 3997,
  [7139] = 3998,
  [7140] = 3944,
  [7141] = 3926,
  [7142] = 7108,
  [7143] = 7143,
  [7144] = 3916,
  [7145] = 2626,
  [7146] = 3956,
  [7147] = 3925,
  [7148] = 7101,
  [7149] = 2628,
  [7150] = 7150,
  [7151] = 7106,
  [7152] = 7107,
  [7153] = 3932,
  [7154] = 3906,
  [7155] = 7155,
  [7156] = 3910,
  [7157] = 6536,
  [7158] = 3928,
  [7159] = 3929,
  [7160] = 3930,
  [7161] = 3950,
  [7162] = 3931,
  [7163] = 7128,
  [7164] = 7150,
  [7165] = 7165,
  [7166] = 7129,
  [7167] = 7167,
  [7168] = 7168,
  [7169] = 7113,
  [7170] = 7115,
  [7171] = 7165,
  [7172] = 7137,
  [7173] = 7143,
  [7174] = 7130,
  [7175] = 7150,
  [7176] = 7165,
  [7177] = 3933,
  [7178] = 3945,
  [7179] = 3946,
  [7180] = 3904,
  [7181] = 3960,
  [7182] = 7131,
  [7183] = 3917,
  [7184] = 7184,
  [7185] = 3936,
  [7186] = 3905,
  [7187] = 7100,
  [7188] = 7130,
  [7189] = 3947,
  [7190] = 3912,
  [7191] = 7191,
  [7192] = 3937,
  [7193] = 3919,
  [7194] = 7194,
  [7195] = 3938,
  [7196] = 3911,
  [7197] = 3993,
  [7198] = 3943,
  [7199] = 7131,
  [7200] = 7128,
  [7201] = 7129,
  [7202] = 7137,
  [7203] = 7203,
  [7204] = 7143,
  [7205] = 3918,
  [7206] = 3935,
  [7207] = 3939,
  [7208] = 7108,
  [7209] = 7209,
  [7210] = 2632,
  [7211] = 7211,
  [7212] = 7212,
  [7213] = 7211,
  [7214] = 2216,
  [7215] = 7215,
  [7216] = 7216,
  [7217] = 7211,
  [7218] = 6826,
  [7219] = 7219,
  [7220] = 2626,
  [7221] = 7219,
  [7222] = 7211,
  [7223] = 7223,
  [7224] = 7211,
  [7225] = 7225,
  [7226] = 2628,
  [7227] = 7227,
  [7228] = 7228,
  [7229] = 7219,
  [7230] = 7230,
  [7231] = 6819,
  [7232] = 7232,
  [7233] = 7219,
  [7234] = 7219,
  [7235] = 2627,
  [7236] = 2630,
  [7237] = 6881,
  [7238] = 7238,
  [7239] = 957,
  [7240] = 951,
  [7241] = 985,
  [7242] = 7242,
  [7243] = 995,
  [7244] = 6882,
  [7245] = 7245,
  [7246] = 6884,
  [7247] = 6845,
  [7248] = 7245,
  [7249] = 6876,
  [7250] = 6860,
  [7251] = 7242,
  [7252] = 986,
  [7253] = 1601,
  [7254] = 7254,
  [7255] = 1006,
  [7256] = 961,
  [7257] = 987,
  [7258] = 984,
  [7259] = 7259,
  [7260] = 960,
  [7261] = 1597,
  [7262] = 1600,
  [7263] = 1005,
  [7264] = 5946,
  [7265] = 7265,
  [7266] = 3324,
  [7267] = 1004,
  [7268] = 7268,
  [7269] = 5943,
  [7270] = 1609,
  [7271] = 7271,
  [7272] = 988,
  [7273] = 7273,
  [7274] = 989,
  [7275] = 990,
  [7276] = 7276,
  [7277] = 1009,
  [7278] = 991,
  [7279] = 1610,
  [7280] = 1611,
  [7281] = 5945,
  [7282] = 1612,
  [7283] = 1613,
  [7284] = 3344,
  [7285] = 7285,
  [7286] = 7286,
  [7287] = 7287,
  [7288] = 7288,
  [7289] = 1614,
  [7290] = 5947,
  [7291] = 5975,
  [7292] = 7292,
  [7293] = 5976,
  [7294] = 7294,
  [7295] = 5961,
  [7296] = 5912,
  [7297] = 5977,
  [7298] = 5978,
  [7299] = 6971,
  [7300] = 5979,
  [7301] = 1615,
  [7302] = 5980,
  [7303] = 7303,
  [7304] = 5924,
  [7305] = 3314,
  [7306] = 3315,
  [7307] = 3311,
  [7308] = 5927,
  [7309] = 5981,
  [7310] = 1616,
  [7311] = 1617,
  [7312] = 5982,
  [7313] = 5983,
  [7314] = 1618,
  [7315] = 7315,
  [7316] = 1619,
  [7317] = 5984,
  [7318] = 1607,
  [7319] = 6935,
  [7320] = 1620,
  [7321] = 3334,
  [7322] = 3320,
  [7323] = 7323,
  [7324] = 7324,
  [7325] = 3316,
  [7326] = 5935,
  [7327] = 7327,
  [7328] = 1029,
  [7329] = 1030,
  [7330] = 3318,
  [7331] = 5936,
  [7332] = 5938,
  [7333] = 7333,
  [7334] = 3326,
  [7335] = 5939,
  [7336] = 5933,
  [7337] = 7337,
  [7338] = 1001,
  [7339] = 5914,
  [7340] = 7340,
  [7341] = 5940,
  [7342] = 6905,
  [7343] = 5941,
  [7344] = 1598,
  [7345] = 5942,
  [7346] = 1602,
  [7347] = 7347,
  [7348] = 1002,
  [7349] = 3280,
  [7350] = 1003,
  [7351] = 5915,
  [7352] = 1244,
  [7353] = 7353,
  [7354] = 5921,
  [7355] = 1604,
  [7356] = 7356,
  [7357] = 1605,
  [7358] = 3290,
  [7359] = 3291,
  [7360] = 3292,
  [7361] = 3322,
  [7362] = 1608,
  [7363] = 3319,
  [7364] = 7364,
  [7365] = 3323,
  [7366] = 3327,
  [7367] = 7287,
  [7368] = 7288,
  [7369] = 3328,
  [7370] = 3329,
  [7371] = 3298,
  [7372] = 3299,
  [7373] = 3300,
  [7374] = 3301,
  [7375] = 3302,
  [7376] = 3303,
  [7377] = 3304,
  [7378] = 3305,
  [7379] = 3306,
  [7380] = 1599,
  [7381] = 1606,
  [7382] = 5944,
  [7383] = 3317,
  [7384] = 3321,
  [7385] = 1035,
  [7386] = 1015,
  [7387] = 6194,
  [7388] = 2216,
  [7389] = 7389,
  [7390] = 7390,
  [7391] = 1040,
  [7392] = 1031,
  [7393] = 1032,
  [7394] = 1033,
  [7395] = 7395,
  [7396] = 1018,
  [7397] = 6193,
  [7398] = 1016,
  [7399] = 1017,
  [7400] = 1019,
  [7401] = 1028,
  [7402] = 1023,
  [7403] = 1036,
  [7404] = 1020,
  [7405] = 1039,
  [7406] = 1037,
  [7407] = 7407,
  [7408] = 7408,
  [7409] = 7409,
  [7410] = 7409,
  [7411] = 7411,
  [7412] = 7412,
  [7413] = 7413,
  [7414] = 7414,
  [7415] = 7415,
  [7416] = 7413,
  [7417] = 7417,
  [7418] = 7418,
  [7419] = 7409,
  [7420] = 7420,
  [7421] = 7421,
  [7422] = 7413,
  [7423] = 7423,
  [7424] = 7424,
  [7425] = 7425,
  [7426] = 7426,
  [7427] = 7427,
  [7428] = 7408,
  [7429] = 7429,
  [7430] = 7412,
  [7431] = 7431,
  [7432] = 7432,
  [7433] = 7408,
  [7434] = 7434,
  [7435] = 7435,
  [7436] = 7436,
  [7437] = 7421,
  [7438] = 7425,
  [7439] = 7432,
  [7440] = 7440,
  [7441] = 7441,
  [7442] = 7442,
  [7443] = 7408,
  [7444] = 7444,
  [7445] = 7445,
  [7446] = 7446,
  [7447] = 7412,
  [7448] = 7448,
  [7449] = 7421,
  [7450] = 7421,
  [7451] = 7409,
  [7452] = 7452,
  [7453] = 7413,
  [7454] = 7425,
  [7455] = 7455,
  [7456] = 7456,
  [7457] = 7457,
  [7458] = 7423,
  [7459] = 7408,
  [7460] = 7421,
  [7461] = 7409,
  [7462] = 7408,
  [7463] = 7463,
  [7464] = 7464,
  [7465] = 7412,
  [7466] = 7413,
  [7467] = 7412,
  [7468] = 7468,
  [7469] = 7469,
  [7470] = 7408,
  [7471] = 7432,
  [7472] = 7472,
  [7473] = 1600,
  [7474] = 7472,
  [7475] = 7472,
  [7476] = 1601,
  [7477] = 7477,
  [7478] = 7478,
  [7479] = 7477,
  [7480] = 7238,
  [7481] = 7472,
  [7482] = 7472,
  [7483] = 7477,
  [7484] = 1597,
  [7485] = 7477,
  [7486] = 7486,
  [7487] = 7487,
  [7488] = 7477,
  [7489] = 2958,
  [7490] = 2969,
  [7491] = 3095,
  [7492] = 1610,
  [7493] = 1608,
  [7494] = 1611,
  [7495] = 7495,
  [7496] = 1601,
  [7497] = 1612,
  [7498] = 1609,
  [7499] = 3143,
  [7500] = 3145,
  [7501] = 1607,
  [7502] = 3151,
  [7503] = 2830,
  [7504] = 3154,
  [7505] = 2836,
  [7506] = 2870,
  [7507] = 1613,
  [7508] = 7508,
  [7509] = 3161,
  [7510] = 951,
  [7511] = 1604,
  [7512] = 1605,
  [7513] = 3038,
  [7514] = 3039,
  [7515] = 2957,
  [7516] = 1606,
  [7517] = 3096,
  [7518] = 1598,
  [7519] = 2910,
  [7520] = 1602,
  [7521] = 3074,
  [7522] = 1614,
  [7523] = 2970,
  [7524] = 3075,
  [7525] = 2966,
  [7526] = 2979,
  [7527] = 2871,
  [7528] = 1615,
  [7529] = 1616,
  [7530] = 2980,
  [7531] = 1617,
  [7532] = 2879,
  [7533] = 3136,
  [7534] = 2880,
  [7535] = 7535,
  [7536] = 2872,
  [7537] = 1618,
  [7538] = 1597,
  [7539] = 2912,
  [7540] = 2913,
  [7541] = 1600,
  [7542] = 3076,
  [7543] = 1619,
  [7544] = 1620,
  [7545] = 2914,
  [7546] = 7546,
  [7547] = 7547,
  [7548] = 7548,
  [7549] = 7254,
  [7550] = 2915,
  [7551] = 3214,
  [7552] = 1599,
  [7553] = 2924,
  [7554] = 1244,
  [7555] = 3147,
  [7556] = 7259,
  [7557] = 2876,
  [7558] = 2914,
  [7559] = 2879,
  [7560] = 7273,
  [7561] = 1620,
  [7562] = 3136,
  [7563] = 7563,
  [7564] = 7265,
  [7565] = 2872,
  [7566] = 1611,
  [7567] = 1612,
  [7568] = 1613,
  [7569] = 1605,
  [7570] = 1598,
  [7571] = 3095,
  [7572] = 2880,
  [7573] = 3344,
  [7574] = 3039,
  [7575] = 1607,
  [7576] = 7353,
  [7577] = 1608,
  [7578] = 3147,
  [7579] = 1604,
  [7580] = 7315,
  [7581] = 3161,
  [7582] = 2957,
  [7583] = 7583,
  [7584] = 2915,
  [7585] = 2958,
  [7586] = 2912,
  [7587] = 2924,
  [7588] = 3096,
  [7589] = 2913,
  [7590] = 1614,
  [7591] = 3074,
  [7592] = 7276,
  [7593] = 1615,
  [7594] = 2910,
  [7595] = 3075,
  [7596] = 1599,
  [7597] = 1616,
  [7598] = 3143,
  [7599] = 2979,
  [7600] = 3145,
  [7601] = 1606,
  [7602] = 3151,
  [7603] = 3154,
  [7604] = 2966,
  [7605] = 1609,
  [7606] = 1610,
  [7607] = 7292,
  [7608] = 2969,
  [7609] = 1617,
  [7610] = 3214,
  [7611] = 2970,
  [7612] = 7347,
  [7613] = 7356,
  [7614] = 3076,
  [7615] = 2980,
  [7616] = 2830,
  [7617] = 2836,
  [7618] = 2870,
  [7619] = 7619,
  [7620] = 1618,
  [7621] = 2876,
  [7622] = 1244,
  [7623] = 7285,
  [7624] = 7624,
  [7625] = 1619,
  [7626] = 7286,
  [7627] = 3038,
  [7628] = 2871,
  [7629] = 7629,
  [7630] = 1602,
  [7631] = 7631,
  [7632] = 7632,
  [7633] = 985,
  [7634] = 7634,
  [7635] = 7635,
  [7636] = 7636,
  [7637] = 7637,
  [7638] = 7638,
  [7639] = 7639,
  [7640] = 7640,
  [7641] = 7640,
  [7642] = 7642,
  [7643] = 7640,
  [7644] = 7644,
  [7645] = 7645,
  [7646] = 7632,
  [7647] = 7647,
  [7648] = 7636,
  [7649] = 7649,
  [7650] = 7650,
  [7651] = 7640,
  [7652] = 7652,
  [7653] = 7653,
  [7654] = 7632,
  [7655] = 7645,
  [7656] = 7656,
  [7657] = 7657,
  [7658] = 7644,
  [7659] = 7659,
  [7660] = 7632,
  [7661] = 957,
  [7662] = 7652,
  [7663] = 7649,
  [7664] = 7664,
  [7665] = 7665,
  [7666] = 7653,
  [7667] = 7667,
  [7668] = 7668,
  [7669] = 7669,
  [7670] = 7638,
  [7671] = 7671,
  [7672] = 7672,
  [7673] = 7640,
  [7674] = 7632,
  [7675] = 7640,
  [7676] = 7676,
  [7677] = 7677,
  [7678] = 995,
  [7679] = 7679,
  [7680] = 7680,
  [7681] = 7676,
  [7682] = 7649,
  [7683] = 7665,
  [7684] = 7680,
  [7685] = 7640,
  [7686] = 7665,
  [7687] = 3344,
  [7688] = 7652,
  [7689] = 3344,
  [7690] = 7690,
  [7691] = 7634,
  [7692] = 7640,
  [7693] = 7635,
  [7694] = 7645,
  [7695] = 7695,
  [7696] = 7637,
  [7697] = 7697,
  [7698] = 7640,
  [7699] = 7699,
  [7700] = 7645,
  [7701] = 7701,
  [7702] = 7702,
  [7703] = 7703,
  [7704] = 7653,
  [7705] = 7669,
  [7706] = 957,
  [7707] = 7656,
  [7708] = 7634,
  [7709] = 7640,
  [7710] = 7710,
  [7711] = 7711,
  [7712] = 7680,
  [7713] = 7634,
  [7714] = 7679,
  [7715] = 7679,
  [7716] = 7640,
  [7717] = 7638,
  [7718] = 7637,
  [7719] = 7719,
  [7720] = 7656,
  [7721] = 7640,
  [7722] = 7676,
  [7723] = 7723,
  [7724] = 7635,
  [7725] = 995,
  [7726] = 7639,
  [7727] = 7676,
  [7728] = 7680,
  [7729] = 7729,
  [7730] = 7636,
  [7731] = 7649,
  [7732] = 7732,
  [7733] = 7644,
  [7734] = 7656,
  [7735] = 7634,
  [7736] = 7644,
  [7737] = 7668,
  [7738] = 985,
  [7739] = 7645,
  [7740] = 7676,
  [7741] = 7637,
  [7742] = 7697,
  [7743] = 7653,
  [7744] = 7744,
  [7745] = 7745,
  [7746] = 7656,
  [7747] = 7747,
  [7748] = 7649,
  [7749] = 7749,
  [7750] = 7750,
  [7751] = 7751,
  [7752] = 7640,
  [7753] = 7669,
  [7754] = 7638,
  [7755] = 7635,
  [7756] = 7636,
  [7757] = 7665,
  [7758] = 7669,
  [7759] = 7680,
  [7760] = 7637,
  [7761] = 7638,
  [7762] = 7762,
  [7763] = 7763,
  [7764] = 7644,
  [7765] = 7636,
  [7766] = 7766,
  [7767] = 7665,
  [7768] = 7679,
  [7769] = 1006,
  [7770] = 7652,
  [7771] = 7640,
  [7772] = 7772,
  [7773] = 7773,
  [7774] = 7679,
  [7775] = 7652,
  [7776] = 7669,
  [7777] = 7653,
  [7778] = 7635,
  [7779] = 7779,
  [7780] = 7780,
  [7781] = 7781,
  [7782] = 7782,
  [7783] = 7783,
  [7784] = 7784,
  [7785] = 7785,
  [7786] = 7786,
  [7787] = 7787,
  [7788] = 7788,
  [7789] = 7789,
  [7790] = 7790,
  [7791] = 7791,
  [7792] = 7792,
  [7793] = 7793,
  [7794] = 7794,
  [7795] = 7795,
  [7796] = 7796,
  [7797] = 7797,
  [7798] = 7798,
  [7799] = 7799,
  [7800] = 7800,
  [7801] = 7801,
  [7802] = 7802,
  [7803] = 7803,
  [7804] = 7804,
  [7805] = 7805,
  [7806] = 7806,
  [7807] = 7807,
  [7808] = 7808,
  [7809] = 7809,
  [7810] = 7810,
  [7811] = 7811,
  [7812] = 7812,
  [7813] = 7813,
  [7814] = 7785,
  [7815] = 7815,
  [7816] = 7815,
  [7817] = 7817,
  [7818] = 7818,
  [7819] = 7817,
  [7820] = 7784,
  [7821] = 7818,
  [7822] = 7822,
  [7823] = 7823,
  [7824] = 7824,
  [7825] = 7825,
  [7826] = 7826,
  [7827] = 7827,
  [7828] = 7828,
  [7829] = 7829,
  [7830] = 7830,
  [7831] = 7831,
  [7832] = 7832,
  [7833] = 7833,
  [7834] = 7834,
  [7835] = 7835,
  [7836] = 7836,
  [7837] = 7837,
  [7838] = 7838,
  [7839] = 7822,
  [7840] = 7789,
  [7841] = 7790,
  [7842] = 7842,
  [7843] = 7843,
  [7844] = 7823,
  [7845] = 7845,
  [7846] = 7846,
  [7847] = 7786,
  [7848] = 7779,
  [7849] = 7787,
  [7850] = 7850,
  [7851] = 7851,
  [7852] = 7797,
  [7853] = 7798,
  [7854] = 7854,
  [7855] = 7855,
  [7856] = 7788,
  [7857] = 7857,
  [7858] = 7858,
  [7859] = 7797,
  [7860] = 7798,
  [7861] = 7861,
  [7862] = 7862,
  [7863] = 7863,
  [7864] = 7838,
  [7865] = 7851,
  [7866] = 7854,
  [7867] = 7867,
  [7868] = 7868,
  [7869] = 7780,
  [7870] = 7783,
  [7871] = 7784,
  [7872] = 7791,
  [7873] = 7792,
  [7874] = 7796,
  [7875] = 7799,
  [7876] = 7824,
  [7877] = 7800,
  [7878] = 7803,
  [7879] = 7804,
  [7880] = 7825,
  [7881] = 7807,
  [7882] = 7797,
  [7883] = 7798,
  [7884] = 7808,
  [7885] = 7809,
  [7886] = 7810,
  [7887] = 7811,
  [7888] = 7789,
  [7889] = 7812,
  [7890] = 7813,
  [7891] = 7790,
  [7892] = 7791,
  [7893] = 7792,
  [7894] = 7815,
  [7895] = 7817,
  [7896] = 7818,
  [7897] = 7822,
  [7898] = 7823,
  [7899] = 7867,
  [7900] = 7900,
  [7901] = 7901,
  [7902] = 7902,
  [7903] = 7793,
  [7904] = 7794,
  [7905] = 7824,
  [7906] = 7825,
  [7907] = 7795,
  [7908] = 7797,
  [7909] = 7798,
  [7910] = 7850,
  [7911] = 7828,
  [7912] = 7829,
  [7913] = 7842,
  [7914] = 7868,
  [7915] = 7843,
  [7916] = 7796,
  [7917] = 7834,
  [7918] = 7835,
  [7919] = 7789,
  [7920] = 7790,
  [7921] = 7842,
  [7922] = 7843,
  [7923] = 7797,
  [7924] = 7798,
  [7925] = 7861,
  [7926] = 7862,
  [7927] = 7863,
  [7928] = 7838,
  [7929] = 7842,
  [7930] = 7851,
  [7931] = 7854,
  [7932] = 7867,
  [7933] = 7843,
  [7934] = 7868,
  [7935] = 7780,
  [7936] = 7784,
  [7937] = 7937,
  [7938] = 7791,
  [7939] = 7792,
  [7940] = 7799,
  [7941] = 7800,
  [7942] = 7942,
  [7943] = 7803,
  [7944] = 7804,
  [7945] = 7807,
  [7946] = 7808,
  [7947] = 7809,
  [7948] = 7799,
  [7949] = 7810,
  [7950] = 7811,
  [7951] = 7812,
  [7952] = 7813,
  [7953] = 7953,
  [7954] = 7815,
  [7955] = 7955,
  [7956] = 7827,
  [7957] = 7817,
  [7958] = 7818,
  [7959] = 7822,
  [7960] = 7823,
  [7961] = 7828,
  [7962] = 7824,
  [7963] = 7825,
  [7964] = 7829,
  [7965] = 7828,
  [7966] = 7829,
  [7967] = 7797,
  [7968] = 7798,
  [7969] = 7969,
  [7970] = 7970,
  [7971] = 7971,
  [7972] = 7834,
  [7973] = 7835,
  [7974] = 7797,
  [7975] = 7798,
  [7976] = 7976,
  [7977] = 7977,
  [7978] = 7978,
  [7979] = 7979,
  [7980] = 7800,
  [7981] = 7861,
  [7982] = 7862,
  [7983] = 7863,
  [7984] = 7838,
  [7985] = 7851,
  [7986] = 7854,
  [7987] = 7867,
  [7988] = 7988,
  [7989] = 7868,
  [7990] = 7780,
  [7991] = 7784,
  [7992] = 7791,
  [7993] = 7792,
  [7994] = 7799,
  [7995] = 7800,
  [7996] = 7803,
  [7997] = 7804,
  [7998] = 7807,
  [7999] = 7808,
  [8000] = 7810,
  [8001] = 7811,
  [8002] = 7812,
  [8003] = 7813,
  [8004] = 7815,
  [8005] = 7817,
  [8006] = 7822,
  [8007] = 7823,
  [8008] = 7824,
  [8009] = 7828,
  [8010] = 7829,
  [8011] = 8011,
  [8012] = 7834,
  [8013] = 7835,
  [8014] = 7797,
  [8015] = 7798,
  [8016] = 7838,
  [8017] = 7867,
  [8018] = 7780,
  [8019] = 7784,
  [8020] = 8020,
  [8021] = 7791,
  [8022] = 7792,
  [8023] = 7799,
  [8024] = 7803,
  [8025] = 7804,
  [8026] = 7808,
  [8027] = 7810,
  [8028] = 7817,
  [8029] = 7801,
  [8030] = 7834,
  [8031] = 7835,
  [8032] = 7838,
  [8033] = 7867,
  [8034] = 7780,
  [8035] = 7784,
  [8036] = 8036,
  [8037] = 7791,
  [8038] = 7792,
  [8039] = 7799,
  [8040] = 7803,
  [8041] = 7804,
  [8042] = 7830,
  [8043] = 7810,
  [8044] = 7838,
  [8045] = 7867,
  [8046] = 7780,
  [8047] = 7784,
  [8048] = 8048,
  [8049] = 7799,
  [8050] = 7810,
  [8051] = 7867,
  [8052] = 7784,
  [8053] = 7799,
  [8054] = 7810,
  [8055] = 7867,
  [8056] = 7784,
  [8057] = 7799,
  [8058] = 7810,
  [8059] = 7867,
  [8060] = 7784,
  [8061] = 7799,
  [8062] = 7810,
  [8063] = 7867,
  [8064] = 7784,
  [8065] = 7799,
  [8066] = 7810,
  [8067] = 8067,
  [8068] = 7861,
  [8069] = 7901,
  [8070] = 7862,
  [8071] = 7846,
  [8072] = 8072,
  [8073] = 8073,
  [8074] = 8074,
  [8075] = 8048,
  [8076] = 7797,
  [8077] = 7798,
  [8078] = 8078,
  [8079] = 8079,
  [8080] = 7831,
  [8081] = 8081,
  [8082] = 8082,
  [8083] = 8083,
  [8084] = 7803,
  [8085] = 7804,
  [8086] = 8086,
  [8087] = 8067,
  [8088] = 7805,
  [8089] = 8067,
  [8090] = 7806,
  [8091] = 7901,
  [8092] = 7797,
  [8093] = 7798,
  [8094] = 7863,
  [8095] = 7832,
  [8096] = 8067,
  [8097] = 7901,
  [8098] = 7833,
  [8099] = 7797,
  [8100] = 8067,
  [8101] = 7798,
  [8102] = 7901,
  [8103] = 8067,
  [8104] = 7901,
  [8105] = 8105,
  [8106] = 7834,
  [8107] = 7835,
  [8108] = 8108,
  [8109] = 8067,
  [8110] = 7901,
  [8111] = 8111,
  [8112] = 7807,
  [8113] = 8067,
  [8114] = 7901,
  [8115] = 8115,
  [8116] = 8067,
  [8117] = 7901,
  [8118] = 8067,
  [8119] = 7901,
  [8120] = 8120,
  [8121] = 8067,
  [8122] = 7901,
  [8123] = 7808,
  [8124] = 7809,
  [8125] = 8067,
  [8126] = 7901,
  [8127] = 8127,
  [8128] = 7810,
  [8129] = 7988,
  [8130] = 8130,
  [8131] = 7836,
  [8132] = 7780,
  [8133] = 7837,
  [8134] = 7811,
  [8135] = 7797,
  [8136] = 7798,
  [8137] = 8120,
  [8138] = 7953,
  [8139] = 7955,
  [8140] = 7826,
  [8141] = 8105,
  [8142] = 8108,
  [8143] = 7979,
  [8144] = 8083,
  [8145] = 8105,
  [8146] = 8108,
  [8147] = 8105,
  [8148] = 8148,
  [8149] = 8149,
  [8150] = 8150,
  [8151] = 8151,
  [8152] = 8152,
  [8153] = 7781,
  [8154] = 7861,
  [8155] = 7862,
  [8156] = 7782,
  [8157] = 7812,
  [8158] = 8158,
  [8159] = 7863,
  [8160] = 7813,
  [8161] = 7797,
  [8162] = 7798,
  [8163] = 8151,
  [8164] = 7838,
  [8165] = 7851,
  [8166] = 7854,
  [8167] = 7867,
  [8168] = 8130,
  [8169] = 7868,
  [8170] = 7976,
  [8171] = 7783,
  [8172] = 8073,
  [8173] = 8074,
  [8174] = 7825,
  [8175] = 8175,
  [8176] = 8176,
  [8177] = 8177,
  [8178] = 8178,
  [8179] = 8179,
  [8180] = 8176,
  [8181] = 8175,
  [8182] = 8182,
  [8183] = 8183,
  [8184] = 8176,
  [8185] = 8185,
  [8186] = 8182,
  [8187] = 8187,
  [8188] = 8188,
  [8189] = 8189,
  [8190] = 960,
  [8191] = 8178,
  [8192] = 961,
  [8193] = 8193,
  [8194] = 8194,
  [8195] = 8193,
  [8196] = 8194,
  [8197] = 8197,
  [8198] = 8198,
  [8199] = 8199,
  [8200] = 8200,
  [8201] = 8176,
  [8202] = 8202,
  [8203] = 986,
  [8204] = 987,
  [8205] = 8205,
  [8206] = 8175,
  [8207] = 8182,
  [8208] = 8177,
  [8209] = 8194,
  [8210] = 8179,
  [8211] = 8211,
  [8212] = 8212,
  [8213] = 8193,
  [8214] = 984,
  [8215] = 8198,
  [8216] = 8216,
  [8217] = 8217,
  [8218] = 8199,
  [8219] = 3545,
  [8220] = 8176,
  [8221] = 8221,
  [8222] = 8222,
  [8223] = 8223,
  [8224] = 8224,
  [8225] = 8193,
  [8226] = 8178,
  [8227] = 6119,
  [8228] = 8194,
  [8229] = 8229,
  [8230] = 8183,
  [8231] = 8231,
  [8232] = 957,
  [8233] = 8183,
  [8234] = 8175,
  [8235] = 8235,
  [8236] = 8236,
  [8237] = 8205,
  [8238] = 8177,
  [8239] = 8179,
  [8240] = 8240,
  [8241] = 8241,
  [8242] = 3664,
  [8243] = 8182,
  [8244] = 8244,
  [8245] = 8245,
  [8246] = 8194,
  [8247] = 8193,
  [8248] = 8194,
  [8249] = 8249,
  [8250] = 8176,
  [8251] = 6054,
  [8252] = 995,
  [8253] = 8182,
  [8254] = 8254,
  [8255] = 8176,
  [8256] = 8256,
  [8257] = 8257,
  [8258] = 8182,
  [8259] = 8205,
  [8260] = 8178,
  [8261] = 8178,
  [8262] = 8205,
  [8263] = 8183,
  [8264] = 8264,
  [8265] = 8265,
  [8266] = 8183,
  [8267] = 8183,
  [8268] = 8175,
  [8269] = 8205,
  [8270] = 8211,
  [8271] = 8271,
  [8272] = 8177,
  [8273] = 8179,
  [8274] = 8176,
  [8275] = 8275,
  [8276] = 8182,
  [8277] = 8277,
  [8278] = 8182,
  [8279] = 8279,
  [8280] = 8193,
  [8281] = 8264,
  [8282] = 8194,
  [8283] = 8176,
  [8284] = 8175,
  [8285] = 8178,
  [8286] = 8177,
  [8287] = 8277,
  [8288] = 8264,
  [8289] = 8178,
  [8290] = 8205,
  [8291] = 8277,
  [8292] = 8264,
  [8293] = 8177,
  [8294] = 951,
  [8295] = 8277,
  [8296] = 8264,
  [8297] = 8179,
  [8298] = 8277,
  [8299] = 8277,
  [8300] = 8300,
  [8301] = 8175,
  [8302] = 8182,
  [8303] = 8175,
  [8304] = 8176,
  [8305] = 8179,
  [8306] = 8178,
  [8307] = 8178,
  [8308] = 8205,
  [8309] = 8175,
  [8310] = 8182,
  [8311] = 8183,
  [8312] = 8176,
  [8313] = 8182,
  [8314] = 8178,
  [8315] = 8177,
  [8316] = 8179,
  [8317] = 8175,
  [8318] = 8182,
  [8319] = 8175,
  [8320] = 8176,
  [8321] = 8271,
  [8322] = 8178,
  [8323] = 8277,
  [8324] = 985,
  [8325] = 8175,
  [8326] = 8193,
  [8327] = 8178,
  [8328] = 8328,
  [8329] = 8329,
  [8330] = 8330,
  [8331] = 8331,
  [8332] = 8332,
  [8333] = 8333,
  [8334] = 8334,
  [8335] = 8335,
  [8336] = 8336,
  [8337] = 8337,
  [8338] = 8338,
  [8339] = 8339,
  [8340] = 8340,
  [8341] = 8341,
  [8342] = 8342,
  [8343] = 8343,
  [8344] = 8344,
  [8345] = 8345,
  [8346] = 8346,
  [8347] = 8347,
  [8348] = 8348,
  [8349] = 8349,
  [8350] = 8350,
  [8351] = 8351,
  [8352] = 8352,
  [8353] = 8353,
  [8354] = 8354,
  [8355] = 8355,
  [8356] = 8356,
  [8357] = 8357,
  [8358] = 8358,
  [8359] = 8359,
  [8360] = 8360,
  [8361] = 8361,
  [8362] = 960,
  [8363] = 8363,
  [8364] = 8364,
  [8365] = 8365,
  [8366] = 961,
  [8367] = 8367,
  [8368] = 8368,
  [8369] = 8369,
  [8370] = 8370,
  [8371] = 8371,
  [8372] = 8372,
  [8373] = 8336,
  [8374] = 8337,
  [8375] = 8339,
  [8376] = 8340,
  [8377] = 8377,
  [8378] = 8342,
  [8379] = 8379,
  [8380] = 8380,
  [8381] = 8346,
  [8382] = 986,
  [8383] = 8383,
  [8384] = 8384,
  [8385] = 8385,
  [8386] = 8386,
  [8387] = 8387,
  [8388] = 1006,
  [8389] = 987,
  [8390] = 8390,
  [8391] = 8391,
  [8392] = 8336,
  [8393] = 1005,
  [8394] = 8394,
  [8395] = 8337,
  [8396] = 1029,
  [8397] = 1030,
  [8398] = 8336,
  [8399] = 8337,
  [8400] = 8339,
  [8401] = 8340,
  [8402] = 1001,
  [8403] = 8403,
  [8404] = 8336,
  [8405] = 8337,
  [8406] = 8339,
  [8407] = 8340,
  [8408] = 1002,
  [8409] = 1003,
  [8410] = 8336,
  [8411] = 8337,
  [8412] = 8412,
  [8413] = 8336,
  [8414] = 8337,
  [8415] = 8339,
  [8416] = 8340,
  [8417] = 8417,
  [8418] = 8418,
  [8419] = 8419,
  [8420] = 8420,
  [8421] = 8421,
  [8422] = 8336,
  [8423] = 8337,
  [8424] = 8339,
  [8425] = 8340,
  [8426] = 8426,
  [8427] = 8339,
  [8428] = 8421,
  [8429] = 8336,
  [8430] = 8337,
  [8431] = 8339,
  [8432] = 8340,
  [8433] = 8433,
  [8434] = 8434,
  [8435] = 8339,
  [8436] = 8340,
  [8437] = 8340,
  [8438] = 8438,
  [8439] = 8369,
  [8440] = 8340,
  [8441] = 8441,
  [8442] = 8442,
  [8443] = 8346,
  [8444] = 8340,
  [8445] = 8445,
  [8446] = 8446,
  [8447] = 8447,
  [8448] = 8342,
  [8449] = 8449,
  [8450] = 8450,
  [8451] = 8451,
  [8452] = 8452,
  [8453] = 8453,
  [8454] = 8454,
  [8455] = 8455,
  [8456] = 8456,
  [8457] = 8457,
  [8458] = 8458,
  [8459] = 8459,
  [8460] = 8460,
  [8461] = 8461,
  [8462] = 8342,
  [8463] = 8463,
  [8464] = 8339,
  [8465] = 8465,
  [8466] = 6054,
  [8467] = 8467,
  [8468] = 8468,
  [8469] = 8469,
  [8470] = 8346,
  [8471] = 8471,
  [8472] = 8472,
  [8473] = 8473,
  [8474] = 8474,
  [8475] = 8475,
  [8476] = 8476,
  [8477] = 8477,
  [8478] = 8478,
  [8479] = 8479,
  [8480] = 8361,
  [8481] = 8481,
  [8482] = 8482,
  [8483] = 6119,
  [8484] = 8484,
  [8485] = 8336,
  [8486] = 8458,
  [8487] = 8459,
  [8488] = 8460,
  [8489] = 8461,
  [8490] = 8490,
  [8491] = 8337,
  [8492] = 8492,
  [8493] = 8458,
  [8494] = 8494,
  [8495] = 8459,
  [8496] = 8496,
  [8497] = 8497,
  [8498] = 8460,
  [8499] = 8461,
  [8500] = 8500,
  [8501] = 8501,
  [8502] = 8502,
  [8503] = 8458,
  [8504] = 8459,
  [8505] = 8460,
  [8506] = 8461,
  [8507] = 8507,
  [8508] = 988,
  [8509] = 989,
  [8510] = 990,
  [8511] = 1009,
  [8512] = 991,
  [8513] = 1004,
  [8514] = 8514,
  [8515] = 8339,
  [8516] = 8516,
  [8517] = 8517,
  [8518] = 8518,
  [8519] = 8519,
  [8520] = 8520,
  [8521] = 8521,
  [8522] = 8522,
  [8523] = 8340,
  [8524] = 8524,
  [8525] = 8340,
  [8526] = 8524,
  [8527] = 8527,
  [8528] = 8528,
  [8529] = 8529,
  [8530] = 8530,
  [8531] = 8531,
  [8532] = 8532,
  [8533] = 8340,
  [8534] = 8534,
  [8535] = 8535,
  [8536] = 8536,
  [8537] = 8537,
  [8538] = 988,
  [8539] = 989,
  [8540] = 8540,
  [8541] = 8541,
  [8542] = 8542,
  [8543] = 8543,
  [8544] = 8544,
  [8545] = 8384,
  [8546] = 8445,
  [8547] = 8535,
  [8548] = 8548,
  [8549] = 8368,
  [8550] = 8456,
  [8551] = 8457,
  [8552] = 8484,
  [8553] = 8553,
  [8554] = 8465,
  [8555] = 8328,
  [8556] = 8475,
  [8557] = 8492,
  [8558] = 8534,
  [8559] = 8559,
  [8560] = 8343,
  [8561] = 8351,
  [8562] = 8359,
  [8563] = 8383,
  [8564] = 8363,
  [8565] = 984,
  [8566] = 8370,
  [8567] = 8379,
  [8568] = 8385,
  [8569] = 8569,
  [8570] = 8377,
  [8571] = 8571,
  [8572] = 8572,
  [8573] = 8387,
  [8574] = 8574,
  [8575] = 8575,
  [8576] = 8576,
  [8577] = 8383,
  [8578] = 8383,
  [8579] = 8383,
  [8580] = 8580,
  [8581] = 8581,
  [8582] = 8582,
  [8583] = 8494,
  [8584] = 8419,
  [8585] = 8471,
  [8586] = 8472,
  [8587] = 8587,
  [8588] = 8588,
  [8589] = 8589,
  [8590] = 8590,
  [8591] = 8591,
  [8592] = 8592,
  [8593] = 8593,
  [8594] = 8594,
  [8595] = 8595,
  [8596] = 8596,
  [8597] = 8597,
  [8598] = 8598,
  [8599] = 8599,
  [8600] = 8600,
  [8601] = 8601,
  [8602] = 8602,
  [8603] = 8603,
  [8604] = 8604,
  [8605] = 8605,
  [8606] = 8606,
  [8607] = 8329,
  [8608] = 8474,
  [8609] = 8609,
  [8610] = 8610,
  [8611] = 8611,
  [8612] = 8338,
  [8613] = 8348,
  [8614] = 8360,
  [8615] = 8412,
  [8616] = 8530,
  [8617] = 8344,
  [8618] = 8477,
  [8619] = 8490,
  [8620] = 8501,
  [8621] = 8502,
  [8622] = 8507,
  [8623] = 8609,
  [8624] = 8350,
  [8625] = 8357,
  [8626] = 8626,
  [8627] = 8390,
  [8628] = 8628,
  [8629] = 8496,
  [8630] = 8529,
  [8631] = 8631,
  [8632] = 8632,
  [8633] = 8494,
  [8634] = 8419,
  [8635] = 8471,
  [8636] = 8472,
  [8637] = 8587,
  [8638] = 8590,
  [8639] = 8591,
  [8640] = 8592,
  [8641] = 8593,
  [8642] = 8594,
  [8643] = 8596,
  [8644] = 8597,
  [8645] = 8598,
  [8646] = 8599,
  [8647] = 8600,
  [8648] = 8601,
  [8649] = 8602,
  [8650] = 8603,
  [8651] = 8604,
  [8652] = 8605,
  [8653] = 8606,
  [8654] = 8329,
  [8655] = 8474,
  [8656] = 8609,
  [8657] = 8610,
  [8658] = 8611,
  [8659] = 8338,
  [8660] = 8348,
  [8661] = 8360,
  [8662] = 8412,
  [8663] = 8530,
  [8664] = 8490,
  [8665] = 8501,
  [8666] = 8502,
  [8667] = 8507,
  [8668] = 8610,
  [8669] = 8494,
  [8670] = 8419,
  [8671] = 8471,
  [8672] = 8601,
  [8673] = 8602,
  [8674] = 8603,
  [8675] = 8604,
  [8676] = 8605,
  [8677] = 8606,
  [8678] = 8329,
  [8679] = 8474,
  [8680] = 8609,
  [8681] = 8610,
  [8682] = 8611,
  [8683] = 8338,
  [8684] = 8348,
  [8685] = 8360,
  [8686] = 8412,
  [8687] = 8501,
  [8688] = 8502,
  [8689] = 8507,
  [8690] = 8494,
  [8691] = 8419,
  [8692] = 8471,
  [8693] = 8602,
  [8694] = 8603,
  [8695] = 8695,
  [8696] = 8696,
  [8697] = 8697,
  [8698] = 8698,
  [8699] = 8419,
  [8700] = 8700,
  [8701] = 8419,
  [8702] = 8419,
  [8703] = 8419,
  [8704] = 8704,
  [8705] = 8356,
  [8706] = 8451,
  [8707] = 8454,
  [8708] = 8468,
  [8709] = 8476,
  [8710] = 8517,
  [8711] = 8711,
  [8712] = 8712,
  [8713] = 8588,
  [8714] = 8714,
  [8715] = 8715,
  [8716] = 8716,
  [8717] = 8589,
  [8718] = 8611,
  [8719] = 8342,
  [8720] = 8720,
  [8721] = 8590,
  [8722] = 8591,
  [8723] = 8592,
  [8724] = 8593,
  [8725] = 8594,
  [8726] = 8704,
  [8727] = 8595,
  [8728] = 8728,
  [8729] = 8596,
  [8730] = 8730,
  [8731] = 8597,
  [8732] = 8598,
  [8733] = 8599,
  [8734] = 8734,
  [8735] = 8346,
  [8736] = 8600,
  [8737] = 8631,
  [8738] = 8738,
  [8739] = 8632,
  [8740] = 8548,
  [8741] = 8601,
  [8742] = 8602,
  [8743] = 8730,
  [8744] = 8433,
  [8745] = 8434,
  [8746] = 8438,
  [8747] = 8365,
  [8748] = 8441,
  [8749] = 8587,
  [8750] = 8519,
  [8751] = 8497,
  [8752] = 8730,
  [8753] = 8433,
  [8754] = 8434,
  [8755] = 8438,
  [8756] = 8365,
  [8757] = 8441,
  [8758] = 8433,
  [8759] = 8434,
  [8760] = 8438,
  [8761] = 8365,
  [8762] = 8762,
  [8763] = 8603,
  [8764] = 8604,
  [8765] = 8605,
  [8766] = 8606,
  [8767] = 8364,
  [8768] = 8768,
  [8769] = 1600,
  [8770] = 8770,
  [8771] = 1601,
  [8772] = 8772,
  [8773] = 8773,
  [8774] = 1032,
  [8775] = 8768,
  [8776] = 1033,
  [8777] = 8777,
  [8778] = 8778,
  [8779] = 8779,
  [8780] = 8780,
  [8781] = 8781,
  [8782] = 1009,
  [8783] = 8783,
  [8784] = 8784,
  [8785] = 8785,
  [8786] = 8786,
  [8787] = 991,
  [8788] = 8788,
  [8789] = 8789,
  [8790] = 8768,
  [8791] = 8791,
  [8792] = 8792,
  [8793] = 8793,
  [8794] = 8794,
  [8795] = 1035,
  [8796] = 1001,
  [8797] = 1037,
  [8798] = 8798,
  [8799] = 8799,
  [8800] = 8800,
  [8801] = 1016,
  [8802] = 1019,
  [8803] = 1017,
  [8804] = 1004,
  [8805] = 1028,
  [8806] = 1023,
  [8807] = 8807,
  [8808] = 1031,
  [8809] = 8809,
  [8810] = 8810,
  [8811] = 6193,
  [8812] = 1018,
  [8813] = 1030,
  [8814] = 8814,
  [8815] = 1015,
  [8816] = 8816,
  [8817] = 1036,
  [8818] = 1020,
  [8819] = 1039,
  [8820] = 8820,
  [8821] = 8821,
  [8822] = 8822,
  [8823] = 8823,
  [8824] = 8824,
  [8825] = 8825,
  [8826] = 8826,
  [8827] = 988,
  [8828] = 8828,
  [8829] = 8829,
  [8830] = 8830,
  [8831] = 989,
  [8832] = 6194,
  [8833] = 8833,
  [8834] = 8834,
  [8835] = 1040,
  [8836] = 1002,
  [8837] = 8837,
  [8838] = 990,
  [8839] = 8839,
  [8840] = 1244,
  [8841] = 1003,
  [8842] = 1597,
  [8843] = 1005,
  [8844] = 1029,
  [8845] = 8845,
  [8846] = 1015,
  [8847] = 8847,
  [8848] = 8848,
  [8849] = 8849,
  [8850] = 8850,
  [8851] = 8851,
  [8852] = 8852,
  [8853] = 8853,
  [8854] = 8854,
  [8855] = 8855,
  [8856] = 8856,
  [8857] = 1019,
  [8858] = 8858,
  [8859] = 8859,
  [8860] = 8860,
  [8861] = 8861,
  [8862] = 8862,
  [8863] = 8863,
  [8864] = 1035,
  [8865] = 1037,
  [8866] = 8866,
  [8867] = 8867,
  [8868] = 8850,
  [8869] = 8854,
  [8870] = 8855,
  [8871] = 8871,
  [8872] = 8845,
  [8873] = 8845,
  [8874] = 8874,
  [8875] = 8875,
  [8876] = 8874,
  [8877] = 8877,
  [8878] = 8878,
  [8879] = 8877,
  [8880] = 8880,
  [8881] = 8881,
  [8882] = 8874,
  [8883] = 8883,
  [8884] = 8884,
  [8885] = 1040,
  [8886] = 8886,
  [8887] = 1031,
  [8888] = 1028,
  [8889] = 1598,
  [8890] = 1599,
  [8891] = 1602,
  [8892] = 1604,
  [8893] = 1605,
  [8894] = 8894,
  [8895] = 1032,
  [8896] = 8877,
  [8897] = 1606,
  [8898] = 1607,
  [8899] = 1608,
  [8900] = 1609,
  [8901] = 1610,
  [8902] = 1611,
  [8903] = 1612,
  [8904] = 1613,
  [8905] = 1018,
  [8906] = 1615,
  [8907] = 1616,
  [8908] = 1617,
  [8909] = 1618,
  [8910] = 1619,
  [8911] = 1620,
  [8912] = 1023,
  [8913] = 8913,
  [8914] = 8914,
  [8915] = 8915,
  [8916] = 8916,
  [8917] = 8916,
  [8918] = 1036,
  [8919] = 8919,
  [8920] = 1735,
  [8921] = 8921,
  [8922] = 8856,
  [8923] = 8923,
  [8924] = 1020,
  [8925] = 1244,
  [8926] = 1039,
  [8927] = 8927,
  [8928] = 8928,
  [8929] = 8929,
  [8930] = 1733,
  [8931] = 8931,
  [8932] = 6193,
  [8933] = 8916,
  [8934] = 1016,
  [8935] = 6194,
  [8936] = 8936,
  [8937] = 8937,
  [8938] = 8938,
  [8939] = 8939,
  [8940] = 8940,
  [8941] = 1017,
  [8942] = 8856,
  [8943] = 8943,
  [8944] = 8944,
  [8945] = 8945,
  [8946] = 8856,
  [8947] = 1033,
  [8948] = 8850,
  [8949] = 8949,
  [8950] = 8855,
  [8951] = 8854,
  [8952] = 8952,
  [8953] = 8953,
  [8954] = 8855,
  [8955] = 8955,
  [8956] = 8845,
  [8957] = 8874,
  [8958] = 8877,
  [8959] = 8916,
  [8960] = 8960,
  [8961] = 8850,
  [8962] = 8854,
  [8963] = 8963,
  [8964] = 1614,
  [8965] = 8965,
  [8966] = 8966,
  [8967] = 8967,
  [8968] = 8966,
  [8969] = 8967,
  [8970] = 8966,
  [8971] = 8967,
  [8972] = 8966,
  [8973] = 8967,
  [8974] = 8966,
  [8975] = 8967,
  [8976] = 8966,
  [8977] = 8967,
  [8978] = 8966,
  [8979] = 8967,
  [8980] = 8966,
  [8981] = 8981,
  [8982] = 8966,
  [8983] = 8967,
  [8984] = 8984,
  [8985] = 8985,
  [8986] = 8079,
  [8987] = 8984,
  [8988] = 8988,
  [8989] = 8989,
  [8990] = 7629,
  [8991] = 8984,
  [8992] = 8992,
  [8993] = 8984,
  [8994] = 8967,
  [8995] = 8966,
  [8996] = 8967,
  [8997] = 8966,
  [8998] = 8967,
  [8999] = 8966,
  [9000] = 8967,
  [9001] = 9001,
  [9002] = 9001,
  [9003] = 9003,
  [9004] = 9004,
  [9005] = 9005,
  [9006] = 9004,
  [9007] = 9007,
  [9008] = 9008,
  [9009] = 9009,
  [9010] = 8279,
  [9011] = 7690,
  [9012] = 7732,
  [9013] = 9013,
  [9014] = 8235,
  [9015] = 7642,
  [9016] = 7657,
  [9017] = 9017,
  [9018] = 9004,
  [9019] = 1244,
  [9020] = 9020,
  [9021] = 7747,
  [9022] = 9001,
  [9023] = 9023,
  [9024] = 8257,
  [9025] = 9004,
  [9026] = 9004,
  [9027] = 9001,
  [9028] = 9004,
  [9029] = 9001,
  [9030] = 7710,
  [9031] = 9001,
  [9032] = 7702,
  [9033] = 9033,
  [9034] = 9034,
  [9035] = 9035,
  [9036] = 3545,
  [9037] = 3993,
  [9038] = 9038,
  [9039] = 3996,
  [9040] = 9040,
  [9041] = 3997,
  [9042] = 3998,
  [9043] = 8463,
  [9044] = 9044,
  [9045] = 9045,
  [9046] = 9046,
  [9047] = 3995,
  [9048] = 3994,
  [9049] = 9049,
  [9050] = 9050,
  [9051] = 3664,
  [9052] = 8482,
  [9053] = 9053,
  [9054] = 9054,
  [9055] = 9055,
  [9056] = 9056,
  [9057] = 9057,
  [9058] = 9058,
  [9059] = 9059,
  [9060] = 9060,
  [9061] = 9061,
  [9062] = 9062,
  [9063] = 9063,
  [9064] = 9064,
  [9065] = 9064,
  [9066] = 9066,
  [9067] = 9067,
  [9068] = 9059,
  [9069] = 9069,
  [9070] = 9069,
  [9071] = 9071,
  [9072] = 9072,
  [9073] = 9073,
  [9074] = 9074,
  [9075] = 9075,
  [9076] = 9076,
  [9077] = 9058,
  [9078] = 9072,
  [9079] = 9079,
  [9080] = 9080,
  [9081] = 9081,
  [9082] = 9060,
  [9083] = 9061,
  [9084] = 9062,
  [9085] = 9067,
  [9086] = 9064,
  [9087] = 9059,
  [9088] = 9071,
  [9089] = 9089,
  [9090] = 9075,
  [9091] = 9073,
  [9092] = 9074,
  [9093] = 9076,
  [9094] = 9094,
  [9095] = 9095,
  [9096] = 9058,
  [9097] = 9074,
  [9098] = 9098,
  [9099] = 9094,
  [9100] = 9100,
  [9101] = 9089,
  [9102] = 9102,
  [9103] = 9072,
  [9104] = 9104,
  [9105] = 9072,
  [9106] = 9079,
  [9107] = 9080,
  [9108] = 9081,
  [9109] = 9060,
  [9110] = 9061,
  [9111] = 9062,
  [9112] = 9067,
  [9113] = 9113,
  [9114] = 9072,
  [9115] = 9089,
  [9116] = 9067,
  [9117] = 1244,
  [9118] = 9098,
  [9119] = 9079,
  [9120] = 9102,
  [9121] = 9121,
  [9122] = 9072,
  [9123] = 9072,
  [9124] = 9079,
  [9125] = 9080,
  [9126] = 9081,
  [9127] = 9060,
  [9128] = 9061,
  [9129] = 9062,
  [9130] = 9067,
  [9131] = 9080,
  [9132] = 9104,
  [9133] = 9072,
  [9134] = 9094,
  [9135] = 9100,
  [9136] = 9113,
  [9137] = 9137,
  [9138] = 9081,
  [9139] = 9066,
  [9140] = 9140,
  [9141] = 9072,
  [9142] = 9075,
  [9143] = 9072,
  [9144] = 9079,
  [9145] = 9080,
  [9146] = 9081,
  [9147] = 9060,
  [9148] = 9076,
  [9149] = 9061,
  [9150] = 9062,
  [9151] = 9067,
  [9152] = 9079,
  [9153] = 9079,
  [9154] = 9080,
  [9155] = 9080,
  [9156] = 9081,
  [9157] = 9060,
  [9158] = 9080,
  [9159] = 9079,
  [9160] = 9061,
  [9161] = 9062,
  [9162] = 9067,
  [9163] = 9102,
  [9164] = 9072,
  [9165] = 9079,
  [9166] = 9080,
  [9167] = 9081,
  [9168] = 9060,
  [9169] = 9061,
  [9170] = 9062,
  [9171] = 9067,
  [9172] = 9081,
  [9173] = 9100,
  [9174] = 9137,
  [9175] = 9121,
  [9176] = 9066,
  [9177] = 9080,
  [9178] = 9060,
  [9179] = 9061,
  [9180] = 9180,
  [9181] = 9062,
  [9182] = 9072,
  [9183] = 9081,
  [9184] = 9079,
  [9185] = 9080,
  [9186] = 9081,
  [9187] = 9060,
  [9188] = 9061,
  [9189] = 9062,
  [9190] = 9074,
  [9191] = 9079,
  [9192] = 9072,
  [9193] = 9079,
  [9194] = 9080,
  [9195] = 9081,
  [9196] = 9196,
  [9197] = 9060,
  [9198] = 9061,
  [9199] = 9062,
  [9200] = 9067,
  [9201] = 9072,
  [9202] = 9079,
  [9203] = 9080,
  [9204] = 9081,
  [9205] = 9060,
  [9206] = 9061,
  [9207] = 9062,
  [9208] = 9067,
  [9209] = 9209,
  [9210] = 9072,
  [9211] = 9121,
  [9212] = 9079,
  [9213] = 9080,
  [9214] = 9080,
  [9215] = 9081,
  [9216] = 9098,
  [9217] = 9060,
  [9218] = 9081,
  [9219] = 9081,
  [9220] = 9196,
  [9221] = 9061,
  [9222] = 9062,
  [9223] = 9067,
  [9224] = 9072,
  [9225] = 9079,
  [9226] = 9080,
  [9227] = 9079,
  [9228] = 9081,
  [9229] = 9060,
  [9230] = 9061,
  [9231] = 9209,
  [9232] = 9062,
  [9233] = 9121,
  [9234] = 9067,
  [9235] = 9071,
  [9236] = 9072,
  [9237] = 9079,
  [9238] = 9063,
  [9239] = 9080,
  [9240] = 9081,
  [9241] = 9060,
  [9242] = 9061,
  [9243] = 9062,
  [9244] = 9067,
  [9245] = 9072,
  [9246] = 9079,
  [9247] = 9073,
  [9248] = 9080,
  [9249] = 9081,
  [9250] = 9060,
  [9251] = 9140,
  [9252] = 9061,
  [9253] = 9062,
  [9254] = 9067,
  [9255] = 9058,
  [9256] = 9072,
  [9257] = 9196,
  [9258] = 9079,
  [9259] = 9080,
  [9260] = 9081,
  [9261] = 9104,
  [9262] = 9060,
  [9263] = 9061,
  [9264] = 9060,
  [9265] = 9113,
  [9266] = 9062,
  [9267] = 9060,
  [9268] = 9061,
  [9269] = 9062,
  [9270] = 9067,
  [9271] = 9137,
  [9272] = 9067,
  [9273] = 9067,
  [9274] = 9061,
  [9275] = 9094,
  [9276] = 9121,
  [9277] = 9196,
  [9278] = 9069,
  [9279] = 9098,
  [9280] = 9061,
  [9281] = 9089,
  [9282] = 9102,
  [9283] = 9104,
  [9284] = 9062,
  [9285] = 9100,
  [9286] = 9113,
  [9287] = 9137,
  [9288] = 9066,
  [9289] = 9075,
  [9290] = 9076,
  [9291] = 9196,
  [9292] = 9060,
  [9293] = 9069,
  [9294] = 9062,
  [9295] = 9064,
  [9296] = 9059,
  [9297] = 9071,
  [9298] = 9067,
  [9299] = 9073,
  [9300] = 9180,
  [9301] = 9067,
  [9302] = 984,
  [9303] = 9303,
  [9304] = 9304,
  [9305] = 9305,
  [9306] = 9306,
  [9307] = 9307,
  [9308] = 9308,
  [9309] = 9309,
  [9310] = 9310,
  [9311] = 9311,
  [9312] = 9312,
  [9313] = 9313,
  [9314] = 9314,
  [9315] = 9315,
  [9316] = 9316,
  [9317] = 9317,
  [9318] = 9318,
  [9319] = 9319,
  [9320] = 9320,
  [9321] = 9321,
  [9322] = 9322,
  [9323] = 9323,
  [9324] = 9324,
  [9325] = 9325,
  [9326] = 9326,
  [9327] = 9327,
  [9328] = 9328,
  [9329] = 9329,
  [9330] = 9330,
  [9331] = 9331,
  [9332] = 9332,
  [9333] = 9333,
  [9334] = 1538,
  [9335] = 1539,
  [9336] = 1533,
  [9337] = 1535,
  [9338] = 9338,
  [9339] = 9339,
  [9340] = 9340,
  [9341] = 9341,
  [9342] = 9342,
  [9343] = 9343,
  [9344] = 9344,
  [9345] = 9338,
  [9346] = 9346,
  [9347] = 9347,
  [9348] = 9348,
  [9349] = 9349,
  [9350] = 9350,
  [9351] = 9316,
  [9352] = 9352,
  [9353] = 9317,
  [9354] = 9354,
  [9355] = 9318,
  [9356] = 9319,
  [9357] = 9333,
  [9358] = 9358,
  [9359] = 9359,
  [9360] = 9360,
  [9361] = 9340,
  [9362] = 9362,
  [9363] = 9363,
  [9364] = 9364,
  [9365] = 9365,
  [9366] = 9366,
  [9367] = 9303,
  [9368] = 9305,
  [9369] = 9306,
  [9370] = 9307,
  [9371] = 9308,
  [9372] = 9352,
  [9373] = 9373,
  [9374] = 9310,
  [9375] = 9311,
  [9376] = 9312,
  [9377] = 9313,
  [9378] = 9314,
  [9379] = 9315,
  [9380] = 9316,
  [9381] = 9317,
  [9382] = 9318,
  [9383] = 9319,
  [9384] = 9384,
  [9385] = 9325,
  [9386] = 9386,
  [9387] = 1540,
  [9388] = 1541,
  [9389] = 1597,
  [9390] = 1598,
  [9391] = 9391,
  [9392] = 1599,
  [9393] = 1600,
  [9394] = 1601,
  [9395] = 1602,
  [9396] = 9396,
  [9397] = 9309,
  [9398] = 9320,
  [9399] = 9322,
  [9400] = 9400,
  [9401] = 9321,
  [9402] = 1604,
  [9403] = 1605,
  [9404] = 9404,
  [9405] = 9342,
  [9406] = 9406,
  [9407] = 9407,
  [9408] = 9354,
  [9409] = 9333,
  [9410] = 9346,
  [9411] = 9342,
  [9412] = 9412,
  [9413] = 9407,
  [9414] = 9414,
  [9415] = 9415,
  [9416] = 9366,
  [9417] = 1606,
  [9418] = 9303,
  [9419] = 1607,
  [9420] = 9305,
  [9421] = 9306,
  [9422] = 9307,
  [9423] = 9308,
  [9424] = 1608,
  [9425] = 1609,
  [9426] = 1610,
  [9427] = 1611,
  [9428] = 9310,
  [9429] = 9311,
  [9430] = 9312,
  [9431] = 9313,
  [9432] = 9314,
  [9433] = 9315,
  [9434] = 1612,
  [9435] = 9316,
  [9436] = 9317,
  [9437] = 9318,
  [9438] = 9319,
  [9439] = 1613,
  [9440] = 1614,
  [9441] = 1615,
  [9442] = 1616,
  [9443] = 9325,
  [9444] = 1617,
  [9445] = 1618,
  [9446] = 1619,
  [9447] = 1620,
  [9448] = 9412,
  [9449] = 9414,
  [9450] = 9450,
  [9451] = 9451,
  [9452] = 9452,
  [9453] = 1542,
  [9454] = 1543,
  [9455] = 9330,
  [9456] = 9456,
  [9457] = 9348,
  [9458] = 9359,
  [9459] = 9350,
  [9460] = 9358,
  [9461] = 9360,
  [9462] = 9462,
  [9463] = 9396,
  [9464] = 9354,
  [9465] = 9465,
  [9466] = 9333,
  [9467] = 9309,
  [9468] = 9320,
  [9469] = 9366,
  [9470] = 9303,
  [9471] = 9305,
  [9472] = 9306,
  [9473] = 9307,
  [9474] = 9308,
  [9475] = 9321,
  [9476] = 9310,
  [9477] = 9311,
  [9478] = 9312,
  [9479] = 9313,
  [9480] = 9314,
  [9481] = 9315,
  [9482] = 9482,
  [9483] = 9316,
  [9484] = 9317,
  [9485] = 9318,
  [9486] = 9319,
  [9487] = 9325,
  [9488] = 9488,
  [9489] = 1544,
  [9490] = 9490,
  [9491] = 1534,
  [9492] = 9451,
  [9493] = 9354,
  [9494] = 9333,
  [9495] = 9452,
  [9496] = 9366,
  [9497] = 9327,
  [9498] = 9305,
  [9499] = 9328,
  [9500] = 9347,
  [9501] = 9330,
  [9502] = 9331,
  [9503] = 9344,
  [9504] = 9504,
  [9505] = 9343,
  [9506] = 9348,
  [9507] = 9350,
  [9508] = 9490,
  [9509] = 9354,
  [9510] = 9333,
  [9511] = 9358,
  [9512] = 9354,
  [9513] = 9333,
  [9514] = 9386,
  [9515] = 9515,
  [9516] = 9391,
  [9517] = 987,
  [9518] = 9354,
  [9519] = 9333,
  [9520] = 9456,
  [9521] = 9521,
  [9522] = 9360,
  [9523] = 9523,
  [9524] = 9329,
  [9525] = 9354,
  [9526] = 9333,
  [9527] = 9527,
  [9528] = 9332,
  [9529] = 9529,
  [9530] = 9346,
  [9531] = 9340,
  [9532] = 9338,
  [9533] = 9533,
  [9534] = 9354,
  [9535] = 9333,
  [9536] = 9536,
  [9537] = 9362,
  [9538] = 9373,
  [9539] = 961,
  [9540] = 9540,
  [9541] = 9541,
  [9542] = 9341,
  [9543] = 9354,
  [9544] = 9333,
  [9545] = 9363,
  [9546] = 9546,
  [9547] = 9342,
  [9548] = 9548,
  [9549] = 9546,
  [9550] = 9364,
  [9551] = 9365,
  [9552] = 9515,
  [9553] = 9347,
  [9554] = 9348,
  [9555] = 9346,
  [9556] = 9350,
  [9557] = 9358,
  [9558] = 9407,
  [9559] = 9360,
  [9560] = 9384,
  [9561] = 9412,
  [9562] = 9414,
  [9563] = 9362,
  [9564] = 9451,
  [9565] = 9452,
  [9566] = 9364,
  [9567] = 9330,
  [9568] = 9456,
  [9569] = 9365,
  [9570] = 9400,
  [9571] = 9384,
  [9572] = 9347,
  [9573] = 9327,
  [9574] = 9328,
  [9575] = 9396,
  [9576] = 9325,
  [9577] = 9309,
  [9578] = 9320,
  [9579] = 9321,
  [9580] = 9404,
  [9581] = 9465,
  [9582] = 960,
  [9583] = 9583,
  [9584] = 9396,
  [9585] = 9359,
  [9586] = 9309,
  [9587] = 9343,
  [9588] = 9588,
  [9589] = 9548,
  [9590] = 9386,
  [9591] = 9391,
  [9592] = 9521,
  [9593] = 9523,
  [9594] = 9320,
  [9595] = 9346,
  [9596] = 9527,
  [9597] = 9348,
  [9598] = 9407,
  [9599] = 9482,
  [9600] = 9350,
  [9601] = 9541,
  [9602] = 9412,
  [9603] = 9414,
  [9604] = 9341,
  [9605] = 9540,
  [9606] = 9451,
  [9607] = 9607,
  [9608] = 9452,
  [9609] = 9323,
  [9610] = 9406,
  [9611] = 9363,
  [9612] = 9612,
  [9613] = 9613,
  [9614] = 9614,
  [9615] = 9615,
  [9616] = 9616,
  [9617] = 9617,
  [9618] = 9330,
  [9619] = 9619,
  [9620] = 9620,
  [9621] = 9621,
  [9622] = 9456,
  [9623] = 9623,
  [9624] = 9624,
  [9625] = 9625,
  [9626] = 9546,
  [9627] = 9321,
  [9628] = 9548,
  [9629] = 9629,
  [9630] = 9373,
  [9631] = 9404,
  [9632] = 9327,
  [9633] = 9328,
  [9634] = 9329,
  [9635] = 9346,
  [9636] = 9407,
  [9637] = 9352,
  [9638] = 9327,
  [9639] = 9328,
  [9640] = 9400,
  [9641] = 986,
  [9642] = 9616,
  [9643] = 9619,
  [9644] = 9620,
  [9645] = 9621,
  [9646] = 9623,
  [9647] = 9624,
  [9648] = 9625,
  [9649] = 9614,
  [9650] = 9629,
  [9651] = 9615,
  [9652] = 9465,
  [9653] = 9616,
  [9654] = 9619,
  [9655] = 9620,
  [9656] = 9621,
  [9657] = 9657,
  [9658] = 9623,
  [9659] = 9624,
  [9660] = 9625,
  [9661] = 9629,
  [9662] = 9373,
  [9663] = 9346,
  [9664] = 9616,
  [9665] = 9619,
  [9666] = 9620,
  [9667] = 9621,
  [9668] = 9623,
  [9669] = 9624,
  [9670] = 9625,
  [9671] = 9629,
  [9672] = 9343,
  [9673] = 9407,
  [9674] = 9386,
  [9675] = 9412,
  [9676] = 9414,
  [9677] = 9451,
  [9678] = 9452,
  [9679] = 9330,
  [9680] = 9456,
  [9681] = 9391,
  [9682] = 9358,
  [9683] = 9360,
  [9684] = 9415,
  [9685] = 9396,
  [9686] = 9328,
  [9687] = 9536,
  [9688] = 9346,
  [9689] = 9521,
  [9690] = 9354,
  [9691] = 9523,
  [9692] = 9612,
  [9693] = 9693,
  [9694] = 9694,
  [9695] = 9346,
  [9696] = 9327,
  [9697] = 9362,
  [9698] = 9407,
  [9699] = 9699,
  [9700] = 9521,
  [9701] = 9412,
  [9702] = 9414,
  [9703] = 9523,
  [9704] = 9451,
  [9705] = 9452,
  [9706] = 9706,
  [9707] = 9330,
  [9708] = 9456,
  [9709] = 9327,
  [9710] = 9328,
  [9711] = 9711,
  [9712] = 9617,
  [9713] = 9613,
  [9714] = 9364,
  [9715] = 9328,
  [9716] = 9412,
  [9717] = 9527,
  [9718] = 9718,
  [9719] = 9607,
  [9720] = 9365,
  [9721] = 9693,
  [9722] = 9706,
  [9723] = 9527,
  [9724] = 9414,
  [9725] = 9346,
  [9726] = 9384,
  [9727] = 9541,
  [9728] = 9407,
  [9729] = 9657,
  [9730] = 9341,
  [9731] = 9731,
  [9732] = 9412,
  [9733] = 9414,
  [9734] = 9734,
  [9735] = 9363,
  [9736] = 9451,
  [9737] = 9452,
  [9738] = 9488,
  [9739] = 9407,
  [9740] = 9330,
  [9741] = 9456,
  [9742] = 9546,
  [9743] = 9327,
  [9744] = 9328,
  [9745] = 9450,
  [9746] = 9548,
  [9747] = 9747,
  [9748] = 9412,
  [9749] = 9414,
  [9750] = 9588,
  [9751] = 9332,
  [9752] = 9451,
  [9753] = 9396,
  [9754] = 9450,
  [9755] = 9346,
  [9756] = 9338,
  [9757] = 9306,
  [9758] = 9407,
  [9759] = 9451,
  [9760] = 9541,
  [9761] = 9412,
  [9762] = 9414,
  [9763] = 9303,
  [9764] = 9451,
  [9765] = 9452,
  [9766] = 9452,
  [9767] = 9330,
  [9768] = 9456,
  [9769] = 9619,
  [9770] = 9327,
  [9771] = 9620,
  [9772] = 9373,
  [9773] = 9346,
  [9774] = 9307,
  [9775] = 9309,
  [9776] = 9407,
  [9777] = 9366,
  [9778] = 9731,
  [9779] = 9734,
  [9780] = 9488,
  [9781] = 9451,
  [9782] = 9412,
  [9783] = 9414,
  [9784] = 9310,
  [9785] = 9451,
  [9786] = 9452,
  [9787] = 9452,
  [9788] = 9330,
  [9789] = 9456,
  [9790] = 9311,
  [9791] = 9312,
  [9792] = 9346,
  [9793] = 9359,
  [9794] = 9330,
  [9795] = 9407,
  [9796] = 9331,
  [9797] = 9344,
  [9798] = 9412,
  [9799] = 9414,
  [9800] = 1536,
  [9801] = 9451,
  [9802] = 9452,
  [9803] = 9322,
  [9804] = 9330,
  [9805] = 9731,
  [9806] = 9734,
  [9807] = 9488,
  [9808] = 9305,
  [9809] = 9456,
  [9810] = 9320,
  [9811] = 9346,
  [9812] = 9313,
  [9813] = 9407,
  [9814] = 9321,
  [9815] = 9314,
  [9816] = 9412,
  [9817] = 9414,
  [9818] = 9490,
  [9819] = 9819,
  [9820] = 9451,
  [9821] = 9452,
  [9822] = 9330,
  [9823] = 9456,
  [9824] = 1537,
  [9825] = 9588,
  [9826] = 9346,
  [9827] = 9322,
  [9828] = 9407,
  [9829] = 9315,
  [9830] = 9412,
  [9831] = 9414,
  [9832] = 9621,
  [9833] = 9451,
  [9834] = 9462,
  [9835] = 9452,
  [9836] = 9327,
  [9837] = 9328,
  [9838] = 9330,
  [9839] = 9456,
  [9840] = 9629,
  [9841] = 9322,
  [9842] = 9346,
  [9843] = 9588,
  [9844] = 9407,
  [9845] = 9352,
  [9846] = 9400,
  [9847] = 9412,
  [9848] = 9414,
  [9849] = 9404,
  [9850] = 9451,
  [9851] = 9452,
  [9852] = 9465,
  [9853] = 9456,
  [9854] = 9330,
  [9855] = 9456,
  [9856] = 9536,
  [9857] = 9330,
  [9858] = 9346,
  [9859] = 9331,
  [9860] = 9322,
  [9861] = 9407,
  [9862] = 9344,
  [9863] = 9456,
  [9864] = 9412,
  [9865] = 9339,
  [9866] = 9414,
  [9867] = 9616,
  [9868] = 9451,
  [9869] = 9452,
  [9870] = 9400,
  [9871] = 9330,
  [9872] = 9456,
  [9873] = 9327,
  [9874] = 9536,
  [9875] = 9329,
  [9876] = 9346,
  [9877] = 9332,
  [9878] = 9328,
  [9879] = 9407,
  [9880] = 9412,
  [9881] = 9414,
  [9882] = 9308,
  [9883] = 9451,
  [9884] = 9407,
  [9885] = 9452,
  [9886] = 9623,
  [9887] = 9412,
  [9888] = 9330,
  [9889] = 9456,
  [9890] = 9414,
  [9891] = 9490,
  [9892] = 9624,
  [9893] = 9346,
  [9894] = 9734,
  [9895] = 9452,
  [9896] = 9340,
  [9897] = 9354,
  [9898] = 9529,
  [9899] = 9407,
  [9900] = 9625,
  [9901] = 9400,
  [9902] = 9412,
  [9903] = 9414,
  [9904] = 9333,
  [9905] = 9456,
  [9906] = 9529,
  [9907] = 9450,
  [9908] = 9327,
  [9909] = 9328,
  [9910] = 9731,
  [9911] = 9451,
  [9912] = 9373,
  [9913] = 9529,
  [9914] = 9452,
  [9915] = 9529,
  [9916] = 9718,
  [9917] = 9529,
  [9918] = 9529,
  [9919] = 9529,
  [9920] = 9529,
  [9921] = 9529,
  [9922] = 9529,
  [9923] = 9529,
  [9924] = 9529,
  [9925] = 9529,
  [9926] = 9529,
  [9927] = 9529,
  [9928] = 9529,
  [9929] = 9529,
  [9930] = 9529,
  [9931] = 9330,
  [9932] = 9932,
  [9933] = 9456,
  [9934] = 9348,
  [9935] = 9350,
  [9936] = 9358,
  [9937] = 9360,
  [9938] = 9366,
  [9939] = 9327,
  [9940] = 9940,
  [9941] = 9941,
  [9942] = 9942,
  [9943] = 1682,
  [9944] = 9944,
  [9945] = 1587,
  [9946] = 9946,
  [9947] = 9947,
  [9948] = 9948,
  [9949] = 1588,
  [9950] = 1589,
  [9951] = 9951,
  [9952] = 9952,
  [9953] = 1590,
  [9954] = 1591,
  [9955] = 9955,
  [9956] = 9956,
  [9957] = 9957,
  [9958] = 5713,
  [9959] = 9940,
  [9960] = 9960,
  [9961] = 9961,
  [9962] = 9962,
  [9963] = 9963,
  [9964] = 9964,
  [9965] = 9946,
  [9966] = 9966,
  [9967] = 1592,
  [9968] = 9968,
  [9969] = 1593,
  [9970] = 9970,
  [9971] = 1594,
  [9972] = 1671,
  [9973] = 1595,
  [9974] = 1596,
  [9975] = 1603,
  [9976] = 9976,
  [9977] = 1621,
  [9978] = 1690,
  [9979] = 1672,
  [9980] = 1624,
  [9981] = 1625,
  [9982] = 1626,
  [9983] = 1627,
  [9984] = 1673,
  [9985] = 9985,
  [9986] = 1711,
  [9987] = 1557,
  [9988] = 1712,
  [9989] = 9989,
  [9990] = 3311,
  [9991] = 9991,
  [9992] = 1713,
  [9993] = 9962,
  [9994] = 1714,
  [9995] = 1715,
  [9996] = 9996,
  [9997] = 9985,
  [9998] = 1716,
  [9999] = 1717,
  [10000] = 1691,
  [10001] = 1692,
  [10002] = 9944,
  [10003] = 1718,
  [10004] = 1693,
  [10005] = 1694,
  [10006] = 10006,
  [10007] = 5669,
  [10008] = 9946,
  [10009] = 9957,
  [10010] = 9962,
  [10011] = 1683,
  [10012] = 9944,
  [10013] = 9946,
  [10014] = 9944,
  [10015] = 9946,
  [10016] = 9964,
  [10017] = 10017,
  [10018] = 10018,
  [10019] = 1628,
  [10020] = 1629,
  [10021] = 9957,
  [10022] = 9962,
  [10023] = 9963,
  [10024] = 9968,
  [10025] = 9955,
  [10026] = 10026,
  [10027] = 1630,
  [10028] = 9947,
  [10029] = 1631,
  [10030] = 1632,
  [10031] = 1633,
  [10032] = 1634,
  [10033] = 9951,
  [10034] = 9952,
  [10035] = 1635,
  [10036] = 9955,
  [10037] = 9956,
  [10038] = 9940,
  [10039] = 9960,
  [10040] = 9970,
  [10041] = 9964,
  [10042] = 9976,
  [10043] = 9957,
  [10044] = 1636,
  [10045] = 1637,
  [10046] = 1638,
  [10047] = 1639,
  [10048] = 9951,
  [10049] = 9962,
  [10050] = 9963,
  [10051] = 9968,
  [10052] = 10052,
  [10053] = 5739,
  [10054] = 9970,
  [10055] = 9976,
  [10056] = 10056,
  [10057] = 1719,
  [10058] = 1685,
  [10059] = 1720,
  [10060] = 1721,
  [10061] = 10061,
  [10062] = 1552,
  [10063] = 1553,
  [10064] = 1554,
  [10065] = 1555,
  [10066] = 1722,
  [10067] = 10067,
  [10068] = 1723,
  [10069] = 1640,
  [10070] = 1641,
  [10071] = 1724,
  [10072] = 9957,
  [10073] = 1657,
  [10074] = 1686,
  [10075] = 9947,
  [10076] = 1642,
  [10077] = 1643,
  [10078] = 1644,
  [10079] = 9963,
  [10080] = 9951,
  [10081] = 9952,
  [10082] = 9955,
  [10083] = 9956,
  [10084] = 9940,
  [10085] = 9960,
  [10086] = 9968,
  [10087] = 9964,
  [10088] = 1725,
  [10089] = 1726,
  [10090] = 10090,
  [10091] = 10018,
  [10092] = 10092,
  [10093] = 1695,
  [10094] = 1658,
  [10095] = 1727,
  [10096] = 1728,
  [10097] = 1729,
  [10098] = 1659,
  [10099] = 1546,
  [10100] = 9947,
  [10101] = 10101,
  [10102] = 1557,
  [10103] = 9970,
  [10104] = 9951,
  [10105] = 9952,
  [10106] = 9976,
  [10107] = 9955,
  [10108] = 9956,
  [10109] = 9940,
  [10110] = 9960,
  [10111] = 9964,
  [10112] = 1696,
  [10113] = 1551,
  [10114] = 1556,
  [10115] = 1558,
  [10116] = 1559,
  [10117] = 9955,
  [10118] = 9940,
  [10119] = 9960,
  [10120] = 9964,
  [10121] = 10121,
  [10122] = 1651,
  [10123] = 1560,
  [10124] = 9955,
  [10125] = 9940,
  [10126] = 9960,
  [10127] = 9964,
  [10128] = 1561,
  [10129] = 9955,
  [10130] = 9940,
  [10131] = 9960,
  [10132] = 9964,
  [10133] = 1562,
  [10134] = 9955,
  [10135] = 9940,
  [10136] = 9960,
  [10137] = 9964,
  [10138] = 9955,
  [10139] = 9940,
  [10140] = 9960,
  [10141] = 9964,
  [10142] = 9955,
  [10143] = 9940,
  [10144] = 9960,
  [10145] = 9964,
  [10146] = 9955,
  [10147] = 9940,
  [10148] = 9960,
  [10149] = 9964,
  [10150] = 9955,
  [10151] = 9940,
  [10152] = 9960,
  [10153] = 9964,
  [10154] = 9955,
  [10155] = 9940,
  [10156] = 9960,
  [10157] = 9964,
  [10158] = 9955,
  [10159] = 9940,
  [10160] = 9960,
  [10161] = 9964,
  [10162] = 9955,
  [10163] = 9940,
  [10164] = 9960,
  [10165] = 9964,
  [10166] = 9955,
  [10167] = 9940,
  [10168] = 10168,
  [10169] = 9964,
  [10170] = 9955,
  [10171] = 1681,
  [10172] = 9960,
  [10173] = 9964,
  [10174] = 9955,
  [10175] = 9940,
  [10176] = 9960,
  [10177] = 9964,
  [10178] = 1676,
  [10179] = 10179,
  [10180] = 1662,
  [10181] = 1660,
  [10182] = 1563,
  [10183] = 1661,
  [10184] = 10018,
  [10185] = 10185,
  [10186] = 9944,
  [10187] = 9946,
  [10188] = 9957,
  [10189] = 3334,
  [10190] = 9962,
  [10191] = 1697,
  [10192] = 9952,
  [10193] = 1698,
  [10194] = 10194,
  [10195] = 10195,
  [10196] = 1699,
  [10197] = 10197,
  [10198] = 1564,
  [10199] = 1700,
  [10200] = 1565,
  [10201] = 1566,
  [10202] = 10202,
  [10203] = 1567,
  [10204] = 1568,
  [10205] = 1569,
  [10206] = 1570,
  [10207] = 1571,
  [10208] = 1572,
  [10209] = 1573,
  [10210] = 1574,
  [10211] = 9963,
  [10212] = 9963,
  [10213] = 9968,
  [10214] = 10018,
  [10215] = 10215,
  [10216] = 9989,
  [10217] = 10217,
  [10218] = 9970,
  [10219] = 9976,
  [10220] = 1687,
  [10221] = 1688,
  [10222] = 1575,
  [10223] = 1701,
  [10224] = 1702,
  [10225] = 1703,
  [10226] = 1704,
  [10227] = 9968,
  [10228] = 10228,
  [10229] = 1576,
  [10230] = 10017,
  [10231] = 7858,
  [10232] = 9947,
  [10233] = 1689,
  [10234] = 10018,
  [10235] = 1577,
  [10236] = 1578,
  [10237] = 1579,
  [10238] = 1580,
  [10239] = 10239,
  [10240] = 1581,
  [10241] = 1582,
  [10242] = 10215,
  [10243] = 1705,
  [10244] = 1706,
  [10245] = 9989,
  [10246] = 9961,
  [10247] = 10026,
  [10248] = 10067,
  [10249] = 10249,
  [10250] = 9985,
  [10251] = 10251,
  [10252] = 10194,
  [10253] = 10217,
  [10254] = 1707,
  [10255] = 1708,
  [10256] = 1709,
  [10257] = 1710,
  [10258] = 10217,
  [10259] = 1583,
  [10260] = 10197,
  [10261] = 10261,
  [10262] = 1584,
  [10263] = 5760,
  [10264] = 10217,
  [10265] = 10215,
  [10266] = 9989,
  [10267] = 9970,
  [10268] = 9944,
  [10269] = 10217,
  [10270] = 9976,
  [10271] = 9940,
  [10272] = 9960,
  [10273] = 9956,
  [10274] = 1665,
  [10275] = 10275,
  [10276] = 10275,
  [10277] = 9942,
  [10278] = 10006,
  [10279] = 9948,
  [10280] = 10090,
  [10281] = 9961,
  [10282] = 10018,
  [10283] = 10185,
  [10284] = 1666,
  [10285] = 9961,
  [10286] = 10215,
  [10287] = 10026,
  [10288] = 10067,
  [10289] = 10275,
  [10290] = 1653,
  [10291] = 9942,
  [10292] = 10006,
  [10293] = 9948,
  [10294] = 10090,
  [10295] = 10295,
  [10296] = 1664,
  [10297] = 10026,
  [10298] = 10298,
  [10299] = 1677,
  [10300] = 10185,
  [10301] = 10275,
  [10302] = 9942,
  [10303] = 10006,
  [10304] = 9948,
  [10305] = 10090,
  [10306] = 10026,
  [10307] = 9985,
  [10308] = 10275,
  [10309] = 9942,
  [10310] = 10006,
  [10311] = 9948,
  [10312] = 10090,
  [10313] = 10067,
  [10314] = 10067,
  [10315] = 10275,
  [10316] = 9942,
  [10317] = 10006,
  [10318] = 9948,
  [10319] = 10090,
  [10320] = 10185,
  [10321] = 10275,
  [10322] = 10215,
  [10323] = 10275,
  [10324] = 9961,
  [10325] = 10275,
  [10326] = 10326,
  [10327] = 10275,
  [10328] = 1678,
  [10329] = 10275,
  [10330] = 1679,
  [10331] = 10275,
  [10332] = 1680,
  [10333] = 10275,
  [10334] = 1548,
  [10335] = 10275,
  [10336] = 1645,
  [10337] = 10275,
  [10338] = 1646,
  [10339] = 10275,
  [10340] = 1647,
  [10341] = 10275,
  [10342] = 1648,
  [10343] = 10275,
  [10344] = 1649,
  [10345] = 10275,
  [10346] = 1652,
  [10347] = 1545,
  [10348] = 1663,
  [10349] = 1547,
  [10350] = 1730,
  [10351] = 1585,
  [10352] = 1586,
  [10353] = 10353,
  [10354] = 9989,
  [10355] = 9960,
  [10356] = 10356,
  [10357] = 10357,
  [10358] = 10358,
  [10359] = 10359,
  [10360] = 10360,
  [10361] = 10361,
  [10362] = 10362,
  [10363] = 10363,
  [10364] = 10364,
  [10365] = 10365,
  [10366] = 10366,
  [10367] = 10356,
  [10368] = 10368,
  [10369] = 10369,
  [10370] = 10370,
  [10371] = 10371,
  [10372] = 10372,
  [10373] = 10373,
  [10374] = 10374,
  [10375] = 10375,
  [10376] = 10376,
  [10377] = 10377,
  [10378] = 10378,
  [10379] = 10379,
  [10380] = 10380,
  [10381] = 10381,
  [10382] = 10382,
  [10383] = 10383,
  [10384] = 10362,
  [10385] = 10385,
  [10386] = 10386,
  [10387] = 10387,
  [10388] = 10388,
  [10389] = 10389,
  [10390] = 10390,
  [10391] = 10391,
  [10392] = 10392,
  [10393] = 10393,
  [10394] = 10394,
  [10395] = 10395,
  [10396] = 10396,
  [10397] = 10397,
  [10398] = 10398,
  [10399] = 10399,
  [10400] = 10400,
  [10401] = 10360,
  [10402] = 10375,
  [10403] = 10376,
  [10404] = 10378,
  [10405] = 10383,
  [10406] = 10406,
  [10407] = 10385,
  [10408] = 10388,
  [10409] = 10393,
  [10410] = 10410,
  [10411] = 10411,
  [10412] = 10364,
  [10413] = 10413,
  [10414] = 10414,
  [10415] = 10415,
  [10416] = 10416,
  [10417] = 10417,
  [10418] = 8244,
  [10419] = 10410,
  [10420] = 10420,
  [10421] = 10421,
  [10422] = 10422,
  [10423] = 10423,
  [10424] = 10424,
  [10425] = 10425,
  [10426] = 10426,
  [10427] = 10365,
  [10428] = 10428,
  [10429] = 10366,
  [10430] = 10430,
  [10431] = 10431,
  [10432] = 10432,
  [10433] = 10411,
  [10434] = 10368,
  [10435] = 10435,
  [10436] = 10436,
  [10437] = 10437,
  [10438] = 10438,
  [10439] = 10439,
  [10440] = 10440,
  [10441] = 10441,
  [10442] = 10442,
  [10443] = 10443,
  [10444] = 10444,
  [10445] = 10445,
  [10446] = 10446,
  [10447] = 10447,
  [10448] = 10448,
  [10449] = 10449,
  [10450] = 10450,
  [10451] = 10451,
  [10452] = 10452,
  [10453] = 10453,
  [10454] = 10454,
  [10455] = 10455,
  [10456] = 10456,
  [10457] = 10457,
  [10458] = 10458,
  [10459] = 10459,
  [10460] = 10460,
  [10461] = 10461,
  [10462] = 10357,
  [10463] = 8212,
  [10464] = 10464,
  [10465] = 10369,
  [10466] = 10466,
  [10467] = 10467,
  [10468] = 10468,
  [10469] = 10469,
  [10470] = 10470,
  [10471] = 10363,
  [10472] = 10370,
  [10473] = 10371,
  [10474] = 10372,
  [10475] = 10373,
  [10476] = 10445,
  [10477] = 10374,
  [10478] = 10446,
  [10479] = 10447,
  [10480] = 10448,
  [10481] = 10481,
  [10482] = 10461,
  [10483] = 10357,
  [10484] = 10363,
  [10485] = 10372,
  [10486] = 10486,
  [10487] = 10487,
  [10488] = 10488,
  [10489] = 10489,
  [10490] = 10490,
  [10491] = 10444,
  [10492] = 10487,
  [10493] = 10488,
  [10494] = 10489,
  [10495] = 10490,
  [10496] = 10496,
  [10497] = 10497,
  [10498] = 10377,
  [10499] = 10499,
  [10500] = 10364,
  [10501] = 10414,
  [10502] = 10502,
  [10503] = 10415,
  [10504] = 10389,
  [10505] = 10486,
  [10506] = 10365,
  [10507] = 10358,
  [10508] = 10359,
  [10509] = 10509,
  [10510] = 10444,
  [10511] = 10511,
  [10512] = 10366,
  [10513] = 10356,
  [10514] = 10481,
  [10515] = 10368,
  [10516] = 10449,
  [10517] = 10369,
  [10518] = 10370,
  [10519] = 10371,
  [10520] = 10416,
  [10521] = 10423,
  [10522] = 10522,
  [10523] = 10417,
  [10524] = 10496,
  [10525] = 10497,
  [10526] = 10373,
  [10527] = 10358,
  [10528] = 10359,
  [10529] = 10450,
  [10530] = 10361,
  [10531] = 10362,
  [10532] = 10451,
  [10533] = 10533,
  [10534] = 10364,
  [10535] = 10365,
  [10536] = 10366,
  [10537] = 10356,
  [10538] = 10368,
  [10539] = 10369,
  [10540] = 10370,
  [10541] = 10371,
  [10542] = 10373,
  [10543] = 10374,
  [10544] = 10374,
  [10545] = 10377,
  [10546] = 10452,
  [10547] = 10424,
  [10548] = 10379,
  [10549] = 10453,
  [10550] = 10381,
  [10551] = 10444,
  [10552] = 10382,
  [10553] = 10454,
  [10554] = 10554,
  [10555] = 10449,
  [10556] = 10455,
  [10557] = 10456,
  [10558] = 10511,
  [10559] = 10386,
  [10560] = 10387,
  [10561] = 10457,
  [10562] = 10460,
  [10563] = 10413,
  [10564] = 10564,
  [10565] = 10391,
  [10566] = 10392,
  [10567] = 10414,
  [10568] = 10394,
  [10569] = 10395,
  [10570] = 10396,
  [10571] = 10397,
  [10572] = 10398,
  [10573] = 10399,
  [10574] = 10400,
  [10575] = 10360,
  [10576] = 10375,
  [10577] = 10577,
  [10578] = 10376,
  [10579] = 10378,
  [10580] = 10383,
  [10581] = 10581,
  [10582] = 10385,
  [10583] = 10388,
  [10584] = 10393,
  [10585] = 10410,
  [10586] = 10411,
  [10587] = 10415,
  [10588] = 10389,
  [10589] = 10486,
  [10590] = 10590,
  [10591] = 10591,
  [10592] = 10509,
  [10593] = 10593,
  [10594] = 10416,
  [10595] = 10417,
  [10596] = 10511,
  [10597] = 10420,
  [10598] = 10444,
  [10599] = 10599,
  [10600] = 10481,
  [10601] = 10449,
  [10602] = 10428,
  [10603] = 10496,
  [10604] = 10497,
  [10605] = 10481,
  [10606] = 10358,
  [10607] = 10359,
  [10608] = 10430,
  [10609] = 10361,
  [10610] = 10362,
  [10611] = 10364,
  [10612] = 10365,
  [10613] = 10366,
  [10614] = 10356,
  [10615] = 10368,
  [10616] = 10369,
  [10617] = 10370,
  [10618] = 10371,
  [10619] = 10421,
  [10620] = 10373,
  [10621] = 10374,
  [10622] = 10509,
  [10623] = 10623,
  [10624] = 10377,
  [10625] = 10444,
  [10626] = 10379,
  [10627] = 10449,
  [10628] = 10425,
  [10629] = 10381,
  [10630] = 10382,
  [10631] = 10413,
  [10632] = 10414,
  [10633] = 10415,
  [10634] = 10634,
  [10635] = 10635,
  [10636] = 10386,
  [10637] = 10387,
  [10638] = 10416,
  [10639] = 10417,
  [10640] = 10377,
  [10641] = 10391,
  [10642] = 10392,
  [10643] = 10420,
  [10644] = 10394,
  [10645] = 10395,
  [10646] = 10396,
  [10647] = 10397,
  [10648] = 10444,
  [10649] = 10449,
  [10650] = 10398,
  [10651] = 10379,
  [10652] = 10399,
  [10653] = 10400,
  [10654] = 10360,
  [10655] = 10375,
  [10656] = 10376,
  [10657] = 10378,
  [10658] = 10383,
  [10659] = 10421,
  [10660] = 10385,
  [10661] = 10388,
  [10662] = 10444,
  [10663] = 10449,
  [10664] = 10393,
  [10665] = 10410,
  [10666] = 10411,
  [10667] = 10413,
  [10668] = 10420,
  [10669] = 10414,
  [10670] = 10415,
  [10671] = 10444,
  [10672] = 10421,
  [10673] = 10449,
  [10674] = 10416,
  [10675] = 10417,
  [10676] = 10431,
  [10677] = 10381,
  [10678] = 10420,
  [10679] = 10421,
  [10680] = 10432,
  [10681] = 10444,
  [10682] = 10449,
  [10683] = 10382,
  [10684] = 10422,
  [10685] = 10426,
  [10686] = 10428,
  [10687] = 10430,
  [10688] = 10431,
  [10689] = 10444,
  [10690] = 10449,
  [10691] = 10432,
  [10692] = 10435,
  [10693] = 10436,
  [10694] = 10422,
  [10695] = 10437,
  [10696] = 10438,
  [10697] = 10439,
  [10698] = 10440,
  [10699] = 10441,
  [10700] = 10444,
  [10701] = 10442,
  [10702] = 10449,
  [10703] = 10443,
  [10704] = 10426,
  [10705] = 10450,
  [10706] = 10444,
  [10707] = 10451,
  [10708] = 10449,
  [10709] = 10709,
  [10710] = 10452,
  [10711] = 10453,
  [10712] = 10454,
  [10713] = 10455,
  [10714] = 10456,
  [10715] = 10444,
  [10716] = 10449,
  [10717] = 10457,
  [10718] = 10460,
  [10719] = 10389,
  [10720] = 10428,
  [10721] = 10464,
  [10722] = 10466,
  [10723] = 8335,
  [10724] = 10444,
  [10725] = 10449,
  [10726] = 10467,
  [10727] = 10468,
  [10728] = 10469,
  [10729] = 10470,
  [10730] = 10445,
  [10731] = 10446,
  [10732] = 10732,
  [10733] = 10447,
  [10734] = 10448,
  [10735] = 10430,
  [10736] = 10461,
  [10737] = 10357,
  [10738] = 10431,
  [10739] = 10363,
  [10740] = 10372,
  [10741] = 10432,
  [10742] = 10435,
  [10743] = 10487,
  [10744] = 10488,
  [10745] = 10489,
  [10746] = 10490,
  [10747] = 10436,
  [10748] = 10437,
  [10749] = 10438,
  [10750] = 10439,
  [10751] = 10386,
  [10752] = 10440,
  [10753] = 10441,
  [10754] = 10442,
  [10755] = 10443,
  [10756] = 10422,
  [10757] = 10757,
  [10758] = 10758,
  [10759] = 10426,
  [10760] = 10486,
  [10761] = 10380,
  [10762] = 10762,
  [10763] = 10406,
  [10764] = 10387,
  [10765] = 10765,
  [10766] = 10766,
  [10767] = 10464,
  [10768] = 10466,
  [10769] = 10769,
  [10770] = 10379,
  [10771] = 10450,
  [10772] = 10451,
  [10773] = 10452,
  [10774] = 10453,
  [10775] = 10454,
  [10776] = 10455,
  [10777] = 10456,
  [10778] = 10457,
  [10779] = 10497,
  [10780] = 10428,
  [10781] = 10430,
  [10782] = 10431,
  [10783] = 10432,
  [10784] = 8254,
  [10785] = 10785,
  [10786] = 10509,
  [10787] = 10464,
  [10788] = 10466,
  [10789] = 10435,
  [10790] = 10406,
  [10791] = 10765,
  [10792] = 10467,
  [10793] = 10468,
  [10794] = 10389,
  [10795] = 10486,
  [10796] = 10469,
  [10797] = 10470,
  [10798] = 10509,
  [10799] = 10799,
  [10800] = 10406,
  [10801] = 10765,
  [10802] = 10481,
  [10803] = 10411,
  [10804] = 10361,
  [10805] = 10436,
  [10806] = 10496,
  [10807] = 10497,
  [10808] = 10808,
  [10809] = 10358,
  [10810] = 10359,
  [10811] = 10361,
  [10812] = 10362,
  [10813] = 10813,
  [10814] = 10369,
  [10815] = 10370,
  [10816] = 10371,
  [10817] = 10373,
  [10818] = 10374,
  [10819] = 10445,
  [10820] = 10406,
  [10821] = 10765,
  [10822] = 10446,
  [10823] = 10447,
  [10824] = 10377,
  [10825] = 10448,
  [10826] = 10381,
  [10827] = 10382,
  [10828] = 10381,
  [10829] = 10461,
  [10830] = 10357,
  [10831] = 10437,
  [10832] = 10406,
  [10833] = 10765,
  [10834] = 10386,
  [10835] = 10387,
  [10836] = 10360,
  [10837] = 10375,
  [10838] = 10376,
  [10839] = 10378,
  [10840] = 10383,
  [10841] = 10363,
  [10842] = 10385,
  [10843] = 10406,
  [10844] = 10765,
  [10845] = 10388,
  [10846] = 10372,
  [10847] = 10406,
  [10848] = 10765,
  [10849] = 10393,
  [10850] = 10410,
  [10851] = 10411,
  [10852] = 10420,
  [10853] = 10421,
  [10854] = 10438,
  [10855] = 10422,
  [10856] = 10426,
  [10857] = 10439,
  [10858] = 10440,
  [10859] = 10441,
  [10860] = 10577,
  [10861] = 10442,
  [10862] = 10443,
  [10863] = 10464,
  [10864] = 10466,
  [10865] = 10439,
  [10866] = 10440,
  [10867] = 10441,
  [10868] = 10442,
  [10869] = 10487,
  [10870] = 10488,
  [10871] = 10489,
  [10872] = 10490,
  [10873] = 10873,
  [10874] = 10443,
  [10875] = 10382,
  [10876] = 10496,
  [10877] = 10877,
  [10878] = 10467,
  [10879] = 10468,
  [10880] = 10880,
  [10881] = 10389,
  [10882] = 10486,
  [10883] = 10509,
  [10884] = 10469,
  [10885] = 10885,
  [10886] = 10497,
  [10887] = 10435,
  [10888] = 10481,
  [10889] = 10889,
  [10890] = 10470,
  [10891] = 10496,
  [10892] = 10497,
  [10893] = 10358,
  [10894] = 10359,
  [10895] = 10577,
  [10896] = 10361,
  [10897] = 10362,
  [10898] = 10898,
  [10899] = 10369,
  [10900] = 10358,
  [10901] = 10370,
  [10902] = 10371,
  [10903] = 10373,
  [10904] = 10374,
  [10905] = 10359,
  [10906] = 10906,
  [10907] = 10377,
  [10908] = 10381,
  [10909] = 10382,
  [10910] = 10386,
  [10911] = 10387,
  [10912] = 10360,
  [10913] = 10375,
  [10914] = 10376,
  [10915] = 10378,
  [10916] = 10383,
  [10917] = 10386,
  [10918] = 10385,
  [10919] = 10388,
  [10920] = 10393,
  [10921] = 10410,
  [10922] = 10411,
  [10923] = 10420,
  [10924] = 10421,
  [10925] = 10422,
  [10926] = 10426,
  [10927] = 10439,
  [10928] = 10440,
  [10929] = 10441,
  [10930] = 10442,
  [10931] = 10443,
  [10932] = 10464,
  [10933] = 10466,
  [10934] = 10387,
  [10935] = 10935,
  [10936] = 10450,
  [10937] = 10451,
  [10938] = 10452,
  [10939] = 10453,
  [10940] = 10454,
  [10941] = 10455,
  [10942] = 10456,
  [10943] = 10577,
  [10944] = 10457,
  [10945] = 10460,
  [10946] = 10436,
  [10947] = 10947,
  [10948] = 10948,
  [10949] = 10949,
  [10950] = 10950,
  [10951] = 10487,
  [10952] = 10488,
  [10953] = 10362,
  [10954] = 10464,
  [10955] = 10466,
  [10956] = 10389,
  [10957] = 10486,
  [10958] = 10509,
  [10959] = 10959,
  [10960] = 10960,
  [10961] = 10437,
  [10962] = 10438,
  [10963] = 10577,
  [10964] = 10489,
  [10965] = 10496,
  [10966] = 10497,
  [10967] = 10358,
  [10968] = 10359,
  [10969] = 10361,
  [10970] = 10362,
  [10971] = 10971,
  [10972] = 10377,
  [10973] = 10381,
  [10974] = 10382,
  [10975] = 10386,
  [10976] = 10387,
  [10977] = 10577,
  [10978] = 10411,
  [10979] = 10420,
  [10980] = 10421,
  [10981] = 10981,
  [10982] = 10422,
  [10983] = 10983,
  [10984] = 10426,
  [10985] = 10443,
  [10986] = 10464,
  [10987] = 10466,
  [10988] = 10988,
  [10989] = 10439,
  [10990] = 10361,
  [10991] = 10440,
  [10992] = 10422,
  [10993] = 10426,
  [10994] = 10441,
  [10995] = 10442,
  [10996] = 10765,
  [10997] = 10997,
  [10998] = 10490,
  [10999] = 10999,
  [11000] = 10511,
  [11001] = 10389,
  [11002] = 10486,
  [11003] = 10467,
  [11004] = 10496,
  [11005] = 10497,
  [11006] = 10358,
  [11007] = 10359,
  [11008] = 10468,
  [11009] = 10469,
  [11010] = 10381,
  [11011] = 10382,
  [11012] = 10470,
  [11013] = 10386,
  [11014] = 10387,
  [11015] = 10420,
  [11016] = 10421,
  [11017] = 10422,
  [11018] = 10426,
  [11019] = 10464,
  [11020] = 10466,
  [11021] = 10443,
  [11022] = 10413,
  [11023] = 11023,
  [11024] = 11024,
  [11025] = 10391,
  [11026] = 10389,
  [11027] = 10486,
  [11028] = 10391,
  [11029] = 10392,
  [11030] = 10496,
  [11031] = 10497,
  [11032] = 10358,
  [11033] = 10359,
  [11034] = 10394,
  [11035] = 10395,
  [11036] = 10381,
  [11037] = 10382,
  [11038] = 10386,
  [11039] = 10387,
  [11040] = 10396,
  [11041] = 10420,
  [11042] = 10421,
  [11043] = 10422,
  [11044] = 10426,
  [11045] = 10464,
  [11046] = 10466,
  [11047] = 10397,
  [11048] = 10398,
  [11049] = 10392,
  [11050] = 10394,
  [11051] = 10395,
  [11052] = 10399,
  [11053] = 10400,
  [11054] = 10360,
  [11055] = 10766,
  [11056] = 10375,
  [11057] = 10396,
  [11058] = 10397,
  [11059] = 10376,
  [11060] = 10378,
  [11061] = 10398,
  [11062] = 10399,
  [11063] = 10389,
  [11064] = 10486,
  [11065] = 10496,
  [11066] = 10383,
  [11067] = 10497,
  [11068] = 10358,
  [11069] = 10359,
  [11070] = 10381,
  [11071] = 10382,
  [11072] = 10386,
  [11073] = 10387,
  [11074] = 10420,
  [11075] = 10421,
  [11076] = 10445,
  [11077] = 10422,
  [11078] = 10426,
  [11079] = 10464,
  [11080] = 10466,
  [11081] = 10389,
  [11082] = 10486,
  [11083] = 10446,
  [11084] = 10447,
  [11085] = 10509,
  [11086] = 10511,
  [11087] = 10448,
  [11088] = 10400,
  [11089] = 10389,
  [11090] = 10486,
  [11091] = 10481,
  [11092] = 10461,
  [11093] = 10496,
  [11094] = 10497,
  [11095] = 11095,
  [11096] = 10358,
  [11097] = 10359,
  [11098] = 10381,
  [11099] = 10382,
  [11100] = 10386,
  [11101] = 10387,
  [11102] = 10420,
  [11103] = 10421,
  [11104] = 10422,
  [11105] = 10385,
  [11106] = 10388,
  [11107] = 10426,
  [11108] = 10393,
  [11109] = 10410,
  [11110] = 10464,
  [11111] = 10466,
  [11112] = 10449,
  [11113] = 10496,
  [11114] = 10460,
  [11115] = 11115,
  [11116] = 11116,
  [11117] = 11117,
  [11118] = 11118,
  [11119] = 1244,
  [11120] = 11120,
  [11121] = 11121,
  [11122] = 11122,
  [11123] = 11123,
  [11124] = 11124,
  [11125] = 3763,
  [11126] = 11126,
  [11127] = 11127,
  [11128] = 11128,
  [11129] = 11129,
  [11130] = 11130,
  [11131] = 11131,
  [11132] = 11132,
  [11133] = 11133,
  [11134] = 11134,
  [11135] = 11135,
  [11136] = 11136,
  [11137] = 8712,
  [11138] = 11127,
  [11139] = 11139,
  [11140] = 11127,
  [11141] = 11127,
  [11142] = 11142,
  [11143] = 11143,
  [11144] = 11144,
  [11145] = 11115,
  [11146] = 11124,
  [11147] = 11115,
  [11148] = 11124,
  [11149] = 11149,
  [11150] = 11150,
  [11151] = 11151,
  [11152] = 11135,
  [11153] = 11153,
  [11154] = 11122,
  [11155] = 11155,
  [11156] = 11156,
  [11157] = 11157,
  [11158] = 11120,
  [11159] = 11127,
  [11160] = 11160,
  [11161] = 11161,
  [11162] = 11162,
  [11163] = 11122,
  [11164] = 11130,
  [11165] = 11136,
  [11166] = 11166,
  [11167] = 11115,
  [11168] = 11168,
  [11169] = 11169,
  [11170] = 11170,
  [11171] = 11151,
  [11172] = 11172,
  [11173] = 11136,
  [11174] = 11174,
  [11175] = 11175,
  [11176] = 11176,
  [11177] = 11177,
  [11178] = 11127,
  [11179] = 11115,
  [11180] = 11124,
  [11181] = 11150,
  [11182] = 11128,
  [11183] = 11127,
  [11184] = 11184,
  [11185] = 11115,
  [11186] = 11135,
  [11187] = 11127,
  [11188] = 11174,
  [11189] = 11189,
  [11190] = 11151,
  [11191] = 11191,
  [11192] = 11166,
  [11193] = 8500,
  [11194] = 11122,
  [11195] = 11128,
  [11196] = 11174,
  [11197] = 11197,
  [11198] = 11198,
  [11199] = 5937,
  [11200] = 5925,
  [11201] = 11174,
  [11202] = 11122,
  [11203] = 11203,
  [11204] = 11120,
  [11205] = 11205,
  [11206] = 11122,
  [11207] = 11189,
  [11208] = 11115,
  [11209] = 11135,
  [11210] = 11122,
  [11211] = 11120,
  [11212] = 11212,
  [11213] = 11213,
  [11214] = 11151,
  [11215] = 11136,
  [11216] = 11216,
  [11217] = 11120,
  [11218] = 11135,
  [11219] = 11151,
  [11220] = 11220,
  [11221] = 11221,
  [11222] = 11174,
  [11223] = 11174,
  [11224] = 11176,
  [11225] = 11135,
  [11226] = 11226,
  [11227] = 11174,
  [11228] = 11228,
  [11229] = 11229,
  [11230] = 11197,
  [11231] = 11120,
  [11232] = 3680,
  [11233] = 11127,
  [11234] = 11115,
  [11235] = 8353,
  [11236] = 11236,
  [11237] = 11166,
  [11238] = 11166,
  [11239] = 11126,
  [11240] = 11240,
  [11241] = 11241,
  [11242] = 11127,
  [11243] = 11133,
  [11244] = 11120,
  [11245] = 11245,
  [11246] = 11124,
  [11247] = 11150,
  [11248] = 11176,
  [11249] = 11120,
  [11250] = 11122,
  [11251] = 11174,
  [11252] = 11252,
  [11253] = 11253,
  [11254] = 11254,
  [11255] = 11255,
  [11256] = 11256,
  [11257] = 11257,
  [11258] = 11258,
  [11259] = 11259,
  [11260] = 11260,
  [11261] = 11261,
  [11262] = 11262,
  [11263] = 11263,
  [11264] = 11264,
  [11265] = 11265,
  [11266] = 11266,
  [11267] = 11267,
  [11268] = 11268,
  [11269] = 11269,
  [11270] = 11270,
  [11271] = 11271,
  [11272] = 11272,
  [11273] = 11273,
  [11274] = 11274,
  [11275] = 11275,
  [11276] = 11276,
  [11277] = 11277,
  [11278] = 11278,
  [11279] = 11279,
  [11280] = 11280,
  [11281] = 11281,
  [11282] = 11282,
  [11283] = 11283,
  [11284] = 11284,
  [11285] = 11285,
  [11286] = 11286,
  [11287] = 11287,
  [11288] = 11288,
  [11289] = 11271,
  [11290] = 11272,
  [11291] = 11291,
  [11292] = 11292,
  [11293] = 11293,
  [11294] = 11294,
  [11295] = 11295,
  [11296] = 11296,
  [11297] = 11291,
  [11298] = 11298,
  [11299] = 11299,
  [11300] = 11300,
  [11301] = 11301,
  [11302] = 11302,
  [11303] = 11303,
  [11304] = 11274,
  [11305] = 11277,
  [11306] = 11280,
  [11307] = 11271,
  [11308] = 11272,
  [11309] = 11282,
  [11310] = 11287,
  [11311] = 11288,
  [11312] = 11292,
  [11313] = 11313,
  [11314] = 11294,
  [11315] = 11296,
  [11316] = 11316,
  [11317] = 11317,
  [11318] = 11318,
  [11319] = 11319,
  [11320] = 11320,
  [11321] = 11303,
  [11322] = 11271,
  [11323] = 11272,
  [11324] = 11324,
  [11325] = 11325,
  [11326] = 11324,
  [11327] = 11327,
  [11328] = 11328,
  [11329] = 11325,
  [11330] = 11330,
  [11331] = 11331,
  [11332] = 11332,
  [11333] = 11333,
  [11334] = 11334,
  [11335] = 11313,
  [11336] = 11336,
  [11337] = 11337,
  [11338] = 11338,
  [11339] = 11339,
  [11340] = 11337,
  [11341] = 11341,
  [11342] = 11331,
  [11343] = 11343,
  [11344] = 11344,
  [11345] = 11345,
  [11346] = 11346,
  [11347] = 11347,
  [11348] = 11348,
  [11349] = 11349,
  [11350] = 11350,
  [11351] = 11271,
  [11352] = 11352,
  [11353] = 11272,
  [11354] = 11354,
  [11355] = 11355,
  [11356] = 11356,
  [11357] = 11357,
  [11358] = 11358,
  [11359] = 11359,
  [11360] = 11360,
  [11361] = 11361,
  [11362] = 11362,
  [11363] = 11363,
  [11364] = 11364,
  [11365] = 11365,
  [11366] = 11366,
  [11367] = 11332,
  [11368] = 11368,
  [11369] = 11369,
  [11370] = 11370,
  [11371] = 11334,
  [11372] = 11343,
  [11373] = 11373,
  [11374] = 11341,
  [11375] = 11345,
  [11376] = 11350,
  [11377] = 11377,
  [11378] = 1735,
  [11379] = 11379,
  [11380] = 11380,
  [11381] = 11381,
  [11382] = 11382,
  [11383] = 11383,
  [11384] = 11384,
  [11385] = 11385,
  [11386] = 11386,
  [11387] = 11387,
  [11388] = 11388,
  [11389] = 11389,
  [11390] = 11390,
  [11391] = 11391,
  [11392] = 11313,
  [11393] = 11393,
  [11394] = 11394,
  [11395] = 11395,
  [11396] = 11396,
  [11397] = 11397,
  [11398] = 11352,
  [11399] = 11327,
  [11400] = 11400,
  [11401] = 11401,
  [11402] = 11274,
  [11403] = 11403,
  [11404] = 11404,
  [11405] = 11405,
  [11406] = 11406,
  [11407] = 11407,
  [11408] = 11408,
  [11409] = 11409,
  [11410] = 11277,
  [11411] = 11411,
  [11412] = 11412,
  [11413] = 11413,
  [11414] = 11414,
  [11415] = 11415,
  [11416] = 11416,
  [11417] = 11417,
  [11418] = 11418,
  [11419] = 11419,
  [11420] = 11420,
  [11421] = 11421,
  [11422] = 11422,
  [11423] = 11403,
  [11424] = 11424,
  [11425] = 11283,
  [11426] = 11316,
  [11427] = 11281,
  [11428] = 11428,
  [11429] = 11429,
  [11430] = 11430,
  [11431] = 11431,
  [11432] = 11432,
  [11433] = 11422,
  [11434] = 11430,
  [11435] = 11435,
  [11436] = 11436,
  [11437] = 11437,
  [11438] = 11438,
  [11439] = 11261,
  [11440] = 11404,
  [11441] = 11441,
  [11442] = 11442,
  [11443] = 11443,
  [11444] = 11444,
  [11445] = 11445,
  [11446] = 11446,
  [11447] = 11447,
  [11448] = 11448,
  [11449] = 11449,
  [11450] = 11450,
  [11451] = 11451,
  [11452] = 11452,
  [11453] = 11453,
  [11454] = 11454,
  [11455] = 11455,
  [11456] = 11456,
  [11457] = 11457,
  [11458] = 11458,
  [11459] = 11459,
  [11460] = 11253,
  [11461] = 11461,
  [11462] = 11462,
  [11463] = 11463,
  [11464] = 11464,
  [11465] = 11465,
  [11466] = 11466,
  [11467] = 11467,
  [11468] = 11468,
  [11469] = 11469,
  [11470] = 11470,
  [11471] = 11441,
  [11472] = 11472,
  [11473] = 11473,
  [11474] = 11474,
  [11475] = 11475,
  [11476] = 11432,
  [11477] = 11477,
  [11478] = 11478,
  [11479] = 11479,
  [11480] = 11480,
  [11481] = 11481,
  [11482] = 11482,
  [11483] = 11483,
  [11484] = 11484,
  [11485] = 11470,
  [11486] = 11486,
  [11487] = 11473,
  [11488] = 11488,
  [11489] = 11489,
  [11490] = 11490,
  [11491] = 11488,
  [11492] = 11492,
  [11493] = 11493,
  [11494] = 11408,
  [11495] = 11255,
  [11496] = 11496,
  [11497] = 11279,
  [11498] = 11357,
  [11499] = 11286,
  [11500] = 11500,
  [11501] = 11501,
  [11502] = 11502,
  [11503] = 11503,
  [11504] = 11504,
  [11505] = 11505,
  [11506] = 11429,
  [11507] = 11507,
  [11508] = 11508,
  [11509] = 11509,
  [11510] = 11510,
  [11511] = 11339,
  [11512] = 11512,
  [11513] = 11285,
  [11514] = 11318,
  [11515] = 11515,
  [11516] = 11389,
  [11517] = 11377,
  [11518] = 11518,
  [11519] = 11519,
  [11520] = 11428,
  [11521] = 11521,
  [11522] = 11522,
  [11523] = 11523,
  [11524] = 11276,
  [11525] = 11360,
  [11526] = 11526,
  [11527] = 11527,
  [11528] = 11528,
  [11529] = 11379,
  [11530] = 11530,
  [11531] = 11531,
  [11532] = 11532,
  [11533] = 11533,
  [11534] = 11530,
  [11535] = 11486,
  [11536] = 11397,
  [11537] = 11537,
  [11538] = 11538,
  [11539] = 11528,
  [11540] = 11540,
  [11541] = 11541,
  [11542] = 11542,
  [11543] = 11472,
  [11544] = 11544,
  [11545] = 11369,
  [11546] = 11546,
  [11547] = 11547,
  [11548] = 11548,
  [11549] = 8778,
  [11550] = 11550,
  [11551] = 11551,
  [11552] = 11552,
  [11553] = 11380,
  [11554] = 11554,
  [11555] = 11555,
  [11556] = 11556,
  [11557] = 11442,
  [11558] = 11414,
  [11559] = 11339,
  [11560] = 11416,
  [11561] = 11418,
  [11562] = 11403,
  [11563] = 11563,
  [11564] = 11283,
  [11565] = 11316,
  [11566] = 11443,
  [11567] = 11567,
  [11568] = 11444,
  [11569] = 11432,
  [11570] = 11437,
  [11571] = 11438,
  [11572] = 11261,
  [11573] = 11442,
  [11574] = 11443,
  [11575] = 11444,
  [11576] = 11445,
  [11577] = 11446,
  [11578] = 11448,
  [11579] = 11449,
  [11580] = 11450,
  [11581] = 11451,
  [11582] = 11452,
  [11583] = 11453,
  [11584] = 11454,
  [11585] = 11455,
  [11586] = 11456,
  [11587] = 11457,
  [11588] = 11458,
  [11589] = 11459,
  [11590] = 11253,
  [11591] = 11461,
  [11592] = 11462,
  [11593] = 11463,
  [11594] = 11464,
  [11595] = 11465,
  [11596] = 11466,
  [11597] = 11467,
  [11598] = 11468,
  [11599] = 11469,
  [11600] = 11600,
  [11601] = 11295,
  [11602] = 11602,
  [11603] = 11383,
  [11604] = 11482,
  [11605] = 11484,
  [11606] = 11470,
  [11607] = 11486,
  [11608] = 11473,
  [11609] = 11488,
  [11610] = 11489,
  [11611] = 11490,
  [11612] = 11408,
  [11613] = 11445,
  [11614] = 11384,
  [11615] = 11259,
  [11616] = 11616,
  [11617] = 11617,
  [11618] = 11618,
  [11619] = 11501,
  [11620] = 11502,
  [11621] = 11621,
  [11622] = 11504,
  [11623] = 11386,
  [11624] = 11624,
  [11625] = 11625,
  [11626] = 11509,
  [11627] = 11512,
  [11628] = 11285,
  [11629] = 11318,
  [11630] = 11630,
  [11631] = 11518,
  [11632] = 11519,
  [11633] = 11633,
  [11634] = 11360,
  [11635] = 11526,
  [11636] = 11636,
  [11637] = 11637,
  [11638] = 11338,
  [11639] = 11639,
  [11640] = 11541,
  [11641] = 11641,
  [11642] = 11546,
  [11643] = 11547,
  [11644] = 11352,
  [11645] = 11446,
  [11646] = 11550,
  [11647] = 11551,
  [11648] = 11278,
  [11649] = 11649,
  [11650] = 11554,
  [11651] = 11555,
  [11652] = 11556,
  [11653] = 11447,
  [11654] = 11414,
  [11655] = 11284,
  [11656] = 11416,
  [11657] = 11418,
  [11658] = 11403,
  [11659] = 11331,
  [11660] = 11283,
  [11661] = 11661,
  [11662] = 11343,
  [11663] = 11437,
  [11664] = 11438,
  [11665] = 11261,
  [11666] = 11454,
  [11667] = 11455,
  [11668] = 11456,
  [11669] = 11457,
  [11670] = 11458,
  [11671] = 11459,
  [11672] = 11515,
  [11673] = 11461,
  [11674] = 11462,
  [11675] = 11463,
  [11676] = 11464,
  [11677] = 11465,
  [11678] = 11466,
  [11679] = 11467,
  [11680] = 11468,
  [11681] = 11469,
  [11682] = 11388,
  [11683] = 11683,
  [11684] = 11684,
  [11685] = 11482,
  [11686] = 11470,
  [11687] = 11486,
  [11688] = 11473,
  [11689] = 11488,
  [11690] = 11408,
  [11691] = 11691,
  [11692] = 11286,
  [11693] = 11448,
  [11694] = 11694,
  [11695] = 11695,
  [11696] = 11696,
  [11697] = 11501,
  [11698] = 11502,
  [11699] = 11515,
  [11700] = 11504,
  [11701] = 11701,
  [11702] = 11702,
  [11703] = 11349,
  [11704] = 11509,
  [11705] = 11512,
  [11706] = 11285,
  [11707] = 11318,
  [11708] = 11708,
  [11709] = 11518,
  [11710] = 11519,
  [11711] = 11711,
  [11712] = 11360,
  [11713] = 11526,
  [11714] = 11714,
  [11715] = 11390,
  [11716] = 11391,
  [11717] = 11449,
  [11718] = 11541,
  [11719] = 11393,
  [11720] = 11546,
  [11721] = 11547,
  [11722] = 11396,
  [11723] = 11723,
  [11724] = 11550,
  [11725] = 11551,
  [11726] = 11726,
  [11727] = 11727,
  [11728] = 11554,
  [11729] = 11555,
  [11730] = 11556,
  [11731] = 11437,
  [11732] = 11414,
  [11733] = 11733,
  [11734] = 11416,
  [11735] = 11418,
  [11736] = 11403,
  [11737] = 11737,
  [11738] = 11283,
  [11739] = 11739,
  [11740] = 11265,
  [11741] = 11437,
  [11742] = 11438,
  [11743] = 11261,
  [11744] = 11455,
  [11745] = 11456,
  [11746] = 11746,
  [11747] = 11733,
  [11748] = 11482,
  [11749] = 11408,
  [11750] = 11737,
  [11751] = 11751,
  [11752] = 11752,
  [11753] = 11271,
  [11754] = 11754,
  [11755] = 11501,
  [11756] = 11502,
  [11757] = 11757,
  [11758] = 11504,
  [11759] = 11272,
  [11760] = 11302,
  [11761] = 11509,
  [11762] = 11512,
  [11763] = 11285,
  [11764] = 11318,
  [11765] = 11765,
  [11766] = 11518,
  [11767] = 11519,
  [11768] = 11360,
  [11769] = 11526,
  [11770] = 11354,
  [11771] = 11259,
  [11772] = 11274,
  [11773] = 11277,
  [11774] = 11414,
  [11775] = 11280,
  [11776] = 11418,
  [11777] = 11403,
  [11778] = 11282,
  [11779] = 11287,
  [11780] = 11288,
  [11781] = 11438,
  [11782] = 11261,
  [11783] = 11292,
  [11784] = 11482,
  [11785] = 11294,
  [11786] = 11296,
  [11787] = 11509,
  [11788] = 11518,
  [11789] = 11519,
  [11790] = 11526,
  [11791] = 11303,
  [11792] = 11324,
  [11793] = 11325,
  [11794] = 11356,
  [11795] = 11414,
  [11796] = 11327,
  [11797] = 11403,
  [11798] = 11295,
  [11799] = 11799,
  [11800] = 11800,
  [11801] = 11438,
  [11802] = 11261,
  [11803] = 11482,
  [11804] = 11509,
  [11805] = 11518,
  [11806] = 11519,
  [11807] = 11526,
  [11808] = 11405,
  [11809] = 11403,
  [11810] = 11810,
  [11811] = 11406,
  [11812] = 11339,
  [11813] = 11438,
  [11814] = 11261,
  [11815] = 11482,
  [11816] = 11509,
  [11817] = 11518,
  [11818] = 11519,
  [11819] = 11526,
  [11820] = 11403,
  [11821] = 11258,
  [11822] = 11822,
  [11823] = 11438,
  [11824] = 11261,
  [11825] = 11482,
  [11826] = 11509,
  [11827] = 11518,
  [11828] = 11519,
  [11829] = 11526,
  [11830] = 11407,
  [11831] = 11354,
  [11832] = 11438,
  [11833] = 11261,
  [11834] = 11482,
  [11835] = 11509,
  [11836] = 11518,
  [11837] = 11519,
  [11838] = 11526,
  [11839] = 11331,
  [11840] = 11343,
  [11841] = 11438,
  [11842] = 11261,
  [11843] = 11482,
  [11844] = 11509,
  [11845] = 11518,
  [11846] = 11519,
  [11847] = 11526,
  [11848] = 11848,
  [11849] = 11518,
  [11850] = 11438,
  [11851] = 11261,
  [11852] = 11482,
  [11853] = 11509,
  [11854] = 11518,
  [11855] = 11519,
  [11856] = 11526,
  [11857] = 11438,
  [11858] = 11261,
  [11859] = 11482,
  [11860] = 11509,
  [11861] = 11518,
  [11862] = 11519,
  [11863] = 11526,
  [11864] = 11438,
  [11865] = 11509,
  [11866] = 11518,
  [11867] = 11519,
  [11868] = 11526,
  [11869] = 11438,
  [11870] = 11509,
  [11871] = 11518,
  [11872] = 11519,
  [11873] = 11526,
  [11874] = 11509,
  [11875] = 11518,
  [11876] = 11519,
  [11877] = 11526,
  [11878] = 11509,
  [11879] = 11518,
  [11880] = 11519,
  [11881] = 11526,
  [11882] = 11509,
  [11883] = 11518,
  [11884] = 11519,
  [11885] = 11526,
  [11886] = 11509,
  [11887] = 11518,
  [11888] = 11519,
  [11889] = 11526,
  [11890] = 11694,
  [11891] = 11891,
  [11892] = 11892,
  [11893] = 11893,
  [11894] = 11894,
  [11895] = 11895,
  [11896] = 11896,
  [11897] = 11897,
  [11898] = 11636,
  [11899] = 11899,
  [11900] = 11300,
  [11901] = 11313,
  [11902] = 11902,
  [11903] = 11752,
  [11904] = 11800,
  [11905] = 11328,
  [11906] = 11906,
  [11907] = 11409,
  [11908] = 11908,
  [11909] = 11349,
  [11910] = 11271,
  [11911] = 11272,
  [11912] = 11313,
  [11913] = 11354,
  [11914] = 11914,
  [11915] = 8824,
  [11916] = 11916,
  [11917] = 11411,
  [11918] = 11918,
  [11919] = 11352,
  [11920] = 11617,
  [11921] = 11618,
  [11922] = 11799,
  [11923] = 11923,
  [11924] = 8800,
  [11925] = 11450,
  [11926] = 11415,
  [11927] = 11451,
  [11928] = 11928,
  [11929] = 11452,
  [11930] = 11453,
  [11931] = 11364,
  [11932] = 11932,
  [11933] = 11933,
  [11934] = 11258,
  [11935] = 8821,
  [11936] = 8822,
  [11937] = 11937,
  [11938] = 11938,
  [11939] = 11939,
  [11940] = 11313,
  [11941] = 11388,
  [11942] = 11390,
  [11943] = 11391,
  [11944] = 11393,
  [11945] = 11945,
  [11946] = 11946,
  [11947] = 11396,
  [11948] = 11364,
  [11949] = 11454,
  [11950] = 11950,
  [11951] = 11382,
  [11952] = 11501,
  [11953] = 11455,
  [11954] = 11954,
  [11955] = 11955,
  [11956] = 11502,
  [11957] = 11822,
  [11958] = 11958,
  [11959] = 11504,
  [11960] = 11515,
  [11961] = 11961,
  [11962] = 11962,
  [11963] = 11528,
  [11964] = 11537,
  [11965] = 11965,
  [11966] = 11537,
  [11967] = 11538,
  [11968] = 11405,
  [11969] = 11969,
  [11970] = 11970,
  [11971] = 11971,
  [11972] = 11972,
  [11973] = 11406,
  [11974] = 11407,
  [11975] = 11456,
  [11976] = 11457,
  [11977] = 11977,
  [11978] = 11409,
  [11979] = 11411,
  [11980] = 11415,
  [11981] = 11295,
  [11982] = 11286,
  [11983] = 11723,
  [11984] = 11848,
  [11985] = 11475,
  [11986] = 11458,
  [11987] = 11551,
  [11988] = 11259,
  [11989] = 11459,
  [11990] = 11253,
  [11991] = 11991,
  [11992] = 11992,
  [11993] = 11429,
  [11994] = 11461,
  [11995] = 11892,
  [11996] = 11332,
  [11997] = 11481,
  [11998] = 11492,
  [11999] = 11493,
  [12000] = 12000,
  [12001] = 11600,
  [12002] = 11489,
  [12003] = 11255,
  [12004] = 12004,
  [12005] = 11515,
  [12006] = 12006,
  [12007] = 11334,
  [12008] = 11286,
  [12009] = 11462,
  [12010] = 11463,
  [12011] = 11341,
  [12012] = 11528,
  [12013] = 11464,
  [12014] = 11542,
  [12015] = 11345,
  [12016] = 11350,
  [12017] = 11361,
  [12018] = 12018,
  [12019] = 11344,
  [12020] = 11377,
  [12021] = 12021,
  [12022] = 11617,
  [12023] = 11618,
  [12024] = 11538,
  [12025] = 11379,
  [12026] = 12026,
  [12027] = 11483,
  [12028] = 11955,
  [12029] = 12029,
  [12030] = 12030,
  [12031] = 11380,
  [12032] = 11383,
  [12033] = 11733,
  [12034] = 11737,
  [12035] = 8955,
  [12036] = 11695,
  [12037] = 11537,
  [12038] = 11538,
  [12039] = 11701,
  [12040] = 11384,
  [12041] = 11386,
  [12042] = 12042,
  [12043] = 11799,
  [12044] = 11388,
  [12045] = 11390,
  [12046] = 11391,
  [12047] = 11393,
  [12048] = 12048,
  [12049] = 11396,
  [12050] = 12050,
  [12051] = 12051,
  [12052] = 11481,
  [12053] = 11492,
  [12054] = 11258,
  [12055] = 11822,
  [12056] = 12056,
  [12057] = 11272,
  [12058] = 11537,
  [12059] = 11465,
  [12060] = 11405,
  [12061] = 11406,
  [12062] = 11407,
  [12063] = 11409,
  [12064] = 11411,
  [12065] = 11415,
  [12066] = 11313,
  [12067] = 11421,
  [12068] = 11932,
  [12069] = 12069,
  [12070] = 11352,
  [12071] = 11554,
  [12072] = 11493,
  [12073] = 11349,
  [12074] = 11503,
  [12075] = 11295,
  [12076] = 12076,
  [12077] = 11546,
  [12078] = 11428,
  [12079] = 11258,
  [12080] = 11822,
  [12081] = 11555,
  [12082] = 11259,
  [12083] = 11263,
  [12084] = 11526,
  [12085] = 11702,
  [12086] = 11616,
  [12087] = 11696,
  [12088] = 11617,
  [12089] = 11618,
  [12090] = 12090,
  [12091] = 8794,
  [12092] = 11714,
  [12093] = 12093,
  [12094] = 12094,
  [12095] = 11515,
  [12096] = 11547,
  [12097] = 12097,
  [12098] = 11528,
  [12099] = 11528,
  [12100] = 11510,
  [12101] = 11537,
  [12102] = 11538,
  [12103] = 11397,
  [12104] = 11302,
  [12105] = 11419,
  [12106] = 12106,
  [12107] = 12107,
  [12108] = 11274,
  [12109] = 12109,
  [12110] = 11711,
  [12111] = 12111,
  [12112] = 11277,
  [12113] = 11280,
  [12114] = 11295,
  [12115] = 11282,
  [12116] = 11287,
  [12117] = 11292,
  [12118] = 11259,
  [12119] = 11294,
  [12120] = 12120,
  [12121] = 11296,
  [12122] = 11303,
  [12123] = 11324,
  [12124] = 11325,
  [12125] = 12125,
  [12126] = 12126,
  [12127] = 11327,
  [12128] = 11490,
  [12129] = 11336,
  [12130] = 11366,
  [12131] = 11522,
  [12132] = 12132,
  [12133] = 12133,
  [12134] = 11286,
  [12135] = 11937,
  [12136] = 11259,
  [12137] = 11600,
  [12138] = 11339,
  [12139] = 11617,
  [12140] = 11618,
  [12141] = 12141,
  [12142] = 12142,
  [12143] = 11346,
  [12144] = 11505,
  [12145] = 11331,
  [12146] = 11343,
  [12147] = 12147,
  [12148] = 12148,
  [12149] = 11258,
  [12150] = 11695,
  [12151] = 11349,
  [12152] = 12152,
  [12153] = 11733,
  [12154] = 11737,
  [12155] = 11271,
  [12156] = 12156,
  [12157] = 11272,
  [12158] = 11354,
  [12159] = 11424,
  [12160] = 11478,
  [12161] = 11481,
  [12162] = 11479,
  [12163] = 11258,
  [12164] = 12164,
  [12165] = 11822,
  [12166] = 11617,
  [12167] = 11618,
  [12168] = 11492,
  [12169] = 12094,
  [12170] = 11480,
  [12171] = 11364,
  [12172] = 11493,
  [12173] = 11255,
  [12174] = 11388,
  [12175] = 11390,
  [12176] = 12176,
  [12177] = 12177,
  [12178] = 11279,
  [12179] = 11357,
  [12180] = 11365,
  [12181] = 11313,
  [12182] = 11617,
  [12183] = 11618,
  [12184] = 11914,
  [12185] = 12185,
  [12186] = 11416,
  [12187] = 11429,
  [12188] = 11352,
  [12189] = 11702,
  [12190] = 11617,
  [12191] = 11618,
  [12192] = 11286,
  [12193] = 12193,
  [12194] = 11484,
  [12195] = 11263,
  [12196] = 11899,
  [12197] = 12197,
  [12198] = 11617,
  [12199] = 11618,
  [12200] = 12200,
  [12201] = 11714,
  [12202] = 11923,
  [12203] = 11280,
  [12204] = 12204,
  [12205] = 11617,
  [12206] = 11618,
  [12207] = 11263,
  [12208] = 11649,
  [12209] = 11295,
  [12210] = 11939,
  [12211] = 11313,
  [12212] = 11617,
  [12213] = 11618,
  [12214] = 11733,
  [12215] = 12215,
  [12216] = 11355,
  [12217] = 11282,
  [12218] = 12218,
  [12219] = 11617,
  [12220] = 11618,
  [12221] = 12221,
  [12222] = 11356,
  [12223] = 11466,
  [12224] = 8791,
  [12225] = 11515,
  [12226] = 11617,
  [12227] = 11618,
  [12228] = 12228,
  [12229] = 11313,
  [12230] = 11528,
  [12231] = 11467,
  [12232] = 11600,
  [12233] = 11617,
  [12234] = 11414,
  [12235] = 11295,
  [12236] = 11538,
  [12237] = 11695,
  [12238] = 11617,
  [12239] = 11702,
  [12240] = 12240,
  [12241] = 11287,
  [12242] = 11468,
  [12243] = 11469,
  [12244] = 12244,
  [12245] = 12245,
  [12246] = 12246,
  [12247] = 11352,
  [12248] = 12248,
  [12249] = 11714,
  [12250] = 11435,
  [12251] = 11733,
  [12252] = 11737,
  [12253] = 12253,
  [12254] = 12254,
  [12255] = 11515,
  [12256] = 11397,
  [12257] = 11739,
  [12258] = 12258,
  [12259] = 11258,
  [12260] = 11822,
  [12261] = 11436,
  [12262] = 11916,
  [12263] = 11288,
  [12264] = 11737,
  [12265] = 11302,
  [12266] = 12000,
  [12267] = 12267,
  [12268] = 12268,
  [12269] = 11313,
  [12270] = 12270,
  [12271] = 8789,
  [12272] = 11359,
  [12273] = 12273,
  [12274] = 12274,
  [12275] = 12275,
  [12276] = 12276,
  [12277] = 12277,
  [12278] = 12278,
  [12279] = 12279,
  [12280] = 12280,
  [12281] = 11532,
  [12282] = 11533,
  [12283] = 11563,
  [12284] = 11630,
  [12285] = 11639,
  [12286] = 12215,
  [12287] = 12228,
  [12288] = 12254,
  [12289] = 12289,
  [12290] = 12290,
  [12291] = 11810,
  [12292] = 12056,
  [12293] = 12097,
  [12294] = 12106,
  [12295] = 12246,
  [12296] = 12248,
  [12297] = 12297,
  [12298] = 12298,
  [12299] = 12299,
  [12300] = 12300,
  [12301] = 12301,
  [12302] = 12204,
  [12303] = 12303,
  [12304] = 11317,
  [12305] = 11552,
  [12306] = 11269,
  [12307] = 11352,
  [12308] = 11264,
  [12309] = 11319,
  [12310] = 11708,
  [12311] = 12311,
  [12312] = 12312,
  [12313] = 12313,
  [12314] = 12314,
  [12315] = 12315,
  [12316] = 11258,
  [12317] = 11327,
  [12318] = 11822,
  [12319] = 11733,
  [12320] = 11515,
  [12321] = 12164,
  [12322] = 11496,
  [12323] = 12323,
  [12324] = 11362,
  [12325] = 11661,
  [12326] = 11292,
  [12327] = 11938,
  [12328] = 12311,
  [12329] = 11352,
  [12330] = 11962,
  [12331] = 11268,
  [12332] = 11500,
  [12333] = 11891,
  [12334] = 11540,
  [12335] = 11515,
  [12336] = 12336,
  [12337] = 12000,
  [12338] = 12267,
  [12339] = 12268,
  [12340] = 12270,
  [12341] = 11359,
  [12342] = 12275,
  [12343] = 12276,
  [12344] = 12277,
  [12345] = 12278,
  [12346] = 12279,
  [12347] = 11532,
  [12348] = 11533,
  [12349] = 11563,
  [12350] = 11630,
  [12351] = 11639,
  [12352] = 12215,
  [12353] = 12228,
  [12354] = 12254,
  [12355] = 12289,
  [12356] = 12290,
  [12357] = 11810,
  [12358] = 12056,
  [12359] = 12097,
  [12360] = 12106,
  [12361] = 12246,
  [12362] = 12248,
  [12363] = 12297,
  [12364] = 12298,
  [12365] = 12299,
  [12366] = 12300,
  [12367] = 12301,
  [12368] = 12204,
  [12369] = 12258,
  [12370] = 11264,
  [12371] = 11708,
  [12372] = 12311,
  [12373] = 12312,
  [12374] = 12313,
  [12375] = 12314,
  [12376] = 12315,
  [12377] = 12377,
  [12378] = 12378,
  [12379] = 11339,
  [12380] = 12297,
  [12381] = 11528,
  [12382] = 11971,
  [12383] = 11972,
  [12384] = 12218,
  [12385] = 11733,
  [12386] = 11550,
  [12387] = 12387,
  [12388] = 11331,
  [12389] = 12389,
  [12390] = 12000,
  [12391] = 12267,
  [12392] = 12268,
  [12393] = 11359,
  [12394] = 12215,
  [12395] = 12228,
  [12396] = 12254,
  [12397] = 12289,
  [12398] = 12290,
  [12399] = 11810,
  [12400] = 12056,
  [12401] = 12097,
  [12402] = 12106,
  [12403] = 12246,
  [12404] = 12248,
  [12405] = 12297,
  [12406] = 12298,
  [12407] = 12299,
  [12408] = 12300,
  [12409] = 12301,
  [12410] = 11906,
  [12411] = 11264,
  [12412] = 12311,
  [12413] = 12312,
  [12414] = 12313,
  [12415] = 12314,
  [12416] = 12336,
  [12417] = 12312,
  [12418] = 12418,
  [12419] = 11418,
  [12420] = 11343,
  [12421] = 11291,
  [12422] = 11528,
  [12423] = 11894,
  [12424] = 11515,
  [12425] = 11420,
  [12426] = 11528,
  [12427] = 12427,
  [12428] = 12428,
  [12429] = 12000,
  [12430] = 12267,
  [12431] = 12268,
  [12432] = 11359,
  [12433] = 11295,
  [12434] = 11264,
  [12435] = 11477,
  [12436] = 12313,
  [12437] = 11737,
  [12438] = 11918,
  [12439] = 12439,
  [12440] = 11897,
  [12441] = 11271,
  [12442] = 11272,
  [12443] = 12443,
  [12444] = 12444,
  [12445] = 11733,
  [12446] = 11537,
  [12447] = 12000,
  [12448] = 12267,
  [12449] = 11264,
  [12450] = 12450,
  [12451] = 11352,
  [12452] = 12093,
  [12453] = 12453,
  [12454] = 11733,
  [12455] = 11737,
  [12456] = 11538,
  [12457] = 8792,
  [12458] = 12458,
  [12459] = 12289,
  [12460] = 11737,
  [12461] = 12267,
  [12462] = 11264,
  [12463] = 11258,
  [12464] = 11737,
  [12465] = 11258,
  [12466] = 11537,
  [12467] = 12267,
  [12468] = 11264,
  [12469] = 11275,
  [12470] = 11822,
  [12471] = 11271,
  [12472] = 11538,
  [12473] = 12267,
  [12474] = 11264,
  [12475] = 12475,
  [12476] = 12476,
  [12477] = 11294,
  [12478] = 12298,
  [12479] = 11264,
  [12480] = 11970,
  [12481] = 11313,
  [12482] = 12482,
  [12483] = 12483,
  [12484] = 11264,
  [12485] = 12299,
  [12486] = 11272,
  [12487] = 11352,
  [12488] = 11507,
  [12489] = 11264,
  [12490] = 12490,
  [12491] = 11296,
  [12492] = 12492,
  [12493] = 12300,
  [12494] = 11264,
  [12495] = 12495,
  [12496] = 12496,
  [12497] = 12273,
  [12498] = 11303,
  [12499] = 12499,
  [12500] = 12500,
  [12501] = 12501,
  [12502] = 11302,
  [12503] = 12503,
  [12504] = 11556,
  [12505] = 11895,
  [12506] = 11896,
  [12507] = 11324,
  [12508] = 12508,
  [12509] = 12509,
  [12510] = 11822,
  [12511] = 12511,
  [12512] = 12512,
  [12513] = 12274,
  [12514] = 11302,
  [12515] = 11325,
  [12516] = 12516,
  [12517] = 11478,
  [12518] = 12301,
  [12519] = 12496,
  [12520] = 12520,
  [12521] = 11515,
  [12522] = 12522,
  [12523] = 12387,
  [12524] = 12389,
  [12525] = 12428,
  [12526] = 12516,
  [12527] = 12495,
  [12528] = 12109,
  [12529] = 11633,
  [12530] = 12303,
  [12531] = 12531,
  [12532] = 11295,
  [12533] = 11421,
  [12534] = 12534,
  [12535] = 12503,
  [12536] = 11508,
  [12537] = 11733,
  [12538] = 12538,
  [12539] = 11295,
  [12540] = 12290,
  [12541] = 11331,
  [12542] = 11343,
  [12543] = 12543,
  [12544] = 11737,
  [12545] = 12267,
  [12546] = 11733,
  [12547] = 12109,
  [12548] = 11633,
  [12549] = 11737,
  [12550] = 12550,
  [12551] = 11313,
  [12552] = 11271,
  [12553] = 12553,
  [12554] = 11272,
  [12555] = 11413,
  [12556] = 11258,
  [12557] = 11822,
  [12558] = 12558,
  [12559] = 12559,
  [12560] = 12492,
  [12561] = 12561,
  [12562] = 12562,
  [12563] = 12109,
  [12564] = 11633,
  [12565] = 11313,
  [12566] = 11364,
  [12567] = 12567,
  [12568] = 11352,
  [12569] = 11259,
  [12570] = 11263,
  [12571] = 12571,
  [12572] = 11541,
  [12573] = 12268,
  [12574] = 5399,
  [12575] = 12575,
  [12576] = 12275,
  [12577] = 12109,
  [12578] = 11633,
  [12579] = 12314,
  [12580] = 12276,
  [12581] = 11799,
  [12582] = 11625,
  [12583] = 11902,
  [12584] = 12323,
  [12585] = 12277,
  [12586] = 11633,
  [12587] = 12278,
  [12588] = 11893,
  [12589] = 12279,
  [12590] = 11302,
  [12591] = 11515,
  [12592] = 11394,
  [12593] = 12280,
  [12594] = 11633,
  [12595] = 11295,
  [12596] = 11412,
  [12597] = 11633,
  [12598] = 11273,
  [12599] = 12599,
  [12600] = 11633,
  [12601] = 11262,
  [12602] = 12602,
  [12603] = 11633,
  [12604] = 12567,
  [12605] = 12315,
  [12606] = 11633,
  [12607] = 12575,
  [12608] = 11331,
  [12609] = 11633,
  [12610] = 12610,
  [12611] = 11295,
  [12612] = 11633,
  [12613] = 12613,
  [12614] = 11733,
  [12615] = 11737,
  [12616] = 11271,
  [12617] = 11272,
  [12618] = 12618,
  [12619] = 11286,
  [12620] = 12458,
  [12621] = 12610,
  [12622] = 11258,
  [12623] = 11822,
  [12624] = 12475,
  [12625] = 12625,
  [12626] = 11950,
  [12627] = 12482,
  [12628] = 12439,
  [12629] = 11991,
  [12630] = 11531,
  [12631] = 12042,
  [12632] = 12125,
  [12633] = 11348,
  [12634] = 11751,
  [12635] = 12534,
  [12636] = 11519,
  [12637] = 11258,
  [12638] = 11965,
  [12639] = 12482,
  [12640] = 11991,
  [12641] = 11531,
  [12642] = 12042,
  [12643] = 12125,
  [12644] = 11348,
  [12645] = 11751,
  [12646] = 11822,
  [12647] = 11509,
  [12648] = 12482,
  [12649] = 11531,
  [12650] = 12042,
  [12651] = 12125,
  [12652] = 11348,
  [12653] = 11313,
  [12654] = 12613,
  [12655] = 11512,
  [12656] = 11438,
  [12657] = 12270,
  [12658] = 11352,
  [12659] = 12659,
  [12660] = 11258,
  [12661] = 12661,
  [12662] = 11544,
  [12663] = 12126,
  [12664] = 11331,
  [12665] = 11822,
  [12666] = 11482,
  [12667] = 11302,
  [12668] = 11271,
  [12669] = 12669,
  [12670] = 11928,
};

static const TSCharacterRange sym_permission_type_character_set_1[] = {
  {'D', 'D'}, {'I', 'I'}, {'M', 'M'}, {'R', 'R'}, {'X', 'X'}, {'d', 'd'}, {'i', 'i'}, {'m', 'm'},
  {'r', 'r'}, {'x', 'x'},
};

static const TSCharacterRange sym_dotnet_assembly_name_character_set_1[] = {
  {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xba, 0xba}, {0xc0, 0xd6}, {0xd8, 0xf6},
  {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee}, {0x370, 0x374}, {0x376, 0x377}, {0x37a, 0x37d},
  {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5}, {0x3f7, 0x481}, {0x48a, 0x52f},
  {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x620, 0x64a}, {0x66e, 0x66f}, {0x671, 0x6d3},
  {0x6d5, 0x6d5}, {0x6e5, 0x6e6}, {0x6ee, 0x6ef}, {0x6fa, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x710}, {0x712, 0x72f}, {0x74d, 0x7a5},
  {0x7b1, 0x7b1}, {0x7ca, 0x7ea}, {0x7f4, 0x7f5}, {0x7fa, 0x7fa}, {0x800, 0x815}, {0x81a, 0x81a}, {0x824, 0x824}, {0x828, 0x828},
  {0x840, 0x858}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x8a0, 0x8c9}, {0x904, 0x939}, {0x93d, 0x93d}, {0x950, 0x950},
  {0x958, 0x961}, {0x971, 0x980}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2}, {0x9b6, 0x9b9},
  {0x9bd, 0x9bd}, {0x9ce, 0x9ce}, {0x9dc, 0x9dd}, {0x9df, 0x9e1}, {0x9f0, 0x9f1}, {0x9fc, 0x9fc}, {0xa05, 0xa0a}, {0xa0f, 0xa10},
  {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa59, 0xa5c}, {0xa5e, 0xa5e}, {0xa72, 0xa74},
  {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9}, {0xabd, 0xabd}, {0xad0, 0xad0},
  {0xae0, 0xae1}, {0xaf9, 0xaf9}, {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33}, {0xb35, 0xb39},
  {0xb3d, 0xb3d}, {0xb5c, 0xb5d}, {0xb5f, 0xb61}, {0xb71, 0xb71}, {0xb83, 0xb83}, {0xb85, 0xb8a}, {0xb8e, 0xb90}, {0xb92, 0xb95},
  {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9}, {0xbd0, 0xbd0}, {0xc05, 0xc0c},
  {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3d, 0xc3d}, {0xc58, 0xc5a}, {0xc5d, 0xc5d}, {0xc60, 0xc61}, {0xc80, 0xc80},
  {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9}, {0xcbd, 0xcbd}, {0xcdd, 0xcde}, {0xce0, 0xce1},
  {0xcf1, 0xcf2}, {0xd04, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd3a}, {0xd3d, 0xd3d}, {0xd4e, 0xd4e}, {0xd54, 0xd56}, {0xd5f, 0xd61},
  {0xd7a, 0xd7f}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xe01, 0xe30}, {0xe32, 0xe33},
  {0xe40, 0xe46}, {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xeb0}, {0xeb2, 0xeb3},
  {0xebd, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf40, 0xf47}, {0xf49, 0xf6c}, {0xf88, 0xf8c},
  {0x1000, 0x102a}, {0x103f, 0x103f}, {0x1050, 0x1055}, {0x105a, 0x105d}, {0x1061, 0x1061}, {0x1065, 0x1066}, {0x106e, 0x1070}, {0x1075, 0x1081},
  {0x108e, 0x108e}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d}, {0x1250, 0x1256},
  {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be}, {0x12c0, 0x12c0},
  {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x1380, 0x138f}, {0x13a0, 0x13f5}, {0x13f8, 0x13fd},
  {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16f1, 0x16f8}, {0x1700, 0x1711}, {0x171f, 0x1731}, {0x1740, 0x1751},
  {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1780, 0x17b3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dc}, {0x1820, 0x1878}, {0x1880, 0x1884}, {0x1887, 0x18a8},
  {0x18aa, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1950, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x1a00, 0x1a16},
  {0x1a20, 0x1a54}, {0x1aa7, 0x1aa7}, {0x1b05, 0x1b33}, {0x1b45, 0x1b4c}, {0x1b83, 0x1ba0}, {0x1bae, 0x1baf}, {0x1bba, 0x1be5}, {0x1c00, 0x1c23},
  {0x1c4d, 0x1c4f}, {0x1c5a, 0x1c7d}, {0x1c80, 0x1c8a}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1ce9, 0x1cec}, {0x1cee, 0x1cf3}, {0x1cf5, 0x1cf6},
  {0x1cfa, 0x1cfa}, {0x1d00, 0x1dbf}, {0x1e00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57}, {0x1f59, 0x1f59},
  {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcc},
  {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x2071, 0x2071}, {0x207f, 0x207f}, {0x2090, 0x209c},
  {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2119, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128},
  {0x212a, 0x212d}, {0x212f, 0x2139}, {0x213c, 0x213f}, {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2183, 0x2184}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cee},
  {0x2cf2, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d80, 0x2d96}, {0x2da0, 0x2da6},
  {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x2e2f, 0x2e2f},
  {0x3005, 0x3006}, {0x3031, 0x3035}, {0x303b, 0x303c}, {0x3041, 0x3096}, {0x309d, 0x309f}, {0x30a1, 0x30fa}, {0x30fc, 0x30ff}, {0x3105, 0x312f},
  {0x3131, 0x318e}, {0x31a0, 0x31bf}, {0x31f0, 0x31ff}, {0x3400, 0x4dbf}, {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa61f},
  {0xa62a, 0xa62b}, {0xa640, 0xa66e}, {0xa67f, 0xa69d}, {0xa6a0, 0xa6e5}, {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7cd}, {0xa7d0, 0xa7d1},
  {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7dc}, {0xa7f2, 0xa801}, {0xa803, 0xa805}, {0xa807, 0xa80a}, {0xa80c, 0xa822}, {0xa840, 0xa873}, {0xa882, 0xa8b3},
  {0xa8f2, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa8fe}, {0xa90a, 0xa925}, {0xa930, 0xa946}, {0xa960, 0xa97c}, {0xa984, 0xa9b2}, {0xa9cf, 0xa9cf},
  {0xa9e0, 0xa9e4}, {0xa9e6, 0xa9ef}, {0xa9fa, 0xa9fe}, {0xaa00, 0xaa28}, {0xaa40, 0xaa42}, {0xaa44, 0xaa4b}, {0xaa60, 0xaa76}, {0xaa7a, 0xaa7a},
  {0xaa7e, 0xaaaf}, {0xaab1, 0xaab1}, {0xaab5, 0xaab6}, {0xaab9, 0xaabd}, {0xaac0, 0xaac0}, {0xaac2, 0xaac2}, {0xaadb, 0xaadd}, {0xaae0, 0xaaea},
  {0xaaf2, 0xaaf4}, {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e}, {0xab30, 0xab5a}, {0xab5c, 0xab69},
  {0xab70, 0xabe2}, {0xac00, 0xd7a3}, {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17},
  {0xfb1d, 0xfb1d}, {0xfb1f, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1},
  {0xfbd3, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdfb}, {0xfe70, 0xfe74}, {0xfe76, 0xfefc}, {0xff21, 0xff3a}, {0xff41, 0xff5a},
  {0xff66, 0xffbe}, {0xffc2, 0xffc7}, {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a},
  {0x1003c, 0x1003d}, {0x1003f, 0x1004d}, {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x10300, 0x1031f}, {0x1032d, 0x10340},
  {0x10342, 0x10349}, {0x10350, 0x10375}, {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x10400, 0x1049d}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb},
  {0x10500, 0x10527}, {0x10530, 0x10563}, {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1},
  {0x105b3, 0x105b9}, {0x105bb, 0x105bc}, {0x105c0, 0x105f3}, {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0},
  {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808}, {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10860, 0x10876},
  {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5}, {0x10900, 0x10915}, {0x10920, 0x10939}, {0x10980, 0x109b7}, {0x109be, 0x109bf}, {0x10a00, 0x10a00},
  {0x10a10, 0x10a13}, {0x10a15, 0x10a17}, {0x10a19, 0x10a35}, {0x10a60, 0x10a7c}, {0x10a80, 0x10a9c}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae4}, {0x10b00, 0x10b35},
  {0x10b40, 0x10b55}, {0x10b60, 0x10b72}, {0x10b80, 0x10b91}, {0x10c00, 0x10c48}, {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10d00, 0x10d23}, {0x10d4a, 0x10d65},
  {0x10d6f, 0x10d85}, {0x10e80, 0x10ea9}, {0x10eb0, 0x10eb1}, {0x10ec2, 0x10ec4}, {0x10f00, 0x10f1c}, {0x10f27, 0x10f27}, {0x10f30, 0x10f45}, {0x10f70, 0x10f81},
  {0x10fb0, 0x10fc4}, {0x10fe0, 0x10ff6}, {0x11003, 0x11037}, {0x11071, 0x11072}, {0x11075, 0x11075}, {0x11083, 0x110af}, {0x110d0, 0x110e8}, {0x11103, 0x11126},
  {0x11144, 0x11144}, {0x11147, 0x11147}, {0x11150, 0x11172}, {0x11176, 0x11176}, {0x11183, 0x111b2}, {0x111c1, 0x111c4}, {0x111da, 0x111da}, {0x111dc, 0x111dc},
  {0x11200, 0x11211}, {0x11213, 0x1122b}, {0x1123f, 0x11240}, {0x11280, 0x11286}, {0x11288, 0x11288}, {0x1128a, 0x1128d}, {0x1128f, 0x1129d}, {0x1129f, 0x112a8},
  {0x112b0, 0x112de}, {0x11305, 0x1130c}, {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330}, {0x11332, 0x11333}, {0x11335, 0x11339}, {0x1133d, 0x1133d},
  {0x11350, 0x11350}, {0x1135d, 0x11361}, {0x11380, 0x11389}, {0x1138b, 0x1138b}, {0x1138e, 0x1138e}, {0x11390, 0x113b5}, {0x113b7, 0x113b7}, {0x113d1, 0x113d1},
  {0x113d3, 0x113d3}, {0x11400, 0x11434}, {0x11447, 0x1144a}, {0x1145f, 0x11461}, {0x11480, 0x114af}, {0x114c4, 0x114c5}, {0x114c7, 0x114c7}, {0x11580, 0x115ae},
  {0x115d8, 0x115db}, {0x11600, 0x1162f}, {0x11644, 0x11644}, {0x11680, 0x116aa}, {0x116b8, 0x116b8}, {0x11700, 0x1171a}, {0x11740, 0x11746}, {0x11800, 0x1182b},
  {0x118a0, 0x118df}, {0x118ff, 0x11906}, {0x11909, 0x11909}, {0x1190c, 0x11913}, {0x11915, 0x11916}, {0x11918, 0x1192f}, {0x1193f, 0x1193f}, {0x11941, 0x11941},
  {0x119a0, 0x119a7}, {0x119aa, 0x119d0}, {0x119e1, 0x119e1}, {0x119e3, 0x119e3}, {0x11a00, 0x11a00}, {0x11a0b, 0x11a32}, {0x11a3a, 0x11a3a}, {0x11a50, 0x11a50},
  {0x11a5c, 0x11a89}, {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11bc0, 0x11be0}, {0x11c00, 0x11c08}, {0x11c0a, 0x11c2e}, {0x11c40, 0x11c40}, {0x11c72, 0x11c8f},
  {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d30}, {0x11d46, 0x11d46}, {0x11d60, 0x11d65}, {0x11d67, 0x11d68}, {0x11d6a, 0x11d89}, {0x11d98, 0x11d98},
  {0x11ee0, 0x11ef2}, {0x11f02, 0x11f02}, {0x11f04, 0x11f10}, {0x11f12, 0x11f33}, {0x11fb0, 0x11fb0}, {0x12000, 0x12399}, {0x12480, 0x12543}, {0x12f90, 0x12ff0},
  {0x13000, 0x1342f}, {0x13441, 0x13446}, {0x13460, 0x143fa}, {0x14400, 0x14646}, {0x16100, 0x1611d}, {0x16800, 0x16a38}, {0x16a40, 0x16a5e}, {0x16a70, 0x16abe},
  {0x16ad0, 0x16aed}, {0x16b00, 0x16b2f}, {0x16b40, 0x16b43}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f}, {0x16d40, 0x16d6c}, {0x16e40, 0x16e7f}, {0x16f00, 0x16f4a},
  {0x16f50, 0x16f50}, {0x16f93, 0x16f9f}, {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe3}, {0x17000, 0x187f7}, {0x18800, 0x18cd5}, {0x18cff, 0x18d08}, {0x1aff0, 0x1aff3},
  {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b132, 0x1b132}, {0x1b150, 0x1b152}, {0x1b155, 0x1b155}, {0x1b164, 0x1b167}, {0x1b170, 0x1b2fb},
  {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99}, {0x1d400, 0x1d454}, {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f}, {0x1d4a2, 0x1d4a2},
  {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb}, {0x1d4bd, 0x1d4c3}, {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a}, {0x1d50d, 0x1d514},
  {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544}, {0x1d546, 0x1d546}, {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5}, {0x1d6a8, 0x1d6c0},
  {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734}, {0x1d736, 0x1d74e}, {0x1d750, 0x1d76e}, {0x1d770, 0x1d788}, {0x1d78a, 0x1d7a8},
  {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1df00, 0x1df1e}, {0x1df25, 0x1df2a}, {0x1e030, 0x1e06d}, {0x1e100, 0x1e12c}, {0x1e137, 0x1e13d}, {0x1e14e, 0x1e14e},
  {0x1e290, 0x1e2ad}, {0x1e2c0, 0x1e2eb}, {0x1e4d0, 0x1e4eb}, {0x1e5d0, 0x1e5ed}, {0x1e5f0, 0x1e5f0}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb}, {0x1e7ed, 0x1e7ee},
  {0x1e7f0, 0x1e7fe}, {0x1e800, 0x1e8c4}, {0x1e900, 0x1e943}, {0x1e94b, 0x1e94b}, {0x1ee00, 0x1ee03}, {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22}, {0x1ee24, 0x1ee24},
  {0x1ee27, 0x1ee27}, {0x1ee29, 0x1ee32}, {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b}, {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47}, {0x1ee49, 0x1ee49},
  {0x1ee4b, 0x1ee4b}, {0x1ee4d, 0x1ee4f}, {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57}, {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b}, {0x1ee5d, 0x1ee5d},
  {0x1ee5f, 0x1ee5f}, {0x1ee61, 0x1ee62}, {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72}, {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c}, {0x1ee7e, 0x1ee7e},
  {0x1ee80, 0x1ee89}, {0x1ee8b, 0x1ee9b}, {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb}, {0x20000, 0x2a6df}, {0x2a700, 0x2b739}, {0x2b740, 0x2b81d},
  {0x2b820, 0x2cea1}, {0x2ceb0, 0x2ebe0}, {0x2ebf0, 0x2ee5d}, {0x2f800, 0x2fa1d}, {0x30000, 0x3134a}, {0x31350, 0x323af},
};

static const TSCharacterRange sym_identifier_character_set_1[] = {
  {'0', '9'}, {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb2, 0xb3}, {0xb5, 0xb5}, {0xb9, 0xba},
  {0xbc, 0xbe}, {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee},
  {0x370, 0x374}, {0x376, 0x377}, {0x37a, 0x37d}, {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1},
  {0x3a3, 0x3f5}, {0x3f7, 0x481}, {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2},
  {0x620, 0x64a}, {0x660, 0x669}, {0x66e, 0x66f}, {0x671, 0x6d3}, {0x6d5, 0x6d5}, {0x6e5, 0x6e6}, {0x6ee, 0x6fc}, {0x6ff, 0x6ff},
  {0x710, 0x710}, {0x712, 0x72f}, {0x74d, 0x7a5}, {0x7b1, 0x7b1}, {0x7c0, 0x7ea}, {0x7f4, 0x7f5}, {0x7fa, 0x7fa}, {0x800, 0x815},
  {0x81a, 0x81a}, {0x824, 0x824}, {0x828, 0x828}, {0x840, 0x858}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x8a0, 0x8c9},
  {0x904, 0x939}, {0x93d, 0x93d}, {0x950, 0x950}, {0x958, 0x961}, {0x966, 0x96f}, {0x971, 0x980}, {0x985, 0x98c}, {0x98f, 0x990},
  {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2}, {0x9b6, 0x9b9}, {0x9bd, 0x9bd}, {0x9ce, 0x9ce}, {0x9dc, 0x9dd}, {0x9df, 0x9e1},
  {0x9e6, 0x9f1}, {0x9f4, 0x9f9}, {0x9fc, 0x9fc}, {0xa05, 0xa0a}, {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33},
  {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa59, 0xa5c}, {0xa5e, 0xa5e}, {0xa66, 0xa6f}, {0xa72, 0xa74}, {0xa85, 0xa8d}, {0xa8f, 0xa91},
  {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9}, {0xabd, 0xabd}, {0xad0, 0xad0}, {0xae0, 0xae1}, {0xae6, 0xaef},
  {0xaf9, 0xaf9}, {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33}, {0xb35, 0xb39}, {0xb3d, 0xb3d},
  {0xb5c, 0xb5d}, {0xb5f, 0xb61}, {0xb66, 0xb6f}, {0xb71, 0xb77}, {0xb83, 0xb83}, {0xb85, 0xb8a}, {0xb8e, 0xb90}, {0xb92, 0xb95},
  {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9}, {0xbd0, 0xbd0}, {0xbe6, 0xbf2},
  {0xc05, 0xc0c}, {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3d, 0xc3d}, {0xc58, 0xc5a}, {0xc5d, 0xc5d}, {0xc60, 0xc61},
  {0xc66, 0xc6f}, {0xc78, 0xc7e}, {0xc80, 0xc80}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9},
  {0xcbd, 0xcbd}, {0xcdd, 0xcde}, {0xce0, 0xce1}, {0xce6, 0xcef}, {0xcf1, 0xcf2}, {0xd04, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd3a},
  {0xd3d, 0xd3d}, {0xd4e, 0xd4e}, {0xd54, 0xd56}, {0xd58, 0xd61}, {0xd66, 0xd78}, {0xd7a, 0xd7f}, {0xd85, 0xd96}, {0xd9a, 0xdb1},
  {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xde6, 0xdef}, {0xe01, 0xe30}, {0xe32, 0xe33}, {0xe40, 0xe46}, {0xe50, 0xe59},
  {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xeb0}, {0xeb2, 0xeb3}, {0xebd, 0xebd},
  {0xec0, 0xec4}, {0xec6, 0xec6}, {0xed0, 0xed9}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf20, 0xf33}, {0xf40, 0xf47}, {0xf49, 0xf6c},
  {0xf88, 0xf8c}, {0x1000, 0x102a}, {0x103f, 0x1049}, {0x1050, 0x1055}, {0x105a, 0x105d}, {0x1061, 0x1061}, {0x1065, 0x1066}, {0x106e, 0x1070},
  {0x1075, 0x1081}, {0x108e, 0x108e}, {0x1090, 0x1099}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248},
  {0x124a, 0x124d}, {0x1250, 0x1256}, {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5},
  {0x12b8, 0x12be}, {0x12c0, 0x12c0}, {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x1369, 0x137c},
  {0x1380, 0x138f}, {0x13a0, 0x13f5}, {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8},
  {0x1700, 0x1711}, {0x171f, 0x1731}, {0x1740, 0x1751}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1780, 0x17b3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dc},
  {0x17e0, 0x17e9}, {0x17f0, 0x17f9}, {0x1810, 0x1819}, {0x1820, 0x1878}, {0x1880, 0x1884}, {0x1887, 0x18a8}, {0x18aa, 0x18aa}, {0x18b0, 0x18f5},
  {0x1900, 0x191e}, {0x1946, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x19d0, 0x19da}, {0x1a00, 0x1a16}, {0x1a20, 0x1a54},
  {0x1a80, 0x1a89}, {0x1a90, 0x1a99}, {0x1aa7, 0x1aa7}, {0x1b05, 0x1b33}, {0x1b45, 0x1b4c}, {0x1b50, 0x1b59}, {0x1b83, 0x1ba0}, {0x1bae, 0x1be5},
  {0x1c00, 0x1c23}, {0x1c40, 0x1c49}, {0x1c4d, 0x1c7d}, {0x1c80, 0x1c8a}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1ce9, 0x1cec}, {0x1cee, 0x1cf3},
  {0x1cf5, 0x1cf6}, {0x1cfa, 0x1cfa}, {0x1d00, 0x1dbf}, {0x1e00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57},
  {0x1f59, 0x1f59}, {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4},
  {0x1fc6, 0x1fcc}, {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x2070, 0x2071}, {0x2074, 0x2079},
  {0x207f, 0x2089}, {0x2090, 0x209c}, {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2119, 0x211d}, {0x2124, 0x2124},
  {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x212d}, {0x212f, 0x2139}, {0x213c, 0x213f}, {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2150, 0x2189},
  {0x2460, 0x249b}, {0x24ea, 0x24ff}, {0x2776, 0x2793}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cee}, {0x2cf2, 0x2cf3}, {0x2cfd, 0x2cfd}, {0x2d00, 0x2d25},
  {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d80, 0x2d96}, {0x2da0, 0x2da6}, {0x2da8, 0x2dae}, {0x2db0, 0x2db6},
  {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x2e2f, 0x2e2f}, {0x3005, 0x3007}, {0x3021, 0x3029},
  {0x3031, 0x3035}, {0x3038, 0x303c}, {0x3041, 0x3096}, {0x309d, 0x309f}, {0x30a1, 0x30fa}, {0x30fc, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e},
  {0x3192, 0x3195}, {0x31a0, 0x31bf}, {0x31f0, 0x31ff}, {0x3220, 0x3229}, {0x3248, 0x324f}, {0x3251, 0x325f}, {0x3280, 0x3289}, {0x32b1, 0x32bf},
  {0x3400, 0x4dbf}, {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa62b}, {0xa640, 0xa66e}, {0xa67f, 0xa69d}, {0xa6a0, 0xa6ef},
  {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7cd}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7dc}, {0xa7f2, 0xa801}, {0xa803, 0xa805},
  {0xa807, 0xa80a}, {0xa80c, 0xa822}, {0xa830, 0xa835}, {0xa840, 0xa873}, {0xa882, 0xa8b3}, {0xa8d0, 0xa8d9}, {0xa8f2, 0xa8f7}, {0xa8fb, 0xa8fb},
  {0xa8fd, 0xa8fe}, {0xa900, 0xa925}, {0xa930, 0xa946}, {0xa960, 0xa97c}, {0xa984, 0xa9b2}, {0xa9cf, 0xa9d9}, {0xa9e0, 0xa9e4}, {0xa9e6, 0xa9fe},
  {0xaa00, 0xaa28}, {0xaa40, 0xaa42}, {0xaa44, 0xaa4b}, {0xaa50, 0xaa59}, {0xaa60, 0xaa76}, {0xaa7a, 0xaa7a}, {0xaa7e, 0xaaaf}, {0xaab1, 0xaab1},
  {0xaab5, 0xaab6}, {0xaab9, 0xaabd}, {0xaac0, 0xaac0}, {0xaac2, 0xaac2}, {0xaadb, 0xaadd}, {0xaae0, 0xaaea}, {0xaaf2, 0xaaf4}, {0xab01, 0xab06},
  {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e}, {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabe2}, {0xabf0, 0xabf9},
  {0xac00, 0xd7a3}, {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb1d},
  {0xfb1f, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfd3d},
  {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdfb}, {0xfe70, 0xfe74}, {0xfe76, 0xfefc}, {0xff10, 0xff19}, {0xff21, 0xff3a}, {0xff41, 0xff5a},
  {0xff66, 0xffbe}, {0xffc2, 0xffc7}, {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a},
  {0x1003c, 0x1003d}, {0x1003f, 0x1004d}, {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10107, 0x10133}, {0x10140, 0x10178}, {0x1018a, 0x1018b}, {0x10280, 0x1029c},
  {0x102a0, 0x102d0}, {0x102e1, 0x102fb}, {0x10300, 0x10323}, {0x1032d, 0x1034a}, {0x10350, 0x10375}, {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf},
  {0x103d1, 0x103d5}, {0x10400, 0x1049d}, {0x104a0, 0x104a9}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527}, {0x10530, 0x10563}, {0x10570, 0x1057a},
  {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc}, {0x105c0, 0x105f3},
  {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808},
  {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10858, 0x10876}, {0x10879, 0x1089e}, {0x108a7, 0x108af}, {0x108e0, 0x108f2},
  {0x108f4, 0x108f5}, {0x108fb, 0x1091b}, {0x10920, 0x10939}, {0x10980, 0x109b7}, {0x109bc, 0x109cf}, {0x109d2, 0x10a00}, {0x10a10, 0x10a13}, {0x10a15, 0x10a17},
  {0x10a19, 0x10a35}, {0x10a40, 0x10a48}, {0x10a60, 0x10a7e}, {0x10a80, 0x10a9f}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae4}, {0x10aeb, 0x10aef}, {0x10b00, 0x10b35},
  {0x10b40, 0x10b55}, {0x10b58, 0x10b72}, {0x10b78, 0x10b91}, {0x10ba9, 0x10baf}, {0x10c00, 0x10c48}, {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10cfa, 0x10d23},
  {0x10d30, 0x10d39}, {0x10d40, 0x10d65}, {0x10d6f, 0x10d85}, {0x10e60, 0x10e7e}, {0x10e80, 0x10ea9}, {0x10eb0, 0x10eb1}, {0x10ec2, 0x10ec4}, {0x10f00, 0x10f27},
  {0x10f30, 0x10f45}, {0x10f51, 0x10f54}, {0x10f70, 0x10f81}, {0x10fb0, 0x10fcb}, {0x10fe0, 0x10ff6}, {0x11003, 0x11037}, {0x11052, 0x1106f}, {0x11071, 0x11072},
  {0x11075, 0x11075}, {0x11083, 0x110af}, {0x110d0, 0x110e8}, {0x110f0, 0x110f9}, {0x11103, 0x11126}, {0x11136, 0x1113f}, {0x11144, 0x11144}, {0x11147, 0x11147},
  {0x11150, 0x11172}, {0x11176, 0x11176}, {0x11183, 0x111b2}, {0x111c1, 0x111c4}, {0x111d0, 0x111da}, {0x111dc, 0x111dc}, {0x111e1, 0x111f4}, {0x11200, 0x11211},
  {0x11213, 0x1122b}, {0x1123f, 0x11240}, {0x11280, 0x11286}, {0x11288, 0x11288}, {0x1128a, 0x1128d}, {0x1128f, 0x1129d}, {0x1129f, 0x112a8}, {0x112b0, 0x112de},
  {0x112f0, 0x112f9}, {0x11305, 0x1130c}, {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330}, {0x11332, 0x11333}, {0x11335, 0x11339}, {0x1133d, 0x1133d},
  {0x11350, 0x11350}, {0x1135d, 0x11361}, {0x11380, 0x11389}, {0x1138b, 0x1138b}, {0x1138e, 0x1138e}, {0x11390, 0x113b5}, {0x113b7, 0x113b7}, {0x113d1, 0x113d1},
  {0x113d3, 0x113d3}, {0x11400, 0x11434}, {0x11447, 0x1144a}, {0x11450, 0x11459}, {0x1145f, 0x11461}, {0x11480, 0x114af}, {0x114c4, 0x114c5}, {0x114c7, 0x114c7},
  {0x114d0, 0x114d9}, {0x11580, 0x115ae}, {0x115d8, 0x115db}, {0x11600, 0x1162f}, {0x11644, 0x11644}, {0x11650, 0x11659}, {0x11680, 0x116aa}, {0x116b8, 0x116b8},
  {0x116c0, 0x116c9}, {0x116d0, 0x116e3}, {0x11700, 0x1171a}, {0x11730, 0x1173b}, {0x11740, 0x11746}, {0x11800, 0x1182b}, {0x118a0, 0x118f2}, {0x118ff, 0x11906},
  {0x11909, 0x11909}, {0x1190c, 0x11913}, {0x11915, 0x11916}, {0x11918, 0x1192f}, {0x1193f, 0x1193f}, {0x11941, 0x11941}, {0x11950, 0x11959}, {0x119a0, 0x119a7},
  {0x119aa, 0x119d0}, {0x119e1, 0x119e1}, {0x119e3, 0x119e3}, {0x11a00, 0x11a00}, {0x11a0b, 0x11a32}, {0x11a3a, 0x11a3a}, {0x11a50, 0x11a50}, {0x11a5c, 0x11a89},
  {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11bc0, 0x11be0}, {0x11bf0, 0x11bf9}, {0x11c00, 0x11c08}, {0x11c0a, 0x11c2e}, {0x11c40, 0x11c40}, {0x11c50, 0x11c6c},
  {0x11c72, 0x11c8f}, {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d30}, {0x11d46, 0x11d46}, {0x11d50, 0x11d59}, {0x11d60, 0x11d65}, {0x11d67, 0x11d68},
  {0x11d6a, 0x11d89}, {0x11d98, 0x11d98}, {0x11da0, 0x11da9}, {0x11ee0, 0x11ef2}, {0x11f02, 0x11f02}, {0x11f04, 0x11f10}, {0x11f12, 0x11f33}, {0x11f50, 0x11f59},
  {0x11fb0, 0x11fb0}, {0x11fc0, 0x11fd4}, {0x12000, 0x12399}, {0x12400, 0x1246e}, {0x12480, 0x12543}, {0x12f90, 0x12ff0}, {0x13000, 0x1342f}, {0x13441, 0x13446},
  {0x13460, 0x143fa}, {0x14400, 0x14646}, {0x16100, 0x1611d}, {0x16130, 0x16139}, {0x16800, 0x16a38}, {0x16a40, 0x16a5e}, {0x16a60, 0x16a69}, {0x16a70, 0x16abe},
  {0x16ac0, 0x16ac9}, {0x16ad0, 0x16aed}, {0x16b00, 0x16b2f}, {0x16b40, 0x16b43}, {0x16b50, 0x16b59}, {0x16b5b, 0x16b61}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f},
  {0x16d40, 0x16d6c}, {0x16d70, 0x16d79}, {0x16e40, 0x16e96}, {0x16f00, 0x16f4a}, {0x16f50, 0x16f50}, {0x16f93, 0x16f9f}, {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe3},
  {0x17000, 0x187f7}, {0x18800, 0x18cd5}, {0x18cff, 0x18d08}, {0x1aff0, 0x1aff3}, {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b132, 0x1b132},
  {0x1b150, 0x1b152}, {0x1b155, 0x1b155}, {0x1b164, 0x1b167}, {0x1b170, 0x1b2fb}, {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99},
  {0x1ccf0, 0x1ccf9}, {0x1d2c0, 0x1d2d3}, {0x1d2e0, 0x1d2f3}, {0x1d360, 0x1d378}, {0x1d400, 0x1d454}, {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f}, {0x1d4a2, 0x1d4a2},
  {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb}, {0x1d4bd, 0x1d4c3}, {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a}, {0x1d50d, 0x1d514},
  {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544}, {0x1d546, 0x1d546}, {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5}, {0x1d6a8, 0x1d6c0},
  {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734}, {0x1d736, 0x1d74e}, {0x1d750, 0x1d76e}, {0x1d770, 0x1d788}, {0x1d78a, 0x1d7a8},
  {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1d7ce, 0x1d7ff}, {0x1df00, 0x1df1e}, {0x1df25, 0x1df2a}, {0x1e030, 0x1e06d}, {0x1e100, 0x1e12c}, {0x1e137, 0x1e13d},
  {0x1e140, 0x1e149}, {0x1e14e, 0x1e14e}, {0x1e290, 0x1e2ad}, {0x1e2c0, 0x1e2eb}, {0x1e2f0, 0x1e2f9}, {0x1e4d0, 0x1e4eb}, {0x1e4f0, 0x1e4f9}, {0x1e5d0, 0x1e5ed},
  {0x1e5f0, 0x1e5fa}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb}, {0x1e7ed, 0x1e7ee}, {0x1e7f0, 0x1e7fe}, {0x1e800, 0x1e8c4}, {0x1e8c7, 0x1e8cf}, {0x1e900, 0x1e943},
  {0x1e94b, 0x1e94b}, {0x1e950, 0x1e959}, {0x1ec71, 0x1ecab}, {0x1ecad, 0x1ecaf}, {0x1ecb1, 0x1ecb4}, {0x1ed01, 0x1ed2d}, {0x1ed2f, 0x1ed3d}, {0x1ee00, 0x1ee03},
  {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22}, {0x1ee24, 0x1ee24}, {0x1ee27, 0x1ee27}, {0x1ee29, 0x1ee32}, {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b},
  {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47}, {0x1ee49, 0x1ee49}, {0x1ee4b, 0x1ee4b}, {0x1ee4d, 0x1ee4f}, {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57},
  {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b}, {0x1ee5d, 0x1ee5d}, {0x1ee5f, 0x1ee5f}, {0x1ee61, 0x1ee62}, {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72},
  {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c}, {0x1ee7e, 0x1ee7e}, {0x1ee80, 0x1ee89}, {0x1ee8b, 0x1ee9b}, {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb},
  {0x1f100, 0x1f10c}, {0x1fbf0, 0x1fbf9}, {0x20000, 0x2a6df}, {0x2a700, 0x2b739}, {0x2b740, 0x2b81d}, {0x2b820, 0x2cea1}, {0x2ceb0, 0x2ebe0}, {0x2ebf0, 0x2ee5d},
  {0x2f800, 0x2fa1d}, {0x30000, 0x3134a}, {0x31350, 0x323af},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(92);
      ADVANCE_MAP(
        '"', 8,
        '#', 21,
        '\'', 13,
        '(', 142,
        ')', 106,
        '*', 117,
        '+', 145,
        ',', 98,
        '-', 103,
        '.', 94,
        '/', 143,
        ':', 101,
        ';', 93,
        '<', 149,
        '=', 97,
        '>', 148,
        '?', 151,
        '[', 119,
        ']', 120,
        '{', 95,
        '}', 96,
        'A', 178,
        'a', 178,
        'D', 165,
        'd', 165,
        'E', 173,
        'e', 173,
        'I', 166,
        'i', 166,
        'O', 168,
        'o', 168,
        '%', 108,
        '&', 108,
        '@', 108,
        '|', 108,
        'M', 181,
        'R', 181,
        'X', 181,
        'm', 181,
        'r', 181,
        'x', 181,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(90);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(193);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(182);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '"', 8,
        '#', 21,
        '\'', 13,
        '(', 142,
        '+', 144,
        '-', 102,
        '/', 14,
        ';', 93,
        '[', 119,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(4);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(193);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(182);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '"', 8,
        '#', 21,
        '\'', 13,
        '(', 105,
        ')', 106,
        '*', 117,
        '+', 145,
        ',', 98,
        '-', 103,
        '.', 94,
        '/', 143,
        ':', 100,
        ';', 93,
        '<', 149,
        '=', 97,
        '>', 148,
        '?', 151,
        '[', 119,
        ']', 120,
        '{', 95,
        '%', 108,
        '&', 108,
        '@', 108,
        '|', 108,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(2);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(193);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(182);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '"', 8,
        '#', 21,
        '\'', 13,
        '(', 105,
        '+', 144,
        ',', 98,
        '-', 102,
        '/', 14,
        ';', 93,
        '[', 119,
        'I', 167,
        'i', 167,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(3);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(193);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(182);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '"', 8,
        '#', 21,
        '\'', 13,
        '(', 105,
        '+', 144,
        '-', 102,
        '/', 14,
        ';', 93,
        '[', 119,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(4);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(193);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(182);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '"', 8,
        '#', 21,
        '\'', 13,
        ')', 106,
        '*', 116,
        ',', 98,
        '-', 102,
        '/', 14,
        ';', 93,
        '[', 119,
        ']', 120,
        '}', 96,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(5);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(196);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(182);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '"', 8,
        '#', 46,
        '\'', 13,
        '(', 105,
        ')', 106,
        '*', 117,
        '+', 145,
        ',', 98,
        '-', 103,
        '.', 94,
        '/', 143,
        ':', 100,
        ';', 93,
        '<', 149,
        '=', 97,
        '>', 148,
        '?', 151,
        '[', 119,
        ']', 120,
        '{', 95,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(6);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(196);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(182);
      END_STATE();
    case 7:
      if (lookahead == '"') ADVANCE(8);
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '\'') ADVANCE(13);
      if (lookahead == '/') ADVANCE(14);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(7);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(123);
      END_STATE();
    case 8:
      if (lookahead == '"') ADVANCE(183);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(8);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '#', 46,
        '(', 105,
        '*', 117,
        '+', 145,
        '-', 103,
        '.', 94,
        '/', 143,
        ':', 17,
        '<', 149,
        '=', 97,
        '>', 148,
        '?', 151,
        '[', 119,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(9);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(182);
      END_STATE();
    case 10:
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '/') ADVANCE(14);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(10);
      if (set_contains(sym_permission_type_character_set_1, 10, lookahead)) ADVANCE(118);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '#', 22,
        '(', 105,
        ')', 106,
        '*', 117,
        '+', 145,
        ',', 98,
        '-', 103,
        '.', 94,
        '/', 143,
        ':', 100,
        ';', 93,
        '<', 149,
        '=', 97,
        '>', 148,
        '?', 151,
        '[', 119,
        ']', 120,
        '{', 95,
        'E', 173,
        'e', 173,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(11);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(182);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '#', 22,
        ')', 106,
        '/', 14,
        ';', 93,
        'A', 80,
        'a', 80,
        'D', 59,
        'd', 59,
        'E', 69,
        'e', 69,
        'O', 60,
        'o', 60,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(12);
      END_STATE();
    case 13:
      if (lookahead == '\'') ADVANCE(186);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(13);
      END_STATE();
    case 14:
      if (lookahead == '*') ADVANCE(16);
      if (lookahead == '/') ADVANCE(184);
      END_STATE();
    case 15:
      if (lookahead == '*') ADVANCE(15);
      if (lookahead == '/') ADVANCE(185);
      if (lookahead != 0) ADVANCE(16);
      END_STATE();
    case 16:
      if (lookahead == '*') ADVANCE(15);
      if (lookahead != 0) ADVANCE(16);
      END_STATE();
    case 17:
      if (lookahead == ':') ADVANCE(124);
      if (lookahead == '=') ADVANCE(141);
      END_STATE();
    case 18:
      if (lookahead == 'D') ADVANCE(28);
      if (lookahead == 'd') ADVANCE(79);
      END_STATE();
    case 19:
      if (lookahead == 'D') ADVANCE(79);
      if (lookahead == 'd') ADVANCE(43);
      END_STATE();
    case 20:
      if (lookahead == 'D') ADVANCE(79);
      if (lookahead == 'd') ADVANCE(44);
      END_STATE();
    case 21:
      if (lookahead == 'E') ADVANCE(29);
      if (lookahead == 'I') ADVANCE(24);
      if (lookahead == 'e') ADVANCE(30);
      if (lookahead == 'i') ADVANCE(35);
      if (lookahead == 'p') ADVANCE(47);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(53);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(54);
      END_STATE();
    case 22:
      if (lookahead == 'E') ADVANCE(29);
      if (lookahead == 'e') ADVANCE(30);
      if (lookahead == 'p') ADVANCE(47);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(53);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(54);
      END_STATE();
    case 23:
      if (lookahead == 'E') ADVANCE(132);
      END_STATE();
    case 24:
      if (lookahead == 'F') ADVANCE(126);
      if (lookahead == 'f') ADVANCE(127);
      END_STATE();
    case 25:
      if (lookahead == 'F') ADVANCE(129);
      END_STATE();
    case 26:
      if (lookahead == 'F') ADVANCE(135);
      END_STATE();
    case 27:
      if (lookahead == 'I') ADVANCE(25);
      if (lookahead == 'S') ADVANCE(23);
      END_STATE();
    case 28:
      if (lookahead == 'I') ADVANCE(26);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(58);
      END_STATE();
    case 29:
      if (lookahead == 'L') ADVANCE(27);
      if (lookahead == 'N') ADVANCE(18);
      if (lookahead == 'l') ADVANCE(41);
      if (lookahead == 'n') ADVANCE(19);
      END_STATE();
    case 30:
      if (lookahead == 'N') ADVANCE(50);
      if (lookahead == 'l') ADVANCE(42);
      if (lookahead == 'n') ADVANCE(20);
      END_STATE();
    case 31:
      if (lookahead == 'a') ADVANCE(40);
      END_STATE();
    case 32:
      if (lookahead == 'a') ADVANCE(137);
      END_STATE();
    case 33:
      if (lookahead == 'e') ADVANCE(133);
      END_STATE();
    case 34:
      if (lookahead == 'e') ADVANCE(131);
      END_STATE();
    case 35:
      if (lookahead == 'f') ADVANCE(125);
      END_STATE();
    case 36:
      if (lookahead == 'f') ADVANCE(130);
      END_STATE();
    case 37:
      if (lookahead == 'f') ADVANCE(128);
      END_STATE();
    case 38:
      if (lookahead == 'f') ADVANCE(136);
      END_STATE();
    case 39:
      if (lookahead == 'f') ADVANCE(134);
      END_STATE();
    case 40:
      if (lookahead == 'g') ADVANCE(45);
      END_STATE();
    case 41:
      if (lookahead == 'i') ADVANCE(36);
      if (lookahead == 's') ADVANCE(33);
      END_STATE();
    case 42:
      if (lookahead == 'i') ADVANCE(37);
      if (lookahead == 's') ADVANCE(34);
      END_STATE();
    case 43:
      if (lookahead == 'i') ADVANCE(38);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(58);
      END_STATE();
    case 44:
      if (lookahead == 'i') ADVANCE(39);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(58);
      END_STATE();
    case 45:
      if (lookahead == 'm') ADVANCE(32);
      END_STATE();
    case 46:
      if (lookahead == 'p') ADVANCE(47);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(70);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(53);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(54);
      END_STATE();
    case 47:
      if (lookahead == 'r') ADVANCE(31);
      END_STATE();
    case 48:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(56);
      END_STATE();
    case 49:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(57);
      END_STATE();
    case 50:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(79);
      END_STATE();
    case 51:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(66);
      END_STATE();
    case 52:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(67);
      END_STATE();
    case 53:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(61);
      END_STATE();
    case 54:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(70);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(53);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(54);
      END_STATE();
    case 55:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(114);
      END_STATE();
    case 56:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(73);
      END_STATE();
    case 57:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(76);
      END_STATE();
    case 58:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(64);
      END_STATE();
    case 59:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(82);
      END_STATE();
    case 60:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(121);
      END_STATE();
    case 61:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(65);
      END_STATE();
    case 62:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(109);
      END_STATE();
    case 63:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(111);
      END_STATE();
    case 64:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(68);
      END_STATE();
    case 65:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(77);
      END_STATE();
    case 66:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(74);
      END_STATE();
    case 67:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(75);
      END_STATE();
    case 68:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(78);
      END_STATE();
    case 69:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(81);
      END_STATE();
    case 70:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(50);
      END_STATE();
    case 71:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(138);
      END_STATE();
    case 72:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(139);
      END_STATE();
    case 73:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(51);
      END_STATE();
    case 74:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(62);
      END_STATE();
    case 75:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(63);
      END_STATE();
    case 76:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(52);
      END_STATE();
    case 77:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(71);
      END_STATE();
    case 78:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(72);
      END_STATE();
    case 79:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(58);
      END_STATE();
    case 80:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(48);
      END_STATE();
    case 81:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(55);
      END_STATE();
    case 82:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(49);
      END_STATE();
    case 83:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(104);
      END_STATE();
    case 84:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(153);
      END_STATE();
    case 85:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(84);
      END_STATE();
    case 86:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(85);
      END_STATE();
    case 87:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(86);
      END_STATE();
    case 88:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(87);
      END_STATE();
    case 89:
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(123);
      END_STATE();
    case 90:
      if (eof) ADVANCE(92);
      ADVANCE_MAP(
        '"', 8,
        '#', 21,
        '\'', 13,
        '(', 105,
        ')', 106,
        '*', 117,
        '+', 145,
        ',', 98,
        '-', 103,
        '.', 94,
        '/', 143,
        ':', 101,
        ';', 93,
        '<', 149,
        '=', 97,
        '>', 148,
        '?', 151,
        '[', 119,
        ']', 120,
        '{', 95,
        '}', 96,
        'A', 178,
        'a', 178,
        'D', 165,
        'd', 165,
        'E', 173,
        'e', 173,
        'I', 166,
        'i', 166,
        'O', 168,
        'o', 168,
        '%', 108,
        '&', 108,
        '@', 108,
        '|', 108,
        'M', 181,
        'R', 181,
        'X', 181,
        'm', 181,
        'r', 181,
        'x', 181,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(90);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(193);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(182);
      END_STATE();
    case 91:
      if (eof) ADVANCE(92);
      ADVANCE_MAP(
        '"', 8,
        '#', 21,
        '\'', 13,
        '(', 105,
        ')', 106,
        '+', 144,
        ',', 98,
        '-', 102,
        '.', 94,
        '/', 14,
        ':', 99,
        ';', 93,
        '[', 119,
        ']', 120,
        '{', 95,
        '}', 96,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(91);
      if (('%' <= lookahead && lookahead <= '*') ||
          ('<' <= lookahead && lookahead <= '>') ||
          lookahead == '@' ||
          lookahead == '|') ADVANCE(108);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(193);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(182);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(107);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(124);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(124);
      if (lookahead == '=') ADVANCE(140);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(124);
      if (lookahead == '=') ADVANCE(141);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '=') ADVANCE(140);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(sym_decimal);
      if (lookahead == 'T') ADVANCE(155);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(104);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(aux_sym_filter_value_token1);
      if (lookahead == '%' ||
          lookahead == '&' ||
          lookahead == '*' ||
          ('<' <= lookahead && lookahead <= '>') ||
          lookahead == '@' ||
          lookahead == '|') ADVANCE(108);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(aux_sym_sorting_value_token3);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(aux_sym_sorting_value_token3);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(aux_sym_sorting_value_token4);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(aux_sym_sorting_value_token4);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(aux_sym_if_table_relation_token1);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(aux_sym_if_table_relation_token2);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(aux_sym_if_table_relation_token2);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '=') ADVANCE(140);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(sym_permission_type);
      ADVANCE_MAP(
        'D', 118,
        'I', 118,
        'M', 118,
        'R', 118,
        'X', 118,
        'd', 118,
        'i', 118,
        'm', 118,
        'r', 118,
        'x', 118,
      );
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(aux_sym_array_type_token2);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(aux_sym_array_type_token2);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(sym_dotnet_assembly_name);
      if (lookahead == '.') ADVANCE(89);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(123);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(anon_sym_POUNDif);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_POUNDIF);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_POUNDIf);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_POUNDelif);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(anon_sym_POUNDELIF);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_POUNDElif);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(anon_sym_POUNDelse);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_POUNDELSE);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_POUNDElse);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_POUNDendif);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(anon_sym_POUNDENDIF);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(anon_sym_POUNDEndif);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(sym_pragma);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(137);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(sym_preproc_region);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(138);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(sym_preproc_endregion);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(139);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(sym__assignment_operator);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(anon_sym_LPAREN2);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(16);
      if (lookahead == '/') ADVANCE(184);
      if (lookahead == '=') ADVANCE(140);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '=') ADVANCE(140);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(146);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(147);
      if (lookahead == '>') ADVANCE(150);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_LT_GT);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(sym_datetime_literal);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(sym_datetime_literal);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(152);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(sym_date_literal);
      if (lookahead == 'T') ADVANCE(152);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(sym_time_literal);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(sym_time_literal);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(88);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(sym_biginteger_literal);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(162);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(164);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(171);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(172);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(174);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(115);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(177);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(sym_identifier);
      ADVANCE_MAP(
        'E', 180,
        'e', 180,
        'D', 181,
        'I', 181,
        'M', 181,
        'R', 181,
        'X', 181,
        'd', 181,
        'i', 181,
        'm', 181,
        'r', 181,
        'x', 181,
      );
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(sym_identifier);
      ADVANCE_MAP(
        'F', 113,
        'f', 113,
        'D', 181,
        'I', 181,
        'M', 181,
        'R', 181,
        'X', 181,
        'd', 181,
        'i', 181,
        'm', 181,
        'r', 181,
        'x', 181,
      );
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(113);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(122);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(110);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(112);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(175);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(176);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(179);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(160);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(169);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(170);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(161);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(158);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(163);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(159);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(sym_identifier);
      ADVANCE_MAP(
        'D', 181,
        'I', 181,
        'M', 181,
        'R', 181,
        'X', 181,
        'd', 181,
        'i', 181,
        'm', 181,
        'r', 181,
        'x', 181,
      );
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(sym_identifier);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(182);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(sym_quoted_identifier);
      if (lookahead == '"') ADVANCE(8);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(184);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(sym_multiline_comment);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(sym_string_literal);
      if (lookahead == '\'') ADVANCE(13);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(83);
      if (lookahead == 'D') ADVANCE(154);
      if (lookahead == 'L') ADVANCE(157);
      if (lookahead == 'T') ADVANCE(155);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(195);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(83);
      if (lookahead == 'D') ADVANCE(154);
      if (lookahead == 'L') ADVANCE(157);
      if (lookahead == 'T') ADVANCE(155);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(187);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(83);
      if (lookahead == 'D') ADVANCE(154);
      if (lookahead == 'L') ADVANCE(157);
      if (lookahead == 'T') ADVANCE(155);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(188);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(83);
      if (lookahead == 'D') ADVANCE(154);
      if (lookahead == 'L') ADVANCE(157);
      if (lookahead == 'T') ADVANCE(155);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(189);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(83);
      if (lookahead == 'D') ADVANCE(154);
      if (lookahead == 'L') ADVANCE(157);
      if (lookahead == 'T') ADVANCE(155);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(190);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(83);
      if (lookahead == 'D') ADVANCE(154);
      if (lookahead == 'L') ADVANCE(157);
      if (lookahead == 'T') ADVANCE(155);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(191);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(83);
      if (lookahead == 'D') ADVANCE(154);
      if (lookahead == 'L') ADVANCE(157);
      if (lookahead == 'T') ADVANCE(155);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(192);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(83);
      if (lookahead == 'D') ADVANCE(154);
      if (lookahead == 'L') ADVANCE(157);
      if (lookahead == 'T') ADVANCE(155);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(194);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(83);
      if (lookahead == 'D') ADVANCE(154);
      if (lookahead == 'L') ADVANCE(157);
      if (lookahead == 'T') ADVANCE(156);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(194);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(sym_integer);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(196);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'A', 1,
        'B', 2,
        'C', 3,
        'D', 4,
        'E', 5,
        'F', 6,
        'I', 7,
        'M', 8,
        'N', 9,
        'O', 10,
        'P', 11,
        'R', 12,
        'T', 13,
        'U', 14,
        'W', 15,
        'X', 16,
        'a', 17,
        'b', 18,
        'c', 19,
        'd', 20,
        'e', 21,
        'f', 22,
        'i', 23,
        'm', 24,
        'n', 25,
        'o', 26,
        'p', 27,
        'r', 28,
        't', 29,
        'u', 30,
        'w', 31,
        'x', 32,
        'G', 33,
        'g', 33,
        'H', 34,
        'h', 34,
        'J', 35,
        'j', 35,
        'L', 36,
        'l', 36,
        'Q', 37,
        'q', 37,
        'S', 38,
        's', 38,
        'V', 39,
        'v', 39,
        'K', 40,
        'k', 40,
        0x212a, 40,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(0);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        'N', 41,
        'n', 42,
        'C', 43,
        'c', 43,
        'D', 44,
        'd', 44,
        'R', 45,
        'r', 45,
        'S', 46,
        's', 46,
      );
      END_STATE();
    case 2:
      ADVANCE_MAP(
        'R', 47,
        'r', 48,
        'E', 49,
        'e', 49,
        'I', 50,
        'i', 50,
        'L', 51,
        'l', 51,
        'O', 52,
        'o', 52,
        'Y', 53,
        'y', 53,
      );
      END_STATE();
    case 3:
      ADVANCE_MAP(
        'A', 54,
        'O', 55,
        'a', 56,
        'o', 57,
        'H', 58,
        'h', 58,
        'R', 59,
        'r', 59,
        'U', 60,
        'u', 60,
      );
      END_STATE();
    case 4:
      ADVANCE_MAP(
        'I', 61,
        'O', 62,
        'i', 63,
        'o', 64,
        'A', 65,
        'a', 65,
        'E', 66,
        'e', 66,
        'U', 67,
        'u', 67,
      );
      END_STATE();
    case 5:
      ADVANCE_MAP(
        'L', 68,
        'N', 69,
        'X', 70,
        'l', 71,
        'n', 72,
        'x', 73,
        'M', 74,
        'm', 74,
        'R', 75,
        'r', 75,
        'V', 76,
        'v', 76,
      );
      END_STATE();
    case 6:
      if (lookahead == 'O') ADVANCE(77);
      if (lookahead == 'o') ADVANCE(78);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(79);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(80);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        'F', 81,
        'N', 82,
        'f', 83,
        'n', 84,
        'M', 85,
        'm', 85,
        'S', 86,
        's', 86,
      );
      END_STATE();
    case 8:
      if (lookahead == 'O') ADVANCE(87);
      if (lookahead == 'o') ADVANCE(88);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(89);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(90);
      END_STATE();
    case 9:
      if (lookahead == 'O') ADVANCE(91);
      if (lookahead == 'o') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(93);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        'F', 94,
        'R', 95,
        'f', 96,
        'r', 97,
        'P', 98,
        'p', 98,
        'U', 99,
        'u', 99,
      );
      END_STATE();
    case 11:
      ADVANCE_MAP(
        'A', 100,
        'E', 101,
        'R', 102,
        'a', 103,
        'e', 104,
        'r', 105,
        'U', 106,
        'u', 106,
      );
      END_STATE();
    case 12:
      if (lookahead == 'E') ADVANCE(107);
      if (lookahead == 'e') ADVANCE(108);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(109);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        'A', 110,
        'H', 111,
        'O', 112,
        'a', 113,
        'h', 114,
        'o', 115,
        'E', 116,
        'e', 116,
        'I', 117,
        'i', 117,
        'R', 118,
        'r', 118,
        'Y', 119,
        'y', 119,
      );
      END_STATE();
    case 14:
      if (lookahead == 'N') ADVANCE(120);
      if (lookahead == 'n') ADVANCE(121);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(122);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(123);
      END_STATE();
    case 15:
      if (lookahead == 'H') ADVANCE(124);
      if (lookahead == 'I') ADVANCE(125);
      if (lookahead == 'h') ADVANCE(126);
      if (lookahead == 'i') ADVANCE(127);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(128);
      END_STATE();
    case 16:
      if (lookahead == 'M') ADVANCE(129);
      if (lookahead == 'O') ADVANCE(130);
      if (lookahead == 'm') ADVANCE(131);
      if (lookahead == 'o') ADVANCE(132);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        'n', 133,
        'C', 43,
        'c', 43,
        'D', 44,
        'd', 44,
        'R', 45,
        'r', 45,
        'S', 46,
        's', 46,
      );
      END_STATE();
    case 18:
      ADVANCE_MAP(
        'r', 134,
        'E', 49,
        'e', 49,
        'I', 50,
        'i', 50,
        'L', 51,
        'l', 51,
        'O', 52,
        'o', 52,
        'Y', 53,
        'y', 53,
      );
      END_STATE();
    case 19:
      ADVANCE_MAP(
        'O', 135,
        'a', 136,
        'o', 137,
        'H', 58,
        'h', 58,
        'R', 59,
        'r', 59,
        'U', 60,
        'u', 60,
      );
      END_STATE();
    case 20:
      ADVANCE_MAP(
        'I', 138,
        'i', 139,
        'o', 140,
        'A', 65,
        'a', 65,
        'E', 66,
        'e', 66,
        'U', 67,
        'u', 67,
      );
      END_STATE();
    case 21:
      ADVANCE_MAP(
        'L', 141,
        'N', 142,
        'X', 143,
        'l', 144,
        'n', 145,
        'x', 146,
        'M', 74,
        'm', 74,
        'R', 75,
        'r', 75,
        'V', 76,
        'v', 76,
      );
      END_STATE();
    case 22:
      if (lookahead == 'o') ADVANCE(147);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(79);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(80);
      END_STATE();
    case 23:
      if (lookahead == 'N') ADVANCE(148);
      if (lookahead == 'f') ADVANCE(149);
      if (lookahead == 'n') ADVANCE(150);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(85);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(86);
      END_STATE();
    case 24:
      if (lookahead == 'O') ADVANCE(151);
      if (lookahead == 'o') ADVANCE(152);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(89);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(90);
      END_STATE();
    case 25:
      if (lookahead == 'O') ADVANCE(153);
      if (lookahead == 'o') ADVANCE(154);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(93);
      END_STATE();
    case 26:
      if (lookahead == 'R') ADVANCE(155);
      if (lookahead == 'f') ADVANCE(156);
      if (lookahead == 'r') ADVANCE(157);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(98);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(99);
      END_STATE();
    case 27:
      if (lookahead == 'A') ADVANCE(158);
      if (lookahead == 'R') ADVANCE(159);
      if (lookahead == 'a') ADVANCE(160);
      if (lookahead == 'e') ADVANCE(161);
      if (lookahead == 'r') ADVANCE(162);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(106);
      END_STATE();
    case 28:
      if (lookahead == 'E') ADVANCE(163);
      if (lookahead == 'e') ADVANCE(164);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(109);
      END_STATE();
    case 29:
      ADVANCE_MAP(
        'A', 165,
        'a', 166,
        'h', 167,
        'o', 168,
        'E', 116,
        'e', 116,
        'I', 117,
        'i', 117,
        'R', 118,
        'r', 118,
        'Y', 119,
        'y', 119,
      );
      END_STATE();
    case 30:
      if (lookahead == 'n') ADVANCE(169);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(122);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(123);
      END_STATE();
    case 31:
      if (lookahead == 'H') ADVANCE(170);
      if (lookahead == 'h') ADVANCE(171);
      if (lookahead == 'i') ADVANCE(172);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(128);
      END_STATE();
    case 32:
      if (lookahead == 'M') ADVANCE(173);
      if (lookahead == 'm') ADVANCE(174);
      if (lookahead == 'o') ADVANCE(175);
      END_STATE();
    case 33:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(176);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(177);
      END_STATE();
    case 34:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(178);
      END_STATE();
    case 35:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(179);
      END_STATE();
    case 36:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(180);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(181);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(182);
      END_STATE();
    case 37:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(183);
      END_STATE();
    case 38:
      ADVANCE_MAP(
        'C', 184,
        'c', 184,
        'E', 185,
        'e', 185,
        'O', 186,
        'o', 186,
        'Y', 187,
        'y', 187,
      );
      END_STATE();
    case 39:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(188);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(189);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(190);
      END_STATE();
    case 40:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(191);
      END_STATE();
    case 41:
      if (lookahead == 'D') ADVANCE(192);
      END_STATE();
    case 42:
      if (lookahead == 'd') ADVANCE(193);
      END_STATE();
    case 43:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(194);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(195);
      END_STATE();
    case 44:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(196);
      END_STATE();
    case 45:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(197);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(198);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(aux_sym__expression_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(199);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(200);
      END_STATE();
    case 47:
      if (lookahead == 'E') ADVANCE(201);
      END_STATE();
    case 48:
      if (lookahead == 'e') ADVANCE(202);
      END_STATE();
    case 49:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(203);
      END_STATE();
    case 50:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(204);
      END_STATE();
    case 51:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(205);
      END_STATE();
    case 52:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(206);
      END_STATE();
    case 53:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(207);
      END_STATE();
    case 54:
      if (lookahead == 'S') ADVANCE(208);
      END_STATE();
    case 55:
      ADVANCE_MAP(
        'D', 209,
        'N', 210,
        'd', 211,
        'n', 212,
        'L', 213,
        'l', 213,
        'M', 214,
        'm', 214,
      );
      END_STATE();
    case 56:
      if (lookahead == 's') ADVANCE(215);
      END_STATE();
    case 57:
      ADVANCE_MAP(
        'D', 216,
        'N', 212,
        'd', 217,
        'n', 218,
        'L', 213,
        'l', 213,
        'M', 214,
        'm', 214,
      );
      END_STATE();
    case 58:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(219);
      END_STATE();
    case 59:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(220);
      END_STATE();
    case 60:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(221);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(222);
      END_STATE();
    case 61:
      if (lookahead == 'V') ADVANCE(223);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(224);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(225);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(anon_sym_DO);
      if (lookahead == 'T') ADVANCE(226);
      if (lookahead == 'W') ADVANCE(227);
      END_STATE();
    case 63:
      if (lookahead == 'v') ADVANCE(228);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(224);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(225);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(anon_sym_Do);
      if (lookahead == 't') ADVANCE(229);
      if (lookahead == 'w') ADVANCE(230);
      END_STATE();
    case 65:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(231);
      END_STATE();
    case 66:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(232);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(233);
      END_STATE();
    case 67:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(234);
      END_STATE();
    case 68:
      if (lookahead == 'S') ADVANCE(235);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(236);
      END_STATE();
    case 69:
      if (lookahead == 'U') ADVANCE(237);
      if (lookahead == 'u') ADVANCE(238);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(239);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(240);
      END_STATE();
    case 70:
      if (lookahead == 'I') ADVANCE(241);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(242);
      END_STATE();
    case 71:
      if (lookahead == 's') ADVANCE(243);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(236);
      END_STATE();
    case 72:
      if (lookahead == 'u') ADVANCE(244);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(239);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(240);
      END_STATE();
    case 73:
      if (lookahead == 'i') ADVANCE(245);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(242);
      END_STATE();
    case 74:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(246);
      END_STATE();
    case 75:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(247);
      END_STATE();
    case 76:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(248);
      END_STATE();
    case 77:
      if (lookahead == 'R') ADVANCE(249);
      END_STATE();
    case 78:
      if (lookahead == 'r') ADVANCE(250);
      END_STATE();
    case 79:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(251);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(252);
      END_STATE();
    case 80:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(253);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(254);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(255);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_IF);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(anon_sym_IN);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(256);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(257);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_If);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_In);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(256);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(257);
      END_STATE();
    case 85:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(258);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(aux_sym__expression_token1);
      END_STATE();
    case 87:
      if (lookahead == 'D') ADVANCE(259);
      if (lookahead == 'd') ADVANCE(260);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(261);
      END_STATE();
    case 88:
      if (lookahead == 'D') ADVANCE(260);
      if (lookahead == 'd') ADVANCE(262);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(261);
      END_STATE();
    case 89:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(263);
      END_STATE();
    case 90:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(264);
      END_STATE();
    case 91:
      if (lookahead == 'T') ADVANCE(265);
      if (lookahead == 't') ADVANCE(266);
      END_STATE();
    case 92:
      if (lookahead == 'T') ADVANCE(266);
      if (lookahead == 't') ADVANCE(267);
      END_STATE();
    case 93:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(268);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(269);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(anon_sym_OF);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(anon_sym_OR);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(270);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_Of);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(anon_sym_Or);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(270);
      END_STATE();
    case 98:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(271);
      END_STATE();
    case 99:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(272);
      END_STATE();
    case 100:
      if (lookahead == 'G') ADVANCE(273);
      if (lookahead == 'g') ADVANCE(274);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(275);
      END_STATE();
    case 101:
      if (lookahead == 'R') ADVANCE(276);
      END_STATE();
    case 102:
      if (lookahead == 'O') ADVANCE(277);
      if (lookahead == 'o') ADVANCE(278);
      END_STATE();
    case 103:
      if (lookahead == 'G') ADVANCE(274);
      if (lookahead == 'g') ADVANCE(279);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(275);
      END_STATE();
    case 104:
      if (lookahead == 'r') ADVANCE(280);
      END_STATE();
    case 105:
      if (lookahead == 'O') ADVANCE(278);
      if (lookahead == 'o') ADVANCE(281);
      END_STATE();
    case 106:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(282);
      END_STATE();
    case 107:
      ADVANCE_MAP(
        'P', 283,
        'p', 284,
        'C', 285,
        'c', 285,
        'N', 286,
        'n', 286,
        'Q', 287,
        'q', 287,
      );
      END_STATE();
    case 108:
      ADVANCE_MAP(
        'P', 284,
        'p', 288,
        'C', 285,
        'c', 285,
        'N', 286,
        'n', 286,
        'Q', 287,
        'q', 287,
      );
      END_STATE();
    case 109:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(289);
      END_STATE();
    case 110:
      if (lookahead == 'B') ADVANCE(290);
      if (lookahead == 'b') ADVANCE(291);
      END_STATE();
    case 111:
      if (lookahead == 'E') ADVANCE(292);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(anon_sym_TO);
      END_STATE();
    case 113:
      if (lookahead == 'B') ADVANCE(291);
      if (lookahead == 'b') ADVANCE(293);
      END_STATE();
    case 114:
      if (lookahead == 'e') ADVANCE(294);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_To);
      END_STATE();
    case 116:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(295);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(296);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(297);
      END_STATE();
    case 117:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(298);
      END_STATE();
    case 118:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(299);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(300);
      END_STATE();
    case 119:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(301);
      END_STATE();
    case 120:
      if (lookahead == 'T') ADVANCE(302);
      END_STATE();
    case 121:
      if (lookahead == 't') ADVANCE(303);
      END_STATE();
    case 122:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(304);
      END_STATE();
    case 123:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(305);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(306);
      END_STATE();
    case 124:
      if (lookahead == 'I') ADVANCE(307);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(308);
      END_STATE();
    case 125:
      if (lookahead == 'T') ADVANCE(309);
      END_STATE();
    case 126:
      if (lookahead == 'i') ADVANCE(310);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(308);
      END_STATE();
    case 127:
      if (lookahead == 't') ADVANCE(311);
      END_STATE();
    case 128:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(312);
      END_STATE();
    case 129:
      if (lookahead == 'L') ADVANCE(313);
      if (lookahead == 'l') ADVANCE(314);
      END_STATE();
    case 130:
      if (lookahead == 'R') ADVANCE(315);
      END_STATE();
    case 131:
      if (lookahead == 'L') ADVANCE(314);
      if (lookahead == 'l') ADVANCE(316);
      END_STATE();
    case 132:
      if (lookahead == 'r') ADVANCE(317);
      END_STATE();
    case 133:
      if (lookahead == 'd') ADVANCE(318);
      END_STATE();
    case 134:
      if (lookahead == 'e') ADVANCE(319);
      END_STATE();
    case 135:
      ADVANCE_MAP(
        'D', 216,
        'd', 216,
        'L', 213,
        'l', 213,
        'M', 214,
        'm', 214,
        'N', 212,
        'n', 212,
      );
      END_STATE();
    case 136:
      if (lookahead == 's') ADVANCE(320);
      END_STATE();
    case 137:
      ADVANCE_MAP(
        'D', 216,
        'N', 212,
        'd', 321,
        'n', 322,
        'L', 213,
        'l', 213,
        'M', 214,
        'm', 214,
      );
      END_STATE();
    case 138:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(224);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(225);
      END_STATE();
    case 139:
      if (lookahead == 'v') ADVANCE(323);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(224);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(225);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_do);
      if (lookahead == 't') ADVANCE(324);
      if (lookahead == 'w') ADVANCE(325);
      END_STATE();
    case 141:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(236);
      END_STATE();
    case 142:
      if (lookahead == 'U') ADVANCE(326);
      if (lookahead == 'u') ADVANCE(327);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(239);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(240);
      END_STATE();
    case 143:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(242);
      END_STATE();
    case 144:
      if (lookahead == 's') ADVANCE(328);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(236);
      END_STATE();
    case 145:
      if (lookahead == 'u') ADVANCE(329);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(239);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(240);
      END_STATE();
    case 146:
      if (lookahead == 'i') ADVANCE(330);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(242);
      END_STATE();
    case 147:
      if (lookahead == 'r') ADVANCE(331);
      END_STATE();
    case 148:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(256);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(257);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(256);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(257);
      END_STATE();
    case 151:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(260);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(261);
      END_STATE();
    case 152:
      if (lookahead == 'D') ADVANCE(260);
      if (lookahead == 'd') ADVANCE(332);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(261);
      END_STATE();
    case 153:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(266);
      END_STATE();
    case 154:
      if (lookahead == 'T') ADVANCE(266);
      if (lookahead == 't') ADVANCE(333);
      END_STATE();
    case 155:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(270);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_of);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_or);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(270);
      END_STATE();
    case 158:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(274);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(275);
      END_STATE();
    case 159:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(278);
      END_STATE();
    case 160:
      if (lookahead == 'G') ADVANCE(274);
      if (lookahead == 'g') ADVANCE(334);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(275);
      END_STATE();
    case 161:
      if (lookahead == 'r') ADVANCE(335);
      END_STATE();
    case 162:
      if (lookahead == 'O') ADVANCE(278);
      if (lookahead == 'o') ADVANCE(336);
      END_STATE();
    case 163:
      ADVANCE_MAP(
        'C', 285,
        'c', 285,
        'N', 286,
        'n', 286,
        'P', 284,
        'p', 284,
        'Q', 287,
        'q', 287,
      );
      END_STATE();
    case 164:
      ADVANCE_MAP(
        'P', 284,
        'p', 337,
        'C', 285,
        'c', 285,
        'N', 286,
        'n', 286,
        'Q', 287,
        'q', 287,
      );
      END_STATE();
    case 165:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(291);
      END_STATE();
    case 166:
      if (lookahead == 'B') ADVANCE(291);
      if (lookahead == 'b') ADVANCE(338);
      END_STATE();
    case 167:
      if (lookahead == 'e') ADVANCE(339);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_to);
      END_STATE();
    case 169:
      if (lookahead == 't') ADVANCE(340);
      END_STATE();
    case 170:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(308);
      END_STATE();
    case 171:
      if (lookahead == 'i') ADVANCE(341);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(308);
      END_STATE();
    case 172:
      if (lookahead == 't') ADVANCE(342);
      END_STATE();
    case 173:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(314);
      END_STATE();
    case 174:
      if (lookahead == 'L') ADVANCE(314);
      if (lookahead == 'l') ADVANCE(343);
      END_STATE();
    case 175:
      if (lookahead == 'r') ADVANCE(344);
      END_STATE();
    case 176:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(345);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(346);
      END_STATE();
    case 177:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(347);
      END_STATE();
    case 178:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(348);
      END_STATE();
    case 179:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(349);
      END_STATE();
    case 180:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(350);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(351);
      END_STATE();
    case 181:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(352);
      END_STATE();
    case 182:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(353);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(354);
      END_STATE();
    case 183:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(355);
      END_STATE();
    case 184:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(356);
      END_STATE();
    case 185:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(357);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(358);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(359);
      END_STATE();
    case 186:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(360);
      END_STATE();
    case 187:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(361);
      END_STATE();
    case 188:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(362);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(363);
      END_STATE();
    case 189:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(364);
      END_STATE();
    case 190:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(365);
      END_STATE();
    case 191:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(366);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_AND);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(anon_sym_And);
      END_STATE();
    case 194:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(367);
      END_STATE();
    case 195:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(368);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(aux_sym_add_dataset_modification_token1);
      ADVANCE_MAP(
        'A', 369,
        'a', 369,
        'B', 370,
        'b', 370,
        'F', 371,
        'f', 371,
        'L', 372,
        'l', 372,
      );
      END_STATE();
    case 197:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(373);
      END_STATE();
    case 198:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(374);
      END_STATE();
    case 199:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(375);
      END_STATE();
    case 200:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(376);
      END_STATE();
    case 201:
      if (lookahead == 'A') ADVANCE(377);
      END_STATE();
    case 202:
      if (lookahead == 'a') ADVANCE(378);
      END_STATE();
    case 203:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(379);
      END_STATE();
    case 204:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(380);
      END_STATE();
    case 205:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(381);
      END_STATE();
    case 206:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(382);
      END_STATE();
    case 207:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(383);
      END_STATE();
    case 208:
      if (lookahead == 'E') ADVANCE(384);
      END_STATE();
    case 209:
      if (lookahead == 'E') ADVANCE(385);
      if (lookahead == 'e') ADVANCE(386);
      END_STATE();
    case 210:
      if (lookahead == 'T') ADVANCE(387);
      if (lookahead == 't') ADVANCE(388);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(389);
      END_STATE();
    case 211:
      if (lookahead == 'E') ADVANCE(386);
      if (lookahead == 'e') ADVANCE(390);
      END_STATE();
    case 212:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(389);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(388);
      END_STATE();
    case 213:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(391);
      END_STATE();
    case 214:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(392);
      END_STATE();
    case 215:
      if (lookahead == 'e') ADVANCE(393);
      END_STATE();
    case 216:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(386);
      END_STATE();
    case 217:
      if (lookahead == 'E') ADVANCE(386);
      if (lookahead == 'e') ADVANCE(394);
      END_STATE();
    case 218:
      if (lookahead == 'T') ADVANCE(388);
      if (lookahead == 't') ADVANCE(395);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(389);
      END_STATE();
    case 219:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(396);
      END_STATE();
    case 220:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(397);
      END_STATE();
    case 221:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(398);
      END_STATE();
    case 222:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(399);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(anon_sym_DIV);
      END_STATE();
    case 224:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(400);
      END_STATE();
    case 225:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(401);
      END_STATE();
    case 226:
      if (lookahead == 'N') ADVANCE(402);
      END_STATE();
    case 227:
      if (lookahead == 'N') ADVANCE(403);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(anon_sym_Div);
      END_STATE();
    case 229:
      if (lookahead == 'N') ADVANCE(404);
      if (lookahead == 'n') ADVANCE(405);
      END_STATE();
    case 230:
      if (lookahead == 'n') ADVANCE(406);
      END_STATE();
    case 231:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(407);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(408);
      END_STATE();
    case 232:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(409);
      END_STATE();
    case 233:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(410);
      END_STATE();
    case 234:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(411);
      END_STATE();
    case 235:
      if (lookahead == 'E') ADVANCE(412);
      END_STATE();
    case 236:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(413);
      END_STATE();
    case 237:
      if (lookahead == 'M') ADVANCE(414);
      END_STATE();
    case 238:
      if (lookahead == 'm') ADVANCE(415);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(aux_sym_preproc_split_procedure_body_token2);
      END_STATE();
    case 240:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(416);
      END_STATE();
    case 241:
      if (lookahead == 'T') ADVANCE(417);
      END_STATE();
    case 242:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(418);
      END_STATE();
    case 243:
      if (lookahead == 'e') ADVANCE(419);
      END_STATE();
    case 244:
      if (lookahead == 'm') ADVANCE(420);
      END_STATE();
    case 245:
      if (lookahead == 't') ADVANCE(421);
      END_STATE();
    case 246:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(422);
      END_STATE();
    case 247:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(423);
      END_STATE();
    case 248:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(424);
      END_STATE();
    case 249:
      ACCEPT_TOKEN(anon_sym_FOR);
      if (lookahead == 'E') ADVANCE(425);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(anon_sym_For);
      if (lookahead == 'e') ADVANCE(426);
      END_STATE();
    case 251:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(427);
      END_STATE();
    case 252:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(428);
      END_STATE();
    case 253:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(429);
      END_STATE();
    case 254:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(430);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(431);
      END_STATE();
    case 255:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(432);
      END_STATE();
    case 256:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(433);
      END_STATE();
    case 257:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(434);
      END_STATE();
    case 258:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(435);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(anon_sym_MOD);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(436);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(437);
      END_STATE();
    case 260:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(436);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(437);
      END_STATE();
    case 261:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(438);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(anon_sym_Mod);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(436);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(437);
      END_STATE();
    case 263:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(439);
      END_STATE();
    case 264:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(440);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(anon_sym_NOT);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(441);
      END_STATE();
    case 266:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(441);
      END_STATE();
    case 267:
      ACCEPT_TOKEN(anon_sym_Not);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(441);
      END_STATE();
    case 268:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(442);
      END_STATE();
    case 269:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(443);
      END_STATE();
    case 270:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(444);
      END_STATE();
    case 271:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(445);
      END_STATE();
    case 272:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(446);
      END_STATE();
    case 273:
      if (lookahead == 'E') ADVANCE(447);
      if (lookahead == 'e') ADVANCE(448);
      END_STATE();
    case 274:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(448);
      END_STATE();
    case 275:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(449);
      END_STATE();
    case 276:
      if (lookahead == 'M') ADVANCE(450);
      END_STATE();
    case 277:
      ADVANCE_MAP(
        'F', 451,
        'f', 452,
        'C', 453,
        'c', 453,
        'M', 454,
        'm', 454,
        'T', 455,
        't', 455,
      );
      END_STATE();
    case 278:
      ADVANCE_MAP(
        'C', 453,
        'c', 453,
        'F', 452,
        'f', 452,
        'M', 454,
        'm', 454,
        'T', 455,
        't', 455,
      );
      END_STATE();
    case 279:
      if (lookahead == 'E') ADVANCE(448);
      if (lookahead == 'e') ADVANCE(456);
      END_STATE();
    case 280:
      if (lookahead == 'm') ADVANCE(457);
      END_STATE();
    case 281:
      ADVANCE_MAP(
        'F', 452,
        'f', 458,
        'C', 453,
        'c', 453,
        'M', 454,
        'm', 454,
        'T', 455,
        't', 455,
      );
      END_STATE();
    case 282:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(459);
      END_STATE();
    case 283:
      if (lookahead == 'E') ADVANCE(460);
      if (lookahead == 'O') ADVANCE(461);
      if (lookahead == 'e') ADVANCE(462);
      if (lookahead == 'o') ADVANCE(463);
      END_STATE();
    case 284:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(462);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(463);
      END_STATE();
    case 285:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(464);
      END_STATE();
    case 286:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(465);
      END_STATE();
    case 287:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(466);
      END_STATE();
    case 288:
      if (lookahead == 'E') ADVANCE(462);
      if (lookahead == 'O') ADVANCE(463);
      if (lookahead == 'e') ADVANCE(467);
      if (lookahead == 'o') ADVANCE(468);
      END_STATE();
    case 289:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(469);
      END_STATE();
    case 290:
      if (lookahead == 'L') ADVANCE(470);
      if (lookahead == 'l') ADVANCE(471);
      END_STATE();
    case 291:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(471);
      END_STATE();
    case 292:
      if (lookahead == 'N') ADVANCE(472);
      END_STATE();
    case 293:
      if (lookahead == 'L') ADVANCE(471);
      if (lookahead == 'l') ADVANCE(473);
      END_STATE();
    case 294:
      if (lookahead == 'n') ADVANCE(474);
      END_STATE();
    case 295:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(475);
      END_STATE();
    case 296:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(476);
      END_STATE();
    case 297:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(477);
      END_STATE();
    case 298:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(478);
      END_STATE();
    case 299:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(479);
      END_STATE();
    case 300:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(480);
      END_STATE();
    case 301:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(481);
      END_STATE();
    case 302:
      if (lookahead == 'I') ADVANCE(482);
      END_STATE();
    case 303:
      if (lookahead == 'i') ADVANCE(483);
      END_STATE();
    case 304:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(484);
      END_STATE();
    case 305:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(485);
      END_STATE();
    case 306:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(486);
      END_STATE();
    case 307:
      if (lookahead == 'L') ADVANCE(487);
      END_STATE();
    case 308:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(488);
      END_STATE();
    case 309:
      if (lookahead == 'H') ADVANCE(489);
      END_STATE();
    case 310:
      if (lookahead == 'l') ADVANCE(490);
      END_STATE();
    case 311:
      if (lookahead == 'h') ADVANCE(491);
      END_STATE();
    case 312:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(492);
      END_STATE();
    case 313:
      ADVANCE_MAP(
        'P', 493,
        'p', 494,
        'A', 495,
        'a', 495,
        'D', 496,
        'd', 496,
        'E', 497,
        'e', 497,
        'N', 498,
        'n', 498,
      );
      END_STATE();
    case 314:
      ADVANCE_MAP(
        'A', 495,
        'a', 495,
        'D', 496,
        'd', 496,
        'E', 497,
        'e', 497,
        'N', 498,
        'n', 498,
      );
      END_STATE();
    case 315:
      ACCEPT_TOKEN(anon_sym_XOR);
      END_STATE();
    case 316:
      ADVANCE_MAP(
        'P', 499,
        'p', 500,
        'A', 495,
        'a', 495,
        'D', 496,
        'd', 496,
        'E', 497,
        'e', 497,
        'N', 498,
        'n', 498,
      );
      END_STATE();
    case 317:
      ACCEPT_TOKEN(anon_sym_Xor);
      END_STATE();
    case 318:
      ACCEPT_TOKEN(anon_sym_and);
      END_STATE();
    case 319:
      if (lookahead == 'a') ADVANCE(501);
      END_STATE();
    case 320:
      if (lookahead == 'e') ADVANCE(502);
      END_STATE();
    case 321:
      if (lookahead == 'E') ADVANCE(386);
      if (lookahead == 'e') ADVANCE(503);
      END_STATE();
    case 322:
      if (lookahead == 'T') ADVANCE(388);
      if (lookahead == 't') ADVANCE(504);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(389);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(anon_sym_div);
      END_STATE();
    case 324:
      if (lookahead == 'N') ADVANCE(505);
      if (lookahead == 'n') ADVANCE(506);
      END_STATE();
    case 325:
      if (lookahead == 'n') ADVANCE(507);
      END_STATE();
    case 326:
      if (lookahead == 'M') ADVANCE(508);
      END_STATE();
    case 327:
      if (lookahead == 'm') ADVANCE(509);
      END_STATE();
    case 328:
      if (lookahead == 'e') ADVANCE(510);
      END_STATE();
    case 329:
      if (lookahead == 'm') ADVANCE(511);
      END_STATE();
    case 330:
      if (lookahead == 't') ADVANCE(512);
      END_STATE();
    case 331:
      ACCEPT_TOKEN(anon_sym_for);
      if (lookahead == 'e') ADVANCE(513);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(anon_sym_mod);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(436);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(437);
      END_STATE();
    case 333:
      ACCEPT_TOKEN(anon_sym_not);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(441);
      END_STATE();
    case 334:
      if (lookahead == 'E') ADVANCE(448);
      if (lookahead == 'e') ADVANCE(514);
      END_STATE();
    case 335:
      if (lookahead == 'm') ADVANCE(515);
      END_STATE();
    case 336:
      ADVANCE_MAP(
        'F', 452,
        'f', 516,
        'C', 453,
        'c', 453,
        'M', 454,
        'm', 454,
        'T', 455,
        't', 455,
      );
      END_STATE();
    case 337:
      if (lookahead == 'E') ADVANCE(462);
      if (lookahead == 'O') ADVANCE(463);
      if (lookahead == 'e') ADVANCE(517);
      if (lookahead == 'o') ADVANCE(518);
      END_STATE();
    case 338:
      if (lookahead == 'L') ADVANCE(471);
      if (lookahead == 'l') ADVANCE(519);
      END_STATE();
    case 339:
      if (lookahead == 'n') ADVANCE(520);
      END_STATE();
    case 340:
      if (lookahead == 'i') ADVANCE(521);
      END_STATE();
    case 341:
      if (lookahead == 'l') ADVANCE(522);
      END_STATE();
    case 342:
      if (lookahead == 'h') ADVANCE(523);
      END_STATE();
    case 343:
      ADVANCE_MAP(
        'p', 524,
        'A', 495,
        'a', 495,
        'D', 496,
        'd', 496,
        'E', 497,
        'e', 497,
        'N', 498,
        'n', 498,
      );
      END_STATE();
    case 344:
      ACCEPT_TOKEN(anon_sym_xor);
      END_STATE();
    case 345:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(525);
      END_STATE();
    case 346:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(526);
      END_STATE();
    case 347:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(527);
      END_STATE();
    case 348:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(528);
      END_STATE();
    case 349:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(529);
      END_STATE();
    case 350:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(530);
      END_STATE();
    case 351:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(531);
      END_STATE();
    case 352:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(532);
      END_STATE();
    case 353:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(533);
      if (lookahead == 'K' ||
          lookahead == 'k' ||
          lookahead == 0x212a) ADVANCE(534);
      END_STATE();
    case 354:
      if (lookahead == 'K' ||
          lookahead == 'k' ||
          lookahead == 0x212a) ADVANCE(535);
      END_STATE();
    case 355:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(536);
      END_STATE();
    case 356:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(537);
      END_STATE();
    case 357:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(538);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(539);
      END_STATE();
    case 358:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(540);
      END_STATE();
    case 359:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(541);
      END_STATE();
    case 360:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(542);
      END_STATE();
    case 361:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(543);
      END_STATE();
    case 362:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(544);
      END_STATE();
    case 363:
      ACCEPT_TOKEN(sym_var_keyword);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(545);
      END_STATE();
    case 364:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(546);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(547);
      END_STATE();
    case 365:
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(548);
      END_STATE();
    case 366:
      ACCEPT_TOKEN(sym_key_keyword);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(549);
      END_STATE();
    case 367:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(550);
      END_STATE();
    case 368:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(551);
      END_STATE();
    case 369:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(552);
      END_STATE();
    case 370:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(553);
      END_STATE();
    case 371:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(554);
      END_STATE();
    case 372:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(555);
      END_STATE();
    case 373:
      ACCEPT_TOKEN(sym_area_keyword);
      END_STATE();
    case 374:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(556);
      END_STATE();
    case 375:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(557);
      END_STATE();
    case 376:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(558);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(559);
      END_STATE();
    case 377:
      if (lookahead == 'K') ADVANCE(560);
      END_STATE();
    case 378:
      if (lookahead == 'k') ADVANCE(561);
      END_STATE();
    case 379:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(562);
      END_STATE();
    case 380:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(563);
      END_STATE();
    case 381:
      ACCEPT_TOKEN(aux_sym_basic_type_token16);
      END_STATE();
    case 382:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(564);
      END_STATE();
    case 383:
      ACCEPT_TOKEN(aux_sym_basic_type_token4);
      END_STATE();
    case 384:
      ACCEPT_TOKEN(anon_sym_CASE);
      END_STATE();
    case 385:
      ACCEPT_TOKEN(aux_sym_code_type_token1);
      if (lookahead == 'U') ADVANCE(565);
      END_STATE();
    case 386:
      ACCEPT_TOKEN(aux_sym_code_type_token1);
      END_STATE();
    case 387:
      if (lookahead == 'I') ADVANCE(566);
      if (lookahead == 'R') ADVANCE(567);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(568);
      END_STATE();
    case 388:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(568);
      END_STATE();
    case 389:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(569);
      END_STATE();
    case 390:
      ACCEPT_TOKEN(aux_sym_code_type_token1);
      if (lookahead == 'u') ADVANCE(570);
      END_STATE();
    case 391:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(571);
      END_STATE();
    case 392:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(572);
      END_STATE();
    case 393:
      ACCEPT_TOKEN(anon_sym_Case);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(aux_sym_code_type_token1);
      if (lookahead == 'U') ADVANCE(573);
      if (lookahead == 'u') ADVANCE(574);
      END_STATE();
    case 395:
      if (lookahead == 'i') ADVANCE(575);
      if (lookahead == 'r') ADVANCE(576);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(568);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(aux_sym_basic_type_token5);
      END_STATE();
    case 397:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(577);
      END_STATE();
    case 398:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(578);
      END_STATE();
    case 399:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(579);
      END_STATE();
    case 400:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(580);
      END_STATE();
    case 401:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(581);
      END_STATE();
    case 402:
      if (lookahead == 'E') ADVANCE(582);
      END_STATE();
    case 403:
      if (lookahead == 'T') ADVANCE(583);
      END_STATE();
    case 404:
      if (lookahead == 'e') ADVANCE(584);
      END_STATE();
    case 405:
      if (lookahead == 'e') ADVANCE(585);
      END_STATE();
    case 406:
      if (lookahead == 't') ADVANCE(586);
      END_STATE();
    case 407:
      ADVANCE_MAP(
        'B', 587,
        'b', 587,
        'I', 588,
        'i', 588,
        'S', 589,
        's', 589,
        'T', 590,
        't', 590,
      );
      END_STATE();
    case 408:
      ACCEPT_TOKEN(aux_sym_basic_type_token9);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(591);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(592);
      END_STATE();
    case 409:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(593);
      END_STATE();
    case 410:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(594);
      END_STATE();
    case 411:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(595);
      END_STATE();
    case 412:
      ACCEPT_TOKEN(anon_sym_ELSE);
      END_STATE();
    case 413:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(596);
      END_STATE();
    case 414:
      ACCEPT_TOKEN(anon_sym_ENUM);
      if (lookahead == 'E') ADVANCE(597);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(anon_sym_ENum);
      END_STATE();
    case 416:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(598);
      END_STATE();
    case 417:
      ACCEPT_TOKEN(anon_sym_EXIT);
      END_STATE();
    case 418:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(599);
      END_STATE();
    case 419:
      ACCEPT_TOKEN(anon_sym_Else);
      END_STATE();
    case 420:
      ACCEPT_TOKEN(anon_sym_Enum);
      if (lookahead == 'E') ADVANCE(600);
      if (lookahead == 'e') ADVANCE(601);
      END_STATE();
    case 421:
      ACCEPT_TOKEN(anon_sym_Exit);
      END_STATE();
    case 422:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(602);
      END_STATE();
    case 423:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(603);
      END_STATE();
    case 424:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(604);
      END_STATE();
    case 425:
      if (lookahead == 'A') ADVANCE(605);
      END_STATE();
    case 426:
      if (lookahead == 'a') ADVANCE(606);
      END_STATE();
    case 427:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(607);
      END_STATE();
    case 428:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(608);
      END_STATE();
    case 429:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(609);
      END_STATE();
    case 430:
      ACCEPT_TOKEN(aux_sym_basic_type_token48);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(610);
      END_STATE();
    case 431:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(611);
      END_STATE();
    case 432:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(612);
      END_STATE();
    case 433:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(613);
      END_STATE();
    case 434:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(614);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(615);
      END_STATE();
    case 435:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(616);
      END_STATE();
    case 436:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(617);
      END_STATE();
    case 437:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(618);
      END_STATE();
    case 438:
      ADVANCE_MAP(
        'A', 619,
        'a', 619,
        'B', 620,
        'b', 620,
        'F', 621,
        'f', 621,
        'L', 622,
        'l', 622,
      );
      END_STATE();
    case 439:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(623);
      END_STATE();
    case 440:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(624);
      END_STATE();
    case 441:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(625);
      END_STATE();
    case 442:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(626);
      END_STATE();
    case 443:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(627);
      END_STATE();
    case 444:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(628);
      END_STATE();
    case 445:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(629);
      END_STATE();
    case 446:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(630);
      END_STATE();
    case 447:
      ACCEPT_TOKEN(sym_page_keyword);
      if (lookahead == 'C') ADVANCE(631);
      if (lookahead == 'E') ADVANCE(632);
      END_STATE();
    case 448:
      ACCEPT_TOKEN(sym_page_keyword);
      END_STATE();
    case 449:
      ACCEPT_TOKEN(sym_part_keyword);
      END_STATE();
    case 450:
      if (lookahead == 'I') ADVANCE(633);
      END_STATE();
    case 451:
      if (lookahead == 'I') ADVANCE(634);
      if (lookahead == 'i') ADVANCE(635);
      END_STATE();
    case 452:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(635);
      END_STATE();
    case 453:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(636);
      END_STATE();
    case 454:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(637);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(638);
      END_STATE();
    case 455:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(639);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(sym_page_keyword);
      if (lookahead == 'C') ADVANCE(640);
      if (lookahead == 'E') ADVANCE(641);
      if (lookahead == 'c') ADVANCE(642);
      if (lookahead == 'e') ADVANCE(643);
      END_STATE();
    case 457:
      if (lookahead == 'i') ADVANCE(644);
      END_STATE();
    case 458:
      if (lookahead == 'I') ADVANCE(635);
      if (lookahead == 'i') ADVANCE(645);
      END_STATE();
    case 459:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(646);
      END_STATE();
    case 460:
      if (lookahead == 'A') ADVANCE(647);
      if (lookahead == 'a') ADVANCE(648);
      END_STATE();
    case 461:
      if (lookahead == 'R') ADVANCE(649);
      if (lookahead == 'r') ADVANCE(650);
      END_STATE();
    case 462:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(648);
      END_STATE();
    case 463:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(650);
      END_STATE();
    case 464:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(651);
      END_STATE();
    case 465:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(652);
      END_STATE();
    case 466:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(653);
      END_STATE();
    case 467:
      if (lookahead == 'A') ADVANCE(648);
      if (lookahead == 'a') ADVANCE(654);
      END_STATE();
    case 468:
      if (lookahead == 'R') ADVANCE(650);
      if (lookahead == 'r') ADVANCE(655);
      END_STATE();
    case 469:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(656);
      END_STATE();
    case 470:
      if (lookahead == 'E') ADVANCE(657);
      if (lookahead == 'e') ADVANCE(658);
      END_STATE();
    case 471:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(658);
      END_STATE();
    case 472:
      ACCEPT_TOKEN(anon_sym_THEN);
      END_STATE();
    case 473:
      if (lookahead == 'E') ADVANCE(658);
      if (lookahead == 'e') ADVANCE(659);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(anon_sym_Then);
      END_STATE();
    case 475:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(660);
      END_STATE();
    case 476:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(661);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(662);
      END_STATE();
    case 477:
      ACCEPT_TOKEN(aux_sym_text_type_token1);
      ADVANCE_MAP(
        'A', 663,
        'a', 663,
        'B', 664,
        'b', 664,
        'C', 665,
        'c', 665,
        'E', 666,
        'e', 666,
      );
      END_STATE();
    case 478:
      ACCEPT_TOKEN(aux_sym_basic_type_token10);
      END_STATE();
    case 479:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(667);
      END_STATE();
    case 480:
      ACCEPT_TOKEN(aux_sym_boolean_token1);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(aux_sym_type_declaration_token1);
      END_STATE();
    case 482:
      if (lookahead == 'L') ADVANCE(668);
      END_STATE();
    case 483:
      if (lookahead == 'l') ADVANCE(669);
      END_STATE();
    case 484:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(670);
      END_STATE();
    case 485:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(671);
      END_STATE();
    case 486:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(672);
      END_STATE();
    case 487:
      if (lookahead == 'E') ADVANCE(673);
      END_STATE();
    case 488:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(674);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(anon_sym_WITH);
      END_STATE();
    case 490:
      if (lookahead == 'e') ADVANCE(675);
      END_STATE();
    case 491:
      ACCEPT_TOKEN(anon_sym_With);
      END_STATE();
    case 492:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(676);
      END_STATE();
    case 493:
      if (lookahead == 'O') ADVANCE(677);
      if (lookahead == 'o') ADVANCE(678);
      END_STATE();
    case 494:
      if (lookahead == 'o') ADVANCE(679);
      END_STATE();
    case 495:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(680);
      END_STATE();
    case 496:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(681);
      END_STATE();
    case 497:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(682);
      END_STATE();
    case 498:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(683);
      END_STATE();
    case 499:
      if (lookahead == 'o') ADVANCE(684);
      END_STATE();
    case 500:
      if (lookahead == 'o') ADVANCE(685);
      END_STATE();
    case 501:
      if (lookahead == 'k') ADVANCE(686);
      END_STATE();
    case 502:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 503:
      ACCEPT_TOKEN(aux_sym_code_type_token1);
      if (lookahead == 'U') ADVANCE(687);
      if (lookahead == 'u') ADVANCE(688);
      END_STATE();
    case 504:
      if (lookahead == 'i') ADVANCE(689);
      if (lookahead == 'r') ADVANCE(690);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(568);
      END_STATE();
    case 505:
      if (lookahead == 'e') ADVANCE(691);
      END_STATE();
    case 506:
      if (lookahead == 'e') ADVANCE(692);
      END_STATE();
    case 507:
      if (lookahead == 't') ADVANCE(693);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(anon_sym_eNUM);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(anon_sym_eNum);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(anon_sym_enum);
      if (lookahead == 'E') ADVANCE(694);
      if (lookahead == 'e') ADVANCE(695);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(anon_sym_exit);
      END_STATE();
    case 513:
      if (lookahead == 'a') ADVANCE(696);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(sym_page_keyword);
      if (lookahead == 'C') ADVANCE(697);
      if (lookahead == 'E') ADVANCE(698);
      if (lookahead == 'c') ADVANCE(699);
      if (lookahead == 'e') ADVANCE(700);
      END_STATE();
    case 515:
      if (lookahead == 'i') ADVANCE(701);
      END_STATE();
    case 516:
      if (lookahead == 'I') ADVANCE(635);
      if (lookahead == 'i') ADVANCE(702);
      END_STATE();
    case 517:
      if (lookahead == 'A') ADVANCE(648);
      if (lookahead == 'a') ADVANCE(703);
      END_STATE();
    case 518:
      if (lookahead == 'R') ADVANCE(650);
      if (lookahead == 'r') ADVANCE(704);
      END_STATE();
    case 519:
      if (lookahead == 'E') ADVANCE(658);
      if (lookahead == 'e') ADVANCE(705);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(anon_sym_then);
      END_STATE();
    case 521:
      if (lookahead == 'l') ADVANCE(706);
      END_STATE();
    case 522:
      if (lookahead == 'e') ADVANCE(707);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(anon_sym_with);
      END_STATE();
    case 524:
      if (lookahead == 'o') ADVANCE(708);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(sym_grid_keyword);
      END_STATE();
    case 526:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(709);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(aux_sym_basic_type_token15);
      END_STATE();
    case 528:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(710);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(711);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(712);
      END_STATE();
    case 529:
      ADVANCE_MAP(
        'A', 713,
        'a', 713,
        'O', 714,
        'o', 714,
        'T', 715,
        't', 715,
        'V', 716,
        'v', 716,
      );
      END_STATE();
    case 530:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(717);
      END_STATE();
    case 531:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(718);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(aux_sym_list_type_token1);
      END_STATE();
    case 533:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(719);
      END_STATE();
    case 534:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(720);
      END_STATE();
    case 535:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(721);
      END_STATE();
    case 536:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(722);
      END_STATE();
    case 537:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(723);
      END_STATE();
    case 538:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(724);
      END_STATE();
    case 539:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(725);
      END_STATE();
    case 540:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(726);
      END_STATE();
    case 541:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(727);
      END_STATE();
    case 542:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(728);
      END_STATE();
    case 543:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(729);
      END_STATE();
    case 544:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(730);
      END_STATE();
    case 545:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(731);
      END_STATE();
    case 546:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(732);
      END_STATE();
    case 547:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(733);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(sym_view_keyword);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(734);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(sym_keys_keyword);
      END_STATE();
    case 550:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(735);
      END_STATE();
    case 551:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(736);
      END_STATE();
    case 552:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(737);
      END_STATE();
    case 553:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(738);
      END_STATE();
    case 554:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(739);
      END_STATE();
    case 555:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(740);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(aux_sym_array_type_token1);
      END_STATE();
    case 557:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(741);
      END_STATE();
    case 558:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(742);
      END_STATE();
    case 559:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(743);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(anon_sym_BREAK);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(anon_sym_Break);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(aux_sym_preproc_split_procedure_body_token1);
      END_STATE();
    case 563:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(744);
      END_STATE();
    case 564:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(745);
      END_STATE();
    case 565:
      if (lookahead == 'N') ADVANCE(746);
      END_STATE();
    case 566:
      if (lookahead == 'N') ADVANCE(747);
      END_STATE();
    case 567:
      if (lookahead == 'O') ADVANCE(748);
      END_STATE();
    case 568:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(749);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(aux_sym_where_condition_token3);
      END_STATE();
    case 570:
      if (lookahead == 'n') ADVANCE(750);
      END_STATE();
    case 571:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(751);
      END_STATE();
    case 572:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(752);
      END_STATE();
    case 573:
      if (lookahead == 'n') ADVANCE(753);
      END_STATE();
    case 574:
      if (lookahead == 'n') ADVANCE(754);
      END_STATE();
    case 575:
      if (lookahead == 'n') ADVANCE(755);
      END_STATE();
    case 576:
      if (lookahead == 'o') ADVANCE(756);
      END_STATE();
    case 577:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(757);
      END_STATE();
    case 578:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(758);
      END_STATE();
    case 579:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(759);
      END_STATE();
    case 580:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(760);
      END_STATE();
    case 581:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(761);
      END_STATE();
    case 582:
      if (lookahead == 'T') ADVANCE(762);
      END_STATE();
    case 583:
      if (lookahead == 'O') ADVANCE(763);
      END_STATE();
    case 584:
      if (lookahead == 't') ADVANCE(764);
      END_STATE();
    case 585:
      if (lookahead == 't') ADVANCE(765);
      END_STATE();
    case 586:
      if (lookahead == 'o') ADVANCE(766);
      END_STATE();
    case 587:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(767);
      END_STATE();
    case 588:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(768);
      END_STATE();
    case 589:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(769);
      END_STATE();
    case 590:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(770);
      END_STATE();
    case 591:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(771);
      END_STATE();
    case 592:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(772);
      END_STATE();
    case 593:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(773);
      END_STATE();
    case 594:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(774);
      END_STATE();
    case 595:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(775);
      END_STATE();
    case 596:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(776);
      END_STATE();
    case 597:
      if (lookahead == 'X') ADVANCE(777);
      END_STATE();
    case 598:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(778);
      END_STATE();
    case 599:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(779);
      END_STATE();
    case 600:
      if (lookahead == 'x') ADVANCE(780);
      END_STATE();
    case 601:
      if (lookahead == 'x') ADVANCE(781);
      END_STATE();
    case 602:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(782);
      END_STATE();
    case 603:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(783);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(sym_event_keyword);
      END_STATE();
    case 605:
      if (lookahead == 'C') ADVANCE(784);
      END_STATE();
    case 606:
      if (lookahead == 'c') ADVANCE(785);
      END_STATE();
    case 607:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(786);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(aux_sym_boolean_token2);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(aux_sym_where_condition_token1);
      ADVANCE_MAP(
        'A', 787,
        'a', 787,
        'E', 788,
        'e', 788,
        'G', 789,
        'g', 789,
        'R', 790,
        'r', 790,
        'S', 791,
        's', 791,
      );
      END_STATE();
    case 610:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(792);
      END_STATE();
    case 611:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(793);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(sym_fixed_keyword);
      END_STATE();
    case 613:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(794);
      END_STATE();
    case 614:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(795);
      END_STATE();
    case 615:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(796);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(797);
      END_STATE();
    case 616:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(798);
      END_STATE();
    case 617:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(799);
      END_STATE();
    case 618:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(800);
      END_STATE();
    case 619:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(801);
      END_STATE();
    case 620:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(802);
      END_STATE();
    case 621:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(803);
      END_STATE();
    case 622:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(804);
      END_STATE();
    case 623:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(805);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(aux_sym_basic_type_token28);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(806);
      END_STATE();
    case 625:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(807);
      END_STATE();
    case 626:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(808);
      END_STATE();
    case 627:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(809);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(aux_sym_sorting_value_token2);
      END_STATE();
    case 629:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(810);
      END_STATE();
    case 630:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(811);
      END_STATE();
    case 631:
      if (lookahead == 'U') ADVANCE(812);
      END_STATE();
    case 632:
      if (lookahead == 'X') ADVANCE(813);
      END_STATE();
    case 633:
      if (lookahead == 'S') ADVANCE(814);
      END_STATE();
    case 634:
      if (lookahead == 'L') ADVANCE(815);
      if (lookahead == 'l') ADVANCE(816);
      END_STATE();
    case 635:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(816);
      END_STATE();
    case 636:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(817);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(818);
      END_STATE();
    case 637:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(819);
      END_STATE();
    case 638:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(820);
      END_STATE();
    case 639:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(821);
      END_STATE();
    case 640:
      if (lookahead == 'u') ADVANCE(822);
      END_STATE();
    case 641:
      if (lookahead == 'x') ADVANCE(823);
      END_STATE();
    case 642:
      if (lookahead == 'u') ADVANCE(824);
      END_STATE();
    case 643:
      if (lookahead == 'x') ADVANCE(825);
      END_STATE();
    case 644:
      if (lookahead == 's') ADVANCE(826);
      END_STATE();
    case 645:
      if (lookahead == 'L') ADVANCE(816);
      if (lookahead == 'l') ADVANCE(827);
      END_STATE();
    case 646:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(828);
      END_STATE();
    case 647:
      if (lookahead == 'T') ADVANCE(829);
      if (lookahead == 't') ADVANCE(830);
      END_STATE();
    case 648:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(830);
      END_STATE();
    case 649:
      if (lookahead == 'T') ADVANCE(831);
      if (lookahead == 't') ADVANCE(832);
      END_STATE();
    case 650:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(832);
      END_STATE();
    case 651:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(833);
      END_STATE();
    case 652:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(834);
      END_STATE();
    case 653:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(835);
      END_STATE();
    case 654:
      if (lookahead == 'T') ADVANCE(830);
      if (lookahead == 't') ADVANCE(836);
      END_STATE();
    case 655:
      if (lookahead == 'T') ADVANCE(832);
      if (lookahead == 't') ADVANCE(837);
      END_STATE();
    case 656:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(838);
      END_STATE();
    case 657:
      ACCEPT_TOKEN(sym_table_keyword);
      ADVANCE_MAP(
        'E', 839,
        'e', 840,
        'C', 841,
        'c', 841,
        'D', 842,
        'd', 842,
        'F', 843,
        'f', 843,
      );
      END_STATE();
    case 658:
      ACCEPT_TOKEN(sym_table_keyword);
      ADVANCE_MAP(
        'C', 841,
        'c', 841,
        'D', 842,
        'd', 842,
        'E', 840,
        'e', 840,
        'F', 843,
        'f', 843,
      );
      END_STATE();
    case 659:
      ACCEPT_TOKEN(sym_table_keyword);
      ADVANCE_MAP(
        'E', 844,
        'e', 845,
        'C', 841,
        'c', 841,
        'D', 842,
        'd', 842,
        'F', 843,
        'f', 843,
      );
      END_STATE();
    case 660:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(846);
      END_STATE();
    case 661:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(847);
      END_STATE();
    case 662:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(848);
      END_STATE();
    case 663:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(849);
      END_STATE();
    case 664:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(850);
      END_STATE();
    case 665:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(851);
      END_STATE();
    case 666:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(852);
      END_STATE();
    case 667:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(853);
      END_STATE();
    case 668:
      ACCEPT_TOKEN(anon_sym_UNTIL);
      END_STATE();
    case 669:
      ACCEPT_TOKEN(anon_sym_Until);
      END_STATE();
    case 670:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(854);
      END_STATE();
    case 671:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(855);
      END_STATE();
    case 672:
      ACCEPT_TOKEN(sym_using_keyword);
      END_STATE();
    case 673:
      ACCEPT_TOKEN(anon_sym_WHILE);
      END_STATE();
    case 674:
      ACCEPT_TOKEN(aux_sym_where_clause_token1);
      END_STATE();
    case 675:
      ACCEPT_TOKEN(anon_sym_While);
      END_STATE();
    case 676:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(856);
      END_STATE();
    case 677:
      if (lookahead == 'R') ADVANCE(857);
      END_STATE();
    case 678:
      if (lookahead == 'r') ADVANCE(858);
      END_STATE();
    case 679:
      if (lookahead == 'r') ADVANCE(859);
      END_STATE();
    case 680:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(860);
      END_STATE();
    case 681:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(861);
      END_STATE();
    case 682:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(862);
      END_STATE();
    case 683:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(863);
      END_STATE();
    case 684:
      if (lookahead == 'r') ADVANCE(864);
      END_STATE();
    case 685:
      if (lookahead == 'r') ADVANCE(865);
      END_STATE();
    case 686:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 687:
      if (lookahead == 'n') ADVANCE(866);
      END_STATE();
    case 688:
      if (lookahead == 'n') ADVANCE(867);
      END_STATE();
    case 689:
      if (lookahead == 'n') ADVANCE(868);
      END_STATE();
    case 690:
      if (lookahead == 'o') ADVANCE(869);
      END_STATE();
    case 691:
      if (lookahead == 't') ADVANCE(870);
      END_STATE();
    case 692:
      if (lookahead == 't') ADVANCE(871);
      END_STATE();
    case 693:
      if (lookahead == 'o') ADVANCE(872);
      END_STATE();
    case 694:
      if (lookahead == 'x') ADVANCE(873);
      END_STATE();
    case 695:
      if (lookahead == 'x') ADVANCE(874);
      END_STATE();
    case 696:
      if (lookahead == 'c') ADVANCE(875);
      END_STATE();
    case 697:
      if (lookahead == 'u') ADVANCE(876);
      END_STATE();
    case 698:
      if (lookahead == 'x') ADVANCE(877);
      END_STATE();
    case 699:
      if (lookahead == 'u') ADVANCE(878);
      END_STATE();
    case 700:
      if (lookahead == 'x') ADVANCE(879);
      END_STATE();
    case 701:
      if (lookahead == 's') ADVANCE(880);
      END_STATE();
    case 702:
      if (lookahead == 'L') ADVANCE(816);
      if (lookahead == 'l') ADVANCE(881);
      END_STATE();
    case 703:
      if (lookahead == 'T') ADVANCE(830);
      if (lookahead == 't') ADVANCE(882);
      END_STATE();
    case 704:
      if (lookahead == 'T') ADVANCE(832);
      if (lookahead == 't') ADVANCE(883);
      END_STATE();
    case 705:
      ACCEPT_TOKEN(sym_table_keyword);
      ADVANCE_MAP(
        'E', 884,
        'e', 885,
        'C', 841,
        'c', 841,
        'D', 842,
        'd', 842,
        'F', 843,
        'f', 843,
      );
      END_STATE();
    case 706:
      ACCEPT_TOKEN(anon_sym_until);
      END_STATE();
    case 707:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 708:
      if (lookahead == 'r') ADVANCE(886);
      END_STATE();
    case 709:
      ACCEPT_TOKEN(sym_group_keyword);
      END_STATE();
    case 710:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(887);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(888);
      END_STATE();
    case 711:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(889);
      END_STATE();
    case 712:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(890);
      END_STATE();
    case 713:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(891);
      END_STATE();
    case 714:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(892);
      END_STATE();
    case 715:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(893);
      END_STATE();
    case 716:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(894);
      END_STATE();
    case 717:
      ACCEPT_TOKEN(aux_sym_basic_type_token6);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(895);
      END_STATE();
    case 718:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(896);
      END_STATE();
    case 719:
      ACCEPT_TOKEN(sym_local_keyword);
      END_STATE();
    case 720:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(897);
      END_STATE();
    case 721:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(898);
      END_STATE();
    case 722:
      ACCEPT_TOKEN(sym_query_keyword);
      END_STATE();
    case 723:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(899);
      END_STATE();
    case 724:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(900);
      END_STATE();
    case 725:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(901);
      END_STATE();
    case 726:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(902);
      END_STATE();
    case 727:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(903);
      END_STATE();
    case 728:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(904);
      END_STATE();
    case 729:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(905);
      END_STATE();
    case 730:
      ACCEPT_TOKEN(aux_sym_enum_value_declaration_token1);
      END_STATE();
    case 731:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(906);
      END_STATE();
    case 732:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(907);
      END_STATE();
    case 733:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(908);
      END_STATE();
    case 734:
      ACCEPT_TOKEN(sym_views_keyword);
      END_STATE();
    case 735:
      ACCEPT_TOKEN(aux_sym_interface_declaration_token1);
      END_STATE();
    case 736:
      ACCEPT_TOKEN(aux_sym_basic_type_token22);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(909);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(910);
      END_STATE();
    case 737:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(911);
      END_STATE();
    case 738:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(912);
      END_STATE();
    case 739:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(913);
      END_STATE();
    case 740:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(914);
      END_STATE();
    case 741:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(915);
      END_STATE();
    case 742:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(916);
      END_STATE();
    case 743:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(917);
      END_STATE();
    case 744:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(918);
      END_STATE();
    case 745:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(919);
      END_STATE();
    case 746:
      if (lookahead == 'I') ADVANCE(920);
      END_STATE();
    case 747:
      if (lookahead == 'U') ADVANCE(921);
      END_STATE();
    case 748:
      if (lookahead == 'L') ADVANCE(922);
      END_STATE();
    case 749:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(923);
      END_STATE();
    case 750:
      if (lookahead == 'i') ADVANCE(924);
      END_STATE();
    case 751:
      ACCEPT_TOKEN(sym_column_keyword);
      END_STATE();
    case 752:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(925);
      END_STATE();
    case 753:
      if (lookahead == 'i') ADVANCE(926);
      END_STATE();
    case 754:
      if (lookahead == 'i') ADVANCE(927);
      END_STATE();
    case 755:
      if (lookahead == 'u') ADVANCE(928);
      END_STATE();
    case 756:
      if (lookahead == 'l') ADVANCE(929);
      END_STATE();
    case 757:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(930);
      END_STATE();
    case 758:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(931);
      END_STATE();
    case 759:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(932);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(933);
      END_STATE();
    case 760:
      ACCEPT_TOKEN(aux_sym_basic_type_token21);
      END_STATE();
    case 761:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(934);
      END_STATE();
    case 762:
      ACCEPT_TOKEN(anon_sym_DOTNET);
      END_STATE();
    case 763:
      ACCEPT_TOKEN(anon_sym_DOWNTO);
      END_STATE();
    case 764:
      ACCEPT_TOKEN(anon_sym_DotNet);
      END_STATE();
    case 765:
      ACCEPT_TOKEN(anon_sym_Dotnet);
      END_STATE();
    case 766:
      ACCEPT_TOKEN(anon_sym_Downto);
      END_STATE();
    case 767:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(935);
      END_STATE();
    case 768:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(936);
      END_STATE();
    case 769:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(937);
      END_STATE();
    case 770:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(938);
      END_STATE();
    case 771:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(939);
      END_STATE();
    case 772:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(940);
      END_STATE();
    case 773:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(941);
      END_STATE();
    case 774:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(942);
      END_STATE();
    case 775:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(943);
      END_STATE();
    case 776:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(944);
      END_STATE();
    case 777:
      if (lookahead == 'T') ADVANCE(945);
      END_STATE();
    case 778:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(946);
      END_STATE();
    case 779:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(947);
      END_STATE();
    case 780:
      if (lookahead == 't') ADVANCE(948);
      END_STATE();
    case 781:
      if (lookahead == 't') ADVANCE(949);
      END_STATE();
    case 782:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(950);
      END_STATE();
    case 783:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(951);
      END_STATE();
    case 784:
      if (lookahead == 'H') ADVANCE(952);
      END_STATE();
    case 785:
      if (lookahead == 'h') ADVANCE(953);
      END_STATE();
    case 786:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(954);
      END_STATE();
    case 787:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(955);
      END_STATE();
    case 788:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(956);
      END_STATE();
    case 789:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(957);
      END_STATE();
    case 790:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(958);
      END_STATE();
    case 791:
      ACCEPT_TOKEN(sym_fields_keyword);
      END_STATE();
    case 792:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(959);
      END_STATE();
    case 793:
      ACCEPT_TOKEN(sym_filter_keyword);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(960);
      END_STATE();
    case 794:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(961);
      END_STATE();
    case 795:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(962);
      END_STATE();
    case 796:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(963);
      END_STATE();
    case 797:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(964);
      END_STATE();
    case 798:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(965);
      END_STATE();
    case 799:
      ACCEPT_TOKEN(aux_sym_modify_modification_token1);
      END_STATE();
    case 800:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(966);
      END_STATE();
    case 801:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(967);
      END_STATE();
    case 802:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(968);
      END_STATE();
    case 803:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(969);
      END_STATE();
    case 804:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(970);
      END_STATE();
    case 805:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(971);
      END_STATE();
    case 806:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(972);
      END_STATE();
    case 807:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(973);
      END_STATE();
    case 808:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(974);
      END_STATE();
    case 809:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(975);
      END_STATE();
    case 810:
      ACCEPT_TOKEN(aux_sym_option_type_token1);
      END_STATE();
    case 811:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(976);
      END_STATE();
    case 812:
      if (lookahead == 'S') ADVANCE(977);
      END_STATE();
    case 813:
      if (lookahead == 'T') ADVANCE(978);
      END_STATE();
    case 814:
      if (lookahead == 'S') ADVANCE(979);
      END_STATE();
    case 815:
      if (lookahead == 'E') ADVANCE(980);
      if (lookahead == 'e') ADVANCE(981);
      END_STATE();
    case 816:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(981);
      END_STATE();
    case 817:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(982);
      END_STATE();
    case 818:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(983);
      END_STATE();
    case 819:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(984);
      END_STATE();
    case 820:
      ACCEPT_TOKEN(aux_sym_area_section_token6);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(985);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(986);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(987);
      END_STATE();
    case 821:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(988);
      END_STATE();
    case 822:
      if (lookahead == 's') ADVANCE(989);
      END_STATE();
    case 823:
      if (lookahead == 't') ADVANCE(990);
      END_STATE();
    case 824:
      if (lookahead == 's') ADVANCE(991);
      END_STATE();
    case 825:
      if (lookahead == 't') ADVANCE(992);
      END_STATE();
    case 826:
      if (lookahead == 's') ADVANCE(993);
      END_STATE();
    case 827:
      if (lookahead == 'E') ADVANCE(981);
      if (lookahead == 'e') ADVANCE(994);
      END_STATE();
    case 828:
      ACCEPT_TOKEN(aux_sym_interface_declaration_token2);
      END_STATE();
    case 829:
      ACCEPT_TOKEN(anon_sym_REPEAT);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(995);
      END_STATE();
    case 830:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(995);
      END_STATE();
    case 831:
      ACCEPT_TOKEN(sym_report_keyword);
      if (lookahead == 'E') ADVANCE(996);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(997);
      END_STATE();
    case 832:
      ACCEPT_TOKEN(sym_report_keyword);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(997);
      END_STATE();
    case 833:
      ACCEPT_TOKEN(aux_sym_record_type_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(998);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(999);
      END_STATE();
    case 834:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1000);
      END_STATE();
    case 835:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1001);
      END_STATE();
    case 836:
      ACCEPT_TOKEN(anon_sym_Repeat);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(995);
      END_STATE();
    case 837:
      ACCEPT_TOKEN(sym_report_keyword);
      if (lookahead == 'E') ADVANCE(1002);
      if (lookahead == 'e') ADVANCE(1003);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(997);
      END_STATE();
    case 838:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1004);
      END_STATE();
    case 839:
      if (lookahead == 'X') ADVANCE(1005);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1006);
      END_STATE();
    case 840:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1006);
      END_STATE();
    case 841:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1007);
      END_STATE();
    case 842:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1008);
      END_STATE();
    case 843:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1009);
      END_STATE();
    case 844:
      if (lookahead == 'x') ADVANCE(1010);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1006);
      END_STATE();
    case 845:
      if (lookahead == 'x') ADVANCE(1011);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1006);
      END_STATE();
    case 846:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1012);
      END_STATE();
    case 847:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1013);
      END_STATE();
    case 848:
      if (lookahead == 'Q' ||
          lookahead == 'q') ADVANCE(1014);
      END_STATE();
    case 849:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1015);
      END_STATE();
    case 850:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1016);
      END_STATE();
    case 851:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1017);
      END_STATE();
    case 852:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1018);
      END_STATE();
    case 853:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1019);
      END_STATE();
    case 854:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1020);
      END_STATE();
    case 855:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1021);
      END_STATE();
    case 856:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1022);
      END_STATE();
    case 857:
      if (lookahead == 'T') ADVANCE(1023);
      END_STATE();
    case 858:
      if (lookahead == 't') ADVANCE(1024);
      END_STATE();
    case 859:
      if (lookahead == 't') ADVANCE(1025);
      END_STATE();
    case 860:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1026);
      END_STATE();
    case 861:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1027);
      END_STATE();
    case 862:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1028);
      END_STATE();
    case 863:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1029);
      END_STATE();
    case 864:
      if (lookahead == 't') ADVANCE(1030);
      END_STATE();
    case 865:
      if (lookahead == 't') ADVANCE(1031);
      END_STATE();
    case 866:
      if (lookahead == 'i') ADVANCE(1032);
      END_STATE();
    case 867:
      if (lookahead == 'i') ADVANCE(1033);
      END_STATE();
    case 868:
      if (lookahead == 'u') ADVANCE(1034);
      END_STATE();
    case 869:
      if (lookahead == 'l') ADVANCE(1035);
      END_STATE();
    case 870:
      ACCEPT_TOKEN(anon_sym_dotNet);
      END_STATE();
    case 871:
      ACCEPT_TOKEN(anon_sym_dotnet);
      END_STATE();
    case 872:
      ACCEPT_TOKEN(anon_sym_downto);
      END_STATE();
    case 873:
      if (lookahead == 't') ADVANCE(1036);
      END_STATE();
    case 874:
      if (lookahead == 't') ADVANCE(1037);
      END_STATE();
    case 875:
      if (lookahead == 'h') ADVANCE(1038);
      END_STATE();
    case 876:
      if (lookahead == 's') ADVANCE(1039);
      END_STATE();
    case 877:
      if (lookahead == 't') ADVANCE(1040);
      END_STATE();
    case 878:
      if (lookahead == 's') ADVANCE(1041);
      END_STATE();
    case 879:
      if (lookahead == 't') ADVANCE(1042);
      END_STATE();
    case 880:
      if (lookahead == 's') ADVANCE(1043);
      END_STATE();
    case 881:
      if (lookahead == 'E') ADVANCE(981);
      if (lookahead == 'e') ADVANCE(1044);
      END_STATE();
    case 882:
      ACCEPT_TOKEN(anon_sym_repeat);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(995);
      END_STATE();
    case 883:
      ACCEPT_TOKEN(sym_report_keyword);
      if (lookahead == 'E') ADVANCE(1045);
      if (lookahead == 'e') ADVANCE(1046);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(997);
      END_STATE();
    case 884:
      if (lookahead == 'x') ADVANCE(1047);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1006);
      END_STATE();
    case 885:
      if (lookahead == 'x') ADVANCE(1048);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1006);
      END_STATE();
    case 886:
      if (lookahead == 't') ADVANCE(1049);
      END_STATE();
    case 887:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1050);
      END_STATE();
    case 888:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1051);
      END_STATE();
    case 889:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1052);
      END_STATE();
    case 890:
      if (lookahead == 'Q' ||
          lookahead == 'q') ADVANCE(1053);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1054);
      END_STATE();
    case 891:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1055);
      END_STATE();
    case 892:
      if (lookahead == 'J' ||
          lookahead == 'j') ADVANCE(1056);
      END_STATE();
    case 893:
      if (lookahead == 'K' ||
          lookahead == 'k' ||
          lookahead == 0x212a) ADVANCE(1057);
      END_STATE();
    case 894:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1058);
      END_STATE();
    case 895:
      ACCEPT_TOKEN(sym_labels_keyword);
      END_STATE();
    case 896:
      ACCEPT_TOKEN(sym_layout_keyword);
      END_STATE();
    case 897:
      ACCEPT_TOKEN(aux_sym_ml_value_list_token1);
      END_STATE();
    case 898:
      ACCEPT_TOKEN(aux_sym_lookup_formula_token1);
      END_STATE();
    case 899:
      ACCEPT_TOKEN(sym_schema_keyword);
      END_STATE();
    case 900:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1059);
      END_STATE();
    case 901:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1060);
      END_STATE();
    case 902:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1061);
      END_STATE();
    case 903:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1062);
      END_STATE();
    case 904:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1063);
      END_STATE();
    case 905:
      ACCEPT_TOKEN(aux_sym_tabledata_permission_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1064);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1065);
      END_STATE();
    case 906:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1066);
      END_STATE();
    case 907:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1067);
      END_STATE();
    case 908:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1068);
      END_STATE();
    case 909:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1069);
      END_STATE();
    case 910:
      ACCEPT_TOKEN(sym_actions_keyword);
      END_STATE();
    case 911:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1070);
      END_STATE();
    case 912:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1071);
      END_STATE();
    case 913:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1072);
      END_STATE();
    case 914:
      ACCEPT_TOKEN(aux_sym_addlast_fieldgroup_modification_token1);
      END_STATE();
    case 915:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1073);
      END_STATE();
    case 916:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1074);
      END_STATE();
    case 917:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1075);
      END_STATE();
    case 918:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1076);
      END_STATE();
    case 919:
      ACCEPT_TOKEN(aux_sym_basic_type_token14);
      END_STATE();
    case 920:
      if (lookahead == 'T') ADVANCE(1077);
      END_STATE();
    case 921:
      if (lookahead == 'E') ADVANCE(1078);
      END_STATE();
    case 922:
      if (lookahead == 'A') ADVANCE(1079);
      END_STATE();
    case 923:
      ACCEPT_TOKEN(aux_sym_area_section_token1);
      END_STATE();
    case 924:
      if (lookahead == 't') ADVANCE(1080);
      END_STATE();
    case 925:
      ACCEPT_TOKEN(aux_sym_label_declaration_token1);
      END_STATE();
    case 926:
      if (lookahead == 't') ADVANCE(1081);
      END_STATE();
    case 927:
      if (lookahead == 't') ADVANCE(1082);
      END_STATE();
    case 928:
      if (lookahead == 'e') ADVANCE(1083);
      END_STATE();
    case 929:
      if (lookahead == 'A') ADVANCE(1084);
      if (lookahead == 'a') ADVANCE(1085);
      END_STATE();
    case 930:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1086);
      END_STATE();
    case 931:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1087);
      END_STATE();
    case 932:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1088);
      END_STATE();
    case 933:
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(1089);
      END_STATE();
    case 934:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1090);
      END_STATE();
    case 935:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1091);
      END_STATE();
    case 936:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1092);
      END_STATE();
    case 937:
      ACCEPT_TOKEN(sym_dataset_keyword);
      END_STATE();
    case 938:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1093);
      END_STATE();
    case 939:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1094);
      END_STATE();
    case 940:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1095);
      END_STATE();
    case 941:
      ACCEPT_TOKEN(aux_sym_basic_type_token3);
      END_STATE();
    case 942:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1096);
      END_STATE();
    case 943:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1097);
      END_STATE();
    case 944:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1098);
      END_STATE();
    case 945:
      if (lookahead == 'E') ADVANCE(1099);
      END_STATE();
    case 946:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1100);
      END_STATE();
    case 947:
      ACCEPT_TOKEN(sym_extends_keyword);
      END_STATE();
    case 948:
      if (lookahead == 'e') ADVANCE(1101);
      END_STATE();
    case 949:
      if (lookahead == 'e') ADVANCE(1102);
      END_STATE();
    case 950:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1103);
      END_STATE();
    case 951:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1104);
      END_STATE();
    case 952:
      ACCEPT_TOKEN(anon_sym_FOREACH);
      END_STATE();
    case 953:
      ACCEPT_TOKEN(anon_sym_Foreach);
      END_STATE();
    case 954:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1105);
      END_STATE();
    case 955:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1106);
      END_STATE();
    case 956:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1107);
      END_STATE();
    case 957:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1108);
      END_STATE();
    case 958:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1109);
      END_STATE();
    case 959:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1110);
      END_STATE();
    case 960:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1111);
      END_STATE();
    case 961:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1112);
      END_STATE();
    case 962:
      ACCEPT_TOKEN(aux_sym_basic_type_token1);
      END_STATE();
    case 963:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1113);
      END_STATE();
    case 964:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1114);
      END_STATE();
    case 965:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1115);
      END_STATE();
    case 966:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1116);
      END_STATE();
    case 967:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1117);
      END_STATE();
    case 968:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1118);
      END_STATE();
    case 969:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1119);
      END_STATE();
    case 970:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1120);
      END_STATE();
    case 971:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1121);
      END_STATE();
    case 972:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1122);
      END_STATE();
    case 973:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1123);
      END_STATE();
    case 974:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1124);
      END_STATE();
    case 975:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1125);
      END_STATE();
    case 976:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1126);
      END_STATE();
    case 977:
      if (lookahead == 'T') ADVANCE(1127);
      END_STATE();
    case 978:
      if (lookahead == 'E') ADVANCE(1128);
      END_STATE();
    case 979:
      if (lookahead == 'I') ADVANCE(1129);
      END_STATE();
    case 980:
      ACCEPT_TOKEN(sym_profile_keyword);
      if (lookahead == 'E') ADVANCE(1130);
      END_STATE();
    case 981:
      ACCEPT_TOKEN(sym_profile_keyword);
      END_STATE();
    case 982:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1131);
      END_STATE();
    case 983:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1132);
      END_STATE();
    case 984:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1133);
      END_STATE();
    case 985:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1134);
      END_STATE();
    case 986:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1135);
      END_STATE();
    case 987:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1136);
      END_STATE();
    case 988:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1137);
      END_STATE();
    case 989:
      if (lookahead == 't') ADVANCE(1138);
      END_STATE();
    case 990:
      if (lookahead == 'e') ADVANCE(1139);
      END_STATE();
    case 991:
      if (lookahead == 't') ADVANCE(1140);
      END_STATE();
    case 992:
      if (lookahead == 'e') ADVANCE(1141);
      END_STATE();
    case 993:
      if (lookahead == 'i') ADVANCE(1142);
      END_STATE();
    case 994:
      ACCEPT_TOKEN(sym_profile_keyword);
      if (lookahead == 'E') ADVANCE(1143);
      if (lookahead == 'e') ADVANCE(1144);
      END_STATE();
    case 995:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1145);
      END_STATE();
    case 996:
      if (lookahead == 'X') ADVANCE(1146);
      END_STATE();
    case 997:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1147);
      END_STATE();
    case 998:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1148);
      END_STATE();
    case 999:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1149);
      END_STATE();
    case 1000:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1150);
      END_STATE();
    case 1001:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1151);
      END_STATE();
    case 1002:
      if (lookahead == 'x') ADVANCE(1152);
      END_STATE();
    case 1003:
      if (lookahead == 'x') ADVANCE(1153);
      END_STATE();
    case 1004:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1154);
      END_STATE();
    case 1005:
      if (lookahead == 'T') ADVANCE(1155);
      END_STATE();
    case 1006:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1156);
      END_STATE();
    case 1007:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1157);
      END_STATE();
    case 1008:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1158);
      END_STATE();
    case 1009:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1159);
      END_STATE();
    case 1010:
      if (lookahead == 't') ADVANCE(1160);
      END_STATE();
    case 1011:
      if (lookahead == 't') ADVANCE(1161);
      END_STATE();
    case 1012:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1162);
      END_STATE();
    case 1013:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1163);
      END_STATE();
    case 1014:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1164);
      END_STATE();
    case 1015:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1165);
      END_STATE();
    case 1016:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1166);
      END_STATE();
    case 1017:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1167);
      END_STATE();
    case 1018:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1168);
      END_STATE();
    case 1019:
      ACCEPT_TOKEN(sym_trigger_keyword);
      END_STATE();
    case 1020:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1169);
      END_STATE();
    case 1021:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1170);
      END_STATE();
    case 1022:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1171);
      END_STATE();
    case 1023:
      ACCEPT_TOKEN(anon_sym_XMLPORT);
      END_STATE();
    case 1024:
      ACCEPT_TOKEN(anon_sym_XMLPort);
      END_STATE();
    case 1025:
      ACCEPT_TOKEN(anon_sym_XMLport);
      END_STATE();
    case 1026:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1172);
      END_STATE();
    case 1027:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1173);
      END_STATE();
    case 1028:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1174);
      END_STATE();
    case 1029:
      ACCEPT_TOKEN(aux_sym_basic_type_token43);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1175);
      END_STATE();
    case 1030:
      ACCEPT_TOKEN(anon_sym_XmlPort);
      END_STATE();
    case 1031:
      ACCEPT_TOKEN(anon_sym_Xmlport);
      END_STATE();
    case 1032:
      if (lookahead == 't') ADVANCE(1176);
      END_STATE();
    case 1033:
      if (lookahead == 't') ADVANCE(1177);
      END_STATE();
    case 1034:
      if (lookahead == 'e') ADVANCE(1178);
      END_STATE();
    case 1035:
      if (lookahead == 'A') ADVANCE(1179);
      if (lookahead == 'a') ADVANCE(1180);
      END_STATE();
    case 1036:
      if (lookahead == 'e') ADVANCE(1181);
      END_STATE();
    case 1037:
      if (lookahead == 'e') ADVANCE(1182);
      END_STATE();
    case 1038:
      ACCEPT_TOKEN(anon_sym_foreach);
      END_STATE();
    case 1039:
      if (lookahead == 't') ADVANCE(1183);
      END_STATE();
    case 1040:
      if (lookahead == 'e') ADVANCE(1184);
      END_STATE();
    case 1041:
      if (lookahead == 't') ADVANCE(1185);
      END_STATE();
    case 1042:
      if (lookahead == 'e') ADVANCE(1186);
      END_STATE();
    case 1043:
      if (lookahead == 'i') ADVANCE(1187);
      END_STATE();
    case 1044:
      ACCEPT_TOKEN(sym_profile_keyword);
      if (lookahead == 'E') ADVANCE(1188);
      if (lookahead == 'e') ADVANCE(1189);
      END_STATE();
    case 1045:
      if (lookahead == 'x') ADVANCE(1190);
      END_STATE();
    case 1046:
      if (lookahead == 'x') ADVANCE(1191);
      END_STATE();
    case 1047:
      if (lookahead == 't') ADVANCE(1192);
      END_STATE();
    case 1048:
      if (lookahead == 't') ADVANCE(1193);
      END_STATE();
    case 1049:
      ACCEPT_TOKEN(anon_sym_xmlport);
      END_STATE();
    case 1050:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1194);
      END_STATE();
    case 1051:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1195);
      END_STATE();
    case 1052:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1196);
      END_STATE();
    case 1053:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1197);
      END_STATE();
    case 1054:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1198);
      END_STATE();
    case 1055:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1199);
      END_STATE();
    case 1056:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1200);
      END_STATE();
    case 1057:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1201);
      END_STATE();
    case 1058:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1202);
      END_STATE();
    case 1059:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1203);
      END_STATE();
    case 1060:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1204);
      END_STATE();
    case 1061:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1205);
      END_STATE();
    case 1062:
      ACCEPT_TOKEN(aux_sym_keyword_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1206);
      END_STATE();
    case 1063:
      ACCEPT_TOKEN(aux_sym_sorting_value_token1);
      END_STATE();
    case 1064:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1207);
      END_STATE();
    case 1065:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1208);
      END_STATE();
    case 1066:
      ACCEPT_TOKEN(aux_sym_basic_type_token20);
      END_STATE();
    case 1067:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1209);
      END_STATE();
    case 1068:
      ACCEPT_TOKEN(aux_sym_basic_type_token53);
      END_STATE();
    case 1069:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1210);
      END_STATE();
    case 1070:
      ACCEPT_TOKEN(aux_sym_addafter_modification_token1);
      END_STATE();
    case 1071:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1211);
      END_STATE();
    case 1072:
      ACCEPT_TOKEN(aux_sym_addfirst_fieldgroup_modification_token1);
      END_STATE();
    case 1073:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1212);
      END_STATE();
    case 1074:
      ACCEPT_TOKEN(aux_sym_assembly_declaration_token1);
      END_STATE();
    case 1075:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1213);
      END_STATE();
    case 1076:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1214);
      END_STATE();
    case 1077:
      ACCEPT_TOKEN(anon_sym_CODEUNIT);
      END_STATE();
    case 1078:
      ACCEPT_TOKEN(anon_sym_CONTINUE);
      END_STATE();
    case 1079:
      if (lookahead == 'D') ADVANCE(1215);
      END_STATE();
    case 1080:
      ACCEPT_TOKEN(anon_sym_COdeunit);
      END_STATE();
    case 1081:
      ACCEPT_TOKEN(anon_sym_CodeUnit);
      END_STATE();
    case 1082:
      ACCEPT_TOKEN(anon_sym_Codeunit);
      END_STATE();
    case 1083:
      ACCEPT_TOKEN(anon_sym_Continue);
      END_STATE();
    case 1084:
      if (lookahead == 'd') ADVANCE(1216);
      END_STATE();
    case 1085:
      if (lookahead == 'd') ADVANCE(1217);
      END_STATE();
    case 1086:
      ACCEPT_TOKEN(aux_sym_action_area_section_token3);
      END_STATE();
    case 1087:
      ACCEPT_TOKEN(sym_cuegroup_keyword);
      END_STATE();
    case 1088:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1218);
      END_STATE();
    case 1089:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1219);
      END_STATE();
    case 1090:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1220);
      END_STATE();
    case 1091:
      ACCEPT_TOKEN(aux_sym_keyword_identifier_token2);
      END_STATE();
    case 1092:
      ACCEPT_TOKEN(sym_dataitem_keyword);
      END_STATE();
    case 1093:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1221);
      END_STATE();
    case 1094:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1222);
      END_STATE();
    case 1095:
      ACCEPT_TOKEN(aux_sym_basic_type_token11);
      END_STATE();
    case 1096:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1223);
      END_STATE();
    case 1097:
      ACCEPT_TOKEN(aux_sym_basic_type_token12);
      END_STATE();
    case 1098:
      ACCEPT_TOKEN(sym_elements_keyword);
      END_STATE();
    case 1099:
      if (lookahead == 'N') ADVANCE(1224);
      END_STATE();
    case 1100:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1225);
      END_STATE();
    case 1101:
      if (lookahead == 'n') ADVANCE(1226);
      END_STATE();
    case 1102:
      if (lookahead == 'n') ADVANCE(1227);
      END_STATE();
    case 1103:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1228);
      END_STATE();
    case 1104:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1229);
      END_STATE();
    case 1105:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1230);
      END_STATE();
    case 1106:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1231);
      END_STATE();
    case 1107:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1232);
      END_STATE();
    case 1108:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1233);
      END_STATE();
    case 1109:
      ACCEPT_TOKEN(aux_sym_basic_type_token19);
      END_STATE();
    case 1110:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1234);
      END_STATE();
    case 1111:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1235);
      END_STATE();
    case 1112:
      ACCEPT_TOKEN(aux_sym_basic_type_token30);
      END_STATE();
    case 1113:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1236);
      END_STATE();
    case 1114:
      ACCEPT_TOKEN(sym_internal_keyword);
      END_STATE();
    case 1115:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1237);
      END_STATE();
    case 1116:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1238);
      END_STATE();
    case 1117:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1239);
      END_STATE();
    case 1118:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1240);
      END_STATE();
    case 1119:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1241);
      END_STATE();
    case 1120:
      ACCEPT_TOKEN(aux_sym_movelast_modification_token1);
      END_STATE();
    case 1121:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1242);
      END_STATE();
    case 1122:
      ACCEPT_TOKEN(aux_sym_basic_type_token29);
      END_STATE();
    case 1123:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1243);
      END_STATE();
    case 1124:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1244);
      END_STATE();
    case 1125:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1245);
      END_STATE();
    case 1126:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1246);
      END_STATE();
    case 1127:
      if (lookahead == 'O') ADVANCE(1247);
      END_STATE();
    case 1128:
      if (lookahead == 'N') ADVANCE(1248);
      END_STATE();
    case 1129:
      if (lookahead == 'O') ADVANCE(1249);
      END_STATE();
    case 1130:
      if (lookahead == 'X') ADVANCE(1250);
      END_STATE();
    case 1131:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1251);
      END_STATE();
    case 1132:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1252);
      END_STATE();
    case 1133:
      ACCEPT_TOKEN(aux_sym_action_area_section_token4);
      END_STATE();
    case 1134:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1253);
      END_STATE();
    case 1135:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1254);
      END_STATE();
    case 1136:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1255);
      END_STATE();
    case 1137:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1256);
      END_STATE();
    case 1138:
      if (lookahead == 'o') ADVANCE(1257);
      END_STATE();
    case 1139:
      if (lookahead == 'n') ADVANCE(1258);
      END_STATE();
    case 1140:
      if (lookahead == 'o') ADVANCE(1259);
      END_STATE();
    case 1141:
      if (lookahead == 'n') ADVANCE(1260);
      END_STATE();
    case 1142:
      if (lookahead == 'o') ADVANCE(1261);
      END_STATE();
    case 1143:
      if (lookahead == 'x') ADVANCE(1262);
      END_STATE();
    case 1144:
      if (lookahead == 'x') ADVANCE(1263);
      END_STATE();
    case 1145:
      ACCEPT_TOKEN(sym_repeater_keyword);
      END_STATE();
    case 1146:
      if (lookahead == 'T') ADVANCE(1264);
      END_STATE();
    case 1147:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1265);
      END_STATE();
    case 1148:
      ACCEPT_TOKEN(aux_sym_basic_type_token17);
      END_STATE();
    case 1149:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1266);
      END_STATE();
    case 1150:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1267);
      END_STATE();
    case 1151:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1268);
      END_STATE();
    case 1152:
      if (lookahead == 't') ADVANCE(1269);
      END_STATE();
    case 1153:
      if (lookahead == 't') ADVANCE(1270);
      END_STATE();
    case 1154:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1271);
      END_STATE();
    case 1155:
      if (lookahead == 'E') ADVANCE(1272);
      END_STATE();
    case 1156:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1273);
      END_STATE();
    case 1157:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1274);
      END_STATE();
    case 1158:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1275);
      END_STATE();
    case 1159:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1276);
      END_STATE();
    case 1160:
      if (lookahead == 'e') ADVANCE(1277);
      END_STATE();
    case 1161:
      if (lookahead == 'e') ADVANCE(1278);
      END_STATE();
    case 1162:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1279);
      END_STATE();
    case 1163:
      ACCEPT_TOKEN(aux_sym_object_reference_type_token1);
      END_STATE();
    case 1164:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1280);
      END_STATE();
    case 1165:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1281);
      END_STATE();
    case 1166:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1282);
      END_STATE();
    case 1167:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1283);
      END_STATE();
    case 1168:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1284);
      END_STATE();
    case 1169:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1285);
      END_STATE();
    case 1170:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1286);
      END_STATE();
    case 1171:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1287);
      END_STATE();
    case 1172:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1288);
      END_STATE();
    case 1173:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1289);
      END_STATE();
    case 1174:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1290);
      END_STATE();
    case 1175:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1291);
      END_STATE();
    case 1176:
      ACCEPT_TOKEN(anon_sym_codeUnit);
      END_STATE();
    case 1177:
      ACCEPT_TOKEN(anon_sym_codeunit);
      END_STATE();
    case 1178:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 1179:
      if (lookahead == 'd') ADVANCE(1292);
      END_STATE();
    case 1180:
      if (lookahead == 'd') ADVANCE(1293);
      END_STATE();
    case 1181:
      if (lookahead == 'n') ADVANCE(1294);
      END_STATE();
    case 1182:
      if (lookahead == 'n') ADVANCE(1295);
      END_STATE();
    case 1183:
      if (lookahead == 'o') ADVANCE(1296);
      END_STATE();
    case 1184:
      if (lookahead == 'n') ADVANCE(1297);
      END_STATE();
    case 1185:
      if (lookahead == 'o') ADVANCE(1298);
      END_STATE();
    case 1186:
      if (lookahead == 'n') ADVANCE(1299);
      END_STATE();
    case 1187:
      if (lookahead == 'o') ADVANCE(1300);
      END_STATE();
    case 1188:
      if (lookahead == 'x') ADVANCE(1301);
      END_STATE();
    case 1189:
      if (lookahead == 'x') ADVANCE(1302);
      END_STATE();
    case 1190:
      if (lookahead == 't') ADVANCE(1303);
      END_STATE();
    case 1191:
      if (lookahead == 't') ADVANCE(1304);
      END_STATE();
    case 1192:
      if (lookahead == 'e') ADVANCE(1305);
      END_STATE();
    case 1193:
      if (lookahead == 'e') ADVANCE(1306);
      END_STATE();
    case 1194:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1307);
      END_STATE();
    case 1195:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1308);
      END_STATE();
    case 1196:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1309);
      END_STATE();
    case 1197:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1310);
      END_STATE();
    case 1198:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1311);
      END_STATE();
    case 1199:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1312);
      END_STATE();
    case 1200:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1313);
      END_STATE();
    case 1201:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1314);
      END_STATE();
    case 1202:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1315);
      END_STATE();
    case 1203:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1316);
      END_STATE();
    case 1204:
      ACCEPT_TOKEN(aux_sym_action_area_section_token5);
      END_STATE();
    case 1205:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1317);
      END_STATE();
    case 1206:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1318);
      END_STATE();
    case 1207:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1319);
      END_STATE();
    case 1208:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1320);
      END_STATE();
    case 1209:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1321);
      END_STATE();
    case 1210:
      ACCEPT_TOKEN(aux_sym_actionref_declaration_token1);
      END_STATE();
    case 1211:
      ACCEPT_TOKEN(aux_sym_addbefore_modification_token1);
      END_STATE();
    case 1212:
      ACCEPT_TOKEN(aux_sym_order_by_item_token1);
      END_STATE();
    case 1213:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1322);
      END_STATE();
    case 1214:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1323);
      END_STATE();
    case 1215:
      if (lookahead == 'D') ADVANCE(1324);
      END_STATE();
    case 1216:
      if (lookahead == 'd') ADVANCE(1325);
      END_STATE();
    case 1217:
      if (lookahead == 'd') ADVANCE(1326);
      END_STATE();
    case 1218:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1327);
      END_STATE();
    case 1219:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1328);
      END_STATE();
    case 1220:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1329);
      END_STATE();
    case 1221:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1330);
      END_STATE();
    case 1222:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1331);
      END_STATE();
    case 1223:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1332);
      END_STATE();
    case 1224:
      if (lookahead == 'S') ADVANCE(1333);
      END_STATE();
    case 1225:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1334);
      END_STATE();
    case 1226:
      if (lookahead == 's') ADVANCE(1335);
      END_STATE();
    case 1227:
      if (lookahead == 's') ADVANCE(1336);
      END_STATE();
    case 1228:
      ACCEPT_TOKEN(aux_sym_action_area_section_token6);
      END_STATE();
    case 1229:
      ACCEPT_TOKEN(aux_sym_basic_type_token46);
      END_STATE();
    case 1230:
      ACCEPT_TOKEN(aux_sym_area_section_token2);
      END_STATE();
    case 1231:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1337);
      END_STATE();
    case 1232:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1338);
      END_STATE();
    case 1233:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1339);
      END_STATE();
    case 1234:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1340);
      END_STATE();
    case 1235:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1341);
      END_STATE();
    case 1236:
      ACCEPT_TOKEN(sym_interface_keyword);
      END_STATE();
    case 1237:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1342);
      END_STATE();
    case 1238:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1343);
      END_STATE();
    case 1239:
      ACCEPT_TOKEN(aux_sym_moveafter_modification_token1);
      END_STATE();
    case 1240:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1344);
      END_STATE();
    case 1241:
      ACCEPT_TOKEN(aux_sym_movefirst_modification_token1);
      END_STATE();
    case 1242:
      ACCEPT_TOKEN(aux_sym_label_declaration_token2);
      END_STATE();
    case 1243:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1345);
      END_STATE();
    case 1244:
      ACCEPT_TOKEN(sym_namespace_keyword);
      END_STATE();
    case 1245:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1346);
      END_STATE();
    case 1246:
      ACCEPT_TOKEN(aux_sym_basic_type_token31);
      END_STATE();
    case 1247:
      if (lookahead == 'M') ADVANCE(1347);
      END_STATE();
    case 1248:
      if (lookahead == 'S') ADVANCE(1348);
      END_STATE();
    case 1249:
      if (lookahead == 'N') ADVANCE(1349);
      END_STATE();
    case 1250:
      if (lookahead == 'T') ADVANCE(1350);
      END_STATE();
    case 1251:
      ACCEPT_TOKEN(sym_procedure_keyword);
      END_STATE();
    case 1252:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1351);
      END_STATE();
    case 1253:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1352);
      END_STATE();
    case 1254:
      ACCEPT_TOKEN(aux_sym_area_section_token5);
      END_STATE();
    case 1255:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1353);
      END_STATE();
    case 1256:
      ACCEPT_TOKEN(sym_protected_keyword);
      END_STATE();
    case 1257:
      if (lookahead == 'm') ADVANCE(1354);
      END_STATE();
    case 1258:
      if (lookahead == 's') ADVANCE(1355);
      END_STATE();
    case 1259:
      if (lookahead == 'm') ADVANCE(1356);
      END_STATE();
    case 1260:
      if (lookahead == 's') ADVANCE(1357);
      END_STATE();
    case 1261:
      if (lookahead == 'n') ADVANCE(1358);
      END_STATE();
    case 1262:
      if (lookahead == 't') ADVANCE(1359);
      END_STATE();
    case 1263:
      if (lookahead == 't') ADVANCE(1360);
      END_STATE();
    case 1264:
      if (lookahead == 'E') ADVANCE(1361);
      END_STATE();
    case 1265:
      ACCEPT_TOKEN(aux_sym_action_area_section_token1);
      END_STATE();
    case 1266:
      ACCEPT_TOKEN(aux_sym_basic_type_token18);
      END_STATE();
    case 1267:
      ACCEPT_TOKEN(sym_rendering_keyword);
      END_STATE();
    case 1268:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1362);
      END_STATE();
    case 1269:
      if (lookahead == 'e') ADVANCE(1363);
      END_STATE();
    case 1270:
      if (lookahead == 'e') ADVANCE(1364);
      END_STATE();
    case 1271:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1365);
      END_STATE();
    case 1272:
      if (lookahead == 'N') ADVANCE(1366);
      END_STATE();
    case 1273:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1367);
      END_STATE();
    case 1274:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1368);
      END_STATE();
    case 1275:
      ACCEPT_TOKEN(aux_sym_tabledata_permission_token1);
      END_STATE();
    case 1276:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1369);
      END_STATE();
    case 1277:
      if (lookahead == 'n') ADVANCE(1370);
      END_STATE();
    case 1278:
      if (lookahead == 'n') ADVANCE(1371);
      END_STATE();
    case 1279:
      ACCEPT_TOKEN(sym_temporary_keyword);
      END_STATE();
    case 1280:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1372);
      END_STATE();
    case 1281:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1373);
      END_STATE();
    case 1282:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1374);
      END_STATE();
    case 1283:
      ACCEPT_TOKEN(aux_sym_basic_type_token8);
      END_STATE();
    case 1284:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1375);
      END_STATE();
    case 1285:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1376);
      END_STATE();
    case 1286:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1377);
      END_STATE();
    case 1287:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1378);
      END_STATE();
    case 1288:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1379);
      END_STATE();
    case 1289:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1380);
      END_STATE();
    case 1290:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1381);
      END_STATE();
    case 1291:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1382);
      END_STATE();
    case 1292:
      if (lookahead == 'd') ADVANCE(1383);
      END_STATE();
    case 1293:
      if (lookahead == 'd') ADVANCE(1384);
      END_STATE();
    case 1294:
      if (lookahead == 's') ADVANCE(1385);
      END_STATE();
    case 1295:
      if (lookahead == 's') ADVANCE(1386);
      END_STATE();
    case 1296:
      if (lookahead == 'm') ADVANCE(1387);
      END_STATE();
    case 1297:
      if (lookahead == 's') ADVANCE(1388);
      END_STATE();
    case 1298:
      if (lookahead == 'm') ADVANCE(1389);
      END_STATE();
    case 1299:
      if (lookahead == 's') ADVANCE(1390);
      END_STATE();
    case 1300:
      if (lookahead == 'n') ADVANCE(1391);
      END_STATE();
    case 1301:
      if (lookahead == 't') ADVANCE(1392);
      END_STATE();
    case 1302:
      if (lookahead == 't') ADVANCE(1393);
      END_STATE();
    case 1303:
      if (lookahead == 'e') ADVANCE(1394);
      END_STATE();
    case 1304:
      if (lookahead == 'e') ADVANCE(1395);
      END_STATE();
    case 1305:
      if (lookahead == 'n') ADVANCE(1396);
      END_STATE();
    case 1306:
      if (lookahead == 'n') ADVANCE(1397);
      END_STATE();
    case 1307:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1398);
      END_STATE();
    case 1308:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1399);
      END_STATE();
    case 1309:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1400);
      END_STATE();
    case 1310:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1401);
      END_STATE();
    case 1311:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1402);
      END_STATE();
    case 1312:
      ACCEPT_TOKEN(aux_sym_basic_type_token26);
      END_STATE();
    case 1313:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1403);
      END_STATE();
    case 1314:
      ACCEPT_TOKEN(aux_sym_basic_type_token24);
      END_STATE();
    case 1315:
      ACCEPT_TOKEN(aux_sym_basic_type_token25);
      END_STATE();
    case 1316:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1404);
      END_STATE();
    case 1317:
      ACCEPT_TOKEN(aux_sym_separator_action_token1);
      END_STATE();
    case 1318:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1405);
      END_STATE();
    case 1319:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1406);
      END_STATE();
    case 1320:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1407);
      END_STATE();
    case 1321:
      ACCEPT_TOKEN(aux_sym_basic_type_token51);
      END_STATE();
    case 1322:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1408);
      END_STATE();
    case 1323:
      ACCEPT_TOKEN(aux_sym_basic_type_token2);
      END_STATE();
    case 1324:
      if (lookahead == 'I') ADVANCE(1409);
      END_STATE();
    case 1325:
      if (lookahead == 'I') ADVANCE(1410);
      if (lookahead == 'i') ADVANCE(1411);
      END_STATE();
    case 1326:
      if (lookahead == 'i') ADVANCE(1412);
      END_STATE();
    case 1327:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1413);
      END_STATE();
    case 1328:
      ACCEPT_TOKEN(sym_customizes_keyword);
      END_STATE();
    case 1329:
      ACCEPT_TOKEN(aux_sym_dictionary_type_token1);
      END_STATE();
    case 1330:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1414);
      END_STATE();
    case 1331:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1415);
      END_STATE();
    case 1332:
      ACCEPT_TOKEN(aux_sym_order_by_item_token2);
      END_STATE();
    case 1333:
      if (lookahead == 'I') ADVANCE(1416);
      END_STATE();
    case 1334:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1417);
      END_STATE();
    case 1335:
      if (lookahead == 'i') ADVANCE(1418);
      END_STATE();
    case 1336:
      if (lookahead == 'i') ADVANCE(1419);
      END_STATE();
    case 1337:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1420);
      END_STATE();
    case 1338:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1421);
      END_STATE();
    case 1339:
      ACCEPT_TOKEN(sym_fieldgroup_keyword);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1422);
      END_STATE();
    case 1340:
      ACCEPT_TOKEN(aux_sym_basic_type_token49);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1423);
      END_STATE();
    case 1341:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1424);
      END_STATE();
    case 1342:
      ACCEPT_TOKEN(sym_implements_keyword);
      END_STATE();
    case 1343:
      ACCEPT_TOKEN(aux_sym_basic_type_token50);
      END_STATE();
    case 1344:
      ACCEPT_TOKEN(aux_sym_movebefore_modification_token1);
      END_STATE();
    case 1345:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1425);
      END_STATE();
    case 1346:
      ACCEPT_TOKEN(aux_sym_action_area_section_token2);
      END_STATE();
    case 1347:
      if (lookahead == 'I') ADVANCE(1426);
      END_STATE();
    case 1348:
      if (lookahead == 'I') ADVANCE(1427);
      END_STATE();
    case 1349:
      if (lookahead == 'S') ADVANCE(1428);
      END_STATE();
    case 1350:
      if (lookahead == 'E') ADVANCE(1429);
      END_STATE();
    case 1351:
      ACCEPT_TOKEN(aux_sym_area_section_token3);
      END_STATE();
    case 1352:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1430);
      END_STATE();
    case 1353:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1431);
      END_STATE();
    case 1354:
      if (lookahead == 'i') ADVANCE(1432);
      END_STATE();
    case 1355:
      if (lookahead == 'i') ADVANCE(1433);
      END_STATE();
    case 1356:
      if (lookahead == 'i') ADVANCE(1434);
      END_STATE();
    case 1357:
      if (lookahead == 'i') ADVANCE(1435);
      END_STATE();
    case 1358:
      if (lookahead == 'S') ADVANCE(1436);
      if (lookahead == 's') ADVANCE(1437);
      END_STATE();
    case 1359:
      if (lookahead == 'e') ADVANCE(1438);
      END_STATE();
    case 1360:
      if (lookahead == 'e') ADVANCE(1439);
      END_STATE();
    case 1361:
      if (lookahead == 'N') ADVANCE(1440);
      END_STATE();
    case 1362:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1441);
      END_STATE();
    case 1363:
      if (lookahead == 'n') ADVANCE(1442);
      END_STATE();
    case 1364:
      if (lookahead == 'n') ADVANCE(1443);
      END_STATE();
    case 1365:
      ACCEPT_TOKEN(aux_sym_area_section_token4);
      END_STATE();
    case 1366:
      if (lookahead == 'S') ADVANCE(1444);
      END_STATE();
    case 1367:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1445);
      END_STATE();
    case 1368:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1446);
      END_STATE();
    case 1369:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1447);
      END_STATE();
    case 1370:
      if (lookahead == 's') ADVANCE(1448);
      END_STATE();
    case 1371:
      if (lookahead == 's') ADVANCE(1449);
      END_STATE();
    case 1372:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1450);
      END_STATE();
    case 1373:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1451);
      END_STATE();
    case 1374:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1452);
      END_STATE();
    case 1375:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1453);
      END_STATE();
    case 1376:
      ACCEPT_TOKEN(aux_sym_where_condition_token2);
      END_STATE();
    case 1377:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1454);
      END_STATE();
    case 1378:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1455);
      END_STATE();
    case 1379:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1456);
      END_STATE();
    case 1380:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1457);
      END_STATE();
    case 1381:
      ACCEPT_TOKEN(aux_sym_basic_type_token42);
      END_STATE();
    case 1382:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1458);
      END_STATE();
    case 1383:
      if (lookahead == 'I') ADVANCE(1459);
      if (lookahead == 'i') ADVANCE(1460);
      END_STATE();
    case 1384:
      if (lookahead == 'i') ADVANCE(1461);
      END_STATE();
    case 1385:
      if (lookahead == 'i') ADVANCE(1462);
      END_STATE();
    case 1386:
      if (lookahead == 'i') ADVANCE(1463);
      END_STATE();
    case 1387:
      if (lookahead == 'i') ADVANCE(1464);
      END_STATE();
    case 1388:
      if (lookahead == 'i') ADVANCE(1465);
      END_STATE();
    case 1389:
      if (lookahead == 'i') ADVANCE(1466);
      END_STATE();
    case 1390:
      if (lookahead == 'i') ADVANCE(1467);
      END_STATE();
    case 1391:
      if (lookahead == 'S') ADVANCE(1468);
      if (lookahead == 's') ADVANCE(1469);
      END_STATE();
    case 1392:
      if (lookahead == 'e') ADVANCE(1470);
      END_STATE();
    case 1393:
      if (lookahead == 'e') ADVANCE(1471);
      END_STATE();
    case 1394:
      if (lookahead == 'n') ADVANCE(1472);
      END_STATE();
    case 1395:
      if (lookahead == 'n') ADVANCE(1473);
      END_STATE();
    case 1396:
      if (lookahead == 's') ADVANCE(1474);
      END_STATE();
    case 1397:
      if (lookahead == 's') ADVANCE(1475);
      END_STATE();
    case 1398:
      ACCEPT_TOKEN(aux_sym_basic_type_token32);
      END_STATE();
    case 1399:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1476);
      END_STATE();
    case 1400:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1477);
      END_STATE();
    case 1401:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1478);
      END_STATE();
    case 1402:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1479);
      END_STATE();
    case 1403:
      ACCEPT_TOKEN(aux_sym_basic_type_token27);
      END_STATE();
    case 1404:
      ACCEPT_TOKEN(aux_sym_basic_type_token23);
      END_STATE();
    case 1405:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1480);
      END_STATE();
    case 1406:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1481);
      END_STATE();
    case 1407:
      ACCEPT_TOKEN(sym_systempart_keyword);
      END_STATE();
    case 1408:
      ACCEPT_TOKEN(sym_asserterror_keyword);
      END_STATE();
    case 1409:
      if (lookahead == 'N') ADVANCE(1482);
      END_STATE();
    case 1410:
      if (lookahead == 'n') ADVANCE(1483);
      END_STATE();
    case 1411:
      if (lookahead == 'n') ADVANCE(1484);
      END_STATE();
    case 1412:
      if (lookahead == 'n') ADVANCE(1485);
      END_STATE();
    case 1413:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1486);
      END_STATE();
    case 1414:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1487);
      END_STATE();
    case 1415:
      ACCEPT_TOKEN(aux_sym_basic_type_token13);
      END_STATE();
    case 1416:
      if (lookahead == 'O') ADVANCE(1488);
      END_STATE();
    case 1417:
      ACCEPT_TOKEN(sym_entitlement_keyword);
      END_STATE();
    case 1418:
      if (lookahead == 'o') ADVANCE(1489);
      END_STATE();
    case 1419:
      if (lookahead == 'o') ADVANCE(1490);
      END_STATE();
    case 1420:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1491);
      END_STATE();
    case 1421:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1492);
      END_STATE();
    case 1422:
      ACCEPT_TOKEN(sym_fieldgroups_keyword);
      END_STATE();
    case 1423:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1493);
      END_STATE();
    case 1424:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1494);
      END_STATE();
    case 1425:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1495);
      END_STATE();
    case 1426:
      if (lookahead == 'Z') ADVANCE(1496);
      END_STATE();
    case 1427:
      if (lookahead == 'O') ADVANCE(1497);
      END_STATE();
    case 1428:
      if (lookahead == 'E') ADVANCE(1498);
      END_STATE();
    case 1429:
      if (lookahead == 'N') ADVANCE(1499);
      END_STATE();
    case 1430:
      ACCEPT_TOKEN(aux_sym_action_area_section_token7);
      END_STATE();
    case 1431:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1500);
      END_STATE();
    case 1432:
      if (lookahead == 'z') ADVANCE(1501);
      END_STATE();
    case 1433:
      if (lookahead == 'o') ADVANCE(1502);
      END_STATE();
    case 1434:
      if (lookahead == 'z') ADVANCE(1503);
      END_STATE();
    case 1435:
      if (lookahead == 'o') ADVANCE(1504);
      END_STATE();
    case 1436:
      if (lookahead == 'e') ADVANCE(1505);
      END_STATE();
    case 1437:
      if (lookahead == 'e') ADVANCE(1506);
      END_STATE();
    case 1438:
      if (lookahead == 'n') ADVANCE(1507);
      END_STATE();
    case 1439:
      if (lookahead == 'n') ADVANCE(1508);
      END_STATE();
    case 1440:
      if (lookahead == 'S') ADVANCE(1509);
      END_STATE();
    case 1441:
      ACCEPT_TOKEN(sym_requestpage_keyword);
      END_STATE();
    case 1442:
      if (lookahead == 's') ADVANCE(1510);
      END_STATE();
    case 1443:
      if (lookahead == 's') ADVANCE(1511);
      END_STATE();
    case 1444:
      if (lookahead == 'I') ADVANCE(1512);
      END_STATE();
    case 1445:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1513);
      END_STATE();
    case 1446:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1514);
      END_STATE();
    case 1447:
      ACCEPT_TOKEN(aux_sym_basic_type_token39);
      END_STATE();
    case 1448:
      if (lookahead == 'i') ADVANCE(1515);
      END_STATE();
    case 1449:
      if (lookahead == 'i') ADVANCE(1516);
      END_STATE();
    case 1450:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1517);
      END_STATE();
    case 1451:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1518);
      END_STATE();
    case 1452:
      ACCEPT_TOKEN(aux_sym_basic_type_token7);
      END_STATE();
    case 1453:
      ACCEPT_TOKEN(aux_sym_xmlport_element_token3);
      END_STATE();
    case 1454:
      ACCEPT_TOKEN(sym_usercontrol_keyword);
      END_STATE();
    case 1455:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1519);
      END_STATE();
    case 1456:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1520);
      END_STATE();
    case 1457:
      ACCEPT_TOKEN(aux_sym_basic_type_token41);
      END_STATE();
    case 1458:
      ACCEPT_TOKEN(aux_sym_basic_type_token44);
      END_STATE();
    case 1459:
      if (lookahead == 'n') ADVANCE(1521);
      END_STATE();
    case 1460:
      if (lookahead == 'n') ADVANCE(1522);
      END_STATE();
    case 1461:
      if (lookahead == 'n') ADVANCE(1523);
      END_STATE();
    case 1462:
      if (lookahead == 'o') ADVANCE(1524);
      END_STATE();
    case 1463:
      if (lookahead == 'o') ADVANCE(1525);
      END_STATE();
    case 1464:
      if (lookahead == 'z') ADVANCE(1526);
      END_STATE();
    case 1465:
      if (lookahead == 'o') ADVANCE(1527);
      END_STATE();
    case 1466:
      if (lookahead == 'z') ADVANCE(1528);
      END_STATE();
    case 1467:
      if (lookahead == 'o') ADVANCE(1529);
      END_STATE();
    case 1468:
      if (lookahead == 'e') ADVANCE(1530);
      END_STATE();
    case 1469:
      if (lookahead == 'e') ADVANCE(1531);
      END_STATE();
    case 1470:
      if (lookahead == 'n') ADVANCE(1532);
      END_STATE();
    case 1471:
      if (lookahead == 'n') ADVANCE(1533);
      END_STATE();
    case 1472:
      if (lookahead == 's') ADVANCE(1534);
      END_STATE();
    case 1473:
      if (lookahead == 's') ADVANCE(1535);
      END_STATE();
    case 1474:
      if (lookahead == 'i') ADVANCE(1536);
      END_STATE();
    case 1475:
      if (lookahead == 'i') ADVANCE(1537);
      END_STATE();
    case 1476:
      ACCEPT_TOKEN(aux_sym_basic_type_token33);
      END_STATE();
    case 1477:
      ACCEPT_TOKEN(aux_sym_basic_type_token34);
      END_STATE();
    case 1478:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1538);
      END_STATE();
    case 1479:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1539);
      END_STATE();
    case 1480:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1540);
      END_STATE();
    case 1481:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1541);
      END_STATE();
    case 1482:
      ACCEPT_TOKEN(anon_sym_CONTROLADDIN);
      END_STATE();
    case 1483:
      ACCEPT_TOKEN(anon_sym_ControlAddIn);
      END_STATE();
    case 1484:
      ACCEPT_TOKEN(anon_sym_ControlAddin);
      END_STATE();
    case 1485:
      ACCEPT_TOKEN(anon_sym_Controladdin);
      END_STATE();
    case 1486:
      ACCEPT_TOKEN(aux_sym_customaction_declaration_token1);
      END_STATE();
    case 1487:
      ACCEPT_TOKEN(aux_sym_basic_type_token52);
      END_STATE();
    case 1488:
      if (lookahead == 'N') ADVANCE(1542);
      END_STATE();
    case 1489:
      if (lookahead == 'n') ADVANCE(1543);
      END_STATE();
    case 1490:
      if (lookahead == 'n') ADVANCE(1544);
      END_STATE();
    case 1491:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1545);
      END_STATE();
    case 1492:
      ACCEPT_TOKEN(aux_sym_xmlport_element_token2);
      END_STATE();
    case 1493:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1546);
      END_STATE();
    case 1494:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1547);
      END_STATE();
    case 1495:
      ACCEPT_TOKEN(aux_sym_basic_type_token37);
      END_STATE();
    case 1496:
      if (lookahead == 'A') ADVANCE(1548);
      END_STATE();
    case 1497:
      if (lookahead == 'N') ADVANCE(1549);
      END_STATE();
    case 1498:
      if (lookahead == 'T') ADVANCE(1550);
      END_STATE();
    case 1499:
      if (lookahead == 'S') ADVANCE(1551);
      END_STATE();
    case 1500:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1552);
      END_STATE();
    case 1501:
      if (lookahead == 'a') ADVANCE(1553);
      END_STATE();
    case 1502:
      if (lookahead == 'n') ADVANCE(1554);
      END_STATE();
    case 1503:
      if (lookahead == 'a') ADVANCE(1555);
      END_STATE();
    case 1504:
      if (lookahead == 'n') ADVANCE(1556);
      END_STATE();
    case 1505:
      if (lookahead == 't') ADVANCE(1557);
      END_STATE();
    case 1506:
      if (lookahead == 't') ADVANCE(1558);
      END_STATE();
    case 1507:
      if (lookahead == 's') ADVANCE(1559);
      END_STATE();
    case 1508:
      if (lookahead == 's') ADVANCE(1560);
      END_STATE();
    case 1509:
      if (lookahead == 'I') ADVANCE(1561);
      END_STATE();
    case 1510:
      if (lookahead == 'i') ADVANCE(1562);
      END_STATE();
    case 1511:
      if (lookahead == 'i') ADVANCE(1563);
      END_STATE();
    case 1512:
      if (lookahead == 'O') ADVANCE(1564);
      END_STATE();
    case 1513:
      ACCEPT_TOKEN(aux_sym_xmlport_element_token1);
      END_STATE();
    case 1514:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1565);
      END_STATE();
    case 1515:
      if (lookahead == 'o') ADVANCE(1566);
      END_STATE();
    case 1516:
      if (lookahead == 'o') ADVANCE(1567);
      END_STATE();
    case 1517:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1568);
      END_STATE();
    case 1518:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1569);
      END_STATE();
    case 1519:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1570);
      END_STATE();
    case 1520:
      ACCEPT_TOKEN(aux_sym_basic_type_token45);
      END_STATE();
    case 1521:
      ACCEPT_TOKEN(anon_sym_controlAddIn);
      END_STATE();
    case 1522:
      ACCEPT_TOKEN(anon_sym_controlAddin);
      END_STATE();
    case 1523:
      ACCEPT_TOKEN(anon_sym_controladdin);
      END_STATE();
    case 1524:
      if (lookahead == 'n') ADVANCE(1571);
      END_STATE();
    case 1525:
      if (lookahead == 'n') ADVANCE(1572);
      END_STATE();
    case 1526:
      if (lookahead == 'a') ADVANCE(1573);
      END_STATE();
    case 1527:
      if (lookahead == 'n') ADVANCE(1574);
      END_STATE();
    case 1528:
      if (lookahead == 'a') ADVANCE(1575);
      END_STATE();
    case 1529:
      if (lookahead == 'n') ADVANCE(1576);
      END_STATE();
    case 1530:
      if (lookahead == 't') ADVANCE(1577);
      END_STATE();
    case 1531:
      if (lookahead == 't') ADVANCE(1578);
      END_STATE();
    case 1532:
      if (lookahead == 's') ADVANCE(1579);
      END_STATE();
    case 1533:
      if (lookahead == 's') ADVANCE(1580);
      END_STATE();
    case 1534:
      if (lookahead == 'i') ADVANCE(1581);
      END_STATE();
    case 1535:
      if (lookahead == 'i') ADVANCE(1582);
      END_STATE();
    case 1536:
      if (lookahead == 'o') ADVANCE(1583);
      END_STATE();
    case 1537:
      if (lookahead == 'o') ADVANCE(1584);
      END_STATE();
    case 1538:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1585);
      END_STATE();
    case 1539:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1586);
      END_STATE();
    case 1540:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1587);
      END_STATE();
    case 1541:
      ACCEPT_TOKEN(aux_sym_systemaction_declaration_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1588);
      END_STATE();
    case 1542:
      ACCEPT_TOKEN(anon_sym_ENUMEXTENSION);
      END_STATE();
    case 1543:
      ACCEPT_TOKEN(anon_sym_EnumExtension);
      END_STATE();
    case 1544:
      ACCEPT_TOKEN(anon_sym_Enumextension);
      END_STATE();
    case 1545:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1589);
      END_STATE();
    case 1546:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1590);
      END_STATE();
    case 1547:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1591);
      END_STATE();
    case 1548:
      if (lookahead == 'T') ADVANCE(1592);
      END_STATE();
    case 1549:
      ACCEPT_TOKEN(anon_sym_PAGEEXTENSION);
      END_STATE();
    case 1550:
      ACCEPT_TOKEN(anon_sym_PERMISSIONSET);
      if (lookahead == 'E') ADVANCE(1593);
      END_STATE();
    case 1551:
      if (lookahead == 'I') ADVANCE(1594);
      END_STATE();
    case 1552:
      ACCEPT_TOKEN(aux_sym_area_section_token7);
      END_STATE();
    case 1553:
      if (lookahead == 't') ADVANCE(1595);
      END_STATE();
    case 1554:
      ACCEPT_TOKEN(anon_sym_PageExtension);
      END_STATE();
    case 1555:
      if (lookahead == 't') ADVANCE(1596);
      END_STATE();
    case 1556:
      ACCEPT_TOKEN(anon_sym_Pageextension);
      END_STATE();
    case 1557:
      ACCEPT_TOKEN(anon_sym_PermissionSet);
      if (lookahead == 'E') ADVANCE(1597);
      END_STATE();
    case 1558:
      ACCEPT_TOKEN(anon_sym_Permissionset);
      if (lookahead == 'e') ADVANCE(1598);
      END_STATE();
    case 1559:
      if (lookahead == 'i') ADVANCE(1599);
      END_STATE();
    case 1560:
      if (lookahead == 'i') ADVANCE(1600);
      END_STATE();
    case 1561:
      if (lookahead == 'O') ADVANCE(1601);
      END_STATE();
    case 1562:
      if (lookahead == 'o') ADVANCE(1602);
      END_STATE();
    case 1563:
      if (lookahead == 'o') ADVANCE(1603);
      END_STATE();
    case 1564:
      if (lookahead == 'N') ADVANCE(1604);
      END_STATE();
    case 1565:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1605);
      END_STATE();
    case 1566:
      if (lookahead == 'n') ADVANCE(1606);
      END_STATE();
    case 1567:
      if (lookahead == 'n') ADVANCE(1607);
      END_STATE();
    case 1568:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1608);
      END_STATE();
    case 1569:
      ACCEPT_TOKEN(aux_sym_xmlport_attribute_token2);
      END_STATE();
    case 1570:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1609);
      END_STATE();
    case 1571:
      ACCEPT_TOKEN(anon_sym_enumExtension);
      END_STATE();
    case 1572:
      ACCEPT_TOKEN(anon_sym_enumextension);
      END_STATE();
    case 1573:
      if (lookahead == 't') ADVANCE(1610);
      END_STATE();
    case 1574:
      ACCEPT_TOKEN(anon_sym_pageExtension);
      END_STATE();
    case 1575:
      if (lookahead == 't') ADVANCE(1611);
      END_STATE();
    case 1576:
      ACCEPT_TOKEN(anon_sym_pageextension);
      END_STATE();
    case 1577:
      ACCEPT_TOKEN(anon_sym_permissionSet);
      if (lookahead == 'E') ADVANCE(1612);
      END_STATE();
    case 1578:
      ACCEPT_TOKEN(anon_sym_permissionset);
      if (lookahead == 'e') ADVANCE(1613);
      END_STATE();
    case 1579:
      if (lookahead == 'i') ADVANCE(1614);
      END_STATE();
    case 1580:
      if (lookahead == 'i') ADVANCE(1615);
      END_STATE();
    case 1581:
      if (lookahead == 'o') ADVANCE(1616);
      END_STATE();
    case 1582:
      if (lookahead == 'o') ADVANCE(1617);
      END_STATE();
    case 1583:
      if (lookahead == 'n') ADVANCE(1618);
      END_STATE();
    case 1584:
      if (lookahead == 'n') ADVANCE(1619);
      END_STATE();
    case 1585:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1620);
      END_STATE();
    case 1586:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1621);
      END_STATE();
    case 1587:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1622);
      END_STATE();
    case 1588:
      ACCEPT_TOKEN(aux_sym_area_section_token8);
      END_STATE();
    case 1589:
      ACCEPT_TOKEN(aux_sym_xmlport_attribute_token1);
      END_STATE();
    case 1590:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1623);
      END_STATE();
    case 1591:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1624);
      END_STATE();
    case 1592:
      if (lookahead == 'I') ADVANCE(1625);
      END_STATE();
    case 1593:
      if (lookahead == 'X') ADVANCE(1626);
      END_STATE();
    case 1594:
      if (lookahead == 'O') ADVANCE(1627);
      END_STATE();
    case 1595:
      if (lookahead == 'i') ADVANCE(1628);
      END_STATE();
    case 1596:
      if (lookahead == 'i') ADVANCE(1629);
      END_STATE();
    case 1597:
      if (lookahead == 'x') ADVANCE(1630);
      END_STATE();
    case 1598:
      if (lookahead == 'x') ADVANCE(1631);
      END_STATE();
    case 1599:
      if (lookahead == 'o') ADVANCE(1632);
      END_STATE();
    case 1600:
      if (lookahead == 'o') ADVANCE(1633);
      END_STATE();
    case 1601:
      if (lookahead == 'N') ADVANCE(1634);
      END_STATE();
    case 1602:
      if (lookahead == 'n') ADVANCE(1635);
      END_STATE();
    case 1603:
      if (lookahead == 'n') ADVANCE(1636);
      END_STATE();
    case 1604:
      ACCEPT_TOKEN(anon_sym_TABLEEXTENSION);
      END_STATE();
    case 1605:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1637);
      END_STATE();
    case 1606:
      ACCEPT_TOKEN(anon_sym_TableExtension);
      END_STATE();
    case 1607:
      ACCEPT_TOKEN(anon_sym_Tableextension);
      END_STATE();
    case 1608:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1638);
      END_STATE();
    case 1609:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1639);
      END_STATE();
    case 1610:
      if (lookahead == 'i') ADVANCE(1640);
      END_STATE();
    case 1611:
      if (lookahead == 'i') ADVANCE(1641);
      END_STATE();
    case 1612:
      if (lookahead == 'x') ADVANCE(1642);
      END_STATE();
    case 1613:
      if (lookahead == 'x') ADVANCE(1643);
      END_STATE();
    case 1614:
      if (lookahead == 'o') ADVANCE(1644);
      END_STATE();
    case 1615:
      if (lookahead == 'o') ADVANCE(1645);
      END_STATE();
    case 1616:
      if (lookahead == 'n') ADVANCE(1646);
      END_STATE();
    case 1617:
      if (lookahead == 'n') ADVANCE(1647);
      END_STATE();
    case 1618:
      ACCEPT_TOKEN(anon_sym_tableExtension);
      END_STATE();
    case 1619:
      ACCEPT_TOKEN(anon_sym_tableextension);
      END_STATE();
    case 1620:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1648);
      END_STATE();
    case 1621:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1649);
      END_STATE();
    case 1622:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1650);
      END_STATE();
    case 1623:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1651);
      END_STATE();
    case 1624:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1652);
      END_STATE();
    case 1625:
      if (lookahead == 'O') ADVANCE(1653);
      END_STATE();
    case 1626:
      if (lookahead == 'T') ADVANCE(1654);
      END_STATE();
    case 1627:
      if (lookahead == 'N') ADVANCE(1655);
      END_STATE();
    case 1628:
      if (lookahead == 'o') ADVANCE(1656);
      END_STATE();
    case 1629:
      if (lookahead == 'o') ADVANCE(1657);
      END_STATE();
    case 1630:
      if (lookahead == 't') ADVANCE(1658);
      END_STATE();
    case 1631:
      if (lookahead == 't') ADVANCE(1659);
      END_STATE();
    case 1632:
      if (lookahead == 'n') ADVANCE(1660);
      END_STATE();
    case 1633:
      if (lookahead == 'n') ADVANCE(1661);
      END_STATE();
    case 1634:
      ACCEPT_TOKEN(anon_sym_REPORTEXTENSION);
      END_STATE();
    case 1635:
      ACCEPT_TOKEN(anon_sym_ReportExtension);
      END_STATE();
    case 1636:
      ACCEPT_TOKEN(anon_sym_Reportextension);
      END_STATE();
    case 1637:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1662);
      END_STATE();
    case 1638:
      ACCEPT_TOKEN(aux_sym_object_reference_type_token2);
      END_STATE();
    case 1639:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1663);
      END_STATE();
    case 1640:
      if (lookahead == 'o') ADVANCE(1664);
      END_STATE();
    case 1641:
      if (lookahead == 'o') ADVANCE(1665);
      END_STATE();
    case 1642:
      if (lookahead == 't') ADVANCE(1666);
      END_STATE();
    case 1643:
      if (lookahead == 't') ADVANCE(1667);
      END_STATE();
    case 1644:
      if (lookahead == 'n') ADVANCE(1668);
      END_STATE();
    case 1645:
      if (lookahead == 'n') ADVANCE(1669);
      END_STATE();
    case 1646:
      ACCEPT_TOKEN(anon_sym_reportExtension);
      END_STATE();
    case 1647:
      ACCEPT_TOKEN(anon_sym_reportextension);
      END_STATE();
    case 1648:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1670);
      END_STATE();
    case 1649:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1671);
      END_STATE();
    case 1650:
      ACCEPT_TOKEN(aux_sym_basic_type_token47);
      END_STATE();
    case 1651:
      ACCEPT_TOKEN(aux_sym_fileuploadaction_declaration_token1);
      END_STATE();
    case 1652:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1672);
      END_STATE();
    case 1653:
      if (lookahead == 'N') ADVANCE(1673);
      END_STATE();
    case 1654:
      if (lookahead == 'E') ADVANCE(1674);
      END_STATE();
    case 1655:
      ACCEPT_TOKEN(anon_sym_PROFILEEXTENSION);
      END_STATE();
    case 1656:
      if (lookahead == 'n') ADVANCE(1675);
      END_STATE();
    case 1657:
      if (lookahead == 'n') ADVANCE(1676);
      END_STATE();
    case 1658:
      if (lookahead == 'e') ADVANCE(1677);
      END_STATE();
    case 1659:
      if (lookahead == 'e') ADVANCE(1678);
      END_STATE();
    case 1660:
      ACCEPT_TOKEN(anon_sym_ProfileExtension);
      END_STATE();
    case 1661:
      ACCEPT_TOKEN(anon_sym_Profileextension);
      END_STATE();
    case 1662:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1679);
      END_STATE();
    case 1663:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1680);
      END_STATE();
    case 1664:
      if (lookahead == 'n') ADVANCE(1681);
      END_STATE();
    case 1665:
      if (lookahead == 'n') ADVANCE(1682);
      END_STATE();
    case 1666:
      if (lookahead == 'e') ADVANCE(1683);
      END_STATE();
    case 1667:
      if (lookahead == 'e') ADVANCE(1684);
      END_STATE();
    case 1668:
      ACCEPT_TOKEN(anon_sym_profileExtension);
      END_STATE();
    case 1669:
      ACCEPT_TOKEN(anon_sym_profileextension);
      END_STATE();
    case 1670:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1685);
      END_STATE();
    case 1671:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1686);
      END_STATE();
    case 1672:
      ACCEPT_TOKEN(aux_sym_basic_type_token38);
      END_STATE();
    case 1673:
      ACCEPT_TOKEN(anon_sym_PAGECUSTOMIZATION);
      END_STATE();
    case 1674:
      if (lookahead == 'N') ADVANCE(1687);
      END_STATE();
    case 1675:
      ACCEPT_TOKEN(anon_sym_PageCustomization);
      END_STATE();
    case 1676:
      ACCEPT_TOKEN(anon_sym_Pagecustomization);
      END_STATE();
    case 1677:
      if (lookahead == 'n') ADVANCE(1688);
      END_STATE();
    case 1678:
      if (lookahead == 'n') ADVANCE(1689);
      END_STATE();
    case 1679:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1690);
      END_STATE();
    case 1680:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1691);
      END_STATE();
    case 1681:
      ACCEPT_TOKEN(anon_sym_pageCustomization);
      END_STATE();
    case 1682:
      ACCEPT_TOKEN(anon_sym_pagecustomization);
      END_STATE();
    case 1683:
      if (lookahead == 'n') ADVANCE(1692);
      END_STATE();
    case 1684:
      if (lookahead == 'n') ADVANCE(1693);
      END_STATE();
    case 1685:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1694);
      END_STATE();
    case 1686:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1695);
      END_STATE();
    case 1687:
      if (lookahead == 'S') ADVANCE(1696);
      END_STATE();
    case 1688:
      if (lookahead == 's') ADVANCE(1697);
      END_STATE();
    case 1689:
      if (lookahead == 's') ADVANCE(1698);
      END_STATE();
    case 1690:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1699);
      END_STATE();
    case 1691:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1700);
      END_STATE();
    case 1692:
      if (lookahead == 's') ADVANCE(1701);
      END_STATE();
    case 1693:
      if (lookahead == 's') ADVANCE(1702);
      END_STATE();
    case 1694:
      ACCEPT_TOKEN(aux_sym_basic_type_token35);
      END_STATE();
    case 1695:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1703);
      END_STATE();
    case 1696:
      if (lookahead == 'I') ADVANCE(1704);
      END_STATE();
    case 1697:
      if (lookahead == 'i') ADVANCE(1705);
      END_STATE();
    case 1698:
      if (lookahead == 'i') ADVANCE(1706);
      END_STATE();
    case 1699:
      ACCEPT_TOKEN(aux_sym_basic_type_token40);
      END_STATE();
    case 1700:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1707);
      END_STATE();
    case 1701:
      if (lookahead == 'i') ADVANCE(1708);
      END_STATE();
    case 1702:
      if (lookahead == 'i') ADVANCE(1709);
      END_STATE();
    case 1703:
      ACCEPT_TOKEN(aux_sym_basic_type_token36);
      END_STATE();
    case 1704:
      if (lookahead == 'O') ADVANCE(1710);
      END_STATE();
    case 1705:
      if (lookahead == 'o') ADVANCE(1711);
      END_STATE();
    case 1706:
      if (lookahead == 'o') ADVANCE(1712);
      END_STATE();
    case 1707:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1713);
      END_STATE();
    case 1708:
      if (lookahead == 'o') ADVANCE(1714);
      END_STATE();
    case 1709:
      if (lookahead == 'o') ADVANCE(1715);
      END_STATE();
    case 1710:
      if (lookahead == 'N') ADVANCE(1716);
      END_STATE();
    case 1711:
      if (lookahead == 'n') ADVANCE(1717);
      END_STATE();
    case 1712:
      if (lookahead == 'n') ADVANCE(1718);
      END_STATE();
    case 1713:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1719);
      END_STATE();
    case 1714:
      if (lookahead == 'n') ADVANCE(1720);
      END_STATE();
    case 1715:
      if (lookahead == 'n') ADVANCE(1721);
      END_STATE();
    case 1716:
      ACCEPT_TOKEN(anon_sym_PERMISSIONSETEXTENSION);
      END_STATE();
    case 1717:
      ACCEPT_TOKEN(anon_sym_PermissionSetExtension);
      END_STATE();
    case 1718:
      ACCEPT_TOKEN(anon_sym_Permissionsetextension);
      END_STATE();
    case 1719:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1722);
      END_STATE();
    case 1720:
      ACCEPT_TOKEN(anon_sym_permissionSetExtension);
      END_STATE();
    case 1721:
      ACCEPT_TOKEN(anon_sym_permissionsetextension);
      END_STATE();
    case 1722:
      ACCEPT_TOKEN(aux_sym_basic_type_token54);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 91, .external_lex_state = 2},
  [2] = {.lex_state = 91, .external_lex_state = 3},
  [3] = {.lex_state = 91, .external_lex_state = 4},
  [4] = {.lex_state = 91, .external_lex_state = 4},
  [5] = {.lex_state = 91, .external_lex_state = 3},
  [6] = {.lex_state = 91, .external_lex_state = 3},
  [7] = {.lex_state = 91, .external_lex_state = 3},
  [8] = {.lex_state = 91, .external_lex_state = 3},
  [9] = {.lex_state = 91, .external_lex_state = 3},
  [10] = {.lex_state = 91, .external_lex_state = 3},
  [11] = {.lex_state = 91, .external_lex_state = 4},
  [12] = {.lex_state = 91, .external_lex_state = 4},
  [13] = {.lex_state = 91, .external_lex_state = 4},
  [14] = {.lex_state = 91, .external_lex_state = 4},
  [15] = {.lex_state = 91, .external_lex_state = 4},
  [16] = {.lex_state = 91, .external_lex_state = 4},
  [17] = {.lex_state = 91, .external_lex_state = 4},
  [18] = {.lex_state = 91, .external_lex_state = 4},
  [19] = {.lex_state = 91, .external_lex_state = 4},
  [20] = {.lex_state = 91, .external_lex_state = 4},
  [21] = {.lex_state = 91, .external_lex_state = 5},
  [22] = {.lex_state = 91, .external_lex_state = 3},
  [23] = {.lex_state = 91, .external_lex_state = 3},
  [24] = {.lex_state = 91, .external_lex_state = 3},
  [25] = {.lex_state = 91, .external_lex_state = 3},
  [26] = {.lex_state = 91, .external_lex_state = 5},
  [27] = {.lex_state = 91, .external_lex_state = 5},
  [28] = {.lex_state = 91, .external_lex_state = 3},
  [29] = {.lex_state = 91, .external_lex_state = 3},
  [30] = {.lex_state = 91, .external_lex_state = 3},
  [31] = {.lex_state = 91, .external_lex_state = 3},
  [32] = {.lex_state = 91, .external_lex_state = 3},
  [33] = {.lex_state = 91, .external_lex_state = 3},
  [34] = {.lex_state = 91, .external_lex_state = 3},
  [35] = {.lex_state = 91, .external_lex_state = 3},
  [36] = {.lex_state = 91, .external_lex_state = 3},
  [37] = {.lex_state = 91, .external_lex_state = 3},
  [38] = {.lex_state = 91, .external_lex_state = 3},
  [39] = {.lex_state = 91, .external_lex_state = 3},
  [40] = {.lex_state = 91, .external_lex_state = 5},
  [41] = {.lex_state = 91, .external_lex_state = 5},
  [42] = {.lex_state = 91, .external_lex_state = 5},
  [43] = {.lex_state = 91, .external_lex_state = 5},
  [44] = {.lex_state = 91, .external_lex_state = 5},
  [45] = {.lex_state = 91, .external_lex_state = 5},
  [46] = {.lex_state = 91, .external_lex_state = 5},
  [47] = {.lex_state = 91, .external_lex_state = 5},
  [48] = {.lex_state = 91, .external_lex_state = 5},
  [49] = {.lex_state = 91, .external_lex_state = 5},
  [50] = {.lex_state = 91, .external_lex_state = 5},
  [51] = {.lex_state = 91, .external_lex_state = 5},
  [52] = {.lex_state = 91, .external_lex_state = 5},
  [53] = {.lex_state = 91, .external_lex_state = 5},
  [54] = {.lex_state = 91, .external_lex_state = 5},
  [55] = {.lex_state = 91, .external_lex_state = 5},
  [56] = {.lex_state = 91, .external_lex_state = 3},
  [57] = {.lex_state = 91, .external_lex_state = 3},
  [58] = {.lex_state = 91, .external_lex_state = 3},
  [59] = {.lex_state = 91, .external_lex_state = 3},
  [60] = {.lex_state = 91, .external_lex_state = 3},
  [61] = {.lex_state = 91, .external_lex_state = 3},
  [62] = {.lex_state = 91, .external_lex_state = 3},
  [63] = {.lex_state = 91, .external_lex_state = 3},
  [64] = {.lex_state = 91, .external_lex_state = 3},
  [65] = {.lex_state = 91, .external_lex_state = 3},
  [66] = {.lex_state = 91, .external_lex_state = 3},
  [67] = {.lex_state = 91, .external_lex_state = 3},
  [68] = {.lex_state = 91, .external_lex_state = 3},
  [69] = {.lex_state = 91, .external_lex_state = 3},
  [70] = {.lex_state = 91, .external_lex_state = 3},
  [71] = {.lex_state = 91, .external_lex_state = 3},
  [72] = {.lex_state = 91, .external_lex_state = 3},
  [73] = {.lex_state = 91, .external_lex_state = 3},
  [74] = {.lex_state = 91, .external_lex_state = 3},
  [75] = {.lex_state = 91, .external_lex_state = 3},
  [76] = {.lex_state = 91, .external_lex_state = 3},
  [77] = {.lex_state = 91, .external_lex_state = 3},
  [78] = {.lex_state = 91, .external_lex_state = 3},
  [79] = {.lex_state = 91, .external_lex_state = 3},
  [80] = {.lex_state = 91, .external_lex_state = 3},
  [81] = {.lex_state = 91, .external_lex_state = 3},
  [82] = {.lex_state = 91, .external_lex_state = 3},
  [83] = {.lex_state = 91, .external_lex_state = 4},
  [84] = {.lex_state = 91, .external_lex_state = 4},
  [85] = {.lex_state = 91, .external_lex_state = 4},
  [86] = {.lex_state = 91, .external_lex_state = 4},
  [87] = {.lex_state = 91, .external_lex_state = 6},
  [88] = {.lex_state = 91, .external_lex_state = 4},
  [89] = {.lex_state = 91, .external_lex_state = 4},
  [90] = {.lex_state = 2, .external_lex_state = 3},
  [91] = {.lex_state = 91, .external_lex_state = 3},
  [92] = {.lex_state = 2, .external_lex_state = 3},
  [93] = {.lex_state = 91, .external_lex_state = 3},
  [94] = {.lex_state = 91, .external_lex_state = 3},
  [95] = {.lex_state = 91, .external_lex_state = 3},
  [96] = {.lex_state = 2, .external_lex_state = 3},
  [97] = {.lex_state = 2, .external_lex_state = 7},
  [98] = {.lex_state = 91, .external_lex_state = 7},
  [99] = {.lex_state = 2, .external_lex_state = 7},
  [100] = {.lex_state = 2, .external_lex_state = 7},
  [101] = {.lex_state = 91, .external_lex_state = 3},
  [102] = {.lex_state = 91, .external_lex_state = 3},
  [103] = {.lex_state = 91, .external_lex_state = 3},
  [104] = {.lex_state = 91, .external_lex_state = 3},
  [105] = {.lex_state = 91, .external_lex_state = 3},
  [106] = {.lex_state = 91, .external_lex_state = 3},
  [107] = {.lex_state = 91, .external_lex_state = 7},
  [108] = {.lex_state = 91, .external_lex_state = 3},
  [109] = {.lex_state = 91, .external_lex_state = 3},
  [110] = {.lex_state = 91, .external_lex_state = 3},
  [111] = {.lex_state = 91, .external_lex_state = 3},
  [112] = {.lex_state = 91, .external_lex_state = 3},
  [113] = {.lex_state = 91, .external_lex_state = 3},
  [114] = {.lex_state = 91, .external_lex_state = 3},
  [115] = {.lex_state = 91, .external_lex_state = 3},
  [116] = {.lex_state = 91, .external_lex_state = 3},
  [117] = {.lex_state = 91, .external_lex_state = 3},
  [118] = {.lex_state = 91, .external_lex_state = 8},
  [119] = {.lex_state = 91, .external_lex_state = 3},
  [120] = {.lex_state = 91, .external_lex_state = 7},
  [121] = {.lex_state = 91, .external_lex_state = 7},
  [122] = {.lex_state = 91, .external_lex_state = 3},
  [123] = {.lex_state = 91, .external_lex_state = 7},
  [124] = {.lex_state = 91, .external_lex_state = 3},
  [125] = {.lex_state = 91, .external_lex_state = 3},
  [126] = {.lex_state = 91, .external_lex_state = 3},
  [127] = {.lex_state = 91, .external_lex_state = 3},
  [128] = {.lex_state = 91, .external_lex_state = 3},
  [129] = {.lex_state = 91, .external_lex_state = 3},
  [130] = {.lex_state = 91, .external_lex_state = 3},
  [131] = {.lex_state = 91, .external_lex_state = 3},
  [132] = {.lex_state = 91, .external_lex_state = 3},
  [133] = {.lex_state = 91, .external_lex_state = 7},
  [134] = {.lex_state = 91, .external_lex_state = 7},
  [135] = {.lex_state = 91, .external_lex_state = 7},
  [136] = {.lex_state = 91, .external_lex_state = 7},
  [137] = {.lex_state = 91, .external_lex_state = 7},
  [138] = {.lex_state = 91, .external_lex_state = 7},
  [139] = {.lex_state = 91, .external_lex_state = 7},
  [140] = {.lex_state = 91, .external_lex_state = 7},
  [141] = {.lex_state = 91, .external_lex_state = 7},
  [142] = {.lex_state = 91, .external_lex_state = 7},
  [143] = {.lex_state = 91, .external_lex_state = 7},
  [144] = {.lex_state = 91, .external_lex_state = 7},
  [145] = {.lex_state = 91, .external_lex_state = 7},
  [146] = {.lex_state = 91, .external_lex_state = 7},
  [147] = {.lex_state = 91, .external_lex_state = 7},
  [148] = {.lex_state = 91, .external_lex_state = 7},
  [149] = {.lex_state = 91, .external_lex_state = 3},
  [150] = {.lex_state = 91, .external_lex_state = 3},
  [151] = {.lex_state = 91, .external_lex_state = 3},
  [152] = {.lex_state = 91, .external_lex_state = 3},
  [153] = {.lex_state = 91, .external_lex_state = 3},
  [154] = {.lex_state = 91, .external_lex_state = 7},
  [155] = {.lex_state = 91, .external_lex_state = 7},
  [156] = {.lex_state = 91, .external_lex_state = 8},
  [157] = {.lex_state = 91, .external_lex_state = 7},
  [158] = {.lex_state = 91, .external_lex_state = 7},
  [159] = {.lex_state = 91, .external_lex_state = 7},
  [160] = {.lex_state = 91, .external_lex_state = 7},
  [161] = {.lex_state = 91, .external_lex_state = 7},
  [162] = {.lex_state = 91, .external_lex_state = 7},
  [163] = {.lex_state = 91, .external_lex_state = 7},
  [164] = {.lex_state = 91, .external_lex_state = 7},
  [165] = {.lex_state = 91, .external_lex_state = 7},
  [166] = {.lex_state = 91, .external_lex_state = 7},
  [167] = {.lex_state = 2, .external_lex_state = 3},
  [168] = {.lex_state = 91, .external_lex_state = 8},
  [169] = {.lex_state = 91, .external_lex_state = 8},
  [170] = {.lex_state = 91, .external_lex_state = 8},
  [171] = {.lex_state = 91, .external_lex_state = 9},
  [172] = {.lex_state = 91, .external_lex_state = 9},
  [173] = {.lex_state = 91, .external_lex_state = 8},
  [174] = {.lex_state = 91, .external_lex_state = 8},
  [175] = {.lex_state = 91, .external_lex_state = 9},
  [176] = {.lex_state = 91, .external_lex_state = 9},
  [177] = {.lex_state = 91, .external_lex_state = 9},
  [178] = {.lex_state = 91, .external_lex_state = 9},
  [179] = {.lex_state = 91, .external_lex_state = 9},
  [180] = {.lex_state = 91, .external_lex_state = 8},
  [181] = {.lex_state = 91, .external_lex_state = 9},
  [182] = {.lex_state = 91, .external_lex_state = 9},
  [183] = {.lex_state = 91, .external_lex_state = 9},
  [184] = {.lex_state = 91, .external_lex_state = 9},
  [185] = {.lex_state = 91, .external_lex_state = 9},
  [186] = {.lex_state = 91, .external_lex_state = 9},
  [187] = {.lex_state = 91, .external_lex_state = 9},
  [188] = {.lex_state = 91, .external_lex_state = 9},
  [189] = {.lex_state = 91, .external_lex_state = 9},
  [190] = {.lex_state = 91, .external_lex_state = 9},
  [191] = {.lex_state = 91, .external_lex_state = 9},
  [192] = {.lex_state = 91, .external_lex_state = 9},
  [193] = {.lex_state = 91, .external_lex_state = 8},
  [194] = {.lex_state = 91, .external_lex_state = 9},
  [195] = {.lex_state = 91, .external_lex_state = 9},
  [196] = {.lex_state = 91, .external_lex_state = 9},
  [197] = {.lex_state = 91, .external_lex_state = 9},
  [198] = {.lex_state = 91, .external_lex_state = 8},
  [199] = {.lex_state = 91, .external_lex_state = 8},
  [200] = {.lex_state = 91, .external_lex_state = 8},
  [201] = {.lex_state = 91, .external_lex_state = 9},
  [202] = {.lex_state = 91, .external_lex_state = 9},
  [203] = {.lex_state = 91, .external_lex_state = 9},
  [204] = {.lex_state = 91, .external_lex_state = 10},
  [205] = {.lex_state = 91, .external_lex_state = 9},
  [206] = {.lex_state = 91, .external_lex_state = 9},
  [207] = {.lex_state = 91, .external_lex_state = 9},
  [208] = {.lex_state = 91, .external_lex_state = 9},
  [209] = {.lex_state = 91, .external_lex_state = 9},
  [210] = {.lex_state = 91, .external_lex_state = 8},
  [211] = {.lex_state = 91, .external_lex_state = 9},
  [212] = {.lex_state = 91, .external_lex_state = 8},
  [213] = {.lex_state = 91, .external_lex_state = 8},
  [214] = {.lex_state = 91, .external_lex_state = 8},
  [215] = {.lex_state = 91, .external_lex_state = 8},
  [216] = {.lex_state = 91, .external_lex_state = 8},
  [217] = {.lex_state = 91, .external_lex_state = 10},
  [218] = {.lex_state = 91, .external_lex_state = 10},
  [219] = {.lex_state = 91, .external_lex_state = 10},
  [220] = {.lex_state = 91, .external_lex_state = 8},
  [221] = {.lex_state = 91, .external_lex_state = 8},
  [222] = {.lex_state = 91, .external_lex_state = 8},
  [223] = {.lex_state = 91, .external_lex_state = 8},
  [224] = {.lex_state = 91, .external_lex_state = 8},
  [225] = {.lex_state = 91, .external_lex_state = 8},
  [226] = {.lex_state = 91, .external_lex_state = 8},
  [227] = {.lex_state = 91, .external_lex_state = 9},
  [228] = {.lex_state = 91, .external_lex_state = 8},
  [229] = {.lex_state = 91, .external_lex_state = 9},
  [230] = {.lex_state = 91, .external_lex_state = 9},
  [231] = {.lex_state = 91, .external_lex_state = 8},
  [232] = {.lex_state = 91, .external_lex_state = 9},
  [233] = {.lex_state = 91, .external_lex_state = 8},
  [234] = {.lex_state = 91, .external_lex_state = 9},
  [235] = {.lex_state = 2, .external_lex_state = 9},
  [236] = {.lex_state = 91, .external_lex_state = 9},
  [237] = {.lex_state = 91, .external_lex_state = 8},
  [238] = {.lex_state = 91, .external_lex_state = 8},
  [239] = {.lex_state = 91, .external_lex_state = 8},
  [240] = {.lex_state = 91, .external_lex_state = 8},
  [241] = {.lex_state = 91, .external_lex_state = 8},
  [242] = {.lex_state = 91, .external_lex_state = 8},
  [243] = {.lex_state = 91, .external_lex_state = 8},
  [244] = {.lex_state = 91, .external_lex_state = 8},
  [245] = {.lex_state = 91, .external_lex_state = 8},
  [246] = {.lex_state = 91, .external_lex_state = 8},
  [247] = {.lex_state = 91, .external_lex_state = 8},
  [248] = {.lex_state = 91, .external_lex_state = 8},
  [249] = {.lex_state = 91, .external_lex_state = 9},
  [250] = {.lex_state = 91, .external_lex_state = 8},
  [251] = {.lex_state = 91, .external_lex_state = 8},
  [252] = {.lex_state = 91, .external_lex_state = 8},
  [253] = {.lex_state = 91, .external_lex_state = 8},
  [254] = {.lex_state = 91, .external_lex_state = 8},
  [255] = {.lex_state = 91, .external_lex_state = 8},
  [256] = {.lex_state = 91, .external_lex_state = 8},
  [257] = {.lex_state = 91, .external_lex_state = 8},
  [258] = {.lex_state = 91, .external_lex_state = 8},
  [259] = {.lex_state = 91, .external_lex_state = 8},
  [260] = {.lex_state = 91, .external_lex_state = 8},
  [261] = {.lex_state = 91, .external_lex_state = 8},
  [262] = {.lex_state = 91, .external_lex_state = 8},
  [263] = {.lex_state = 91, .external_lex_state = 8},
  [264] = {.lex_state = 91, .external_lex_state = 8},
  [265] = {.lex_state = 91, .external_lex_state = 8},
  [266] = {.lex_state = 91, .external_lex_state = 8},
  [267] = {.lex_state = 91, .external_lex_state = 8},
  [268] = {.lex_state = 91, .external_lex_state = 8},
  [269] = {.lex_state = 91, .external_lex_state = 8},
  [270] = {.lex_state = 91, .external_lex_state = 8},
  [271] = {.lex_state = 91, .external_lex_state = 8},
  [272] = {.lex_state = 91, .external_lex_state = 8},
  [273] = {.lex_state = 91, .external_lex_state = 8},
  [274] = {.lex_state = 91, .external_lex_state = 8},
  [275] = {.lex_state = 91, .external_lex_state = 8},
  [276] = {.lex_state = 91, .external_lex_state = 8},
  [277] = {.lex_state = 91, .external_lex_state = 8},
  [278] = {.lex_state = 91, .external_lex_state = 8},
  [279] = {.lex_state = 91, .external_lex_state = 8},
  [280] = {.lex_state = 91, .external_lex_state = 8},
  [281] = {.lex_state = 91, .external_lex_state = 8},
  [282] = {.lex_state = 91, .external_lex_state = 8},
  [283] = {.lex_state = 91, .external_lex_state = 8},
  [284] = {.lex_state = 91, .external_lex_state = 8},
  [285] = {.lex_state = 91, .external_lex_state = 8},
  [286] = {.lex_state = 91, .external_lex_state = 8},
  [287] = {.lex_state = 91, .external_lex_state = 8},
  [288] = {.lex_state = 91, .external_lex_state = 8},
  [289] = {.lex_state = 91, .external_lex_state = 8},
  [290] = {.lex_state = 91, .external_lex_state = 8},
  [291] = {.lex_state = 91, .external_lex_state = 8},
  [292] = {.lex_state = 91, .external_lex_state = 8},
  [293] = {.lex_state = 91, .external_lex_state = 8},
  [294] = {.lex_state = 91, .external_lex_state = 8},
  [295] = {.lex_state = 91, .external_lex_state = 8},
  [296] = {.lex_state = 91, .external_lex_state = 8},
  [297] = {.lex_state = 91, .external_lex_state = 8},
  [298] = {.lex_state = 91, .external_lex_state = 8},
  [299] = {.lex_state = 91, .external_lex_state = 8},
  [300] = {.lex_state = 91, .external_lex_state = 8},
  [301] = {.lex_state = 91, .external_lex_state = 8},
  [302] = {.lex_state = 91, .external_lex_state = 8},
  [303] = {.lex_state = 91, .external_lex_state = 8},
  [304] = {.lex_state = 91, .external_lex_state = 8},
  [305] = {.lex_state = 91, .external_lex_state = 8},
  [306] = {.lex_state = 91, .external_lex_state = 8},
  [307] = {.lex_state = 91, .external_lex_state = 8},
  [308] = {.lex_state = 91, .external_lex_state = 8},
  [309] = {.lex_state = 91, .external_lex_state = 8},
  [310] = {.lex_state = 91, .external_lex_state = 8},
  [311] = {.lex_state = 91, .external_lex_state = 8},
  [312] = {.lex_state = 91, .external_lex_state = 8},
  [313] = {.lex_state = 91, .external_lex_state = 8},
  [314] = {.lex_state = 91, .external_lex_state = 8},
  [315] = {.lex_state = 91, .external_lex_state = 8},
  [316] = {.lex_state = 91, .external_lex_state = 8},
  [317] = {.lex_state = 91, .external_lex_state = 8},
  [318] = {.lex_state = 91, .external_lex_state = 8},
  [319] = {.lex_state = 91, .external_lex_state = 8},
  [320] = {.lex_state = 91, .external_lex_state = 8},
  [321] = {.lex_state = 91, .external_lex_state = 8},
  [322] = {.lex_state = 91, .external_lex_state = 8},
  [323] = {.lex_state = 91, .external_lex_state = 8},
  [324] = {.lex_state = 91, .external_lex_state = 8},
  [325] = {.lex_state = 91, .external_lex_state = 8},
  [326] = {.lex_state = 91, .external_lex_state = 8},
  [327] = {.lex_state = 91, .external_lex_state = 8},
  [328] = {.lex_state = 91, .external_lex_state = 8},
  [329] = {.lex_state = 91, .external_lex_state = 8},
  [330] = {.lex_state = 91, .external_lex_state = 8},
  [331] = {.lex_state = 91, .external_lex_state = 8},
  [332] = {.lex_state = 91, .external_lex_state = 8},
  [333] = {.lex_state = 91, .external_lex_state = 8},
  [334] = {.lex_state = 91, .external_lex_state = 8},
  [335] = {.lex_state = 91, .external_lex_state = 8},
  [336] = {.lex_state = 91, .external_lex_state = 8},
  [337] = {.lex_state = 91, .external_lex_state = 8},
  [338] = {.lex_state = 91, .external_lex_state = 8},
  [339] = {.lex_state = 91, .external_lex_state = 8},
  [340] = {.lex_state = 91, .external_lex_state = 8},
  [341] = {.lex_state = 2, .external_lex_state = 9},
  [342] = {.lex_state = 91, .external_lex_state = 8},
  [343] = {.lex_state = 91, .external_lex_state = 8},
  [344] = {.lex_state = 91, .external_lex_state = 8},
  [345] = {.lex_state = 91, .external_lex_state = 8},
  [346] = {.lex_state = 91, .external_lex_state = 8},
  [347] = {.lex_state = 91, .external_lex_state = 9},
  [348] = {.lex_state = 91, .external_lex_state = 8},
  [349] = {.lex_state = 91, .external_lex_state = 9},
  [350] = {.lex_state = 91, .external_lex_state = 9},
  [351] = {.lex_state = 91, .external_lex_state = 9},
  [352] = {.lex_state = 91, .external_lex_state = 9},
  [353] = {.lex_state = 91, .external_lex_state = 9},
  [354] = {.lex_state = 91, .external_lex_state = 9},
  [355] = {.lex_state = 91, .external_lex_state = 9},
  [356] = {.lex_state = 91, .external_lex_state = 9},
  [357] = {.lex_state = 91, .external_lex_state = 9},
  [358] = {.lex_state = 91, .external_lex_state = 9},
  [359] = {.lex_state = 91, .external_lex_state = 9},
  [360] = {.lex_state = 91, .external_lex_state = 9},
  [361] = {.lex_state = 91, .external_lex_state = 9},
  [362] = {.lex_state = 91, .external_lex_state = 9},
  [363] = {.lex_state = 91, .external_lex_state = 9},
  [364] = {.lex_state = 91, .external_lex_state = 9},
  [365] = {.lex_state = 91, .external_lex_state = 9},
  [366] = {.lex_state = 91, .external_lex_state = 9},
  [367] = {.lex_state = 91, .external_lex_state = 9},
  [368] = {.lex_state = 91, .external_lex_state = 9},
  [369] = {.lex_state = 91, .external_lex_state = 9},
  [370] = {.lex_state = 91, .external_lex_state = 9},
  [371] = {.lex_state = 91, .external_lex_state = 9},
  [372] = {.lex_state = 91, .external_lex_state = 8},
  [373] = {.lex_state = 91, .external_lex_state = 9},
  [374] = {.lex_state = 91, .external_lex_state = 9},
  [375] = {.lex_state = 91, .external_lex_state = 9},
  [376] = {.lex_state = 91, .external_lex_state = 9},
  [377] = {.lex_state = 91, .external_lex_state = 9},
  [378] = {.lex_state = 91, .external_lex_state = 9},
  [379] = {.lex_state = 91, .external_lex_state = 9},
  [380] = {.lex_state = 91, .external_lex_state = 8},
  [381] = {.lex_state = 91, .external_lex_state = 8},
  [382] = {.lex_state = 91, .external_lex_state = 8},
  [383] = {.lex_state = 91, .external_lex_state = 8},
  [384] = {.lex_state = 91, .external_lex_state = 8},
  [385] = {.lex_state = 91, .external_lex_state = 8},
  [386] = {.lex_state = 91, .external_lex_state = 8},
  [387] = {.lex_state = 91, .external_lex_state = 8},
  [388] = {.lex_state = 91, .external_lex_state = 8},
  [389] = {.lex_state = 91, .external_lex_state = 8},
  [390] = {.lex_state = 91, .external_lex_state = 8},
  [391] = {.lex_state = 91, .external_lex_state = 8},
  [392] = {.lex_state = 91, .external_lex_state = 8},
  [393] = {.lex_state = 91, .external_lex_state = 8},
  [394] = {.lex_state = 91, .external_lex_state = 8},
  [395] = {.lex_state = 91, .external_lex_state = 8},
  [396] = {.lex_state = 91, .external_lex_state = 8},
  [397] = {.lex_state = 91, .external_lex_state = 8},
  [398] = {.lex_state = 91, .external_lex_state = 8},
  [399] = {.lex_state = 91, .external_lex_state = 8},
  [400] = {.lex_state = 91, .external_lex_state = 8},
  [401] = {.lex_state = 91, .external_lex_state = 8},
  [402] = {.lex_state = 91, .external_lex_state = 8},
  [403] = {.lex_state = 91, .external_lex_state = 8},
  [404] = {.lex_state = 91, .external_lex_state = 8},
  [405] = {.lex_state = 91, .external_lex_state = 8},
  [406] = {.lex_state = 91, .external_lex_state = 8},
  [407] = {.lex_state = 91, .external_lex_state = 8},
  [408] = {.lex_state = 91, .external_lex_state = 8},
  [409] = {.lex_state = 91, .external_lex_state = 8},
  [410] = {.lex_state = 91, .external_lex_state = 8},
  [411] = {.lex_state = 91, .external_lex_state = 8},
  [412] = {.lex_state = 91, .external_lex_state = 8},
  [413] = {.lex_state = 91, .external_lex_state = 8},
  [414] = {.lex_state = 91, .external_lex_state = 8},
  [415] = {.lex_state = 91, .external_lex_state = 8},
  [416] = {.lex_state = 91, .external_lex_state = 8},
  [417] = {.lex_state = 91, .external_lex_state = 8},
  [418] = {.lex_state = 91, .external_lex_state = 8},
  [419] = {.lex_state = 91, .external_lex_state = 8},
  [420] = {.lex_state = 91, .external_lex_state = 8},
  [421] = {.lex_state = 91, .external_lex_state = 8},
  [422] = {.lex_state = 91, .external_lex_state = 8},
  [423] = {.lex_state = 91, .external_lex_state = 8},
  [424] = {.lex_state = 91, .external_lex_state = 8},
  [425] = {.lex_state = 91, .external_lex_state = 8},
  [426] = {.lex_state = 91, .external_lex_state = 8},
  [427] = {.lex_state = 91, .external_lex_state = 8},
  [428] = {.lex_state = 91, .external_lex_state = 8},
  [429] = {.lex_state = 91, .external_lex_state = 8},
  [430] = {.lex_state = 91, .external_lex_state = 8},
  [431] = {.lex_state = 91, .external_lex_state = 8},
  [432] = {.lex_state = 91, .external_lex_state = 8},
  [433] = {.lex_state = 91, .external_lex_state = 8},
  [434] = {.lex_state = 91, .external_lex_state = 8},
  [435] = {.lex_state = 91, .external_lex_state = 8},
  [436] = {.lex_state = 91, .external_lex_state = 8},
  [437] = {.lex_state = 91, .external_lex_state = 8},
  [438] = {.lex_state = 91, .external_lex_state = 8},
  [439] = {.lex_state = 91, .external_lex_state = 8},
  [440] = {.lex_state = 91, .external_lex_state = 8},
  [441] = {.lex_state = 91, .external_lex_state = 8},
  [442] = {.lex_state = 91, .external_lex_state = 8},
  [443] = {.lex_state = 91, .external_lex_state = 8},
  [444] = {.lex_state = 91, .external_lex_state = 8},
  [445] = {.lex_state = 91, .external_lex_state = 8},
  [446] = {.lex_state = 91, .external_lex_state = 8},
  [447] = {.lex_state = 91, .external_lex_state = 8},
  [448] = {.lex_state = 91, .external_lex_state = 9},
  [449] = {.lex_state = 91, .external_lex_state = 9},
  [450] = {.lex_state = 91, .external_lex_state = 9},
  [451] = {.lex_state = 91, .external_lex_state = 9},
  [452] = {.lex_state = 91, .external_lex_state = 9},
  [453] = {.lex_state = 91, .external_lex_state = 9},
  [454] = {.lex_state = 91, .external_lex_state = 9},
  [455] = {.lex_state = 91, .external_lex_state = 9},
  [456] = {.lex_state = 91, .external_lex_state = 9},
  [457] = {.lex_state = 91, .external_lex_state = 9},
  [458] = {.lex_state = 91, .external_lex_state = 9},
  [459] = {.lex_state = 91, .external_lex_state = 9},
  [460] = {.lex_state = 91, .external_lex_state = 9},
  [461] = {.lex_state = 91, .external_lex_state = 9},
  [462] = {.lex_state = 91, .external_lex_state = 9},
  [463] = {.lex_state = 91, .external_lex_state = 9},
  [464] = {.lex_state = 91, .external_lex_state = 9},
  [465] = {.lex_state = 91, .external_lex_state = 9},
  [466] = {.lex_state = 91, .external_lex_state = 9},
  [467] = {.lex_state = 91, .external_lex_state = 9},
  [468] = {.lex_state = 91, .external_lex_state = 9},
  [469] = {.lex_state = 91, .external_lex_state = 9},
  [470] = {.lex_state = 91, .external_lex_state = 9},
  [471] = {.lex_state = 91, .external_lex_state = 9},
  [472] = {.lex_state = 91, .external_lex_state = 9},
  [473] = {.lex_state = 91, .external_lex_state = 9},
  [474] = {.lex_state = 91, .external_lex_state = 9},
  [475] = {.lex_state = 91, .external_lex_state = 9},
  [476] = {.lex_state = 91, .external_lex_state = 9},
  [477] = {.lex_state = 91, .external_lex_state = 9},
  [478] = {.lex_state = 91, .external_lex_state = 9},
  [479] = {.lex_state = 91, .external_lex_state = 9},
  [480] = {.lex_state = 91, .external_lex_state = 9},
  [481] = {.lex_state = 91, .external_lex_state = 9},
  [482] = {.lex_state = 91, .external_lex_state = 8},
  [483] = {.lex_state = 91, .external_lex_state = 8},
  [484] = {.lex_state = 91, .external_lex_state = 8},
  [485] = {.lex_state = 91, .external_lex_state = 9},
  [486] = {.lex_state = 91, .external_lex_state = 9},
  [487] = {.lex_state = 91, .external_lex_state = 9},
  [488] = {.lex_state = 91, .external_lex_state = 9},
  [489] = {.lex_state = 91, .external_lex_state = 9},
  [490] = {.lex_state = 91, .external_lex_state = 9},
  [491] = {.lex_state = 91, .external_lex_state = 9},
  [492] = {.lex_state = 91, .external_lex_state = 9},
  [493] = {.lex_state = 91, .external_lex_state = 9},
  [494] = {.lex_state = 91, .external_lex_state = 9},
  [495] = {.lex_state = 91, .external_lex_state = 9},
  [496] = {.lex_state = 91, .external_lex_state = 9},
  [497] = {.lex_state = 91, .external_lex_state = 9},
  [498] = {.lex_state = 91, .external_lex_state = 9},
  [499] = {.lex_state = 91, .external_lex_state = 9},
  [500] = {.lex_state = 91, .external_lex_state = 9},
  [501] = {.lex_state = 91, .external_lex_state = 9},
  [502] = {.lex_state = 91, .external_lex_state = 9},
  [503] = {.lex_state = 91, .external_lex_state = 9},
  [504] = {.lex_state = 91, .external_lex_state = 9},
  [505] = {.lex_state = 91, .external_lex_state = 9},
  [506] = {.lex_state = 91, .external_lex_state = 9},
  [507] = {.lex_state = 91, .external_lex_state = 9},
  [508] = {.lex_state = 91, .external_lex_state = 9},
  [509] = {.lex_state = 91, .external_lex_state = 9},
  [510] = {.lex_state = 91, .external_lex_state = 9},
  [511] = {.lex_state = 91, .external_lex_state = 9},
  [512] = {.lex_state = 91, .external_lex_state = 9},
  [513] = {.lex_state = 91, .external_lex_state = 9},
  [514] = {.lex_state = 91, .external_lex_state = 9},
  [515] = {.lex_state = 91, .external_lex_state = 9},
  [516] = {.lex_state = 91, .external_lex_state = 9},
  [517] = {.lex_state = 91, .external_lex_state = 9},
  [518] = {.lex_state = 91, .external_lex_state = 9},
  [519] = {.lex_state = 91, .external_lex_state = 9},
  [520] = {.lex_state = 91, .external_lex_state = 9},
  [521] = {.lex_state = 91, .external_lex_state = 9},
  [522] = {.lex_state = 91, .external_lex_state = 9},
  [523] = {.lex_state = 91, .external_lex_state = 9},
  [524] = {.lex_state = 91, .external_lex_state = 9},
  [525] = {.lex_state = 91, .external_lex_state = 9},
  [526] = {.lex_state = 91, .external_lex_state = 9},
  [527] = {.lex_state = 91, .external_lex_state = 9},
  [528] = {.lex_state = 91, .external_lex_state = 9},
  [529] = {.lex_state = 91, .external_lex_state = 9},
  [530] = {.lex_state = 91, .external_lex_state = 9},
  [531] = {.lex_state = 91, .external_lex_state = 9},
  [532] = {.lex_state = 91, .external_lex_state = 9},
  [533] = {.lex_state = 91, .external_lex_state = 9},
  [534] = {.lex_state = 91, .external_lex_state = 9},
  [535] = {.lex_state = 91, .external_lex_state = 9},
  [536] = {.lex_state = 91, .external_lex_state = 9},
  [537] = {.lex_state = 91, .external_lex_state = 9},
  [538] = {.lex_state = 91, .external_lex_state = 9},
  [539] = {.lex_state = 91, .external_lex_state = 9},
  [540] = {.lex_state = 91, .external_lex_state = 9},
  [541] = {.lex_state = 91, .external_lex_state = 9},
  [542] = {.lex_state = 91, .external_lex_state = 9},
  [543] = {.lex_state = 91, .external_lex_state = 9},
  [544] = {.lex_state = 91, .external_lex_state = 9},
  [545] = {.lex_state = 91, .external_lex_state = 9},
  [546] = {.lex_state = 91, .external_lex_state = 9},
  [547] = {.lex_state = 91, .external_lex_state = 9},
  [548] = {.lex_state = 91, .external_lex_state = 9},
  [549] = {.lex_state = 91, .external_lex_state = 9},
  [550] = {.lex_state = 91, .external_lex_state = 9},
  [551] = {.lex_state = 91, .external_lex_state = 9},
  [552] = {.lex_state = 91, .external_lex_state = 9},
  [553] = {.lex_state = 91, .external_lex_state = 9},
  [554] = {.lex_state = 91, .external_lex_state = 8},
  [555] = {.lex_state = 91, .external_lex_state = 8},
  [556] = {.lex_state = 91, .external_lex_state = 8},
  [557] = {.lex_state = 91, .external_lex_state = 8},
  [558] = {.lex_state = 91, .external_lex_state = 8},
  [559] = {.lex_state = 91, .external_lex_state = 8},
  [560] = {.lex_state = 91, .external_lex_state = 9},
  [561] = {.lex_state = 91, .external_lex_state = 9},
  [562] = {.lex_state = 91, .external_lex_state = 9},
  [563] = {.lex_state = 91, .external_lex_state = 9},
  [564] = {.lex_state = 91, .external_lex_state = 9},
  [565] = {.lex_state = 91, .external_lex_state = 9},
  [566] = {.lex_state = 91, .external_lex_state = 9},
  [567] = {.lex_state = 91, .external_lex_state = 9},
  [568] = {.lex_state = 91, .external_lex_state = 9},
  [569] = {.lex_state = 91, .external_lex_state = 9},
  [570] = {.lex_state = 91, .external_lex_state = 8},
  [571] = {.lex_state = 91, .external_lex_state = 8},
  [572] = {.lex_state = 91, .external_lex_state = 8},
  [573] = {.lex_state = 91, .external_lex_state = 8},
  [574] = {.lex_state = 91, .external_lex_state = 8},
  [575] = {.lex_state = 91, .external_lex_state = 9},
  [576] = {.lex_state = 91, .external_lex_state = 9},
  [577] = {.lex_state = 91, .external_lex_state = 9},
  [578] = {.lex_state = 91, .external_lex_state = 9},
  [579] = {.lex_state = 91, .external_lex_state = 9},
  [580] = {.lex_state = 91, .external_lex_state = 9},
  [581] = {.lex_state = 91, .external_lex_state = 8},
  [582] = {.lex_state = 91, .external_lex_state = 8},
  [583] = {.lex_state = 91, .external_lex_state = 8},
  [584] = {.lex_state = 91, .external_lex_state = 8},
  [585] = {.lex_state = 91, .external_lex_state = 8},
  [586] = {.lex_state = 91, .external_lex_state = 8},
  [587] = {.lex_state = 91, .external_lex_state = 8},
  [588] = {.lex_state = 91, .external_lex_state = 8},
  [589] = {.lex_state = 91, .external_lex_state = 8},
  [590] = {.lex_state = 91, .external_lex_state = 8},
  [591] = {.lex_state = 91, .external_lex_state = 8},
  [592] = {.lex_state = 91, .external_lex_state = 8},
  [593] = {.lex_state = 91, .external_lex_state = 8},
  [594] = {.lex_state = 91, .external_lex_state = 8},
  [595] = {.lex_state = 91, .external_lex_state = 8},
  [596] = {.lex_state = 91, .external_lex_state = 8},
  [597] = {.lex_state = 91, .external_lex_state = 8},
  [598] = {.lex_state = 91, .external_lex_state = 8},
  [599] = {.lex_state = 91, .external_lex_state = 8},
  [600] = {.lex_state = 91, .external_lex_state = 8},
  [601] = {.lex_state = 91, .external_lex_state = 8},
  [602] = {.lex_state = 91, .external_lex_state = 8},
  [603] = {.lex_state = 91, .external_lex_state = 8},
  [604] = {.lex_state = 91, .external_lex_state = 8},
  [605] = {.lex_state = 91, .external_lex_state = 8},
  [606] = {.lex_state = 91, .external_lex_state = 8},
  [607] = {.lex_state = 91, .external_lex_state = 8},
  [608] = {.lex_state = 91, .external_lex_state = 8},
  [609] = {.lex_state = 91, .external_lex_state = 8},
  [610] = {.lex_state = 91, .external_lex_state = 8},
  [611] = {.lex_state = 91, .external_lex_state = 8},
  [612] = {.lex_state = 91, .external_lex_state = 8},
  [613] = {.lex_state = 91, .external_lex_state = 8},
  [614] = {.lex_state = 91, .external_lex_state = 7},
  [615] = {.lex_state = 91, .external_lex_state = 7},
  [616] = {.lex_state = 91, .external_lex_state = 11},
  [617] = {.lex_state = 91, .external_lex_state = 7},
  [618] = {.lex_state = 91, .external_lex_state = 7},
  [619] = {.lex_state = 91, .external_lex_state = 7},
  [620] = {.lex_state = 91, .external_lex_state = 11},
  [621] = {.lex_state = 91, .external_lex_state = 7},
  [622] = {.lex_state = 91, .external_lex_state = 7},
  [623] = {.lex_state = 2, .external_lex_state = 9},
  [624] = {.lex_state = 91, .external_lex_state = 7},
  [625] = {.lex_state = 91, .external_lex_state = 7},
  [626] = {.lex_state = 91, .external_lex_state = 7},
  [627] = {.lex_state = 91, .external_lex_state = 7},
  [628] = {.lex_state = 91, .external_lex_state = 7},
  [629] = {.lex_state = 91, .external_lex_state = 7},
  [630] = {.lex_state = 91, .external_lex_state = 7},
  [631] = {.lex_state = 91, .external_lex_state = 7},
  [632] = {.lex_state = 91, .external_lex_state = 7},
  [633] = {.lex_state = 91, .external_lex_state = 7},
  [634] = {.lex_state = 91, .external_lex_state = 7},
  [635] = {.lex_state = 91, .external_lex_state = 7},
  [636] = {.lex_state = 91, .external_lex_state = 7},
  [637] = {.lex_state = 91, .external_lex_state = 7},
  [638] = {.lex_state = 91, .external_lex_state = 7},
  [639] = {.lex_state = 91, .external_lex_state = 7},
  [640] = {.lex_state = 91, .external_lex_state = 7},
  [641] = {.lex_state = 91, .external_lex_state = 7},
  [642] = {.lex_state = 91, .external_lex_state = 7},
  [643] = {.lex_state = 91, .external_lex_state = 7},
  [644] = {.lex_state = 91, .external_lex_state = 7},
  [645] = {.lex_state = 91, .external_lex_state = 7},
  [646] = {.lex_state = 91, .external_lex_state = 7},
  [647] = {.lex_state = 91, .external_lex_state = 7},
  [648] = {.lex_state = 91, .external_lex_state = 7},
  [649] = {.lex_state = 91, .external_lex_state = 7},
  [650] = {.lex_state = 91, .external_lex_state = 7},
  [651] = {.lex_state = 91, .external_lex_state = 7},
  [652] = {.lex_state = 91, .external_lex_state = 7},
  [653] = {.lex_state = 91, .external_lex_state = 7},
  [654] = {.lex_state = 91, .external_lex_state = 7},
  [655] = {.lex_state = 91, .external_lex_state = 7},
  [656] = {.lex_state = 91, .external_lex_state = 7},
  [657] = {.lex_state = 91, .external_lex_state = 7},
  [658] = {.lex_state = 91, .external_lex_state = 7},
  [659] = {.lex_state = 91, .external_lex_state = 7},
  [660] = {.lex_state = 91, .external_lex_state = 7},
  [661] = {.lex_state = 91, .external_lex_state = 7},
  [662] = {.lex_state = 91, .external_lex_state = 7},
  [663] = {.lex_state = 91, .external_lex_state = 7},
  [664] = {.lex_state = 91, .external_lex_state = 7},
  [665] = {.lex_state = 91, .external_lex_state = 7},
  [666] = {.lex_state = 91, .external_lex_state = 7},
  [667] = {.lex_state = 91, .external_lex_state = 7},
  [668] = {.lex_state = 91, .external_lex_state = 7},
  [669] = {.lex_state = 91, .external_lex_state = 7},
  [670] = {.lex_state = 91, .external_lex_state = 7},
  [671] = {.lex_state = 91, .external_lex_state = 7},
  [672] = {.lex_state = 91, .external_lex_state = 7},
  [673] = {.lex_state = 91, .external_lex_state = 7},
  [674] = {.lex_state = 91, .external_lex_state = 7},
  [675] = {.lex_state = 91, .external_lex_state = 7},
  [676] = {.lex_state = 91, .external_lex_state = 7},
  [677] = {.lex_state = 91, .external_lex_state = 7},
  [678] = {.lex_state = 91, .external_lex_state = 7},
  [679] = {.lex_state = 91, .external_lex_state = 7},
  [680] = {.lex_state = 91, .external_lex_state = 7},
  [681] = {.lex_state = 91, .external_lex_state = 7},
  [682] = {.lex_state = 91, .external_lex_state = 7},
  [683] = {.lex_state = 91, .external_lex_state = 7},
  [684] = {.lex_state = 91, .external_lex_state = 7},
  [685] = {.lex_state = 91, .external_lex_state = 7},
  [686] = {.lex_state = 91, .external_lex_state = 7},
  [687] = {.lex_state = 91, .external_lex_state = 7},
  [688] = {.lex_state = 91, .external_lex_state = 7},
  [689] = {.lex_state = 91, .external_lex_state = 7},
  [690] = {.lex_state = 91, .external_lex_state = 7},
  [691] = {.lex_state = 91, .external_lex_state = 7},
  [692] = {.lex_state = 91, .external_lex_state = 7},
  [693] = {.lex_state = 91, .external_lex_state = 7},
  [694] = {.lex_state = 91, .external_lex_state = 7},
  [695] = {.lex_state = 91, .external_lex_state = 7},
  [696] = {.lex_state = 91, .external_lex_state = 7},
  [697] = {.lex_state = 91, .external_lex_state = 7},
  [698] = {.lex_state = 91, .external_lex_state = 7},
  [699] = {.lex_state = 91, .external_lex_state = 7},
  [700] = {.lex_state = 91, .external_lex_state = 7},
  [701] = {.lex_state = 91, .external_lex_state = 7},
  [702] = {.lex_state = 91, .external_lex_state = 7},
  [703] = {.lex_state = 91, .external_lex_state = 7},
  [704] = {.lex_state = 91, .external_lex_state = 7},
  [705] = {.lex_state = 91, .external_lex_state = 7},
  [706] = {.lex_state = 91, .external_lex_state = 7},
  [707] = {.lex_state = 91, .external_lex_state = 7},
  [708] = {.lex_state = 91, .external_lex_state = 7},
  [709] = {.lex_state = 91, .external_lex_state = 7},
  [710] = {.lex_state = 91, .external_lex_state = 7},
  [711] = {.lex_state = 91, .external_lex_state = 7},
  [712] = {.lex_state = 91, .external_lex_state = 7},
  [713] = {.lex_state = 91, .external_lex_state = 7},
  [714] = {.lex_state = 91, .external_lex_state = 7},
  [715] = {.lex_state = 91, .external_lex_state = 7},
  [716] = {.lex_state = 91, .external_lex_state = 7},
  [717] = {.lex_state = 91, .external_lex_state = 7},
  [718] = {.lex_state = 91, .external_lex_state = 7},
  [719] = {.lex_state = 91, .external_lex_state = 7},
  [720] = {.lex_state = 91, .external_lex_state = 7},
  [721] = {.lex_state = 91, .external_lex_state = 7},
  [722] = {.lex_state = 91, .external_lex_state = 7},
  [723] = {.lex_state = 91, .external_lex_state = 7},
  [724] = {.lex_state = 91, .external_lex_state = 7},
  [725] = {.lex_state = 91, .external_lex_state = 7},
  [726] = {.lex_state = 91, .external_lex_state = 7},
  [727] = {.lex_state = 91, .external_lex_state = 7},
  [728] = {.lex_state = 91, .external_lex_state = 7},
  [729] = {.lex_state = 91, .external_lex_state = 7},
  [730] = {.lex_state = 91, .external_lex_state = 7},
  [731] = {.lex_state = 91, .external_lex_state = 7},
  [732] = {.lex_state = 91, .external_lex_state = 7},
  [733] = {.lex_state = 91, .external_lex_state = 7},
  [734] = {.lex_state = 91, .external_lex_state = 7},
  [735] = {.lex_state = 91, .external_lex_state = 7},
  [736] = {.lex_state = 91, .external_lex_state = 7},
  [737] = {.lex_state = 91, .external_lex_state = 7},
  [738] = {.lex_state = 91, .external_lex_state = 7},
  [739] = {.lex_state = 91, .external_lex_state = 7},
  [740] = {.lex_state = 91, .external_lex_state = 7},
  [741] = {.lex_state = 91, .external_lex_state = 7},
  [742] = {.lex_state = 91, .external_lex_state = 7},
  [743] = {.lex_state = 91, .external_lex_state = 7},
  [744] = {.lex_state = 91, .external_lex_state = 7},
  [745] = {.lex_state = 91, .external_lex_state = 7},
  [746] = {.lex_state = 91, .external_lex_state = 7},
  [747] = {.lex_state = 91, .external_lex_state = 7},
  [748] = {.lex_state = 91, .external_lex_state = 7},
  [749] = {.lex_state = 91, .external_lex_state = 7},
  [750] = {.lex_state = 91, .external_lex_state = 7},
  [751] = {.lex_state = 91, .external_lex_state = 7},
  [752] = {.lex_state = 91, .external_lex_state = 7},
  [753] = {.lex_state = 91, .external_lex_state = 7},
  [754] = {.lex_state = 91, .external_lex_state = 7},
  [755] = {.lex_state = 91, .external_lex_state = 7},
  [756] = {.lex_state = 91, .external_lex_state = 7},
  [757] = {.lex_state = 91, .external_lex_state = 7},
  [758] = {.lex_state = 91, .external_lex_state = 7},
  [759] = {.lex_state = 91, .external_lex_state = 7},
  [760] = {.lex_state = 91, .external_lex_state = 7},
  [761] = {.lex_state = 91, .external_lex_state = 7},
  [762] = {.lex_state = 91, .external_lex_state = 7},
  [763] = {.lex_state = 91, .external_lex_state = 7},
  [764] = {.lex_state = 91, .external_lex_state = 7},
  [765] = {.lex_state = 91, .external_lex_state = 7},
  [766] = {.lex_state = 91, .external_lex_state = 7},
  [767] = {.lex_state = 91, .external_lex_state = 7},
  [768] = {.lex_state = 91, .external_lex_state = 7},
  [769] = {.lex_state = 91, .external_lex_state = 7},
  [770] = {.lex_state = 91, .external_lex_state = 7},
  [771] = {.lex_state = 91, .external_lex_state = 7},
  [772] = {.lex_state = 91, .external_lex_state = 7},
  [773] = {.lex_state = 91, .external_lex_state = 7},
  [774] = {.lex_state = 91, .external_lex_state = 7},
  [775] = {.lex_state = 91, .external_lex_state = 7},
  [776] = {.lex_state = 91, .external_lex_state = 7},
  [777] = {.lex_state = 91, .external_lex_state = 7},
  [778] = {.lex_state = 91, .external_lex_state = 7},
  [779] = {.lex_state = 91, .external_lex_state = 7},
  [780] = {.lex_state = 91, .external_lex_state = 7},
  [781] = {.lex_state = 91, .external_lex_state = 7},
  [782] = {.lex_state = 91, .external_lex_state = 7},
  [783] = {.lex_state = 91, .external_lex_state = 7},
  [784] = {.lex_state = 91, .external_lex_state = 7},
  [785] = {.lex_state = 91, .external_lex_state = 7},
  [786] = {.lex_state = 91, .external_lex_state = 7},
  [787] = {.lex_state = 91, .external_lex_state = 7},
  [788] = {.lex_state = 91, .external_lex_state = 7},
  [789] = {.lex_state = 91, .external_lex_state = 7},
  [790] = {.lex_state = 91, .external_lex_state = 7},
  [791] = {.lex_state = 91, .external_lex_state = 7},
  [792] = {.lex_state = 91, .external_lex_state = 7},
  [793] = {.lex_state = 91, .external_lex_state = 7},
  [794] = {.lex_state = 91, .external_lex_state = 7},
  [795] = {.lex_state = 91, .external_lex_state = 7},
  [796] = {.lex_state = 91, .external_lex_state = 7},
  [797] = {.lex_state = 91, .external_lex_state = 7},
  [798] = {.lex_state = 91, .external_lex_state = 7},
  [799] = {.lex_state = 91, .external_lex_state = 7},
  [800] = {.lex_state = 91, .external_lex_state = 7},
  [801] = {.lex_state = 91, .external_lex_state = 7},
  [802] = {.lex_state = 91, .external_lex_state = 7},
  [803] = {.lex_state = 91, .external_lex_state = 7},
  [804] = {.lex_state = 91, .external_lex_state = 7},
  [805] = {.lex_state = 91, .external_lex_state = 7},
  [806] = {.lex_state = 91, .external_lex_state = 7},
  [807] = {.lex_state = 91, .external_lex_state = 7},
  [808] = {.lex_state = 91, .external_lex_state = 7},
  [809] = {.lex_state = 91, .external_lex_state = 7},
  [810] = {.lex_state = 91, .external_lex_state = 7},
  [811] = {.lex_state = 91, .external_lex_state = 7},
  [812] = {.lex_state = 91, .external_lex_state = 7},
  [813] = {.lex_state = 91, .external_lex_state = 7},
  [814] = {.lex_state = 91, .external_lex_state = 7},
  [815] = {.lex_state = 91, .external_lex_state = 7},
  [816] = {.lex_state = 91, .external_lex_state = 7},
  [817] = {.lex_state = 91, .external_lex_state = 7},
  [818] = {.lex_state = 91, .external_lex_state = 7},
  [819] = {.lex_state = 91, .external_lex_state = 7},
  [820] = {.lex_state = 91, .external_lex_state = 7},
  [821] = {.lex_state = 91, .external_lex_state = 7},
  [822] = {.lex_state = 91, .external_lex_state = 7},
  [823] = {.lex_state = 91, .external_lex_state = 7},
  [824] = {.lex_state = 91, .external_lex_state = 7},
  [825] = {.lex_state = 91, .external_lex_state = 7},
  [826] = {.lex_state = 91, .external_lex_state = 7},
  [827] = {.lex_state = 91, .external_lex_state = 7},
  [828] = {.lex_state = 91, .external_lex_state = 7},
  [829] = {.lex_state = 91, .external_lex_state = 7},
  [830] = {.lex_state = 91, .external_lex_state = 7},
  [831] = {.lex_state = 91, .external_lex_state = 7},
  [832] = {.lex_state = 91, .external_lex_state = 7},
  [833] = {.lex_state = 91, .external_lex_state = 7},
  [834] = {.lex_state = 91, .external_lex_state = 7},
  [835] = {.lex_state = 91, .external_lex_state = 7},
  [836] = {.lex_state = 91, .external_lex_state = 7},
  [837] = {.lex_state = 91, .external_lex_state = 7},
  [838] = {.lex_state = 91, .external_lex_state = 7},
  [839] = {.lex_state = 91, .external_lex_state = 7},
  [840] = {.lex_state = 91, .external_lex_state = 7},
  [841] = {.lex_state = 91, .external_lex_state = 7},
  [842] = {.lex_state = 91, .external_lex_state = 7},
  [843] = {.lex_state = 91, .external_lex_state = 7},
  [844] = {.lex_state = 91, .external_lex_state = 7},
  [845] = {.lex_state = 91, .external_lex_state = 7},
  [846] = {.lex_state = 91, .external_lex_state = 7},
  [847] = {.lex_state = 91, .external_lex_state = 7},
  [848] = {.lex_state = 91, .external_lex_state = 7},
  [849] = {.lex_state = 91, .external_lex_state = 7},
  [850] = {.lex_state = 91, .external_lex_state = 7},
  [851] = {.lex_state = 91, .external_lex_state = 7},
  [852] = {.lex_state = 91, .external_lex_state = 7},
  [853] = {.lex_state = 91, .external_lex_state = 7},
  [854] = {.lex_state = 91, .external_lex_state = 7},
  [855] = {.lex_state = 91, .external_lex_state = 7},
  [856] = {.lex_state = 91, .external_lex_state = 7},
  [857] = {.lex_state = 91, .external_lex_state = 7},
  [858] = {.lex_state = 91, .external_lex_state = 7},
  [859] = {.lex_state = 91, .external_lex_state = 7},
  [860] = {.lex_state = 91, .external_lex_state = 7},
  [861] = {.lex_state = 91, .external_lex_state = 7},
  [862] = {.lex_state = 91, .external_lex_state = 7},
  [863] = {.lex_state = 91, .external_lex_state = 7},
  [864] = {.lex_state = 91, .external_lex_state = 7},
  [865] = {.lex_state = 91, .external_lex_state = 7},
  [866] = {.lex_state = 91, .external_lex_state = 7},
  [867] = {.lex_state = 91, .external_lex_state = 7},
  [868] = {.lex_state = 91, .external_lex_state = 7},
  [869] = {.lex_state = 91, .external_lex_state = 7},
  [870] = {.lex_state = 91, .external_lex_state = 7},
  [871] = {.lex_state = 91, .external_lex_state = 7},
  [872] = {.lex_state = 91, .external_lex_state = 7},
  [873] = {.lex_state = 91, .external_lex_state = 7},
  [874] = {.lex_state = 91, .external_lex_state = 7},
  [875] = {.lex_state = 91, .external_lex_state = 7},
  [876] = {.lex_state = 91, .external_lex_state = 7},
  [877] = {.lex_state = 91, .external_lex_state = 7},
  [878] = {.lex_state = 91, .external_lex_state = 7},
  [879] = {.lex_state = 91, .external_lex_state = 7},
  [880] = {.lex_state = 91, .external_lex_state = 7},
  [881] = {.lex_state = 91, .external_lex_state = 7},
  [882] = {.lex_state = 91, .external_lex_state = 7},
  [883] = {.lex_state = 91, .external_lex_state = 7},
  [884] = {.lex_state = 91, .external_lex_state = 7},
  [885] = {.lex_state = 91, .external_lex_state = 7},
  [886] = {.lex_state = 91, .external_lex_state = 7},
  [887] = {.lex_state = 91, .external_lex_state = 7},
  [888] = {.lex_state = 91, .external_lex_state = 7},
  [889] = {.lex_state = 91, .external_lex_state = 7},
  [890] = {.lex_state = 91, .external_lex_state = 7},
  [891] = {.lex_state = 91, .external_lex_state = 7},
  [892] = {.lex_state = 91, .external_lex_state = 7},
  [893] = {.lex_state = 91, .external_lex_state = 7},
  [894] = {.lex_state = 91, .external_lex_state = 7},
  [895] = {.lex_state = 91, .external_lex_state = 7},
  [896] = {.lex_state = 91, .external_lex_state = 7},
  [897] = {.lex_state = 91, .external_lex_state = 7},
  [898] = {.lex_state = 91, .external_lex_state = 7},
  [899] = {.lex_state = 91, .external_lex_state = 7},
  [900] = {.lex_state = 91, .external_lex_state = 7},
  [901] = {.lex_state = 91, .external_lex_state = 7},
  [902] = {.lex_state = 91, .external_lex_state = 7},
  [903] = {.lex_state = 91, .external_lex_state = 7},
  [904] = {.lex_state = 91, .external_lex_state = 7},
  [905] = {.lex_state = 91, .external_lex_state = 7},
  [906] = {.lex_state = 91, .external_lex_state = 7},
  [907] = {.lex_state = 91, .external_lex_state = 7},
  [908] = {.lex_state = 91, .external_lex_state = 7},
  [909] = {.lex_state = 91, .external_lex_state = 7},
  [910] = {.lex_state = 91, .external_lex_state = 7},
  [911] = {.lex_state = 91, .external_lex_state = 7},
  [912] = {.lex_state = 91, .external_lex_state = 7},
  [913] = {.lex_state = 91, .external_lex_state = 7},
  [914] = {.lex_state = 91, .external_lex_state = 7},
  [915] = {.lex_state = 91, .external_lex_state = 7},
  [916] = {.lex_state = 91, .external_lex_state = 7},
  [917] = {.lex_state = 2, .external_lex_state = 7},
  [918] = {.lex_state = 91, .external_lex_state = 7},
  [919] = {.lex_state = 91, .external_lex_state = 7},
  [920] = {.lex_state = 91, .external_lex_state = 7},
  [921] = {.lex_state = 91, .external_lex_state = 7},
  [922] = {.lex_state = 91, .external_lex_state = 7},
  [923] = {.lex_state = 91, .external_lex_state = 7},
  [924] = {.lex_state = 91, .external_lex_state = 7},
  [925] = {.lex_state = 91, .external_lex_state = 7},
  [926] = {.lex_state = 91, .external_lex_state = 7},
  [927] = {.lex_state = 91, .external_lex_state = 7},
  [928] = {.lex_state = 91, .external_lex_state = 7},
  [929] = {.lex_state = 91, .external_lex_state = 7},
  [930] = {.lex_state = 91, .external_lex_state = 7},
  [931] = {.lex_state = 91, .external_lex_state = 7},
  [932] = {.lex_state = 91, .external_lex_state = 7},
  [933] = {.lex_state = 91, .external_lex_state = 7},
  [934] = {.lex_state = 91, .external_lex_state = 7},
  [935] = {.lex_state = 91, .external_lex_state = 11},
  [936] = {.lex_state = 91, .external_lex_state = 11},
  [937] = {.lex_state = 91, .external_lex_state = 11},
  [938] = {.lex_state = 91, .external_lex_state = 11},
  [939] = {.lex_state = 91, .external_lex_state = 11},
  [940] = {.lex_state = 91, .external_lex_state = 11},
  [941] = {.lex_state = 3, .external_lex_state = 7},
  [942] = {.lex_state = 3, .external_lex_state = 7},
  [943] = {.lex_state = 3, .external_lex_state = 7},
  [944] = {.lex_state = 3, .external_lex_state = 7},
  [945] = {.lex_state = 3, .external_lex_state = 7},
  [946] = {.lex_state = 3, .external_lex_state = 7},
  [947] = {.lex_state = 3, .external_lex_state = 7},
  [948] = {.lex_state = 91, .external_lex_state = 11},
  [949] = {.lex_state = 3, .external_lex_state = 7},
  [950] = {.lex_state = 2, .external_lex_state = 9},
  [951] = {.lex_state = 2, .external_lex_state = 3},
  [952] = {.lex_state = 2, .external_lex_state = 3},
  [953] = {.lex_state = 2, .external_lex_state = 3},
  [954] = {.lex_state = 2, .external_lex_state = 3},
  [955] = {.lex_state = 91, .external_lex_state = 11},
  [956] = {.lex_state = 2, .external_lex_state = 3},
  [957] = {.lex_state = 2, .external_lex_state = 3},
  [958] = {.lex_state = 91, .external_lex_state = 11},
  [959] = {.lex_state = 2, .external_lex_state = 3},
  [960] = {.lex_state = 2, .external_lex_state = 3},
  [961] = {.lex_state = 2, .external_lex_state = 3},
  [962] = {.lex_state = 2, .external_lex_state = 3},
  [963] = {.lex_state = 2, .external_lex_state = 3},
  [964] = {.lex_state = 2, .external_lex_state = 3},
  [965] = {.lex_state = 2, .external_lex_state = 3},
  [966] = {.lex_state = 2, .external_lex_state = 3},
  [967] = {.lex_state = 2, .external_lex_state = 3},
  [968] = {.lex_state = 2, .external_lex_state = 3},
  [969] = {.lex_state = 2, .external_lex_state = 3},
  [970] = {.lex_state = 2, .external_lex_state = 3},
  [971] = {.lex_state = 2, .external_lex_state = 3},
  [972] = {.lex_state = 2, .external_lex_state = 3},
  [973] = {.lex_state = 2, .external_lex_state = 3},
  [974] = {.lex_state = 2, .external_lex_state = 3},
  [975] = {.lex_state = 2, .external_lex_state = 3},
  [976] = {.lex_state = 2, .external_lex_state = 3},
  [977] = {.lex_state = 2, .external_lex_state = 3},
  [978] = {.lex_state = 2, .external_lex_state = 3},
  [979] = {.lex_state = 2, .external_lex_state = 3},
  [980] = {.lex_state = 2, .external_lex_state = 3},
  [981] = {.lex_state = 2, .external_lex_state = 3},
  [982] = {.lex_state = 2, .external_lex_state = 3},
  [983] = {.lex_state = 2, .external_lex_state = 3},
  [984] = {.lex_state = 2, .external_lex_state = 3},
  [985] = {.lex_state = 2, .external_lex_state = 3},
  [986] = {.lex_state = 2, .external_lex_state = 3},
  [987] = {.lex_state = 2, .external_lex_state = 3},
  [988] = {.lex_state = 2, .external_lex_state = 3},
  [989] = {.lex_state = 2, .external_lex_state = 3},
  [990] = {.lex_state = 2, .external_lex_state = 3},
  [991] = {.lex_state = 2, .external_lex_state = 3},
  [992] = {.lex_state = 2, .external_lex_state = 3},
  [993] = {.lex_state = 2, .external_lex_state = 3},
  [994] = {.lex_state = 91, .external_lex_state = 11},
  [995] = {.lex_state = 2, .external_lex_state = 3},
  [996] = {.lex_state = 91, .external_lex_state = 11},
  [997] = {.lex_state = 2, .external_lex_state = 3},
  [998] = {.lex_state = 2, .external_lex_state = 3},
  [999] = {.lex_state = 2, .external_lex_state = 3},
  [1000] = {.lex_state = 2, .external_lex_state = 3},
  [1001] = {.lex_state = 2, .external_lex_state = 3},
  [1002] = {.lex_state = 2, .external_lex_state = 3},
  [1003] = {.lex_state = 2, .external_lex_state = 3},
  [1004] = {.lex_state = 2, .external_lex_state = 3},
  [1005] = {.lex_state = 2, .external_lex_state = 3},
  [1006] = {.lex_state = 2, .external_lex_state = 3},
  [1007] = {.lex_state = 2, .external_lex_state = 3},
  [1008] = {.lex_state = 2, .external_lex_state = 3},
  [1009] = {.lex_state = 2, .external_lex_state = 3},
  [1010] = {.lex_state = 2, .external_lex_state = 3},
  [1011] = {.lex_state = 2, .external_lex_state = 3},
  [1012] = {.lex_state = 2, .external_lex_state = 3},
  [1013] = {.lex_state = 2, .external_lex_state = 3},
  [1014] = {.lex_state = 2, .external_lex_state = 3},
  [1015] = {.lex_state = 2, .external_lex_state = 3},
  [1016] = {.lex_state = 2, .external_lex_state = 3},
  [1017] = {.lex_state = 2, .external_lex_state = 3},
  [1018] = {.lex_state = 2, .external_lex_state = 3},
  [1019] = {.lex_state = 2, .external_lex_state = 3},
  [1020] = {.lex_state = 2, .external_lex_state = 3},
  [1021] = {.lex_state = 2, .external_lex_state = 3},
  [1022] = {.lex_state = 2, .external_lex_state = 3},
  [1023] = {.lex_state = 2, .external_lex_state = 3},
  [1024] = {.lex_state = 2, .external_lex_state = 3},
  [1025] = {.lex_state = 2, .external_lex_state = 3},
  [1026] = {.lex_state = 2, .external_lex_state = 3},
  [1027] = {.lex_state = 2, .external_lex_state = 3},
  [1028] = {.lex_state = 2, .external_lex_state = 3},
  [1029] = {.lex_state = 2, .external_lex_state = 3},
  [1030] = {.lex_state = 2, .external_lex_state = 3},
  [1031] = {.lex_state = 2, .external_lex_state = 3},
  [1032] = {.lex_state = 2, .external_lex_state = 3},
  [1033] = {.lex_state = 2, .external_lex_state = 3},
  [1034] = {.lex_state = 2, .external_lex_state = 3},
  [1035] = {.lex_state = 2, .external_lex_state = 3},
  [1036] = {.lex_state = 2, .external_lex_state = 3},
  [1037] = {.lex_state = 2, .external_lex_state = 3},
  [1038] = {.lex_state = 2, .external_lex_state = 3},
  [1039] = {.lex_state = 2, .external_lex_state = 3},
  [1040] = {.lex_state = 2, .external_lex_state = 3},
  [1041] = {.lex_state = 91, .external_lex_state = 11},
  [1042] = {.lex_state = 2, .external_lex_state = 7},
  [1043] = {.lex_state = 91, .external_lex_state = 11},
  [1044] = {.lex_state = 91, .external_lex_state = 11},
  [1045] = {.lex_state = 91, .external_lex_state = 11},
  [1046] = {.lex_state = 91, .external_lex_state = 11},
  [1047] = {.lex_state = 91, .external_lex_state = 11},
  [1048] = {.lex_state = 91, .external_lex_state = 11},
  [1049] = {.lex_state = 91, .external_lex_state = 11},
  [1050] = {.lex_state = 2, .external_lex_state = 7},
  [1051] = {.lex_state = 2, .external_lex_state = 7},
  [1052] = {.lex_state = 2, .external_lex_state = 7},
  [1053] = {.lex_state = 2, .external_lex_state = 7},
  [1054] = {.lex_state = 2, .external_lex_state = 7},
  [1055] = {.lex_state = 2, .external_lex_state = 7},
  [1056] = {.lex_state = 2, .external_lex_state = 7},
  [1057] = {.lex_state = 2, .external_lex_state = 7},
  [1058] = {.lex_state = 2, .external_lex_state = 7},
  [1059] = {.lex_state = 2, .external_lex_state = 7},
  [1060] = {.lex_state = 2, .external_lex_state = 7},
  [1061] = {.lex_state = 2, .external_lex_state = 7},
  [1062] = {.lex_state = 2, .external_lex_state = 7},
  [1063] = {.lex_state = 2, .external_lex_state = 7},
  [1064] = {.lex_state = 2, .external_lex_state = 7},
  [1065] = {.lex_state = 2, .external_lex_state = 7},
  [1066] = {.lex_state = 2, .external_lex_state = 7},
  [1067] = {.lex_state = 2, .external_lex_state = 7},
  [1068] = {.lex_state = 2, .external_lex_state = 7},
  [1069] = {.lex_state = 2, .external_lex_state = 7},
  [1070] = {.lex_state = 2, .external_lex_state = 7},
  [1071] = {.lex_state = 2, .external_lex_state = 7},
  [1072] = {.lex_state = 2, .external_lex_state = 7},
  [1073] = {.lex_state = 2, .external_lex_state = 7},
  [1074] = {.lex_state = 2, .external_lex_state = 7},
  [1075] = {.lex_state = 2, .external_lex_state = 7},
  [1076] = {.lex_state = 2, .external_lex_state = 7},
  [1077] = {.lex_state = 2, .external_lex_state = 7},
  [1078] = {.lex_state = 2, .external_lex_state = 7},
  [1079] = {.lex_state = 2, .external_lex_state = 7},
  [1080] = {.lex_state = 2, .external_lex_state = 7},
  [1081] = {.lex_state = 2, .external_lex_state = 7},
  [1082] = {.lex_state = 2, .external_lex_state = 7},
  [1083] = {.lex_state = 2, .external_lex_state = 7},
  [1084] = {.lex_state = 2, .external_lex_state = 7},
  [1085] = {.lex_state = 2, .external_lex_state = 7},
  [1086] = {.lex_state = 2, .external_lex_state = 7},
  [1087] = {.lex_state = 2, .external_lex_state = 7},
  [1088] = {.lex_state = 2, .external_lex_state = 7},
  [1089] = {.lex_state = 2, .external_lex_state = 7},
  [1090] = {.lex_state = 2, .external_lex_state = 7},
  [1091] = {.lex_state = 2, .external_lex_state = 7},
  [1092] = {.lex_state = 2, .external_lex_state = 7},
  [1093] = {.lex_state = 91, .external_lex_state = 11},
  [1094] = {.lex_state = 91, .external_lex_state = 11},
  [1095] = {.lex_state = 91, .external_lex_state = 11},
  [1096] = {.lex_state = 91, .external_lex_state = 11},
  [1097] = {.lex_state = 91, .external_lex_state = 11},
  [1098] = {.lex_state = 91, .external_lex_state = 11},
  [1099] = {.lex_state = 2, .external_lex_state = 7},
  [1100] = {.lex_state = 2, .external_lex_state = 7},
  [1101] = {.lex_state = 2, .external_lex_state = 7},
  [1102] = {.lex_state = 2, .external_lex_state = 7},
  [1103] = {.lex_state = 91, .external_lex_state = 11},
  [1104] = {.lex_state = 2, .external_lex_state = 7},
  [1105] = {.lex_state = 91, .external_lex_state = 11},
  [1106] = {.lex_state = 2, .external_lex_state = 7},
  [1107] = {.lex_state = 2, .external_lex_state = 7},
  [1108] = {.lex_state = 91, .external_lex_state = 11},
  [1109] = {.lex_state = 2, .external_lex_state = 7},
  [1110] = {.lex_state = 91, .external_lex_state = 11},
  [1111] = {.lex_state = 2, .external_lex_state = 7},
  [1112] = {.lex_state = 2, .external_lex_state = 7},
  [1113] = {.lex_state = 2, .external_lex_state = 7},
  [1114] = {.lex_state = 2, .external_lex_state = 7},
  [1115] = {.lex_state = 91, .external_lex_state = 11},
  [1116] = {.lex_state = 2, .external_lex_state = 7},
  [1117] = {.lex_state = 91, .external_lex_state = 11},
  [1118] = {.lex_state = 2, .external_lex_state = 7},
  [1119] = {.lex_state = 2, .external_lex_state = 7},
  [1120] = {.lex_state = 91, .external_lex_state = 11},
  [1121] = {.lex_state = 91, .external_lex_state = 11},
  [1122] = {.lex_state = 91, .external_lex_state = 11},
  [1123] = {.lex_state = 91, .external_lex_state = 11},
  [1124] = {.lex_state = 91, .external_lex_state = 11},
  [1125] = {.lex_state = 91, .external_lex_state = 11},
  [1126] = {.lex_state = 2, .external_lex_state = 7},
  [1127] = {.lex_state = 2, .external_lex_state = 7},
  [1128] = {.lex_state = 2, .external_lex_state = 7},
  [1129] = {.lex_state = 2, .external_lex_state = 7},
  [1130] = {.lex_state = 2, .external_lex_state = 7},
  [1131] = {.lex_state = 2, .external_lex_state = 7},
  [1132] = {.lex_state = 2, .external_lex_state = 7},
  [1133] = {.lex_state = 2, .external_lex_state = 7},
  [1134] = {.lex_state = 2, .external_lex_state = 7},
  [1135] = {.lex_state = 2, .external_lex_state = 7},
  [1136] = {.lex_state = 2, .external_lex_state = 7},
  [1137] = {.lex_state = 2, .external_lex_state = 7},
  [1138] = {.lex_state = 2, .external_lex_state = 7},
  [1139] = {.lex_state = 2, .external_lex_state = 7},
  [1140] = {.lex_state = 2, .external_lex_state = 7},
  [1141] = {.lex_state = 2, .external_lex_state = 7},
  [1142] = {.lex_state = 2, .external_lex_state = 7},
  [1143] = {.lex_state = 2, .external_lex_state = 7},
  [1144] = {.lex_state = 2, .external_lex_state = 7},
  [1145] = {.lex_state = 2, .external_lex_state = 7},
  [1146] = {.lex_state = 2, .external_lex_state = 7},
  [1147] = {.lex_state = 2, .external_lex_state = 7},
  [1148] = {.lex_state = 2, .external_lex_state = 7},
  [1149] = {.lex_state = 2, .external_lex_state = 7},
  [1150] = {.lex_state = 2, .external_lex_state = 7},
  [1151] = {.lex_state = 2, .external_lex_state = 7},
  [1152] = {.lex_state = 2, .external_lex_state = 7},
  [1153] = {.lex_state = 2, .external_lex_state = 9},
  [1154] = {.lex_state = 2, .external_lex_state = 9},
  [1155] = {.lex_state = 91, .external_lex_state = 6},
  [1156] = {.lex_state = 2, .external_lex_state = 9},
  [1157] = {.lex_state = 2, .external_lex_state = 9},
  [1158] = {.lex_state = 2, .external_lex_state = 9},
  [1159] = {.lex_state = 91, .external_lex_state = 2},
  [1160] = {.lex_state = 2, .external_lex_state = 9},
  [1161] = {.lex_state = 2, .external_lex_state = 9},
  [1162] = {.lex_state = 2, .external_lex_state = 9},
  [1163] = {.lex_state = 2, .external_lex_state = 9},
  [1164] = {.lex_state = 91, .external_lex_state = 2},
  [1165] = {.lex_state = 2, .external_lex_state = 9},
  [1166] = {.lex_state = 2, .external_lex_state = 9},
  [1167] = {.lex_state = 2, .external_lex_state = 9},
  [1168] = {.lex_state = 2, .external_lex_state = 9},
  [1169] = {.lex_state = 2, .external_lex_state = 9},
  [1170] = {.lex_state = 91, .external_lex_state = 2},
  [1171] = {.lex_state = 2, .external_lex_state = 9},
  [1172] = {.lex_state = 2, .external_lex_state = 9},
  [1173] = {.lex_state = 2, .external_lex_state = 9},
  [1174] = {.lex_state = 2, .external_lex_state = 9},
  [1175] = {.lex_state = 2, .external_lex_state = 9},
  [1176] = {.lex_state = 2, .external_lex_state = 9},
  [1177] = {.lex_state = 2, .external_lex_state = 9},
  [1178] = {.lex_state = 2, .external_lex_state = 9},
  [1179] = {.lex_state = 91, .external_lex_state = 2},
  [1180] = {.lex_state = 2, .external_lex_state = 9},
  [1181] = {.lex_state = 2, .external_lex_state = 9},
  [1182] = {.lex_state = 2, .external_lex_state = 9},
  [1183] = {.lex_state = 2, .external_lex_state = 9},
  [1184] = {.lex_state = 2, .external_lex_state = 9},
  [1185] = {.lex_state = 2, .external_lex_state = 9},
  [1186] = {.lex_state = 2, .external_lex_state = 9},
  [1187] = {.lex_state = 2, .external_lex_state = 9},
  [1188] = {.lex_state = 2, .external_lex_state = 9},
  [1189] = {.lex_state = 2, .external_lex_state = 9},
  [1190] = {.lex_state = 2, .external_lex_state = 9},
  [1191] = {.lex_state = 2, .external_lex_state = 9},
  [1192] = {.lex_state = 2, .external_lex_state = 9},
  [1193] = {.lex_state = 2, .external_lex_state = 9},
  [1194] = {.lex_state = 2, .external_lex_state = 9},
  [1195] = {.lex_state = 2, .external_lex_state = 9},
  [1196] = {.lex_state = 2, .external_lex_state = 9},
  [1197] = {.lex_state = 2, .external_lex_state = 9},
  [1198] = {.lex_state = 2, .external_lex_state = 9},
  [1199] = {.lex_state = 2, .external_lex_state = 9},
  [1200] = {.lex_state = 2, .external_lex_state = 9},
  [1201] = {.lex_state = 2, .external_lex_state = 9},
  [1202] = {.lex_state = 2, .external_lex_state = 9},
  [1203] = {.lex_state = 2, .external_lex_state = 9},
  [1204] = {.lex_state = 2, .external_lex_state = 9},
  [1205] = {.lex_state = 2, .external_lex_state = 9},
  [1206] = {.lex_state = 2, .external_lex_state = 9},
  [1207] = {.lex_state = 2, .external_lex_state = 9},
  [1208] = {.lex_state = 2, .external_lex_state = 9},
  [1209] = {.lex_state = 2, .external_lex_state = 9},
  [1210] = {.lex_state = 2, .external_lex_state = 9},
  [1211] = {.lex_state = 2, .external_lex_state = 9},
  [1212] = {.lex_state = 2, .external_lex_state = 9},
  [1213] = {.lex_state = 2, .external_lex_state = 9},
  [1214] = {.lex_state = 2, .external_lex_state = 9},
  [1215] = {.lex_state = 2, .external_lex_state = 9},
  [1216] = {.lex_state = 2, .external_lex_state = 9},
  [1217] = {.lex_state = 2, .external_lex_state = 9},
  [1218] = {.lex_state = 2, .external_lex_state = 9},
  [1219] = {.lex_state = 2, .external_lex_state = 9},
  [1220] = {.lex_state = 2, .external_lex_state = 9},
  [1221] = {.lex_state = 2, .external_lex_state = 9},
  [1222] = {.lex_state = 2, .external_lex_state = 9},
  [1223] = {.lex_state = 2, .external_lex_state = 9},
  [1224] = {.lex_state = 2, .external_lex_state = 9},
  [1225] = {.lex_state = 2, .external_lex_state = 9},
  [1226] = {.lex_state = 2, .external_lex_state = 9},
  [1227] = {.lex_state = 2, .external_lex_state = 9},
  [1228] = {.lex_state = 2, .external_lex_state = 9},
  [1229] = {.lex_state = 2, .external_lex_state = 9},
  [1230] = {.lex_state = 2, .external_lex_state = 9},
  [1231] = {.lex_state = 2, .external_lex_state = 9},
  [1232] = {.lex_state = 2, .external_lex_state = 9},
  [1233] = {.lex_state = 2, .external_lex_state = 9},
  [1234] = {.lex_state = 2, .external_lex_state = 9},
  [1235] = {.lex_state = 2, .external_lex_state = 9},
  [1236] = {.lex_state = 2, .external_lex_state = 9},
  [1237] = {.lex_state = 2, .external_lex_state = 9},
  [1238] = {.lex_state = 2, .external_lex_state = 9},
  [1239] = {.lex_state = 2, .external_lex_state = 9},
  [1240] = {.lex_state = 2, .external_lex_state = 9},
  [1241] = {.lex_state = 2, .external_lex_state = 9},
  [1242] = {.lex_state = 2, .external_lex_state = 9},
  [1243] = {.lex_state = 2, .external_lex_state = 9},
  [1244] = {.lex_state = 91, .external_lex_state = 2},
  [1245] = {.lex_state = 91, .external_lex_state = 12},
  [1246] = {.lex_state = 2, .external_lex_state = 3},
  [1247] = {.lex_state = 91, .external_lex_state = 8},
  [1248] = {.lex_state = 2, .external_lex_state = 3},
  [1249] = {.lex_state = 91, .external_lex_state = 12},
  [1250] = {.lex_state = 91, .external_lex_state = 12},
  [1251] = {.lex_state = 2, .external_lex_state = 3},
  [1252] = {.lex_state = 91},
  [1253] = {.lex_state = 91},
  [1254] = {.lex_state = 91},
  [1255] = {.lex_state = 91},
  [1256] = {.lex_state = 91},
  [1257] = {.lex_state = 3, .external_lex_state = 3},
  [1258] = {.lex_state = 91},
  [1259] = {.lex_state = 91},
  [1260] = {.lex_state = 91},
  [1261] = {.lex_state = 91},
  [1262] = {.lex_state = 91},
  [1263] = {.lex_state = 91},
  [1264] = {.lex_state = 91},
  [1265] = {.lex_state = 91},
  [1266] = {.lex_state = 91},
  [1267] = {.lex_state = 91},
  [1268] = {.lex_state = 91},
  [1269] = {.lex_state = 91},
  [1270] = {.lex_state = 91},
  [1271] = {.lex_state = 91},
  [1272] = {.lex_state = 91},
  [1273] = {.lex_state = 91},
  [1274] = {.lex_state = 91},
  [1275] = {.lex_state = 91},
  [1276] = {.lex_state = 91},
  [1277] = {.lex_state = 91},
  [1278] = {.lex_state = 91},
  [1279] = {.lex_state = 91},
  [1280] = {.lex_state = 91},
  [1281] = {.lex_state = 91},
  [1282] = {.lex_state = 91},
  [1283] = {.lex_state = 91},
  [1284] = {.lex_state = 91},
  [1285] = {.lex_state = 91},
  [1286] = {.lex_state = 91},
  [1287] = {.lex_state = 91},
  [1288] = {.lex_state = 91},
  [1289] = {.lex_state = 91},
  [1290] = {.lex_state = 91},
  [1291] = {.lex_state = 91},
  [1292] = {.lex_state = 91},
  [1293] = {.lex_state = 91},
  [1294] = {.lex_state = 91},
  [1295] = {.lex_state = 91},
  [1296] = {.lex_state = 91},
  [1297] = {.lex_state = 91},
  [1298] = {.lex_state = 91},
  [1299] = {.lex_state = 91},
  [1300] = {.lex_state = 91},
  [1301] = {.lex_state = 91},
  [1302] = {.lex_state = 91},
  [1303] = {.lex_state = 91},
  [1304] = {.lex_state = 91},
  [1305] = {.lex_state = 91},
  [1306] = {.lex_state = 91},
  [1307] = {.lex_state = 91},
  [1308] = {.lex_state = 91},
  [1309] = {.lex_state = 91},
  [1310] = {.lex_state = 91},
  [1311] = {.lex_state = 91},
  [1312] = {.lex_state = 91},
  [1313] = {.lex_state = 91},
  [1314] = {.lex_state = 91},
  [1315] = {.lex_state = 91},
  [1316] = {.lex_state = 91},
  [1317] = {.lex_state = 91},
  [1318] = {.lex_state = 91},
  [1319] = {.lex_state = 91},
  [1320] = {.lex_state = 91},
  [1321] = {.lex_state = 91},
  [1322] = {.lex_state = 91},
  [1323] = {.lex_state = 91},
  [1324] = {.lex_state = 91},
  [1325] = {.lex_state = 91},
  [1326] = {.lex_state = 91},
  [1327] = {.lex_state = 91},
  [1328] = {.lex_state = 91},
  [1329] = {.lex_state = 91},
  [1330] = {.lex_state = 91},
  [1331] = {.lex_state = 91},
  [1332] = {.lex_state = 91},
  [1333] = {.lex_state = 91},
  [1334] = {.lex_state = 91},
  [1335] = {.lex_state = 91},
  [1336] = {.lex_state = 91},
  [1337] = {.lex_state = 91},
  [1338] = {.lex_state = 91},
  [1339] = {.lex_state = 91},
  [1340] = {.lex_state = 91},
  [1341] = {.lex_state = 91},
  [1342] = {.lex_state = 91},
  [1343] = {.lex_state = 91},
  [1344] = {.lex_state = 91},
  [1345] = {.lex_state = 91},
  [1346] = {.lex_state = 91},
  [1347] = {.lex_state = 91},
  [1348] = {.lex_state = 91},
  [1349] = {.lex_state = 91},
  [1350] = {.lex_state = 91},
  [1351] = {.lex_state = 91},
  [1352] = {.lex_state = 91},
  [1353] = {.lex_state = 91},
  [1354] = {.lex_state = 91},
  [1355] = {.lex_state = 91},
  [1356] = {.lex_state = 91},
  [1357] = {.lex_state = 91},
  [1358] = {.lex_state = 91},
  [1359] = {.lex_state = 91},
  [1360] = {.lex_state = 91},
  [1361] = {.lex_state = 91},
  [1362] = {.lex_state = 91},
  [1363] = {.lex_state = 91},
  [1364] = {.lex_state = 91},
  [1365] = {.lex_state = 91, .external_lex_state = 13},
  [1366] = {.lex_state = 91, .external_lex_state = 12},
  [1367] = {.lex_state = 91, .external_lex_state = 12},
  [1368] = {.lex_state = 2, .external_lex_state = 3},
  [1369] = {.lex_state = 2, .external_lex_state = 7},
  [1370] = {.lex_state = 3, .external_lex_state = 3},
  [1371] = {.lex_state = 91, .external_lex_state = 12},
  [1372] = {.lex_state = 2, .external_lex_state = 14},
  [1373] = {.lex_state = 2, .external_lex_state = 14},
  [1374] = {.lex_state = 3, .external_lex_state = 3},
  [1375] = {.lex_state = 91, .external_lex_state = 12},
  [1376] = {.lex_state = 2, .external_lex_state = 7},
  [1377] = {.lex_state = 91, .external_lex_state = 12},
  [1378] = {.lex_state = 91, .external_lex_state = 12},
  [1379] = {.lex_state = 2, .external_lex_state = 14},
  [1380] = {.lex_state = 2, .external_lex_state = 7},
  [1381] = {.lex_state = 91, .external_lex_state = 12},
  [1382] = {.lex_state = 3, .external_lex_state = 3},
  [1383] = {.lex_state = 91, .external_lex_state = 12},
  [1384] = {.lex_state = 91, .external_lex_state = 12},
  [1385] = {.lex_state = 3, .external_lex_state = 3},
  [1386] = {.lex_state = 3, .external_lex_state = 3},
  [1387] = {.lex_state = 3, .external_lex_state = 3},
  [1388] = {.lex_state = 91, .external_lex_state = 12},
  [1389] = {.lex_state = 91, .external_lex_state = 12},
  [1390] = {.lex_state = 91, .external_lex_state = 12},
  [1391] = {.lex_state = 91, .external_lex_state = 12},
  [1392] = {.lex_state = 91, .external_lex_state = 12},
  [1393] = {.lex_state = 91, .external_lex_state = 12},
  [1394] = {.lex_state = 91, .external_lex_state = 12},
  [1395] = {.lex_state = 6},
  [1396] = {.lex_state = 2, .external_lex_state = 3},
  [1397] = {.lex_state = 6},
  [1398] = {.lex_state = 91, .external_lex_state = 3},
  [1399] = {.lex_state = 2, .external_lex_state = 3},
  [1400] = {.lex_state = 2, .external_lex_state = 3},
  [1401] = {.lex_state = 2, .external_lex_state = 3},
  [1402] = {.lex_state = 2, .external_lex_state = 3},
  [1403] = {.lex_state = 2, .external_lex_state = 3},
  [1404] = {.lex_state = 2, .external_lex_state = 3},
  [1405] = {.lex_state = 2, .external_lex_state = 3},
  [1406] = {.lex_state = 2, .external_lex_state = 3},
  [1407] = {.lex_state = 2, .external_lex_state = 3},
  [1408] = {.lex_state = 2, .external_lex_state = 3},
  [1409] = {.lex_state = 2, .external_lex_state = 3},
  [1410] = {.lex_state = 2, .external_lex_state = 3},
  [1411] = {.lex_state = 2, .external_lex_state = 3},
  [1412] = {.lex_state = 2, .external_lex_state = 3},
  [1413] = {.lex_state = 2, .external_lex_state = 3},
  [1414] = {.lex_state = 2, .external_lex_state = 3},
  [1415] = {.lex_state = 2, .external_lex_state = 3},
  [1416] = {.lex_state = 2, .external_lex_state = 3},
  [1417] = {.lex_state = 2, .external_lex_state = 3},
  [1418] = {.lex_state = 2, .external_lex_state = 3},
  [1419] = {.lex_state = 2, .external_lex_state = 3},
  [1420] = {.lex_state = 2, .external_lex_state = 3},
  [1421] = {.lex_state = 2, .external_lex_state = 3},
  [1422] = {.lex_state = 2, .external_lex_state = 3},
  [1423] = {.lex_state = 2, .external_lex_state = 3},
  [1424] = {.lex_state = 2, .external_lex_state = 7},
  [1425] = {.lex_state = 2, .external_lex_state = 3},
  [1426] = {.lex_state = 2, .external_lex_state = 3},
  [1427] = {.lex_state = 2, .external_lex_state = 3},
  [1428] = {.lex_state = 2, .external_lex_state = 14},
  [1429] = {.lex_state = 2, .external_lex_state = 3},
  [1430] = {.lex_state = 91, .external_lex_state = 15},
  [1431] = {.lex_state = 91, .external_lex_state = 15},
  [1432] = {.lex_state = 2, .external_lex_state = 3},
  [1433] = {.lex_state = 2, .external_lex_state = 3},
  [1434] = {.lex_state = 2, .external_lex_state = 3},
  [1435] = {.lex_state = 2, .external_lex_state = 3},
  [1436] = {.lex_state = 2, .external_lex_state = 3},
  [1437] = {.lex_state = 2, .external_lex_state = 3},
  [1438] = {.lex_state = 2, .external_lex_state = 3},
  [1439] = {.lex_state = 2, .external_lex_state = 3},
  [1440] = {.lex_state = 2, .external_lex_state = 3},
  [1441] = {.lex_state = 2, .external_lex_state = 3},
  [1442] = {.lex_state = 2, .external_lex_state = 3},
  [1443] = {.lex_state = 2, .external_lex_state = 3},
  [1444] = {.lex_state = 91, .external_lex_state = 15},
  [1445] = {.lex_state = 2, .external_lex_state = 3},
  [1446] = {.lex_state = 2, .external_lex_state = 3},
  [1447] = {.lex_state = 2, .external_lex_state = 3},
  [1448] = {.lex_state = 2, .external_lex_state = 3},
  [1449] = {.lex_state = 2, .external_lex_state = 3},
  [1450] = {.lex_state = 2, .external_lex_state = 3},
  [1451] = {.lex_state = 91, .external_lex_state = 15},
  [1452] = {.lex_state = 2, .external_lex_state = 3},
  [1453] = {.lex_state = 91, .external_lex_state = 15},
  [1454] = {.lex_state = 91, .external_lex_state = 15},
  [1455] = {.lex_state = 91, .external_lex_state = 15},
  [1456] = {.lex_state = 91, .external_lex_state = 15},
  [1457] = {.lex_state = 91, .external_lex_state = 15},
  [1458] = {.lex_state = 91, .external_lex_state = 15},
  [1459] = {.lex_state = 91, .external_lex_state = 15},
  [1460] = {.lex_state = 91, .external_lex_state = 15},
  [1461] = {.lex_state = 91, .external_lex_state = 15},
  [1462] = {.lex_state = 91, .external_lex_state = 15},
  [1463] = {.lex_state = 91, .external_lex_state = 15},
  [1464] = {.lex_state = 91, .external_lex_state = 15},
  [1465] = {.lex_state = 91, .external_lex_state = 15},
  [1466] = {.lex_state = 91, .external_lex_state = 15},
  [1467] = {.lex_state = 91, .external_lex_state = 15},
  [1468] = {.lex_state = 91, .external_lex_state = 15},
  [1469] = {.lex_state = 91, .external_lex_state = 15},
  [1470] = {.lex_state = 91, .external_lex_state = 15},
  [1471] = {.lex_state = 91, .external_lex_state = 15},
  [1472] = {.lex_state = 91, .external_lex_state = 15},
  [1473] = {.lex_state = 91, .external_lex_state = 15},
  [1474] = {.lex_state = 91, .external_lex_state = 15},
  [1475] = {.lex_state = 91, .external_lex_state = 15},
  [1476] = {.lex_state = 91, .external_lex_state = 15},
  [1477] = {.lex_state = 91, .external_lex_state = 15},
  [1478] = {.lex_state = 91, .external_lex_state = 15},
  [1479] = {.lex_state = 91, .external_lex_state = 15},
  [1480] = {.lex_state = 91, .external_lex_state = 15},
  [1481] = {.lex_state = 91, .external_lex_state = 15},
  [1482] = {.lex_state = 91, .external_lex_state = 15},
  [1483] = {.lex_state = 91, .external_lex_state = 15},
  [1484] = {.lex_state = 2, .external_lex_state = 3},
  [1485] = {.lex_state = 6},
  [1486] = {.lex_state = 91, .external_lex_state = 15},
  [1487] = {.lex_state = 91, .external_lex_state = 15},
  [1488] = {.lex_state = 91, .external_lex_state = 15},
  [1489] = {.lex_state = 91, .external_lex_state = 15},
  [1490] = {.lex_state = 91, .external_lex_state = 15},
  [1491] = {.lex_state = 91, .external_lex_state = 15},
  [1492] = {.lex_state = 2, .external_lex_state = 3},
  [1493] = {.lex_state = 2, .external_lex_state = 3},
  [1494] = {.lex_state = 2, .external_lex_state = 3},
  [1495] = {.lex_state = 2, .external_lex_state = 3},
  [1496] = {.lex_state = 2, .external_lex_state = 3},
  [1497] = {.lex_state = 2, .external_lex_state = 3},
  [1498] = {.lex_state = 2, .external_lex_state = 3},
  [1499] = {.lex_state = 2, .external_lex_state = 3},
  [1500] = {.lex_state = 2, .external_lex_state = 3},
  [1501] = {.lex_state = 2, .external_lex_state = 3},
  [1502] = {.lex_state = 2, .external_lex_state = 3},
  [1503] = {.lex_state = 3, .external_lex_state = 3},
  [1504] = {.lex_state = 3, .external_lex_state = 3},
  [1505] = {.lex_state = 2, .external_lex_state = 3},
  [1506] = {.lex_state = 2, .external_lex_state = 3},
  [1507] = {.lex_state = 2, .external_lex_state = 3},
  [1508] = {.lex_state = 2, .external_lex_state = 3},
  [1509] = {.lex_state = 2, .external_lex_state = 3},
  [1510] = {.lex_state = 2, .external_lex_state = 3},
  [1511] = {.lex_state = 2, .external_lex_state = 3},
  [1512] = {.lex_state = 2, .external_lex_state = 3},
  [1513] = {.lex_state = 2, .external_lex_state = 3},
  [1514] = {.lex_state = 2, .external_lex_state = 3},
  [1515] = {.lex_state = 2, .external_lex_state = 3},
  [1516] = {.lex_state = 2, .external_lex_state = 3},
  [1517] = {.lex_state = 2, .external_lex_state = 3},
  [1518] = {.lex_state = 2, .external_lex_state = 3},
  [1519] = {.lex_state = 2, .external_lex_state = 3},
  [1520] = {.lex_state = 2, .external_lex_state = 3},
  [1521] = {.lex_state = 2, .external_lex_state = 3},
  [1522] = {.lex_state = 91, .external_lex_state = 3},
  [1523] = {.lex_state = 2, .external_lex_state = 3},
  [1524] = {.lex_state = 2, .external_lex_state = 3},
  [1525] = {.lex_state = 2, .external_lex_state = 3},
  [1526] = {.lex_state = 2, .external_lex_state = 3},
  [1527] = {.lex_state = 2, .external_lex_state = 3},
  [1528] = {.lex_state = 2, .external_lex_state = 3},
  [1529] = {.lex_state = 2, .external_lex_state = 3},
  [1530] = {.lex_state = 2, .external_lex_state = 3},
  [1531] = {.lex_state = 91, .external_lex_state = 3},
  [1532] = {.lex_state = 91, .external_lex_state = 3},
  [1533] = {.lex_state = 91, .external_lex_state = 3},
  [1534] = {.lex_state = 91, .external_lex_state = 3},
  [1535] = {.lex_state = 91, .external_lex_state = 3},
  [1536] = {.lex_state = 1, .external_lex_state = 3},
  [1537] = {.lex_state = 1, .external_lex_state = 3},
  [1538] = {.lex_state = 91, .external_lex_state = 3},
  [1539] = {.lex_state = 91, .external_lex_state = 3},
  [1540] = {.lex_state = 91, .external_lex_state = 3},
  [1541] = {.lex_state = 91, .external_lex_state = 3},
  [1542] = {.lex_state = 91, .external_lex_state = 3},
  [1543] = {.lex_state = 91, .external_lex_state = 3},
  [1544] = {.lex_state = 91, .external_lex_state = 3},
  [1545] = {.lex_state = 91, .external_lex_state = 3},
  [1546] = {.lex_state = 91, .external_lex_state = 3},
  [1547] = {.lex_state = 91, .external_lex_state = 3},
  [1548] = {.lex_state = 91, .external_lex_state = 3},
  [1549] = {.lex_state = 91, .external_lex_state = 3},
  [1550] = {.lex_state = 91, .external_lex_state = 3},
  [1551] = {.lex_state = 91, .external_lex_state = 3},
  [1552] = {.lex_state = 91, .external_lex_state = 3},
  [1553] = {.lex_state = 91, .external_lex_state = 3},
  [1554] = {.lex_state = 91, .external_lex_state = 3},
  [1555] = {.lex_state = 91, .external_lex_state = 3},
  [1556] = {.lex_state = 91, .external_lex_state = 3},
  [1557] = {.lex_state = 91, .external_lex_state = 3},
  [1558] = {.lex_state = 91, .external_lex_state = 3},
  [1559] = {.lex_state = 91, .external_lex_state = 3},
  [1560] = {.lex_state = 91, .external_lex_state = 3},
  [1561] = {.lex_state = 91, .external_lex_state = 3},
  [1562] = {.lex_state = 91, .external_lex_state = 3},
  [1563] = {.lex_state = 91, .external_lex_state = 3},
  [1564] = {.lex_state = 91, .external_lex_state = 3},
  [1565] = {.lex_state = 91, .external_lex_state = 3},
  [1566] = {.lex_state = 91, .external_lex_state = 3},
  [1567] = {.lex_state = 91, .external_lex_state = 3},
  [1568] = {.lex_state = 91, .external_lex_state = 3},
  [1569] = {.lex_state = 91, .external_lex_state = 3},
  [1570] = {.lex_state = 91, .external_lex_state = 3},
  [1571] = {.lex_state = 91, .external_lex_state = 3},
  [1572] = {.lex_state = 91, .external_lex_state = 3},
  [1573] = {.lex_state = 91, .external_lex_state = 3},
  [1574] = {.lex_state = 91, .external_lex_state = 3},
  [1575] = {.lex_state = 91, .external_lex_state = 3},
  [1576] = {.lex_state = 91, .external_lex_state = 3},
  [1577] = {.lex_state = 91, .external_lex_state = 3},
  [1578] = {.lex_state = 91, .external_lex_state = 3},
  [1579] = {.lex_state = 91, .external_lex_state = 3},
  [1580] = {.lex_state = 91, .external_lex_state = 3},
  [1581] = {.lex_state = 91, .external_lex_state = 3},
  [1582] = {.lex_state = 91, .external_lex_state = 3},
  [1583] = {.lex_state = 91, .external_lex_state = 3},
  [1584] = {.lex_state = 91, .external_lex_state = 3},
  [1585] = {.lex_state = 91, .external_lex_state = 3},
  [1586] = {.lex_state = 91, .external_lex_state = 3},
  [1587] = {.lex_state = 91, .external_lex_state = 3},
  [1588] = {.lex_state = 91, .external_lex_state = 3},
  [1589] = {.lex_state = 91, .external_lex_state = 3},
  [1590] = {.lex_state = 91, .external_lex_state = 3},
  [1591] = {.lex_state = 91, .external_lex_state = 3},
  [1592] = {.lex_state = 91, .external_lex_state = 3},
  [1593] = {.lex_state = 91, .external_lex_state = 3},
  [1594] = {.lex_state = 91, .external_lex_state = 3},
  [1595] = {.lex_state = 91, .external_lex_state = 3},
  [1596] = {.lex_state = 91, .external_lex_state = 3},
  [1597] = {.lex_state = 91, .external_lex_state = 3},
  [1598] = {.lex_state = 91, .external_lex_state = 3},
  [1599] = {.lex_state = 91, .external_lex_state = 3},
  [1600] = {.lex_state = 91, .external_lex_state = 3},
  [1601] = {.lex_state = 91, .external_lex_state = 3},
  [1602] = {.lex_state = 91, .external_lex_state = 3},
  [1603] = {.lex_state = 91, .external_lex_state = 3},
  [1604] = {.lex_state = 91, .external_lex_state = 3},
  [1605] = {.lex_state = 91, .external_lex_state = 3},
  [1606] = {.lex_state = 91, .external_lex_state = 3},
  [1607] = {.lex_state = 91, .external_lex_state = 3},
  [1608] = {.lex_state = 91, .external_lex_state = 3},
  [1609] = {.lex_state = 91, .external_lex_state = 3},
  [1610] = {.lex_state = 91, .external_lex_state = 3},
  [1611] = {.lex_state = 91, .external_lex_state = 3},
  [1612] = {.lex_state = 91, .external_lex_state = 3},
  [1613] = {.lex_state = 91, .external_lex_state = 3},
  [1614] = {.lex_state = 91, .external_lex_state = 3},
  [1615] = {.lex_state = 91, .external_lex_state = 3},
  [1616] = {.lex_state = 91, .external_lex_state = 3},
  [1617] = {.lex_state = 91, .external_lex_state = 3},
  [1618] = {.lex_state = 91, .external_lex_state = 3},
  [1619] = {.lex_state = 91, .external_lex_state = 3},
  [1620] = {.lex_state = 91, .external_lex_state = 3},
  [1621] = {.lex_state = 91, .external_lex_state = 3},
  [1622] = {.lex_state = 91, .external_lex_state = 3},
  [1623] = {.lex_state = 91, .external_lex_state = 3},
  [1624] = {.lex_state = 91, .external_lex_state = 3},
  [1625] = {.lex_state = 91, .external_lex_state = 3},
  [1626] = {.lex_state = 91, .external_lex_state = 3},
  [1627] = {.lex_state = 91, .external_lex_state = 3},
  [1628] = {.lex_state = 91, .external_lex_state = 3},
  [1629] = {.lex_state = 91, .external_lex_state = 3},
  [1630] = {.lex_state = 91, .external_lex_state = 3},
  [1631] = {.lex_state = 91, .external_lex_state = 3},
  [1632] = {.lex_state = 91, .external_lex_state = 3},
  [1633] = {.lex_state = 91, .external_lex_state = 3},
  [1634] = {.lex_state = 91, .external_lex_state = 3},
  [1635] = {.lex_state = 91, .external_lex_state = 3},
  [1636] = {.lex_state = 91, .external_lex_state = 3},
  [1637] = {.lex_state = 91, .external_lex_state = 3},
  [1638] = {.lex_state = 91, .external_lex_state = 3},
  [1639] = {.lex_state = 91, .external_lex_state = 3},
  [1640] = {.lex_state = 91, .external_lex_state = 3},
  [1641] = {.lex_state = 91, .external_lex_state = 3},
  [1642] = {.lex_state = 91, .external_lex_state = 3},
  [1643] = {.lex_state = 91, .external_lex_state = 3},
  [1644] = {.lex_state = 91, .external_lex_state = 3},
  [1645] = {.lex_state = 91, .external_lex_state = 3},
  [1646] = {.lex_state = 91, .external_lex_state = 3},
  [1647] = {.lex_state = 91, .external_lex_state = 3},
  [1648] = {.lex_state = 91, .external_lex_state = 3},
  [1649] = {.lex_state = 91, .external_lex_state = 3},
  [1650] = {.lex_state = 91, .external_lex_state = 3},
  [1651] = {.lex_state = 91, .external_lex_state = 3},
  [1652] = {.lex_state = 91, .external_lex_state = 3},
  [1653] = {.lex_state = 91, .external_lex_state = 3},
  [1654] = {.lex_state = 6},
  [1655] = {.lex_state = 91, .external_lex_state = 3},
  [1656] = {.lex_state = 91, .external_lex_state = 3},
  [1657] = {.lex_state = 91, .external_lex_state = 3},
  [1658] = {.lex_state = 91, .external_lex_state = 3},
  [1659] = {.lex_state = 91, .external_lex_state = 3},
  [1660] = {.lex_state = 91, .external_lex_state = 3},
  [1661] = {.lex_state = 91, .external_lex_state = 3},
  [1662] = {.lex_state = 91, .external_lex_state = 3},
  [1663] = {.lex_state = 91, .external_lex_state = 3},
  [1664] = {.lex_state = 91, .external_lex_state = 3},
  [1665] = {.lex_state = 91, .external_lex_state = 3},
  [1666] = {.lex_state = 91, .external_lex_state = 3},
  [1667] = {.lex_state = 91, .external_lex_state = 3},
  [1668] = {.lex_state = 91, .external_lex_state = 3},
  [1669] = {.lex_state = 91, .external_lex_state = 3},
  [1670] = {.lex_state = 91, .external_lex_state = 3},
  [1671] = {.lex_state = 91, .external_lex_state = 3},
  [1672] = {.lex_state = 91, .external_lex_state = 3},
  [1673] = {.lex_state = 91, .external_lex_state = 3},
  [1674] = {.lex_state = 91, .external_lex_state = 3},
  [1675] = {.lex_state = 91, .external_lex_state = 3},
  [1676] = {.lex_state = 91, .external_lex_state = 3},
  [1677] = {.lex_state = 91, .external_lex_state = 3},
  [1678] = {.lex_state = 91, .external_lex_state = 3},
  [1679] = {.lex_state = 91, .external_lex_state = 3},
  [1680] = {.lex_state = 91, .external_lex_state = 3},
  [1681] = {.lex_state = 91, .external_lex_state = 3},
  [1682] = {.lex_state = 91, .external_lex_state = 3},
  [1683] = {.lex_state = 91, .external_lex_state = 3},
  [1684] = {.lex_state = 2, .external_lex_state = 3},
  [1685] = {.lex_state = 91, .external_lex_state = 3},
  [1686] = {.lex_state = 91, .external_lex_state = 3},
  [1687] = {.lex_state = 91, .external_lex_state = 3},
  [1688] = {.lex_state = 91, .external_lex_state = 3},
  [1689] = {.lex_state = 91, .external_lex_state = 3},
  [1690] = {.lex_state = 91, .external_lex_state = 3},
  [1691] = {.lex_state = 91, .external_lex_state = 3},
  [1692] = {.lex_state = 91, .external_lex_state = 3},
  [1693] = {.lex_state = 91, .external_lex_state = 3},
  [1694] = {.lex_state = 91, .external_lex_state = 3},
  [1695] = {.lex_state = 91, .external_lex_state = 3},
  [1696] = {.lex_state = 91, .external_lex_state = 3},
  [1697] = {.lex_state = 91, .external_lex_state = 3},
  [1698] = {.lex_state = 91, .external_lex_state = 3},
  [1699] = {.lex_state = 91, .external_lex_state = 3},
  [1700] = {.lex_state = 91, .external_lex_state = 3},
  [1701] = {.lex_state = 91, .external_lex_state = 3},
  [1702] = {.lex_state = 91, .external_lex_state = 3},
  [1703] = {.lex_state = 91, .external_lex_state = 3},
  [1704] = {.lex_state = 91, .external_lex_state = 3},
  [1705] = {.lex_state = 91, .external_lex_state = 3},
  [1706] = {.lex_state = 91, .external_lex_state = 3},
  [1707] = {.lex_state = 91, .external_lex_state = 3},
  [1708] = {.lex_state = 91, .external_lex_state = 3},
  [1709] = {.lex_state = 91, .external_lex_state = 3},
  [1710] = {.lex_state = 91, .external_lex_state = 3},
  [1711] = {.lex_state = 91, .external_lex_state = 3},
  [1712] = {.lex_state = 91, .external_lex_state = 3},
  [1713] = {.lex_state = 91, .external_lex_state = 3},
  [1714] = {.lex_state = 91, .external_lex_state = 3},
  [1715] = {.lex_state = 91, .external_lex_state = 3},
  [1716] = {.lex_state = 91, .external_lex_state = 3},
  [1717] = {.lex_state = 91, .external_lex_state = 3},
  [1718] = {.lex_state = 91, .external_lex_state = 3},
  [1719] = {.lex_state = 91, .external_lex_state = 3},
  [1720] = {.lex_state = 91, .external_lex_state = 3},
  [1721] = {.lex_state = 91, .external_lex_state = 3},
  [1722] = {.lex_state = 91, .external_lex_state = 3},
  [1723] = {.lex_state = 91, .external_lex_state = 3},
  [1724] = {.lex_state = 91, .external_lex_state = 3},
  [1725] = {.lex_state = 91, .external_lex_state = 3},
  [1726] = {.lex_state = 91, .external_lex_state = 3},
  [1727] = {.lex_state = 91, .external_lex_state = 3},
  [1728] = {.lex_state = 91, .external_lex_state = 3},
  [1729] = {.lex_state = 91, .external_lex_state = 3},
  [1730] = {.lex_state = 91, .external_lex_state = 3},
  [1731] = {.lex_state = 91, .external_lex_state = 3},
  [1732] = {.lex_state = 91, .external_lex_state = 3},
  [1733] = {.lex_state = 91, .external_lex_state = 4},
  [1734] = {.lex_state = 2, .external_lex_state = 3},
  [1735] = {.lex_state = 91, .external_lex_state = 4},
  [1736] = {.lex_state = 91, .external_lex_state = 6},
  [1737] = {.lex_state = 2, .external_lex_state = 3},
  [1738] = {.lex_state = 91, .external_lex_state = 12},
  [1739] = {.lex_state = 6},
  [1740] = {.lex_state = 91, .external_lex_state = 3},
  [1741] = {.lex_state = 2, .external_lex_state = 3},
  [1742] = {.lex_state = 91, .external_lex_state = 3},
  [1743] = {.lex_state = 91, .external_lex_state = 7},
  [1744] = {.lex_state = 91, .external_lex_state = 5},
  [1745] = {.lex_state = 91, .external_lex_state = 7},
  [1746] = {.lex_state = 91, .external_lex_state = 7},
  [1747] = {.lex_state = 1, .external_lex_state = 7},
  [1748] = {.lex_state = 91, .external_lex_state = 7},
  [1749] = {.lex_state = 3, .external_lex_state = 3},
  [1750] = {.lex_state = 91, .external_lex_state = 11},
  [1751] = {.lex_state = 91, .external_lex_state = 7},
  [1752] = {.lex_state = 3, .external_lex_state = 3},
  [1753] = {.lex_state = 3, .external_lex_state = 3},
  [1754] = {.lex_state = 91, .external_lex_state = 7},
  [1755] = {.lex_state = 91, .external_lex_state = 7},
  [1756] = {.lex_state = 3, .external_lex_state = 3},
  [1757] = {.lex_state = 91, .external_lex_state = 3},
  [1758] = {.lex_state = 91, .external_lex_state = 7},
  [1759] = {.lex_state = 91, .external_lex_state = 7},
  [1760] = {.lex_state = 3, .external_lex_state = 3},
  [1761] = {.lex_state = 91, .external_lex_state = 7},
  [1762] = {.lex_state = 91, .external_lex_state = 11},
  [1763] = {.lex_state = 3, .external_lex_state = 3},
  [1764] = {.lex_state = 91, .external_lex_state = 11},
  [1765] = {.lex_state = 3, .external_lex_state = 3},
  [1766] = {.lex_state = 91, .external_lex_state = 3},
  [1767] = {.lex_state = 3, .external_lex_state = 3},
  [1768] = {.lex_state = 1, .external_lex_state = 7},
  [1769] = {.lex_state = 6},
  [1770] = {.lex_state = 91, .external_lex_state = 3},
  [1771] = {.lex_state = 91, .external_lex_state = 7},
  [1772] = {.lex_state = 91, .external_lex_state = 5},
  [1773] = {.lex_state = 91, .external_lex_state = 7},
  [1774] = {.lex_state = 91, .external_lex_state = 7},
  [1775] = {.lex_state = 91, .external_lex_state = 7},
  [1776] = {.lex_state = 91, .external_lex_state = 7},
  [1777] = {.lex_state = 91, .external_lex_state = 7},
  [1778] = {.lex_state = 91, .external_lex_state = 7},
  [1779] = {.lex_state = 91, .external_lex_state = 7},
  [1780] = {.lex_state = 91, .external_lex_state = 7},
  [1781] = {.lex_state = 91, .external_lex_state = 7},
  [1782] = {.lex_state = 91, .external_lex_state = 7},
  [1783] = {.lex_state = 91, .external_lex_state = 7},
  [1784] = {.lex_state = 91, .external_lex_state = 7},
  [1785] = {.lex_state = 91, .external_lex_state = 7},
  [1786] = {.lex_state = 91, .external_lex_state = 7},
  [1787] = {.lex_state = 91, .external_lex_state = 7},
  [1788] = {.lex_state = 91, .external_lex_state = 7},
  [1789] = {.lex_state = 91, .external_lex_state = 7},
  [1790] = {.lex_state = 91, .external_lex_state = 7},
  [1791] = {.lex_state = 91, .external_lex_state = 7},
  [1792] = {.lex_state = 91, .external_lex_state = 7},
  [1793] = {.lex_state = 91, .external_lex_state = 7},
  [1794] = {.lex_state = 91, .external_lex_state = 7},
  [1795] = {.lex_state = 91, .external_lex_state = 7},
  [1796] = {.lex_state = 91, .external_lex_state = 7},
  [1797] = {.lex_state = 91, .external_lex_state = 7},
  [1798] = {.lex_state = 91, .external_lex_state = 7},
  [1799] = {.lex_state = 91, .external_lex_state = 7},
  [1800] = {.lex_state = 91, .external_lex_state = 7},
  [1801] = {.lex_state = 91, .external_lex_state = 7},
  [1802] = {.lex_state = 91, .external_lex_state = 7},
  [1803] = {.lex_state = 91, .external_lex_state = 7},
  [1804] = {.lex_state = 91, .external_lex_state = 7},
  [1805] = {.lex_state = 91, .external_lex_state = 7},
  [1806] = {.lex_state = 91, .external_lex_state = 7},
  [1807] = {.lex_state = 91, .external_lex_state = 7},
  [1808] = {.lex_state = 91, .external_lex_state = 7},
  [1809] = {.lex_state = 91, .external_lex_state = 7},
  [1810] = {.lex_state = 91, .external_lex_state = 7},
  [1811] = {.lex_state = 91, .external_lex_state = 7},
  [1812] = {.lex_state = 91, .external_lex_state = 7},
  [1813] = {.lex_state = 91, .external_lex_state = 7},
  [1814] = {.lex_state = 91, .external_lex_state = 7},
  [1815] = {.lex_state = 91, .external_lex_state = 7},
  [1816] = {.lex_state = 91, .external_lex_state = 7},
  [1817] = {.lex_state = 91, .external_lex_state = 7},
  [1818] = {.lex_state = 91, .external_lex_state = 7},
  [1819] = {.lex_state = 91, .external_lex_state = 7},
  [1820] = {.lex_state = 91, .external_lex_state = 7},
  [1821] = {.lex_state = 91, .external_lex_state = 7},
  [1822] = {.lex_state = 91, .external_lex_state = 7},
  [1823] = {.lex_state = 91, .external_lex_state = 7},
  [1824] = {.lex_state = 91, .external_lex_state = 7},
  [1825] = {.lex_state = 91, .external_lex_state = 7},
  [1826] = {.lex_state = 91, .external_lex_state = 7},
  [1827] = {.lex_state = 91, .external_lex_state = 7},
  [1828] = {.lex_state = 91, .external_lex_state = 7},
  [1829] = {.lex_state = 91, .external_lex_state = 7},
  [1830] = {.lex_state = 91, .external_lex_state = 7},
  [1831] = {.lex_state = 91, .external_lex_state = 7},
  [1832] = {.lex_state = 91, .external_lex_state = 7},
  [1833] = {.lex_state = 91, .external_lex_state = 7},
  [1834] = {.lex_state = 91, .external_lex_state = 7},
  [1835] = {.lex_state = 91, .external_lex_state = 7},
  [1836] = {.lex_state = 91, .external_lex_state = 7},
  [1837] = {.lex_state = 91, .external_lex_state = 7},
  [1838] = {.lex_state = 91, .external_lex_state = 7},
  [1839] = {.lex_state = 91, .external_lex_state = 7},
  [1840] = {.lex_state = 91, .external_lex_state = 7},
  [1841] = {.lex_state = 91, .external_lex_state = 7},
  [1842] = {.lex_state = 91, .external_lex_state = 7},
  [1843] = {.lex_state = 91, .external_lex_state = 7},
  [1844] = {.lex_state = 91, .external_lex_state = 7},
  [1845] = {.lex_state = 91, .external_lex_state = 7},
  [1846] = {.lex_state = 91, .external_lex_state = 7},
  [1847] = {.lex_state = 91, .external_lex_state = 7},
  [1848] = {.lex_state = 91, .external_lex_state = 7},
  [1849] = {.lex_state = 91, .external_lex_state = 7},
  [1850] = {.lex_state = 91, .external_lex_state = 7},
  [1851] = {.lex_state = 91, .external_lex_state = 7},
  [1852] = {.lex_state = 91, .external_lex_state = 7},
  [1853] = {.lex_state = 91, .external_lex_state = 7},
  [1854] = {.lex_state = 91, .external_lex_state = 7},
  [1855] = {.lex_state = 91, .external_lex_state = 7},
  [1856] = {.lex_state = 91, .external_lex_state = 7},
  [1857] = {.lex_state = 91, .external_lex_state = 7},
  [1858] = {.lex_state = 91, .external_lex_state = 7},
  [1859] = {.lex_state = 91, .external_lex_state = 7},
  [1860] = {.lex_state = 91, .external_lex_state = 7},
  [1861] = {.lex_state = 91, .external_lex_state = 7},
  [1862] = {.lex_state = 91, .external_lex_state = 7},
  [1863] = {.lex_state = 91, .external_lex_state = 7},
  [1864] = {.lex_state = 91, .external_lex_state = 7},
  [1865] = {.lex_state = 91, .external_lex_state = 7},
  [1866] = {.lex_state = 91, .external_lex_state = 7},
  [1867] = {.lex_state = 91, .external_lex_state = 7},
  [1868] = {.lex_state = 91, .external_lex_state = 7},
  [1869] = {.lex_state = 91, .external_lex_state = 7},
  [1870] = {.lex_state = 91, .external_lex_state = 7},
  [1871] = {.lex_state = 91, .external_lex_state = 7},
  [1872] = {.lex_state = 91, .external_lex_state = 7},
  [1873] = {.lex_state = 6},
  [1874] = {.lex_state = 91, .external_lex_state = 7},
  [1875] = {.lex_state = 91, .external_lex_state = 7},
  [1876] = {.lex_state = 91, .external_lex_state = 7},
  [1877] = {.lex_state = 91, .external_lex_state = 7},
  [1878] = {.lex_state = 91, .external_lex_state = 7},
  [1879] = {.lex_state = 91, .external_lex_state = 7},
  [1880] = {.lex_state = 91, .external_lex_state = 7},
  [1881] = {.lex_state = 91, .external_lex_state = 7},
  [1882] = {.lex_state = 91, .external_lex_state = 7},
  [1883] = {.lex_state = 91, .external_lex_state = 7},
  [1884] = {.lex_state = 91, .external_lex_state = 7},
  [1885] = {.lex_state = 91, .external_lex_state = 7},
  [1886] = {.lex_state = 91, .external_lex_state = 11},
  [1887] = {.lex_state = 91, .external_lex_state = 7},
  [1888] = {.lex_state = 91, .external_lex_state = 7},
  [1889] = {.lex_state = 91, .external_lex_state = 7},
  [1890] = {.lex_state = 91, .external_lex_state = 7},
  [1891] = {.lex_state = 91, .external_lex_state = 7},
  [1892] = {.lex_state = 6},
  [1893] = {.lex_state = 91, .external_lex_state = 7},
  [1894] = {.lex_state = 91, .external_lex_state = 7},
  [1895] = {.lex_state = 91, .external_lex_state = 7},
  [1896] = {.lex_state = 91, .external_lex_state = 7},
  [1897] = {.lex_state = 91, .external_lex_state = 7},
  [1898] = {.lex_state = 91, .external_lex_state = 7},
  [1899] = {.lex_state = 91, .external_lex_state = 7},
  [1900] = {.lex_state = 91, .external_lex_state = 7},
  [1901] = {.lex_state = 91, .external_lex_state = 7},
  [1902] = {.lex_state = 91, .external_lex_state = 7},
  [1903] = {.lex_state = 91, .external_lex_state = 7},
  [1904] = {.lex_state = 91, .external_lex_state = 7},
  [1905] = {.lex_state = 91, .external_lex_state = 7},
  [1906] = {.lex_state = 91, .external_lex_state = 7},
  [1907] = {.lex_state = 91, .external_lex_state = 7},
  [1908] = {.lex_state = 91, .external_lex_state = 7},
  [1909] = {.lex_state = 91, .external_lex_state = 7},
  [1910] = {.lex_state = 91, .external_lex_state = 7},
  [1911] = {.lex_state = 91, .external_lex_state = 7},
  [1912] = {.lex_state = 91, .external_lex_state = 7},
  [1913] = {.lex_state = 91, .external_lex_state = 7},
  [1914] = {.lex_state = 91, .external_lex_state = 7},
  [1915] = {.lex_state = 91, .external_lex_state = 7},
  [1916] = {.lex_state = 91, .external_lex_state = 7},
  [1917] = {.lex_state = 91, .external_lex_state = 7},
  [1918] = {.lex_state = 91, .external_lex_state = 7},
  [1919] = {.lex_state = 91, .external_lex_state = 7},
  [1920] = {.lex_state = 91, .external_lex_state = 7},
  [1921] = {.lex_state = 91, .external_lex_state = 7},
  [1922] = {.lex_state = 91, .external_lex_state = 7},
  [1923] = {.lex_state = 91, .external_lex_state = 7},
  [1924] = {.lex_state = 91, .external_lex_state = 7},
  [1925] = {.lex_state = 91, .external_lex_state = 7},
  [1926] = {.lex_state = 91, .external_lex_state = 7},
  [1927] = {.lex_state = 91, .external_lex_state = 7},
  [1928] = {.lex_state = 91, .external_lex_state = 7},
  [1929] = {.lex_state = 91, .external_lex_state = 7},
  [1930] = {.lex_state = 91, .external_lex_state = 7},
  [1931] = {.lex_state = 91, .external_lex_state = 7},
  [1932] = {.lex_state = 91, .external_lex_state = 7},
  [1933] = {.lex_state = 91, .external_lex_state = 7},
  [1934] = {.lex_state = 91, .external_lex_state = 7},
  [1935] = {.lex_state = 91, .external_lex_state = 7},
  [1936] = {.lex_state = 91, .external_lex_state = 7},
  [1937] = {.lex_state = 91, .external_lex_state = 7},
  [1938] = {.lex_state = 91, .external_lex_state = 7},
  [1939] = {.lex_state = 91, .external_lex_state = 3},
  [1940] = {.lex_state = 91, .external_lex_state = 7},
  [1941] = {.lex_state = 91, .external_lex_state = 7},
  [1942] = {.lex_state = 91, .external_lex_state = 7},
  [1943] = {.lex_state = 91, .external_lex_state = 7},
  [1944] = {.lex_state = 91, .external_lex_state = 7},
  [1945] = {.lex_state = 91, .external_lex_state = 7},
  [1946] = {.lex_state = 91, .external_lex_state = 7},
  [1947] = {.lex_state = 91, .external_lex_state = 7},
  [1948] = {.lex_state = 91, .external_lex_state = 11},
  [1949] = {.lex_state = 2, .external_lex_state = 14},
  [1950] = {.lex_state = 91, .external_lex_state = 11},
  [1951] = {.lex_state = 91, .external_lex_state = 11},
  [1952] = {.lex_state = 91, .external_lex_state = 11},
  [1953] = {.lex_state = 91, .external_lex_state = 11},
  [1954] = {.lex_state = 2, .external_lex_state = 14},
  [1955] = {.lex_state = 91, .external_lex_state = 11},
  [1956] = {.lex_state = 91, .external_lex_state = 11},
  [1957] = {.lex_state = 91, .external_lex_state = 11},
  [1958] = {.lex_state = 91, .external_lex_state = 11},
  [1959] = {.lex_state = 91, .external_lex_state = 11},
  [1960] = {.lex_state = 91, .external_lex_state = 11},
  [1961] = {.lex_state = 91, .external_lex_state = 11},
  [1962] = {.lex_state = 91, .external_lex_state = 11},
  [1963] = {.lex_state = 91, .external_lex_state = 11},
  [1964] = {.lex_state = 91, .external_lex_state = 11},
  [1965] = {.lex_state = 91, .external_lex_state = 11},
  [1966] = {.lex_state = 91, .external_lex_state = 11},
  [1967] = {.lex_state = 91, .external_lex_state = 11},
  [1968] = {.lex_state = 91, .external_lex_state = 11},
  [1969] = {.lex_state = 91, .external_lex_state = 11},
  [1970] = {.lex_state = 91, .external_lex_state = 11},
  [1971] = {.lex_state = 91, .external_lex_state = 11},
  [1972] = {.lex_state = 91, .external_lex_state = 11},
  [1973] = {.lex_state = 91, .external_lex_state = 11},
  [1974] = {.lex_state = 91, .external_lex_state = 11},
  [1975] = {.lex_state = 2, .external_lex_state = 14},
  [1976] = {.lex_state = 2, .external_lex_state = 14},
  [1977] = {.lex_state = 2, .external_lex_state = 14},
  [1978] = {.lex_state = 91, .external_lex_state = 11},
  [1979] = {.lex_state = 91, .external_lex_state = 11},
  [1980] = {.lex_state = 91, .external_lex_state = 11},
  [1981] = {.lex_state = 2, .external_lex_state = 14},
  [1982] = {.lex_state = 2, .external_lex_state = 7},
  [1983] = {.lex_state = 2, .external_lex_state = 7},
  [1984] = {.lex_state = 2, .external_lex_state = 14},
  [1985] = {.lex_state = 91, .external_lex_state = 11},
  [1986] = {.lex_state = 91, .external_lex_state = 11},
  [1987] = {.lex_state = 2, .external_lex_state = 7},
  [1988] = {.lex_state = 91, .external_lex_state = 11},
  [1989] = {.lex_state = 91, .external_lex_state = 11},
  [1990] = {.lex_state = 91, .external_lex_state = 11},
  [1991] = {.lex_state = 91, .external_lex_state = 11},
  [1992] = {.lex_state = 91, .external_lex_state = 11},
  [1993] = {.lex_state = 91, .external_lex_state = 11},
  [1994] = {.lex_state = 91, .external_lex_state = 11},
  [1995] = {.lex_state = 91, .external_lex_state = 11},
  [1996] = {.lex_state = 91, .external_lex_state = 11},
  [1997] = {.lex_state = 91, .external_lex_state = 11},
  [1998] = {.lex_state = 2, .external_lex_state = 7},
  [1999] = {.lex_state = 2, .external_lex_state = 14},
  [2000] = {.lex_state = 91, .external_lex_state = 11},
  [2001] = {.lex_state = 91, .external_lex_state = 11},
  [2002] = {.lex_state = 91, .external_lex_state = 11},
  [2003] = {.lex_state = 91, .external_lex_state = 11},
  [2004] = {.lex_state = 91, .external_lex_state = 11},
  [2005] = {.lex_state = 91, .external_lex_state = 11},
  [2006] = {.lex_state = 91, .external_lex_state = 11},
  [2007] = {.lex_state = 91, .external_lex_state = 11},
  [2008] = {.lex_state = 91, .external_lex_state = 11},
  [2009] = {.lex_state = 91, .external_lex_state = 11},
  [2010] = {.lex_state = 91, .external_lex_state = 11},
  [2011] = {.lex_state = 91, .external_lex_state = 11},
  [2012] = {.lex_state = 91, .external_lex_state = 11},
  [2013] = {.lex_state = 91, .external_lex_state = 11},
  [2014] = {.lex_state = 2, .external_lex_state = 14},
  [2015] = {.lex_state = 2, .external_lex_state = 14},
  [2016] = {.lex_state = 6},
  [2017] = {.lex_state = 2, .external_lex_state = 7},
  [2018] = {.lex_state = 2, .external_lex_state = 14},
  [2019] = {.lex_state = 2, .external_lex_state = 14},
  [2020] = {.lex_state = 91, .external_lex_state = 11},
  [2021] = {.lex_state = 91, .external_lex_state = 11},
  [2022] = {.lex_state = 91, .external_lex_state = 11},
  [2023] = {.lex_state = 2, .external_lex_state = 14},
  [2024] = {.lex_state = 2, .external_lex_state = 14},
  [2025] = {.lex_state = 2, .external_lex_state = 7},
  [2026] = {.lex_state = 91, .external_lex_state = 11},
  [2027] = {.lex_state = 91, .external_lex_state = 11},
  [2028] = {.lex_state = 91, .external_lex_state = 11},
  [2029] = {.lex_state = 91, .external_lex_state = 11},
  [2030] = {.lex_state = 2, .external_lex_state = 14},
  [2031] = {.lex_state = 2, .external_lex_state = 14},
  [2032] = {.lex_state = 2, .external_lex_state = 14},
  [2033] = {.lex_state = 2, .external_lex_state = 14},
  [2034] = {.lex_state = 91, .external_lex_state = 11},
  [2035] = {.lex_state = 91, .external_lex_state = 11},
  [2036] = {.lex_state = 91, .external_lex_state = 11},
  [2037] = {.lex_state = 2, .external_lex_state = 14},
  [2038] = {.lex_state = 91, .external_lex_state = 11},
  [2039] = {.lex_state = 91, .external_lex_state = 11},
  [2040] = {.lex_state = 91, .external_lex_state = 11},
  [2041] = {.lex_state = 91, .external_lex_state = 11},
  [2042] = {.lex_state = 2, .external_lex_state = 14},
  [2043] = {.lex_state = 2, .external_lex_state = 14},
  [2044] = {.lex_state = 2, .external_lex_state = 14},
  [2045] = {.lex_state = 2, .external_lex_state = 14},
  [2046] = {.lex_state = 2, .external_lex_state = 7},
  [2047] = {.lex_state = 2, .external_lex_state = 7},
  [2048] = {.lex_state = 91, .external_lex_state = 11},
  [2049] = {.lex_state = 91, .external_lex_state = 11},
  [2050] = {.lex_state = 91, .external_lex_state = 11},
  [2051] = {.lex_state = 91, .external_lex_state = 11},
  [2052] = {.lex_state = 2, .external_lex_state = 14},
  [2053] = {.lex_state = 2, .external_lex_state = 14},
  [2054] = {.lex_state = 91, .external_lex_state = 11},
  [2055] = {.lex_state = 91, .external_lex_state = 11},
  [2056] = {.lex_state = 91, .external_lex_state = 11},
  [2057] = {.lex_state = 91, .external_lex_state = 11},
  [2058] = {.lex_state = 2, .external_lex_state = 14},
  [2059] = {.lex_state = 2, .external_lex_state = 14},
  [2060] = {.lex_state = 2, .external_lex_state = 7},
  [2061] = {.lex_state = 2, .external_lex_state = 7},
  [2062] = {.lex_state = 2, .external_lex_state = 7},
  [2063] = {.lex_state = 2, .external_lex_state = 7},
  [2064] = {.lex_state = 2, .external_lex_state = 7},
  [2065] = {.lex_state = 2, .external_lex_state = 7},
  [2066] = {.lex_state = 2, .external_lex_state = 7},
  [2067] = {.lex_state = 2, .external_lex_state = 7},
  [2068] = {.lex_state = 2, .external_lex_state = 7},
  [2069] = {.lex_state = 2, .external_lex_state = 7},
  [2070] = {.lex_state = 2, .external_lex_state = 7},
  [2071] = {.lex_state = 2, .external_lex_state = 7},
  [2072] = {.lex_state = 2, .external_lex_state = 7},
  [2073] = {.lex_state = 2, .external_lex_state = 7},
  [2074] = {.lex_state = 2, .external_lex_state = 7},
  [2075] = {.lex_state = 91, .external_lex_state = 11},
  [2076] = {.lex_state = 91, .external_lex_state = 11},
  [2077] = {.lex_state = 91, .external_lex_state = 11},
  [2078] = {.lex_state = 2, .external_lex_state = 7},
  [2079] = {.lex_state = 2, .external_lex_state = 7},
  [2080] = {.lex_state = 2, .external_lex_state = 7},
  [2081] = {.lex_state = 2, .external_lex_state = 7},
  [2082] = {.lex_state = 2, .external_lex_state = 7},
  [2083] = {.lex_state = 2, .external_lex_state = 7},
  [2084] = {.lex_state = 91, .external_lex_state = 11},
  [2085] = {.lex_state = 2, .external_lex_state = 14},
  [2086] = {.lex_state = 2, .external_lex_state = 14},
  [2087] = {.lex_state = 2, .external_lex_state = 14},
  [2088] = {.lex_state = 91, .external_lex_state = 11},
  [2089] = {.lex_state = 2, .external_lex_state = 7},
  [2090] = {.lex_state = 2, .external_lex_state = 14},
  [2091] = {.lex_state = 2, .external_lex_state = 14},
  [2092] = {.lex_state = 2, .external_lex_state = 14},
  [2093] = {.lex_state = 2, .external_lex_state = 14},
  [2094] = {.lex_state = 5, .external_lex_state = 16},
  [2095] = {.lex_state = 2, .external_lex_state = 7},
  [2096] = {.lex_state = 2, .external_lex_state = 7},
  [2097] = {.lex_state = 2, .external_lex_state = 7},
  [2098] = {.lex_state = 2, .external_lex_state = 7},
  [2099] = {.lex_state = 2, .external_lex_state = 14},
  [2100] = {.lex_state = 2, .external_lex_state = 14},
  [2101] = {.lex_state = 2, .external_lex_state = 7},
  [2102] = {.lex_state = 2, .external_lex_state = 7},
  [2103] = {.lex_state = 2, .external_lex_state = 7},
  [2104] = {.lex_state = 2, .external_lex_state = 7},
  [2105] = {.lex_state = 2, .external_lex_state = 14},
  [2106] = {.lex_state = 2, .external_lex_state = 14},
  [2107] = {.lex_state = 2, .external_lex_state = 7},
  [2108] = {.lex_state = 91, .external_lex_state = 3},
  [2109] = {.lex_state = 6},
  [2110] = {.lex_state = 2, .external_lex_state = 14},
  [2111] = {.lex_state = 2, .external_lex_state = 7},
  [2112] = {.lex_state = 2, .external_lex_state = 14},
  [2113] = {.lex_state = 2, .external_lex_state = 7},
  [2114] = {.lex_state = 2, .external_lex_state = 7},
  [2115] = {.lex_state = 2, .external_lex_state = 7},
  [2116] = {.lex_state = 2, .external_lex_state = 14},
  [2117] = {.lex_state = 2, .external_lex_state = 7},
  [2118] = {.lex_state = 2, .external_lex_state = 7},
  [2119] = {.lex_state = 2, .external_lex_state = 14},
  [2120] = {.lex_state = 2, .external_lex_state = 7},
  [2121] = {.lex_state = 2, .external_lex_state = 14},
  [2122] = {.lex_state = 2, .external_lex_state = 14},
  [2123] = {.lex_state = 2, .external_lex_state = 14},
  [2124] = {.lex_state = 2, .external_lex_state = 14},
  [2125] = {.lex_state = 2, .external_lex_state = 14},
  [2126] = {.lex_state = 2, .external_lex_state = 14},
  [2127] = {.lex_state = 2, .external_lex_state = 14},
  [2128] = {.lex_state = 2, .external_lex_state = 14},
  [2129] = {.lex_state = 2, .external_lex_state = 14},
  [2130] = {.lex_state = 2, .external_lex_state = 7},
  [2131] = {.lex_state = 2, .external_lex_state = 14},
  [2132] = {.lex_state = 2, .external_lex_state = 7},
  [2133] = {.lex_state = 2, .external_lex_state = 7},
  [2134] = {.lex_state = 2, .external_lex_state = 7},
  [2135] = {.lex_state = 91, .external_lex_state = 3},
  [2136] = {.lex_state = 2, .external_lex_state = 7},
  [2137] = {.lex_state = 2, .external_lex_state = 7},
  [2138] = {.lex_state = 2, .external_lex_state = 7},
  [2139] = {.lex_state = 2, .external_lex_state = 7},
  [2140] = {.lex_state = 2, .external_lex_state = 7},
  [2141] = {.lex_state = 2, .external_lex_state = 7},
  [2142] = {.lex_state = 2, .external_lex_state = 7},
  [2143] = {.lex_state = 2, .external_lex_state = 7},
  [2144] = {.lex_state = 2, .external_lex_state = 7},
  [2145] = {.lex_state = 2, .external_lex_state = 14},
  [2146] = {.lex_state = 2, .external_lex_state = 14},
  [2147] = {.lex_state = 2, .external_lex_state = 14},
  [2148] = {.lex_state = 2, .external_lex_state = 14},
  [2149] = {.lex_state = 2, .external_lex_state = 14},
  [2150] = {.lex_state = 5, .external_lex_state = 16},
  [2151] = {.lex_state = 91, .external_lex_state = 12},
  [2152] = {.lex_state = 2, .external_lex_state = 14},
  [2153] = {.lex_state = 2, .external_lex_state = 14},
  [2154] = {.lex_state = 91, .external_lex_state = 3},
  [2155] = {.lex_state = 2, .external_lex_state = 14},
  [2156] = {.lex_state = 2, .external_lex_state = 14},
  [2157] = {.lex_state = 2, .external_lex_state = 7},
  [2158] = {.lex_state = 2, .external_lex_state = 7},
  [2159] = {.lex_state = 2, .external_lex_state = 7},
  [2160] = {.lex_state = 91, .external_lex_state = 3},
  [2161] = {.lex_state = 2, .external_lex_state = 14},
  [2162] = {.lex_state = 2, .external_lex_state = 7},
  [2163] = {.lex_state = 2, .external_lex_state = 7},
  [2164] = {.lex_state = 2, .external_lex_state = 14},
  [2165] = {.lex_state = 2, .external_lex_state = 7},
  [2166] = {.lex_state = 2, .external_lex_state = 14},
  [2167] = {.lex_state = 2, .external_lex_state = 14},
  [2168] = {.lex_state = 2, .external_lex_state = 14},
  [2169] = {.lex_state = 2, .external_lex_state = 14},
  [2170] = {.lex_state = 2, .external_lex_state = 14},
  [2171] = {.lex_state = 2, .external_lex_state = 14},
  [2172] = {.lex_state = 2, .external_lex_state = 14},
  [2173] = {.lex_state = 91, .external_lex_state = 3},
  [2174] = {.lex_state = 2, .external_lex_state = 14},
  [2175] = {.lex_state = 91, .external_lex_state = 3},
  [2176] = {.lex_state = 2, .external_lex_state = 7},
  [2177] = {.lex_state = 91, .external_lex_state = 3},
  [2178] = {.lex_state = 2, .external_lex_state = 7},
  [2179] = {.lex_state = 2, .external_lex_state = 7},
  [2180] = {.lex_state = 2, .external_lex_state = 14},
  [2181] = {.lex_state = 91, .external_lex_state = 6},
  [2182] = {.lex_state = 2, .external_lex_state = 14},
  [2183] = {.lex_state = 2, .external_lex_state = 14},
  [2184] = {.lex_state = 2, .external_lex_state = 14},
  [2185] = {.lex_state = 2, .external_lex_state = 7},
  [2186] = {.lex_state = 2, .external_lex_state = 7},
  [2187] = {.lex_state = 2, .external_lex_state = 14},
  [2188] = {.lex_state = 2, .external_lex_state = 14},
  [2189] = {.lex_state = 2, .external_lex_state = 14},
  [2190] = {.lex_state = 2, .external_lex_state = 14},
  [2191] = {.lex_state = 2, .external_lex_state = 14},
  [2192] = {.lex_state = 2, .external_lex_state = 14},
  [2193] = {.lex_state = 91, .external_lex_state = 3},
  [2194] = {.lex_state = 2, .external_lex_state = 14},
  [2195] = {.lex_state = 2, .external_lex_state = 7},
  [2196] = {.lex_state = 2, .external_lex_state = 7},
  [2197] = {.lex_state = 2, .external_lex_state = 7},
  [2198] = {.lex_state = 2, .external_lex_state = 7},
  [2199] = {.lex_state = 2, .external_lex_state = 7},
  [2200] = {.lex_state = 2, .external_lex_state = 14},
  [2201] = {.lex_state = 2, .external_lex_state = 7},
  [2202] = {.lex_state = 2, .external_lex_state = 7},
  [2203] = {.lex_state = 2, .external_lex_state = 14},
  [2204] = {.lex_state = 91, .external_lex_state = 12},
  [2205] = {.lex_state = 2, .external_lex_state = 7},
  [2206] = {.lex_state = 2, .external_lex_state = 7},
  [2207] = {.lex_state = 2, .external_lex_state = 7},
  [2208] = {.lex_state = 2, .external_lex_state = 7},
  [2209] = {.lex_state = 2, .external_lex_state = 7},
  [2210] = {.lex_state = 2, .external_lex_state = 7},
  [2211] = {.lex_state = 2, .external_lex_state = 7},
  [2212] = {.lex_state = 91, .external_lex_state = 7},
  [2213] = {.lex_state = 2, .external_lex_state = 7},
  [2214] = {.lex_state = 2, .external_lex_state = 7},
  [2215] = {.lex_state = 2, .external_lex_state = 14},
  [2216] = {.lex_state = 91, .external_lex_state = 3},
  [2217] = {.lex_state = 91, .external_lex_state = 9},
  [2218] = {.lex_state = 3, .external_lex_state = 7},
  [2219] = {.lex_state = 91, .external_lex_state = 9},
  [2220] = {.lex_state = 91, .external_lex_state = 9},
  [2221] = {.lex_state = 91, .external_lex_state = 9},
  [2222] = {.lex_state = 1, .external_lex_state = 9},
  [2223] = {.lex_state = 91, .external_lex_state = 9},
  [2224] = {.lex_state = 91, .external_lex_state = 9},
  [2225] = {.lex_state = 91, .external_lex_state = 9},
  [2226] = {.lex_state = 1, .external_lex_state = 9},
  [2227] = {.lex_state = 91, .external_lex_state = 9},
  [2228] = {.lex_state = 91, .external_lex_state = 9},
  [2229] = {.lex_state = 5, .external_lex_state = 16},
  [2230] = {.lex_state = 91, .external_lex_state = 9},
  [2231] = {.lex_state = 3, .external_lex_state = 7},
  [2232] = {.lex_state = 91, .external_lex_state = 9},
  [2233] = {.lex_state = 91, .external_lex_state = 9},
  [2234] = {.lex_state = 91, .external_lex_state = 9},
  [2235] = {.lex_state = 91, .external_lex_state = 9},
  [2236] = {.lex_state = 91, .external_lex_state = 9},
  [2237] = {.lex_state = 91, .external_lex_state = 9},
  [2238] = {.lex_state = 91, .external_lex_state = 9},
  [2239] = {.lex_state = 91, .external_lex_state = 9},
  [2240] = {.lex_state = 91, .external_lex_state = 9},
  [2241] = {.lex_state = 91, .external_lex_state = 9},
  [2242] = {.lex_state = 91, .external_lex_state = 9},
  [2243] = {.lex_state = 91, .external_lex_state = 9},
  [2244] = {.lex_state = 91, .external_lex_state = 9},
  [2245] = {.lex_state = 91, .external_lex_state = 9},
  [2246] = {.lex_state = 91, .external_lex_state = 9},
  [2247] = {.lex_state = 91, .external_lex_state = 9},
  [2248] = {.lex_state = 91, .external_lex_state = 9},
  [2249] = {.lex_state = 91, .external_lex_state = 9},
  [2250] = {.lex_state = 91, .external_lex_state = 9},
  [2251] = {.lex_state = 91, .external_lex_state = 9},
  [2252] = {.lex_state = 91, .external_lex_state = 9},
  [2253] = {.lex_state = 91, .external_lex_state = 9},
  [2254] = {.lex_state = 91, .external_lex_state = 9},
  [2255] = {.lex_state = 91, .external_lex_state = 9},
  [2256] = {.lex_state = 91, .external_lex_state = 9},
  [2257] = {.lex_state = 91, .external_lex_state = 9},
  [2258] = {.lex_state = 91, .external_lex_state = 9},
  [2259] = {.lex_state = 91, .external_lex_state = 9},
  [2260] = {.lex_state = 91, .external_lex_state = 9},
  [2261] = {.lex_state = 91, .external_lex_state = 9},
  [2262] = {.lex_state = 91, .external_lex_state = 9},
  [2263] = {.lex_state = 91, .external_lex_state = 9},
  [2264] = {.lex_state = 91, .external_lex_state = 9},
  [2265] = {.lex_state = 91, .external_lex_state = 9},
  [2266] = {.lex_state = 91, .external_lex_state = 9},
  [2267] = {.lex_state = 91, .external_lex_state = 9},
  [2268] = {.lex_state = 91, .external_lex_state = 9},
  [2269] = {.lex_state = 91, .external_lex_state = 9},
  [2270] = {.lex_state = 91, .external_lex_state = 9},
  [2271] = {.lex_state = 91, .external_lex_state = 9},
  [2272] = {.lex_state = 91, .external_lex_state = 9},
  [2273] = {.lex_state = 91, .external_lex_state = 9},
  [2274] = {.lex_state = 91, .external_lex_state = 11},
  [2275] = {.lex_state = 91, .external_lex_state = 9},
  [2276] = {.lex_state = 91, .external_lex_state = 9},
  [2277] = {.lex_state = 91, .external_lex_state = 9},
  [2278] = {.lex_state = 91, .external_lex_state = 9},
  [2279] = {.lex_state = 91, .external_lex_state = 9},
  [2280] = {.lex_state = 91, .external_lex_state = 9},
  [2281] = {.lex_state = 91, .external_lex_state = 9},
  [2282] = {.lex_state = 91, .external_lex_state = 9},
  [2283] = {.lex_state = 91, .external_lex_state = 9},
  [2284] = {.lex_state = 91, .external_lex_state = 9},
  [2285] = {.lex_state = 91, .external_lex_state = 9},
  [2286] = {.lex_state = 91, .external_lex_state = 9},
  [2287] = {.lex_state = 91, .external_lex_state = 9},
  [2288] = {.lex_state = 91, .external_lex_state = 9},
  [2289] = {.lex_state = 91, .external_lex_state = 9},
  [2290] = {.lex_state = 91, .external_lex_state = 9},
  [2291] = {.lex_state = 91, .external_lex_state = 9},
  [2292] = {.lex_state = 91, .external_lex_state = 9},
  [2293] = {.lex_state = 91, .external_lex_state = 9},
  [2294] = {.lex_state = 91, .external_lex_state = 9},
  [2295] = {.lex_state = 91, .external_lex_state = 9},
  [2296] = {.lex_state = 91, .external_lex_state = 9},
  [2297] = {.lex_state = 91, .external_lex_state = 9},
  [2298] = {.lex_state = 91, .external_lex_state = 9},
  [2299] = {.lex_state = 91, .external_lex_state = 9},
  [2300] = {.lex_state = 91, .external_lex_state = 9},
  [2301] = {.lex_state = 91, .external_lex_state = 9},
  [2302] = {.lex_state = 91, .external_lex_state = 9},
  [2303] = {.lex_state = 91, .external_lex_state = 9},
  [2304] = {.lex_state = 91, .external_lex_state = 9},
  [2305] = {.lex_state = 91, .external_lex_state = 9},
  [2306] = {.lex_state = 91, .external_lex_state = 9},
  [2307] = {.lex_state = 91, .external_lex_state = 9},
  [2308] = {.lex_state = 91, .external_lex_state = 9},
  [2309] = {.lex_state = 91, .external_lex_state = 9},
  [2310] = {.lex_state = 91, .external_lex_state = 9},
  [2311] = {.lex_state = 91, .external_lex_state = 9},
  [2312] = {.lex_state = 91, .external_lex_state = 9},
  [2313] = {.lex_state = 91, .external_lex_state = 9},
  [2314] = {.lex_state = 91, .external_lex_state = 9},
  [2315] = {.lex_state = 91, .external_lex_state = 9},
  [2316] = {.lex_state = 91, .external_lex_state = 9},
  [2317] = {.lex_state = 91, .external_lex_state = 9},
  [2318] = {.lex_state = 91, .external_lex_state = 9},
  [2319] = {.lex_state = 91, .external_lex_state = 9},
  [2320] = {.lex_state = 91, .external_lex_state = 9},
  [2321] = {.lex_state = 91, .external_lex_state = 9},
  [2322] = {.lex_state = 91, .external_lex_state = 9},
  [2323] = {.lex_state = 91, .external_lex_state = 9},
  [2324] = {.lex_state = 91, .external_lex_state = 9},
  [2325] = {.lex_state = 91, .external_lex_state = 9},
  [2326] = {.lex_state = 91, .external_lex_state = 9},
  [2327] = {.lex_state = 91, .external_lex_state = 9},
  [2328] = {.lex_state = 91, .external_lex_state = 9},
  [2329] = {.lex_state = 91, .external_lex_state = 9},
  [2330] = {.lex_state = 91, .external_lex_state = 9},
  [2331] = {.lex_state = 91, .external_lex_state = 9},
  [2332] = {.lex_state = 91, .external_lex_state = 9},
  [2333] = {.lex_state = 91, .external_lex_state = 9},
  [2334] = {.lex_state = 91, .external_lex_state = 9},
  [2335] = {.lex_state = 91, .external_lex_state = 9},
  [2336] = {.lex_state = 91, .external_lex_state = 9},
  [2337] = {.lex_state = 91, .external_lex_state = 9},
  [2338] = {.lex_state = 91, .external_lex_state = 9},
  [2339] = {.lex_state = 91, .external_lex_state = 9},
  [2340] = {.lex_state = 91, .external_lex_state = 9},
  [2341] = {.lex_state = 91, .external_lex_state = 9},
  [2342] = {.lex_state = 91, .external_lex_state = 9},
  [2343] = {.lex_state = 91, .external_lex_state = 9},
  [2344] = {.lex_state = 91, .external_lex_state = 9},
  [2345] = {.lex_state = 91, .external_lex_state = 9},
  [2346] = {.lex_state = 91, .external_lex_state = 9},
  [2347] = {.lex_state = 91, .external_lex_state = 9},
  [2348] = {.lex_state = 91, .external_lex_state = 9},
  [2349] = {.lex_state = 91, .external_lex_state = 9},
  [2350] = {.lex_state = 91, .external_lex_state = 9},
  [2351] = {.lex_state = 91, .external_lex_state = 9},
  [2352] = {.lex_state = 91, .external_lex_state = 9},
  [2353] = {.lex_state = 91, .external_lex_state = 9},
  [2354] = {.lex_state = 91, .external_lex_state = 9},
  [2355] = {.lex_state = 91, .external_lex_state = 9},
  [2356] = {.lex_state = 91, .external_lex_state = 9},
  [2357] = {.lex_state = 91, .external_lex_state = 9},
  [2358] = {.lex_state = 91, .external_lex_state = 9},
  [2359] = {.lex_state = 91, .external_lex_state = 9},
  [2360] = {.lex_state = 91, .external_lex_state = 9},
  [2361] = {.lex_state = 91, .external_lex_state = 9},
  [2362] = {.lex_state = 91, .external_lex_state = 9},
  [2363] = {.lex_state = 91, .external_lex_state = 9},
  [2364] = {.lex_state = 91, .external_lex_state = 9},
  [2365] = {.lex_state = 91, .external_lex_state = 9},
  [2366] = {.lex_state = 91, .external_lex_state = 9},
  [2367] = {.lex_state = 91, .external_lex_state = 9},
  [2368] = {.lex_state = 91, .external_lex_state = 9},
  [2369] = {.lex_state = 91, .external_lex_state = 9},
  [2370] = {.lex_state = 91, .external_lex_state = 9},
  [2371] = {.lex_state = 91, .external_lex_state = 9},
  [2372] = {.lex_state = 91, .external_lex_state = 9},
  [2373] = {.lex_state = 91, .external_lex_state = 9},
  [2374] = {.lex_state = 91, .external_lex_state = 8},
  [2375] = {.lex_state = 91, .external_lex_state = 9},
  [2376] = {.lex_state = 91, .external_lex_state = 9},
  [2377] = {.lex_state = 91, .external_lex_state = 9},
  [2378] = {.lex_state = 91, .external_lex_state = 9},
  [2379] = {.lex_state = 91, .external_lex_state = 9},
  [2380] = {.lex_state = 91, .external_lex_state = 9},
  [2381] = {.lex_state = 91, .external_lex_state = 9},
  [2382] = {.lex_state = 91, .external_lex_state = 9},
  [2383] = {.lex_state = 91, .external_lex_state = 9},
  [2384] = {.lex_state = 91, .external_lex_state = 9},
  [2385] = {.lex_state = 91, .external_lex_state = 9},
  [2386] = {.lex_state = 91, .external_lex_state = 9},
  [2387] = {.lex_state = 91, .external_lex_state = 9},
  [2388] = {.lex_state = 91, .external_lex_state = 9},
  [2389] = {.lex_state = 91, .external_lex_state = 9},
  [2390] = {.lex_state = 91, .external_lex_state = 9},
  [2391] = {.lex_state = 91, .external_lex_state = 9},
  [2392] = {.lex_state = 91, .external_lex_state = 9},
  [2393] = {.lex_state = 91, .external_lex_state = 9},
  [2394] = {.lex_state = 91, .external_lex_state = 9},
  [2395] = {.lex_state = 91, .external_lex_state = 9},
  [2396] = {.lex_state = 91, .external_lex_state = 9},
  [2397] = {.lex_state = 91, .external_lex_state = 9},
  [2398] = {.lex_state = 91, .external_lex_state = 9},
  [2399] = {.lex_state = 91, .external_lex_state = 9},
  [2400] = {.lex_state = 91, .external_lex_state = 9},
  [2401] = {.lex_state = 91, .external_lex_state = 9},
  [2402] = {.lex_state = 91, .external_lex_state = 9},
  [2403] = {.lex_state = 91, .external_lex_state = 9},
  [2404] = {.lex_state = 91, .external_lex_state = 9},
  [2405] = {.lex_state = 91, .external_lex_state = 9},
  [2406] = {.lex_state = 2, .external_lex_state = 7},
  [2407] = {.lex_state = 91, .external_lex_state = 7},
  [2408] = {.lex_state = 91, .external_lex_state = 7},
  [2409] = {.lex_state = 91, .external_lex_state = 7},
  [2410] = {.lex_state = 91, .external_lex_state = 7},
  [2411] = {.lex_state = 91, .external_lex_state = 7},
  [2412] = {.lex_state = 91, .external_lex_state = 7},
  [2413] = {.lex_state = 91, .external_lex_state = 7},
  [2414] = {.lex_state = 91, .external_lex_state = 7},
  [2415] = {.lex_state = 6},
  [2416] = {.lex_state = 2, .external_lex_state = 7},
  [2417] = {.lex_state = 91, .external_lex_state = 10},
  [2418] = {.lex_state = 91, .external_lex_state = 17},
  [2419] = {.lex_state = 91, .external_lex_state = 17},
  [2420] = {.lex_state = 91, .external_lex_state = 17},
  [2421] = {.lex_state = 91, .external_lex_state = 7},
  [2422] = {.lex_state = 91, .external_lex_state = 17},
  [2423] = {.lex_state = 91, .external_lex_state = 17},
  [2424] = {.lex_state = 91, .external_lex_state = 17},
  [2425] = {.lex_state = 91, .external_lex_state = 17},
  [2426] = {.lex_state = 91, .external_lex_state = 17},
  [2427] = {.lex_state = 91, .external_lex_state = 8},
  [2428] = {.lex_state = 91, .external_lex_state = 15},
  [2429] = {.lex_state = 91, .external_lex_state = 14},
  [2430] = {.lex_state = 2, .external_lex_state = 7},
  [2431] = {.lex_state = 91, .external_lex_state = 14},
  [2432] = {.lex_state = 91, .external_lex_state = 15},
  [2433] = {.lex_state = 91, .external_lex_state = 14},
  [2434] = {.lex_state = 91, .external_lex_state = 15},
  [2435] = {.lex_state = 91, .external_lex_state = 8},
  [2436] = {.lex_state = 91, .external_lex_state = 15},
  [2437] = {.lex_state = 91, .external_lex_state = 15},
  [2438] = {.lex_state = 91, .external_lex_state = 15},
  [2439] = {.lex_state = 91, .external_lex_state = 15},
  [2440] = {.lex_state = 91, .external_lex_state = 14},
  [2441] = {.lex_state = 91, .external_lex_state = 14},
  [2442] = {.lex_state = 91, .external_lex_state = 8},
  [2443] = {.lex_state = 91, .external_lex_state = 7},
  [2444] = {.lex_state = 91, .external_lex_state = 9},
  [2445] = {.lex_state = 2, .external_lex_state = 7},
  [2446] = {.lex_state = 91, .external_lex_state = 12},
  [2447] = {.lex_state = 91, .external_lex_state = 7},
  [2448] = {.lex_state = 91, .external_lex_state = 17},
  [2449] = {.lex_state = 91, .external_lex_state = 17},
  [2450] = {.lex_state = 91, .external_lex_state = 17},
  [2451] = {.lex_state = 91, .external_lex_state = 17},
  [2452] = {.lex_state = 91, .external_lex_state = 17},
  [2453] = {.lex_state = 91, .external_lex_state = 17},
  [2454] = {.lex_state = 91, .external_lex_state = 17},
  [2455] = {.lex_state = 91, .external_lex_state = 17},
  [2456] = {.lex_state = 91, .external_lex_state = 12},
  [2457] = {.lex_state = 91, .external_lex_state = 2},
  [2458] = {.lex_state = 91, .external_lex_state = 2},
  [2459] = {.lex_state = 91, .external_lex_state = 2},
  [2460] = {.lex_state = 91, .external_lex_state = 2},
  [2461] = {.lex_state = 91, .external_lex_state = 2},
  [2462] = {.lex_state = 91, .external_lex_state = 2},
  [2463] = {.lex_state = 91, .external_lex_state = 2},
  [2464] = {.lex_state = 91, .external_lex_state = 2},
  [2465] = {.lex_state = 91, .external_lex_state = 2},
  [2466] = {.lex_state = 91, .external_lex_state = 2},
  [2467] = {.lex_state = 91, .external_lex_state = 2},
  [2468] = {.lex_state = 91, .external_lex_state = 2},
  [2469] = {.lex_state = 91, .external_lex_state = 2},
  [2470] = {.lex_state = 91, .external_lex_state = 2},
  [2471] = {.lex_state = 91, .external_lex_state = 2},
  [2472] = {.lex_state = 91, .external_lex_state = 2},
  [2473] = {.lex_state = 91, .external_lex_state = 2},
  [2474] = {.lex_state = 91, .external_lex_state = 2},
  [2475] = {.lex_state = 91, .external_lex_state = 12},
  [2476] = {.lex_state = 91, .external_lex_state = 2},
  [2477] = {.lex_state = 91, .external_lex_state = 2},
  [2478] = {.lex_state = 91, .external_lex_state = 2},
  [2479] = {.lex_state = 91, .external_lex_state = 2},
  [2480] = {.lex_state = 91, .external_lex_state = 2},
  [2481] = {.lex_state = 91, .external_lex_state = 2},
  [2482] = {.lex_state = 91, .external_lex_state = 2},
  [2483] = {.lex_state = 91, .external_lex_state = 2},
  [2484] = {.lex_state = 91, .external_lex_state = 2},
  [2485] = {.lex_state = 91, .external_lex_state = 2},
  [2486] = {.lex_state = 91, .external_lex_state = 2},
  [2487] = {.lex_state = 91, .external_lex_state = 2},
  [2488] = {.lex_state = 91, .external_lex_state = 2},
  [2489] = {.lex_state = 91, .external_lex_state = 2},
  [2490] = {.lex_state = 91, .external_lex_state = 2},
  [2491] = {.lex_state = 91, .external_lex_state = 2},
  [2492] = {.lex_state = 91, .external_lex_state = 2},
  [2493] = {.lex_state = 91, .external_lex_state = 2},
  [2494] = {.lex_state = 91, .external_lex_state = 12},
  [2495] = {.lex_state = 91, .external_lex_state = 2},
  [2496] = {.lex_state = 91, .external_lex_state = 2},
  [2497] = {.lex_state = 91, .external_lex_state = 2},
  [2498] = {.lex_state = 91, .external_lex_state = 2},
  [2499] = {.lex_state = 91, .external_lex_state = 2},
  [2500] = {.lex_state = 91, .external_lex_state = 2},
  [2501] = {.lex_state = 91, .external_lex_state = 2},
  [2502] = {.lex_state = 91, .external_lex_state = 2},
  [2503] = {.lex_state = 91, .external_lex_state = 2},
  [2504] = {.lex_state = 91, .external_lex_state = 2},
  [2505] = {.lex_state = 91, .external_lex_state = 2},
  [2506] = {.lex_state = 91, .external_lex_state = 2},
  [2507] = {.lex_state = 91, .external_lex_state = 2},
  [2508] = {.lex_state = 91, .external_lex_state = 2},
  [2509] = {.lex_state = 91, .external_lex_state = 2},
  [2510] = {.lex_state = 91, .external_lex_state = 2},
  [2511] = {.lex_state = 91, .external_lex_state = 2},
  [2512] = {.lex_state = 91, .external_lex_state = 2},
  [2513] = {.lex_state = 91, .external_lex_state = 2},
  [2514] = {.lex_state = 91, .external_lex_state = 2},
  [2515] = {.lex_state = 91, .external_lex_state = 2},
  [2516] = {.lex_state = 91, .external_lex_state = 2},
  [2517] = {.lex_state = 91, .external_lex_state = 2},
  [2518] = {.lex_state = 91, .external_lex_state = 2},
  [2519] = {.lex_state = 91, .external_lex_state = 2},
  [2520] = {.lex_state = 91, .external_lex_state = 2},
  [2521] = {.lex_state = 91, .external_lex_state = 2},
  [2522] = {.lex_state = 91, .external_lex_state = 2},
  [2523] = {.lex_state = 91, .external_lex_state = 2},
  [2524] = {.lex_state = 91, .external_lex_state = 2},
  [2525] = {.lex_state = 91, .external_lex_state = 2},
  [2526] = {.lex_state = 2, .external_lex_state = 18},
  [2527] = {.lex_state = 5, .external_lex_state = 16},
  [2528] = {.lex_state = 91, .external_lex_state = 2},
  [2529] = {.lex_state = 91, .external_lex_state = 2},
  [2530] = {.lex_state = 91, .external_lex_state = 2},
  [2531] = {.lex_state = 91, .external_lex_state = 2},
  [2532] = {.lex_state = 91, .external_lex_state = 2},
  [2533] = {.lex_state = 91, .external_lex_state = 2},
  [2534] = {.lex_state = 91, .external_lex_state = 2},
  [2535] = {.lex_state = 91, .external_lex_state = 2},
  [2536] = {.lex_state = 91, .external_lex_state = 2},
  [2537] = {.lex_state = 91, .external_lex_state = 2},
  [2538] = {.lex_state = 91, .external_lex_state = 2},
  [2539] = {.lex_state = 91, .external_lex_state = 2},
  [2540] = {.lex_state = 91, .external_lex_state = 2},
  [2541] = {.lex_state = 91, .external_lex_state = 2},
  [2542] = {.lex_state = 2, .external_lex_state = 18},
  [2543] = {.lex_state = 2, .external_lex_state = 18},
  [2544] = {.lex_state = 2, .external_lex_state = 18},
  [2545] = {.lex_state = 2, .external_lex_state = 18},
  [2546] = {.lex_state = 2, .external_lex_state = 18},
  [2547] = {.lex_state = 2, .external_lex_state = 18},
  [2548] = {.lex_state = 2, .external_lex_state = 18},
  [2549] = {.lex_state = 2, .external_lex_state = 18},
  [2550] = {.lex_state = 91, .external_lex_state = 7},
  [2551] = {.lex_state = 5, .external_lex_state = 19},
  [2552] = {.lex_state = 91, .external_lex_state = 7},
  [2553] = {.lex_state = 5, .external_lex_state = 19},
  [2554] = {.lex_state = 91, .external_lex_state = 8},
  [2555] = {.lex_state = 2, .external_lex_state = 18},
  [2556] = {.lex_state = 2, .external_lex_state = 18},
  [2557] = {.lex_state = 91, .external_lex_state = 12},
  [2558] = {.lex_state = 91, .external_lex_state = 12},
  [2559] = {.lex_state = 2, .external_lex_state = 18},
  [2560] = {.lex_state = 91, .external_lex_state = 14},
  [2561] = {.lex_state = 91, .external_lex_state = 14},
  [2562] = {.lex_state = 91, .external_lex_state = 14},
  [2563] = {.lex_state = 2, .external_lex_state = 18},
  [2564] = {.lex_state = 2, .external_lex_state = 18},
  [2565] = {.lex_state = 91, .external_lex_state = 12},
  [2566] = {.lex_state = 5, .external_lex_state = 19},
  [2567] = {.lex_state = 91, .external_lex_state = 18},
  [2568] = {.lex_state = 91, .external_lex_state = 18},
  [2569] = {.lex_state = 91, .external_lex_state = 18},
  [2570] = {.lex_state = 91, .external_lex_state = 17},
  [2571] = {.lex_state = 91, .external_lex_state = 12},
  [2572] = {.lex_state = 91, .external_lex_state = 17},
  [2573] = {.lex_state = 91, .external_lex_state = 17},
  [2574] = {.lex_state = 91, .external_lex_state = 12},
  [2575] = {.lex_state = 91, .external_lex_state = 12},
  [2576] = {.lex_state = 91, .external_lex_state = 7},
  [2577] = {.lex_state = 91, .external_lex_state = 7},
  [2578] = {.lex_state = 91, .external_lex_state = 7},
  [2579] = {.lex_state = 91, .external_lex_state = 7},
  [2580] = {.lex_state = 91, .external_lex_state = 7},
  [2581] = {.lex_state = 91, .external_lex_state = 7},
  [2582] = {.lex_state = 91, .external_lex_state = 7},
  [2583] = {.lex_state = 91, .external_lex_state = 7},
  [2584] = {.lex_state = 91, .external_lex_state = 7},
  [2585] = {.lex_state = 91, .external_lex_state = 7},
  [2586] = {.lex_state = 91, .external_lex_state = 7},
  [2587] = {.lex_state = 91, .external_lex_state = 7},
  [2588] = {.lex_state = 91, .external_lex_state = 7},
  [2589] = {.lex_state = 91, .external_lex_state = 7},
  [2590] = {.lex_state = 91, .external_lex_state = 7},
  [2591] = {.lex_state = 91, .external_lex_state = 7},
  [2592] = {.lex_state = 91, .external_lex_state = 7},
  [2593] = {.lex_state = 91, .external_lex_state = 7},
  [2594] = {.lex_state = 91, .external_lex_state = 7},
  [2595] = {.lex_state = 91, .external_lex_state = 7},
  [2596] = {.lex_state = 91, .external_lex_state = 7},
  [2597] = {.lex_state = 91, .external_lex_state = 7},
  [2598] = {.lex_state = 91, .external_lex_state = 7},
  [2599] = {.lex_state = 91, .external_lex_state = 7},
  [2600] = {.lex_state = 91, .external_lex_state = 7},
  [2601] = {.lex_state = 91, .external_lex_state = 7},
  [2602] = {.lex_state = 91, .external_lex_state = 7},
  [2603] = {.lex_state = 91, .external_lex_state = 7},
  [2604] = {.lex_state = 91, .external_lex_state = 7},
  [2605] = {.lex_state = 91, .external_lex_state = 7},
  [2606] = {.lex_state = 91, .external_lex_state = 7},
  [2607] = {.lex_state = 91, .external_lex_state = 7},
  [2608] = {.lex_state = 91, .external_lex_state = 7},
  [2609] = {.lex_state = 91, .external_lex_state = 7},
  [2610] = {.lex_state = 91, .external_lex_state = 7},
  [2611] = {.lex_state = 91, .external_lex_state = 7},
  [2612] = {.lex_state = 91, .external_lex_state = 7},
  [2613] = {.lex_state = 91, .external_lex_state = 7},
  [2614] = {.lex_state = 91, .external_lex_state = 7},
  [2615] = {.lex_state = 91, .external_lex_state = 2},
  [2616] = {.lex_state = 91, .external_lex_state = 7},
  [2617] = {.lex_state = 91, .external_lex_state = 7},
  [2618] = {.lex_state = 91, .external_lex_state = 7},
  [2619] = {.lex_state = 91, .external_lex_state = 7},
  [2620] = {.lex_state = 91, .external_lex_state = 7},
  [2621] = {.lex_state = 91, .external_lex_state = 7},
  [2622] = {.lex_state = 91, .external_lex_state = 7},
  [2623] = {.lex_state = 91, .external_lex_state = 7},
  [2624] = {.lex_state = 91, .external_lex_state = 7},
  [2625] = {.lex_state = 91, .external_lex_state = 7},
  [2626] = {.lex_state = 91, .external_lex_state = 17},
  [2627] = {.lex_state = 91, .external_lex_state = 17},
  [2628] = {.lex_state = 91, .external_lex_state = 17},
  [2629] = {.lex_state = 91, .external_lex_state = 12},
  [2630] = {.lex_state = 91, .external_lex_state = 17},
  [2631] = {.lex_state = 91, .external_lex_state = 12},
  [2632] = {.lex_state = 91, .external_lex_state = 17},
  [2633] = {.lex_state = 91, .external_lex_state = 12},
  [2634] = {.lex_state = 91, .external_lex_state = 12},
  [2635] = {.lex_state = 91, .external_lex_state = 12},
  [2636] = {.lex_state = 91, .external_lex_state = 14},
  [2637] = {.lex_state = 91, .external_lex_state = 14},
  [2638] = {.lex_state = 91, .external_lex_state = 14},
  [2639] = {.lex_state = 91, .external_lex_state = 14},
  [2640] = {.lex_state = 91, .external_lex_state = 14},
  [2641] = {.lex_state = 91, .external_lex_state = 12},
  [2642] = {.lex_state = 91, .external_lex_state = 14},
  [2643] = {.lex_state = 91, .external_lex_state = 20},
  [2644] = {.lex_state = 91, .external_lex_state = 14},
  [2645] = {.lex_state = 91, .external_lex_state = 18},
  [2646] = {.lex_state = 91, .external_lex_state = 14},
  [2647] = {.lex_state = 91, .external_lex_state = 14},
  [2648] = {.lex_state = 91, .external_lex_state = 14},
  [2649] = {.lex_state = 91, .external_lex_state = 14},
  [2650] = {.lex_state = 91, .external_lex_state = 14},
  [2651] = {.lex_state = 91, .external_lex_state = 14},
  [2652] = {.lex_state = 91, .external_lex_state = 12},
  [2653] = {.lex_state = 91, .external_lex_state = 14},
  [2654] = {.lex_state = 91, .external_lex_state = 14},
  [2655] = {.lex_state = 91, .external_lex_state = 14},
  [2656] = {.lex_state = 91, .external_lex_state = 12},
  [2657] = {.lex_state = 91, .external_lex_state = 12},
  [2658] = {.lex_state = 91, .external_lex_state = 14},
  [2659] = {.lex_state = 91, .external_lex_state = 14},
  [2660] = {.lex_state = 91, .external_lex_state = 14},
  [2661] = {.lex_state = 91, .external_lex_state = 14},
  [2662] = {.lex_state = 91, .external_lex_state = 14},
  [2663] = {.lex_state = 91, .external_lex_state = 14},
  [2664] = {.lex_state = 91, .external_lex_state = 14},
  [2665] = {.lex_state = 91, .external_lex_state = 17},
  [2666] = {.lex_state = 91, .external_lex_state = 17},
  [2667] = {.lex_state = 91, .external_lex_state = 17},
  [2668] = {.lex_state = 91, .external_lex_state = 17},
  [2669] = {.lex_state = 91, .external_lex_state = 17},
  [2670] = {.lex_state = 91, .external_lex_state = 17},
  [2671] = {.lex_state = 91, .external_lex_state = 17},
  [2672] = {.lex_state = 91, .external_lex_state = 17},
  [2673] = {.lex_state = 91, .external_lex_state = 17},
  [2674] = {.lex_state = 91, .external_lex_state = 17},
  [2675] = {.lex_state = 91, .external_lex_state = 17},
  [2676] = {.lex_state = 91, .external_lex_state = 17},
  [2677] = {.lex_state = 91, .external_lex_state = 17},
  [2678] = {.lex_state = 91, .external_lex_state = 17},
  [2679] = {.lex_state = 91, .external_lex_state = 17},
  [2680] = {.lex_state = 91, .external_lex_state = 12},
  [2681] = {.lex_state = 91, .external_lex_state = 17},
  [2682] = {.lex_state = 91, .external_lex_state = 17},
  [2683] = {.lex_state = 91, .external_lex_state = 17},
  [2684] = {.lex_state = 91, .external_lex_state = 17},
  [2685] = {.lex_state = 91, .external_lex_state = 17},
  [2686] = {.lex_state = 91, .external_lex_state = 17},
  [2687] = {.lex_state = 91, .external_lex_state = 17},
  [2688] = {.lex_state = 91, .external_lex_state = 17},
  [2689] = {.lex_state = 91, .external_lex_state = 17},
  [2690] = {.lex_state = 91, .external_lex_state = 17},
  [2691] = {.lex_state = 91, .external_lex_state = 17},
  [2692] = {.lex_state = 91, .external_lex_state = 17},
  [2693] = {.lex_state = 91, .external_lex_state = 17},
  [2694] = {.lex_state = 91, .external_lex_state = 17},
  [2695] = {.lex_state = 91, .external_lex_state = 17},
  [2696] = {.lex_state = 91, .external_lex_state = 17},
  [2697] = {.lex_state = 91, .external_lex_state = 17},
  [2698] = {.lex_state = 91, .external_lex_state = 17},
  [2699] = {.lex_state = 91, .external_lex_state = 17},
  [2700] = {.lex_state = 91, .external_lex_state = 17},
  [2701] = {.lex_state = 91, .external_lex_state = 17},
  [2702] = {.lex_state = 91, .external_lex_state = 17},
  [2703] = {.lex_state = 91, .external_lex_state = 17},
  [2704] = {.lex_state = 91, .external_lex_state = 17},
  [2705] = {.lex_state = 91, .external_lex_state = 17},
  [2706] = {.lex_state = 91, .external_lex_state = 17},
  [2707] = {.lex_state = 91, .external_lex_state = 17},
  [2708] = {.lex_state = 91, .external_lex_state = 17},
  [2709] = {.lex_state = 91, .external_lex_state = 17},
  [2710] = {.lex_state = 91, .external_lex_state = 17},
  [2711] = {.lex_state = 91, .external_lex_state = 17},
  [2712] = {.lex_state = 91, .external_lex_state = 17},
  [2713] = {.lex_state = 91, .external_lex_state = 12},
  [2714] = {.lex_state = 91, .external_lex_state = 12},
  [2715] = {.lex_state = 91, .external_lex_state = 17},
  [2716] = {.lex_state = 5, .external_lex_state = 19},
  [2717] = {.lex_state = 91, .external_lex_state = 12},
  [2718] = {.lex_state = 91, .external_lex_state = 18},
  [2719] = {.lex_state = 91, .external_lex_state = 18},
  [2720] = {.lex_state = 91, .external_lex_state = 18},
  [2721] = {.lex_state = 91, .external_lex_state = 12},
  [2722] = {.lex_state = 91, .external_lex_state = 12},
  [2723] = {.lex_state = 91, .external_lex_state = 18},
  [2724] = {.lex_state = 91, .external_lex_state = 12},
  [2725] = {.lex_state = 5, .external_lex_state = 21},
  [2726] = {.lex_state = 91, .external_lex_state = 12},
  [2727] = {.lex_state = 91, .external_lex_state = 18},
  [2728] = {.lex_state = 91, .external_lex_state = 18},
  [2729] = {.lex_state = 91, .external_lex_state = 12},
  [2730] = {.lex_state = 91, .external_lex_state = 18},
  [2731] = {.lex_state = 91, .external_lex_state = 12},
  [2732] = {.lex_state = 91, .external_lex_state = 12},
  [2733] = {.lex_state = 91, .external_lex_state = 12},
  [2734] = {.lex_state = 91, .external_lex_state = 18},
  [2735] = {.lex_state = 91, .external_lex_state = 12},
  [2736] = {.lex_state = 91, .external_lex_state = 18},
  [2737] = {.lex_state = 91, .external_lex_state = 12},
  [2738] = {.lex_state = 5, .external_lex_state = 21},
  [2739] = {.lex_state = 91, .external_lex_state = 12},
  [2740] = {.lex_state = 91, .external_lex_state = 12},
  [2741] = {.lex_state = 3, .external_lex_state = 3},
  [2742] = {.lex_state = 91, .external_lex_state = 12},
  [2743] = {.lex_state = 91, .external_lex_state = 12},
  [2744] = {.lex_state = 3, .external_lex_state = 3},
  [2745] = {.lex_state = 91, .external_lex_state = 12},
  [2746] = {.lex_state = 91, .external_lex_state = 12},
  [2747] = {.lex_state = 91, .external_lex_state = 12},
  [2748] = {.lex_state = 91, .external_lex_state = 12},
  [2749] = {.lex_state = 91, .external_lex_state = 12},
  [2750] = {.lex_state = 3, .external_lex_state = 3},
  [2751] = {.lex_state = 91, .external_lex_state = 12},
  [2752] = {.lex_state = 91, .external_lex_state = 12},
  [2753] = {.lex_state = 91, .external_lex_state = 12},
  [2754] = {.lex_state = 91, .external_lex_state = 12},
  [2755] = {.lex_state = 91, .external_lex_state = 12},
  [2756] = {.lex_state = 91, .external_lex_state = 12},
  [2757] = {.lex_state = 5, .external_lex_state = 21},
  [2758] = {.lex_state = 91, .external_lex_state = 12},
  [2759] = {.lex_state = 91, .external_lex_state = 12},
  [2760] = {.lex_state = 91, .external_lex_state = 18},
  [2761] = {.lex_state = 91, .external_lex_state = 18},
  [2762] = {.lex_state = 91, .external_lex_state = 18},
  [2763] = {.lex_state = 91, .external_lex_state = 12},
  [2764] = {.lex_state = 91, .external_lex_state = 18},
  [2765] = {.lex_state = 91, .external_lex_state = 18},
  [2766] = {.lex_state = 91, .external_lex_state = 18},
  [2767] = {.lex_state = 91, .external_lex_state = 18},
  [2768] = {.lex_state = 91, .external_lex_state = 18},
  [2769] = {.lex_state = 91, .external_lex_state = 12},
  [2770] = {.lex_state = 91, .external_lex_state = 18},
  [2771] = {.lex_state = 91, .external_lex_state = 18},
  [2772] = {.lex_state = 91, .external_lex_state = 18},
  [2773] = {.lex_state = 91, .external_lex_state = 18},
  [2774] = {.lex_state = 91, .external_lex_state = 18},
  [2775] = {.lex_state = 91, .external_lex_state = 18},
  [2776] = {.lex_state = 91, .external_lex_state = 12},
  [2777] = {.lex_state = 91, .external_lex_state = 18},
  [2778] = {.lex_state = 91, .external_lex_state = 18},
  [2779] = {.lex_state = 91, .external_lex_state = 18},
  [2780] = {.lex_state = 91, .external_lex_state = 18},
  [2781] = {.lex_state = 91, .external_lex_state = 12},
  [2782] = {.lex_state = 91, .external_lex_state = 18},
  [2783] = {.lex_state = 91, .external_lex_state = 18},
  [2784] = {.lex_state = 91, .external_lex_state = 18},
  [2785] = {.lex_state = 91, .external_lex_state = 18},
  [2786] = {.lex_state = 91, .external_lex_state = 18},
  [2787] = {.lex_state = 91, .external_lex_state = 18},
  [2788] = {.lex_state = 91, .external_lex_state = 18},
  [2789] = {.lex_state = 91, .external_lex_state = 12},
  [2790] = {.lex_state = 91, .external_lex_state = 12},
  [2791] = {.lex_state = 91, .external_lex_state = 18},
  [2792] = {.lex_state = 91, .external_lex_state = 18},
  [2793] = {.lex_state = 91, .external_lex_state = 18},
  [2794] = {.lex_state = 91, .external_lex_state = 18},
  [2795] = {.lex_state = 91, .external_lex_state = 18},
  [2796] = {.lex_state = 91, .external_lex_state = 18},
  [2797] = {.lex_state = 91, .external_lex_state = 12},
  [2798] = {.lex_state = 91, .external_lex_state = 12},
  [2799] = {.lex_state = 91, .external_lex_state = 12},
  [2800] = {.lex_state = 91, .external_lex_state = 12},
  [2801] = {.lex_state = 91, .external_lex_state = 18},
  [2802] = {.lex_state = 91, .external_lex_state = 18},
  [2803] = {.lex_state = 91, .external_lex_state = 18},
  [2804] = {.lex_state = 91, .external_lex_state = 18},
  [2805] = {.lex_state = 91, .external_lex_state = 18},
  [2806] = {.lex_state = 91, .external_lex_state = 12},
  [2807] = {.lex_state = 91, .external_lex_state = 18},
  [2808] = {.lex_state = 91, .external_lex_state = 18},
  [2809] = {.lex_state = 91, .external_lex_state = 18},
  [2810] = {.lex_state = 91, .external_lex_state = 18},
  [2811] = {.lex_state = 91, .external_lex_state = 18},
  [2812] = {.lex_state = 91, .external_lex_state = 18},
  [2813] = {.lex_state = 91, .external_lex_state = 18},
  [2814] = {.lex_state = 91, .external_lex_state = 18},
  [2815] = {.lex_state = 91, .external_lex_state = 18},
  [2816] = {.lex_state = 91, .external_lex_state = 18},
  [2817] = {.lex_state = 91, .external_lex_state = 18},
  [2818] = {.lex_state = 91, .external_lex_state = 18},
  [2819] = {.lex_state = 91, .external_lex_state = 18},
  [2820] = {.lex_state = 91, .external_lex_state = 18},
  [2821] = {.lex_state = 91, .external_lex_state = 18},
  [2822] = {.lex_state = 91, .external_lex_state = 18},
  [2823] = {.lex_state = 91, .external_lex_state = 18},
  [2824] = {.lex_state = 91, .external_lex_state = 18},
  [2825] = {.lex_state = 91, .external_lex_state = 18},
  [2826] = {.lex_state = 91, .external_lex_state = 18},
  [2827] = {.lex_state = 91, .external_lex_state = 18},
  [2828] = {.lex_state = 91, .external_lex_state = 18},
  [2829] = {.lex_state = 91, .external_lex_state = 18},
  [2830] = {.lex_state = 91, .external_lex_state = 17},
  [2831] = {.lex_state = 91, .external_lex_state = 18},
  [2832] = {.lex_state = 91, .external_lex_state = 18},
  [2833] = {.lex_state = 91, .external_lex_state = 18},
  [2834] = {.lex_state = 91, .external_lex_state = 18},
  [2835] = {.lex_state = 91, .external_lex_state = 18},
  [2836] = {.lex_state = 91, .external_lex_state = 17},
  [2837] = {.lex_state = 91, .external_lex_state = 18},
  [2838] = {.lex_state = 91, .external_lex_state = 18},
  [2839] = {.lex_state = 91, .external_lex_state = 18},
  [2840] = {.lex_state = 91, .external_lex_state = 18},
  [2841] = {.lex_state = 91, .external_lex_state = 18},
  [2842] = {.lex_state = 91, .external_lex_state = 18},
  [2843] = {.lex_state = 91, .external_lex_state = 18},
  [2844] = {.lex_state = 91, .external_lex_state = 18},
  [2845] = {.lex_state = 91, .external_lex_state = 18},
  [2846] = {.lex_state = 91, .external_lex_state = 18},
  [2847] = {.lex_state = 91, .external_lex_state = 18},
  [2848] = {.lex_state = 91, .external_lex_state = 18},
  [2849] = {.lex_state = 91, .external_lex_state = 18},
  [2850] = {.lex_state = 91, .external_lex_state = 18},
  [2851] = {.lex_state = 91, .external_lex_state = 18},
  [2852] = {.lex_state = 91, .external_lex_state = 18},
  [2853] = {.lex_state = 91, .external_lex_state = 18},
  [2854] = {.lex_state = 91, .external_lex_state = 18},
  [2855] = {.lex_state = 91, .external_lex_state = 18},
  [2856] = {.lex_state = 91, .external_lex_state = 18},
  [2857] = {.lex_state = 91, .external_lex_state = 18},
  [2858] = {.lex_state = 91, .external_lex_state = 18},
  [2859] = {.lex_state = 91, .external_lex_state = 18},
  [2860] = {.lex_state = 91, .external_lex_state = 18},
  [2861] = {.lex_state = 91, .external_lex_state = 18},
  [2862] = {.lex_state = 91, .external_lex_state = 18},
  [2863] = {.lex_state = 91, .external_lex_state = 18},
  [2864] = {.lex_state = 91, .external_lex_state = 18},
  [2865] = {.lex_state = 91, .external_lex_state = 18},
  [2866] = {.lex_state = 91, .external_lex_state = 18},
  [2867] = {.lex_state = 91, .external_lex_state = 18},
  [2868] = {.lex_state = 91, .external_lex_state = 18},
  [2869] = {.lex_state = 91, .external_lex_state = 18},
  [2870] = {.lex_state = 91, .external_lex_state = 17},
  [2871] = {.lex_state = 91, .external_lex_state = 17},
  [2872] = {.lex_state = 91, .external_lex_state = 17},
  [2873] = {.lex_state = 91, .external_lex_state = 18},
  [2874] = {.lex_state = 91, .external_lex_state = 12},
  [2875] = {.lex_state = 91, .external_lex_state = 18},
  [2876] = {.lex_state = 91, .external_lex_state = 17},
  [2877] = {.lex_state = 91, .external_lex_state = 18},
  [2878] = {.lex_state = 91, .external_lex_state = 18},
  [2879] = {.lex_state = 91, .external_lex_state = 17},
  [2880] = {.lex_state = 91, .external_lex_state = 17},
  [2881] = {.lex_state = 91, .external_lex_state = 18},
  [2882] = {.lex_state = 91, .external_lex_state = 18},
  [2883] = {.lex_state = 91, .external_lex_state = 18},
  [2884] = {.lex_state = 91, .external_lex_state = 18},
  [2885] = {.lex_state = 91, .external_lex_state = 12},
  [2886] = {.lex_state = 91, .external_lex_state = 18},
  [2887] = {.lex_state = 91, .external_lex_state = 18},
  [2888] = {.lex_state = 91, .external_lex_state = 18},
  [2889] = {.lex_state = 91, .external_lex_state = 18},
  [2890] = {.lex_state = 91, .external_lex_state = 18},
  [2891] = {.lex_state = 91, .external_lex_state = 18},
  [2892] = {.lex_state = 91, .external_lex_state = 18},
  [2893] = {.lex_state = 91, .external_lex_state = 18},
  [2894] = {.lex_state = 91, .external_lex_state = 18},
  [2895] = {.lex_state = 91, .external_lex_state = 18},
  [2896] = {.lex_state = 91, .external_lex_state = 18},
  [2897] = {.lex_state = 91, .external_lex_state = 18},
  [2898] = {.lex_state = 91, .external_lex_state = 18},
  [2899] = {.lex_state = 91, .external_lex_state = 18},
  [2900] = {.lex_state = 91, .external_lex_state = 18},
  [2901] = {.lex_state = 91, .external_lex_state = 18},
  [2902] = {.lex_state = 91, .external_lex_state = 18},
  [2903] = {.lex_state = 91, .external_lex_state = 17},
  [2904] = {.lex_state = 91, .external_lex_state = 18},
  [2905] = {.lex_state = 91, .external_lex_state = 18},
  [2906] = {.lex_state = 91, .external_lex_state = 17},
  [2907] = {.lex_state = 91, .external_lex_state = 18},
  [2908] = {.lex_state = 91, .external_lex_state = 18},
  [2909] = {.lex_state = 91, .external_lex_state = 18},
  [2910] = {.lex_state = 91, .external_lex_state = 17},
  [2911] = {.lex_state = 91, .external_lex_state = 18},
  [2912] = {.lex_state = 91, .external_lex_state = 17},
  [2913] = {.lex_state = 91, .external_lex_state = 17},
  [2914] = {.lex_state = 91, .external_lex_state = 17},
  [2915] = {.lex_state = 91, .external_lex_state = 17},
  [2916] = {.lex_state = 91, .external_lex_state = 18},
  [2917] = {.lex_state = 91, .external_lex_state = 18},
  [2918] = {.lex_state = 91, .external_lex_state = 18},
  [2919] = {.lex_state = 91, .external_lex_state = 18},
  [2920] = {.lex_state = 91, .external_lex_state = 18},
  [2921] = {.lex_state = 91, .external_lex_state = 18},
  [2922] = {.lex_state = 91, .external_lex_state = 18},
  [2923] = {.lex_state = 91, .external_lex_state = 18},
  [2924] = {.lex_state = 91, .external_lex_state = 17},
  [2925] = {.lex_state = 91, .external_lex_state = 18},
  [2926] = {.lex_state = 91, .external_lex_state = 18},
  [2927] = {.lex_state = 91, .external_lex_state = 18},
  [2928] = {.lex_state = 91, .external_lex_state = 18},
  [2929] = {.lex_state = 91, .external_lex_state = 18},
  [2930] = {.lex_state = 91, .external_lex_state = 18},
  [2931] = {.lex_state = 91, .external_lex_state = 18},
  [2932] = {.lex_state = 91, .external_lex_state = 18},
  [2933] = {.lex_state = 91, .external_lex_state = 18},
  [2934] = {.lex_state = 91, .external_lex_state = 18},
  [2935] = {.lex_state = 91, .external_lex_state = 18},
  [2936] = {.lex_state = 91, .external_lex_state = 18},
  [2937] = {.lex_state = 91, .external_lex_state = 18},
  [2938] = {.lex_state = 91, .external_lex_state = 18},
  [2939] = {.lex_state = 91, .external_lex_state = 18},
  [2940] = {.lex_state = 91, .external_lex_state = 18},
  [2941] = {.lex_state = 91, .external_lex_state = 18},
  [2942] = {.lex_state = 91, .external_lex_state = 18},
  [2943] = {.lex_state = 91, .external_lex_state = 18},
  [2944] = {.lex_state = 91, .external_lex_state = 18},
  [2945] = {.lex_state = 91, .external_lex_state = 18},
  [2946] = {.lex_state = 91, .external_lex_state = 18},
  [2947] = {.lex_state = 91, .external_lex_state = 18},
  [2948] = {.lex_state = 91, .external_lex_state = 18},
  [2949] = {.lex_state = 91, .external_lex_state = 18},
  [2950] = {.lex_state = 91, .external_lex_state = 18},
  [2951] = {.lex_state = 91, .external_lex_state = 18},
  [2952] = {.lex_state = 91, .external_lex_state = 18},
  [2953] = {.lex_state = 91, .external_lex_state = 18},
  [2954] = {.lex_state = 91, .external_lex_state = 18},
  [2955] = {.lex_state = 91, .external_lex_state = 18},
  [2956] = {.lex_state = 91, .external_lex_state = 18},
  [2957] = {.lex_state = 91, .external_lex_state = 17},
  [2958] = {.lex_state = 91, .external_lex_state = 17},
  [2959] = {.lex_state = 91, .external_lex_state = 18},
  [2960] = {.lex_state = 91, .external_lex_state = 18},
  [2961] = {.lex_state = 91, .external_lex_state = 18},
  [2962] = {.lex_state = 91, .external_lex_state = 18},
  [2963] = {.lex_state = 91, .external_lex_state = 18},
  [2964] = {.lex_state = 91, .external_lex_state = 18},
  [2965] = {.lex_state = 91, .external_lex_state = 18},
  [2966] = {.lex_state = 91, .external_lex_state = 17},
  [2967] = {.lex_state = 91, .external_lex_state = 18},
  [2968] = {.lex_state = 91, .external_lex_state = 18},
  [2969] = {.lex_state = 91, .external_lex_state = 17},
  [2970] = {.lex_state = 91, .external_lex_state = 17},
  [2971] = {.lex_state = 91, .external_lex_state = 18},
  [2972] = {.lex_state = 91, .external_lex_state = 18},
  [2973] = {.lex_state = 91, .external_lex_state = 17},
  [2974] = {.lex_state = 91, .external_lex_state = 18},
  [2975] = {.lex_state = 91, .external_lex_state = 18},
  [2976] = {.lex_state = 91, .external_lex_state = 18},
  [2977] = {.lex_state = 91, .external_lex_state = 18},
  [2978] = {.lex_state = 91, .external_lex_state = 18},
  [2979] = {.lex_state = 91, .external_lex_state = 17},
  [2980] = {.lex_state = 91, .external_lex_state = 17},
  [2981] = {.lex_state = 91, .external_lex_state = 18},
  [2982] = {.lex_state = 91, .external_lex_state = 18},
  [2983] = {.lex_state = 91, .external_lex_state = 18},
  [2984] = {.lex_state = 91, .external_lex_state = 18},
  [2985] = {.lex_state = 91, .external_lex_state = 18},
  [2986] = {.lex_state = 91, .external_lex_state = 18},
  [2987] = {.lex_state = 91, .external_lex_state = 18},
  [2988] = {.lex_state = 91, .external_lex_state = 18},
  [2989] = {.lex_state = 91, .external_lex_state = 18},
  [2990] = {.lex_state = 91, .external_lex_state = 18},
  [2991] = {.lex_state = 91, .external_lex_state = 18},
  [2992] = {.lex_state = 91, .external_lex_state = 18},
  [2993] = {.lex_state = 91, .external_lex_state = 18},
  [2994] = {.lex_state = 91, .external_lex_state = 18},
  [2995] = {.lex_state = 91, .external_lex_state = 18},
  [2996] = {.lex_state = 91, .external_lex_state = 18},
  [2997] = {.lex_state = 91, .external_lex_state = 18},
  [2998] = {.lex_state = 91, .external_lex_state = 18},
  [2999] = {.lex_state = 91, .external_lex_state = 18},
  [3000] = {.lex_state = 91, .external_lex_state = 18},
  [3001] = {.lex_state = 91, .external_lex_state = 18},
  [3002] = {.lex_state = 91, .external_lex_state = 18},
  [3003] = {.lex_state = 91, .external_lex_state = 18},
  [3004] = {.lex_state = 91, .external_lex_state = 18},
  [3005] = {.lex_state = 91, .external_lex_state = 18},
  [3006] = {.lex_state = 91, .external_lex_state = 18},
  [3007] = {.lex_state = 91, .external_lex_state = 18},
  [3008] = {.lex_state = 91, .external_lex_state = 18},
  [3009] = {.lex_state = 91, .external_lex_state = 18},
  [3010] = {.lex_state = 91, .external_lex_state = 18},
  [3011] = {.lex_state = 91, .external_lex_state = 18},
  [3012] = {.lex_state = 91, .external_lex_state = 18},
  [3013] = {.lex_state = 91, .external_lex_state = 12},
  [3014] = {.lex_state = 91, .external_lex_state = 18},
  [3015] = {.lex_state = 91, .external_lex_state = 17},
  [3016] = {.lex_state = 91, .external_lex_state = 18},
  [3017] = {.lex_state = 91, .external_lex_state = 18},
  [3018] = {.lex_state = 91, .external_lex_state = 18},
  [3019] = {.lex_state = 91, .external_lex_state = 12},
  [3020] = {.lex_state = 91, .external_lex_state = 18},
  [3021] = {.lex_state = 91, .external_lex_state = 18},
  [3022] = {.lex_state = 91, .external_lex_state = 18},
  [3023] = {.lex_state = 91, .external_lex_state = 18},
  [3024] = {.lex_state = 91, .external_lex_state = 18},
  [3025] = {.lex_state = 91, .external_lex_state = 18},
  [3026] = {.lex_state = 91, .external_lex_state = 18},
  [3027] = {.lex_state = 91, .external_lex_state = 18},
  [3028] = {.lex_state = 91, .external_lex_state = 17},
  [3029] = {.lex_state = 91, .external_lex_state = 18},
  [3030] = {.lex_state = 91, .external_lex_state = 17},
  [3031] = {.lex_state = 91, .external_lex_state = 17},
  [3032] = {.lex_state = 91, .external_lex_state = 17},
  [3033] = {.lex_state = 91, .external_lex_state = 17},
  [3034] = {.lex_state = 91, .external_lex_state = 17},
  [3035] = {.lex_state = 91, .external_lex_state = 18},
  [3036] = {.lex_state = 91, .external_lex_state = 17},
  [3037] = {.lex_state = 91, .external_lex_state = 17},
  [3038] = {.lex_state = 91, .external_lex_state = 17},
  [3039] = {.lex_state = 91, .external_lex_state = 17},
  [3040] = {.lex_state = 91, .external_lex_state = 17},
  [3041] = {.lex_state = 91, .external_lex_state = 17},
  [3042] = {.lex_state = 91, .external_lex_state = 18},
  [3043] = {.lex_state = 91, .external_lex_state = 18},
  [3044] = {.lex_state = 91, .external_lex_state = 18},
  [3045] = {.lex_state = 91, .external_lex_state = 18},
  [3046] = {.lex_state = 91, .external_lex_state = 18},
  [3047] = {.lex_state = 91, .external_lex_state = 18},
  [3048] = {.lex_state = 91, .external_lex_state = 18},
  [3049] = {.lex_state = 91, .external_lex_state = 18},
  [3050] = {.lex_state = 91, .external_lex_state = 18},
  [3051] = {.lex_state = 91, .external_lex_state = 18},
  [3052] = {.lex_state = 91, .external_lex_state = 18},
  [3053] = {.lex_state = 91, .external_lex_state = 18},
  [3054] = {.lex_state = 91, .external_lex_state = 18},
  [3055] = {.lex_state = 91, .external_lex_state = 18},
  [3056] = {.lex_state = 91, .external_lex_state = 18},
  [3057] = {.lex_state = 91, .external_lex_state = 18},
  [3058] = {.lex_state = 91, .external_lex_state = 18},
  [3059] = {.lex_state = 91, .external_lex_state = 18},
  [3060] = {.lex_state = 91, .external_lex_state = 18},
  [3061] = {.lex_state = 91, .external_lex_state = 18},
  [3062] = {.lex_state = 91, .external_lex_state = 17},
  [3063] = {.lex_state = 91, .external_lex_state = 18},
  [3064] = {.lex_state = 91, .external_lex_state = 18},
  [3065] = {.lex_state = 91, .external_lex_state = 18},
  [3066] = {.lex_state = 91, .external_lex_state = 18},
  [3067] = {.lex_state = 91, .external_lex_state = 18},
  [3068] = {.lex_state = 91, .external_lex_state = 18},
  [3069] = {.lex_state = 91, .external_lex_state = 18},
  [3070] = {.lex_state = 91, .external_lex_state = 18},
  [3071] = {.lex_state = 91, .external_lex_state = 17},
  [3072] = {.lex_state = 91, .external_lex_state = 18},
  [3073] = {.lex_state = 91, .external_lex_state = 18},
  [3074] = {.lex_state = 91, .external_lex_state = 17},
  [3075] = {.lex_state = 91, .external_lex_state = 17},
  [3076] = {.lex_state = 91, .external_lex_state = 17},
  [3077] = {.lex_state = 91, .external_lex_state = 18},
  [3078] = {.lex_state = 91, .external_lex_state = 18},
  [3079] = {.lex_state = 91, .external_lex_state = 18},
  [3080] = {.lex_state = 91, .external_lex_state = 18},
  [3081] = {.lex_state = 91, .external_lex_state = 18},
  [3082] = {.lex_state = 91, .external_lex_state = 18},
  [3083] = {.lex_state = 91, .external_lex_state = 18},
  [3084] = {.lex_state = 91, .external_lex_state = 18},
  [3085] = {.lex_state = 91, .external_lex_state = 18},
  [3086] = {.lex_state = 91, .external_lex_state = 18},
  [3087] = {.lex_state = 91, .external_lex_state = 18},
  [3088] = {.lex_state = 91, .external_lex_state = 18},
  [3089] = {.lex_state = 91, .external_lex_state = 17},
  [3090] = {.lex_state = 91, .external_lex_state = 18},
  [3091] = {.lex_state = 91, .external_lex_state = 18},
  [3092] = {.lex_state = 91, .external_lex_state = 18},
  [3093] = {.lex_state = 91, .external_lex_state = 18},
  [3094] = {.lex_state = 91, .external_lex_state = 18},
  [3095] = {.lex_state = 91, .external_lex_state = 17},
  [3096] = {.lex_state = 91, .external_lex_state = 17},
  [3097] = {.lex_state = 91, .external_lex_state = 18},
  [3098] = {.lex_state = 91, .external_lex_state = 18},
  [3099] = {.lex_state = 91, .external_lex_state = 18},
  [3100] = {.lex_state = 91, .external_lex_state = 18},
  [3101] = {.lex_state = 91, .external_lex_state = 18},
  [3102] = {.lex_state = 91, .external_lex_state = 18},
  [3103] = {.lex_state = 91, .external_lex_state = 18},
  [3104] = {.lex_state = 91, .external_lex_state = 18},
  [3105] = {.lex_state = 91, .external_lex_state = 18},
  [3106] = {.lex_state = 91, .external_lex_state = 18},
  [3107] = {.lex_state = 91, .external_lex_state = 18},
  [3108] = {.lex_state = 91, .external_lex_state = 18},
  [3109] = {.lex_state = 91, .external_lex_state = 18},
  [3110] = {.lex_state = 91, .external_lex_state = 18},
  [3111] = {.lex_state = 91, .external_lex_state = 18},
  [3112] = {.lex_state = 91, .external_lex_state = 18},
  [3113] = {.lex_state = 91, .external_lex_state = 18},
  [3114] = {.lex_state = 91, .external_lex_state = 18},
  [3115] = {.lex_state = 91, .external_lex_state = 18},
  [3116] = {.lex_state = 91, .external_lex_state = 18},
  [3117] = {.lex_state = 91, .external_lex_state = 17},
  [3118] = {.lex_state = 91, .external_lex_state = 18},
  [3119] = {.lex_state = 91, .external_lex_state = 18},
  [3120] = {.lex_state = 91, .external_lex_state = 18},
  [3121] = {.lex_state = 91, .external_lex_state = 18},
  [3122] = {.lex_state = 91, .external_lex_state = 18},
  [3123] = {.lex_state = 91, .external_lex_state = 18},
  [3124] = {.lex_state = 91, .external_lex_state = 18},
  [3125] = {.lex_state = 91, .external_lex_state = 17},
  [3126] = {.lex_state = 91, .external_lex_state = 18},
  [3127] = {.lex_state = 91, .external_lex_state = 18},
  [3128] = {.lex_state = 91, .external_lex_state = 18},
  [3129] = {.lex_state = 91, .external_lex_state = 18},
  [3130] = {.lex_state = 91, .external_lex_state = 18},
  [3131] = {.lex_state = 91, .external_lex_state = 18},
  [3132] = {.lex_state = 91, .external_lex_state = 18},
  [3133] = {.lex_state = 91, .external_lex_state = 18},
  [3134] = {.lex_state = 91, .external_lex_state = 18},
  [3135] = {.lex_state = 91, .external_lex_state = 18},
  [3136] = {.lex_state = 91, .external_lex_state = 17},
  [3137] = {.lex_state = 91, .external_lex_state = 18},
  [3138] = {.lex_state = 91, .external_lex_state = 18},
  [3139] = {.lex_state = 91, .external_lex_state = 18},
  [3140] = {.lex_state = 91, .external_lex_state = 17},
  [3141] = {.lex_state = 91, .external_lex_state = 18},
  [3142] = {.lex_state = 91, .external_lex_state = 18},
  [3143] = {.lex_state = 91, .external_lex_state = 17},
  [3144] = {.lex_state = 91, .external_lex_state = 18},
  [3145] = {.lex_state = 91, .external_lex_state = 17},
  [3146] = {.lex_state = 91, .external_lex_state = 18},
  [3147] = {.lex_state = 91, .external_lex_state = 17},
  [3148] = {.lex_state = 91, .external_lex_state = 18},
  [3149] = {.lex_state = 91, .external_lex_state = 18},
  [3150] = {.lex_state = 91, .external_lex_state = 18},
  [3151] = {.lex_state = 91, .external_lex_state = 17},
  [3152] = {.lex_state = 91, .external_lex_state = 18},
  [3153] = {.lex_state = 91, .external_lex_state = 18},
  [3154] = {.lex_state = 91, .external_lex_state = 17},
  [3155] = {.lex_state = 91, .external_lex_state = 18},
  [3156] = {.lex_state = 91, .external_lex_state = 18},
  [3157] = {.lex_state = 91, .external_lex_state = 18},
  [3158] = {.lex_state = 91, .external_lex_state = 18},
  [3159] = {.lex_state = 91, .external_lex_state = 18},
  [3160] = {.lex_state = 91, .external_lex_state = 18},
  [3161] = {.lex_state = 91, .external_lex_state = 17},
  [3162] = {.lex_state = 91, .external_lex_state = 18},
  [3163] = {.lex_state = 91, .external_lex_state = 18},
  [3164] = {.lex_state = 91, .external_lex_state = 18},
  [3165] = {.lex_state = 91, .external_lex_state = 18},
  [3166] = {.lex_state = 91, .external_lex_state = 18},
  [3167] = {.lex_state = 91, .external_lex_state = 18},
  [3168] = {.lex_state = 91, .external_lex_state = 18},
  [3169] = {.lex_state = 91, .external_lex_state = 18},
  [3170] = {.lex_state = 91, .external_lex_state = 18},
  [3171] = {.lex_state = 91, .external_lex_state = 18},
  [3172] = {.lex_state = 91, .external_lex_state = 18},
  [3173] = {.lex_state = 91, .external_lex_state = 18},
  [3174] = {.lex_state = 91, .external_lex_state = 18},
  [3175] = {.lex_state = 91, .external_lex_state = 18},
  [3176] = {.lex_state = 91, .external_lex_state = 18},
  [3177] = {.lex_state = 91, .external_lex_state = 18},
  [3178] = {.lex_state = 91, .external_lex_state = 18},
  [3179] = {.lex_state = 91, .external_lex_state = 18},
  [3180] = {.lex_state = 91, .external_lex_state = 18},
  [3181] = {.lex_state = 91, .external_lex_state = 18},
  [3182] = {.lex_state = 91, .external_lex_state = 18},
  [3183] = {.lex_state = 91, .external_lex_state = 18},
  [3184] = {.lex_state = 91, .external_lex_state = 18},
  [3185] = {.lex_state = 91, .external_lex_state = 18},
  [3186] = {.lex_state = 91, .external_lex_state = 18},
  [3187] = {.lex_state = 91, .external_lex_state = 18},
  [3188] = {.lex_state = 91, .external_lex_state = 18},
  [3189] = {.lex_state = 91, .external_lex_state = 18},
  [3190] = {.lex_state = 91, .external_lex_state = 18},
  [3191] = {.lex_state = 91, .external_lex_state = 18},
  [3192] = {.lex_state = 91, .external_lex_state = 18},
  [3193] = {.lex_state = 91, .external_lex_state = 18},
  [3194] = {.lex_state = 91, .external_lex_state = 18},
  [3195] = {.lex_state = 91, .external_lex_state = 18},
  [3196] = {.lex_state = 91, .external_lex_state = 18},
  [3197] = {.lex_state = 91, .external_lex_state = 18},
  [3198] = {.lex_state = 91, .external_lex_state = 18},
  [3199] = {.lex_state = 91, .external_lex_state = 18},
  [3200] = {.lex_state = 91, .external_lex_state = 18},
  [3201] = {.lex_state = 91, .external_lex_state = 18},
  [3202] = {.lex_state = 91, .external_lex_state = 18},
  [3203] = {.lex_state = 91, .external_lex_state = 18},
  [3204] = {.lex_state = 91, .external_lex_state = 18},
  [3205] = {.lex_state = 91, .external_lex_state = 12},
  [3206] = {.lex_state = 91, .external_lex_state = 18},
  [3207] = {.lex_state = 91, .external_lex_state = 18},
  [3208] = {.lex_state = 91, .external_lex_state = 18},
  [3209] = {.lex_state = 91, .external_lex_state = 18},
  [3210] = {.lex_state = 91, .external_lex_state = 18},
  [3211] = {.lex_state = 91, .external_lex_state = 18},
  [3212] = {.lex_state = 91, .external_lex_state = 18},
  [3213] = {.lex_state = 91, .external_lex_state = 18},
  [3214] = {.lex_state = 91, .external_lex_state = 17},
  [3215] = {.lex_state = 91, .external_lex_state = 17},
  [3216] = {.lex_state = 91, .external_lex_state = 18},
  [3217] = {.lex_state = 91, .external_lex_state = 18},
  [3218] = {.lex_state = 91, .external_lex_state = 18},
  [3219] = {.lex_state = 91, .external_lex_state = 18},
  [3220] = {.lex_state = 91, .external_lex_state = 18},
  [3221] = {.lex_state = 91, .external_lex_state = 18},
  [3222] = {.lex_state = 91, .external_lex_state = 17},
  [3223] = {.lex_state = 91, .external_lex_state = 18},
  [3224] = {.lex_state = 91, .external_lex_state = 18},
  [3225] = {.lex_state = 91, .external_lex_state = 18},
  [3226] = {.lex_state = 91, .external_lex_state = 18},
  [3227] = {.lex_state = 91, .external_lex_state = 18},
  [3228] = {.lex_state = 91, .external_lex_state = 17},
  [3229] = {.lex_state = 91, .external_lex_state = 18},
  [3230] = {.lex_state = 91, .external_lex_state = 18},
  [3231] = {.lex_state = 91, .external_lex_state = 18},
  [3232] = {.lex_state = 91, .external_lex_state = 18},
  [3233] = {.lex_state = 91, .external_lex_state = 18},
  [3234] = {.lex_state = 91, .external_lex_state = 18},
  [3235] = {.lex_state = 91, .external_lex_state = 18},
  [3236] = {.lex_state = 91, .external_lex_state = 18},
  [3237] = {.lex_state = 91, .external_lex_state = 18},
  [3238] = {.lex_state = 91, .external_lex_state = 18},
  [3239] = {.lex_state = 91, .external_lex_state = 18},
  [3240] = {.lex_state = 91, .external_lex_state = 18},
  [3241] = {.lex_state = 91, .external_lex_state = 18},
  [3242] = {.lex_state = 91, .external_lex_state = 17},
  [3243] = {.lex_state = 91, .external_lex_state = 18},
  [3244] = {.lex_state = 91, .external_lex_state = 18},
  [3245] = {.lex_state = 91, .external_lex_state = 18},
  [3246] = {.lex_state = 91, .external_lex_state = 18},
  [3247] = {.lex_state = 91, .external_lex_state = 18},
  [3248] = {.lex_state = 91, .external_lex_state = 18},
  [3249] = {.lex_state = 91, .external_lex_state = 18},
  [3250] = {.lex_state = 91, .external_lex_state = 18},
  [3251] = {.lex_state = 91, .external_lex_state = 18},
  [3252] = {.lex_state = 91, .external_lex_state = 12},
  [3253] = {.lex_state = 91, .external_lex_state = 22},
  [3254] = {.lex_state = 91, .external_lex_state = 12},
  [3255] = {.lex_state = 91, .external_lex_state = 12},
  [3256] = {.lex_state = 91, .external_lex_state = 2},
  [3257] = {.lex_state = 91, .external_lex_state = 12},
  [3258] = {.lex_state = 91, .external_lex_state = 22},
  [3259] = {.lex_state = 91, .external_lex_state = 12},
  [3260] = {.lex_state = 91, .external_lex_state = 12},
  [3261] = {.lex_state = 91, .external_lex_state = 12},
  [3262] = {.lex_state = 91, .external_lex_state = 12},
  [3263] = {.lex_state = 91, .external_lex_state = 22},
  [3264] = {.lex_state = 91, .external_lex_state = 12},
  [3265] = {.lex_state = 91, .external_lex_state = 22},
  [3266] = {.lex_state = 91, .external_lex_state = 12},
  [3267] = {.lex_state = 91, .external_lex_state = 12},
  [3268] = {.lex_state = 91, .external_lex_state = 2},
  [3269] = {.lex_state = 91, .external_lex_state = 22},
  [3270] = {.lex_state = 91, .external_lex_state = 2},
  [3271] = {.lex_state = 91, .external_lex_state = 2},
  [3272] = {.lex_state = 91, .external_lex_state = 12},
  [3273] = {.lex_state = 91, .external_lex_state = 12},
  [3274] = {.lex_state = 91, .external_lex_state = 12},
  [3275] = {.lex_state = 91, .external_lex_state = 12},
  [3276] = {.lex_state = 91, .external_lex_state = 15},
  [3277] = {.lex_state = 91, .external_lex_state = 12},
  [3278] = {.lex_state = 91, .external_lex_state = 15},
  [3279] = {.lex_state = 91, .external_lex_state = 15},
  [3280] = {.lex_state = 91, .external_lex_state = 12},
  [3281] = {.lex_state = 91, .external_lex_state = 15},
  [3282] = {.lex_state = 91, .external_lex_state = 15},
  [3283] = {.lex_state = 91, .external_lex_state = 12},
  [3284] = {.lex_state = 91, .external_lex_state = 12},
  [3285] = {.lex_state = 91, .external_lex_state = 12},
  [3286] = {.lex_state = 91, .external_lex_state = 12},
  [3287] = {.lex_state = 91, .external_lex_state = 12},
  [3288] = {.lex_state = 91, .external_lex_state = 12},
  [3289] = {.lex_state = 91, .external_lex_state = 12},
  [3290] = {.lex_state = 91, .external_lex_state = 12},
  [3291] = {.lex_state = 91, .external_lex_state = 12},
  [3292] = {.lex_state = 91, .external_lex_state = 12},
  [3293] = {.lex_state = 91, .external_lex_state = 12},
  [3294] = {.lex_state = 91, .external_lex_state = 12},
  [3295] = {.lex_state = 91, .external_lex_state = 12},
  [3296] = {.lex_state = 91, .external_lex_state = 12},
  [3297] = {.lex_state = 91, .external_lex_state = 12},
  [3298] = {.lex_state = 91, .external_lex_state = 12},
  [3299] = {.lex_state = 91, .external_lex_state = 12},
  [3300] = {.lex_state = 91, .external_lex_state = 12},
  [3301] = {.lex_state = 91, .external_lex_state = 12},
  [3302] = {.lex_state = 91, .external_lex_state = 12},
  [3303] = {.lex_state = 91, .external_lex_state = 12},
  [3304] = {.lex_state = 91, .external_lex_state = 12},
  [3305] = {.lex_state = 91, .external_lex_state = 12},
  [3306] = {.lex_state = 91, .external_lex_state = 12},
  [3307] = {.lex_state = 91, .external_lex_state = 12},
  [3308] = {.lex_state = 91, .external_lex_state = 12},
  [3309] = {.lex_state = 91, .external_lex_state = 15},
  [3310] = {.lex_state = 91, .external_lex_state = 12},
  [3311] = {.lex_state = 91, .external_lex_state = 12},
  [3312] = {.lex_state = 91, .external_lex_state = 12},
  [3313] = {.lex_state = 91, .external_lex_state = 12},
  [3314] = {.lex_state = 91, .external_lex_state = 12},
  [3315] = {.lex_state = 91, .external_lex_state = 12},
  [3316] = {.lex_state = 91, .external_lex_state = 12},
  [3317] = {.lex_state = 91, .external_lex_state = 12},
  [3318] = {.lex_state = 91, .external_lex_state = 12},
  [3319] = {.lex_state = 91, .external_lex_state = 12},
  [3320] = {.lex_state = 91, .external_lex_state = 12},
  [3321] = {.lex_state = 91, .external_lex_state = 12},
  [3322] = {.lex_state = 91, .external_lex_state = 12},
  [3323] = {.lex_state = 91, .external_lex_state = 12},
  [3324] = {.lex_state = 91, .external_lex_state = 12},
  [3325] = {.lex_state = 91, .external_lex_state = 15},
  [3326] = {.lex_state = 91, .external_lex_state = 12},
  [3327] = {.lex_state = 91, .external_lex_state = 12},
  [3328] = {.lex_state = 91, .external_lex_state = 12},
  [3329] = {.lex_state = 91, .external_lex_state = 12},
  [3330] = {.lex_state = 91, .external_lex_state = 15},
  [3331] = {.lex_state = 91, .external_lex_state = 12},
  [3332] = {.lex_state = 91, .external_lex_state = 12},
  [3333] = {.lex_state = 91, .external_lex_state = 15},
  [3334] = {.lex_state = 91, .external_lex_state = 12},
  [3335] = {.lex_state = 91, .external_lex_state = 12},
  [3336] = {.lex_state = 91, .external_lex_state = 15},
  [3337] = {.lex_state = 91, .external_lex_state = 15},
  [3338] = {.lex_state = 91, .external_lex_state = 15},
  [3339] = {.lex_state = 91, .external_lex_state = 12},
  [3340] = {.lex_state = 91, .external_lex_state = 15},
  [3341] = {.lex_state = 91, .external_lex_state = 12},
  [3342] = {.lex_state = 91, .external_lex_state = 12},
  [3343] = {.lex_state = 91, .external_lex_state = 12},
  [3344] = {.lex_state = 91, .external_lex_state = 12},
  [3345] = {.lex_state = 91, .external_lex_state = 3},
  [3346] = {.lex_state = 91, .external_lex_state = 3},
  [3347] = {.lex_state = 91, .external_lex_state = 15},
  [3348] = {.lex_state = 91, .external_lex_state = 15},
  [3349] = {.lex_state = 91, .external_lex_state = 3},
  [3350] = {.lex_state = 6},
  [3351] = {.lex_state = 91, .external_lex_state = 3},
  [3352] = {.lex_state = 91, .external_lex_state = 15},
  [3353] = {.lex_state = 6},
  [3354] = {.lex_state = 91, .external_lex_state = 3},
  [3355] = {.lex_state = 91, .external_lex_state = 3},
  [3356] = {.lex_state = 91, .external_lex_state = 3},
  [3357] = {.lex_state = 91, .external_lex_state = 3},
  [3358] = {.lex_state = 91, .external_lex_state = 3},
  [3359] = {.lex_state = 91, .external_lex_state = 3},
  [3360] = {.lex_state = 91, .external_lex_state = 3},
  [3361] = {.lex_state = 91, .external_lex_state = 3},
  [3362] = {.lex_state = 6},
  [3363] = {.lex_state = 5, .external_lex_state = 23},
  [3364] = {.lex_state = 91, .external_lex_state = 15},
  [3365] = {.lex_state = 91, .external_lex_state = 15},
  [3366] = {.lex_state = 91, .external_lex_state = 15},
  [3367] = {.lex_state = 91, .external_lex_state = 15},
  [3368] = {.lex_state = 5, .external_lex_state = 21},
  [3369] = {.lex_state = 3, .external_lex_state = 3},
  [3370] = {.lex_state = 91, .external_lex_state = 11},
  [3371] = {.lex_state = 91, .external_lex_state = 11},
  [3372] = {.lex_state = 2, .external_lex_state = 23},
  [3373] = {.lex_state = 91, .external_lex_state = 12},
  [3374] = {.lex_state = 91, .external_lex_state = 11},
  [3375] = {.lex_state = 91, .external_lex_state = 12},
  [3376] = {.lex_state = 5, .external_lex_state = 23},
  [3377] = {.lex_state = 91, .external_lex_state = 11},
  [3378] = {.lex_state = 91, .external_lex_state = 3},
  [3379] = {.lex_state = 91, .external_lex_state = 15},
  [3380] = {.lex_state = 91, .external_lex_state = 3},
  [3381] = {.lex_state = 91, .external_lex_state = 15},
  [3382] = {.lex_state = 91, .external_lex_state = 3},
  [3383] = {.lex_state = 91, .external_lex_state = 15},
  [3384] = {.lex_state = 91, .external_lex_state = 11},
  [3385] = {.lex_state = 91, .external_lex_state = 3},
  [3386] = {.lex_state = 91, .external_lex_state = 3},
  [3387] = {.lex_state = 91, .external_lex_state = 15},
  [3388] = {.lex_state = 91, .external_lex_state = 12},
  [3389] = {.lex_state = 91, .external_lex_state = 3},
  [3390] = {.lex_state = 91, .external_lex_state = 12},
  [3391] = {.lex_state = 91, .external_lex_state = 3},
  [3392] = {.lex_state = 91, .external_lex_state = 3},
  [3393] = {.lex_state = 91, .external_lex_state = 3},
  [3394] = {.lex_state = 91, .external_lex_state = 3},
  [3395] = {.lex_state = 91, .external_lex_state = 3},
  [3396] = {.lex_state = 91, .external_lex_state = 12},
  [3397] = {.lex_state = 91, .external_lex_state = 3},
  [3398] = {.lex_state = 91, .external_lex_state = 3},
  [3399] = {.lex_state = 91, .external_lex_state = 3},
  [3400] = {.lex_state = 91, .external_lex_state = 3},
  [3401] = {.lex_state = 91, .external_lex_state = 3},
  [3402] = {.lex_state = 5, .external_lex_state = 23},
  [3403] = {.lex_state = 91, .external_lex_state = 11},
  [3404] = {.lex_state = 91, .external_lex_state = 11},
  [3405] = {.lex_state = 91, .external_lex_state = 11},
  [3406] = {.lex_state = 91, .external_lex_state = 11},
  [3407] = {.lex_state = 91, .external_lex_state = 11},
  [3408] = {.lex_state = 91, .external_lex_state = 3},
  [3409] = {.lex_state = 91, .external_lex_state = 12},
  [3410] = {.lex_state = 91, .external_lex_state = 15},
  [3411] = {.lex_state = 91, .external_lex_state = 3},
  [3412] = {.lex_state = 91, .external_lex_state = 15},
  [3413] = {.lex_state = 91, .external_lex_state = 3},
  [3414] = {.lex_state = 91, .external_lex_state = 3},
  [3415] = {.lex_state = 91, .external_lex_state = 3},
  [3416] = {.lex_state = 91, .external_lex_state = 3},
  [3417] = {.lex_state = 91, .external_lex_state = 12},
  [3418] = {.lex_state = 91, .external_lex_state = 12},
  [3419] = {.lex_state = 91, .external_lex_state = 12},
  [3420] = {.lex_state = 91, .external_lex_state = 3},
  [3421] = {.lex_state = 91, .external_lex_state = 3},
  [3422] = {.lex_state = 91, .external_lex_state = 15},
  [3423] = {.lex_state = 91, .external_lex_state = 3},
  [3424] = {.lex_state = 91, .external_lex_state = 15},
  [3425] = {.lex_state = 91, .external_lex_state = 15},
  [3426] = {.lex_state = 91, .external_lex_state = 3},
  [3427] = {.lex_state = 91, .external_lex_state = 12},
  [3428] = {.lex_state = 91, .external_lex_state = 12},
  [3429] = {.lex_state = 91, .external_lex_state = 3},
  [3430] = {.lex_state = 91, .external_lex_state = 12},
  [3431] = {.lex_state = 91, .external_lex_state = 3},
  [3432] = {.lex_state = 91, .external_lex_state = 3},
  [3433] = {.lex_state = 91, .external_lex_state = 3},
  [3434] = {.lex_state = 91, .external_lex_state = 3},
  [3435] = {.lex_state = 91, .external_lex_state = 3},
  [3436] = {.lex_state = 91, .external_lex_state = 3},
  [3437] = {.lex_state = 91},
  [3438] = {.lex_state = 91, .external_lex_state = 3},
  [3439] = {.lex_state = 91, .external_lex_state = 3},
  [3440] = {.lex_state = 91, .external_lex_state = 3},
  [3441] = {.lex_state = 91, .external_lex_state = 3},
  [3442] = {.lex_state = 91, .external_lex_state = 3},
  [3443] = {.lex_state = 91, .external_lex_state = 3},
  [3444] = {.lex_state = 91, .external_lex_state = 3},
  [3445] = {.lex_state = 91, .external_lex_state = 11},
  [3446] = {.lex_state = 91, .external_lex_state = 11},
  [3447] = {.lex_state = 91},
  [3448] = {.lex_state = 91},
  [3449] = {.lex_state = 91},
  [3450] = {.lex_state = 91, .external_lex_state = 3},
  [3451] = {.lex_state = 91},
  [3452] = {.lex_state = 91},
  [3453] = {.lex_state = 91},
  [3454] = {.lex_state = 91},
  [3455] = {.lex_state = 91},
  [3456] = {.lex_state = 91},
  [3457] = {.lex_state = 91},
  [3458] = {.lex_state = 91, .external_lex_state = 11},
  [3459] = {.lex_state = 91},
  [3460] = {.lex_state = 91},
  [3461] = {.lex_state = 91},
  [3462] = {.lex_state = 91, .external_lex_state = 11},
  [3463] = {.lex_state = 5, .external_lex_state = 24},
  [3464] = {.lex_state = 91, .external_lex_state = 12},
  [3465] = {.lex_state = 91, .external_lex_state = 15},
  [3466] = {.lex_state = 91, .external_lex_state = 12},
  [3467] = {.lex_state = 91, .external_lex_state = 15},
  [3468] = {.lex_state = 91, .external_lex_state = 12},
  [3469] = {.lex_state = 91, .external_lex_state = 12},
  [3470] = {.lex_state = 91, .external_lex_state = 15},
  [3471] = {.lex_state = 91, .external_lex_state = 15},
  [3472] = {.lex_state = 91, .external_lex_state = 12},
  [3473] = {.lex_state = 91, .external_lex_state = 12},
  [3474] = {.lex_state = 91, .external_lex_state = 12},
  [3475] = {.lex_state = 91, .external_lex_state = 12},
  [3476] = {.lex_state = 91, .external_lex_state = 12},
  [3477] = {.lex_state = 91, .external_lex_state = 12},
  [3478] = {.lex_state = 91, .external_lex_state = 15},
  [3479] = {.lex_state = 91, .external_lex_state = 12},
  [3480] = {.lex_state = 91, .external_lex_state = 12},
  [3481] = {.lex_state = 91, .external_lex_state = 15},
  [3482] = {.lex_state = 91, .external_lex_state = 12},
  [3483] = {.lex_state = 91, .external_lex_state = 15},
  [3484] = {.lex_state = 91, .external_lex_state = 12},
  [3485] = {.lex_state = 91, .external_lex_state = 12},
  [3486] = {.lex_state = 91, .external_lex_state = 12},
  [3487] = {.lex_state = 91, .external_lex_state = 12},
  [3488] = {.lex_state = 91, .external_lex_state = 15},
  [3489] = {.lex_state = 91, .external_lex_state = 15},
  [3490] = {.lex_state = 91, .external_lex_state = 12},
  [3491] = {.lex_state = 91, .external_lex_state = 15},
  [3492] = {.lex_state = 91, .external_lex_state = 12},
  [3493] = {.lex_state = 91, .external_lex_state = 12},
  [3494] = {.lex_state = 91, .external_lex_state = 12},
  [3495] = {.lex_state = 91},
  [3496] = {.lex_state = 91, .external_lex_state = 12},
  [3497] = {.lex_state = 91, .external_lex_state = 3},
  [3498] = {.lex_state = 91, .external_lex_state = 12},
  [3499] = {.lex_state = 91, .external_lex_state = 12},
  [3500] = {.lex_state = 5, .external_lex_state = 24},
  [3501] = {.lex_state = 91, .external_lex_state = 15},
  [3502] = {.lex_state = 91, .external_lex_state = 15},
  [3503] = {.lex_state = 91, .external_lex_state = 15},
  [3504] = {.lex_state = 91},
  [3505] = {.lex_state = 91, .external_lex_state = 12},
  [3506] = {.lex_state = 91, .external_lex_state = 12},
  [3507] = {.lex_state = 91, .external_lex_state = 12},
  [3508] = {.lex_state = 91, .external_lex_state = 12},
  [3509] = {.lex_state = 91, .external_lex_state = 12},
  [3510] = {.lex_state = 91, .external_lex_state = 12},
  [3511] = {.lex_state = 91, .external_lex_state = 12},
  [3512] = {.lex_state = 91, .external_lex_state = 12},
  [3513] = {.lex_state = 91, .external_lex_state = 12},
  [3514] = {.lex_state = 91, .external_lex_state = 12},
  [3515] = {.lex_state = 91, .external_lex_state = 12},
  [3516] = {.lex_state = 91, .external_lex_state = 12},
  [3517] = {.lex_state = 91, .external_lex_state = 12},
  [3518] = {.lex_state = 91, .external_lex_state = 12},
  [3519] = {.lex_state = 91, .external_lex_state = 12},
  [3520] = {.lex_state = 91, .external_lex_state = 12},
  [3521] = {.lex_state = 91, .external_lex_state = 12},
  [3522] = {.lex_state = 91, .external_lex_state = 12},
  [3523] = {.lex_state = 91, .external_lex_state = 12},
  [3524] = {.lex_state = 91, .external_lex_state = 12},
  [3525] = {.lex_state = 91, .external_lex_state = 12},
  [3526] = {.lex_state = 91, .external_lex_state = 12},
  [3527] = {.lex_state = 91, .external_lex_state = 12},
  [3528] = {.lex_state = 91, .external_lex_state = 12},
  [3529] = {.lex_state = 91, .external_lex_state = 12},
  [3530] = {.lex_state = 91, .external_lex_state = 12},
  [3531] = {.lex_state = 91, .external_lex_state = 12},
  [3532] = {.lex_state = 91, .external_lex_state = 12},
  [3533] = {.lex_state = 91, .external_lex_state = 12},
  [3534] = {.lex_state = 91, .external_lex_state = 12},
  [3535] = {.lex_state = 91, .external_lex_state = 12},
  [3536] = {.lex_state = 91, .external_lex_state = 12},
  [3537] = {.lex_state = 91, .external_lex_state = 12},
  [3538] = {.lex_state = 91, .external_lex_state = 12},
  [3539] = {.lex_state = 91, .external_lex_state = 12},
  [3540] = {.lex_state = 91, .external_lex_state = 12},
  [3541] = {.lex_state = 91, .external_lex_state = 12},
  [3542] = {.lex_state = 91, .external_lex_state = 12},
  [3543] = {.lex_state = 91, .external_lex_state = 12},
  [3544] = {.lex_state = 91, .external_lex_state = 12},
  [3545] = {.lex_state = 91, .external_lex_state = 12},
  [3546] = {.lex_state = 91, .external_lex_state = 12},
  [3547] = {.lex_state = 91, .external_lex_state = 12},
  [3548] = {.lex_state = 91, .external_lex_state = 12},
  [3549] = {.lex_state = 91, .external_lex_state = 12},
  [3550] = {.lex_state = 91, .external_lex_state = 12},
  [3551] = {.lex_state = 91, .external_lex_state = 12},
  [3552] = {.lex_state = 91, .external_lex_state = 12},
  [3553] = {.lex_state = 91, .external_lex_state = 12},
  [3554] = {.lex_state = 91, .external_lex_state = 12},
  [3555] = {.lex_state = 91, .external_lex_state = 12},
  [3556] = {.lex_state = 91, .external_lex_state = 12},
  [3557] = {.lex_state = 91, .external_lex_state = 12},
  [3558] = {.lex_state = 91, .external_lex_state = 12},
  [3559] = {.lex_state = 91, .external_lex_state = 12},
  [3560] = {.lex_state = 91, .external_lex_state = 12},
  [3561] = {.lex_state = 91, .external_lex_state = 12},
  [3562] = {.lex_state = 91, .external_lex_state = 12},
  [3563] = {.lex_state = 91, .external_lex_state = 12},
  [3564] = {.lex_state = 91, .external_lex_state = 12},
  [3565] = {.lex_state = 91, .external_lex_state = 12},
  [3566] = {.lex_state = 91, .external_lex_state = 12},
  [3567] = {.lex_state = 91, .external_lex_state = 12},
  [3568] = {.lex_state = 91, .external_lex_state = 12},
  [3569] = {.lex_state = 91, .external_lex_state = 12},
  [3570] = {.lex_state = 91, .external_lex_state = 12},
  [3571] = {.lex_state = 91, .external_lex_state = 12},
  [3572] = {.lex_state = 91, .external_lex_state = 12},
  [3573] = {.lex_state = 91, .external_lex_state = 12},
  [3574] = {.lex_state = 91, .external_lex_state = 12},
  [3575] = {.lex_state = 91, .external_lex_state = 12},
  [3576] = {.lex_state = 91, .external_lex_state = 12},
  [3577] = {.lex_state = 91, .external_lex_state = 12},
  [3578] = {.lex_state = 91, .external_lex_state = 12},
  [3579] = {.lex_state = 91, .external_lex_state = 12},
  [3580] = {.lex_state = 91, .external_lex_state = 12},
  [3581] = {.lex_state = 91, .external_lex_state = 12},
  [3582] = {.lex_state = 91, .external_lex_state = 12},
  [3583] = {.lex_state = 91, .external_lex_state = 12},
  [3584] = {.lex_state = 91, .external_lex_state = 12},
  [3585] = {.lex_state = 91, .external_lex_state = 12},
  [3586] = {.lex_state = 91, .external_lex_state = 12},
  [3587] = {.lex_state = 91, .external_lex_state = 12},
  [3588] = {.lex_state = 91, .external_lex_state = 12},
  [3589] = {.lex_state = 91, .external_lex_state = 12},
  [3590] = {.lex_state = 91, .external_lex_state = 12},
  [3591] = {.lex_state = 91, .external_lex_state = 12},
  [3592] = {.lex_state = 91, .external_lex_state = 12},
  [3593] = {.lex_state = 91, .external_lex_state = 12},
  [3594] = {.lex_state = 91, .external_lex_state = 12},
  [3595] = {.lex_state = 91, .external_lex_state = 12},
  [3596] = {.lex_state = 91, .external_lex_state = 12},
  [3597] = {.lex_state = 91, .external_lex_state = 12},
  [3598] = {.lex_state = 91, .external_lex_state = 12},
  [3599] = {.lex_state = 91, .external_lex_state = 12},
  [3600] = {.lex_state = 91, .external_lex_state = 12},
  [3601] = {.lex_state = 91, .external_lex_state = 12},
  [3602] = {.lex_state = 91, .external_lex_state = 12},
  [3603] = {.lex_state = 91, .external_lex_state = 12},
  [3604] = {.lex_state = 91, .external_lex_state = 12},
  [3605] = {.lex_state = 91, .external_lex_state = 12},
  [3606] = {.lex_state = 91, .external_lex_state = 12},
  [3607] = {.lex_state = 91, .external_lex_state = 12},
  [3608] = {.lex_state = 91, .external_lex_state = 12},
  [3609] = {.lex_state = 91, .external_lex_state = 12},
  [3610] = {.lex_state = 91, .external_lex_state = 12},
  [3611] = {.lex_state = 91, .external_lex_state = 12},
  [3612] = {.lex_state = 91, .external_lex_state = 12},
  [3613] = {.lex_state = 91, .external_lex_state = 12},
  [3614] = {.lex_state = 91, .external_lex_state = 12},
  [3615] = {.lex_state = 91, .external_lex_state = 12},
  [3616] = {.lex_state = 91, .external_lex_state = 12},
  [3617] = {.lex_state = 91, .external_lex_state = 12},
  [3618] = {.lex_state = 91, .external_lex_state = 12},
  [3619] = {.lex_state = 91, .external_lex_state = 12},
  [3620] = {.lex_state = 91, .external_lex_state = 12},
  [3621] = {.lex_state = 91, .external_lex_state = 12},
  [3622] = {.lex_state = 91, .external_lex_state = 12},
  [3623] = {.lex_state = 91, .external_lex_state = 12},
  [3624] = {.lex_state = 91, .external_lex_state = 12},
  [3625] = {.lex_state = 91, .external_lex_state = 12},
  [3626] = {.lex_state = 91, .external_lex_state = 12},
  [3627] = {.lex_state = 91, .external_lex_state = 12},
  [3628] = {.lex_state = 91, .external_lex_state = 12},
  [3629] = {.lex_state = 91, .external_lex_state = 12},
  [3630] = {.lex_state = 91, .external_lex_state = 12},
  [3631] = {.lex_state = 91, .external_lex_state = 12},
  [3632] = {.lex_state = 91, .external_lex_state = 12},
  [3633] = {.lex_state = 91, .external_lex_state = 12},
  [3634] = {.lex_state = 91, .external_lex_state = 12},
  [3635] = {.lex_state = 91, .external_lex_state = 12},
  [3636] = {.lex_state = 91, .external_lex_state = 12},
  [3637] = {.lex_state = 91, .external_lex_state = 12},
  [3638] = {.lex_state = 91, .external_lex_state = 12},
  [3639] = {.lex_state = 91, .external_lex_state = 12},
  [3640] = {.lex_state = 91, .external_lex_state = 12},
  [3641] = {.lex_state = 91, .external_lex_state = 12},
  [3642] = {.lex_state = 91, .external_lex_state = 12},
  [3643] = {.lex_state = 91, .external_lex_state = 12},
  [3644] = {.lex_state = 91, .external_lex_state = 12},
  [3645] = {.lex_state = 91, .external_lex_state = 12},
  [3646] = {.lex_state = 91, .external_lex_state = 12},
  [3647] = {.lex_state = 91, .external_lex_state = 12},
  [3648] = {.lex_state = 91, .external_lex_state = 12},
  [3649] = {.lex_state = 91, .external_lex_state = 12},
  [3650] = {.lex_state = 91, .external_lex_state = 12},
  [3651] = {.lex_state = 91, .external_lex_state = 12},
  [3652] = {.lex_state = 91, .external_lex_state = 12},
  [3653] = {.lex_state = 91, .external_lex_state = 12},
  [3654] = {.lex_state = 91, .external_lex_state = 12},
  [3655] = {.lex_state = 91, .external_lex_state = 12},
  [3656] = {.lex_state = 91, .external_lex_state = 12},
  [3657] = {.lex_state = 91, .external_lex_state = 12},
  [3658] = {.lex_state = 91, .external_lex_state = 12},
  [3659] = {.lex_state = 91, .external_lex_state = 12},
  [3660] = {.lex_state = 91, .external_lex_state = 12},
  [3661] = {.lex_state = 91, .external_lex_state = 17},
  [3662] = {.lex_state = 91, .external_lex_state = 17},
  [3663] = {.lex_state = 91, .external_lex_state = 17},
  [3664] = {.lex_state = 91, .external_lex_state = 12},
  [3665] = {.lex_state = 91, .external_lex_state = 12},
  [3666] = {.lex_state = 91, .external_lex_state = 12},
  [3667] = {.lex_state = 91, .external_lex_state = 17},
  [3668] = {.lex_state = 91, .external_lex_state = 12},
  [3669] = {.lex_state = 91, .external_lex_state = 17},
  [3670] = {.lex_state = 91, .external_lex_state = 12},
  [3671] = {.lex_state = 91, .external_lex_state = 12},
  [3672] = {.lex_state = 91, .external_lex_state = 12},
  [3673] = {.lex_state = 91, .external_lex_state = 12},
  [3674] = {.lex_state = 91, .external_lex_state = 12},
  [3675] = {.lex_state = 91, .external_lex_state = 12},
  [3676] = {.lex_state = 91, .external_lex_state = 12},
  [3677] = {.lex_state = 91, .external_lex_state = 12},
  [3678] = {.lex_state = 91, .external_lex_state = 12},
  [3679] = {.lex_state = 91, .external_lex_state = 12},
  [3680] = {.lex_state = 91, .external_lex_state = 12},
  [3681] = {.lex_state = 91, .external_lex_state = 12},
  [3682] = {.lex_state = 91, .external_lex_state = 12},
  [3683] = {.lex_state = 91, .external_lex_state = 12},
  [3684] = {.lex_state = 91, .external_lex_state = 12},
  [3685] = {.lex_state = 91, .external_lex_state = 12},
  [3686] = {.lex_state = 91, .external_lex_state = 12},
  [3687] = {.lex_state = 91, .external_lex_state = 12},
  [3688] = {.lex_state = 91, .external_lex_state = 12},
  [3689] = {.lex_state = 91, .external_lex_state = 12},
  [3690] = {.lex_state = 91, .external_lex_state = 12},
  [3691] = {.lex_state = 91, .external_lex_state = 12},
  [3692] = {.lex_state = 91, .external_lex_state = 12},
  [3693] = {.lex_state = 91, .external_lex_state = 12},
  [3694] = {.lex_state = 91, .external_lex_state = 12},
  [3695] = {.lex_state = 91, .external_lex_state = 12},
  [3696] = {.lex_state = 91, .external_lex_state = 12},
  [3697] = {.lex_state = 91, .external_lex_state = 12},
  [3698] = {.lex_state = 91, .external_lex_state = 12},
  [3699] = {.lex_state = 91, .external_lex_state = 12},
  [3700] = {.lex_state = 91, .external_lex_state = 12},
  [3701] = {.lex_state = 91, .external_lex_state = 12},
  [3702] = {.lex_state = 91, .external_lex_state = 12},
  [3703] = {.lex_state = 91, .external_lex_state = 12},
  [3704] = {.lex_state = 91, .external_lex_state = 12},
  [3705] = {.lex_state = 91, .external_lex_state = 12},
  [3706] = {.lex_state = 91, .external_lex_state = 12},
  [3707] = {.lex_state = 91, .external_lex_state = 12},
  [3708] = {.lex_state = 91, .external_lex_state = 12},
  [3709] = {.lex_state = 91, .external_lex_state = 12},
  [3710] = {.lex_state = 91, .external_lex_state = 12},
  [3711] = {.lex_state = 91, .external_lex_state = 12},
  [3712] = {.lex_state = 91, .external_lex_state = 12},
  [3713] = {.lex_state = 91, .external_lex_state = 12},
  [3714] = {.lex_state = 91, .external_lex_state = 12},
  [3715] = {.lex_state = 91, .external_lex_state = 12},
  [3716] = {.lex_state = 91, .external_lex_state = 12},
  [3717] = {.lex_state = 91, .external_lex_state = 12},
  [3718] = {.lex_state = 91, .external_lex_state = 12},
  [3719] = {.lex_state = 91, .external_lex_state = 12},
  [3720] = {.lex_state = 91, .external_lex_state = 12},
  [3721] = {.lex_state = 91, .external_lex_state = 12},
  [3722] = {.lex_state = 91, .external_lex_state = 12},
  [3723] = {.lex_state = 91, .external_lex_state = 12},
  [3724] = {.lex_state = 91, .external_lex_state = 12},
  [3725] = {.lex_state = 91, .external_lex_state = 12},
  [3726] = {.lex_state = 91, .external_lex_state = 12},
  [3727] = {.lex_state = 91, .external_lex_state = 12},
  [3728] = {.lex_state = 91, .external_lex_state = 12},
  [3729] = {.lex_state = 91, .external_lex_state = 12},
  [3730] = {.lex_state = 5, .external_lex_state = 24},
  [3731] = {.lex_state = 91, .external_lex_state = 12},
  [3732] = {.lex_state = 91, .external_lex_state = 12},
  [3733] = {.lex_state = 91, .external_lex_state = 12},
  [3734] = {.lex_state = 91, .external_lex_state = 12},
  [3735] = {.lex_state = 91, .external_lex_state = 12},
  [3736] = {.lex_state = 91, .external_lex_state = 12},
  [3737] = {.lex_state = 91, .external_lex_state = 12},
  [3738] = {.lex_state = 91, .external_lex_state = 12},
  [3739] = {.lex_state = 91, .external_lex_state = 12},
  [3740] = {.lex_state = 91, .external_lex_state = 12},
  [3741] = {.lex_state = 91, .external_lex_state = 12},
  [3742] = {.lex_state = 91, .external_lex_state = 12},
  [3743] = {.lex_state = 91, .external_lex_state = 12},
  [3744] = {.lex_state = 91, .external_lex_state = 12},
  [3745] = {.lex_state = 91, .external_lex_state = 12},
  [3746] = {.lex_state = 91, .external_lex_state = 12},
  [3747] = {.lex_state = 91, .external_lex_state = 12},
  [3748] = {.lex_state = 91, .external_lex_state = 12},
  [3749] = {.lex_state = 91, .external_lex_state = 12},
  [3750] = {.lex_state = 91, .external_lex_state = 12},
  [3751] = {.lex_state = 91, .external_lex_state = 12},
  [3752] = {.lex_state = 91, .external_lex_state = 12},
  [3753] = {.lex_state = 91, .external_lex_state = 12},
  [3754] = {.lex_state = 91, .external_lex_state = 12},
  [3755] = {.lex_state = 91, .external_lex_state = 12},
  [3756] = {.lex_state = 91, .external_lex_state = 12},
  [3757] = {.lex_state = 91, .external_lex_state = 12},
  [3758] = {.lex_state = 91, .external_lex_state = 12},
  [3759] = {.lex_state = 91, .external_lex_state = 12},
  [3760] = {.lex_state = 91, .external_lex_state = 12},
  [3761] = {.lex_state = 91, .external_lex_state = 12},
  [3762] = {.lex_state = 91, .external_lex_state = 12},
  [3763] = {.lex_state = 91, .external_lex_state = 12},
  [3764] = {.lex_state = 91, .external_lex_state = 12},
  [3765] = {.lex_state = 91, .external_lex_state = 12},
  [3766] = {.lex_state = 91, .external_lex_state = 12},
  [3767] = {.lex_state = 91, .external_lex_state = 12},
  [3768] = {.lex_state = 91, .external_lex_state = 12},
  [3769] = {.lex_state = 91, .external_lex_state = 12},
  [3770] = {.lex_state = 91, .external_lex_state = 12},
  [3771] = {.lex_state = 91, .external_lex_state = 12},
  [3772] = {.lex_state = 91, .external_lex_state = 12},
  [3773] = {.lex_state = 91, .external_lex_state = 12},
  [3774] = {.lex_state = 91, .external_lex_state = 12},
  [3775] = {.lex_state = 91, .external_lex_state = 12},
  [3776] = {.lex_state = 91, .external_lex_state = 12},
  [3777] = {.lex_state = 91, .external_lex_state = 12},
  [3778] = {.lex_state = 91, .external_lex_state = 12},
  [3779] = {.lex_state = 91, .external_lex_state = 12},
  [3780] = {.lex_state = 91, .external_lex_state = 12},
  [3781] = {.lex_state = 91, .external_lex_state = 12},
  [3782] = {.lex_state = 91, .external_lex_state = 12},
  [3783] = {.lex_state = 91, .external_lex_state = 12},
  [3784] = {.lex_state = 91, .external_lex_state = 12},
  [3785] = {.lex_state = 91, .external_lex_state = 12},
  [3786] = {.lex_state = 91, .external_lex_state = 12},
  [3787] = {.lex_state = 91, .external_lex_state = 12},
  [3788] = {.lex_state = 91, .external_lex_state = 12},
  [3789] = {.lex_state = 91, .external_lex_state = 12},
  [3790] = {.lex_state = 91, .external_lex_state = 12},
  [3791] = {.lex_state = 91, .external_lex_state = 12},
  [3792] = {.lex_state = 91, .external_lex_state = 12},
  [3793] = {.lex_state = 91, .external_lex_state = 12},
  [3794] = {.lex_state = 91, .external_lex_state = 12},
  [3795] = {.lex_state = 91, .external_lex_state = 12},
  [3796] = {.lex_state = 91, .external_lex_state = 12},
  [3797] = {.lex_state = 91, .external_lex_state = 12},
  [3798] = {.lex_state = 91, .external_lex_state = 22},
  [3799] = {.lex_state = 91, .external_lex_state = 22},
  [3800] = {.lex_state = 91, .external_lex_state = 22},
  [3801] = {.lex_state = 91, .external_lex_state = 22},
  [3802] = {.lex_state = 91, .external_lex_state = 15},
  [3803] = {.lex_state = 91, .external_lex_state = 22},
  [3804] = {.lex_state = 91, .external_lex_state = 15},
  [3805] = {.lex_state = 91, .external_lex_state = 22},
  [3806] = {.lex_state = 91, .external_lex_state = 22},
  [3807] = {.lex_state = 91, .external_lex_state = 22},
  [3808] = {.lex_state = 91, .external_lex_state = 15},
  [3809] = {.lex_state = 91, .external_lex_state = 22},
  [3810] = {.lex_state = 91, .external_lex_state = 22},
  [3811] = {.lex_state = 91, .external_lex_state = 22},
  [3812] = {.lex_state = 91, .external_lex_state = 22},
  [3813] = {.lex_state = 91, .external_lex_state = 16},
  [3814] = {.lex_state = 91, .external_lex_state = 22},
  [3815] = {.lex_state = 91, .external_lex_state = 22},
  [3816] = {.lex_state = 91, .external_lex_state = 22},
  [3817] = {.lex_state = 91, .external_lex_state = 22},
  [3818] = {.lex_state = 91, .external_lex_state = 22},
  [3819] = {.lex_state = 91, .external_lex_state = 22},
  [3820] = {.lex_state = 91, .external_lex_state = 22},
  [3821] = {.lex_state = 91, .external_lex_state = 22},
  [3822] = {.lex_state = 91, .external_lex_state = 22},
  [3823] = {.lex_state = 91, .external_lex_state = 22},
  [3824] = {.lex_state = 91, .external_lex_state = 22},
  [3825] = {.lex_state = 91, .external_lex_state = 22},
  [3826] = {.lex_state = 91, .external_lex_state = 22},
  [3827] = {.lex_state = 91, .external_lex_state = 22},
  [3828] = {.lex_state = 91, .external_lex_state = 16},
  [3829] = {.lex_state = 91, .external_lex_state = 22},
  [3830] = {.lex_state = 91, .external_lex_state = 22},
  [3831] = {.lex_state = 91, .external_lex_state = 22},
  [3832] = {.lex_state = 91, .external_lex_state = 22},
  [3833] = {.lex_state = 91, .external_lex_state = 22},
  [3834] = {.lex_state = 91, .external_lex_state = 22},
  [3835] = {.lex_state = 91, .external_lex_state = 22},
  [3836] = {.lex_state = 91, .external_lex_state = 22},
  [3837] = {.lex_state = 91, .external_lex_state = 16},
  [3838] = {.lex_state = 91, .external_lex_state = 22},
  [3839] = {.lex_state = 91, .external_lex_state = 16},
  [3840] = {.lex_state = 91, .external_lex_state = 22},
  [3841] = {.lex_state = 91, .external_lex_state = 22},
  [3842] = {.lex_state = 91, .external_lex_state = 22},
  [3843] = {.lex_state = 91, .external_lex_state = 22},
  [3844] = {.lex_state = 91, .external_lex_state = 22},
  [3845] = {.lex_state = 91, .external_lex_state = 22},
  [3846] = {.lex_state = 91, .external_lex_state = 22},
  [3847] = {.lex_state = 91, .external_lex_state = 22},
  [3848] = {.lex_state = 91, .external_lex_state = 22},
  [3849] = {.lex_state = 91, .external_lex_state = 22},
  [3850] = {.lex_state = 91, .external_lex_state = 22},
  [3851] = {.lex_state = 91, .external_lex_state = 22},
  [3852] = {.lex_state = 91, .external_lex_state = 11},
  [3853] = {.lex_state = 91, .external_lex_state = 22},
  [3854] = {.lex_state = 91, .external_lex_state = 15},
  [3855] = {.lex_state = 91, .external_lex_state = 22},
  [3856] = {.lex_state = 91, .external_lex_state = 22},
  [3857] = {.lex_state = 91, .external_lex_state = 22},
  [3858] = {.lex_state = 91, .external_lex_state = 22},
  [3859] = {.lex_state = 91, .external_lex_state = 22},
  [3860] = {.lex_state = 91, .external_lex_state = 22},
  [3861] = {.lex_state = 91, .external_lex_state = 22},
  [3862] = {.lex_state = 91, .external_lex_state = 22},
  [3863] = {.lex_state = 91, .external_lex_state = 22},
  [3864] = {.lex_state = 91, .external_lex_state = 22},
  [3865] = {.lex_state = 91, .external_lex_state = 22},
  [3866] = {.lex_state = 91, .external_lex_state = 22},
  [3867] = {.lex_state = 91, .external_lex_state = 15},
  [3868] = {.lex_state = 91, .external_lex_state = 15},
  [3869] = {.lex_state = 91, .external_lex_state = 15},
  [3870] = {.lex_state = 91, .external_lex_state = 15},
  [3871] = {.lex_state = 91, .external_lex_state = 15},
  [3872] = {.lex_state = 91, .external_lex_state = 12},
  [3873] = {.lex_state = 91, .external_lex_state = 15},
  [3874] = {.lex_state = 91, .external_lex_state = 15},
  [3875] = {.lex_state = 91, .external_lex_state = 12},
  [3876] = {.lex_state = 91, .external_lex_state = 15},
  [3877] = {.lex_state = 91, .external_lex_state = 15},
  [3878] = {.lex_state = 91, .external_lex_state = 15},
  [3879] = {.lex_state = 91, .external_lex_state = 11},
  [3880] = {.lex_state = 91, .external_lex_state = 12},
  [3881] = {.lex_state = 91, .external_lex_state = 15},
  [3882] = {.lex_state = 91, .external_lex_state = 15},
  [3883] = {.lex_state = 91, .external_lex_state = 12},
  [3884] = {.lex_state = 11},
  [3885] = {.lex_state = 91, .external_lex_state = 12},
  [3886] = {.lex_state = 91, .external_lex_state = 15},
  [3887] = {.lex_state = 91, .external_lex_state = 15},
  [3888] = {.lex_state = 91, .external_lex_state = 15},
  [3889] = {.lex_state = 91, .external_lex_state = 15},
  [3890] = {.lex_state = 91, .external_lex_state = 11},
  [3891] = {.lex_state = 91, .external_lex_state = 15},
  [3892] = {.lex_state = 91, .external_lex_state = 15},
  [3893] = {.lex_state = 91, .external_lex_state = 15},
  [3894] = {.lex_state = 91, .external_lex_state = 15},
  [3895] = {.lex_state = 91, .external_lex_state = 15},
  [3896] = {.lex_state = 91, .external_lex_state = 15},
  [3897] = {.lex_state = 91, .external_lex_state = 15},
  [3898] = {.lex_state = 91, .external_lex_state = 15},
  [3899] = {.lex_state = 91, .external_lex_state = 15},
  [3900] = {.lex_state = 91, .external_lex_state = 15},
  [3901] = {.lex_state = 91, .external_lex_state = 15},
  [3902] = {.lex_state = 91, .external_lex_state = 15},
  [3903] = {.lex_state = 91, .external_lex_state = 15},
  [3904] = {.lex_state = 91, .external_lex_state = 12},
  [3905] = {.lex_state = 91, .external_lex_state = 12},
  [3906] = {.lex_state = 91, .external_lex_state = 12},
  [3907] = {.lex_state = 91, .external_lex_state = 12},
  [3908] = {.lex_state = 91, .external_lex_state = 12},
  [3909] = {.lex_state = 91, .external_lex_state = 12},
  [3910] = {.lex_state = 91, .external_lex_state = 12},
  [3911] = {.lex_state = 91, .external_lex_state = 12},
  [3912] = {.lex_state = 91, .external_lex_state = 12},
  [3913] = {.lex_state = 91, .external_lex_state = 12},
  [3914] = {.lex_state = 91, .external_lex_state = 12},
  [3915] = {.lex_state = 91, .external_lex_state = 12},
  [3916] = {.lex_state = 91, .external_lex_state = 12},
  [3917] = {.lex_state = 91, .external_lex_state = 12},
  [3918] = {.lex_state = 91, .external_lex_state = 12},
  [3919] = {.lex_state = 91, .external_lex_state = 12},
  [3920] = {.lex_state = 91, .external_lex_state = 15},
  [3921] = {.lex_state = 91, .external_lex_state = 15},
  [3922] = {.lex_state = 91, .external_lex_state = 15},
  [3923] = {.lex_state = 91, .external_lex_state = 15},
  [3924] = {.lex_state = 91, .external_lex_state = 15},
  [3925] = {.lex_state = 91, .external_lex_state = 12},
  [3926] = {.lex_state = 91, .external_lex_state = 12},
  [3927] = {.lex_state = 91, .external_lex_state = 12},
  [3928] = {.lex_state = 91, .external_lex_state = 12},
  [3929] = {.lex_state = 91, .external_lex_state = 12},
  [3930] = {.lex_state = 91, .external_lex_state = 12},
  [3931] = {.lex_state = 91, .external_lex_state = 12},
  [3932] = {.lex_state = 91, .external_lex_state = 12},
  [3933] = {.lex_state = 91, .external_lex_state = 12},
  [3934] = {.lex_state = 91, .external_lex_state = 15},
  [3935] = {.lex_state = 91, .external_lex_state = 12},
  [3936] = {.lex_state = 91, .external_lex_state = 12},
  [3937] = {.lex_state = 91, .external_lex_state = 12},
  [3938] = {.lex_state = 91, .external_lex_state = 12},
  [3939] = {.lex_state = 91, .external_lex_state = 12},
  [3940] = {.lex_state = 91, .external_lex_state = 12},
  [3941] = {.lex_state = 91, .external_lex_state = 15},
  [3942] = {.lex_state = 91, .external_lex_state = 15},
  [3943] = {.lex_state = 91, .external_lex_state = 12},
  [3944] = {.lex_state = 91, .external_lex_state = 12},
  [3945] = {.lex_state = 91, .external_lex_state = 12},
  [3946] = {.lex_state = 91, .external_lex_state = 12},
  [3947] = {.lex_state = 91, .external_lex_state = 12},
  [3948] = {.lex_state = 91, .external_lex_state = 15},
  [3949] = {.lex_state = 91, .external_lex_state = 15},
  [3950] = {.lex_state = 91, .external_lex_state = 12},
  [3951] = {.lex_state = 91, .external_lex_state = 15},
  [3952] = {.lex_state = 91, .external_lex_state = 15},
  [3953] = {.lex_state = 91, .external_lex_state = 15},
  [3954] = {.lex_state = 91, .external_lex_state = 15},
  [3955] = {.lex_state = 91, .external_lex_state = 15},
  [3956] = {.lex_state = 91, .external_lex_state = 12},
  [3957] = {.lex_state = 91, .external_lex_state = 15},
  [3958] = {.lex_state = 91, .external_lex_state = 15},
  [3959] = {.lex_state = 91, .external_lex_state = 15},
  [3960] = {.lex_state = 91, .external_lex_state = 12},
  [3961] = {.lex_state = 91, .external_lex_state = 15},
  [3962] = {.lex_state = 91, .external_lex_state = 15},
  [3963] = {.lex_state = 91, .external_lex_state = 15},
  [3964] = {.lex_state = 91, .external_lex_state = 15},
  [3965] = {.lex_state = 91, .external_lex_state = 15},
  [3966] = {.lex_state = 91, .external_lex_state = 15},
  [3967] = {.lex_state = 91, .external_lex_state = 15},
  [3968] = {.lex_state = 91, .external_lex_state = 15},
  [3969] = {.lex_state = 91, .external_lex_state = 15},
  [3970] = {.lex_state = 91, .external_lex_state = 15},
  [3971] = {.lex_state = 91, .external_lex_state = 15},
  [3972] = {.lex_state = 91, .external_lex_state = 15},
  [3973] = {.lex_state = 91, .external_lex_state = 15},
  [3974] = {.lex_state = 91, .external_lex_state = 15},
  [3975] = {.lex_state = 91, .external_lex_state = 15},
  [3976] = {.lex_state = 91, .external_lex_state = 15},
  [3977] = {.lex_state = 91, .external_lex_state = 15},
  [3978] = {.lex_state = 91, .external_lex_state = 15},
  [3979] = {.lex_state = 91, .external_lex_state = 15},
  [3980] = {.lex_state = 91, .external_lex_state = 15},
  [3981] = {.lex_state = 91, .external_lex_state = 15},
  [3982] = {.lex_state = 91, .external_lex_state = 15},
  [3983] = {.lex_state = 91, .external_lex_state = 15},
  [3984] = {.lex_state = 91, .external_lex_state = 15},
  [3985] = {.lex_state = 91, .external_lex_state = 15},
  [3986] = {.lex_state = 91, .external_lex_state = 15},
  [3987] = {.lex_state = 91, .external_lex_state = 15},
  [3988] = {.lex_state = 91, .external_lex_state = 15},
  [3989] = {.lex_state = 91, .external_lex_state = 15},
  [3990] = {.lex_state = 91, .external_lex_state = 15},
  [3991] = {.lex_state = 91, .external_lex_state = 15},
  [3992] = {.lex_state = 91, .external_lex_state = 15},
  [3993] = {.lex_state = 91, .external_lex_state = 12},
  [3994] = {.lex_state = 91, .external_lex_state = 12},
  [3995] = {.lex_state = 91, .external_lex_state = 12},
  [3996] = {.lex_state = 91, .external_lex_state = 12},
  [3997] = {.lex_state = 91, .external_lex_state = 12},
  [3998] = {.lex_state = 91, .external_lex_state = 12},
  [3999] = {.lex_state = 91, .external_lex_state = 15},
  [4000] = {.lex_state = 91, .external_lex_state = 15},
  [4001] = {.lex_state = 91, .external_lex_state = 15},
  [4002] = {.lex_state = 91, .external_lex_state = 15},
  [4003] = {.lex_state = 91, .external_lex_state = 15},
  [4004] = {.lex_state = 91, .external_lex_state = 15},
  [4005] = {.lex_state = 91, .external_lex_state = 15},
  [4006] = {.lex_state = 91, .external_lex_state = 15},
  [4007] = {.lex_state = 91, .external_lex_state = 15},
  [4008] = {.lex_state = 91, .external_lex_state = 15},
  [4009] = {.lex_state = 91, .external_lex_state = 15},
  [4010] = {.lex_state = 91, .external_lex_state = 15},
  [4011] = {.lex_state = 91, .external_lex_state = 15},
  [4012] = {.lex_state = 91, .external_lex_state = 15},
  [4013] = {.lex_state = 91, .external_lex_state = 15},
  [4014] = {.lex_state = 91, .external_lex_state = 15},
  [4015] = {.lex_state = 91, .external_lex_state = 15},
  [4016] = {.lex_state = 91, .external_lex_state = 15},
  [4017] = {.lex_state = 91, .external_lex_state = 15},
  [4018] = {.lex_state = 91, .external_lex_state = 15},
  [4019] = {.lex_state = 91, .external_lex_state = 15},
  [4020] = {.lex_state = 91, .external_lex_state = 15},
  [4021] = {.lex_state = 91, .external_lex_state = 15},
  [4022] = {.lex_state = 91, .external_lex_state = 15},
  [4023] = {.lex_state = 91, .external_lex_state = 15},
  [4024] = {.lex_state = 91, .external_lex_state = 15},
  [4025] = {.lex_state = 91, .external_lex_state = 15},
  [4026] = {.lex_state = 91, .external_lex_state = 15},
  [4027] = {.lex_state = 91, .external_lex_state = 15},
  [4028] = {.lex_state = 91, .external_lex_state = 15},
  [4029] = {.lex_state = 91, .external_lex_state = 15},
  [4030] = {.lex_state = 91, .external_lex_state = 15},
  [4031] = {.lex_state = 91, .external_lex_state = 15},
  [4032] = {.lex_state = 91, .external_lex_state = 15},
  [4033] = {.lex_state = 91, .external_lex_state = 15},
  [4034] = {.lex_state = 91, .external_lex_state = 15},
  [4035] = {.lex_state = 91, .external_lex_state = 15},
  [4036] = {.lex_state = 91, .external_lex_state = 15},
  [4037] = {.lex_state = 91, .external_lex_state = 15},
  [4038] = {.lex_state = 91, .external_lex_state = 15},
  [4039] = {.lex_state = 91, .external_lex_state = 15},
  [4040] = {.lex_state = 91, .external_lex_state = 15},
  [4041] = {.lex_state = 91, .external_lex_state = 15},
  [4042] = {.lex_state = 91, .external_lex_state = 15},
  [4043] = {.lex_state = 91, .external_lex_state = 15},
  [4044] = {.lex_state = 91, .external_lex_state = 15},
  [4045] = {.lex_state = 91, .external_lex_state = 15},
  [4046] = {.lex_state = 91, .external_lex_state = 15},
  [4047] = {.lex_state = 91, .external_lex_state = 15},
  [4048] = {.lex_state = 91, .external_lex_state = 15},
  [4049] = {.lex_state = 91, .external_lex_state = 15},
  [4050] = {.lex_state = 91, .external_lex_state = 15},
  [4051] = {.lex_state = 91, .external_lex_state = 15},
  [4052] = {.lex_state = 91, .external_lex_state = 15},
  [4053] = {.lex_state = 91, .external_lex_state = 15},
  [4054] = {.lex_state = 91, .external_lex_state = 15},
  [4055] = {.lex_state = 91, .external_lex_state = 15},
  [4056] = {.lex_state = 91, .external_lex_state = 15},
  [4057] = {.lex_state = 91, .external_lex_state = 15},
  [4058] = {.lex_state = 91, .external_lex_state = 15},
  [4059] = {.lex_state = 91, .external_lex_state = 12},
  [4060] = {.lex_state = 91, .external_lex_state = 15},
  [4061] = {.lex_state = 91, .external_lex_state = 12},
  [4062] = {.lex_state = 91, .external_lex_state = 12},
  [4063] = {.lex_state = 91, .external_lex_state = 15},
  [4064] = {.lex_state = 91, .external_lex_state = 15},
  [4065] = {.lex_state = 91, .external_lex_state = 15},
  [4066] = {.lex_state = 91, .external_lex_state = 15},
  [4067] = {.lex_state = 91, .external_lex_state = 15},
  [4068] = {.lex_state = 91, .external_lex_state = 15},
  [4069] = {.lex_state = 91, .external_lex_state = 15},
  [4070] = {.lex_state = 91, .external_lex_state = 15},
  [4071] = {.lex_state = 91, .external_lex_state = 15},
  [4072] = {.lex_state = 91, .external_lex_state = 15},
  [4073] = {.lex_state = 91, .external_lex_state = 15},
  [4074] = {.lex_state = 91, .external_lex_state = 15},
  [4075] = {.lex_state = 91, .external_lex_state = 15},
  [4076] = {.lex_state = 91, .external_lex_state = 15},
  [4077] = {.lex_state = 91, .external_lex_state = 15},
  [4078] = {.lex_state = 91, .external_lex_state = 15},
  [4079] = {.lex_state = 91, .external_lex_state = 15},
  [4080] = {.lex_state = 91, .external_lex_state = 15},
  [4081] = {.lex_state = 91, .external_lex_state = 15},
  [4082] = {.lex_state = 91, .external_lex_state = 15},
  [4083] = {.lex_state = 91, .external_lex_state = 15},
  [4084] = {.lex_state = 91, .external_lex_state = 15},
  [4085] = {.lex_state = 91, .external_lex_state = 15},
  [4086] = {.lex_state = 91, .external_lex_state = 15},
  [4087] = {.lex_state = 91, .external_lex_state = 15},
  [4088] = {.lex_state = 91, .external_lex_state = 15},
  [4089] = {.lex_state = 91, .external_lex_state = 15},
  [4090] = {.lex_state = 91, .external_lex_state = 15},
  [4091] = {.lex_state = 91, .external_lex_state = 15},
  [4092] = {.lex_state = 91, .external_lex_state = 15},
  [4093] = {.lex_state = 91, .external_lex_state = 15},
  [4094] = {.lex_state = 91, .external_lex_state = 15},
  [4095] = {.lex_state = 91, .external_lex_state = 15},
  [4096] = {.lex_state = 91, .external_lex_state = 15},
  [4097] = {.lex_state = 91, .external_lex_state = 15},
  [4098] = {.lex_state = 91, .external_lex_state = 15},
  [4099] = {.lex_state = 91, .external_lex_state = 12},
  [4100] = {.lex_state = 5, .external_lex_state = 23},
  [4101] = {.lex_state = 91, .external_lex_state = 15},
  [4102] = {.lex_state = 91, .external_lex_state = 15},
  [4103] = {.lex_state = 91, .external_lex_state = 15},
  [4104] = {.lex_state = 91, .external_lex_state = 15},
  [4105] = {.lex_state = 91, .external_lex_state = 15},
  [4106] = {.lex_state = 91, .external_lex_state = 15},
  [4107] = {.lex_state = 91, .external_lex_state = 12},
  [4108] = {.lex_state = 91, .external_lex_state = 15},
  [4109] = {.lex_state = 91, .external_lex_state = 15},
  [4110] = {.lex_state = 91, .external_lex_state = 15},
  [4111] = {.lex_state = 91, .external_lex_state = 15},
  [4112] = {.lex_state = 91, .external_lex_state = 15},
  [4113] = {.lex_state = 91, .external_lex_state = 15},
  [4114] = {.lex_state = 91, .external_lex_state = 15},
  [4115] = {.lex_state = 91, .external_lex_state = 15},
  [4116] = {.lex_state = 91, .external_lex_state = 15},
  [4117] = {.lex_state = 91, .external_lex_state = 12},
  [4118] = {.lex_state = 91, .external_lex_state = 15},
  [4119] = {.lex_state = 91, .external_lex_state = 15},
  [4120] = {.lex_state = 91, .external_lex_state = 15},
  [4121] = {.lex_state = 91, .external_lex_state = 15},
  [4122] = {.lex_state = 91, .external_lex_state = 15},
  [4123] = {.lex_state = 91, .external_lex_state = 15},
  [4124] = {.lex_state = 91, .external_lex_state = 15},
  [4125] = {.lex_state = 91, .external_lex_state = 15},
  [4126] = {.lex_state = 91, .external_lex_state = 15},
  [4127] = {.lex_state = 91, .external_lex_state = 15},
  [4128] = {.lex_state = 91, .external_lex_state = 15},
  [4129] = {.lex_state = 91, .external_lex_state = 15},
  [4130] = {.lex_state = 91, .external_lex_state = 15},
  [4131] = {.lex_state = 91, .external_lex_state = 14},
  [4132] = {.lex_state = 91, .external_lex_state = 15},
  [4133] = {.lex_state = 91, .external_lex_state = 15},
  [4134] = {.lex_state = 91, .external_lex_state = 15},
  [4135] = {.lex_state = 91, .external_lex_state = 15},
  [4136] = {.lex_state = 91, .external_lex_state = 15},
  [4137] = {.lex_state = 91, .external_lex_state = 15},
  [4138] = {.lex_state = 91, .external_lex_state = 15},
  [4139] = {.lex_state = 91, .external_lex_state = 15},
  [4140] = {.lex_state = 91, .external_lex_state = 15},
  [4141] = {.lex_state = 91, .external_lex_state = 15},
  [4142] = {.lex_state = 91, .external_lex_state = 15},
  [4143] = {.lex_state = 91, .external_lex_state = 15},
  [4144] = {.lex_state = 91, .external_lex_state = 15},
  [4145] = {.lex_state = 91, .external_lex_state = 15},
  [4146] = {.lex_state = 91, .external_lex_state = 15},
  [4147] = {.lex_state = 91, .external_lex_state = 15},
  [4148] = {.lex_state = 91, .external_lex_state = 15},
  [4149] = {.lex_state = 91, .external_lex_state = 15},
  [4150] = {.lex_state = 91, .external_lex_state = 15},
  [4151] = {.lex_state = 91, .external_lex_state = 15},
  [4152] = {.lex_state = 91, .external_lex_state = 15},
  [4153] = {.lex_state = 91, .external_lex_state = 15},
  [4154] = {.lex_state = 91, .external_lex_state = 15},
  [4155] = {.lex_state = 91, .external_lex_state = 15},
  [4156] = {.lex_state = 91, .external_lex_state = 15},
  [4157] = {.lex_state = 91, .external_lex_state = 15},
  [4158] = {.lex_state = 91, .external_lex_state = 15},
  [4159] = {.lex_state = 91, .external_lex_state = 15},
  [4160] = {.lex_state = 91, .external_lex_state = 15},
  [4161] = {.lex_state = 91, .external_lex_state = 15},
  [4162] = {.lex_state = 91, .external_lex_state = 15},
  [4163] = {.lex_state = 91, .external_lex_state = 15},
  [4164] = {.lex_state = 91, .external_lex_state = 15},
  [4165] = {.lex_state = 91, .external_lex_state = 15},
  [4166] = {.lex_state = 91, .external_lex_state = 15},
  [4167] = {.lex_state = 91, .external_lex_state = 15},
  [4168] = {.lex_state = 91, .external_lex_state = 15},
  [4169] = {.lex_state = 91, .external_lex_state = 15},
  [4170] = {.lex_state = 91, .external_lex_state = 15},
  [4171] = {.lex_state = 91, .external_lex_state = 15},
  [4172] = {.lex_state = 91, .external_lex_state = 15},
  [4173] = {.lex_state = 91, .external_lex_state = 15},
  [4174] = {.lex_state = 91, .external_lex_state = 15},
  [4175] = {.lex_state = 91, .external_lex_state = 15},
  [4176] = {.lex_state = 91, .external_lex_state = 15},
  [4177] = {.lex_state = 91, .external_lex_state = 15},
  [4178] = {.lex_state = 91, .external_lex_state = 12},
  [4179] = {.lex_state = 91, .external_lex_state = 15},
  [4180] = {.lex_state = 91, .external_lex_state = 15},
  [4181] = {.lex_state = 91, .external_lex_state = 15},
  [4182] = {.lex_state = 91, .external_lex_state = 15},
  [4183] = {.lex_state = 91, .external_lex_state = 15},
  [4184] = {.lex_state = 91, .external_lex_state = 15},
  [4185] = {.lex_state = 91, .external_lex_state = 15},
  [4186] = {.lex_state = 91, .external_lex_state = 15},
  [4187] = {.lex_state = 91, .external_lex_state = 15},
  [4188] = {.lex_state = 91, .external_lex_state = 15},
  [4189] = {.lex_state = 91, .external_lex_state = 15},
  [4190] = {.lex_state = 91, .external_lex_state = 15},
  [4191] = {.lex_state = 91, .external_lex_state = 15},
  [4192] = {.lex_state = 91, .external_lex_state = 15},
  [4193] = {.lex_state = 91, .external_lex_state = 15},
  [4194] = {.lex_state = 91, .external_lex_state = 15},
  [4195] = {.lex_state = 91, .external_lex_state = 15},
  [4196] = {.lex_state = 91, .external_lex_state = 15},
  [4197] = {.lex_state = 91, .external_lex_state = 15},
  [4198] = {.lex_state = 91, .external_lex_state = 15},
  [4199] = {.lex_state = 91, .external_lex_state = 15},
  [4200] = {.lex_state = 91, .external_lex_state = 15},
  [4201] = {.lex_state = 91, .external_lex_state = 15},
  [4202] = {.lex_state = 91, .external_lex_state = 15},
  [4203] = {.lex_state = 91, .external_lex_state = 15},
  [4204] = {.lex_state = 91, .external_lex_state = 15},
  [4205] = {.lex_state = 91, .external_lex_state = 15},
  [4206] = {.lex_state = 91, .external_lex_state = 15},
  [4207] = {.lex_state = 91, .external_lex_state = 15},
  [4208] = {.lex_state = 91, .external_lex_state = 15},
  [4209] = {.lex_state = 91, .external_lex_state = 15},
  [4210] = {.lex_state = 91, .external_lex_state = 15},
  [4211] = {.lex_state = 91, .external_lex_state = 15},
  [4212] = {.lex_state = 91, .external_lex_state = 15},
  [4213] = {.lex_state = 91, .external_lex_state = 15},
  [4214] = {.lex_state = 91, .external_lex_state = 15},
  [4215] = {.lex_state = 91, .external_lex_state = 15},
  [4216] = {.lex_state = 91, .external_lex_state = 15},
  [4217] = {.lex_state = 91, .external_lex_state = 15},
  [4218] = {.lex_state = 91, .external_lex_state = 15},
  [4219] = {.lex_state = 91, .external_lex_state = 15},
  [4220] = {.lex_state = 91, .external_lex_state = 15},
  [4221] = {.lex_state = 91, .external_lex_state = 15},
  [4222] = {.lex_state = 91, .external_lex_state = 15},
  [4223] = {.lex_state = 91, .external_lex_state = 15},
  [4224] = {.lex_state = 91, .external_lex_state = 15},
  [4225] = {.lex_state = 91, .external_lex_state = 15},
  [4226] = {.lex_state = 91, .external_lex_state = 15},
  [4227] = {.lex_state = 91, .external_lex_state = 15},
  [4228] = {.lex_state = 91, .external_lex_state = 15},
  [4229] = {.lex_state = 91, .external_lex_state = 15},
  [4230] = {.lex_state = 91, .external_lex_state = 15},
  [4231] = {.lex_state = 91, .external_lex_state = 15},
  [4232] = {.lex_state = 91, .external_lex_state = 15},
  [4233] = {.lex_state = 91, .external_lex_state = 15},
  [4234] = {.lex_state = 91, .external_lex_state = 15},
  [4235] = {.lex_state = 91, .external_lex_state = 15},
  [4236] = {.lex_state = 91, .external_lex_state = 15},
  [4237] = {.lex_state = 91, .external_lex_state = 15},
  [4238] = {.lex_state = 91, .external_lex_state = 15},
  [4239] = {.lex_state = 91, .external_lex_state = 15},
  [4240] = {.lex_state = 91, .external_lex_state = 15},
  [4241] = {.lex_state = 91, .external_lex_state = 15},
  [4242] = {.lex_state = 91, .external_lex_state = 15},
  [4243] = {.lex_state = 91, .external_lex_state = 15},
  [4244] = {.lex_state = 91, .external_lex_state = 15},
  [4245] = {.lex_state = 91, .external_lex_state = 15},
  [4246] = {.lex_state = 91, .external_lex_state = 15},
  [4247] = {.lex_state = 91, .external_lex_state = 15},
  [4248] = {.lex_state = 91, .external_lex_state = 15},
  [4249] = {.lex_state = 91, .external_lex_state = 15},
  [4250] = {.lex_state = 91, .external_lex_state = 15},
  [4251] = {.lex_state = 91, .external_lex_state = 15},
  [4252] = {.lex_state = 91, .external_lex_state = 15},
  [4253] = {.lex_state = 91, .external_lex_state = 15},
  [4254] = {.lex_state = 91, .external_lex_state = 15},
  [4255] = {.lex_state = 91, .external_lex_state = 15},
  [4256] = {.lex_state = 91, .external_lex_state = 15},
  [4257] = {.lex_state = 91, .external_lex_state = 15},
  [4258] = {.lex_state = 91, .external_lex_state = 15},
  [4259] = {.lex_state = 91, .external_lex_state = 15},
  [4260] = {.lex_state = 91, .external_lex_state = 15},
  [4261] = {.lex_state = 91, .external_lex_state = 15},
  [4262] = {.lex_state = 91, .external_lex_state = 15},
  [4263] = {.lex_state = 91, .external_lex_state = 15},
  [4264] = {.lex_state = 91, .external_lex_state = 15},
  [4265] = {.lex_state = 91, .external_lex_state = 15},
  [4266] = {.lex_state = 91, .external_lex_state = 15},
  [4267] = {.lex_state = 91, .external_lex_state = 15},
  [4268] = {.lex_state = 91, .external_lex_state = 15},
  [4269] = {.lex_state = 91, .external_lex_state = 15},
  [4270] = {.lex_state = 91, .external_lex_state = 15},
  [4271] = {.lex_state = 91, .external_lex_state = 15},
  [4272] = {.lex_state = 91, .external_lex_state = 15},
  [4273] = {.lex_state = 91, .external_lex_state = 15},
  [4274] = {.lex_state = 91, .external_lex_state = 15},
  [4275] = {.lex_state = 91, .external_lex_state = 15},
  [4276] = {.lex_state = 91, .external_lex_state = 15},
  [4277] = {.lex_state = 91, .external_lex_state = 15},
  [4278] = {.lex_state = 91, .external_lex_state = 15},
  [4279] = {.lex_state = 91, .external_lex_state = 15},
  [4280] = {.lex_state = 91, .external_lex_state = 15},
  [4281] = {.lex_state = 91, .external_lex_state = 15},
  [4282] = {.lex_state = 91, .external_lex_state = 15},
  [4283] = {.lex_state = 91, .external_lex_state = 15},
  [4284] = {.lex_state = 91, .external_lex_state = 15},
  [4285] = {.lex_state = 91, .external_lex_state = 15},
  [4286] = {.lex_state = 91, .external_lex_state = 15},
  [4287] = {.lex_state = 91, .external_lex_state = 15},
  [4288] = {.lex_state = 91, .external_lex_state = 15},
  [4289] = {.lex_state = 91, .external_lex_state = 15},
  [4290] = {.lex_state = 91, .external_lex_state = 15},
  [4291] = {.lex_state = 91, .external_lex_state = 15},
  [4292] = {.lex_state = 91, .external_lex_state = 15},
  [4293] = {.lex_state = 91, .external_lex_state = 15},
  [4294] = {.lex_state = 91, .external_lex_state = 15},
  [4295] = {.lex_state = 91, .external_lex_state = 15},
  [4296] = {.lex_state = 91, .external_lex_state = 15},
  [4297] = {.lex_state = 91, .external_lex_state = 15},
  [4298] = {.lex_state = 91, .external_lex_state = 15},
  [4299] = {.lex_state = 91, .external_lex_state = 15},
  [4300] = {.lex_state = 91, .external_lex_state = 15},
  [4301] = {.lex_state = 91, .external_lex_state = 15},
  [4302] = {.lex_state = 91, .external_lex_state = 15},
  [4303] = {.lex_state = 91, .external_lex_state = 15},
  [4304] = {.lex_state = 91, .external_lex_state = 15},
  [4305] = {.lex_state = 91, .external_lex_state = 15},
  [4306] = {.lex_state = 91, .external_lex_state = 15},
  [4307] = {.lex_state = 91, .external_lex_state = 15},
  [4308] = {.lex_state = 91, .external_lex_state = 15},
  [4309] = {.lex_state = 91, .external_lex_state = 15},
  [4310] = {.lex_state = 91, .external_lex_state = 15},
  [4311] = {.lex_state = 91, .external_lex_state = 15},
  [4312] = {.lex_state = 91, .external_lex_state = 15},
  [4313] = {.lex_state = 91, .external_lex_state = 15},
  [4314] = {.lex_state = 91, .external_lex_state = 15},
  [4315] = {.lex_state = 91, .external_lex_state = 15},
  [4316] = {.lex_state = 91, .external_lex_state = 15},
  [4317] = {.lex_state = 91, .external_lex_state = 15},
  [4318] = {.lex_state = 91, .external_lex_state = 15},
  [4319] = {.lex_state = 91, .external_lex_state = 15},
  [4320] = {.lex_state = 91, .external_lex_state = 12},
  [4321] = {.lex_state = 91, .external_lex_state = 15},
  [4322] = {.lex_state = 91, .external_lex_state = 15},
  [4323] = {.lex_state = 91, .external_lex_state = 15},
  [4324] = {.lex_state = 91, .external_lex_state = 15},
  [4325] = {.lex_state = 91, .external_lex_state = 15},
  [4326] = {.lex_state = 91, .external_lex_state = 15},
  [4327] = {.lex_state = 91, .external_lex_state = 15},
  [4328] = {.lex_state = 91, .external_lex_state = 15},
  [4329] = {.lex_state = 91, .external_lex_state = 15},
  [4330] = {.lex_state = 91, .external_lex_state = 15},
  [4331] = {.lex_state = 91, .external_lex_state = 15},
  [4332] = {.lex_state = 91, .external_lex_state = 15},
  [4333] = {.lex_state = 91, .external_lex_state = 15},
  [4334] = {.lex_state = 91, .external_lex_state = 15},
  [4335] = {.lex_state = 91, .external_lex_state = 15},
  [4336] = {.lex_state = 91, .external_lex_state = 15},
  [4337] = {.lex_state = 91, .external_lex_state = 15},
  [4338] = {.lex_state = 91, .external_lex_state = 15},
  [4339] = {.lex_state = 91, .external_lex_state = 15},
  [4340] = {.lex_state = 91, .external_lex_state = 15},
  [4341] = {.lex_state = 91, .external_lex_state = 15},
  [4342] = {.lex_state = 91, .external_lex_state = 15},
  [4343] = {.lex_state = 91, .external_lex_state = 15},
  [4344] = {.lex_state = 91, .external_lex_state = 15},
  [4345] = {.lex_state = 91, .external_lex_state = 15},
  [4346] = {.lex_state = 91, .external_lex_state = 15},
  [4347] = {.lex_state = 91, .external_lex_state = 15},
  [4348] = {.lex_state = 91, .external_lex_state = 15},
  [4349] = {.lex_state = 91, .external_lex_state = 15},
  [4350] = {.lex_state = 91, .external_lex_state = 15},
  [4351] = {.lex_state = 91, .external_lex_state = 15},
  [4352] = {.lex_state = 91, .external_lex_state = 15},
  [4353] = {.lex_state = 91, .external_lex_state = 15},
  [4354] = {.lex_state = 91, .external_lex_state = 15},
  [4355] = {.lex_state = 91, .external_lex_state = 15},
  [4356] = {.lex_state = 91, .external_lex_state = 15},
  [4357] = {.lex_state = 91, .external_lex_state = 15},
  [4358] = {.lex_state = 91, .external_lex_state = 15},
  [4359] = {.lex_state = 91, .external_lex_state = 15},
  [4360] = {.lex_state = 91, .external_lex_state = 15},
  [4361] = {.lex_state = 91, .external_lex_state = 15},
  [4362] = {.lex_state = 91, .external_lex_state = 15},
  [4363] = {.lex_state = 91, .external_lex_state = 15},
  [4364] = {.lex_state = 91, .external_lex_state = 15},
  [4365] = {.lex_state = 91, .external_lex_state = 15},
  [4366] = {.lex_state = 91, .external_lex_state = 15},
  [4367] = {.lex_state = 91, .external_lex_state = 15},
  [4368] = {.lex_state = 91, .external_lex_state = 15},
  [4369] = {.lex_state = 91, .external_lex_state = 15},
  [4370] = {.lex_state = 91, .external_lex_state = 15},
  [4371] = {.lex_state = 91, .external_lex_state = 15},
  [4372] = {.lex_state = 91, .external_lex_state = 15},
  [4373] = {.lex_state = 91, .external_lex_state = 15},
  [4374] = {.lex_state = 91, .external_lex_state = 15},
  [4375] = {.lex_state = 91, .external_lex_state = 15},
  [4376] = {.lex_state = 91, .external_lex_state = 15},
  [4377] = {.lex_state = 91, .external_lex_state = 15},
  [4378] = {.lex_state = 91, .external_lex_state = 15},
  [4379] = {.lex_state = 91, .external_lex_state = 15},
  [4380] = {.lex_state = 91, .external_lex_state = 15},
  [4381] = {.lex_state = 91, .external_lex_state = 15},
  [4382] = {.lex_state = 91, .external_lex_state = 15},
  [4383] = {.lex_state = 91, .external_lex_state = 15},
  [4384] = {.lex_state = 91, .external_lex_state = 15},
  [4385] = {.lex_state = 91, .external_lex_state = 15},
  [4386] = {.lex_state = 91, .external_lex_state = 15},
  [4387] = {.lex_state = 91, .external_lex_state = 15},
  [4388] = {.lex_state = 91, .external_lex_state = 15},
  [4389] = {.lex_state = 91, .external_lex_state = 15},
  [4390] = {.lex_state = 91, .external_lex_state = 15},
  [4391] = {.lex_state = 91, .external_lex_state = 15},
  [4392] = {.lex_state = 91, .external_lex_state = 15},
  [4393] = {.lex_state = 91, .external_lex_state = 15},
  [4394] = {.lex_state = 91, .external_lex_state = 15},
  [4395] = {.lex_state = 91, .external_lex_state = 15},
  [4396] = {.lex_state = 91, .external_lex_state = 15},
  [4397] = {.lex_state = 91, .external_lex_state = 15},
  [4398] = {.lex_state = 91, .external_lex_state = 15},
  [4399] = {.lex_state = 91, .external_lex_state = 15},
  [4400] = {.lex_state = 91, .external_lex_state = 15},
  [4401] = {.lex_state = 91, .external_lex_state = 15},
  [4402] = {.lex_state = 91, .external_lex_state = 15},
  [4403] = {.lex_state = 91, .external_lex_state = 15},
  [4404] = {.lex_state = 91, .external_lex_state = 15},
  [4405] = {.lex_state = 91, .external_lex_state = 15},
  [4406] = {.lex_state = 91, .external_lex_state = 15},
  [4407] = {.lex_state = 91, .external_lex_state = 15},
  [4408] = {.lex_state = 91, .external_lex_state = 15},
  [4409] = {.lex_state = 91, .external_lex_state = 15},
  [4410] = {.lex_state = 91, .external_lex_state = 15},
  [4411] = {.lex_state = 91, .external_lex_state = 15},
  [4412] = {.lex_state = 91, .external_lex_state = 15},
  [4413] = {.lex_state = 91, .external_lex_state = 15},
  [4414] = {.lex_state = 91, .external_lex_state = 15},
  [4415] = {.lex_state = 91, .external_lex_state = 15},
  [4416] = {.lex_state = 91, .external_lex_state = 15},
  [4417] = {.lex_state = 91, .external_lex_state = 15},
  [4418] = {.lex_state = 91, .external_lex_state = 15},
  [4419] = {.lex_state = 91, .external_lex_state = 15},
  [4420] = {.lex_state = 91, .external_lex_state = 15},
  [4421] = {.lex_state = 91, .external_lex_state = 15},
  [4422] = {.lex_state = 91, .external_lex_state = 15},
  [4423] = {.lex_state = 91, .external_lex_state = 15},
  [4424] = {.lex_state = 91, .external_lex_state = 15},
  [4425] = {.lex_state = 91, .external_lex_state = 15},
  [4426] = {.lex_state = 91, .external_lex_state = 15},
  [4427] = {.lex_state = 91, .external_lex_state = 15},
  [4428] = {.lex_state = 91, .external_lex_state = 15},
  [4429] = {.lex_state = 91, .external_lex_state = 15},
  [4430] = {.lex_state = 91, .external_lex_state = 15},
  [4431] = {.lex_state = 91, .external_lex_state = 15},
  [4432] = {.lex_state = 91, .external_lex_state = 15},
  [4433] = {.lex_state = 91, .external_lex_state = 15},
  [4434] = {.lex_state = 91, .external_lex_state = 15},
  [4435] = {.lex_state = 91, .external_lex_state = 15},
  [4436] = {.lex_state = 91, .external_lex_state = 15},
  [4437] = {.lex_state = 91, .external_lex_state = 15},
  [4438] = {.lex_state = 91, .external_lex_state = 15},
  [4439] = {.lex_state = 91, .external_lex_state = 15},
  [4440] = {.lex_state = 91, .external_lex_state = 15},
  [4441] = {.lex_state = 91, .external_lex_state = 15},
  [4442] = {.lex_state = 91, .external_lex_state = 15},
  [4443] = {.lex_state = 91, .external_lex_state = 15},
  [4444] = {.lex_state = 91, .external_lex_state = 15},
  [4445] = {.lex_state = 91, .external_lex_state = 15},
  [4446] = {.lex_state = 91, .external_lex_state = 15},
  [4447] = {.lex_state = 91, .external_lex_state = 15},
  [4448] = {.lex_state = 91, .external_lex_state = 15},
  [4449] = {.lex_state = 91, .external_lex_state = 15},
  [4450] = {.lex_state = 91, .external_lex_state = 15},
  [4451] = {.lex_state = 91, .external_lex_state = 15},
  [4452] = {.lex_state = 91, .external_lex_state = 15},
  [4453] = {.lex_state = 91, .external_lex_state = 15},
  [4454] = {.lex_state = 91, .external_lex_state = 15},
  [4455] = {.lex_state = 91, .external_lex_state = 15},
  [4456] = {.lex_state = 91, .external_lex_state = 15},
  [4457] = {.lex_state = 91, .external_lex_state = 15},
  [4458] = {.lex_state = 91, .external_lex_state = 15},
  [4459] = {.lex_state = 91, .external_lex_state = 15},
  [4460] = {.lex_state = 91, .external_lex_state = 15},
  [4461] = {.lex_state = 91, .external_lex_state = 15},
  [4462] = {.lex_state = 91, .external_lex_state = 15},
  [4463] = {.lex_state = 91, .external_lex_state = 15},
  [4464] = {.lex_state = 91, .external_lex_state = 15},
  [4465] = {.lex_state = 91, .external_lex_state = 15},
  [4466] = {.lex_state = 91, .external_lex_state = 15},
  [4467] = {.lex_state = 91, .external_lex_state = 15},
  [4468] = {.lex_state = 91, .external_lex_state = 15},
  [4469] = {.lex_state = 91, .external_lex_state = 15},
  [4470] = {.lex_state = 91, .external_lex_state = 15},
  [4471] = {.lex_state = 91, .external_lex_state = 15},
  [4472] = {.lex_state = 91, .external_lex_state = 15},
  [4473] = {.lex_state = 91, .external_lex_state = 15},
  [4474] = {.lex_state = 91, .external_lex_state = 15},
  [4475] = {.lex_state = 91, .external_lex_state = 15},
  [4476] = {.lex_state = 91, .external_lex_state = 15},
  [4477] = {.lex_state = 91, .external_lex_state = 15},
  [4478] = {.lex_state = 91, .external_lex_state = 15},
  [4479] = {.lex_state = 91, .external_lex_state = 15},
  [4480] = {.lex_state = 91, .external_lex_state = 15},
  [4481] = {.lex_state = 91, .external_lex_state = 15},
  [4482] = {.lex_state = 91, .external_lex_state = 15},
  [4483] = {.lex_state = 91, .external_lex_state = 15},
  [4484] = {.lex_state = 91, .external_lex_state = 15},
  [4485] = {.lex_state = 91, .external_lex_state = 15},
  [4486] = {.lex_state = 91, .external_lex_state = 15},
  [4487] = {.lex_state = 91, .external_lex_state = 15},
  [4488] = {.lex_state = 91, .external_lex_state = 15},
  [4489] = {.lex_state = 91, .external_lex_state = 15},
  [4490] = {.lex_state = 91, .external_lex_state = 15},
  [4491] = {.lex_state = 91, .external_lex_state = 15},
  [4492] = {.lex_state = 91, .external_lex_state = 15},
  [4493] = {.lex_state = 91, .external_lex_state = 15},
  [4494] = {.lex_state = 91, .external_lex_state = 15},
  [4495] = {.lex_state = 91, .external_lex_state = 15},
  [4496] = {.lex_state = 91, .external_lex_state = 15},
  [4497] = {.lex_state = 91, .external_lex_state = 15},
  [4498] = {.lex_state = 91, .external_lex_state = 15},
  [4499] = {.lex_state = 91, .external_lex_state = 15},
  [4500] = {.lex_state = 91, .external_lex_state = 15},
  [4501] = {.lex_state = 91, .external_lex_state = 12},
  [4502] = {.lex_state = 91, .external_lex_state = 15},
  [4503] = {.lex_state = 91, .external_lex_state = 15},
  [4504] = {.lex_state = 91, .external_lex_state = 15},
  [4505] = {.lex_state = 91, .external_lex_state = 15},
  [4506] = {.lex_state = 91, .external_lex_state = 15},
  [4507] = {.lex_state = 91, .external_lex_state = 15},
  [4508] = {.lex_state = 91, .external_lex_state = 15},
  [4509] = {.lex_state = 91, .external_lex_state = 15},
  [4510] = {.lex_state = 91, .external_lex_state = 15},
  [4511] = {.lex_state = 91, .external_lex_state = 15},
  [4512] = {.lex_state = 91, .external_lex_state = 15},
  [4513] = {.lex_state = 91, .external_lex_state = 15},
  [4514] = {.lex_state = 91, .external_lex_state = 15},
  [4515] = {.lex_state = 91, .external_lex_state = 15},
  [4516] = {.lex_state = 91, .external_lex_state = 15},
  [4517] = {.lex_state = 91, .external_lex_state = 15},
  [4518] = {.lex_state = 91, .external_lex_state = 15},
  [4519] = {.lex_state = 91, .external_lex_state = 15},
  [4520] = {.lex_state = 91, .external_lex_state = 15},
  [4521] = {.lex_state = 91, .external_lex_state = 15},
  [4522] = {.lex_state = 91, .external_lex_state = 15},
  [4523] = {.lex_state = 91, .external_lex_state = 15},
  [4524] = {.lex_state = 91, .external_lex_state = 15},
  [4525] = {.lex_state = 91, .external_lex_state = 15},
  [4526] = {.lex_state = 91, .external_lex_state = 15},
  [4527] = {.lex_state = 91, .external_lex_state = 15},
  [4528] = {.lex_state = 91, .external_lex_state = 15},
  [4529] = {.lex_state = 91, .external_lex_state = 15},
  [4530] = {.lex_state = 91, .external_lex_state = 15},
  [4531] = {.lex_state = 91, .external_lex_state = 15},
  [4532] = {.lex_state = 91, .external_lex_state = 15},
  [4533] = {.lex_state = 91, .external_lex_state = 15},
  [4534] = {.lex_state = 91, .external_lex_state = 15},
  [4535] = {.lex_state = 91, .external_lex_state = 15},
  [4536] = {.lex_state = 91, .external_lex_state = 15},
  [4537] = {.lex_state = 91, .external_lex_state = 15},
  [4538] = {.lex_state = 91, .external_lex_state = 15},
  [4539] = {.lex_state = 91, .external_lex_state = 15},
  [4540] = {.lex_state = 91, .external_lex_state = 15},
  [4541] = {.lex_state = 91, .external_lex_state = 15},
  [4542] = {.lex_state = 91, .external_lex_state = 15},
  [4543] = {.lex_state = 91, .external_lex_state = 15},
  [4544] = {.lex_state = 91, .external_lex_state = 15},
  [4545] = {.lex_state = 91, .external_lex_state = 15},
  [4546] = {.lex_state = 91, .external_lex_state = 15},
  [4547] = {.lex_state = 91, .external_lex_state = 15},
  [4548] = {.lex_state = 91, .external_lex_state = 15},
  [4549] = {.lex_state = 91, .external_lex_state = 15},
  [4550] = {.lex_state = 91, .external_lex_state = 15},
  [4551] = {.lex_state = 91, .external_lex_state = 15},
  [4552] = {.lex_state = 91, .external_lex_state = 15},
  [4553] = {.lex_state = 91, .external_lex_state = 15},
  [4554] = {.lex_state = 91, .external_lex_state = 15},
  [4555] = {.lex_state = 91, .external_lex_state = 15},
  [4556] = {.lex_state = 91, .external_lex_state = 15},
  [4557] = {.lex_state = 91, .external_lex_state = 15},
  [4558] = {.lex_state = 91, .external_lex_state = 15},
  [4559] = {.lex_state = 91, .external_lex_state = 15},
  [4560] = {.lex_state = 91, .external_lex_state = 15},
  [4561] = {.lex_state = 91, .external_lex_state = 15},
  [4562] = {.lex_state = 91, .external_lex_state = 15},
  [4563] = {.lex_state = 91, .external_lex_state = 15},
  [4564] = {.lex_state = 91, .external_lex_state = 15},
  [4565] = {.lex_state = 91, .external_lex_state = 15},
  [4566] = {.lex_state = 91, .external_lex_state = 15},
  [4567] = {.lex_state = 91, .external_lex_state = 15},
  [4568] = {.lex_state = 91, .external_lex_state = 15},
  [4569] = {.lex_state = 91, .external_lex_state = 15},
  [4570] = {.lex_state = 91, .external_lex_state = 15},
  [4571] = {.lex_state = 91, .external_lex_state = 15},
  [4572] = {.lex_state = 91, .external_lex_state = 15},
  [4573] = {.lex_state = 91, .external_lex_state = 15},
  [4574] = {.lex_state = 91, .external_lex_state = 15},
  [4575] = {.lex_state = 91, .external_lex_state = 15},
  [4576] = {.lex_state = 91, .external_lex_state = 15},
  [4577] = {.lex_state = 91, .external_lex_state = 15},
  [4578] = {.lex_state = 91, .external_lex_state = 15},
  [4579] = {.lex_state = 91, .external_lex_state = 15},
  [4580] = {.lex_state = 91, .external_lex_state = 15},
  [4581] = {.lex_state = 91, .external_lex_state = 15},
  [4582] = {.lex_state = 91, .external_lex_state = 15},
  [4583] = {.lex_state = 91, .external_lex_state = 15},
  [4584] = {.lex_state = 91, .external_lex_state = 15},
  [4585] = {.lex_state = 91, .external_lex_state = 15},
  [4586] = {.lex_state = 91, .external_lex_state = 15},
  [4587] = {.lex_state = 91, .external_lex_state = 15},
  [4588] = {.lex_state = 91, .external_lex_state = 15},
  [4589] = {.lex_state = 91, .external_lex_state = 15},
  [4590] = {.lex_state = 91, .external_lex_state = 15},
  [4591] = {.lex_state = 91, .external_lex_state = 15},
  [4592] = {.lex_state = 91, .external_lex_state = 15},
  [4593] = {.lex_state = 91, .external_lex_state = 15},
  [4594] = {.lex_state = 91, .external_lex_state = 15},
  [4595] = {.lex_state = 91, .external_lex_state = 15},
  [4596] = {.lex_state = 91, .external_lex_state = 15},
  [4597] = {.lex_state = 91, .external_lex_state = 15},
  [4598] = {.lex_state = 91, .external_lex_state = 15},
  [4599] = {.lex_state = 5},
  [4600] = {.lex_state = 91, .external_lex_state = 15},
  [4601] = {.lex_state = 91, .external_lex_state = 15},
  [4602] = {.lex_state = 91, .external_lex_state = 15},
  [4603] = {.lex_state = 91, .external_lex_state = 15},
  [4604] = {.lex_state = 91, .external_lex_state = 15},
  [4605] = {.lex_state = 91, .external_lex_state = 12},
  [4606] = {.lex_state = 91, .external_lex_state = 15},
  [4607] = {.lex_state = 91, .external_lex_state = 15},
  [4608] = {.lex_state = 91, .external_lex_state = 15},
  [4609] = {.lex_state = 91, .external_lex_state = 15},
  [4610] = {.lex_state = 91, .external_lex_state = 12},
  [4611] = {.lex_state = 91, .external_lex_state = 15},
  [4612] = {.lex_state = 91, .external_lex_state = 12},
  [4613] = {.lex_state = 91, .external_lex_state = 15},
  [4614] = {.lex_state = 91, .external_lex_state = 14},
  [4615] = {.lex_state = 91, .external_lex_state = 14},
  [4616] = {.lex_state = 91, .external_lex_state = 7},
  [4617] = {.lex_state = 91, .external_lex_state = 7},
  [4618] = {.lex_state = 91, .external_lex_state = 22},
  [4619] = {.lex_state = 91, .external_lex_state = 22},
  [4620] = {.lex_state = 91, .external_lex_state = 22},
  [4621] = {.lex_state = 91, .external_lex_state = 22},
  [4622] = {.lex_state = 91, .external_lex_state = 14},
  [4623] = {.lex_state = 91, .external_lex_state = 22},
  [4624] = {.lex_state = 5},
  [4625] = {.lex_state = 91, .external_lex_state = 14},
  [4626] = {.lex_state = 91, .external_lex_state = 7},
  [4627] = {.lex_state = 91, .external_lex_state = 7},
  [4628] = {.lex_state = 91, .external_lex_state = 7},
  [4629] = {.lex_state = 91, .external_lex_state = 7},
  [4630] = {.lex_state = 91, .external_lex_state = 7},
  [4631] = {.lex_state = 91, .external_lex_state = 7},
  [4632] = {.lex_state = 91, .external_lex_state = 7},
  [4633] = {.lex_state = 91, .external_lex_state = 7},
  [4634] = {.lex_state = 91, .external_lex_state = 7},
  [4635] = {.lex_state = 91, .external_lex_state = 7},
  [4636] = {.lex_state = 5},
  [4637] = {.lex_state = 91, .external_lex_state = 7},
  [4638] = {.lex_state = 91, .external_lex_state = 7},
  [4639] = {.lex_state = 91, .external_lex_state = 7},
  [4640] = {.lex_state = 91, .external_lex_state = 7},
  [4641] = {.lex_state = 91, .external_lex_state = 7},
  [4642] = {.lex_state = 2},
  [4643] = {.lex_state = 2},
  [4644] = {.lex_state = 91, .external_lex_state = 7},
  [4645] = {.lex_state = 91, .external_lex_state = 7},
  [4646] = {.lex_state = 91, .external_lex_state = 7},
  [4647] = {.lex_state = 91, .external_lex_state = 7},
  [4648] = {.lex_state = 91, .external_lex_state = 7},
  [4649] = {.lex_state = 91, .external_lex_state = 7},
  [4650] = {.lex_state = 91, .external_lex_state = 7},
  [4651] = {.lex_state = 91, .external_lex_state = 7},
  [4652] = {.lex_state = 91, .external_lex_state = 7},
  [4653] = {.lex_state = 91, .external_lex_state = 7},
  [4654] = {.lex_state = 91, .external_lex_state = 7},
  [4655] = {.lex_state = 91, .external_lex_state = 7},
  [4656] = {.lex_state = 91, .external_lex_state = 7},
  [4657] = {.lex_state = 91, .external_lex_state = 7},
  [4658] = {.lex_state = 91, .external_lex_state = 7},
  [4659] = {.lex_state = 91, .external_lex_state = 7},
  [4660] = {.lex_state = 91, .external_lex_state = 7},
  [4661] = {.lex_state = 91, .external_lex_state = 7},
  [4662] = {.lex_state = 91, .external_lex_state = 7},
  [4663] = {.lex_state = 91, .external_lex_state = 7},
  [4664] = {.lex_state = 91, .external_lex_state = 7},
  [4665] = {.lex_state = 91, .external_lex_state = 7},
  [4666] = {.lex_state = 91, .external_lex_state = 7},
  [4667] = {.lex_state = 91, .external_lex_state = 7},
  [4668] = {.lex_state = 91, .external_lex_state = 7},
  [4669] = {.lex_state = 5, .external_lex_state = 24},
  [4670] = {.lex_state = 91, .external_lex_state = 7},
  [4671] = {.lex_state = 91, .external_lex_state = 7},
  [4672] = {.lex_state = 91, .external_lex_state = 7},
  [4673] = {.lex_state = 91, .external_lex_state = 7},
  [4674] = {.lex_state = 91, .external_lex_state = 7},
  [4675] = {.lex_state = 91, .external_lex_state = 7},
  [4676] = {.lex_state = 91, .external_lex_state = 7},
  [4677] = {.lex_state = 91, .external_lex_state = 7},
  [4678] = {.lex_state = 91, .external_lex_state = 7},
  [4679] = {.lex_state = 91, .external_lex_state = 7},
  [4680] = {.lex_state = 91, .external_lex_state = 7},
  [4681] = {.lex_state = 91, .external_lex_state = 7},
  [4682] = {.lex_state = 91, .external_lex_state = 7},
  [4683] = {.lex_state = 91, .external_lex_state = 7},
  [4684] = {.lex_state = 91, .external_lex_state = 7},
  [4685] = {.lex_state = 91, .external_lex_state = 7},
  [4686] = {.lex_state = 91, .external_lex_state = 7},
  [4687] = {.lex_state = 91, .external_lex_state = 11},
  [4688] = {.lex_state = 2},
  [4689] = {.lex_state = 91, .external_lex_state = 11},
  [4690] = {.lex_state = 91, .external_lex_state = 11},
  [4691] = {.lex_state = 91, .external_lex_state = 12},
  [4692] = {.lex_state = 91, .external_lex_state = 11},
  [4693] = {.lex_state = 91, .external_lex_state = 11},
  [4694] = {.lex_state = 91, .external_lex_state = 11},
  [4695] = {.lex_state = 91, .external_lex_state = 12},
  [4696] = {.lex_state = 2},
  [4697] = {.lex_state = 91, .external_lex_state = 11},
  [4698] = {.lex_state = 91, .external_lex_state = 11},
  [4699] = {.lex_state = 91, .external_lex_state = 11},
  [4700] = {.lex_state = 91, .external_lex_state = 11},
  [4701] = {.lex_state = 91, .external_lex_state = 11},
  [4702] = {.lex_state = 91, .external_lex_state = 11},
  [4703] = {.lex_state = 91, .external_lex_state = 12},
  [4704] = {.lex_state = 91, .external_lex_state = 11},
  [4705] = {.lex_state = 91, .external_lex_state = 11},
  [4706] = {.lex_state = 91, .external_lex_state = 11},
  [4707] = {.lex_state = 91, .external_lex_state = 11},
  [4708] = {.lex_state = 91, .external_lex_state = 12},
  [4709] = {.lex_state = 91, .external_lex_state = 11},
  [4710] = {.lex_state = 91, .external_lex_state = 11},
  [4711] = {.lex_state = 91, .external_lex_state = 11},
  [4712] = {.lex_state = 2},
  [4713] = {.lex_state = 91, .external_lex_state = 11},
  [4714] = {.lex_state = 91, .external_lex_state = 11},
  [4715] = {.lex_state = 91, .external_lex_state = 11},
  [4716] = {.lex_state = 91, .external_lex_state = 12},
  [4717] = {.lex_state = 2},
  [4718] = {.lex_state = 91, .external_lex_state = 17},
  [4719] = {.lex_state = 91, .external_lex_state = 17},
  [4720] = {.lex_state = 91, .external_lex_state = 17},
  [4721] = {.lex_state = 91, .external_lex_state = 17},
  [4722] = {.lex_state = 91, .external_lex_state = 17},
  [4723] = {.lex_state = 91, .external_lex_state = 17},
  [4724] = {.lex_state = 91, .external_lex_state = 17},
  [4725] = {.lex_state = 91, .external_lex_state = 17},
  [4726] = {.lex_state = 91, .external_lex_state = 17},
  [4727] = {.lex_state = 91, .external_lex_state = 17},
  [4728] = {.lex_state = 91, .external_lex_state = 17},
  [4729] = {.lex_state = 91, .external_lex_state = 17},
  [4730] = {.lex_state = 91, .external_lex_state = 17},
  [4731] = {.lex_state = 91, .external_lex_state = 17},
  [4732] = {.lex_state = 91, .external_lex_state = 17},
  [4733] = {.lex_state = 91, .external_lex_state = 17},
  [4734] = {.lex_state = 91, .external_lex_state = 17},
  [4735] = {.lex_state = 11},
  [4736] = {.lex_state = 2},
  [4737] = {.lex_state = 91, .external_lex_state = 17},
  [4738] = {.lex_state = 91, .external_lex_state = 17},
  [4739] = {.lex_state = 91, .external_lex_state = 17},
  [4740] = {.lex_state = 91, .external_lex_state = 17},
  [4741] = {.lex_state = 91, .external_lex_state = 17},
  [4742] = {.lex_state = 91, .external_lex_state = 17},
  [4743] = {.lex_state = 91, .external_lex_state = 17},
  [4744] = {.lex_state = 91, .external_lex_state = 17},
  [4745] = {.lex_state = 91, .external_lex_state = 17},
  [4746] = {.lex_state = 91, .external_lex_state = 17},
  [4747] = {.lex_state = 91, .external_lex_state = 17},
  [4748] = {.lex_state = 91, .external_lex_state = 17},
  [4749] = {.lex_state = 91, .external_lex_state = 17},
  [4750] = {.lex_state = 91, .external_lex_state = 17},
  [4751] = {.lex_state = 91, .external_lex_state = 17},
  [4752] = {.lex_state = 91, .external_lex_state = 17},
  [4753] = {.lex_state = 91, .external_lex_state = 17},
  [4754] = {.lex_state = 91, .external_lex_state = 17},
  [4755] = {.lex_state = 91, .external_lex_state = 17},
  [4756] = {.lex_state = 91, .external_lex_state = 17},
  [4757] = {.lex_state = 91, .external_lex_state = 17},
  [4758] = {.lex_state = 91, .external_lex_state = 17},
  [4759] = {.lex_state = 91, .external_lex_state = 17},
  [4760] = {.lex_state = 91, .external_lex_state = 17},
  [4761] = {.lex_state = 91, .external_lex_state = 7},
  [4762] = {.lex_state = 11},
  [4763] = {.lex_state = 2},
  [4764] = {.lex_state = 91},
  [4765] = {.lex_state = 2},
  [4766] = {.lex_state = 91, .external_lex_state = 17},
  [4767] = {.lex_state = 91, .external_lex_state = 17},
  [4768] = {.lex_state = 91, .external_lex_state = 17},
  [4769] = {.lex_state = 91, .external_lex_state = 17},
  [4770] = {.lex_state = 91, .external_lex_state = 17},
  [4771] = {.lex_state = 91, .external_lex_state = 17},
  [4772] = {.lex_state = 91, .external_lex_state = 17},
  [4773] = {.lex_state = 91, .external_lex_state = 17},
  [4774] = {.lex_state = 91, .external_lex_state = 17},
  [4775] = {.lex_state = 91, .external_lex_state = 17},
  [4776] = {.lex_state = 91, .external_lex_state = 17},
  [4777] = {.lex_state = 91, .external_lex_state = 17},
  [4778] = {.lex_state = 91, .external_lex_state = 17},
  [4779] = {.lex_state = 11},
  [4780] = {.lex_state = 6},
  [4781] = {.lex_state = 2},
  [4782] = {.lex_state = 6},
  [4783] = {.lex_state = 91, .external_lex_state = 17},
  [4784] = {.lex_state = 11},
  [4785] = {.lex_state = 91, .external_lex_state = 2},
  [4786] = {.lex_state = 91, .external_lex_state = 2},
  [4787] = {.lex_state = 91, .external_lex_state = 17},
  [4788] = {.lex_state = 2},
  [4789] = {.lex_state = 2},
  [4790] = {.lex_state = 2},
  [4791] = {.lex_state = 91, .external_lex_state = 17},
  [4792] = {.lex_state = 91, .external_lex_state = 17},
  [4793] = {.lex_state = 91, .external_lex_state = 17},
  [4794] = {.lex_state = 91, .external_lex_state = 17},
  [4795] = {.lex_state = 2},
  [4796] = {.lex_state = 91, .external_lex_state = 7},
  [4797] = {.lex_state = 91, .external_lex_state = 7},
  [4798] = {.lex_state = 91, .external_lex_state = 7},
  [4799] = {.lex_state = 2},
  [4800] = {.lex_state = 2},
  [4801] = {.lex_state = 2},
  [4802] = {.lex_state = 91, .external_lex_state = 15},
  [4803] = {.lex_state = 2},
  [4804] = {.lex_state = 2},
  [4805] = {.lex_state = 2},
  [4806] = {.lex_state = 91, .external_lex_state = 7},
  [4807] = {.lex_state = 91, .external_lex_state = 7},
  [4808] = {.lex_state = 91, .external_lex_state = 7},
  [4809] = {.lex_state = 91, .external_lex_state = 7},
  [4810] = {.lex_state = 11},
  [4811] = {.lex_state = 2},
  [4812] = {.lex_state = 91, .external_lex_state = 22},
  [4813] = {.lex_state = 91, .external_lex_state = 22},
  [4814] = {.lex_state = 91, .external_lex_state = 22},
  [4815] = {.lex_state = 91, .external_lex_state = 22},
  [4816] = {.lex_state = 91, .external_lex_state = 22},
  [4817] = {.lex_state = 2},
  [4818] = {.lex_state = 2},
  [4819] = {.lex_state = 2},
  [4820] = {.lex_state = 91, .external_lex_state = 7},
  [4821] = {.lex_state = 91, .external_lex_state = 7},
  [4822] = {.lex_state = 91, .external_lex_state = 7},
  [4823] = {.lex_state = 2},
  [4824] = {.lex_state = 2},
  [4825] = {.lex_state = 2},
  [4826] = {.lex_state = 2},
  [4827] = {.lex_state = 2},
  [4828] = {.lex_state = 2},
  [4829] = {.lex_state = 2},
  [4830] = {.lex_state = 91, .external_lex_state = 7},
  [4831] = {.lex_state = 2},
  [4832] = {.lex_state = 91, .external_lex_state = 7},
  [4833] = {.lex_state = 91, .external_lex_state = 7},
  [4834] = {.lex_state = 2},
  [4835] = {.lex_state = 2},
  [4836] = {.lex_state = 2},
  [4837] = {.lex_state = 91, .external_lex_state = 15},
  [4838] = {.lex_state = 2},
  [4839] = {.lex_state = 2},
  [4840] = {.lex_state = 2},
  [4841] = {.lex_state = 2},
  [4842] = {.lex_state = 2},
  [4843] = {.lex_state = 2},
  [4844] = {.lex_state = 2},
  [4845] = {.lex_state = 11, .external_lex_state = 23},
  [4846] = {.lex_state = 91, .external_lex_state = 2},
  [4847] = {.lex_state = 91, .external_lex_state = 2},
  [4848] = {.lex_state = 91, .external_lex_state = 12},
  [4849] = {.lex_state = 91, .external_lex_state = 2},
  [4850] = {.lex_state = 91, .external_lex_state = 2},
  [4851] = {.lex_state = 91, .external_lex_state = 2},
  [4852] = {.lex_state = 6},
  [4853] = {.lex_state = 91, .external_lex_state = 12},
  [4854] = {.lex_state = 91, .external_lex_state = 12},
  [4855] = {.lex_state = 91, .external_lex_state = 2},
  [4856] = {.lex_state = 6},
  [4857] = {.lex_state = 91, .external_lex_state = 2},
  [4858] = {.lex_state = 91, .external_lex_state = 12},
  [4859] = {.lex_state = 91, .external_lex_state = 19},
  [4860] = {.lex_state = 91, .external_lex_state = 19},
  [4861] = {.lex_state = 11, .external_lex_state = 23},
  [4862] = {.lex_state = 91, .external_lex_state = 14},
  [4863] = {.lex_state = 91, .external_lex_state = 12},
  [4864] = {.lex_state = 91, .external_lex_state = 12},
  [4865] = {.lex_state = 91, .external_lex_state = 2},
  [4866] = {.lex_state = 2},
  [4867] = {.lex_state = 2, .external_lex_state = 23},
  [4868] = {.lex_state = 91, .external_lex_state = 2},
  [4869] = {.lex_state = 11, .external_lex_state = 23},
  [4870] = {.lex_state = 2},
  [4871] = {.lex_state = 91, .external_lex_state = 2},
  [4872] = {.lex_state = 2},
  [4873] = {.lex_state = 91, .external_lex_state = 2},
  [4874] = {.lex_state = 91, .external_lex_state = 15},
  [4875] = {.lex_state = 91, .external_lex_state = 2},
  [4876] = {.lex_state = 91, .external_lex_state = 2},
  [4877] = {.lex_state = 91, .external_lex_state = 2},
  [4878] = {.lex_state = 91, .external_lex_state = 2},
  [4879] = {.lex_state = 91, .external_lex_state = 2},
  [4880] = {.lex_state = 91, .external_lex_state = 15},
  [4881] = {.lex_state = 91, .external_lex_state = 12},
  [4882] = {.lex_state = 91, .external_lex_state = 2},
  [4883] = {.lex_state = 91, .external_lex_state = 2},
  [4884] = {.lex_state = 91, .external_lex_state = 2},
  [4885] = {.lex_state = 91, .external_lex_state = 2},
  [4886] = {.lex_state = 91, .external_lex_state = 2},
  [4887] = {.lex_state = 91, .external_lex_state = 2},
  [4888] = {.lex_state = 91, .external_lex_state = 2},
  [4889] = {.lex_state = 91, .external_lex_state = 2},
  [4890] = {.lex_state = 91, .external_lex_state = 2},
  [4891] = {.lex_state = 91, .external_lex_state = 2},
  [4892] = {.lex_state = 91, .external_lex_state = 2},
  [4893] = {.lex_state = 91, .external_lex_state = 2},
  [4894] = {.lex_state = 91, .external_lex_state = 2},
  [4895] = {.lex_state = 91, .external_lex_state = 2},
  [4896] = {.lex_state = 91, .external_lex_state = 2},
  [4897] = {.lex_state = 91, .external_lex_state = 12},
  [4898] = {.lex_state = 91, .external_lex_state = 2},
  [4899] = {.lex_state = 91, .external_lex_state = 2},
  [4900] = {.lex_state = 91, .external_lex_state = 2},
  [4901] = {.lex_state = 91, .external_lex_state = 2},
  [4902] = {.lex_state = 91, .external_lex_state = 15},
  [4903] = {.lex_state = 91, .external_lex_state = 2},
  [4904] = {.lex_state = 91, .external_lex_state = 2},
  [4905] = {.lex_state = 91, .external_lex_state = 2},
  [4906] = {.lex_state = 91, .external_lex_state = 12},
  [4907] = {.lex_state = 91, .external_lex_state = 2},
  [4908] = {.lex_state = 91, .external_lex_state = 2},
  [4909] = {.lex_state = 91, .external_lex_state = 2},
  [4910] = {.lex_state = 91, .external_lex_state = 2},
  [4911] = {.lex_state = 91, .external_lex_state = 2},
  [4912] = {.lex_state = 91, .external_lex_state = 2},
  [4913] = {.lex_state = 91, .external_lex_state = 2},
  [4914] = {.lex_state = 91, .external_lex_state = 2},
  [4915] = {.lex_state = 91, .external_lex_state = 15},
  [4916] = {.lex_state = 11, .external_lex_state = 23},
  [4917] = {.lex_state = 91, .external_lex_state = 15},
  [4918] = {.lex_state = 91, .external_lex_state = 2},
  [4919] = {.lex_state = 91, .external_lex_state = 2},
  [4920] = {.lex_state = 91, .external_lex_state = 2},
  [4921] = {.lex_state = 91, .external_lex_state = 2},
  [4922] = {.lex_state = 2},
  [4923] = {.lex_state = 2},
  [4924] = {.lex_state = 2},
  [4925] = {.lex_state = 91, .external_lex_state = 2},
  [4926] = {.lex_state = 91, .external_lex_state = 2},
  [4927] = {.lex_state = 2},
  [4928] = {.lex_state = 91, .external_lex_state = 2},
  [4929] = {.lex_state = 91, .external_lex_state = 2},
  [4930] = {.lex_state = 91, .external_lex_state = 2},
  [4931] = {.lex_state = 2},
  [4932] = {.lex_state = 2},
  [4933] = {.lex_state = 2},
  [4934] = {.lex_state = 91, .external_lex_state = 18},
  [4935] = {.lex_state = 91, .external_lex_state = 2},
  [4936] = {.lex_state = 2},
  [4937] = {.lex_state = 2},
  [4938] = {.lex_state = 2},
  [4939] = {.lex_state = 2},
  [4940] = {.lex_state = 2},
  [4941] = {.lex_state = 2},
  [4942] = {.lex_state = 91, .external_lex_state = 2},
  [4943] = {.lex_state = 91, .external_lex_state = 2},
  [4944] = {.lex_state = 91, .external_lex_state = 2},
  [4945] = {.lex_state = 91, .external_lex_state = 2},
  [4946] = {.lex_state = 91, .external_lex_state = 2},
  [4947] = {.lex_state = 91, .external_lex_state = 2},
  [4948] = {.lex_state = 91, .external_lex_state = 2},
  [4949] = {.lex_state = 91, .external_lex_state = 2},
  [4950] = {.lex_state = 2},
  [4951] = {.lex_state = 2},
  [4952] = {.lex_state = 2},
  [4953] = {.lex_state = 2},
  [4954] = {.lex_state = 91, .external_lex_state = 2},
  [4955] = {.lex_state = 2},
  [4956] = {.lex_state = 5},
  [4957] = {.lex_state = 91, .external_lex_state = 2},
  [4958] = {.lex_state = 11, .external_lex_state = 23},
  [4959] = {.lex_state = 91, .external_lex_state = 2},
  [4960] = {.lex_state = 91, .external_lex_state = 2},
  [4961] = {.lex_state = 2},
  [4962] = {.lex_state = 2},
  [4963] = {.lex_state = 2},
  [4964] = {.lex_state = 91, .external_lex_state = 2},
  [4965] = {.lex_state = 91, .external_lex_state = 2},
  [4966] = {.lex_state = 91, .external_lex_state = 2},
  [4967] = {.lex_state = 2},
  [4968] = {.lex_state = 2},
  [4969] = {.lex_state = 2},
  [4970] = {.lex_state = 91, .external_lex_state = 2},
  [4971] = {.lex_state = 2},
  [4972] = {.lex_state = 2},
  [4973] = {.lex_state = 2},
  [4974] = {.lex_state = 91, .external_lex_state = 2},
  [4975] = {.lex_state = 91, .external_lex_state = 15},
  [4976] = {.lex_state = 91, .external_lex_state = 22},
  [4977] = {.lex_state = 91, .external_lex_state = 22},
  [4978] = {.lex_state = 91, .external_lex_state = 22},
  [4979] = {.lex_state = 91, .external_lex_state = 15},
  [4980] = {.lex_state = 91, .external_lex_state = 15},
  [4981] = {.lex_state = 91, .external_lex_state = 22},
  [4982] = {.lex_state = 91, .external_lex_state = 22},
  [4983] = {.lex_state = 91, .external_lex_state = 22},
  [4984] = {.lex_state = 91, .external_lex_state = 15},
  [4985] = {.lex_state = 91, .external_lex_state = 15},
  [4986] = {.lex_state = 91, .external_lex_state = 15},
  [4987] = {.lex_state = 91, .external_lex_state = 22},
  [4988] = {.lex_state = 91, .external_lex_state = 22},
  [4989] = {.lex_state = 91, .external_lex_state = 22},
  [4990] = {.lex_state = 91, .external_lex_state = 22},
  [4991] = {.lex_state = 91, .external_lex_state = 22},
  [4992] = {.lex_state = 91, .external_lex_state = 22},
  [4993] = {.lex_state = 91, .external_lex_state = 22},
  [4994] = {.lex_state = 91, .external_lex_state = 22},
  [4995] = {.lex_state = 91, .external_lex_state = 15},
  [4996] = {.lex_state = 91, .external_lex_state = 22},
  [4997] = {.lex_state = 91, .external_lex_state = 22},
  [4998] = {.lex_state = 91, .external_lex_state = 22},
  [4999] = {.lex_state = 91, .external_lex_state = 22},
  [5000] = {.lex_state = 91, .external_lex_state = 22},
  [5001] = {.lex_state = 91, .external_lex_state = 22},
  [5002] = {.lex_state = 91, .external_lex_state = 22},
  [5003] = {.lex_state = 91, .external_lex_state = 22},
  [5004] = {.lex_state = 91, .external_lex_state = 22},
  [5005] = {.lex_state = 91, .external_lex_state = 15},
  [5006] = {.lex_state = 91, .external_lex_state = 15},
  [5007] = {.lex_state = 91, .external_lex_state = 22},
  [5008] = {.lex_state = 91, .external_lex_state = 22},
  [5009] = {.lex_state = 91, .external_lex_state = 15},
  [5010] = {.lex_state = 91, .external_lex_state = 15},
  [5011] = {.lex_state = 91, .external_lex_state = 15},
  [5012] = {.lex_state = 91, .external_lex_state = 15},
  [5013] = {.lex_state = 91, .external_lex_state = 15},
  [5014] = {.lex_state = 91, .external_lex_state = 15},
  [5015] = {.lex_state = 91, .external_lex_state = 15},
  [5016] = {.lex_state = 91, .external_lex_state = 15},
  [5017] = {.lex_state = 91, .external_lex_state = 15},
  [5018] = {.lex_state = 91, .external_lex_state = 15},
  [5019] = {.lex_state = 91, .external_lex_state = 15},
  [5020] = {.lex_state = 91, .external_lex_state = 15},
  [5021] = {.lex_state = 91, .external_lex_state = 15},
  [5022] = {.lex_state = 91, .external_lex_state = 15},
  [5023] = {.lex_state = 91, .external_lex_state = 15},
  [5024] = {.lex_state = 91, .external_lex_state = 22},
  [5025] = {.lex_state = 91, .external_lex_state = 22},
  [5026] = {.lex_state = 91, .external_lex_state = 22},
  [5027] = {.lex_state = 91, .external_lex_state = 22},
  [5028] = {.lex_state = 91, .external_lex_state = 22},
  [5029] = {.lex_state = 91, .external_lex_state = 22},
  [5030] = {.lex_state = 91, .external_lex_state = 22},
  [5031] = {.lex_state = 11, .external_lex_state = 23},
  [5032] = {.lex_state = 91, .external_lex_state = 22},
  [5033] = {.lex_state = 91, .external_lex_state = 22},
  [5034] = {.lex_state = 91, .external_lex_state = 22},
  [5035] = {.lex_state = 91, .external_lex_state = 15},
  [5036] = {.lex_state = 91, .external_lex_state = 22},
  [5037] = {.lex_state = 91, .external_lex_state = 22},
  [5038] = {.lex_state = 91, .external_lex_state = 22},
  [5039] = {.lex_state = 91, .external_lex_state = 22},
  [5040] = {.lex_state = 91, .external_lex_state = 15},
  [5041] = {.lex_state = 91, .external_lex_state = 15},
  [5042] = {.lex_state = 91, .external_lex_state = 15},
  [5043] = {.lex_state = 91, .external_lex_state = 15},
  [5044] = {.lex_state = 91, .external_lex_state = 15},
  [5045] = {.lex_state = 91, .external_lex_state = 15},
  [5046] = {.lex_state = 91, .external_lex_state = 15},
  [5047] = {.lex_state = 91, .external_lex_state = 15},
  [5048] = {.lex_state = 91, .external_lex_state = 15},
  [5049] = {.lex_state = 91, .external_lex_state = 22},
  [5050] = {.lex_state = 91, .external_lex_state = 22},
  [5051] = {.lex_state = 91, .external_lex_state = 22},
  [5052] = {.lex_state = 91, .external_lex_state = 22},
  [5053] = {.lex_state = 91, .external_lex_state = 22},
  [5054] = {.lex_state = 91, .external_lex_state = 22},
  [5055] = {.lex_state = 91, .external_lex_state = 22},
  [5056] = {.lex_state = 91, .external_lex_state = 22},
  [5057] = {.lex_state = 91, .external_lex_state = 22},
  [5058] = {.lex_state = 91, .external_lex_state = 15},
  [5059] = {.lex_state = 91, .external_lex_state = 15},
  [5060] = {.lex_state = 91, .external_lex_state = 15},
  [5061] = {.lex_state = 91, .external_lex_state = 15},
  [5062] = {.lex_state = 91, .external_lex_state = 15},
  [5063] = {.lex_state = 91, .external_lex_state = 22},
  [5064] = {.lex_state = 91, .external_lex_state = 22},
  [5065] = {.lex_state = 91, .external_lex_state = 22},
  [5066] = {.lex_state = 91, .external_lex_state = 22},
  [5067] = {.lex_state = 91, .external_lex_state = 15},
  [5068] = {.lex_state = 91, .external_lex_state = 22},
  [5069] = {.lex_state = 91, .external_lex_state = 22},
  [5070] = {.lex_state = 91, .external_lex_state = 15},
  [5071] = {.lex_state = 91, .external_lex_state = 15},
  [5072] = {.lex_state = 91, .external_lex_state = 22},
  [5073] = {.lex_state = 91, .external_lex_state = 22},
  [5074] = {.lex_state = 91, .external_lex_state = 22},
  [5075] = {.lex_state = 91, .external_lex_state = 15},
  [5076] = {.lex_state = 91, .external_lex_state = 15},
  [5077] = {.lex_state = 91, .external_lex_state = 15},
  [5078] = {.lex_state = 91, .external_lex_state = 15},
  [5079] = {.lex_state = 91, .external_lex_state = 15},
  [5080] = {.lex_state = 91, .external_lex_state = 15},
  [5081] = {.lex_state = 91, .external_lex_state = 15},
  [5082] = {.lex_state = 91, .external_lex_state = 15},
  [5083] = {.lex_state = 91, .external_lex_state = 15},
  [5084] = {.lex_state = 91, .external_lex_state = 15},
  [5085] = {.lex_state = 91, .external_lex_state = 15},
  [5086] = {.lex_state = 91, .external_lex_state = 22},
  [5087] = {.lex_state = 91, .external_lex_state = 15},
  [5088] = {.lex_state = 91, .external_lex_state = 15},
  [5089] = {.lex_state = 2},
  [5090] = {.lex_state = 91, .external_lex_state = 15},
  [5091] = {.lex_state = 91, .external_lex_state = 22},
  [5092] = {.lex_state = 91, .external_lex_state = 22},
  [5093] = {.lex_state = 91, .external_lex_state = 17},
  [5094] = {.lex_state = 91, .external_lex_state = 17},
  [5095] = {.lex_state = 91, .external_lex_state = 17},
  [5096] = {.lex_state = 91, .external_lex_state = 17},
  [5097] = {.lex_state = 91, .external_lex_state = 17},
  [5098] = {.lex_state = 91, .external_lex_state = 17},
  [5099] = {.lex_state = 91, .external_lex_state = 17},
  [5100] = {.lex_state = 91, .external_lex_state = 17},
  [5101] = {.lex_state = 91, .external_lex_state = 17},
  [5102] = {.lex_state = 91, .external_lex_state = 17},
  [5103] = {.lex_state = 91, .external_lex_state = 17},
  [5104] = {.lex_state = 91, .external_lex_state = 17},
  [5105] = {.lex_state = 91, .external_lex_state = 17},
  [5106] = {.lex_state = 91, .external_lex_state = 17},
  [5107] = {.lex_state = 91, .external_lex_state = 17},
  [5108] = {.lex_state = 91, .external_lex_state = 17},
  [5109] = {.lex_state = 91, .external_lex_state = 17},
  [5110] = {.lex_state = 91, .external_lex_state = 17},
  [5111] = {.lex_state = 91, .external_lex_state = 17},
  [5112] = {.lex_state = 91, .external_lex_state = 17},
  [5113] = {.lex_state = 91, .external_lex_state = 17},
  [5114] = {.lex_state = 91, .external_lex_state = 17},
  [5115] = {.lex_state = 91, .external_lex_state = 17},
  [5116] = {.lex_state = 91, .external_lex_state = 17},
  [5117] = {.lex_state = 91, .external_lex_state = 17},
  [5118] = {.lex_state = 91, .external_lex_state = 17},
  [5119] = {.lex_state = 91, .external_lex_state = 17},
  [5120] = {.lex_state = 91, .external_lex_state = 17},
  [5121] = {.lex_state = 91, .external_lex_state = 17},
  [5122] = {.lex_state = 91, .external_lex_state = 17},
  [5123] = {.lex_state = 91, .external_lex_state = 17},
  [5124] = {.lex_state = 91, .external_lex_state = 17},
  [5125] = {.lex_state = 91, .external_lex_state = 17},
  [5126] = {.lex_state = 91, .external_lex_state = 17},
  [5127] = {.lex_state = 91, .external_lex_state = 17},
  [5128] = {.lex_state = 91, .external_lex_state = 17},
  [5129] = {.lex_state = 91, .external_lex_state = 17},
  [5130] = {.lex_state = 91, .external_lex_state = 17},
  [5131] = {.lex_state = 91, .external_lex_state = 17},
  [5132] = {.lex_state = 91, .external_lex_state = 17},
  [5133] = {.lex_state = 91, .external_lex_state = 17},
  [5134] = {.lex_state = 91, .external_lex_state = 17},
  [5135] = {.lex_state = 91, .external_lex_state = 17},
  [5136] = {.lex_state = 91, .external_lex_state = 17},
  [5137] = {.lex_state = 91, .external_lex_state = 17},
  [5138] = {.lex_state = 91, .external_lex_state = 17},
  [5139] = {.lex_state = 91, .external_lex_state = 17},
  [5140] = {.lex_state = 91, .external_lex_state = 17},
  [5141] = {.lex_state = 91, .external_lex_state = 17},
  [5142] = {.lex_state = 91, .external_lex_state = 17},
  [5143] = {.lex_state = 91, .external_lex_state = 17},
  [5144] = {.lex_state = 91, .external_lex_state = 17},
  [5145] = {.lex_state = 91, .external_lex_state = 17},
  [5146] = {.lex_state = 91, .external_lex_state = 17},
  [5147] = {.lex_state = 91, .external_lex_state = 17},
  [5148] = {.lex_state = 91, .external_lex_state = 17},
  [5149] = {.lex_state = 91, .external_lex_state = 17},
  [5150] = {.lex_state = 91, .external_lex_state = 17},
  [5151] = {.lex_state = 91, .external_lex_state = 17},
  [5152] = {.lex_state = 91, .external_lex_state = 17},
  [5153] = {.lex_state = 91, .external_lex_state = 17},
  [5154] = {.lex_state = 91, .external_lex_state = 17},
  [5155] = {.lex_state = 91, .external_lex_state = 17},
  [5156] = {.lex_state = 91, .external_lex_state = 17},
  [5157] = {.lex_state = 91, .external_lex_state = 17},
  [5158] = {.lex_state = 91, .external_lex_state = 17},
  [5159] = {.lex_state = 91, .external_lex_state = 17},
  [5160] = {.lex_state = 91, .external_lex_state = 17},
  [5161] = {.lex_state = 91, .external_lex_state = 17},
  [5162] = {.lex_state = 91, .external_lex_state = 17},
  [5163] = {.lex_state = 91, .external_lex_state = 17},
  [5164] = {.lex_state = 91, .external_lex_state = 17},
  [5165] = {.lex_state = 91, .external_lex_state = 17},
  [5166] = {.lex_state = 91, .external_lex_state = 17},
  [5167] = {.lex_state = 91, .external_lex_state = 17},
  [5168] = {.lex_state = 91, .external_lex_state = 17},
  [5169] = {.lex_state = 91, .external_lex_state = 17},
  [5170] = {.lex_state = 91, .external_lex_state = 17},
  [5171] = {.lex_state = 91, .external_lex_state = 17},
  [5172] = {.lex_state = 91, .external_lex_state = 17},
  [5173] = {.lex_state = 91, .external_lex_state = 17},
  [5174] = {.lex_state = 91, .external_lex_state = 17},
  [5175] = {.lex_state = 91, .external_lex_state = 17},
  [5176] = {.lex_state = 91, .external_lex_state = 17},
  [5177] = {.lex_state = 91, .external_lex_state = 17},
  [5178] = {.lex_state = 91, .external_lex_state = 17},
  [5179] = {.lex_state = 91, .external_lex_state = 17},
  [5180] = {.lex_state = 91, .external_lex_state = 17},
  [5181] = {.lex_state = 91, .external_lex_state = 17},
  [5182] = {.lex_state = 91, .external_lex_state = 17},
  [5183] = {.lex_state = 91, .external_lex_state = 17},
  [5184] = {.lex_state = 91, .external_lex_state = 17},
  [5185] = {.lex_state = 91, .external_lex_state = 17},
  [5186] = {.lex_state = 91, .external_lex_state = 17},
  [5187] = {.lex_state = 91, .external_lex_state = 17},
  [5188] = {.lex_state = 91, .external_lex_state = 17},
  [5189] = {.lex_state = 91, .external_lex_state = 17},
  [5190] = {.lex_state = 91, .external_lex_state = 17},
  [5191] = {.lex_state = 91, .external_lex_state = 17},
  [5192] = {.lex_state = 91, .external_lex_state = 17},
  [5193] = {.lex_state = 91, .external_lex_state = 17},
  [5194] = {.lex_state = 91, .external_lex_state = 17},
  [5195] = {.lex_state = 91, .external_lex_state = 17},
  [5196] = {.lex_state = 91, .external_lex_state = 17},
  [5197] = {.lex_state = 91, .external_lex_state = 17},
  [5198] = {.lex_state = 91, .external_lex_state = 17},
  [5199] = {.lex_state = 91, .external_lex_state = 17},
  [5200] = {.lex_state = 91, .external_lex_state = 17},
  [5201] = {.lex_state = 91, .external_lex_state = 17},
  [5202] = {.lex_state = 91, .external_lex_state = 17},
  [5203] = {.lex_state = 91, .external_lex_state = 17},
  [5204] = {.lex_state = 91, .external_lex_state = 17},
  [5205] = {.lex_state = 91, .external_lex_state = 17},
  [5206] = {.lex_state = 91, .external_lex_state = 17},
  [5207] = {.lex_state = 91, .external_lex_state = 17},
  [5208] = {.lex_state = 91, .external_lex_state = 17},
  [5209] = {.lex_state = 91, .external_lex_state = 17},
  [5210] = {.lex_state = 91, .external_lex_state = 17},
  [5211] = {.lex_state = 91, .external_lex_state = 17},
  [5212] = {.lex_state = 91, .external_lex_state = 17},
  [5213] = {.lex_state = 91, .external_lex_state = 17},
  [5214] = {.lex_state = 91, .external_lex_state = 17},
  [5215] = {.lex_state = 91, .external_lex_state = 17},
  [5216] = {.lex_state = 91, .external_lex_state = 17},
  [5217] = {.lex_state = 91, .external_lex_state = 17},
  [5218] = {.lex_state = 91, .external_lex_state = 17},
  [5219] = {.lex_state = 91, .external_lex_state = 17},
  [5220] = {.lex_state = 91, .external_lex_state = 17},
  [5221] = {.lex_state = 91, .external_lex_state = 17},
  [5222] = {.lex_state = 91, .external_lex_state = 17},
  [5223] = {.lex_state = 91, .external_lex_state = 17},
  [5224] = {.lex_state = 91, .external_lex_state = 17},
  [5225] = {.lex_state = 91, .external_lex_state = 17},
  [5226] = {.lex_state = 91, .external_lex_state = 17},
  [5227] = {.lex_state = 91, .external_lex_state = 17},
  [5228] = {.lex_state = 91, .external_lex_state = 17},
  [5229] = {.lex_state = 91, .external_lex_state = 17},
  [5230] = {.lex_state = 91, .external_lex_state = 17},
  [5231] = {.lex_state = 91, .external_lex_state = 17},
  [5232] = {.lex_state = 91, .external_lex_state = 17},
  [5233] = {.lex_state = 91, .external_lex_state = 17},
  [5234] = {.lex_state = 91, .external_lex_state = 17},
  [5235] = {.lex_state = 91, .external_lex_state = 17},
  [5236] = {.lex_state = 91, .external_lex_state = 17},
  [5237] = {.lex_state = 91, .external_lex_state = 17},
  [5238] = {.lex_state = 91, .external_lex_state = 17},
  [5239] = {.lex_state = 91, .external_lex_state = 17},
  [5240] = {.lex_state = 91, .external_lex_state = 17},
  [5241] = {.lex_state = 91, .external_lex_state = 17},
  [5242] = {.lex_state = 91, .external_lex_state = 17},
  [5243] = {.lex_state = 91, .external_lex_state = 17},
  [5244] = {.lex_state = 91, .external_lex_state = 17},
  [5245] = {.lex_state = 91, .external_lex_state = 17},
  [5246] = {.lex_state = 91, .external_lex_state = 17},
  [5247] = {.lex_state = 91, .external_lex_state = 17},
  [5248] = {.lex_state = 91, .external_lex_state = 17},
  [5249] = {.lex_state = 91, .external_lex_state = 17},
  [5250] = {.lex_state = 91, .external_lex_state = 17},
  [5251] = {.lex_state = 91, .external_lex_state = 17},
  [5252] = {.lex_state = 91, .external_lex_state = 17},
  [5253] = {.lex_state = 91, .external_lex_state = 17},
  [5254] = {.lex_state = 91, .external_lex_state = 17},
  [5255] = {.lex_state = 91, .external_lex_state = 17},
  [5256] = {.lex_state = 91, .external_lex_state = 17},
  [5257] = {.lex_state = 91, .external_lex_state = 17},
  [5258] = {.lex_state = 91, .external_lex_state = 17},
  [5259] = {.lex_state = 91, .external_lex_state = 17},
  [5260] = {.lex_state = 91, .external_lex_state = 17},
  [5261] = {.lex_state = 91, .external_lex_state = 17},
  [5262] = {.lex_state = 91, .external_lex_state = 17},
  [5263] = {.lex_state = 91, .external_lex_state = 17},
  [5264] = {.lex_state = 91, .external_lex_state = 17},
  [5265] = {.lex_state = 91, .external_lex_state = 17},
  [5266] = {.lex_state = 91, .external_lex_state = 17},
  [5267] = {.lex_state = 91, .external_lex_state = 17},
  [5268] = {.lex_state = 91, .external_lex_state = 17},
  [5269] = {.lex_state = 91, .external_lex_state = 17},
  [5270] = {.lex_state = 91, .external_lex_state = 17},
  [5271] = {.lex_state = 91, .external_lex_state = 17},
  [5272] = {.lex_state = 91, .external_lex_state = 17},
  [5273] = {.lex_state = 91, .external_lex_state = 17},
  [5274] = {.lex_state = 91, .external_lex_state = 17},
  [5275] = {.lex_state = 91, .external_lex_state = 17},
  [5276] = {.lex_state = 91, .external_lex_state = 17},
  [5277] = {.lex_state = 91, .external_lex_state = 17},
  [5278] = {.lex_state = 91, .external_lex_state = 17},
  [5279] = {.lex_state = 91, .external_lex_state = 17},
  [5280] = {.lex_state = 91, .external_lex_state = 17},
  [5281] = {.lex_state = 91, .external_lex_state = 17},
  [5282] = {.lex_state = 91, .external_lex_state = 17},
  [5283] = {.lex_state = 91, .external_lex_state = 17},
  [5284] = {.lex_state = 91, .external_lex_state = 17},
  [5285] = {.lex_state = 91, .external_lex_state = 17},
  [5286] = {.lex_state = 91, .external_lex_state = 17},
  [5287] = {.lex_state = 91, .external_lex_state = 17},
  [5288] = {.lex_state = 91, .external_lex_state = 17},
  [5289] = {.lex_state = 91, .external_lex_state = 17},
  [5290] = {.lex_state = 91, .external_lex_state = 17},
  [5291] = {.lex_state = 91, .external_lex_state = 17},
  [5292] = {.lex_state = 91, .external_lex_state = 17},
  [5293] = {.lex_state = 91, .external_lex_state = 17},
  [5294] = {.lex_state = 91, .external_lex_state = 17},
  [5295] = {.lex_state = 91, .external_lex_state = 17},
  [5296] = {.lex_state = 91, .external_lex_state = 17},
  [5297] = {.lex_state = 91, .external_lex_state = 17},
  [5298] = {.lex_state = 91, .external_lex_state = 17},
  [5299] = {.lex_state = 91, .external_lex_state = 17},
  [5300] = {.lex_state = 91, .external_lex_state = 17},
  [5301] = {.lex_state = 91, .external_lex_state = 17},
  [5302] = {.lex_state = 91, .external_lex_state = 17},
  [5303] = {.lex_state = 91, .external_lex_state = 17},
  [5304] = {.lex_state = 91, .external_lex_state = 17},
  [5305] = {.lex_state = 91, .external_lex_state = 17},
  [5306] = {.lex_state = 91, .external_lex_state = 17},
  [5307] = {.lex_state = 91, .external_lex_state = 17},
  [5308] = {.lex_state = 91, .external_lex_state = 17},
  [5309] = {.lex_state = 91, .external_lex_state = 17},
  [5310] = {.lex_state = 91, .external_lex_state = 17},
  [5311] = {.lex_state = 91, .external_lex_state = 17},
  [5312] = {.lex_state = 91, .external_lex_state = 17},
  [5313] = {.lex_state = 91, .external_lex_state = 17},
  [5314] = {.lex_state = 91, .external_lex_state = 17},
  [5315] = {.lex_state = 91, .external_lex_state = 17},
  [5316] = {.lex_state = 91, .external_lex_state = 17},
  [5317] = {.lex_state = 91, .external_lex_state = 17},
  [5318] = {.lex_state = 91, .external_lex_state = 17},
  [5319] = {.lex_state = 91, .external_lex_state = 17},
  [5320] = {.lex_state = 91, .external_lex_state = 17},
  [5321] = {.lex_state = 91, .external_lex_state = 17},
  [5322] = {.lex_state = 91, .external_lex_state = 17},
  [5323] = {.lex_state = 91, .external_lex_state = 17},
  [5324] = {.lex_state = 91, .external_lex_state = 17},
  [5325] = {.lex_state = 91, .external_lex_state = 17},
  [5326] = {.lex_state = 91, .external_lex_state = 17},
  [5327] = {.lex_state = 91, .external_lex_state = 17},
  [5328] = {.lex_state = 91, .external_lex_state = 17},
  [5329] = {.lex_state = 91, .external_lex_state = 17},
  [5330] = {.lex_state = 91, .external_lex_state = 17},
  [5331] = {.lex_state = 91, .external_lex_state = 17},
  [5332] = {.lex_state = 91, .external_lex_state = 17},
  [5333] = {.lex_state = 91, .external_lex_state = 17},
  [5334] = {.lex_state = 91, .external_lex_state = 17},
  [5335] = {.lex_state = 91, .external_lex_state = 17},
  [5336] = {.lex_state = 91, .external_lex_state = 17},
  [5337] = {.lex_state = 91, .external_lex_state = 17},
  [5338] = {.lex_state = 91, .external_lex_state = 17},
  [5339] = {.lex_state = 91, .external_lex_state = 17},
  [5340] = {.lex_state = 91, .external_lex_state = 17},
  [5341] = {.lex_state = 91, .external_lex_state = 17},
  [5342] = {.lex_state = 91, .external_lex_state = 17},
  [5343] = {.lex_state = 91, .external_lex_state = 17},
  [5344] = {.lex_state = 91, .external_lex_state = 17},
  [5345] = {.lex_state = 91, .external_lex_state = 17},
  [5346] = {.lex_state = 91, .external_lex_state = 17},
  [5347] = {.lex_state = 91, .external_lex_state = 17},
  [5348] = {.lex_state = 91, .external_lex_state = 17},
  [5349] = {.lex_state = 91, .external_lex_state = 17},
  [5350] = {.lex_state = 91, .external_lex_state = 17},
  [5351] = {.lex_state = 91, .external_lex_state = 17},
  [5352] = {.lex_state = 91, .external_lex_state = 17},
  [5353] = {.lex_state = 91, .external_lex_state = 17},
  [5354] = {.lex_state = 91, .external_lex_state = 17},
  [5355] = {.lex_state = 91, .external_lex_state = 17},
  [5356] = {.lex_state = 91, .external_lex_state = 17},
  [5357] = {.lex_state = 91, .external_lex_state = 17},
  [5358] = {.lex_state = 91, .external_lex_state = 17},
  [5359] = {.lex_state = 91, .external_lex_state = 17},
  [5360] = {.lex_state = 91, .external_lex_state = 17},
  [5361] = {.lex_state = 91, .external_lex_state = 17},
  [5362] = {.lex_state = 91, .external_lex_state = 17},
  [5363] = {.lex_state = 91, .external_lex_state = 17},
  [5364] = {.lex_state = 91, .external_lex_state = 17},
  [5365] = {.lex_state = 91, .external_lex_state = 17},
  [5366] = {.lex_state = 91, .external_lex_state = 17},
  [5367] = {.lex_state = 91, .external_lex_state = 17},
  [5368] = {.lex_state = 91, .external_lex_state = 17},
  [5369] = {.lex_state = 91, .external_lex_state = 17},
  [5370] = {.lex_state = 91, .external_lex_state = 17},
  [5371] = {.lex_state = 91, .external_lex_state = 17},
  [5372] = {.lex_state = 91, .external_lex_state = 17},
  [5373] = {.lex_state = 91, .external_lex_state = 17},
  [5374] = {.lex_state = 91, .external_lex_state = 17},
  [5375] = {.lex_state = 91, .external_lex_state = 17},
  [5376] = {.lex_state = 91, .external_lex_state = 17},
  [5377] = {.lex_state = 91, .external_lex_state = 17},
  [5378] = {.lex_state = 91, .external_lex_state = 17},
  [5379] = {.lex_state = 91, .external_lex_state = 17},
  [5380] = {.lex_state = 91, .external_lex_state = 17},
  [5381] = {.lex_state = 91, .external_lex_state = 17},
  [5382] = {.lex_state = 91, .external_lex_state = 17},
  [5383] = {.lex_state = 91, .external_lex_state = 17},
  [5384] = {.lex_state = 91, .external_lex_state = 17},
  [5385] = {.lex_state = 2, .external_lex_state = 23},
  [5386] = {.lex_state = 91, .external_lex_state = 17},
  [5387] = {.lex_state = 11, .external_lex_state = 23},
  [5388] = {.lex_state = 91, .external_lex_state = 17},
  [5389] = {.lex_state = 2},
  [5390] = {.lex_state = 91, .external_lex_state = 18},
  [5391] = {.lex_state = 91, .external_lex_state = 18},
  [5392] = {.lex_state = 91, .external_lex_state = 18},
  [5393] = {.lex_state = 91, .external_lex_state = 18},
  [5394] = {.lex_state = 91, .external_lex_state = 18},
  [5395] = {.lex_state = 91, .external_lex_state = 18},
  [5396] = {.lex_state = 2},
  [5397] = {.lex_state = 91, .external_lex_state = 18},
  [5398] = {.lex_state = 91, .external_lex_state = 18},
  [5399] = {.lex_state = 91, .external_lex_state = 18},
  [5400] = {.lex_state = 91, .external_lex_state = 18},
  [5401] = {.lex_state = 2},
  [5402] = {.lex_state = 2},
  [5403] = {.lex_state = 91, .external_lex_state = 16},
  [5404] = {.lex_state = 91, .external_lex_state = 16},
  [5405] = {.lex_state = 91, .external_lex_state = 16},
  [5406] = {.lex_state = 91, .external_lex_state = 16},
  [5407] = {.lex_state = 91, .external_lex_state = 16},
  [5408] = {.lex_state = 91, .external_lex_state = 16},
  [5409] = {.lex_state = 91, .external_lex_state = 16},
  [5410] = {.lex_state = 91, .external_lex_state = 16},
  [5411] = {.lex_state = 91, .external_lex_state = 16},
  [5412] = {.lex_state = 91, .external_lex_state = 16},
  [5413] = {.lex_state = 91, .external_lex_state = 16},
  [5414] = {.lex_state = 91, .external_lex_state = 16},
  [5415] = {.lex_state = 91, .external_lex_state = 16},
  [5416] = {.lex_state = 91, .external_lex_state = 16},
  [5417] = {.lex_state = 91, .external_lex_state = 16},
  [5418] = {.lex_state = 91, .external_lex_state = 16},
  [5419] = {.lex_state = 91, .external_lex_state = 16},
  [5420] = {.lex_state = 91, .external_lex_state = 16},
  [5421] = {.lex_state = 2},
  [5422] = {.lex_state = 2},
  [5423] = {.lex_state = 2},
  [5424] = {.lex_state = 2},
  [5425] = {.lex_state = 91, .external_lex_state = 12},
  [5426] = {.lex_state = 91, .external_lex_state = 12},
  [5427] = {.lex_state = 91, .external_lex_state = 12},
  [5428] = {.lex_state = 91, .external_lex_state = 12},
  [5429] = {.lex_state = 91, .external_lex_state = 12},
  [5430] = {.lex_state = 91, .external_lex_state = 12},
  [5431] = {.lex_state = 91, .external_lex_state = 12},
  [5432] = {.lex_state = 91, .external_lex_state = 12},
  [5433] = {.lex_state = 91, .external_lex_state = 12},
  [5434] = {.lex_state = 91, .external_lex_state = 12},
  [5435] = {.lex_state = 91, .external_lex_state = 12},
  [5436] = {.lex_state = 91, .external_lex_state = 12},
  [5437] = {.lex_state = 91, .external_lex_state = 12},
  [5438] = {.lex_state = 2},
  [5439] = {.lex_state = 91, .external_lex_state = 12},
  [5440] = {.lex_state = 91, .external_lex_state = 12},
  [5441] = {.lex_state = 91, .external_lex_state = 12},
  [5442] = {.lex_state = 91, .external_lex_state = 12},
  [5443] = {.lex_state = 2},
  [5444] = {.lex_state = 2},
  [5445] = {.lex_state = 2},
  [5446] = {.lex_state = 91, .external_lex_state = 12},
  [5447] = {.lex_state = 91, .external_lex_state = 12},
  [5448] = {.lex_state = 91, .external_lex_state = 12},
  [5449] = {.lex_state = 91, .external_lex_state = 12},
  [5450] = {.lex_state = 91, .external_lex_state = 12},
  [5451] = {.lex_state = 91, .external_lex_state = 12},
  [5452] = {.lex_state = 91, .external_lex_state = 12},
  [5453] = {.lex_state = 91, .external_lex_state = 12},
  [5454] = {.lex_state = 91, .external_lex_state = 12},
  [5455] = {.lex_state = 91, .external_lex_state = 12},
  [5456] = {.lex_state = 91, .external_lex_state = 12},
  [5457] = {.lex_state = 91, .external_lex_state = 12},
  [5458] = {.lex_state = 91, .external_lex_state = 12},
  [5459] = {.lex_state = 91, .external_lex_state = 12},
  [5460] = {.lex_state = 91, .external_lex_state = 12},
  [5461] = {.lex_state = 91, .external_lex_state = 12},
  [5462] = {.lex_state = 91, .external_lex_state = 12},
  [5463] = {.lex_state = 91, .external_lex_state = 12},
  [5464] = {.lex_state = 91, .external_lex_state = 12},
  [5465] = {.lex_state = 91, .external_lex_state = 12},
  [5466] = {.lex_state = 91, .external_lex_state = 12},
  [5467] = {.lex_state = 91, .external_lex_state = 12},
  [5468] = {.lex_state = 91, .external_lex_state = 12},
  [5469] = {.lex_state = 91, .external_lex_state = 12},
  [5470] = {.lex_state = 91, .external_lex_state = 22},
  [5471] = {.lex_state = 91, .external_lex_state = 22},
  [5472] = {.lex_state = 91, .external_lex_state = 12},
  [5473] = {.lex_state = 91, .external_lex_state = 12},
  [5474] = {.lex_state = 91, .external_lex_state = 12},
  [5475] = {.lex_state = 91, .external_lex_state = 12},
  [5476] = {.lex_state = 91, .external_lex_state = 12},
  [5477] = {.lex_state = 91, .external_lex_state = 12},
  [5478] = {.lex_state = 91, .external_lex_state = 12},
  [5479] = {.lex_state = 91, .external_lex_state = 12},
  [5480] = {.lex_state = 91, .external_lex_state = 12},
  [5481] = {.lex_state = 91, .external_lex_state = 12},
  [5482] = {.lex_state = 91, .external_lex_state = 12},
  [5483] = {.lex_state = 91, .external_lex_state = 12},
  [5484] = {.lex_state = 91, .external_lex_state = 12},
  [5485] = {.lex_state = 91, .external_lex_state = 12},
  [5486] = {.lex_state = 91, .external_lex_state = 12},
  [5487] = {.lex_state = 91, .external_lex_state = 12},
  [5488] = {.lex_state = 91, .external_lex_state = 12},
  [5489] = {.lex_state = 91, .external_lex_state = 12},
  [5490] = {.lex_state = 91, .external_lex_state = 12},
  [5491] = {.lex_state = 91, .external_lex_state = 22},
  [5492] = {.lex_state = 91, .external_lex_state = 12},
  [5493] = {.lex_state = 91, .external_lex_state = 22},
  [5494] = {.lex_state = 91, .external_lex_state = 12},
  [5495] = {.lex_state = 91, .external_lex_state = 12},
  [5496] = {.lex_state = 91, .external_lex_state = 12},
  [5497] = {.lex_state = 91, .external_lex_state = 12},
  [5498] = {.lex_state = 91, .external_lex_state = 12},
  [5499] = {.lex_state = 91, .external_lex_state = 12},
  [5500] = {.lex_state = 91, .external_lex_state = 22},
  [5501] = {.lex_state = 91, .external_lex_state = 22},
  [5502] = {.lex_state = 91, .external_lex_state = 22},
  [5503] = {.lex_state = 91, .external_lex_state = 12},
  [5504] = {.lex_state = 91, .external_lex_state = 12},
  [5505] = {.lex_state = 91, .external_lex_state = 12},
  [5506] = {.lex_state = 91, .external_lex_state = 12},
  [5507] = {.lex_state = 91, .external_lex_state = 12},
  [5508] = {.lex_state = 91, .external_lex_state = 22},
  [5509] = {.lex_state = 91, .external_lex_state = 12},
  [5510] = {.lex_state = 91, .external_lex_state = 12},
  [5511] = {.lex_state = 91, .external_lex_state = 12},
  [5512] = {.lex_state = 91, .external_lex_state = 12},
  [5513] = {.lex_state = 91, .external_lex_state = 12},
  [5514] = {.lex_state = 91, .external_lex_state = 12},
  [5515] = {.lex_state = 91, .external_lex_state = 12},
  [5516] = {.lex_state = 91, .external_lex_state = 12},
  [5517] = {.lex_state = 91, .external_lex_state = 12},
  [5518] = {.lex_state = 91, .external_lex_state = 12},
  [5519] = {.lex_state = 91, .external_lex_state = 12},
  [5520] = {.lex_state = 91, .external_lex_state = 12},
  [5521] = {.lex_state = 91, .external_lex_state = 12},
  [5522] = {.lex_state = 91, .external_lex_state = 12},
  [5523] = {.lex_state = 91, .external_lex_state = 12},
  [5524] = {.lex_state = 91, .external_lex_state = 22},
  [5525] = {.lex_state = 91, .external_lex_state = 22},
  [5526] = {.lex_state = 91, .external_lex_state = 12},
  [5527] = {.lex_state = 91, .external_lex_state = 12},
  [5528] = {.lex_state = 91, .external_lex_state = 12},
  [5529] = {.lex_state = 91, .external_lex_state = 12},
  [5530] = {.lex_state = 91, .external_lex_state = 12},
  [5531] = {.lex_state = 91, .external_lex_state = 12},
  [5532] = {.lex_state = 91, .external_lex_state = 12},
  [5533] = {.lex_state = 91, .external_lex_state = 12},
  [5534] = {.lex_state = 91, .external_lex_state = 12},
  [5535] = {.lex_state = 91, .external_lex_state = 12},
  [5536] = {.lex_state = 91, .external_lex_state = 12},
  [5537] = {.lex_state = 91, .external_lex_state = 12},
  [5538] = {.lex_state = 91, .external_lex_state = 12},
  [5539] = {.lex_state = 91, .external_lex_state = 12},
  [5540] = {.lex_state = 91, .external_lex_state = 12},
  [5541] = {.lex_state = 91, .external_lex_state = 12},
  [5542] = {.lex_state = 91, .external_lex_state = 12},
  [5543] = {.lex_state = 91, .external_lex_state = 12},
  [5544] = {.lex_state = 91, .external_lex_state = 12},
  [5545] = {.lex_state = 91, .external_lex_state = 12},
  [5546] = {.lex_state = 91, .external_lex_state = 12},
  [5547] = {.lex_state = 91, .external_lex_state = 12},
  [5548] = {.lex_state = 91, .external_lex_state = 12},
  [5549] = {.lex_state = 91, .external_lex_state = 12},
  [5550] = {.lex_state = 91, .external_lex_state = 12},
  [5551] = {.lex_state = 91, .external_lex_state = 12},
  [5552] = {.lex_state = 91, .external_lex_state = 12},
  [5553] = {.lex_state = 91, .external_lex_state = 12},
  [5554] = {.lex_state = 91, .external_lex_state = 12},
  [5555] = {.lex_state = 91, .external_lex_state = 22},
  [5556] = {.lex_state = 91, .external_lex_state = 12},
  [5557] = {.lex_state = 91, .external_lex_state = 12},
  [5558] = {.lex_state = 91, .external_lex_state = 12},
  [5559] = {.lex_state = 91, .external_lex_state = 12},
  [5560] = {.lex_state = 91, .external_lex_state = 12},
  [5561] = {.lex_state = 91, .external_lex_state = 12},
  [5562] = {.lex_state = 91, .external_lex_state = 12},
  [5563] = {.lex_state = 91, .external_lex_state = 22},
  [5564] = {.lex_state = 91, .external_lex_state = 12},
  [5565] = {.lex_state = 91, .external_lex_state = 12},
  [5566] = {.lex_state = 91, .external_lex_state = 12},
  [5567] = {.lex_state = 91, .external_lex_state = 12},
  [5568] = {.lex_state = 91, .external_lex_state = 12},
  [5569] = {.lex_state = 91, .external_lex_state = 12},
  [5570] = {.lex_state = 91, .external_lex_state = 12},
  [5571] = {.lex_state = 91, .external_lex_state = 12},
  [5572] = {.lex_state = 91, .external_lex_state = 12},
  [5573] = {.lex_state = 91, .external_lex_state = 12},
  [5574] = {.lex_state = 91, .external_lex_state = 12},
  [5575] = {.lex_state = 91, .external_lex_state = 12},
  [5576] = {.lex_state = 91, .external_lex_state = 12},
  [5577] = {.lex_state = 91, .external_lex_state = 12},
  [5578] = {.lex_state = 91, .external_lex_state = 12},
  [5579] = {.lex_state = 91, .external_lex_state = 12},
  [5580] = {.lex_state = 91, .external_lex_state = 12},
  [5581] = {.lex_state = 91, .external_lex_state = 12},
  [5582] = {.lex_state = 91, .external_lex_state = 12},
  [5583] = {.lex_state = 91, .external_lex_state = 12},
  [5584] = {.lex_state = 91, .external_lex_state = 12},
  [5585] = {.lex_state = 91, .external_lex_state = 12},
  [5586] = {.lex_state = 91, .external_lex_state = 12},
  [5587] = {.lex_state = 91, .external_lex_state = 12},
  [5588] = {.lex_state = 91, .external_lex_state = 12},
  [5589] = {.lex_state = 91, .external_lex_state = 12},
  [5590] = {.lex_state = 91, .external_lex_state = 12},
  [5591] = {.lex_state = 91, .external_lex_state = 12},
  [5592] = {.lex_state = 2},
  [5593] = {.lex_state = 91, .external_lex_state = 12},
  [5594] = {.lex_state = 91, .external_lex_state = 12},
  [5595] = {.lex_state = 91, .external_lex_state = 12},
  [5596] = {.lex_state = 91, .external_lex_state = 12},
  [5597] = {.lex_state = 91, .external_lex_state = 12},
  [5598] = {.lex_state = 91, .external_lex_state = 12},
  [5599] = {.lex_state = 91, .external_lex_state = 12},
  [5600] = {.lex_state = 91, .external_lex_state = 12},
  [5601] = {.lex_state = 91, .external_lex_state = 12},
  [5602] = {.lex_state = 91, .external_lex_state = 12},
  [5603] = {.lex_state = 91, .external_lex_state = 12},
  [5604] = {.lex_state = 91, .external_lex_state = 12},
  [5605] = {.lex_state = 91, .external_lex_state = 12},
  [5606] = {.lex_state = 91, .external_lex_state = 12},
  [5607] = {.lex_state = 91, .external_lex_state = 12},
  [5608] = {.lex_state = 91, .external_lex_state = 12},
  [5609] = {.lex_state = 91, .external_lex_state = 12},
  [5610] = {.lex_state = 91, .external_lex_state = 12},
  [5611] = {.lex_state = 91, .external_lex_state = 12},
  [5612] = {.lex_state = 91, .external_lex_state = 12},
  [5613] = {.lex_state = 91, .external_lex_state = 12},
  [5614] = {.lex_state = 91, .external_lex_state = 12},
  [5615] = {.lex_state = 91, .external_lex_state = 12},
  [5616] = {.lex_state = 91, .external_lex_state = 12},
  [5617] = {.lex_state = 91, .external_lex_state = 16},
  [5618] = {.lex_state = 91, .external_lex_state = 12},
  [5619] = {.lex_state = 91, .external_lex_state = 12},
  [5620] = {.lex_state = 91, .external_lex_state = 12},
  [5621] = {.lex_state = 91, .external_lex_state = 12},
  [5622] = {.lex_state = 91, .external_lex_state = 12},
  [5623] = {.lex_state = 91, .external_lex_state = 12},
  [5624] = {.lex_state = 91, .external_lex_state = 12},
  [5625] = {.lex_state = 91, .external_lex_state = 12},
  [5626] = {.lex_state = 91, .external_lex_state = 12},
  [5627] = {.lex_state = 91, .external_lex_state = 12},
  [5628] = {.lex_state = 91, .external_lex_state = 12},
  [5629] = {.lex_state = 91, .external_lex_state = 12},
  [5630] = {.lex_state = 91, .external_lex_state = 12},
  [5631] = {.lex_state = 91, .external_lex_state = 12},
  [5632] = {.lex_state = 91, .external_lex_state = 12},
  [5633] = {.lex_state = 91, .external_lex_state = 12},
  [5634] = {.lex_state = 91, .external_lex_state = 12},
  [5635] = {.lex_state = 91, .external_lex_state = 12},
  [5636] = {.lex_state = 91, .external_lex_state = 12},
  [5637] = {.lex_state = 91, .external_lex_state = 12},
  [5638] = {.lex_state = 91, .external_lex_state = 12},
  [5639] = {.lex_state = 91, .external_lex_state = 12},
  [5640] = {.lex_state = 91, .external_lex_state = 12},
  [5641] = {.lex_state = 91, .external_lex_state = 12},
  [5642] = {.lex_state = 91, .external_lex_state = 12},
  [5643] = {.lex_state = 91, .external_lex_state = 12},
  [5644] = {.lex_state = 91, .external_lex_state = 12},
  [5645] = {.lex_state = 91, .external_lex_state = 12},
  [5646] = {.lex_state = 91, .external_lex_state = 12},
  [5647] = {.lex_state = 91, .external_lex_state = 12},
  [5648] = {.lex_state = 91, .external_lex_state = 12},
  [5649] = {.lex_state = 91, .external_lex_state = 12},
  [5650] = {.lex_state = 91, .external_lex_state = 12},
  [5651] = {.lex_state = 91, .external_lex_state = 12},
  [5652] = {.lex_state = 91, .external_lex_state = 12},
  [5653] = {.lex_state = 91, .external_lex_state = 12},
  [5654] = {.lex_state = 91, .external_lex_state = 12},
  [5655] = {.lex_state = 91, .external_lex_state = 12},
  [5656] = {.lex_state = 91, .external_lex_state = 12},
  [5657] = {.lex_state = 91, .external_lex_state = 12},
  [5658] = {.lex_state = 91, .external_lex_state = 12},
  [5659] = {.lex_state = 91, .external_lex_state = 12},
  [5660] = {.lex_state = 91, .external_lex_state = 12},
  [5661] = {.lex_state = 91, .external_lex_state = 12},
  [5662] = {.lex_state = 91, .external_lex_state = 12},
  [5663] = {.lex_state = 91, .external_lex_state = 12},
  [5664] = {.lex_state = 91, .external_lex_state = 12},
  [5665] = {.lex_state = 91, .external_lex_state = 12},
  [5666] = {.lex_state = 91, .external_lex_state = 12},
  [5667] = {.lex_state = 91, .external_lex_state = 12},
  [5668] = {.lex_state = 91, .external_lex_state = 12},
  [5669] = {.lex_state = 91, .external_lex_state = 12},
  [5670] = {.lex_state = 91, .external_lex_state = 16},
  [5671] = {.lex_state = 91, .external_lex_state = 12},
  [5672] = {.lex_state = 91, .external_lex_state = 12},
  [5673] = {.lex_state = 91, .external_lex_state = 12},
  [5674] = {.lex_state = 91, .external_lex_state = 12},
  [5675] = {.lex_state = 91, .external_lex_state = 12},
  [5676] = {.lex_state = 91, .external_lex_state = 12},
  [5677] = {.lex_state = 91, .external_lex_state = 12},
  [5678] = {.lex_state = 91, .external_lex_state = 12},
  [5679] = {.lex_state = 91, .external_lex_state = 12},
  [5680] = {.lex_state = 91, .external_lex_state = 12},
  [5681] = {.lex_state = 91, .external_lex_state = 12},
  [5682] = {.lex_state = 91, .external_lex_state = 12},
  [5683] = {.lex_state = 91, .external_lex_state = 12},
  [5684] = {.lex_state = 91, .external_lex_state = 12},
  [5685] = {.lex_state = 91, .external_lex_state = 16},
  [5686] = {.lex_state = 91, .external_lex_state = 12},
  [5687] = {.lex_state = 91, .external_lex_state = 12},
  [5688] = {.lex_state = 91, .external_lex_state = 12},
  [5689] = {.lex_state = 91, .external_lex_state = 12},
  [5690] = {.lex_state = 91, .external_lex_state = 12},
  [5691] = {.lex_state = 91, .external_lex_state = 12},
  [5692] = {.lex_state = 91, .external_lex_state = 12},
  [5693] = {.lex_state = 91, .external_lex_state = 12},
  [5694] = {.lex_state = 91, .external_lex_state = 12},
  [5695] = {.lex_state = 91, .external_lex_state = 12},
  [5696] = {.lex_state = 91, .external_lex_state = 12},
  [5697] = {.lex_state = 91, .external_lex_state = 12},
  [5698] = {.lex_state = 91, .external_lex_state = 12},
  [5699] = {.lex_state = 91, .external_lex_state = 12},
  [5700] = {.lex_state = 91, .external_lex_state = 12},
  [5701] = {.lex_state = 91, .external_lex_state = 12},
  [5702] = {.lex_state = 91, .external_lex_state = 12},
  [5703] = {.lex_state = 91, .external_lex_state = 12},
  [5704] = {.lex_state = 91, .external_lex_state = 12},
  [5705] = {.lex_state = 91, .external_lex_state = 12},
  [5706] = {.lex_state = 91, .external_lex_state = 12},
  [5707] = {.lex_state = 91, .external_lex_state = 12},
  [5708] = {.lex_state = 91, .external_lex_state = 12},
  [5709] = {.lex_state = 91, .external_lex_state = 12},
  [5710] = {.lex_state = 91, .external_lex_state = 12},
  [5711] = {.lex_state = 91, .external_lex_state = 12},
  [5712] = {.lex_state = 91, .external_lex_state = 12},
  [5713] = {.lex_state = 91, .external_lex_state = 12},
  [5714] = {.lex_state = 91, .external_lex_state = 12},
  [5715] = {.lex_state = 91, .external_lex_state = 12},
  [5716] = {.lex_state = 91, .external_lex_state = 12},
  [5717] = {.lex_state = 91, .external_lex_state = 12},
  [5718] = {.lex_state = 91, .external_lex_state = 12},
  [5719] = {.lex_state = 91, .external_lex_state = 12},
  [5720] = {.lex_state = 91, .external_lex_state = 12},
  [5721] = {.lex_state = 91, .external_lex_state = 12},
  [5722] = {.lex_state = 91, .external_lex_state = 12},
  [5723] = {.lex_state = 91, .external_lex_state = 22},
  [5724] = {.lex_state = 91, .external_lex_state = 12},
  [5725] = {.lex_state = 91, .external_lex_state = 12},
  [5726] = {.lex_state = 91, .external_lex_state = 12},
  [5727] = {.lex_state = 91, .external_lex_state = 12},
  [5728] = {.lex_state = 91, .external_lex_state = 12},
  [5729] = {.lex_state = 91, .external_lex_state = 12},
  [5730] = {.lex_state = 91, .external_lex_state = 12},
  [5731] = {.lex_state = 91, .external_lex_state = 12},
  [5732] = {.lex_state = 91, .external_lex_state = 12},
  [5733] = {.lex_state = 91, .external_lex_state = 12},
  [5734] = {.lex_state = 91, .external_lex_state = 12},
  [5735] = {.lex_state = 91, .external_lex_state = 12},
  [5736] = {.lex_state = 91, .external_lex_state = 12},
  [5737] = {.lex_state = 91, .external_lex_state = 12},
  [5738] = {.lex_state = 91, .external_lex_state = 12},
  [5739] = {.lex_state = 91, .external_lex_state = 12},
  [5740] = {.lex_state = 91, .external_lex_state = 12},
  [5741] = {.lex_state = 91, .external_lex_state = 12},
  [5742] = {.lex_state = 91, .external_lex_state = 12},
  [5743] = {.lex_state = 91, .external_lex_state = 12},
  [5744] = {.lex_state = 91, .external_lex_state = 12},
  [5745] = {.lex_state = 91, .external_lex_state = 12},
  [5746] = {.lex_state = 91, .external_lex_state = 12},
  [5747] = {.lex_state = 91, .external_lex_state = 12},
  [5748] = {.lex_state = 91, .external_lex_state = 12},
  [5749] = {.lex_state = 91, .external_lex_state = 12},
  [5750] = {.lex_state = 91, .external_lex_state = 12},
  [5751] = {.lex_state = 2},
  [5752] = {.lex_state = 91, .external_lex_state = 12},
  [5753] = {.lex_state = 91, .external_lex_state = 12},
  [5754] = {.lex_state = 2},
  [5755] = {.lex_state = 91, .external_lex_state = 12},
  [5756] = {.lex_state = 91, .external_lex_state = 12},
  [5757] = {.lex_state = 91, .external_lex_state = 12},
  [5758] = {.lex_state = 91, .external_lex_state = 12},
  [5759] = {.lex_state = 91, .external_lex_state = 12},
  [5760] = {.lex_state = 91, .external_lex_state = 12},
  [5761] = {.lex_state = 91, .external_lex_state = 12},
  [5762] = {.lex_state = 91, .external_lex_state = 12},
  [5763] = {.lex_state = 91, .external_lex_state = 12},
  [5764] = {.lex_state = 91, .external_lex_state = 12},
  [5765] = {.lex_state = 91, .external_lex_state = 12},
  [5766] = {.lex_state = 91, .external_lex_state = 12},
  [5767] = {.lex_state = 91, .external_lex_state = 12},
  [5768] = {.lex_state = 91, .external_lex_state = 12},
  [5769] = {.lex_state = 91, .external_lex_state = 22},
  [5770] = {.lex_state = 91, .external_lex_state = 12},
  [5771] = {.lex_state = 91, .external_lex_state = 12},
  [5772] = {.lex_state = 91, .external_lex_state = 12},
  [5773] = {.lex_state = 91, .external_lex_state = 12},
  [5774] = {.lex_state = 91, .external_lex_state = 12},
  [5775] = {.lex_state = 91, .external_lex_state = 12},
  [5776] = {.lex_state = 91, .external_lex_state = 12},
  [5777] = {.lex_state = 91, .external_lex_state = 12},
  [5778] = {.lex_state = 2},
  [5779] = {.lex_state = 2},
  [5780] = {.lex_state = 91},
  [5781] = {.lex_state = 91, .external_lex_state = 12},
  [5782] = {.lex_state = 91, .external_lex_state = 12},
  [5783] = {.lex_state = 91, .external_lex_state = 12},
  [5784] = {.lex_state = 91, .external_lex_state = 12},
  [5785] = {.lex_state = 91, .external_lex_state = 12},
  [5786] = {.lex_state = 91, .external_lex_state = 12},
  [5787] = {.lex_state = 91, .external_lex_state = 12},
  [5788] = {.lex_state = 91, .external_lex_state = 12},
  [5789] = {.lex_state = 91, .external_lex_state = 12},
  [5790] = {.lex_state = 91, .external_lex_state = 12},
  [5791] = {.lex_state = 91, .external_lex_state = 12},
  [5792] = {.lex_state = 91, .external_lex_state = 12},
  [5793] = {.lex_state = 91, .external_lex_state = 12},
  [5794] = {.lex_state = 91, .external_lex_state = 12},
  [5795] = {.lex_state = 91, .external_lex_state = 12},
  [5796] = {.lex_state = 91, .external_lex_state = 12},
  [5797] = {.lex_state = 91, .external_lex_state = 12},
  [5798] = {.lex_state = 91, .external_lex_state = 12},
  [5799] = {.lex_state = 91, .external_lex_state = 12},
  [5800] = {.lex_state = 91, .external_lex_state = 22},
  [5801] = {.lex_state = 91, .external_lex_state = 22},
  [5802] = {.lex_state = 91, .external_lex_state = 22},
  [5803] = {.lex_state = 91, .external_lex_state = 22},
  [5804] = {.lex_state = 91, .external_lex_state = 12},
  [5805] = {.lex_state = 91, .external_lex_state = 22},
  [5806] = {.lex_state = 91, .external_lex_state = 22},
  [5807] = {.lex_state = 91, .external_lex_state = 22},
  [5808] = {.lex_state = 91, .external_lex_state = 22},
  [5809] = {.lex_state = 91, .external_lex_state = 22},
  [5810] = {.lex_state = 91, .external_lex_state = 22},
  [5811] = {.lex_state = 91, .external_lex_state = 12},
  [5812] = {.lex_state = 91, .external_lex_state = 22},
  [5813] = {.lex_state = 91, .external_lex_state = 22},
  [5814] = {.lex_state = 91, .external_lex_state = 22},
  [5815] = {.lex_state = 91, .external_lex_state = 12},
  [5816] = {.lex_state = 91, .external_lex_state = 22},
  [5817] = {.lex_state = 91, .external_lex_state = 22},
  [5818] = {.lex_state = 91, .external_lex_state = 22},
  [5819] = {.lex_state = 91, .external_lex_state = 12},
  [5820] = {.lex_state = 91, .external_lex_state = 22},
  [5821] = {.lex_state = 91, .external_lex_state = 22},
  [5822] = {.lex_state = 91, .external_lex_state = 12},
  [5823] = {.lex_state = 91, .external_lex_state = 12},
  [5824] = {.lex_state = 91, .external_lex_state = 12},
  [5825] = {.lex_state = 91, .external_lex_state = 22},
  [5826] = {.lex_state = 91, .external_lex_state = 22},
  [5827] = {.lex_state = 91, .external_lex_state = 22},
  [5828] = {.lex_state = 91, .external_lex_state = 22},
  [5829] = {.lex_state = 91, .external_lex_state = 22},
  [5830] = {.lex_state = 91, .external_lex_state = 12},
  [5831] = {.lex_state = 91, .external_lex_state = 22},
  [5832] = {.lex_state = 91, .external_lex_state = 22},
  [5833] = {.lex_state = 91, .external_lex_state = 22},
  [5834] = {.lex_state = 91, .external_lex_state = 22},
  [5835] = {.lex_state = 91, .external_lex_state = 22},
  [5836] = {.lex_state = 91, .external_lex_state = 22},
  [5837] = {.lex_state = 91, .external_lex_state = 22},
  [5838] = {.lex_state = 91, .external_lex_state = 22},
  [5839] = {.lex_state = 91, .external_lex_state = 12},
  [5840] = {.lex_state = 91, .external_lex_state = 16},
  [5841] = {.lex_state = 91, .external_lex_state = 12},
  [5842] = {.lex_state = 91, .external_lex_state = 12},
  [5843] = {.lex_state = 91, .external_lex_state = 12},
  [5844] = {.lex_state = 91, .external_lex_state = 12},
  [5845] = {.lex_state = 91, .external_lex_state = 12},
  [5846] = {.lex_state = 91, .external_lex_state = 22},
  [5847] = {.lex_state = 91, .external_lex_state = 12},
  [5848] = {.lex_state = 91, .external_lex_state = 22},
  [5849] = {.lex_state = 91, .external_lex_state = 12},
  [5850] = {.lex_state = 91, .external_lex_state = 12},
  [5851] = {.lex_state = 91, .external_lex_state = 12},
  [5852] = {.lex_state = 91, .external_lex_state = 12},
  [5853] = {.lex_state = 91, .external_lex_state = 22},
  [5854] = {.lex_state = 91, .external_lex_state = 22},
  [5855] = {.lex_state = 91, .external_lex_state = 22},
  [5856] = {.lex_state = 91, .external_lex_state = 22},
  [5857] = {.lex_state = 91, .external_lex_state = 22},
  [5858] = {.lex_state = 91, .external_lex_state = 12},
  [5859] = {.lex_state = 91, .external_lex_state = 12},
  [5860] = {.lex_state = 91, .external_lex_state = 12},
  [5861] = {.lex_state = 91, .external_lex_state = 22},
  [5862] = {.lex_state = 91, .external_lex_state = 12},
  [5863] = {.lex_state = 91, .external_lex_state = 22},
  [5864] = {.lex_state = 91, .external_lex_state = 22},
  [5865] = {.lex_state = 91, .external_lex_state = 22},
  [5866] = {.lex_state = 91, .external_lex_state = 22},
  [5867] = {.lex_state = 91, .external_lex_state = 22},
  [5868] = {.lex_state = 91, .external_lex_state = 22},
  [5869] = {.lex_state = 91, .external_lex_state = 22},
  [5870] = {.lex_state = 91, .external_lex_state = 12},
  [5871] = {.lex_state = 2},
  [5872] = {.lex_state = 91, .external_lex_state = 16},
  [5873] = {.lex_state = 2},
  [5874] = {.lex_state = 2},
  [5875] = {.lex_state = 91},
  [5876] = {.lex_state = 91, .external_lex_state = 16},
  [5877] = {.lex_state = 91, .external_lex_state = 16},
  [5878] = {.lex_state = 2},
  [5879] = {.lex_state = 2},
  [5880] = {.lex_state = 91, .external_lex_state = 16},
  [5881] = {.lex_state = 2},
  [5882] = {.lex_state = 2},
  [5883] = {.lex_state = 2},
  [5884] = {.lex_state = 2},
  [5885] = {.lex_state = 2},
  [5886] = {.lex_state = 2},
  [5887] = {.lex_state = 2},
  [5888] = {.lex_state = 2},
  [5889] = {.lex_state = 2},
  [5890] = {.lex_state = 2},
  [5891] = {.lex_state = 2},
  [5892] = {.lex_state = 2},
  [5893] = {.lex_state = 2},
  [5894] = {.lex_state = 2},
  [5895] = {.lex_state = 2},
  [5896] = {.lex_state = 2},
  [5897] = {.lex_state = 2},
  [5898] = {.lex_state = 2},
  [5899] = {.lex_state = 2},
  [5900] = {.lex_state = 2},
  [5901] = {.lex_state = 2},
  [5902] = {.lex_state = 2},
  [5903] = {.lex_state = 2},
  [5904] = {.lex_state = 2},
  [5905] = {.lex_state = 2},
  [5906] = {.lex_state = 91, .external_lex_state = 16},
  [5907] = {.lex_state = 91, .external_lex_state = 16},
  [5908] = {.lex_state = 11},
  [5909] = {.lex_state = 2},
  [5910] = {.lex_state = 2},
  [5911] = {.lex_state = 2},
  [5912] = {.lex_state = 91, .external_lex_state = 15},
  [5913] = {.lex_state = 91, .external_lex_state = 12},
  [5914] = {.lex_state = 91, .external_lex_state = 15},
  [5915] = {.lex_state = 91, .external_lex_state = 15},
  [5916] = {.lex_state = 91, .external_lex_state = 11},
  [5917] = {.lex_state = 2},
  [5918] = {.lex_state = 91, .external_lex_state = 12},
  [5919] = {.lex_state = 2},
  [5920] = {.lex_state = 2},
  [5921] = {.lex_state = 91, .external_lex_state = 15},
  [5922] = {.lex_state = 91, .external_lex_state = 12},
  [5923] = {.lex_state = 2},
  [5924] = {.lex_state = 91, .external_lex_state = 15},
  [5925] = {.lex_state = 91, .external_lex_state = 12},
  [5926] = {.lex_state = 2},
  [5927] = {.lex_state = 91, .external_lex_state = 15},
  [5928] = {.lex_state = 91, .external_lex_state = 15},
  [5929] = {.lex_state = 91, .external_lex_state = 16},
  [5930] = {.lex_state = 91, .external_lex_state = 16},
  [5931] = {.lex_state = 2},
  [5932] = {.lex_state = 2},
  [5933] = {.lex_state = 91, .external_lex_state = 15},
  [5934] = {.lex_state = 91, .external_lex_state = 15},
  [5935] = {.lex_state = 91, .external_lex_state = 15},
  [5936] = {.lex_state = 91, .external_lex_state = 15},
  [5937] = {.lex_state = 91, .external_lex_state = 12},
  [5938] = {.lex_state = 91, .external_lex_state = 15},
  [5939] = {.lex_state = 91, .external_lex_state = 15},
  [5940] = {.lex_state = 91, .external_lex_state = 15},
  [5941] = {.lex_state = 91, .external_lex_state = 15},
  [5942] = {.lex_state = 91, .external_lex_state = 15},
  [5943] = {.lex_state = 91, .external_lex_state = 15},
  [5944] = {.lex_state = 91, .external_lex_state = 15},
  [5945] = {.lex_state = 91, .external_lex_state = 15},
  [5946] = {.lex_state = 91, .external_lex_state = 15},
  [5947] = {.lex_state = 91, .external_lex_state = 15},
  [5948] = {.lex_state = 2},
  [5949] = {.lex_state = 2},
  [5950] = {.lex_state = 91, .external_lex_state = 12},
  [5951] = {.lex_state = 91, .external_lex_state = 12},
  [5952] = {.lex_state = 11},
  [5953] = {.lex_state = 91, .external_lex_state = 12},
  [5954] = {.lex_state = 91, .external_lex_state = 12},
  [5955] = {.lex_state = 91, .external_lex_state = 16},
  [5956] = {.lex_state = 91, .external_lex_state = 12},
  [5957] = {.lex_state = 91, .external_lex_state = 12},
  [5958] = {.lex_state = 91, .external_lex_state = 11},
  [5959] = {.lex_state = 91, .external_lex_state = 16},
  [5960] = {.lex_state = 91, .external_lex_state = 16},
  [5961] = {.lex_state = 91, .external_lex_state = 15},
  [5962] = {.lex_state = 91, .external_lex_state = 11},
  [5963] = {.lex_state = 91, .external_lex_state = 12},
  [5964] = {.lex_state = 91, .external_lex_state = 12},
  [5965] = {.lex_state = 2},
  [5966] = {.lex_state = 91, .external_lex_state = 15},
  [5967] = {.lex_state = 91, .external_lex_state = 16},
  [5968] = {.lex_state = 91, .external_lex_state = 17},
  [5969] = {.lex_state = 91, .external_lex_state = 16},
  [5970] = {.lex_state = 91, .external_lex_state = 16},
  [5971] = {.lex_state = 91, .external_lex_state = 12},
  [5972] = {.lex_state = 91, .external_lex_state = 16},
  [5973] = {.lex_state = 91, .external_lex_state = 16},
  [5974] = {.lex_state = 91, .external_lex_state = 11},
  [5975] = {.lex_state = 91, .external_lex_state = 15},
  [5976] = {.lex_state = 91, .external_lex_state = 15},
  [5977] = {.lex_state = 91, .external_lex_state = 15},
  [5978] = {.lex_state = 91, .external_lex_state = 15},
  [5979] = {.lex_state = 91, .external_lex_state = 15},
  [5980] = {.lex_state = 91, .external_lex_state = 15},
  [5981] = {.lex_state = 91, .external_lex_state = 15},
  [5982] = {.lex_state = 91, .external_lex_state = 15},
  [5983] = {.lex_state = 91, .external_lex_state = 15},
  [5984] = {.lex_state = 91, .external_lex_state = 15},
  [5985] = {.lex_state = 91, .external_lex_state = 15},
  [5986] = {.lex_state = 2},
  [5987] = {.lex_state = 91, .external_lex_state = 15},
  [5988] = {.lex_state = 2},
  [5989] = {.lex_state = 91, .external_lex_state = 12},
  [5990] = {.lex_state = 91, .external_lex_state = 15},
  [5991] = {.lex_state = 2},
  [5992] = {.lex_state = 91, .external_lex_state = 15},
  [5993] = {.lex_state = 2},
  [5994] = {.lex_state = 2},
  [5995] = {.lex_state = 2},
  [5996] = {.lex_state = 2},
  [5997] = {.lex_state = 2},
  [5998] = {.lex_state = 2},
  [5999] = {.lex_state = 91, .external_lex_state = 15},
  [6000] = {.lex_state = 2},
  [6001] = {.lex_state = 2},
  [6002] = {.lex_state = 91, .external_lex_state = 15},
  [6003] = {.lex_state = 2},
  [6004] = {.lex_state = 2},
  [6005] = {.lex_state = 2},
  [6006] = {.lex_state = 2},
  [6007] = {.lex_state = 2},
  [6008] = {.lex_state = 91, .external_lex_state = 12},
  [6009] = {.lex_state = 2},
  [6010] = {.lex_state = 2},
  [6011] = {.lex_state = 2},
  [6012] = {.lex_state = 2},
  [6013] = {.lex_state = 2},
  [6014] = {.lex_state = 2},
  [6015] = {.lex_state = 91, .external_lex_state = 12},
  [6016] = {.lex_state = 91, .external_lex_state = 12},
  [6017] = {.lex_state = 91, .external_lex_state = 12},
  [6018] = {.lex_state = 2},
  [6019] = {.lex_state = 2},
  [6020] = {.lex_state = 2},
  [6021] = {.lex_state = 2},
  [6022] = {.lex_state = 2},
  [6023] = {.lex_state = 2},
  [6024] = {.lex_state = 2},
  [6025] = {.lex_state = 2},
  [6026] = {.lex_state = 2},
  [6027] = {.lex_state = 2},
  [6028] = {.lex_state = 2},
  [6029] = {.lex_state = 2},
  [6030] = {.lex_state = 91, .external_lex_state = 16},
  [6031] = {.lex_state = 2},
  [6032] = {.lex_state = 2},
  [6033] = {.lex_state = 91, .external_lex_state = 16},
  [6034] = {.lex_state = 2},
  [6035] = {.lex_state = 2},
  [6036] = {.lex_state = 91, .external_lex_state = 16},
  [6037] = {.lex_state = 91, .external_lex_state = 16},
  [6038] = {.lex_state = 2},
  [6039] = {.lex_state = 91, .external_lex_state = 16},
  [6040] = {.lex_state = 91, .external_lex_state = 16},
  [6041] = {.lex_state = 91, .external_lex_state = 16},
  [6042] = {.lex_state = 91, .external_lex_state = 16},
  [6043] = {.lex_state = 91, .external_lex_state = 12},
  [6044] = {.lex_state = 2},
  [6045] = {.lex_state = 2},
  [6046] = {.lex_state = 2},
  [6047] = {.lex_state = 2},
  [6048] = {.lex_state = 2},
  [6049] = {.lex_state = 2},
  [6050] = {.lex_state = 2},
  [6051] = {.lex_state = 2},
  [6052] = {.lex_state = 2},
  [6053] = {.lex_state = 2},
  [6054] = {.lex_state = 91, .external_lex_state = 12},
  [6055] = {.lex_state = 2},
  [6056] = {.lex_state = 2},
  [6057] = {.lex_state = 2},
  [6058] = {.lex_state = 2},
  [6059] = {.lex_state = 91, .external_lex_state = 15},
  [6060] = {.lex_state = 2},
  [6061] = {.lex_state = 2},
  [6062] = {.lex_state = 2},
  [6063] = {.lex_state = 2},
  [6064] = {.lex_state = 2},
  [6065] = {.lex_state = 2},
  [6066] = {.lex_state = 2},
  [6067] = {.lex_state = 2},
  [6068] = {.lex_state = 2},
  [6069] = {.lex_state = 2},
  [6070] = {.lex_state = 2},
  [6071] = {.lex_state = 2},
  [6072] = {.lex_state = 2},
  [6073] = {.lex_state = 91, .external_lex_state = 15},
  [6074] = {.lex_state = 91, .external_lex_state = 15},
  [6075] = {.lex_state = 2},
  [6076] = {.lex_state = 91, .external_lex_state = 15},
  [6077] = {.lex_state = 91, .external_lex_state = 15},
  [6078] = {.lex_state = 91, .external_lex_state = 15},
  [6079] = {.lex_state = 91, .external_lex_state = 16},
  [6080] = {.lex_state = 91, .external_lex_state = 16},
  [6081] = {.lex_state = 2},
  [6082] = {.lex_state = 91, .external_lex_state = 16},
  [6083] = {.lex_state = 2},
  [6084] = {.lex_state = 91, .external_lex_state = 15},
  [6085] = {.lex_state = 2},
  [6086] = {.lex_state = 91, .external_lex_state = 16},
  [6087] = {.lex_state = 2},
  [6088] = {.lex_state = 91, .external_lex_state = 15},
  [6089] = {.lex_state = 2},
  [6090] = {.lex_state = 91, .external_lex_state = 12},
  [6091] = {.lex_state = 91, .external_lex_state = 12},
  [6092] = {.lex_state = 91, .external_lex_state = 16},
  [6093] = {.lex_state = 2},
  [6094] = {.lex_state = 2},
  [6095] = {.lex_state = 2},
  [6096] = {.lex_state = 2},
  [6097] = {.lex_state = 2},
  [6098] = {.lex_state = 91, .external_lex_state = 15},
  [6099] = {.lex_state = 2},
  [6100] = {.lex_state = 2},
  [6101] = {.lex_state = 2},
  [6102] = {.lex_state = 91, .external_lex_state = 15},
  [6103] = {.lex_state = 2},
  [6104] = {.lex_state = 2},
  [6105] = {.lex_state = 2},
  [6106] = {.lex_state = 2},
  [6107] = {.lex_state = 91, .external_lex_state = 15},
  [6108] = {.lex_state = 91, .external_lex_state = 15},
  [6109] = {.lex_state = 91, .external_lex_state = 15},
  [6110] = {.lex_state = 2},
  [6111] = {.lex_state = 91, .external_lex_state = 15},
  [6112] = {.lex_state = 91, .external_lex_state = 15},
  [6113] = {.lex_state = 91, .external_lex_state = 15},
  [6114] = {.lex_state = 2},
  [6115] = {.lex_state = 91, .external_lex_state = 15},
  [6116] = {.lex_state = 2},
  [6117] = {.lex_state = 91, .external_lex_state = 15},
  [6118] = {.lex_state = 2},
  [6119] = {.lex_state = 91, .external_lex_state = 12},
  [6120] = {.lex_state = 91, .external_lex_state = 15},
  [6121] = {.lex_state = 91, .external_lex_state = 12},
  [6122] = {.lex_state = 91, .external_lex_state = 15},
  [6123] = {.lex_state = 91, .external_lex_state = 15},
  [6124] = {.lex_state = 91, .external_lex_state = 15},
  [6125] = {.lex_state = 91, .external_lex_state = 15},
  [6126] = {.lex_state = 91, .external_lex_state = 15},
  [6127] = {.lex_state = 2},
  [6128] = {.lex_state = 91, .external_lex_state = 15},
  [6129] = {.lex_state = 91, .external_lex_state = 15},
  [6130] = {.lex_state = 91, .external_lex_state = 15},
  [6131] = {.lex_state = 91, .external_lex_state = 15},
  [6132] = {.lex_state = 2},
  [6133] = {.lex_state = 2},
  [6134] = {.lex_state = 91, .external_lex_state = 12},
  [6135] = {.lex_state = 2},
  [6136] = {.lex_state = 2},
  [6137] = {.lex_state = 2},
  [6138] = {.lex_state = 2},
  [6139] = {.lex_state = 91, .external_lex_state = 15},
  [6140] = {.lex_state = 91, .external_lex_state = 16},
  [6141] = {.lex_state = 2},
  [6142] = {.lex_state = 2},
  [6143] = {.lex_state = 2},
  [6144] = {.lex_state = 2},
  [6145] = {.lex_state = 2},
  [6146] = {.lex_state = 2},
  [6147] = {.lex_state = 2},
  [6148] = {.lex_state = 2},
  [6149] = {.lex_state = 2},
  [6150] = {.lex_state = 2},
  [6151] = {.lex_state = 2},
  [6152] = {.lex_state = 2},
  [6153] = {.lex_state = 91, .external_lex_state = 15},
  [6154] = {.lex_state = 2},
  [6155] = {.lex_state = 91, .external_lex_state = 15},
  [6156] = {.lex_state = 2},
  [6157] = {.lex_state = 2},
  [6158] = {.lex_state = 2},
  [6159] = {.lex_state = 2},
  [6160] = {.lex_state = 2},
  [6161] = {.lex_state = 2},
  [6162] = {.lex_state = 2},
  [6163] = {.lex_state = 2},
  [6164] = {.lex_state = 2},
  [6165] = {.lex_state = 2},
  [6166] = {.lex_state = 2},
  [6167] = {.lex_state = 2},
  [6168] = {.lex_state = 2},
  [6169] = {.lex_state = 2},
  [6170] = {.lex_state = 2},
  [6171] = {.lex_state = 2},
  [6172] = {.lex_state = 2},
  [6173] = {.lex_state = 2},
  [6174] = {.lex_state = 2},
  [6175] = {.lex_state = 2},
  [6176] = {.lex_state = 2},
  [6177] = {.lex_state = 2},
  [6178] = {.lex_state = 2},
  [6179] = {.lex_state = 91, .external_lex_state = 16},
  [6180] = {.lex_state = 91, .external_lex_state = 15},
  [6181] = {.lex_state = 2},
  [6182] = {.lex_state = 2},
  [6183] = {.lex_state = 91, .external_lex_state = 15},
  [6184] = {.lex_state = 2},
  [6185] = {.lex_state = 91, .external_lex_state = 16},
  [6186] = {.lex_state = 2},
  [6187] = {.lex_state = 91, .external_lex_state = 16},
  [6188] = {.lex_state = 2},
  [6189] = {.lex_state = 91, .external_lex_state = 15},
  [6190] = {.lex_state = 2},
  [6191] = {.lex_state = 2},
  [6192] = {.lex_state = 2},
  [6193] = {.lex_state = 91, .external_lex_state = 16},
  [6194] = {.lex_state = 91, .external_lex_state = 16},
  [6195] = {.lex_state = 2},
  [6196] = {.lex_state = 2},
  [6197] = {.lex_state = 91, .external_lex_state = 15},
  [6198] = {.lex_state = 11},
  [6199] = {.lex_state = 91, .external_lex_state = 15},
  [6200] = {.lex_state = 91, .external_lex_state = 15},
  [6201] = {.lex_state = 2},
  [6202] = {.lex_state = 2},
  [6203] = {.lex_state = 2},
  [6204] = {.lex_state = 91, .external_lex_state = 16},
  [6205] = {.lex_state = 2},
  [6206] = {.lex_state = 2},
  [6207] = {.lex_state = 2},
  [6208] = {.lex_state = 2},
  [6209] = {.lex_state = 2},
  [6210] = {.lex_state = 91, .external_lex_state = 21},
  [6211] = {.lex_state = 2},
  [6212] = {.lex_state = 2},
  [6213] = {.lex_state = 11},
  [6214] = {.lex_state = 2},
  [6215] = {.lex_state = 91, .external_lex_state = 21},
  [6216] = {.lex_state = 2},
  [6217] = {.lex_state = 2},
  [6218] = {.lex_state = 2},
  [6219] = {.lex_state = 2},
  [6220] = {.lex_state = 2},
  [6221] = {.lex_state = 2},
  [6222] = {.lex_state = 2},
  [6223] = {.lex_state = 2},
  [6224] = {.lex_state = 91, .external_lex_state = 21},
  [6225] = {.lex_state = 2},
  [6226] = {.lex_state = 2},
  [6227] = {.lex_state = 2},
  [6228] = {.lex_state = 2},
  [6229] = {.lex_state = 91, .external_lex_state = 21},
  [6230] = {.lex_state = 91, .external_lex_state = 21},
  [6231] = {.lex_state = 91, .external_lex_state = 21},
  [6232] = {.lex_state = 91, .external_lex_state = 21},
  [6233] = {.lex_state = 91, .external_lex_state = 21},
  [6234] = {.lex_state = 2},
  [6235] = {.lex_state = 2},
  [6236] = {.lex_state = 2},
  [6237] = {.lex_state = 2},
  [6238] = {.lex_state = 91, .external_lex_state = 21},
  [6239] = {.lex_state = 91, .external_lex_state = 21},
  [6240] = {.lex_state = 91, .external_lex_state = 21},
  [6241] = {.lex_state = 2},
  [6242] = {.lex_state = 2},
  [6243] = {.lex_state = 91, .external_lex_state = 21},
  [6244] = {.lex_state = 2},
  [6245] = {.lex_state = 2},
  [6246] = {.lex_state = 2},
  [6247] = {.lex_state = 9},
  [6248] = {.lex_state = 91, .external_lex_state = 12},
  [6249] = {.lex_state = 2},
  [6250] = {.lex_state = 91, .external_lex_state = 12},
  [6251] = {.lex_state = 91, .external_lex_state = 12},
  [6252] = {.lex_state = 2},
  [6253] = {.lex_state = 9},
  [6254] = {.lex_state = 2},
  [6255] = {.lex_state = 9},
  [6256] = {.lex_state = 91, .external_lex_state = 12},
  [6257] = {.lex_state = 91, .external_lex_state = 12},
  [6258] = {.lex_state = 9},
  [6259] = {.lex_state = 2},
  [6260] = {.lex_state = 9},
  [6261] = {.lex_state = 9},
  [6262] = {.lex_state = 2},
  [6263] = {.lex_state = 91, .external_lex_state = 12},
  [6264] = {.lex_state = 91, .external_lex_state = 12},
  [6265] = {.lex_state = 2},
  [6266] = {.lex_state = 91, .external_lex_state = 12},
  [6267] = {.lex_state = 2},
  [6268] = {.lex_state = 91, .external_lex_state = 12},
  [6269] = {.lex_state = 91, .external_lex_state = 12},
  [6270] = {.lex_state = 2},
  [6271] = {.lex_state = 91, .external_lex_state = 11},
  [6272] = {.lex_state = 2},
  [6273] = {.lex_state = 91, .external_lex_state = 12},
  [6274] = {.lex_state = 2},
  [6275] = {.lex_state = 2},
  [6276] = {.lex_state = 2},
  [6277] = {.lex_state = 2},
  [6278] = {.lex_state = 2},
  [6279] = {.lex_state = 2},
  [6280] = {.lex_state = 2},
  [6281] = {.lex_state = 91, .external_lex_state = 11},
  [6282] = {.lex_state = 2},
  [6283] = {.lex_state = 2},
  [6284] = {.lex_state = 2},
  [6285] = {.lex_state = 2},
  [6286] = {.lex_state = 2},
  [6287] = {.lex_state = 2},
  [6288] = {.lex_state = 2},
  [6289] = {.lex_state = 2},
  [6290] = {.lex_state = 2},
  [6291] = {.lex_state = 2},
  [6292] = {.lex_state = 2},
  [6293] = {.lex_state = 2},
  [6294] = {.lex_state = 2},
  [6295] = {.lex_state = 2},
  [6296] = {.lex_state = 2},
  [6297] = {.lex_state = 2},
  [6298] = {.lex_state = 2},
  [6299] = {.lex_state = 2},
  [6300] = {.lex_state = 2},
  [6301] = {.lex_state = 2},
  [6302] = {.lex_state = 91, .external_lex_state = 11},
  [6303] = {.lex_state = 2},
  [6304] = {.lex_state = 2},
  [6305] = {.lex_state = 2},
  [6306] = {.lex_state = 2},
  [6307] = {.lex_state = 2},
  [6308] = {.lex_state = 2},
  [6309] = {.lex_state = 2},
  [6310] = {.lex_state = 2},
  [6311] = {.lex_state = 2},
  [6312] = {.lex_state = 2},
  [6313] = {.lex_state = 2},
  [6314] = {.lex_state = 2},
  [6315] = {.lex_state = 2},
  [6316] = {.lex_state = 2},
  [6317] = {.lex_state = 2},
  [6318] = {.lex_state = 2},
  [6319] = {.lex_state = 2},
  [6320] = {.lex_state = 2},
  [6321] = {.lex_state = 2},
  [6322] = {.lex_state = 11},
  [6323] = {.lex_state = 2},
  [6324] = {.lex_state = 2},
  [6325] = {.lex_state = 2},
  [6326] = {.lex_state = 2},
  [6327] = {.lex_state = 2},
  [6328] = {.lex_state = 2},
  [6329] = {.lex_state = 9},
  [6330] = {.lex_state = 9},
  [6331] = {.lex_state = 2},
  [6332] = {.lex_state = 91, .external_lex_state = 19},
  [6333] = {.lex_state = 91, .external_lex_state = 19},
  [6334] = {.lex_state = 91, .external_lex_state = 19},
  [6335] = {.lex_state = 91, .external_lex_state = 19},
  [6336] = {.lex_state = 91, .external_lex_state = 19},
  [6337] = {.lex_state = 2},
  [6338] = {.lex_state = 2},
  [6339] = {.lex_state = 2},
  [6340] = {.lex_state = 9},
  [6341] = {.lex_state = 91, .external_lex_state = 19},
  [6342] = {.lex_state = 91, .external_lex_state = 19},
  [6343] = {.lex_state = 91, .external_lex_state = 19},
  [6344] = {.lex_state = 2},
  [6345] = {.lex_state = 2},
  [6346] = {.lex_state = 2},
  [6347] = {.lex_state = 2},
  [6348] = {.lex_state = 2},
  [6349] = {.lex_state = 2},
  [6350] = {.lex_state = 91, .external_lex_state = 19},
  [6351] = {.lex_state = 91, .external_lex_state = 19},
  [6352] = {.lex_state = 2},
  [6353] = {.lex_state = 2},
  [6354] = {.lex_state = 2},
  [6355] = {.lex_state = 2},
  [6356] = {.lex_state = 2},
  [6357] = {.lex_state = 2},
  [6358] = {.lex_state = 2},
  [6359] = {.lex_state = 9},
  [6360] = {.lex_state = 9},
  [6361] = {.lex_state = 9},
  [6362] = {.lex_state = 9},
  [6363] = {.lex_state = 9},
  [6364] = {.lex_state = 2},
  [6365] = {.lex_state = 91, .external_lex_state = 11},
  [6366] = {.lex_state = 91, .external_lex_state = 11},
  [6367] = {.lex_state = 2},
  [6368] = {.lex_state = 91, .external_lex_state = 11},
  [6369] = {.lex_state = 91, .external_lex_state = 11},
  [6370] = {.lex_state = 91, .external_lex_state = 11},
  [6371] = {.lex_state = 2},
  [6372] = {.lex_state = 2},
  [6373] = {.lex_state = 91, .external_lex_state = 11},
  [6374] = {.lex_state = 2},
  [6375] = {.lex_state = 2},
  [6376] = {.lex_state = 2},
  [6377] = {.lex_state = 2},
  [6378] = {.lex_state = 2},
  [6379] = {.lex_state = 2},
  [6380] = {.lex_state = 2},
  [6381] = {.lex_state = 91, .external_lex_state = 15},
  [6382] = {.lex_state = 91, .external_lex_state = 11},
  [6383] = {.lex_state = 91, .external_lex_state = 15},
  [6384] = {.lex_state = 91, .external_lex_state = 15},
  [6385] = {.lex_state = 91, .external_lex_state = 15},
  [6386] = {.lex_state = 91, .external_lex_state = 15},
  [6387] = {.lex_state = 91, .external_lex_state = 15},
  [6388] = {.lex_state = 91, .external_lex_state = 15},
  [6389] = {.lex_state = 91, .external_lex_state = 15},
  [6390] = {.lex_state = 91, .external_lex_state = 15},
  [6391] = {.lex_state = 91, .external_lex_state = 15},
  [6392] = {.lex_state = 91, .external_lex_state = 15},
  [6393] = {.lex_state = 91, .external_lex_state = 15},
  [6394] = {.lex_state = 91, .external_lex_state = 15},
  [6395] = {.lex_state = 91, .external_lex_state = 15},
  [6396] = {.lex_state = 91, .external_lex_state = 19},
  [6397] = {.lex_state = 91, .external_lex_state = 11},
  [6398] = {.lex_state = 91, .external_lex_state = 15},
  [6399] = {.lex_state = 91, .external_lex_state = 15},
  [6400] = {.lex_state = 91, .external_lex_state = 15},
  [6401] = {.lex_state = 91, .external_lex_state = 15},
  [6402] = {.lex_state = 91, .external_lex_state = 15},
  [6403] = {.lex_state = 91, .external_lex_state = 15},
  [6404] = {.lex_state = 91, .external_lex_state = 15},
  [6405] = {.lex_state = 91, .external_lex_state = 15},
  [6406] = {.lex_state = 91, .external_lex_state = 15},
  [6407] = {.lex_state = 91, .external_lex_state = 15},
  [6408] = {.lex_state = 91, .external_lex_state = 15},
  [6409] = {.lex_state = 91, .external_lex_state = 11},
  [6410] = {.lex_state = 91, .external_lex_state = 11},
  [6411] = {.lex_state = 91, .external_lex_state = 15},
  [6412] = {.lex_state = 91, .external_lex_state = 15},
  [6413] = {.lex_state = 91, .external_lex_state = 15},
  [6414] = {.lex_state = 91, .external_lex_state = 15},
  [6415] = {.lex_state = 91, .external_lex_state = 15},
  [6416] = {.lex_state = 91, .external_lex_state = 15},
  [6417] = {.lex_state = 91, .external_lex_state = 11},
  [6418] = {.lex_state = 91, .external_lex_state = 11},
  [6419] = {.lex_state = 91, .external_lex_state = 15},
  [6420] = {.lex_state = 91, .external_lex_state = 11},
  [6421] = {.lex_state = 91, .external_lex_state = 15},
  [6422] = {.lex_state = 91, .external_lex_state = 15},
  [6423] = {.lex_state = 91, .external_lex_state = 15},
  [6424] = {.lex_state = 91, .external_lex_state = 15},
  [6425] = {.lex_state = 91, .external_lex_state = 15},
  [6426] = {.lex_state = 91, .external_lex_state = 15},
  [6427] = {.lex_state = 91, .external_lex_state = 15},
  [6428] = {.lex_state = 91, .external_lex_state = 11},
  [6429] = {.lex_state = 91, .external_lex_state = 11},
  [6430] = {.lex_state = 91, .external_lex_state = 15},
  [6431] = {.lex_state = 91, .external_lex_state = 15},
  [6432] = {.lex_state = 91, .external_lex_state = 15},
  [6433] = {.lex_state = 91, .external_lex_state = 15},
  [6434] = {.lex_state = 91, .external_lex_state = 15},
  [6435] = {.lex_state = 91, .external_lex_state = 19},
  [6436] = {.lex_state = 91, .external_lex_state = 15},
  [6437] = {.lex_state = 91, .external_lex_state = 15},
  [6438] = {.lex_state = 91, .external_lex_state = 15},
  [6439] = {.lex_state = 91, .external_lex_state = 15},
  [6440] = {.lex_state = 91, .external_lex_state = 15},
  [6441] = {.lex_state = 91, .external_lex_state = 15},
  [6442] = {.lex_state = 91, .external_lex_state = 15},
  [6443] = {.lex_state = 91, .external_lex_state = 15},
  [6444] = {.lex_state = 91, .external_lex_state = 15},
  [6445] = {.lex_state = 91, .external_lex_state = 15},
  [6446] = {.lex_state = 91, .external_lex_state = 15},
  [6447] = {.lex_state = 91, .external_lex_state = 15},
  [6448] = {.lex_state = 91, .external_lex_state = 15},
  [6449] = {.lex_state = 91, .external_lex_state = 15},
  [6450] = {.lex_state = 91, .external_lex_state = 15},
  [6451] = {.lex_state = 91, .external_lex_state = 15},
  [6452] = {.lex_state = 91, .external_lex_state = 15},
  [6453] = {.lex_state = 91, .external_lex_state = 15},
  [6454] = {.lex_state = 91, .external_lex_state = 11},
  [6455] = {.lex_state = 91, .external_lex_state = 15},
  [6456] = {.lex_state = 91, .external_lex_state = 15},
  [6457] = {.lex_state = 91, .external_lex_state = 15},
  [6458] = {.lex_state = 91, .external_lex_state = 15},
  [6459] = {.lex_state = 91, .external_lex_state = 15},
  [6460] = {.lex_state = 91, .external_lex_state = 15},
  [6461] = {.lex_state = 91, .external_lex_state = 15},
  [6462] = {.lex_state = 91, .external_lex_state = 15},
  [6463] = {.lex_state = 91, .external_lex_state = 15},
  [6464] = {.lex_state = 91, .external_lex_state = 15},
  [6465] = {.lex_state = 91, .external_lex_state = 15},
  [6466] = {.lex_state = 91, .external_lex_state = 15},
  [6467] = {.lex_state = 91, .external_lex_state = 15},
  [6468] = {.lex_state = 91, .external_lex_state = 15},
  [6469] = {.lex_state = 91, .external_lex_state = 15},
  [6470] = {.lex_state = 91, .external_lex_state = 15},
  [6471] = {.lex_state = 91, .external_lex_state = 15},
  [6472] = {.lex_state = 91, .external_lex_state = 15},
  [6473] = {.lex_state = 91, .external_lex_state = 15},
  [6474] = {.lex_state = 91, .external_lex_state = 15},
  [6475] = {.lex_state = 91, .external_lex_state = 15},
  [6476] = {.lex_state = 91, .external_lex_state = 15},
  [6477] = {.lex_state = 91, .external_lex_state = 15},
  [6478] = {.lex_state = 91, .external_lex_state = 15},
  [6479] = {.lex_state = 91, .external_lex_state = 15},
  [6480] = {.lex_state = 91, .external_lex_state = 15},
  [6481] = {.lex_state = 91, .external_lex_state = 15},
  [6482] = {.lex_state = 91, .external_lex_state = 11},
  [6483] = {.lex_state = 91, .external_lex_state = 15},
  [6484] = {.lex_state = 91, .external_lex_state = 15},
  [6485] = {.lex_state = 91, .external_lex_state = 15},
  [6486] = {.lex_state = 91, .external_lex_state = 15},
  [6487] = {.lex_state = 91, .external_lex_state = 15},
  [6488] = {.lex_state = 91, .external_lex_state = 15},
  [6489] = {.lex_state = 91, .external_lex_state = 11},
  [6490] = {.lex_state = 91, .external_lex_state = 15},
  [6491] = {.lex_state = 91, .external_lex_state = 15},
  [6492] = {.lex_state = 91, .external_lex_state = 15},
  [6493] = {.lex_state = 91, .external_lex_state = 11},
  [6494] = {.lex_state = 91, .external_lex_state = 11},
  [6495] = {.lex_state = 91, .external_lex_state = 15},
  [6496] = {.lex_state = 91, .external_lex_state = 15},
  [6497] = {.lex_state = 91, .external_lex_state = 15},
  [6498] = {.lex_state = 91, .external_lex_state = 15},
  [6499] = {.lex_state = 91, .external_lex_state = 15},
  [6500] = {.lex_state = 91, .external_lex_state = 15},
  [6501] = {.lex_state = 91, .external_lex_state = 15},
  [6502] = {.lex_state = 91, .external_lex_state = 15},
  [6503] = {.lex_state = 91, .external_lex_state = 15},
  [6504] = {.lex_state = 91, .external_lex_state = 15},
  [6505] = {.lex_state = 91, .external_lex_state = 15},
  [6506] = {.lex_state = 91, .external_lex_state = 15},
  [6507] = {.lex_state = 91, .external_lex_state = 15},
  [6508] = {.lex_state = 91, .external_lex_state = 15},
  [6509] = {.lex_state = 91, .external_lex_state = 15},
  [6510] = {.lex_state = 91, .external_lex_state = 15},
  [6511] = {.lex_state = 91, .external_lex_state = 15},
  [6512] = {.lex_state = 91, .external_lex_state = 15},
  [6513] = {.lex_state = 91, .external_lex_state = 15},
  [6514] = {.lex_state = 91, .external_lex_state = 15},
  [6515] = {.lex_state = 91, .external_lex_state = 15},
  [6516] = {.lex_state = 91, .external_lex_state = 15},
  [6517] = {.lex_state = 91, .external_lex_state = 15},
  [6518] = {.lex_state = 91, .external_lex_state = 15},
  [6519] = {.lex_state = 91, .external_lex_state = 15},
  [6520] = {.lex_state = 91, .external_lex_state = 15},
  [6521] = {.lex_state = 91, .external_lex_state = 15},
  [6522] = {.lex_state = 91, .external_lex_state = 15},
  [6523] = {.lex_state = 91, .external_lex_state = 15},
  [6524] = {.lex_state = 91, .external_lex_state = 15},
  [6525] = {.lex_state = 91, .external_lex_state = 15},
  [6526] = {.lex_state = 91, .external_lex_state = 15},
  [6527] = {.lex_state = 91, .external_lex_state = 15},
  [6528] = {.lex_state = 91, .external_lex_state = 15},
  [6529] = {.lex_state = 91, .external_lex_state = 15},
  [6530] = {.lex_state = 91, .external_lex_state = 15},
  [6531] = {.lex_state = 91, .external_lex_state = 15},
  [6532] = {.lex_state = 91, .external_lex_state = 15},
  [6533] = {.lex_state = 91, .external_lex_state = 15},
  [6534] = {.lex_state = 91, .external_lex_state = 15},
  [6535] = {.lex_state = 91, .external_lex_state = 15},
  [6536] = {.lex_state = 91, .external_lex_state = 11},
  [6537] = {.lex_state = 91, .external_lex_state = 15},
  [6538] = {.lex_state = 91, .external_lex_state = 15},
  [6539] = {.lex_state = 91, .external_lex_state = 15},
  [6540] = {.lex_state = 91, .external_lex_state = 15},
  [6541] = {.lex_state = 91, .external_lex_state = 15},
  [6542] = {.lex_state = 91, .external_lex_state = 15},
  [6543] = {.lex_state = 91, .external_lex_state = 15},
  [6544] = {.lex_state = 91, .external_lex_state = 11},
  [6545] = {.lex_state = 91, .external_lex_state = 15},
  [6546] = {.lex_state = 91, .external_lex_state = 15},
  [6547] = {.lex_state = 91, .external_lex_state = 15},
  [6548] = {.lex_state = 91, .external_lex_state = 15},
  [6549] = {.lex_state = 91, .external_lex_state = 15},
  [6550] = {.lex_state = 91, .external_lex_state = 15},
  [6551] = {.lex_state = 91, .external_lex_state = 15},
  [6552] = {.lex_state = 91, .external_lex_state = 15},
  [6553] = {.lex_state = 91, .external_lex_state = 11},
  [6554] = {.lex_state = 91, .external_lex_state = 11},
  [6555] = {.lex_state = 91, .external_lex_state = 11},
  [6556] = {.lex_state = 91, .external_lex_state = 11},
  [6557] = {.lex_state = 91, .external_lex_state = 15},
  [6558] = {.lex_state = 91, .external_lex_state = 15},
  [6559] = {.lex_state = 91, .external_lex_state = 15},
  [6560] = {.lex_state = 91, .external_lex_state = 15},
  [6561] = {.lex_state = 91, .external_lex_state = 11},
  [6562] = {.lex_state = 91, .external_lex_state = 15},
  [6563] = {.lex_state = 91, .external_lex_state = 15},
  [6564] = {.lex_state = 91, .external_lex_state = 15},
  [6565] = {.lex_state = 91, .external_lex_state = 15},
  [6566] = {.lex_state = 91, .external_lex_state = 15},
  [6567] = {.lex_state = 91, .external_lex_state = 11},
  [6568] = {.lex_state = 91, .external_lex_state = 15},
  [6569] = {.lex_state = 91, .external_lex_state = 15},
  [6570] = {.lex_state = 91, .external_lex_state = 11},
  [6571] = {.lex_state = 91, .external_lex_state = 11},
  [6572] = {.lex_state = 91, .external_lex_state = 11},
  [6573] = {.lex_state = 91, .external_lex_state = 11},
  [6574] = {.lex_state = 91, .external_lex_state = 11},
  [6575] = {.lex_state = 91, .external_lex_state = 11},
  [6576] = {.lex_state = 91, .external_lex_state = 15},
  [6577] = {.lex_state = 91, .external_lex_state = 15},
  [6578] = {.lex_state = 91, .external_lex_state = 11},
  [6579] = {.lex_state = 91, .external_lex_state = 11},
  [6580] = {.lex_state = 91, .external_lex_state = 11},
  [6581] = {.lex_state = 91, .external_lex_state = 11},
  [6582] = {.lex_state = 91, .external_lex_state = 11},
  [6583] = {.lex_state = 91, .external_lex_state = 11},
  [6584] = {.lex_state = 91, .external_lex_state = 11},
  [6585] = {.lex_state = 91, .external_lex_state = 11},
  [6586] = {.lex_state = 91, .external_lex_state = 11},
  [6587] = {.lex_state = 91, .external_lex_state = 11},
  [6588] = {.lex_state = 91, .external_lex_state = 11},
  [6589] = {.lex_state = 91, .external_lex_state = 15},
  [6590] = {.lex_state = 91, .external_lex_state = 15},
  [6591] = {.lex_state = 91, .external_lex_state = 15},
  [6592] = {.lex_state = 91, .external_lex_state = 15},
  [6593] = {.lex_state = 91, .external_lex_state = 15},
  [6594] = {.lex_state = 91, .external_lex_state = 15},
  [6595] = {.lex_state = 91, .external_lex_state = 11},
  [6596] = {.lex_state = 91, .external_lex_state = 15},
  [6597] = {.lex_state = 91, .external_lex_state = 11},
  [6598] = {.lex_state = 91, .external_lex_state = 11},
  [6599] = {.lex_state = 91, .external_lex_state = 15},
  [6600] = {.lex_state = 91, .external_lex_state = 15},
  [6601] = {.lex_state = 91, .external_lex_state = 15},
  [6602] = {.lex_state = 91, .external_lex_state = 15},
  [6603] = {.lex_state = 91, .external_lex_state = 15},
  [6604] = {.lex_state = 91, .external_lex_state = 15},
  [6605] = {.lex_state = 91, .external_lex_state = 15},
  [6606] = {.lex_state = 91, .external_lex_state = 15},
  [6607] = {.lex_state = 91, .external_lex_state = 15},
  [6608] = {.lex_state = 91, .external_lex_state = 15},
  [6609] = {.lex_state = 91, .external_lex_state = 15},
  [6610] = {.lex_state = 91, .external_lex_state = 11},
  [6611] = {.lex_state = 91, .external_lex_state = 15},
  [6612] = {.lex_state = 91, .external_lex_state = 15},
  [6613] = {.lex_state = 91, .external_lex_state = 15},
  [6614] = {.lex_state = 91, .external_lex_state = 15},
  [6615] = {.lex_state = 91, .external_lex_state = 15},
  [6616] = {.lex_state = 91, .external_lex_state = 15},
  [6617] = {.lex_state = 91, .external_lex_state = 15},
  [6618] = {.lex_state = 91, .external_lex_state = 15},
  [6619] = {.lex_state = 91, .external_lex_state = 15},
  [6620] = {.lex_state = 91, .external_lex_state = 15},
  [6621] = {.lex_state = 91, .external_lex_state = 15},
  [6622] = {.lex_state = 91, .external_lex_state = 15},
  [6623] = {.lex_state = 91, .external_lex_state = 15},
  [6624] = {.lex_state = 91, .external_lex_state = 15},
  [6625] = {.lex_state = 91, .external_lex_state = 15},
  [6626] = {.lex_state = 91, .external_lex_state = 15},
  [6627] = {.lex_state = 91, .external_lex_state = 15},
  [6628] = {.lex_state = 91, .external_lex_state = 15},
  [6629] = {.lex_state = 91, .external_lex_state = 15},
  [6630] = {.lex_state = 91, .external_lex_state = 15},
  [6631] = {.lex_state = 91, .external_lex_state = 15},
  [6632] = {.lex_state = 91, .external_lex_state = 15},
  [6633] = {.lex_state = 91, .external_lex_state = 15},
  [6634] = {.lex_state = 91, .external_lex_state = 15},
  [6635] = {.lex_state = 91, .external_lex_state = 15},
  [6636] = {.lex_state = 91, .external_lex_state = 15},
  [6637] = {.lex_state = 91, .external_lex_state = 15},
  [6638] = {.lex_state = 91, .external_lex_state = 15},
  [6639] = {.lex_state = 91, .external_lex_state = 15},
  [6640] = {.lex_state = 91, .external_lex_state = 15},
  [6641] = {.lex_state = 91, .external_lex_state = 15},
  [6642] = {.lex_state = 91, .external_lex_state = 15},
  [6643] = {.lex_state = 91, .external_lex_state = 15},
  [6644] = {.lex_state = 91, .external_lex_state = 15},
  [6645] = {.lex_state = 91, .external_lex_state = 15},
  [6646] = {.lex_state = 91, .external_lex_state = 15},
  [6647] = {.lex_state = 91, .external_lex_state = 15},
  [6648] = {.lex_state = 91, .external_lex_state = 15},
  [6649] = {.lex_state = 91, .external_lex_state = 15},
  [6650] = {.lex_state = 91, .external_lex_state = 15},
  [6651] = {.lex_state = 91, .external_lex_state = 15},
  [6652] = {.lex_state = 91, .external_lex_state = 15},
  [6653] = {.lex_state = 91, .external_lex_state = 15},
  [6654] = {.lex_state = 91, .external_lex_state = 15},
  [6655] = {.lex_state = 91, .external_lex_state = 15},
  [6656] = {.lex_state = 91, .external_lex_state = 15},
  [6657] = {.lex_state = 91, .external_lex_state = 15},
  [6658] = {.lex_state = 91, .external_lex_state = 15},
  [6659] = {.lex_state = 91, .external_lex_state = 15},
  [6660] = {.lex_state = 91, .external_lex_state = 15},
  [6661] = {.lex_state = 91, .external_lex_state = 15},
  [6662] = {.lex_state = 91, .external_lex_state = 15},
  [6663] = {.lex_state = 91, .external_lex_state = 15},
  [6664] = {.lex_state = 91, .external_lex_state = 15},
  [6665] = {.lex_state = 91, .external_lex_state = 15},
  [6666] = {.lex_state = 91, .external_lex_state = 15},
  [6667] = {.lex_state = 91, .external_lex_state = 15},
  [6668] = {.lex_state = 91, .external_lex_state = 15},
  [6669] = {.lex_state = 91, .external_lex_state = 15},
  [6670] = {.lex_state = 91, .external_lex_state = 15},
  [6671] = {.lex_state = 91, .external_lex_state = 19},
  [6672] = {.lex_state = 91, .external_lex_state = 11},
  [6673] = {.lex_state = 91, .external_lex_state = 15},
  [6674] = {.lex_state = 91, .external_lex_state = 15},
  [6675] = {.lex_state = 91, .external_lex_state = 15},
  [6676] = {.lex_state = 91, .external_lex_state = 15},
  [6677] = {.lex_state = 91, .external_lex_state = 11},
  [6678] = {.lex_state = 91, .external_lex_state = 15},
  [6679] = {.lex_state = 91, .external_lex_state = 15},
  [6680] = {.lex_state = 91, .external_lex_state = 15},
  [6681] = {.lex_state = 91, .external_lex_state = 15},
  [6682] = {.lex_state = 91, .external_lex_state = 15},
  [6683] = {.lex_state = 91, .external_lex_state = 15},
  [6684] = {.lex_state = 91, .external_lex_state = 15},
  [6685] = {.lex_state = 91, .external_lex_state = 15},
  [6686] = {.lex_state = 91, .external_lex_state = 15},
  [6687] = {.lex_state = 91, .external_lex_state = 15},
  [6688] = {.lex_state = 91, .external_lex_state = 15},
  [6689] = {.lex_state = 91, .external_lex_state = 15},
  [6690] = {.lex_state = 91, .external_lex_state = 19},
  [6691] = {.lex_state = 91, .external_lex_state = 15},
  [6692] = {.lex_state = 91, .external_lex_state = 15},
  [6693] = {.lex_state = 91, .external_lex_state = 11},
  [6694] = {.lex_state = 91, .external_lex_state = 11},
  [6695] = {.lex_state = 91, .external_lex_state = 11},
  [6696] = {.lex_state = 91, .external_lex_state = 11},
  [6697] = {.lex_state = 91, .external_lex_state = 11},
  [6698] = {.lex_state = 91, .external_lex_state = 15},
  [6699] = {.lex_state = 91, .external_lex_state = 15},
  [6700] = {.lex_state = 91, .external_lex_state = 15},
  [6701] = {.lex_state = 91, .external_lex_state = 15},
  [6702] = {.lex_state = 91, .external_lex_state = 15},
  [6703] = {.lex_state = 91, .external_lex_state = 15},
  [6704] = {.lex_state = 91, .external_lex_state = 15},
  [6705] = {.lex_state = 91, .external_lex_state = 15},
  [6706] = {.lex_state = 91, .external_lex_state = 15},
  [6707] = {.lex_state = 91, .external_lex_state = 15},
  [6708] = {.lex_state = 91, .external_lex_state = 15},
  [6709] = {.lex_state = 91, .external_lex_state = 15},
  [6710] = {.lex_state = 91, .external_lex_state = 15},
  [6711] = {.lex_state = 91, .external_lex_state = 15},
  [6712] = {.lex_state = 91, .external_lex_state = 15},
  [6713] = {.lex_state = 91, .external_lex_state = 15},
  [6714] = {.lex_state = 91, .external_lex_state = 15},
  [6715] = {.lex_state = 91, .external_lex_state = 15},
  [6716] = {.lex_state = 91, .external_lex_state = 15},
  [6717] = {.lex_state = 91, .external_lex_state = 11},
  [6718] = {.lex_state = 91, .external_lex_state = 15},
  [6719] = {.lex_state = 91, .external_lex_state = 15},
  [6720] = {.lex_state = 91, .external_lex_state = 11},
  [6721] = {.lex_state = 91, .external_lex_state = 11},
  [6722] = {.lex_state = 91, .external_lex_state = 15},
  [6723] = {.lex_state = 91, .external_lex_state = 15},
  [6724] = {.lex_state = 91, .external_lex_state = 15},
  [6725] = {.lex_state = 91, .external_lex_state = 15},
  [6726] = {.lex_state = 91, .external_lex_state = 15},
  [6727] = {.lex_state = 91, .external_lex_state = 15},
  [6728] = {.lex_state = 91, .external_lex_state = 15},
  [6729] = {.lex_state = 91, .external_lex_state = 15},
  [6730] = {.lex_state = 91, .external_lex_state = 15},
  [6731] = {.lex_state = 91, .external_lex_state = 15},
  [6732] = {.lex_state = 91, .external_lex_state = 15},
  [6733] = {.lex_state = 91, .external_lex_state = 15},
  [6734] = {.lex_state = 91, .external_lex_state = 15},
  [6735] = {.lex_state = 91, .external_lex_state = 15},
  [6736] = {.lex_state = 91, .external_lex_state = 15},
  [6737] = {.lex_state = 91, .external_lex_state = 15},
  [6738] = {.lex_state = 91, .external_lex_state = 15},
  [6739] = {.lex_state = 91, .external_lex_state = 15},
  [6740] = {.lex_state = 91, .external_lex_state = 15},
  [6741] = {.lex_state = 91, .external_lex_state = 15},
  [6742] = {.lex_state = 91, .external_lex_state = 15},
  [6743] = {.lex_state = 91, .external_lex_state = 15},
  [6744] = {.lex_state = 91, .external_lex_state = 15},
  [6745] = {.lex_state = 91, .external_lex_state = 15},
  [6746] = {.lex_state = 91, .external_lex_state = 15},
  [6747] = {.lex_state = 91, .external_lex_state = 15},
  [6748] = {.lex_state = 91, .external_lex_state = 15},
  [6749] = {.lex_state = 91, .external_lex_state = 15},
  [6750] = {.lex_state = 91, .external_lex_state = 15},
  [6751] = {.lex_state = 91, .external_lex_state = 15},
  [6752] = {.lex_state = 91, .external_lex_state = 15},
  [6753] = {.lex_state = 91, .external_lex_state = 15},
  [6754] = {.lex_state = 91, .external_lex_state = 15},
  [6755] = {.lex_state = 91, .external_lex_state = 15},
  [6756] = {.lex_state = 91, .external_lex_state = 15},
  [6757] = {.lex_state = 91, .external_lex_state = 15},
  [6758] = {.lex_state = 91, .external_lex_state = 15},
  [6759] = {.lex_state = 91, .external_lex_state = 15},
  [6760] = {.lex_state = 91, .external_lex_state = 15},
  [6761] = {.lex_state = 91, .external_lex_state = 15},
  [6762] = {.lex_state = 91, .external_lex_state = 15},
  [6763] = {.lex_state = 91, .external_lex_state = 15},
  [6764] = {.lex_state = 91, .external_lex_state = 15},
  [6765] = {.lex_state = 91, .external_lex_state = 15},
  [6766] = {.lex_state = 91, .external_lex_state = 15},
  [6767] = {.lex_state = 91, .external_lex_state = 15},
  [6768] = {.lex_state = 91, .external_lex_state = 15},
  [6769] = {.lex_state = 91, .external_lex_state = 15},
  [6770] = {.lex_state = 91, .external_lex_state = 15},
  [6771] = {.lex_state = 91, .external_lex_state = 15},
  [6772] = {.lex_state = 91, .external_lex_state = 15},
  [6773] = {.lex_state = 91, .external_lex_state = 15},
  [6774] = {.lex_state = 91, .external_lex_state = 15},
  [6775] = {.lex_state = 91, .external_lex_state = 15},
  [6776] = {.lex_state = 91, .external_lex_state = 15},
  [6777] = {.lex_state = 91, .external_lex_state = 15},
  [6778] = {.lex_state = 91, .external_lex_state = 15},
  [6779] = {.lex_state = 91, .external_lex_state = 15},
  [6780] = {.lex_state = 91, .external_lex_state = 15},
  [6781] = {.lex_state = 91, .external_lex_state = 15},
  [6782] = {.lex_state = 91, .external_lex_state = 15},
  [6783] = {.lex_state = 91, .external_lex_state = 15},
  [6784] = {.lex_state = 91, .external_lex_state = 15},
  [6785] = {.lex_state = 91, .external_lex_state = 15},
  [6786] = {.lex_state = 91, .external_lex_state = 15},
  [6787] = {.lex_state = 91, .external_lex_state = 15},
  [6788] = {.lex_state = 91, .external_lex_state = 11},
  [6789] = {.lex_state = 91, .external_lex_state = 11},
  [6790] = {.lex_state = 91, .external_lex_state = 19},
  [6791] = {.lex_state = 91, .external_lex_state = 19},
  [6792] = {.lex_state = 91, .external_lex_state = 19},
  [6793] = {.lex_state = 91, .external_lex_state = 25},
  [6794] = {.lex_state = 91, .external_lex_state = 25},
  [6795] = {.lex_state = 91, .external_lex_state = 25},
  [6796] = {.lex_state = 91, .external_lex_state = 19},
  [6797] = {.lex_state = 91, .external_lex_state = 25},
  [6798] = {.lex_state = 91, .external_lex_state = 25},
  [6799] = {.lex_state = 91, .external_lex_state = 19},
  [6800] = {.lex_state = 91, .external_lex_state = 19},
  [6801] = {.lex_state = 91, .external_lex_state = 2},
  [6802] = {.lex_state = 91, .external_lex_state = 11},
  [6803] = {.lex_state = 91, .external_lex_state = 19},
  [6804] = {.lex_state = 91, .external_lex_state = 15},
  [6805] = {.lex_state = 91, .external_lex_state = 15},
  [6806] = {.lex_state = 91, .external_lex_state = 19},
  [6807] = {.lex_state = 91, .external_lex_state = 11},
  [6808] = {.lex_state = 91, .external_lex_state = 19},
  [6809] = {.lex_state = 91, .external_lex_state = 11},
  [6810] = {.lex_state = 91, .external_lex_state = 15},
  [6811] = {.lex_state = 91, .external_lex_state = 2},
  [6812] = {.lex_state = 91, .external_lex_state = 11},
  [6813] = {.lex_state = 91, .external_lex_state = 11},
  [6814] = {.lex_state = 91, .external_lex_state = 15},
  [6815] = {.lex_state = 91, .external_lex_state = 15},
  [6816] = {.lex_state = 91, .external_lex_state = 15},
  [6817] = {.lex_state = 91, .external_lex_state = 15},
  [6818] = {.lex_state = 91, .external_lex_state = 15},
  [6819] = {.lex_state = 91, .external_lex_state = 11},
  [6820] = {.lex_state = 91, .external_lex_state = 15},
  [6821] = {.lex_state = 91, .external_lex_state = 19},
  [6822] = {.lex_state = 91, .external_lex_state = 15},
  [6823] = {.lex_state = 91, .external_lex_state = 11},
  [6824] = {.lex_state = 91, .external_lex_state = 19},
  [6825] = {.lex_state = 91, .external_lex_state = 11},
  [6826] = {.lex_state = 91, .external_lex_state = 11},
  [6827] = {.lex_state = 91, .external_lex_state = 11},
  [6828] = {.lex_state = 91, .external_lex_state = 19},
  [6829] = {.lex_state = 91, .external_lex_state = 19},
  [6830] = {.lex_state = 91, .external_lex_state = 11},
  [6831] = {.lex_state = 91, .external_lex_state = 11},
  [6832] = {.lex_state = 91, .external_lex_state = 15},
  [6833] = {.lex_state = 91, .external_lex_state = 15},
  [6834] = {.lex_state = 91, .external_lex_state = 11},
  [6835] = {.lex_state = 91, .external_lex_state = 19},
  [6836] = {.lex_state = 91, .external_lex_state = 11},
  [6837] = {.lex_state = 91, .external_lex_state = 19},
  [6838] = {.lex_state = 91, .external_lex_state = 11},
  [6839] = {.lex_state = 91, .external_lex_state = 15},
  [6840] = {.lex_state = 91, .external_lex_state = 2},
  [6841] = {.lex_state = 91, .external_lex_state = 19},
  [6842] = {.lex_state = 91, .external_lex_state = 15},
  [6843] = {.lex_state = 91, .external_lex_state = 11},
  [6844] = {.lex_state = 91, .external_lex_state = 11},
  [6845] = {.lex_state = 91, .external_lex_state = 11},
  [6846] = {.lex_state = 91, .external_lex_state = 19},
  [6847] = {.lex_state = 91, .external_lex_state = 19},
  [6848] = {.lex_state = 91, .external_lex_state = 19},
  [6849] = {.lex_state = 91, .external_lex_state = 15},
  [6850] = {.lex_state = 91, .external_lex_state = 15},
  [6851] = {.lex_state = 91, .external_lex_state = 15},
  [6852] = {.lex_state = 91, .external_lex_state = 19},
  [6853] = {.lex_state = 91, .external_lex_state = 19},
  [6854] = {.lex_state = 91, .external_lex_state = 19},
  [6855] = {.lex_state = 91, .external_lex_state = 19},
  [6856] = {.lex_state = 91, .external_lex_state = 19},
  [6857] = {.lex_state = 91, .external_lex_state = 19},
  [6858] = {.lex_state = 91, .external_lex_state = 19},
  [6859] = {.lex_state = 91, .external_lex_state = 19},
  [6860] = {.lex_state = 91, .external_lex_state = 11},
  [6861] = {.lex_state = 91, .external_lex_state = 19},
  [6862] = {.lex_state = 91, .external_lex_state = 15},
  [6863] = {.lex_state = 91, .external_lex_state = 15},
  [6864] = {.lex_state = 91, .external_lex_state = 19},
  [6865] = {.lex_state = 91, .external_lex_state = 15},
  [6866] = {.lex_state = 91, .external_lex_state = 15},
  [6867] = {.lex_state = 91, .external_lex_state = 11},
  [6868] = {.lex_state = 91, .external_lex_state = 11},
  [6869] = {.lex_state = 91, .external_lex_state = 11},
  [6870] = {.lex_state = 91, .external_lex_state = 19},
  [6871] = {.lex_state = 91, .external_lex_state = 15},
  [6872] = {.lex_state = 91, .external_lex_state = 19},
  [6873] = {.lex_state = 91, .external_lex_state = 19},
  [6874] = {.lex_state = 91, .external_lex_state = 19},
  [6875] = {.lex_state = 91, .external_lex_state = 19},
  [6876] = {.lex_state = 91, .external_lex_state = 11},
  [6877] = {.lex_state = 91, .external_lex_state = 19},
  [6878] = {.lex_state = 91, .external_lex_state = 15},
  [6879] = {.lex_state = 91, .external_lex_state = 15},
  [6880] = {.lex_state = 91, .external_lex_state = 15},
  [6881] = {.lex_state = 91, .external_lex_state = 11},
  [6882] = {.lex_state = 91, .external_lex_state = 11},
  [6883] = {.lex_state = 91, .external_lex_state = 19},
  [6884] = {.lex_state = 91, .external_lex_state = 11},
  [6885] = {.lex_state = 91, .external_lex_state = 12},
  [6886] = {.lex_state = 91, .external_lex_state = 12},
  [6887] = {.lex_state = 91, .external_lex_state = 12},
  [6888] = {.lex_state = 91, .external_lex_state = 12},
  [6889] = {.lex_state = 91, .external_lex_state = 24},
  [6890] = {.lex_state = 91, .external_lex_state = 24},
  [6891] = {.lex_state = 91, .external_lex_state = 15},
  [6892] = {.lex_state = 91, .external_lex_state = 24},
  [6893] = {.lex_state = 91, .external_lex_state = 12},
  [6894] = {.lex_state = 91, .external_lex_state = 12},
  [6895] = {.lex_state = 91, .external_lex_state = 12},
  [6896] = {.lex_state = 91, .external_lex_state = 15},
  [6897] = {.lex_state = 91, .external_lex_state = 24},
  [6898] = {.lex_state = 91, .external_lex_state = 24},
  [6899] = {.lex_state = 91, .external_lex_state = 24},
  [6900] = {.lex_state = 91, .external_lex_state = 12},
  [6901] = {.lex_state = 91, .external_lex_state = 12},
  [6902] = {.lex_state = 91, .external_lex_state = 12},
  [6903] = {.lex_state = 91, .external_lex_state = 12},
  [6904] = {.lex_state = 91, .external_lex_state = 12},
  [6905] = {.lex_state = 91, .external_lex_state = 12},
  [6906] = {.lex_state = 91, .external_lex_state = 12},
  [6907] = {.lex_state = 91, .external_lex_state = 12},
  [6908] = {.lex_state = 91, .external_lex_state = 12},
  [6909] = {.lex_state = 91, .external_lex_state = 12},
  [6910] = {.lex_state = 91, .external_lex_state = 12},
  [6911] = {.lex_state = 91, .external_lex_state = 12},
  [6912] = {.lex_state = 91, .external_lex_state = 12},
  [6913] = {.lex_state = 91, .external_lex_state = 12},
  [6914] = {.lex_state = 91, .external_lex_state = 12},
  [6915] = {.lex_state = 91, .external_lex_state = 12},
  [6916] = {.lex_state = 91, .external_lex_state = 12},
  [6917] = {.lex_state = 91, .external_lex_state = 12},
  [6918] = {.lex_state = 91, .external_lex_state = 12},
  [6919] = {.lex_state = 91, .external_lex_state = 12},
  [6920] = {.lex_state = 91, .external_lex_state = 12},
  [6921] = {.lex_state = 91, .external_lex_state = 12},
  [6922] = {.lex_state = 91, .external_lex_state = 12},
  [6923] = {.lex_state = 91, .external_lex_state = 12},
  [6924] = {.lex_state = 91, .external_lex_state = 12},
  [6925] = {.lex_state = 91, .external_lex_state = 12},
  [6926] = {.lex_state = 91, .external_lex_state = 15},
  [6927] = {.lex_state = 91, .external_lex_state = 12},
  [6928] = {.lex_state = 91, .external_lex_state = 24},
  [6929] = {.lex_state = 91, .external_lex_state = 15},
  [6930] = {.lex_state = 91, .external_lex_state = 12},
  [6931] = {.lex_state = 91, .external_lex_state = 24},
  [6932] = {.lex_state = 91, .external_lex_state = 24},
  [6933] = {.lex_state = 91, .external_lex_state = 24},
  [6934] = {.lex_state = 91, .external_lex_state = 12},
  [6935] = {.lex_state = 91, .external_lex_state = 12},
  [6936] = {.lex_state = 91, .external_lex_state = 12},
  [6937] = {.lex_state = 91, .external_lex_state = 12},
  [6938] = {.lex_state = 91, .external_lex_state = 24},
  [6939] = {.lex_state = 91, .external_lex_state = 15},
  [6940] = {.lex_state = 91, .external_lex_state = 12},
  [6941] = {.lex_state = 91, .external_lex_state = 12},
  [6942] = {.lex_state = 91, .external_lex_state = 24},
  [6943] = {.lex_state = 91, .external_lex_state = 12},
  [6944] = {.lex_state = 91, .external_lex_state = 12},
  [6945] = {.lex_state = 91, .external_lex_state = 12},
  [6946] = {.lex_state = 91, .external_lex_state = 12},
  [6947] = {.lex_state = 91, .external_lex_state = 12},
  [6948] = {.lex_state = 91, .external_lex_state = 12},
  [6949] = {.lex_state = 91, .external_lex_state = 15},
  [6950] = {.lex_state = 91, .external_lex_state = 12},
  [6951] = {.lex_state = 91, .external_lex_state = 12},
  [6952] = {.lex_state = 91, .external_lex_state = 12},
  [6953] = {.lex_state = 91, .external_lex_state = 12},
  [6954] = {.lex_state = 91, .external_lex_state = 12},
  [6955] = {.lex_state = 91, .external_lex_state = 12},
  [6956] = {.lex_state = 91, .external_lex_state = 12},
  [6957] = {.lex_state = 91, .external_lex_state = 12},
  [6958] = {.lex_state = 91, .external_lex_state = 12},
  [6959] = {.lex_state = 91, .external_lex_state = 15},
  [6960] = {.lex_state = 91, .external_lex_state = 12},
  [6961] = {.lex_state = 91, .external_lex_state = 12},
  [6962] = {.lex_state = 91, .external_lex_state = 12},
  [6963] = {.lex_state = 91, .external_lex_state = 12},
  [6964] = {.lex_state = 91, .external_lex_state = 12},
  [6965] = {.lex_state = 91, .external_lex_state = 12},
  [6966] = {.lex_state = 91, .external_lex_state = 12},
  [6967] = {.lex_state = 91, .external_lex_state = 12},
  [6968] = {.lex_state = 91, .external_lex_state = 12},
  [6969] = {.lex_state = 91, .external_lex_state = 12},
  [6970] = {.lex_state = 91, .external_lex_state = 12},
  [6971] = {.lex_state = 91, .external_lex_state = 12},
  [6972] = {.lex_state = 91, .external_lex_state = 12},
  [6973] = {.lex_state = 91, .external_lex_state = 12},
  [6974] = {.lex_state = 91, .external_lex_state = 12},
  [6975] = {.lex_state = 91, .external_lex_state = 12},
  [6976] = {.lex_state = 91, .external_lex_state = 12},
  [6977] = {.lex_state = 91, .external_lex_state = 12},
  [6978] = {.lex_state = 91, .external_lex_state = 12},
  [6979] = {.lex_state = 91, .external_lex_state = 12},
  [6980] = {.lex_state = 91, .external_lex_state = 12},
  [6981] = {.lex_state = 91, .external_lex_state = 24},
  [6982] = {.lex_state = 91, .external_lex_state = 12},
  [6983] = {.lex_state = 91, .external_lex_state = 15},
  [6984] = {.lex_state = 91, .external_lex_state = 12},
  [6985] = {.lex_state = 91, .external_lex_state = 24},
  [6986] = {.lex_state = 91, .external_lex_state = 24},
  [6987] = {.lex_state = 91, .external_lex_state = 24},
  [6988] = {.lex_state = 91, .external_lex_state = 12},
  [6989] = {.lex_state = 91, .external_lex_state = 12},
  [6990] = {.lex_state = 91, .external_lex_state = 12},
  [6991] = {.lex_state = 91, .external_lex_state = 12},
  [6992] = {.lex_state = 91, .external_lex_state = 12},
  [6993] = {.lex_state = 91, .external_lex_state = 12},
  [6994] = {.lex_state = 91, .external_lex_state = 12},
  [6995] = {.lex_state = 91, .external_lex_state = 12},
  [6996] = {.lex_state = 91, .external_lex_state = 24},
  [6997] = {.lex_state = 91, .external_lex_state = 12},
  [6998] = {.lex_state = 91, .external_lex_state = 12},
  [6999] = {.lex_state = 91, .external_lex_state = 24},
  [7000] = {.lex_state = 91, .external_lex_state = 12},
  [7001] = {.lex_state = 91, .external_lex_state = 24},
  [7002] = {.lex_state = 91, .external_lex_state = 24},
  [7003] = {.lex_state = 91, .external_lex_state = 12},
  [7004] = {.lex_state = 91, .external_lex_state = 24},
  [7005] = {.lex_state = 91, .external_lex_state = 24},
  [7006] = {.lex_state = 91, .external_lex_state = 2},
  [7007] = {.lex_state = 91, .external_lex_state = 24},
  [7008] = {.lex_state = 91, .external_lex_state = 24},
  [7009] = {.lex_state = 91, .external_lex_state = 24},
  [7010] = {.lex_state = 91, .external_lex_state = 2},
  [7011] = {.lex_state = 91, .external_lex_state = 24},
  [7012] = {.lex_state = 91, .external_lex_state = 24},
  [7013] = {.lex_state = 91, .external_lex_state = 24},
  [7014] = {.lex_state = 91, .external_lex_state = 24},
  [7015] = {.lex_state = 91, .external_lex_state = 24},
  [7016] = {.lex_state = 91, .external_lex_state = 24},
  [7017] = {.lex_state = 91, .external_lex_state = 24},
  [7018] = {.lex_state = 91, .external_lex_state = 24},
  [7019] = {.lex_state = 91, .external_lex_state = 24},
  [7020] = {.lex_state = 91, .external_lex_state = 23},
  [7021] = {.lex_state = 91, .external_lex_state = 23},
  [7022] = {.lex_state = 91, .external_lex_state = 23},
  [7023] = {.lex_state = 91, .external_lex_state = 2},
  [7024] = {.lex_state = 91, .external_lex_state = 23},
  [7025] = {.lex_state = 91, .external_lex_state = 11},
  [7026] = {.lex_state = 91, .external_lex_state = 23},
  [7027] = {.lex_state = 91, .external_lex_state = 2},
  [7028] = {.lex_state = 91, .external_lex_state = 23},
  [7029] = {.lex_state = 91, .external_lex_state = 25},
  [7030] = {.lex_state = 91, .external_lex_state = 23},
  [7031] = {.lex_state = 91, .external_lex_state = 23},
  [7032] = {.lex_state = 91, .external_lex_state = 25},
  [7033] = {.lex_state = 91, .external_lex_state = 25},
  [7034] = {.lex_state = 91, .external_lex_state = 25},
  [7035] = {.lex_state = 91, .external_lex_state = 25},
  [7036] = {.lex_state = 91, .external_lex_state = 25},
  [7037] = {.lex_state = 91, .external_lex_state = 25},
  [7038] = {.lex_state = 91, .external_lex_state = 25},
  [7039] = {.lex_state = 91, .external_lex_state = 25},
  [7040] = {.lex_state = 91, .external_lex_state = 25},
  [7041] = {.lex_state = 91, .external_lex_state = 25},
  [7042] = {.lex_state = 91, .external_lex_state = 25},
  [7043] = {.lex_state = 91, .external_lex_state = 2},
  [7044] = {.lex_state = 91, .external_lex_state = 25},
  [7045] = {.lex_state = 91, .external_lex_state = 2},
  [7046] = {.lex_state = 91, .external_lex_state = 25},
  [7047] = {.lex_state = 91, .external_lex_state = 23},
  [7048] = {.lex_state = 91, .external_lex_state = 25},
  [7049] = {.lex_state = 91, .external_lex_state = 25},
  [7050] = {.lex_state = 91, .external_lex_state = 25},
  [7051] = {.lex_state = 91, .external_lex_state = 25},
  [7052] = {.lex_state = 91, .external_lex_state = 2},
  [7053] = {.lex_state = 91, .external_lex_state = 25},
  [7054] = {.lex_state = 91, .external_lex_state = 2},
  [7055] = {.lex_state = 91, .external_lex_state = 25},
  [7056] = {.lex_state = 91, .external_lex_state = 25},
  [7057] = {.lex_state = 91, .external_lex_state = 25},
  [7058] = {.lex_state = 91, .external_lex_state = 25},
  [7059] = {.lex_state = 91, .external_lex_state = 25},
  [7060] = {.lex_state = 91, .external_lex_state = 25},
  [7061] = {.lex_state = 91, .external_lex_state = 25},
  [7062] = {.lex_state = 91, .external_lex_state = 25},
  [7063] = {.lex_state = 91, .external_lex_state = 25},
  [7064] = {.lex_state = 91, .external_lex_state = 25},
  [7065] = {.lex_state = 91, .external_lex_state = 25},
  [7066] = {.lex_state = 91, .external_lex_state = 25},
  [7067] = {.lex_state = 91, .external_lex_state = 25},
  [7068] = {.lex_state = 91, .external_lex_state = 25},
  [7069] = {.lex_state = 91, .external_lex_state = 25},
  [7070] = {.lex_state = 91, .external_lex_state = 25},
  [7071] = {.lex_state = 91, .external_lex_state = 25},
  [7072] = {.lex_state = 91, .external_lex_state = 25},
  [7073] = {.lex_state = 91, .external_lex_state = 25},
  [7074] = {.lex_state = 91, .external_lex_state = 25},
  [7075] = {.lex_state = 91, .external_lex_state = 25},
  [7076] = {.lex_state = 91, .external_lex_state = 25},
  [7077] = {.lex_state = 91, .external_lex_state = 11},
  [7078] = {.lex_state = 91, .external_lex_state = 25},
  [7079] = {.lex_state = 91, .external_lex_state = 25},
  [7080] = {.lex_state = 91, .external_lex_state = 25},
  [7081] = {.lex_state = 91, .external_lex_state = 25},
  [7082] = {.lex_state = 91, .external_lex_state = 25},
  [7083] = {.lex_state = 91, .external_lex_state = 25},
  [7084] = {.lex_state = 91, .external_lex_state = 25},
  [7085] = {.lex_state = 91, .external_lex_state = 25},
  [7086] = {.lex_state = 91, .external_lex_state = 25},
  [7087] = {.lex_state = 91, .external_lex_state = 25},
  [7088] = {.lex_state = 91, .external_lex_state = 25},
  [7089] = {.lex_state = 91, .external_lex_state = 25},
  [7090] = {.lex_state = 91, .external_lex_state = 25},
  [7091] = {.lex_state = 91, .external_lex_state = 25},
  [7092] = {.lex_state = 91, .external_lex_state = 2},
  [7093] = {.lex_state = 91, .external_lex_state = 25},
  [7094] = {.lex_state = 91, .external_lex_state = 25},
  [7095] = {.lex_state = 91, .external_lex_state = 25},
  [7096] = {.lex_state = 91, .external_lex_state = 25},
  [7097] = {.lex_state = 91, .external_lex_state = 25},
  [7098] = {.lex_state = 91, .external_lex_state = 2},
  [7099] = {.lex_state = 91, .external_lex_state = 2},
  [7100] = {.lex_state = 91, .external_lex_state = 21},
  [7101] = {.lex_state = 91, .external_lex_state = 21},
  [7102] = {.lex_state = 91, .external_lex_state = 2},
  [7103] = {.lex_state = 91, .external_lex_state = 2},
  [7104] = {.lex_state = 91, .external_lex_state = 2},
  [7105] = {.lex_state = 91, .external_lex_state = 21},
  [7106] = {.lex_state = 91, .external_lex_state = 21},
  [7107] = {.lex_state = 91, .external_lex_state = 21},
  [7108] = {.lex_state = 91, .external_lex_state = 21},
  [7109] = {.lex_state = 91, .external_lex_state = 2},
  [7110] = {.lex_state = 91, .external_lex_state = 2},
  [7111] = {.lex_state = 91, .external_lex_state = 2},
  [7112] = {.lex_state = 91, .external_lex_state = 2},
  [7113] = {.lex_state = 91, .external_lex_state = 21},
  [7114] = {.lex_state = 91, .external_lex_state = 2},
  [7115] = {.lex_state = 91, .external_lex_state = 21},
  [7116] = {.lex_state = 91, .external_lex_state = 26},
  [7117] = {.lex_state = 91, .external_lex_state = 21},
  [7118] = {.lex_state = 91, .external_lex_state = 26},
  [7119] = {.lex_state = 91, .external_lex_state = 2},
  [7120] = {.lex_state = 91, .external_lex_state = 2},
  [7121] = {.lex_state = 91, .external_lex_state = 2},
  [7122] = {.lex_state = 91, .external_lex_state = 21},
  [7123] = {.lex_state = 91, .external_lex_state = 21},
  [7124] = {.lex_state = 91, .external_lex_state = 2},
  [7125] = {.lex_state = 91, .external_lex_state = 2},
  [7126] = {.lex_state = 91, .external_lex_state = 26},
  [7127] = {.lex_state = 91, .external_lex_state = 21},
  [7128] = {.lex_state = 91, .external_lex_state = 21},
  [7129] = {.lex_state = 91, .external_lex_state = 21},
  [7130] = {.lex_state = 91, .external_lex_state = 21},
  [7131] = {.lex_state = 91, .external_lex_state = 21},
  [7132] = {.lex_state = 91, .external_lex_state = 21},
  [7133] = {.lex_state = 91, .external_lex_state = 21},
  [7134] = {.lex_state = 91, .external_lex_state = 23},
  [7135] = {.lex_state = 91, .external_lex_state = 21},
  [7136] = {.lex_state = 91, .external_lex_state = 21},
  [7137] = {.lex_state = 91, .external_lex_state = 21},
  [7138] = {.lex_state = 91, .external_lex_state = 2},
  [7139] = {.lex_state = 91, .external_lex_state = 2},
  [7140] = {.lex_state = 91, .external_lex_state = 2},
  [7141] = {.lex_state = 91, .external_lex_state = 2},
  [7142] = {.lex_state = 91, .external_lex_state = 21},
  [7143] = {.lex_state = 91, .external_lex_state = 21},
  [7144] = {.lex_state = 91, .external_lex_state = 2},
  [7145] = {.lex_state = 91, .external_lex_state = 26},
  [7146] = {.lex_state = 91, .external_lex_state = 2},
  [7147] = {.lex_state = 91, .external_lex_state = 2},
  [7148] = {.lex_state = 91, .external_lex_state = 21},
  [7149] = {.lex_state = 91, .external_lex_state = 26},
  [7150] = {.lex_state = 91, .external_lex_state = 21},
  [7151] = {.lex_state = 91, .external_lex_state = 21},
  [7152] = {.lex_state = 91, .external_lex_state = 21},
  [7153] = {.lex_state = 91, .external_lex_state = 2},
  [7154] = {.lex_state = 91, .external_lex_state = 2},
  [7155] = {.lex_state = 91, .external_lex_state = 23},
  [7156] = {.lex_state = 91, .external_lex_state = 2},
  [7157] = {.lex_state = 91, .external_lex_state = 2},
  [7158] = {.lex_state = 91, .external_lex_state = 2},
  [7159] = {.lex_state = 91, .external_lex_state = 2},
  [7160] = {.lex_state = 91, .external_lex_state = 2},
  [7161] = {.lex_state = 91, .external_lex_state = 2},
  [7162] = {.lex_state = 91, .external_lex_state = 2},
  [7163] = {.lex_state = 91, .external_lex_state = 21},
  [7164] = {.lex_state = 91, .external_lex_state = 21},
  [7165] = {.lex_state = 91, .external_lex_state = 21},
  [7166] = {.lex_state = 91, .external_lex_state = 21},
  [7167] = {.lex_state = 91, .external_lex_state = 23},
  [7168] = {.lex_state = 91, .external_lex_state = 23},
  [7169] = {.lex_state = 91, .external_lex_state = 21},
  [7170] = {.lex_state = 91, .external_lex_state = 21},
  [7171] = {.lex_state = 91, .external_lex_state = 21},
  [7172] = {.lex_state = 91, .external_lex_state = 21},
  [7173] = {.lex_state = 91, .external_lex_state = 21},
  [7174] = {.lex_state = 91, .external_lex_state = 21},
  [7175] = {.lex_state = 91, .external_lex_state = 21},
  [7176] = {.lex_state = 91, .external_lex_state = 21},
  [7177] = {.lex_state = 91, .external_lex_state = 2},
  [7178] = {.lex_state = 91, .external_lex_state = 2},
  [7179] = {.lex_state = 91, .external_lex_state = 2},
  [7180] = {.lex_state = 91, .external_lex_state = 2},
  [7181] = {.lex_state = 91, .external_lex_state = 2},
  [7182] = {.lex_state = 91, .external_lex_state = 21},
  [7183] = {.lex_state = 91, .external_lex_state = 2},
  [7184] = {.lex_state = 91, .external_lex_state = 23},
  [7185] = {.lex_state = 91, .external_lex_state = 2},
  [7186] = {.lex_state = 91, .external_lex_state = 2},
  [7187] = {.lex_state = 91, .external_lex_state = 21},
  [7188] = {.lex_state = 91, .external_lex_state = 21},
  [7189] = {.lex_state = 91, .external_lex_state = 2},
  [7190] = {.lex_state = 91, .external_lex_state = 2},
  [7191] = {.lex_state = 91, .external_lex_state = 23},
  [7192] = {.lex_state = 91, .external_lex_state = 2},
  [7193] = {.lex_state = 91, .external_lex_state = 2},
  [7194] = {.lex_state = 91, .external_lex_state = 23},
  [7195] = {.lex_state = 91, .external_lex_state = 2},
  [7196] = {.lex_state = 91, .external_lex_state = 2},
  [7197] = {.lex_state = 91, .external_lex_state = 2},
  [7198] = {.lex_state = 91, .external_lex_state = 2},
  [7199] = {.lex_state = 91, .external_lex_state = 21},
  [7200] = {.lex_state = 91, .external_lex_state = 21},
  [7201] = {.lex_state = 91, .external_lex_state = 21},
  [7202] = {.lex_state = 91, .external_lex_state = 21},
  [7203] = {.lex_state = 91, .external_lex_state = 23},
  [7204] = {.lex_state = 91, .external_lex_state = 21},
  [7205] = {.lex_state = 91, .external_lex_state = 2},
  [7206] = {.lex_state = 91, .external_lex_state = 2},
  [7207] = {.lex_state = 91, .external_lex_state = 2},
  [7208] = {.lex_state = 91, .external_lex_state = 21},
  [7209] = {.lex_state = 91, .external_lex_state = 23},
  [7210] = {.lex_state = 91, .external_lex_state = 27},
  [7211] = {.lex_state = 91, .external_lex_state = 2},
  [7212] = {.lex_state = 91, .external_lex_state = 23},
  [7213] = {.lex_state = 91, .external_lex_state = 2},
  [7214] = {.lex_state = 91, .external_lex_state = 12},
  [7215] = {.lex_state = 91, .external_lex_state = 23},
  [7216] = {.lex_state = 91, .external_lex_state = 23},
  [7217] = {.lex_state = 91, .external_lex_state = 2},
  [7218] = {.lex_state = 91, .external_lex_state = 2},
  [7219] = {.lex_state = 91, .external_lex_state = 2},
  [7220] = {.lex_state = 91, .external_lex_state = 27},
  [7221] = {.lex_state = 91, .external_lex_state = 2},
  [7222] = {.lex_state = 91, .external_lex_state = 2},
  [7223] = {.lex_state = 91, .external_lex_state = 2},
  [7224] = {.lex_state = 91, .external_lex_state = 2},
  [7225] = {.lex_state = 91, .external_lex_state = 23},
  [7226] = {.lex_state = 91, .external_lex_state = 27},
  [7227] = {.lex_state = 91, .external_lex_state = 23},
  [7228] = {.lex_state = 91, .external_lex_state = 23},
  [7229] = {.lex_state = 91, .external_lex_state = 2},
  [7230] = {.lex_state = 91, .external_lex_state = 23},
  [7231] = {.lex_state = 91, .external_lex_state = 2},
  [7232] = {.lex_state = 91, .external_lex_state = 23},
  [7233] = {.lex_state = 91, .external_lex_state = 2},
  [7234] = {.lex_state = 91, .external_lex_state = 2},
  [7235] = {.lex_state = 91, .external_lex_state = 27},
  [7236] = {.lex_state = 91, .external_lex_state = 27},
  [7237] = {.lex_state = 91, .external_lex_state = 2},
  [7238] = {.lex_state = 91, .external_lex_state = 23},
  [7239] = {.lex_state = 91, .external_lex_state = 21},
  [7240] = {.lex_state = 91, .external_lex_state = 21},
  [7241] = {.lex_state = 91, .external_lex_state = 21},
  [7242] = {.lex_state = 91, .external_lex_state = 11},
  [7243] = {.lex_state = 91, .external_lex_state = 21},
  [7244] = {.lex_state = 91, .external_lex_state = 2},
  [7245] = {.lex_state = 91, .external_lex_state = 11},
  [7246] = {.lex_state = 91, .external_lex_state = 2},
  [7247] = {.lex_state = 91, .external_lex_state = 2},
  [7248] = {.lex_state = 91, .external_lex_state = 11},
  [7249] = {.lex_state = 91, .external_lex_state = 2},
  [7250] = {.lex_state = 91, .external_lex_state = 2},
  [7251] = {.lex_state = 91, .external_lex_state = 11},
  [7252] = {.lex_state = 91, .external_lex_state = 21},
  [7253] = {.lex_state = 91, .external_lex_state = 15},
  [7254] = {.lex_state = 91, .external_lex_state = 23},
  [7255] = {.lex_state = 91, .external_lex_state = 21},
  [7256] = {.lex_state = 91, .external_lex_state = 21},
  [7257] = {.lex_state = 91, .external_lex_state = 21},
  [7258] = {.lex_state = 91, .external_lex_state = 21},
  [7259] = {.lex_state = 91, .external_lex_state = 23},
  [7260] = {.lex_state = 91, .external_lex_state = 21},
  [7261] = {.lex_state = 91, .external_lex_state = 15},
  [7262] = {.lex_state = 91, .external_lex_state = 15},
  [7263] = {.lex_state = 91, .external_lex_state = 21},
  [7264] = {.lex_state = 91, .external_lex_state = 15},
  [7265] = {.lex_state = 91, .external_lex_state = 23},
  [7266] = {.lex_state = 91, .external_lex_state = 15},
  [7267] = {.lex_state = 91, .external_lex_state = 21},
  [7268] = {.lex_state = 91, .external_lex_state = 23},
  [7269] = {.lex_state = 91, .external_lex_state = 15},
  [7270] = {.lex_state = 91, .external_lex_state = 15},
  [7271] = {.lex_state = 91, .external_lex_state = 2},
  [7272] = {.lex_state = 91, .external_lex_state = 21},
  [7273] = {.lex_state = 91, .external_lex_state = 23},
  [7274] = {.lex_state = 91, .external_lex_state = 21},
  [7275] = {.lex_state = 91, .external_lex_state = 21},
  [7276] = {.lex_state = 91, .external_lex_state = 23},
  [7277] = {.lex_state = 91, .external_lex_state = 21},
  [7278] = {.lex_state = 91, .external_lex_state = 21},
  [7279] = {.lex_state = 91, .external_lex_state = 15},
  [7280] = {.lex_state = 91, .external_lex_state = 15},
  [7281] = {.lex_state = 91, .external_lex_state = 15},
  [7282] = {.lex_state = 91, .external_lex_state = 15},
  [7283] = {.lex_state = 91, .external_lex_state = 15},
  [7284] = {.lex_state = 91, .external_lex_state = 15},
  [7285] = {.lex_state = 91, .external_lex_state = 23},
  [7286] = {.lex_state = 91, .external_lex_state = 23},
  [7287] = {.lex_state = 91, .external_lex_state = 2},
  [7288] = {.lex_state = 91, .external_lex_state = 2},
  [7289] = {.lex_state = 91, .external_lex_state = 15},
  [7290] = {.lex_state = 91, .external_lex_state = 15},
  [7291] = {.lex_state = 91, .external_lex_state = 15},
  [7292] = {.lex_state = 91, .external_lex_state = 23},
  [7293] = {.lex_state = 91, .external_lex_state = 15},
  [7294] = {.lex_state = 91, .external_lex_state = 23},
  [7295] = {.lex_state = 91, .external_lex_state = 15},
  [7296] = {.lex_state = 91, .external_lex_state = 15},
  [7297] = {.lex_state = 91, .external_lex_state = 15},
  [7298] = {.lex_state = 91, .external_lex_state = 15},
  [7299] = {.lex_state = 91, .external_lex_state = 15},
  [7300] = {.lex_state = 91, .external_lex_state = 15},
  [7301] = {.lex_state = 91, .external_lex_state = 15},
  [7302] = {.lex_state = 91, .external_lex_state = 15},
  [7303] = {.lex_state = 91, .external_lex_state = 2},
  [7304] = {.lex_state = 91, .external_lex_state = 15},
  [7305] = {.lex_state = 91, .external_lex_state = 15},
  [7306] = {.lex_state = 91, .external_lex_state = 15},
  [7307] = {.lex_state = 91, .external_lex_state = 15},
  [7308] = {.lex_state = 91, .external_lex_state = 15},
  [7309] = {.lex_state = 91, .external_lex_state = 15},
  [7310] = {.lex_state = 91, .external_lex_state = 15},
  [7311] = {.lex_state = 91, .external_lex_state = 15},
  [7312] = {.lex_state = 91, .external_lex_state = 15},
  [7313] = {.lex_state = 91, .external_lex_state = 15},
  [7314] = {.lex_state = 91, .external_lex_state = 15},
  [7315] = {.lex_state = 91, .external_lex_state = 23},
  [7316] = {.lex_state = 91, .external_lex_state = 15},
  [7317] = {.lex_state = 91, .external_lex_state = 15},
  [7318] = {.lex_state = 91, .external_lex_state = 15},
  [7319] = {.lex_state = 91, .external_lex_state = 15},
  [7320] = {.lex_state = 91, .external_lex_state = 15},
  [7321] = {.lex_state = 91, .external_lex_state = 15},
  [7322] = {.lex_state = 91, .external_lex_state = 15},
  [7323] = {.lex_state = 91, .external_lex_state = 23},
  [7324] = {.lex_state = 91, .external_lex_state = 2},
  [7325] = {.lex_state = 91, .external_lex_state = 15},
  [7326] = {.lex_state = 91, .external_lex_state = 15},
  [7327] = {.lex_state = 91, .external_lex_state = 23},
  [7328] = {.lex_state = 91, .external_lex_state = 21},
  [7329] = {.lex_state = 91, .external_lex_state = 21},
  [7330] = {.lex_state = 91, .external_lex_state = 15},
  [7331] = {.lex_state = 91, .external_lex_state = 15},
  [7332] = {.lex_state = 91, .external_lex_state = 15},
  [7333] = {.lex_state = 91, .external_lex_state = 2},
  [7334] = {.lex_state = 91, .external_lex_state = 15},
  [7335] = {.lex_state = 91, .external_lex_state = 15},
  [7336] = {.lex_state = 91, .external_lex_state = 15},
  [7337] = {.lex_state = 91, .external_lex_state = 2},
  [7338] = {.lex_state = 91, .external_lex_state = 21},
  [7339] = {.lex_state = 91, .external_lex_state = 15},
  [7340] = {.lex_state = 91, .external_lex_state = 2},
  [7341] = {.lex_state = 91, .external_lex_state = 15},
  [7342] = {.lex_state = 91, .external_lex_state = 15},
  [7343] = {.lex_state = 91, .external_lex_state = 15},
  [7344] = {.lex_state = 91, .external_lex_state = 15},
  [7345] = {.lex_state = 91, .external_lex_state = 15},
  [7346] = {.lex_state = 91, .external_lex_state = 15},
  [7347] = {.lex_state = 91, .external_lex_state = 23},
  [7348] = {.lex_state = 91, .external_lex_state = 21},
  [7349] = {.lex_state = 91, .external_lex_state = 15},
  [7350] = {.lex_state = 91, .external_lex_state = 21},
  [7351] = {.lex_state = 91, .external_lex_state = 15},
  [7352] = {.lex_state = 91, .external_lex_state = 15},
  [7353] = {.lex_state = 91, .external_lex_state = 23},
  [7354] = {.lex_state = 91, .external_lex_state = 15},
  [7355] = {.lex_state = 91, .external_lex_state = 15},
  [7356] = {.lex_state = 91, .external_lex_state = 23},
  [7357] = {.lex_state = 91, .external_lex_state = 15},
  [7358] = {.lex_state = 91, .external_lex_state = 15},
  [7359] = {.lex_state = 91, .external_lex_state = 15},
  [7360] = {.lex_state = 91, .external_lex_state = 15},
  [7361] = {.lex_state = 91, .external_lex_state = 15},
  [7362] = {.lex_state = 91, .external_lex_state = 15},
  [7363] = {.lex_state = 91, .external_lex_state = 15},
  [7364] = {.lex_state = 91, .external_lex_state = 23},
  [7365] = {.lex_state = 91, .external_lex_state = 15},
  [7366] = {.lex_state = 91, .external_lex_state = 15},
  [7367] = {.lex_state = 91, .external_lex_state = 2},
  [7368] = {.lex_state = 91, .external_lex_state = 2},
  [7369] = {.lex_state = 91, .external_lex_state = 15},
  [7370] = {.lex_state = 91, .external_lex_state = 15},
  [7371] = {.lex_state = 91, .external_lex_state = 15},
  [7372] = {.lex_state = 91, .external_lex_state = 15},
  [7373] = {.lex_state = 91, .external_lex_state = 15},
  [7374] = {.lex_state = 91, .external_lex_state = 15},
  [7375] = {.lex_state = 91, .external_lex_state = 15},
  [7376] = {.lex_state = 91, .external_lex_state = 15},
  [7377] = {.lex_state = 91, .external_lex_state = 15},
  [7378] = {.lex_state = 91, .external_lex_state = 15},
  [7379] = {.lex_state = 91, .external_lex_state = 15},
  [7380] = {.lex_state = 91, .external_lex_state = 15},
  [7381] = {.lex_state = 91, .external_lex_state = 15},
  [7382] = {.lex_state = 91, .external_lex_state = 15},
  [7383] = {.lex_state = 91, .external_lex_state = 15},
  [7384] = {.lex_state = 91, .external_lex_state = 15},
  [7385] = {.lex_state = 91, .external_lex_state = 21},
  [7386] = {.lex_state = 91, .external_lex_state = 21},
  [7387] = {.lex_state = 91, .external_lex_state = 21},
  [7388] = {.lex_state = 91, .external_lex_state = 23},
  [7389] = {.lex_state = 91, .external_lex_state = 23},
  [7390] = {.lex_state = 91, .external_lex_state = 23},
  [7391] = {.lex_state = 91, .external_lex_state = 21},
  [7392] = {.lex_state = 91, .external_lex_state = 21},
  [7393] = {.lex_state = 91, .external_lex_state = 21},
  [7394] = {.lex_state = 91, .external_lex_state = 21},
  [7395] = {.lex_state = 91, .external_lex_state = 23},
  [7396] = {.lex_state = 91, .external_lex_state = 21},
  [7397] = {.lex_state = 91, .external_lex_state = 21},
  [7398] = {.lex_state = 91, .external_lex_state = 21},
  [7399] = {.lex_state = 91, .external_lex_state = 21},
  [7400] = {.lex_state = 91, .external_lex_state = 21},
  [7401] = {.lex_state = 91, .external_lex_state = 21},
  [7402] = {.lex_state = 91, .external_lex_state = 21},
  [7403] = {.lex_state = 91, .external_lex_state = 21},
  [7404] = {.lex_state = 91, .external_lex_state = 21},
  [7405] = {.lex_state = 91, .external_lex_state = 21},
  [7406] = {.lex_state = 91, .external_lex_state = 21},
  [7407] = {.lex_state = 91, .external_lex_state = 23},
  [7408] = {.lex_state = 91},
  [7409] = {.lex_state = 91},
  [7410] = {.lex_state = 91},
  [7411] = {.lex_state = 91},
  [7412] = {.lex_state = 91},
  [7413] = {.lex_state = 91, .external_lex_state = 23},
  [7414] = {.lex_state = 91, .external_lex_state = 23},
  [7415] = {.lex_state = 91},
  [7416] = {.lex_state = 91, .external_lex_state = 23},
  [7417] = {.lex_state = 91, .external_lex_state = 23},
  [7418] = {.lex_state = 91, .external_lex_state = 23},
  [7419] = {.lex_state = 91},
  [7420] = {.lex_state = 91, .external_lex_state = 23},
  [7421] = {.lex_state = 91},
  [7422] = {.lex_state = 91, .external_lex_state = 23},
  [7423] = {.lex_state = 91},
  [7424] = {.lex_state = 91, .external_lex_state = 23},
  [7425] = {.lex_state = 91},
  [7426] = {.lex_state = 91, .external_lex_state = 23},
  [7427] = {.lex_state = 91, .external_lex_state = 23},
  [7428] = {.lex_state = 91},
  [7429] = {.lex_state = 91, .external_lex_state = 23},
  [7430] = {.lex_state = 91},
  [7431] = {.lex_state = 91, .external_lex_state = 23},
  [7432] = {.lex_state = 91},
  [7433] = {.lex_state = 91},
  [7434] = {.lex_state = 91, .external_lex_state = 23},
  [7435] = {.lex_state = 91},
  [7436] = {.lex_state = 91, .external_lex_state = 23},
  [7437] = {.lex_state = 91},
  [7438] = {.lex_state = 91},
  [7439] = {.lex_state = 91},
  [7440] = {.lex_state = 91, .external_lex_state = 23},
  [7441] = {.lex_state = 91},
  [7442] = {.lex_state = 91, .external_lex_state = 23},
  [7443] = {.lex_state = 91},
  [7444] = {.lex_state = 91, .external_lex_state = 11},
  [7445] = {.lex_state = 91, .external_lex_state = 23},
  [7446] = {.lex_state = 91, .external_lex_state = 23},
  [7447] = {.lex_state = 91},
  [7448] = {.lex_state = 91, .external_lex_state = 23},
  [7449] = {.lex_state = 91},
  [7450] = {.lex_state = 91},
  [7451] = {.lex_state = 91},
  [7452] = {.lex_state = 91, .external_lex_state = 23},
  [7453] = {.lex_state = 91, .external_lex_state = 23},
  [7454] = {.lex_state = 91},
  [7455] = {.lex_state = 91, .external_lex_state = 23},
  [7456] = {.lex_state = 91, .external_lex_state = 23},
  [7457] = {.lex_state = 91, .external_lex_state = 11},
  [7458] = {.lex_state = 91},
  [7459] = {.lex_state = 91},
  [7460] = {.lex_state = 91},
  [7461] = {.lex_state = 91},
  [7462] = {.lex_state = 91},
  [7463] = {.lex_state = 91},
  [7464] = {.lex_state = 91, .external_lex_state = 23},
  [7465] = {.lex_state = 91},
  [7466] = {.lex_state = 91, .external_lex_state = 23},
  [7467] = {.lex_state = 91},
  [7468] = {.lex_state = 91, .external_lex_state = 23},
  [7469] = {.lex_state = 91, .external_lex_state = 11},
  [7470] = {.lex_state = 91},
  [7471] = {.lex_state = 91},
  [7472] = {.lex_state = 91},
  [7473] = {.lex_state = 91, .external_lex_state = 26},
  [7474] = {.lex_state = 91},
  [7475] = {.lex_state = 91},
  [7476] = {.lex_state = 91, .external_lex_state = 26},
  [7477] = {.lex_state = 91},
  [7478] = {.lex_state = 91},
  [7479] = {.lex_state = 91},
  [7480] = {.lex_state = 91, .external_lex_state = 2},
  [7481] = {.lex_state = 91},
  [7482] = {.lex_state = 91},
  [7483] = {.lex_state = 91},
  [7484] = {.lex_state = 91, .external_lex_state = 26},
  [7485] = {.lex_state = 91},
  [7486] = {.lex_state = 91, .external_lex_state = 23},
  [7487] = {.lex_state = 91},
  [7488] = {.lex_state = 91},
  [7489] = {.lex_state = 91, .external_lex_state = 26},
  [7490] = {.lex_state = 91, .external_lex_state = 26},
  [7491] = {.lex_state = 91, .external_lex_state = 26},
  [7492] = {.lex_state = 91, .external_lex_state = 26},
  [7493] = {.lex_state = 91, .external_lex_state = 26},
  [7494] = {.lex_state = 91, .external_lex_state = 26},
  [7495] = {.lex_state = 91},
  [7496] = {.lex_state = 91, .external_lex_state = 27},
  [7497] = {.lex_state = 91, .external_lex_state = 26},
  [7498] = {.lex_state = 91, .external_lex_state = 26},
  [7499] = {.lex_state = 91, .external_lex_state = 26},
  [7500] = {.lex_state = 91, .external_lex_state = 26},
  [7501] = {.lex_state = 91, .external_lex_state = 26},
  [7502] = {.lex_state = 91, .external_lex_state = 26},
  [7503] = {.lex_state = 91, .external_lex_state = 26},
  [7504] = {.lex_state = 91, .external_lex_state = 26},
  [7505] = {.lex_state = 91, .external_lex_state = 26},
  [7506] = {.lex_state = 91, .external_lex_state = 26},
  [7507] = {.lex_state = 91, .external_lex_state = 26},
  [7508] = {.lex_state = 91},
  [7509] = {.lex_state = 91, .external_lex_state = 26},
  [7510] = {.lex_state = 91, .external_lex_state = 2},
  [7511] = {.lex_state = 91, .external_lex_state = 26},
  [7512] = {.lex_state = 91, .external_lex_state = 26},
  [7513] = {.lex_state = 91, .external_lex_state = 26},
  [7514] = {.lex_state = 91, .external_lex_state = 26},
  [7515] = {.lex_state = 91, .external_lex_state = 26},
  [7516] = {.lex_state = 91, .external_lex_state = 26},
  [7517] = {.lex_state = 91, .external_lex_state = 26},
  [7518] = {.lex_state = 91, .external_lex_state = 26},
  [7519] = {.lex_state = 91, .external_lex_state = 26},
  [7520] = {.lex_state = 91, .external_lex_state = 26},
  [7521] = {.lex_state = 91, .external_lex_state = 26},
  [7522] = {.lex_state = 91, .external_lex_state = 26},
  [7523] = {.lex_state = 91, .external_lex_state = 26},
  [7524] = {.lex_state = 91, .external_lex_state = 26},
  [7525] = {.lex_state = 91, .external_lex_state = 26},
  [7526] = {.lex_state = 91, .external_lex_state = 26},
  [7527] = {.lex_state = 91, .external_lex_state = 26},
  [7528] = {.lex_state = 91, .external_lex_state = 26},
  [7529] = {.lex_state = 91, .external_lex_state = 26},
  [7530] = {.lex_state = 91, .external_lex_state = 26},
  [7531] = {.lex_state = 91, .external_lex_state = 26},
  [7532] = {.lex_state = 91, .external_lex_state = 26},
  [7533] = {.lex_state = 91, .external_lex_state = 26},
  [7534] = {.lex_state = 91, .external_lex_state = 26},
  [7535] = {.lex_state = 91},
  [7536] = {.lex_state = 91, .external_lex_state = 26},
  [7537] = {.lex_state = 91, .external_lex_state = 26},
  [7538] = {.lex_state = 91, .external_lex_state = 27},
  [7539] = {.lex_state = 91, .external_lex_state = 26},
  [7540] = {.lex_state = 91, .external_lex_state = 26},
  [7541] = {.lex_state = 91, .external_lex_state = 27},
  [7542] = {.lex_state = 91, .external_lex_state = 26},
  [7543] = {.lex_state = 91, .external_lex_state = 26},
  [7544] = {.lex_state = 91, .external_lex_state = 26},
  [7545] = {.lex_state = 91, .external_lex_state = 26},
  [7546] = {.lex_state = 91, .external_lex_state = 23},
  [7547] = {.lex_state = 91, .external_lex_state = 23},
  [7548] = {.lex_state = 91, .external_lex_state = 23},
  [7549] = {.lex_state = 91, .external_lex_state = 2},
  [7550] = {.lex_state = 91, .external_lex_state = 26},
  [7551] = {.lex_state = 91, .external_lex_state = 26},
  [7552] = {.lex_state = 91, .external_lex_state = 26},
  [7553] = {.lex_state = 91, .external_lex_state = 26},
  [7554] = {.lex_state = 91, .external_lex_state = 26},
  [7555] = {.lex_state = 91, .external_lex_state = 26},
  [7556] = {.lex_state = 91, .external_lex_state = 2},
  [7557] = {.lex_state = 91, .external_lex_state = 26},
  [7558] = {.lex_state = 91, .external_lex_state = 27},
  [7559] = {.lex_state = 91, .external_lex_state = 27},
  [7560] = {.lex_state = 91, .external_lex_state = 2},
  [7561] = {.lex_state = 91, .external_lex_state = 27},
  [7562] = {.lex_state = 91, .external_lex_state = 27},
  [7563] = {.lex_state = 91},
  [7564] = {.lex_state = 91, .external_lex_state = 2},
  [7565] = {.lex_state = 91, .external_lex_state = 27},
  [7566] = {.lex_state = 91, .external_lex_state = 27},
  [7567] = {.lex_state = 91, .external_lex_state = 27},
  [7568] = {.lex_state = 91, .external_lex_state = 27},
  [7569] = {.lex_state = 91, .external_lex_state = 27},
  [7570] = {.lex_state = 91, .external_lex_state = 27},
  [7571] = {.lex_state = 91, .external_lex_state = 27},
  [7572] = {.lex_state = 91, .external_lex_state = 27},
  [7573] = {.lex_state = 91},
  [7574] = {.lex_state = 91, .external_lex_state = 27},
  [7575] = {.lex_state = 91, .external_lex_state = 27},
  [7576] = {.lex_state = 91, .external_lex_state = 2},
  [7577] = {.lex_state = 91, .external_lex_state = 27},
  [7578] = {.lex_state = 91, .external_lex_state = 27},
  [7579] = {.lex_state = 91, .external_lex_state = 27},
  [7580] = {.lex_state = 91, .external_lex_state = 2},
  [7581] = {.lex_state = 91, .external_lex_state = 27},
  [7582] = {.lex_state = 91, .external_lex_state = 27},
  [7583] = {.lex_state = 91, .external_lex_state = 2},
  [7584] = {.lex_state = 91, .external_lex_state = 27},
  [7585] = {.lex_state = 91, .external_lex_state = 27},
  [7586] = {.lex_state = 91, .external_lex_state = 27},
  [7587] = {.lex_state = 91, .external_lex_state = 27},
  [7588] = {.lex_state = 91, .external_lex_state = 27},
  [7589] = {.lex_state = 91, .external_lex_state = 27},
  [7590] = {.lex_state = 91, .external_lex_state = 27},
  [7591] = {.lex_state = 91, .external_lex_state = 27},
  [7592] = {.lex_state = 91, .external_lex_state = 2},
  [7593] = {.lex_state = 91, .external_lex_state = 27},
  [7594] = {.lex_state = 91, .external_lex_state = 27},
  [7595] = {.lex_state = 91, .external_lex_state = 27},
  [7596] = {.lex_state = 91, .external_lex_state = 27},
  [7597] = {.lex_state = 91, .external_lex_state = 27},
  [7598] = {.lex_state = 91, .external_lex_state = 27},
  [7599] = {.lex_state = 91, .external_lex_state = 27},
  [7600] = {.lex_state = 91, .external_lex_state = 27},
  [7601] = {.lex_state = 91, .external_lex_state = 27},
  [7602] = {.lex_state = 91, .external_lex_state = 27},
  [7603] = {.lex_state = 91, .external_lex_state = 27},
  [7604] = {.lex_state = 91, .external_lex_state = 27},
  [7605] = {.lex_state = 91, .external_lex_state = 27},
  [7606] = {.lex_state = 91, .external_lex_state = 27},
  [7607] = {.lex_state = 91, .external_lex_state = 2},
  [7608] = {.lex_state = 91, .external_lex_state = 27},
  [7609] = {.lex_state = 91, .external_lex_state = 27},
  [7610] = {.lex_state = 91, .external_lex_state = 27},
  [7611] = {.lex_state = 91, .external_lex_state = 27},
  [7612] = {.lex_state = 91, .external_lex_state = 2},
  [7613] = {.lex_state = 91, .external_lex_state = 2},
  [7614] = {.lex_state = 91, .external_lex_state = 27},
  [7615] = {.lex_state = 91, .external_lex_state = 27},
  [7616] = {.lex_state = 91, .external_lex_state = 27},
  [7617] = {.lex_state = 91, .external_lex_state = 27},
  [7618] = {.lex_state = 91, .external_lex_state = 27},
  [7619] = {.lex_state = 91, .external_lex_state = 2},
  [7620] = {.lex_state = 91, .external_lex_state = 27},
  [7621] = {.lex_state = 91, .external_lex_state = 27},
  [7622] = {.lex_state = 91, .external_lex_state = 27},
  [7623] = {.lex_state = 91, .external_lex_state = 2},
  [7624] = {.lex_state = 91, .external_lex_state = 2},
  [7625] = {.lex_state = 91, .external_lex_state = 27},
  [7626] = {.lex_state = 91, .external_lex_state = 2},
  [7627] = {.lex_state = 91, .external_lex_state = 27},
  [7628] = {.lex_state = 91, .external_lex_state = 27},
  [7629] = {.lex_state = 91, .external_lex_state = 11},
  [7630] = {.lex_state = 91, .external_lex_state = 27},
  [7631] = {.lex_state = 91},
  [7632] = {.lex_state = 91, .external_lex_state = 23},
  [7633] = {.lex_state = 91, .external_lex_state = 23},
  [7634] = {.lex_state = 91, .external_lex_state = 24},
  [7635] = {.lex_state = 91, .external_lex_state = 24},
  [7636] = {.lex_state = 91, .external_lex_state = 24},
  [7637] = {.lex_state = 91, .external_lex_state = 24},
  [7638] = {.lex_state = 91, .external_lex_state = 24},
  [7639] = {.lex_state = 91},
  [7640] = {.lex_state = 6},
  [7641] = {.lex_state = 6},
  [7642] = {.lex_state = 91, .external_lex_state = 11},
  [7643] = {.lex_state = 6},
  [7644] = {.lex_state = 91, .external_lex_state = 24},
  [7645] = {.lex_state = 91, .external_lex_state = 24},
  [7646] = {.lex_state = 91, .external_lex_state = 23},
  [7647] = {.lex_state = 91, .external_lex_state = 23},
  [7648] = {.lex_state = 91, .external_lex_state = 24},
  [7649] = {.lex_state = 91, .external_lex_state = 24},
  [7650] = {.lex_state = 91, .external_lex_state = 2},
  [7651] = {.lex_state = 6},
  [7652] = {.lex_state = 91, .external_lex_state = 24},
  [7653] = {.lex_state = 91, .external_lex_state = 24},
  [7654] = {.lex_state = 91, .external_lex_state = 23},
  [7655] = {.lex_state = 91, .external_lex_state = 24},
  [7656] = {.lex_state = 91, .external_lex_state = 24},
  [7657] = {.lex_state = 91, .external_lex_state = 11},
  [7658] = {.lex_state = 91, .external_lex_state = 24},
  [7659] = {.lex_state = 91, .external_lex_state = 23},
  [7660] = {.lex_state = 91, .external_lex_state = 23},
  [7661] = {.lex_state = 11, .external_lex_state = 23},
  [7662] = {.lex_state = 91, .external_lex_state = 24},
  [7663] = {.lex_state = 91, .external_lex_state = 24},
  [7664] = {.lex_state = 5},
  [7665] = {.lex_state = 91, .external_lex_state = 24},
  [7666] = {.lex_state = 91, .external_lex_state = 24},
  [7667] = {.lex_state = 91, .external_lex_state = 2},
  [7668] = {.lex_state = 0, .external_lex_state = 23},
  [7669] = {.lex_state = 91, .external_lex_state = 24},
  [7670] = {.lex_state = 91, .external_lex_state = 24},
  [7671] = {.lex_state = 91, .external_lex_state = 2},
  [7672] = {.lex_state = 91, .external_lex_state = 2},
  [7673] = {.lex_state = 6},
  [7674] = {.lex_state = 91, .external_lex_state = 23},
  [7675] = {.lex_state = 6},
  [7676] = {.lex_state = 91, .external_lex_state = 24},
  [7677] = {.lex_state = 91, .external_lex_state = 2},
  [7678] = {.lex_state = 11, .external_lex_state = 23},
  [7679] = {.lex_state = 91, .external_lex_state = 24},
  [7680] = {.lex_state = 91, .external_lex_state = 24},
  [7681] = {.lex_state = 91, .external_lex_state = 24},
  [7682] = {.lex_state = 91, .external_lex_state = 24},
  [7683] = {.lex_state = 91, .external_lex_state = 24},
  [7684] = {.lex_state = 91, .external_lex_state = 24},
  [7685] = {.lex_state = 6},
  [7686] = {.lex_state = 91, .external_lex_state = 24},
  [7687] = {.lex_state = 91, .external_lex_state = 2},
  [7688] = {.lex_state = 91, .external_lex_state = 24},
  [7689] = {.lex_state = 91, .external_lex_state = 23},
  [7690] = {.lex_state = 91, .external_lex_state = 11},
  [7691] = {.lex_state = 91, .external_lex_state = 24},
  [7692] = {.lex_state = 6},
  [7693] = {.lex_state = 91, .external_lex_state = 24},
  [7694] = {.lex_state = 91, .external_lex_state = 24},
  [7695] = {.lex_state = 91, .external_lex_state = 2},
  [7696] = {.lex_state = 91, .external_lex_state = 24},
  [7697] = {.lex_state = 5},
  [7698] = {.lex_state = 6},
  [7699] = {.lex_state = 91, .external_lex_state = 2},
  [7700] = {.lex_state = 91, .external_lex_state = 24},
  [7701] = {.lex_state = 91, .external_lex_state = 23},
  [7702] = {.lex_state = 91, .external_lex_state = 11},
  [7703] = {.lex_state = 91, .external_lex_state = 2},
  [7704] = {.lex_state = 91, .external_lex_state = 24},
  [7705] = {.lex_state = 91, .external_lex_state = 24},
  [7706] = {.lex_state = 91, .external_lex_state = 23},
  [7707] = {.lex_state = 91, .external_lex_state = 24},
  [7708] = {.lex_state = 91, .external_lex_state = 24},
  [7709] = {.lex_state = 6},
  [7710] = {.lex_state = 91, .external_lex_state = 11},
  [7711] = {.lex_state = 2, .external_lex_state = 23},
  [7712] = {.lex_state = 91, .external_lex_state = 24},
  [7713] = {.lex_state = 91, .external_lex_state = 24},
  [7714] = {.lex_state = 91, .external_lex_state = 24},
  [7715] = {.lex_state = 91, .external_lex_state = 24},
  [7716] = {.lex_state = 6},
  [7717] = {.lex_state = 91, .external_lex_state = 24},
  [7718] = {.lex_state = 91, .external_lex_state = 24},
  [7719] = {.lex_state = 91, .external_lex_state = 23},
  [7720] = {.lex_state = 91, .external_lex_state = 24},
  [7721] = {.lex_state = 6},
  [7722] = {.lex_state = 91, .external_lex_state = 24},
  [7723] = {.lex_state = 91, .external_lex_state = 2},
  [7724] = {.lex_state = 91, .external_lex_state = 24},
  [7725] = {.lex_state = 91, .external_lex_state = 23},
  [7726] = {.lex_state = 91},
  [7727] = {.lex_state = 91, .external_lex_state = 24},
  [7728] = {.lex_state = 91, .external_lex_state = 24},
  [7729] = {.lex_state = 91, .external_lex_state = 2},
  [7730] = {.lex_state = 91, .external_lex_state = 24},
  [7731] = {.lex_state = 91, .external_lex_state = 24},
  [7732] = {.lex_state = 91, .external_lex_state = 11},
  [7733] = {.lex_state = 91, .external_lex_state = 24},
  [7734] = {.lex_state = 91, .external_lex_state = 24},
  [7735] = {.lex_state = 91, .external_lex_state = 24},
  [7736] = {.lex_state = 91, .external_lex_state = 24},
  [7737] = {.lex_state = 0, .external_lex_state = 23},
  [7738] = {.lex_state = 11, .external_lex_state = 23},
  [7739] = {.lex_state = 91, .external_lex_state = 24},
  [7740] = {.lex_state = 91, .external_lex_state = 24},
  [7741] = {.lex_state = 91, .external_lex_state = 24},
  [7742] = {.lex_state = 5},
  [7743] = {.lex_state = 91, .external_lex_state = 24},
  [7744] = {.lex_state = 91, .external_lex_state = 2},
  [7745] = {.lex_state = 91, .external_lex_state = 2},
  [7746] = {.lex_state = 91, .external_lex_state = 24},
  [7747] = {.lex_state = 91, .external_lex_state = 11},
  [7748] = {.lex_state = 91, .external_lex_state = 24},
  [7749] = {.lex_state = 91, .external_lex_state = 2},
  [7750] = {.lex_state = 91, .external_lex_state = 23},
  [7751] = {.lex_state = 91, .external_lex_state = 23},
  [7752] = {.lex_state = 6},
  [7753] = {.lex_state = 91, .external_lex_state = 24},
  [7754] = {.lex_state = 91, .external_lex_state = 24},
  [7755] = {.lex_state = 91, .external_lex_state = 24},
  [7756] = {.lex_state = 91, .external_lex_state = 24},
  [7757] = {.lex_state = 91, .external_lex_state = 24},
  [7758] = {.lex_state = 91, .external_lex_state = 24},
  [7759] = {.lex_state = 91, .external_lex_state = 24},
  [7760] = {.lex_state = 91, .external_lex_state = 24},
  [7761] = {.lex_state = 91, .external_lex_state = 24},
  [7762] = {.lex_state = 91, .external_lex_state = 2},
  [7763] = {.lex_state = 91, .external_lex_state = 2},
  [7764] = {.lex_state = 91, .external_lex_state = 24},
  [7765] = {.lex_state = 91, .external_lex_state = 24},
  [7766] = {.lex_state = 91, .external_lex_state = 2},
  [7767] = {.lex_state = 91, .external_lex_state = 24},
  [7768] = {.lex_state = 91, .external_lex_state = 24},
  [7769] = {.lex_state = 11, .external_lex_state = 23},
  [7770] = {.lex_state = 91, .external_lex_state = 24},
  [7771] = {.lex_state = 6},
  [7772] = {.lex_state = 91, .external_lex_state = 2},
  [7773] = {.lex_state = 91, .external_lex_state = 2},
  [7774] = {.lex_state = 91, .external_lex_state = 24},
  [7775] = {.lex_state = 91, .external_lex_state = 24},
  [7776] = {.lex_state = 91, .external_lex_state = 24},
  [7777] = {.lex_state = 91, .external_lex_state = 24},
  [7778] = {.lex_state = 91, .external_lex_state = 24},
  [7779] = {.lex_state = 0, .external_lex_state = 23},
  [7780] = {.lex_state = 0, .external_lex_state = 23},
  [7781] = {.lex_state = 91, .external_lex_state = 11},
  [7782] = {.lex_state = 0, .external_lex_state = 23},
  [7783] = {.lex_state = 0, .external_lex_state = 23},
  [7784] = {.lex_state = 91, .external_lex_state = 24},
  [7785] = {.lex_state = 91, .external_lex_state = 11},
  [7786] = {.lex_state = 0, .external_lex_state = 23},
  [7787] = {.lex_state = 0, .external_lex_state = 23},
  [7788] = {.lex_state = 0, .external_lex_state = 23},
  [7789] = {.lex_state = 0, .external_lex_state = 23},
  [7790] = {.lex_state = 0, .external_lex_state = 23},
  [7791] = {.lex_state = 91, .external_lex_state = 24},
  [7792] = {.lex_state = 91, .external_lex_state = 24},
  [7793] = {.lex_state = 91, .external_lex_state = 11},
  [7794] = {.lex_state = 91, .external_lex_state = 11},
  [7795] = {.lex_state = 0, .external_lex_state = 23},
  [7796] = {.lex_state = 0, .external_lex_state = 23},
  [7797] = {.lex_state = 6},
  [7798] = {.lex_state = 6},
  [7799] = {.lex_state = 91, .external_lex_state = 24},
  [7800] = {.lex_state = 91, .external_lex_state = 24},
  [7801] = {.lex_state = 0, .external_lex_state = 23},
  [7802] = {.lex_state = 0, .external_lex_state = 23},
  [7803] = {.lex_state = 91, .external_lex_state = 24},
  [7804] = {.lex_state = 91, .external_lex_state = 24},
  [7805] = {.lex_state = 91, .external_lex_state = 11},
  [7806] = {.lex_state = 91, .external_lex_state = 11},
  [7807] = {.lex_state = 91, .external_lex_state = 24},
  [7808] = {.lex_state = 0, .external_lex_state = 23},
  [7809] = {.lex_state = 0, .external_lex_state = 23},
  [7810] = {.lex_state = 91, .external_lex_state = 24},
  [7811] = {.lex_state = 91, .external_lex_state = 24},
  [7812] = {.lex_state = 91, .external_lex_state = 24},
  [7813] = {.lex_state = 91, .external_lex_state = 24},
  [7814] = {.lex_state = 91, .external_lex_state = 11},
  [7815] = {.lex_state = 91, .external_lex_state = 24},
  [7816] = {.lex_state = 91, .external_lex_state = 24},
  [7817] = {.lex_state = 0, .external_lex_state = 23},
  [7818] = {.lex_state = 0, .external_lex_state = 23},
  [7819] = {.lex_state = 0, .external_lex_state = 23},
  [7820] = {.lex_state = 91, .external_lex_state = 24},
  [7821] = {.lex_state = 0, .external_lex_state = 23},
  [7822] = {.lex_state = 91, .external_lex_state = 24},
  [7823] = {.lex_state = 91, .external_lex_state = 24},
  [7824] = {.lex_state = 91, .external_lex_state = 24},
  [7825] = {.lex_state = 91, .external_lex_state = 24},
  [7826] = {.lex_state = 0, .external_lex_state = 23},
  [7827] = {.lex_state = 0, .external_lex_state = 23},
  [7828] = {.lex_state = 91, .external_lex_state = 24},
  [7829] = {.lex_state = 91, .external_lex_state = 24},
  [7830] = {.lex_state = 0, .external_lex_state = 23},
  [7831] = {.lex_state = 91},
  [7832] = {.lex_state = 0, .external_lex_state = 23},
  [7833] = {.lex_state = 0, .external_lex_state = 23},
  [7834] = {.lex_state = 0, .external_lex_state = 23},
  [7835] = {.lex_state = 0, .external_lex_state = 23},
  [7836] = {.lex_state = 0, .external_lex_state = 23},
  [7837] = {.lex_state = 0, .external_lex_state = 23},
  [7838] = {.lex_state = 0, .external_lex_state = 23},
  [7839] = {.lex_state = 91, .external_lex_state = 24},
  [7840] = {.lex_state = 0, .external_lex_state = 23},
  [7841] = {.lex_state = 0, .external_lex_state = 23},
  [7842] = {.lex_state = 0, .external_lex_state = 23},
  [7843] = {.lex_state = 0, .external_lex_state = 23},
  [7844] = {.lex_state = 91, .external_lex_state = 24},
  [7845] = {.lex_state = 91},
  [7846] = {.lex_state = 0, .external_lex_state = 23},
  [7847] = {.lex_state = 0, .external_lex_state = 23},
  [7848] = {.lex_state = 0, .external_lex_state = 23},
  [7849] = {.lex_state = 0, .external_lex_state = 23},
  [7850] = {.lex_state = 0, .external_lex_state = 23},
  [7851] = {.lex_state = 91, .external_lex_state = 2},
  [7852] = {.lex_state = 6},
  [7853] = {.lex_state = 6},
  [7854] = {.lex_state = 91, .external_lex_state = 2},
  [7855] = {.lex_state = 0, .external_lex_state = 23},
  [7856] = {.lex_state = 0, .external_lex_state = 23},
  [7857] = {.lex_state = 0, .external_lex_state = 23},
  [7858] = {.lex_state = 11, .external_lex_state = 23},
  [7859] = {.lex_state = 6},
  [7860] = {.lex_state = 6},
  [7861] = {.lex_state = 91, .external_lex_state = 2},
  [7862] = {.lex_state = 91, .external_lex_state = 2},
  [7863] = {.lex_state = 0, .external_lex_state = 23},
  [7864] = {.lex_state = 0, .external_lex_state = 23},
  [7865] = {.lex_state = 91, .external_lex_state = 2},
  [7866] = {.lex_state = 91, .external_lex_state = 2},
  [7867] = {.lex_state = 91, .external_lex_state = 24},
  [7868] = {.lex_state = 0, .external_lex_state = 23},
  [7869] = {.lex_state = 0, .external_lex_state = 23},
  [7870] = {.lex_state = 0, .external_lex_state = 23},
  [7871] = {.lex_state = 91, .external_lex_state = 24},
  [7872] = {.lex_state = 91, .external_lex_state = 24},
  [7873] = {.lex_state = 91, .external_lex_state = 24},
  [7874] = {.lex_state = 0, .external_lex_state = 23},
  [7875] = {.lex_state = 91, .external_lex_state = 24},
  [7876] = {.lex_state = 91, .external_lex_state = 24},
  [7877] = {.lex_state = 91, .external_lex_state = 24},
  [7878] = {.lex_state = 91, .external_lex_state = 24},
  [7879] = {.lex_state = 91, .external_lex_state = 24},
  [7880] = {.lex_state = 91, .external_lex_state = 24},
  [7881] = {.lex_state = 91, .external_lex_state = 24},
  [7882] = {.lex_state = 6},
  [7883] = {.lex_state = 6},
  [7884] = {.lex_state = 0, .external_lex_state = 23},
  [7885] = {.lex_state = 0, .external_lex_state = 23},
  [7886] = {.lex_state = 91, .external_lex_state = 24},
  [7887] = {.lex_state = 91, .external_lex_state = 24},
  [7888] = {.lex_state = 0, .external_lex_state = 23},
  [7889] = {.lex_state = 91, .external_lex_state = 24},
  [7890] = {.lex_state = 91, .external_lex_state = 24},
  [7891] = {.lex_state = 0, .external_lex_state = 23},
  [7892] = {.lex_state = 91, .external_lex_state = 24},
  [7893] = {.lex_state = 91, .external_lex_state = 24},
  [7894] = {.lex_state = 91, .external_lex_state = 24},
  [7895] = {.lex_state = 0, .external_lex_state = 23},
  [7896] = {.lex_state = 0, .external_lex_state = 23},
  [7897] = {.lex_state = 91, .external_lex_state = 24},
  [7898] = {.lex_state = 91, .external_lex_state = 24},
  [7899] = {.lex_state = 91, .external_lex_state = 24},
  [7900] = {.lex_state = 0, .external_lex_state = 23},
  [7901] = {.lex_state = 0, .external_lex_state = 23},
  [7902] = {.lex_state = 0, .external_lex_state = 23},
  [7903] = {.lex_state = 91, .external_lex_state = 11},
  [7904] = {.lex_state = 91, .external_lex_state = 11},
  [7905] = {.lex_state = 91, .external_lex_state = 24},
  [7906] = {.lex_state = 91, .external_lex_state = 24},
  [7907] = {.lex_state = 0, .external_lex_state = 23},
  [7908] = {.lex_state = 6},
  [7909] = {.lex_state = 6},
  [7910] = {.lex_state = 0, .external_lex_state = 23},
  [7911] = {.lex_state = 91, .external_lex_state = 24},
  [7912] = {.lex_state = 91, .external_lex_state = 24},
  [7913] = {.lex_state = 0, .external_lex_state = 23},
  [7914] = {.lex_state = 0, .external_lex_state = 23},
  [7915] = {.lex_state = 0, .external_lex_state = 23},
  [7916] = {.lex_state = 0, .external_lex_state = 23},
  [7917] = {.lex_state = 0, .external_lex_state = 23},
  [7918] = {.lex_state = 0, .external_lex_state = 23},
  [7919] = {.lex_state = 0, .external_lex_state = 23},
  [7920] = {.lex_state = 0, .external_lex_state = 23},
  [7921] = {.lex_state = 0, .external_lex_state = 23},
  [7922] = {.lex_state = 0, .external_lex_state = 23},
  [7923] = {.lex_state = 6},
  [7924] = {.lex_state = 6},
  [7925] = {.lex_state = 91, .external_lex_state = 2},
  [7926] = {.lex_state = 91, .external_lex_state = 2},
  [7927] = {.lex_state = 0, .external_lex_state = 23},
  [7928] = {.lex_state = 0, .external_lex_state = 23},
  [7929] = {.lex_state = 0, .external_lex_state = 23},
  [7930] = {.lex_state = 91, .external_lex_state = 2},
  [7931] = {.lex_state = 91, .external_lex_state = 2},
  [7932] = {.lex_state = 91, .external_lex_state = 24},
  [7933] = {.lex_state = 0, .external_lex_state = 23},
  [7934] = {.lex_state = 0, .external_lex_state = 23},
  [7935] = {.lex_state = 0, .external_lex_state = 23},
  [7936] = {.lex_state = 91, .external_lex_state = 24},
  [7937] = {.lex_state = 0, .external_lex_state = 23},
  [7938] = {.lex_state = 91, .external_lex_state = 24},
  [7939] = {.lex_state = 91, .external_lex_state = 24},
  [7940] = {.lex_state = 91, .external_lex_state = 24},
  [7941] = {.lex_state = 91, .external_lex_state = 24},
  [7942] = {.lex_state = 0, .external_lex_state = 23},
  [7943] = {.lex_state = 91, .external_lex_state = 24},
  [7944] = {.lex_state = 91, .external_lex_state = 24},
  [7945] = {.lex_state = 91, .external_lex_state = 24},
  [7946] = {.lex_state = 0, .external_lex_state = 23},
  [7947] = {.lex_state = 0, .external_lex_state = 23},
  [7948] = {.lex_state = 91, .external_lex_state = 24},
  [7949] = {.lex_state = 91, .external_lex_state = 24},
  [7950] = {.lex_state = 91, .external_lex_state = 24},
  [7951] = {.lex_state = 91, .external_lex_state = 24},
  [7952] = {.lex_state = 91, .external_lex_state = 24},
  [7953] = {.lex_state = 0, .external_lex_state = 23},
  [7954] = {.lex_state = 91, .external_lex_state = 24},
  [7955] = {.lex_state = 0, .external_lex_state = 23},
  [7956] = {.lex_state = 0, .external_lex_state = 23},
  [7957] = {.lex_state = 0, .external_lex_state = 23},
  [7958] = {.lex_state = 0, .external_lex_state = 23},
  [7959] = {.lex_state = 91, .external_lex_state = 24},
  [7960] = {.lex_state = 91, .external_lex_state = 24},
  [7961] = {.lex_state = 91, .external_lex_state = 24},
  [7962] = {.lex_state = 91, .external_lex_state = 24},
  [7963] = {.lex_state = 91, .external_lex_state = 24},
  [7964] = {.lex_state = 91, .external_lex_state = 24},
  [7965] = {.lex_state = 91, .external_lex_state = 24},
  [7966] = {.lex_state = 91, .external_lex_state = 24},
  [7967] = {.lex_state = 6},
  [7968] = {.lex_state = 6},
  [7969] = {.lex_state = 0, .external_lex_state = 23},
  [7970] = {.lex_state = 91, .external_lex_state = 23},
  [7971] = {.lex_state = 0, .external_lex_state = 23},
  [7972] = {.lex_state = 0, .external_lex_state = 23},
  [7973] = {.lex_state = 0, .external_lex_state = 23},
  [7974] = {.lex_state = 6},
  [7975] = {.lex_state = 6},
  [7976] = {.lex_state = 0, .external_lex_state = 23},
  [7977] = {.lex_state = 0, .external_lex_state = 23},
  [7978] = {.lex_state = 0, .external_lex_state = 23},
  [7979] = {.lex_state = 0, .external_lex_state = 23},
  [7980] = {.lex_state = 91, .external_lex_state = 24},
  [7981] = {.lex_state = 91, .external_lex_state = 2},
  [7982] = {.lex_state = 91, .external_lex_state = 2},
  [7983] = {.lex_state = 0, .external_lex_state = 23},
  [7984] = {.lex_state = 0, .external_lex_state = 23},
  [7985] = {.lex_state = 91, .external_lex_state = 2},
  [7986] = {.lex_state = 91, .external_lex_state = 2},
  [7987] = {.lex_state = 91, .external_lex_state = 24},
  [7988] = {.lex_state = 0, .external_lex_state = 23},
  [7989] = {.lex_state = 0, .external_lex_state = 23},
  [7990] = {.lex_state = 0, .external_lex_state = 23},
  [7991] = {.lex_state = 91, .external_lex_state = 24},
  [7992] = {.lex_state = 91, .external_lex_state = 24},
  [7993] = {.lex_state = 91, .external_lex_state = 24},
  [7994] = {.lex_state = 91, .external_lex_state = 24},
  [7995] = {.lex_state = 91, .external_lex_state = 24},
  [7996] = {.lex_state = 91, .external_lex_state = 24},
  [7997] = {.lex_state = 91, .external_lex_state = 24},
  [7998] = {.lex_state = 91, .external_lex_state = 24},
  [7999] = {.lex_state = 0, .external_lex_state = 23},
  [8000] = {.lex_state = 91, .external_lex_state = 24},
  [8001] = {.lex_state = 91, .external_lex_state = 24},
  [8002] = {.lex_state = 91, .external_lex_state = 24},
  [8003] = {.lex_state = 91, .external_lex_state = 24},
  [8004] = {.lex_state = 91, .external_lex_state = 24},
  [8005] = {.lex_state = 0, .external_lex_state = 23},
  [8006] = {.lex_state = 91, .external_lex_state = 24},
  [8007] = {.lex_state = 91, .external_lex_state = 24},
  [8008] = {.lex_state = 91, .external_lex_state = 24},
  [8009] = {.lex_state = 91, .external_lex_state = 24},
  [8010] = {.lex_state = 91, .external_lex_state = 24},
  [8011] = {.lex_state = 0, .external_lex_state = 23},
  [8012] = {.lex_state = 0, .external_lex_state = 23},
  [8013] = {.lex_state = 0, .external_lex_state = 23},
  [8014] = {.lex_state = 6},
  [8015] = {.lex_state = 6},
  [8016] = {.lex_state = 0, .external_lex_state = 23},
  [8017] = {.lex_state = 91, .external_lex_state = 24},
  [8018] = {.lex_state = 0, .external_lex_state = 23},
  [8019] = {.lex_state = 91, .external_lex_state = 24},
  [8020] = {.lex_state = 0, .external_lex_state = 23},
  [8021] = {.lex_state = 91, .external_lex_state = 24},
  [8022] = {.lex_state = 91, .external_lex_state = 24},
  [8023] = {.lex_state = 91, .external_lex_state = 24},
  [8024] = {.lex_state = 91, .external_lex_state = 24},
  [8025] = {.lex_state = 91, .external_lex_state = 24},
  [8026] = {.lex_state = 0, .external_lex_state = 23},
  [8027] = {.lex_state = 91, .external_lex_state = 24},
  [8028] = {.lex_state = 0, .external_lex_state = 23},
  [8029] = {.lex_state = 0, .external_lex_state = 23},
  [8030] = {.lex_state = 0, .external_lex_state = 23},
  [8031] = {.lex_state = 0, .external_lex_state = 23},
  [8032] = {.lex_state = 0, .external_lex_state = 23},
  [8033] = {.lex_state = 91, .external_lex_state = 24},
  [8034] = {.lex_state = 0, .external_lex_state = 23},
  [8035] = {.lex_state = 91, .external_lex_state = 24},
  [8036] = {.lex_state = 91},
  [8037] = {.lex_state = 91, .external_lex_state = 24},
  [8038] = {.lex_state = 91, .external_lex_state = 24},
  [8039] = {.lex_state = 91, .external_lex_state = 24},
  [8040] = {.lex_state = 91, .external_lex_state = 24},
  [8041] = {.lex_state = 91, .external_lex_state = 24},
  [8042] = {.lex_state = 0, .external_lex_state = 23},
  [8043] = {.lex_state = 91, .external_lex_state = 24},
  [8044] = {.lex_state = 0, .external_lex_state = 23},
  [8045] = {.lex_state = 91, .external_lex_state = 24},
  [8046] = {.lex_state = 0, .external_lex_state = 23},
  [8047] = {.lex_state = 91, .external_lex_state = 24},
  [8048] = {.lex_state = 91},
  [8049] = {.lex_state = 91, .external_lex_state = 24},
  [8050] = {.lex_state = 91, .external_lex_state = 24},
  [8051] = {.lex_state = 91, .external_lex_state = 24},
  [8052] = {.lex_state = 91, .external_lex_state = 24},
  [8053] = {.lex_state = 91, .external_lex_state = 24},
  [8054] = {.lex_state = 91, .external_lex_state = 24},
  [8055] = {.lex_state = 91, .external_lex_state = 24},
  [8056] = {.lex_state = 91, .external_lex_state = 24},
  [8057] = {.lex_state = 91, .external_lex_state = 24},
  [8058] = {.lex_state = 91, .external_lex_state = 24},
  [8059] = {.lex_state = 91, .external_lex_state = 24},
  [8060] = {.lex_state = 91, .external_lex_state = 24},
  [8061] = {.lex_state = 91, .external_lex_state = 24},
  [8062] = {.lex_state = 91, .external_lex_state = 24},
  [8063] = {.lex_state = 91, .external_lex_state = 24},
  [8064] = {.lex_state = 91, .external_lex_state = 24},
  [8065] = {.lex_state = 91, .external_lex_state = 24},
  [8066] = {.lex_state = 91, .external_lex_state = 24},
  [8067] = {.lex_state = 0, .external_lex_state = 23},
  [8068] = {.lex_state = 91, .external_lex_state = 2},
  [8069] = {.lex_state = 0, .external_lex_state = 23},
  [8070] = {.lex_state = 91, .external_lex_state = 2},
  [8071] = {.lex_state = 0, .external_lex_state = 23},
  [8072] = {.lex_state = 0, .external_lex_state = 23},
  [8073] = {.lex_state = 0, .external_lex_state = 23},
  [8074] = {.lex_state = 0, .external_lex_state = 23},
  [8075] = {.lex_state = 91},
  [8076] = {.lex_state = 6},
  [8077] = {.lex_state = 6},
  [8078] = {.lex_state = 0, .external_lex_state = 23},
  [8079] = {.lex_state = 91, .external_lex_state = 23},
  [8080] = {.lex_state = 91},
  [8081] = {.lex_state = 0, .external_lex_state = 23},
  [8082] = {.lex_state = 0, .external_lex_state = 23},
  [8083] = {.lex_state = 0, .external_lex_state = 23},
  [8084] = {.lex_state = 91, .external_lex_state = 24},
  [8085] = {.lex_state = 91, .external_lex_state = 24},
  [8086] = {.lex_state = 0, .external_lex_state = 23},
  [8087] = {.lex_state = 0, .external_lex_state = 23},
  [8088] = {.lex_state = 91, .external_lex_state = 11},
  [8089] = {.lex_state = 0, .external_lex_state = 23},
  [8090] = {.lex_state = 91, .external_lex_state = 11},
  [8091] = {.lex_state = 0, .external_lex_state = 23},
  [8092] = {.lex_state = 6},
  [8093] = {.lex_state = 6},
  [8094] = {.lex_state = 0, .external_lex_state = 23},
  [8095] = {.lex_state = 0, .external_lex_state = 23},
  [8096] = {.lex_state = 0, .external_lex_state = 23},
  [8097] = {.lex_state = 0, .external_lex_state = 23},
  [8098] = {.lex_state = 0, .external_lex_state = 23},
  [8099] = {.lex_state = 6},
  [8100] = {.lex_state = 0, .external_lex_state = 23},
  [8101] = {.lex_state = 6},
  [8102] = {.lex_state = 0, .external_lex_state = 23},
  [8103] = {.lex_state = 0, .external_lex_state = 23},
  [8104] = {.lex_state = 0, .external_lex_state = 23},
  [8105] = {.lex_state = 6},
  [8106] = {.lex_state = 0, .external_lex_state = 23},
  [8107] = {.lex_state = 0, .external_lex_state = 23},
  [8108] = {.lex_state = 6},
  [8109] = {.lex_state = 0, .external_lex_state = 23},
  [8110] = {.lex_state = 0, .external_lex_state = 23},
  [8111] = {.lex_state = 0, .external_lex_state = 23},
  [8112] = {.lex_state = 91, .external_lex_state = 24},
  [8113] = {.lex_state = 0, .external_lex_state = 23},
  [8114] = {.lex_state = 0, .external_lex_state = 23},
  [8115] = {.lex_state = 0, .external_lex_state = 23},
  [8116] = {.lex_state = 0, .external_lex_state = 23},
  [8117] = {.lex_state = 0, .external_lex_state = 23},
  [8118] = {.lex_state = 0, .external_lex_state = 23},
  [8119] = {.lex_state = 0, .external_lex_state = 23},
  [8120] = {.lex_state = 0, .external_lex_state = 23},
  [8121] = {.lex_state = 0, .external_lex_state = 23},
  [8122] = {.lex_state = 0, .external_lex_state = 23},
  [8123] = {.lex_state = 0, .external_lex_state = 23},
  [8124] = {.lex_state = 0, .external_lex_state = 23},
  [8125] = {.lex_state = 0, .external_lex_state = 23},
  [8126] = {.lex_state = 0, .external_lex_state = 23},
  [8127] = {.lex_state = 0, .external_lex_state = 23},
  [8128] = {.lex_state = 91, .external_lex_state = 24},
  [8129] = {.lex_state = 0, .external_lex_state = 23},
  [8130] = {.lex_state = 0, .external_lex_state = 23},
  [8131] = {.lex_state = 0, .external_lex_state = 23},
  [8132] = {.lex_state = 0, .external_lex_state = 23},
  [8133] = {.lex_state = 0, .external_lex_state = 23},
  [8134] = {.lex_state = 91, .external_lex_state = 24},
  [8135] = {.lex_state = 6},
  [8136] = {.lex_state = 6},
  [8137] = {.lex_state = 0, .external_lex_state = 23},
  [8138] = {.lex_state = 0, .external_lex_state = 23},
  [8139] = {.lex_state = 0, .external_lex_state = 23},
  [8140] = {.lex_state = 0, .external_lex_state = 23},
  [8141] = {.lex_state = 6},
  [8142] = {.lex_state = 6},
  [8143] = {.lex_state = 0, .external_lex_state = 23},
  [8144] = {.lex_state = 0, .external_lex_state = 23},
  [8145] = {.lex_state = 6},
  [8146] = {.lex_state = 6},
  [8147] = {.lex_state = 6},
  [8148] = {.lex_state = 0, .external_lex_state = 23},
  [8149] = {.lex_state = 0, .external_lex_state = 23},
  [8150] = {.lex_state = 91, .external_lex_state = 2},
  [8151] = {.lex_state = 0, .external_lex_state = 23},
  [8152] = {.lex_state = 0, .external_lex_state = 23},
  [8153] = {.lex_state = 91, .external_lex_state = 11},
  [8154] = {.lex_state = 91, .external_lex_state = 2},
  [8155] = {.lex_state = 91, .external_lex_state = 2},
  [8156] = {.lex_state = 0, .external_lex_state = 23},
  [8157] = {.lex_state = 91, .external_lex_state = 24},
  [8158] = {.lex_state = 91, .external_lex_state = 2},
  [8159] = {.lex_state = 0, .external_lex_state = 23},
  [8160] = {.lex_state = 91, .external_lex_state = 24},
  [8161] = {.lex_state = 6},
  [8162] = {.lex_state = 6},
  [8163] = {.lex_state = 0, .external_lex_state = 23},
  [8164] = {.lex_state = 0, .external_lex_state = 23},
  [8165] = {.lex_state = 91, .external_lex_state = 2},
  [8166] = {.lex_state = 91, .external_lex_state = 2},
  [8167] = {.lex_state = 91, .external_lex_state = 24},
  [8168] = {.lex_state = 0, .external_lex_state = 23},
  [8169] = {.lex_state = 0, .external_lex_state = 23},
  [8170] = {.lex_state = 0, .external_lex_state = 23},
  [8171] = {.lex_state = 0, .external_lex_state = 23},
  [8172] = {.lex_state = 0, .external_lex_state = 23},
  [8173] = {.lex_state = 0, .external_lex_state = 23},
  [8174] = {.lex_state = 91, .external_lex_state = 24},
  [8175] = {.lex_state = 91, .external_lex_state = 24},
  [8176] = {.lex_state = 91, .external_lex_state = 24},
  [8177] = {.lex_state = 91, .external_lex_state = 24},
  [8178] = {.lex_state = 91, .external_lex_state = 24},
  [8179] = {.lex_state = 91, .external_lex_state = 24},
  [8180] = {.lex_state = 91, .external_lex_state = 24},
  [8181] = {.lex_state = 91, .external_lex_state = 24},
  [8182] = {.lex_state = 91, .external_lex_state = 24},
  [8183] = {.lex_state = 91, .external_lex_state = 24},
  [8184] = {.lex_state = 91, .external_lex_state = 24},
  [8185] = {.lex_state = 91, .external_lex_state = 2},
  [8186] = {.lex_state = 91, .external_lex_state = 24},
  [8187] = {.lex_state = 91, .external_lex_state = 2},
  [8188] = {.lex_state = 6},
  [8189] = {.lex_state = 91, .external_lex_state = 2},
  [8190] = {.lex_state = 0, .external_lex_state = 23},
  [8191] = {.lex_state = 91, .external_lex_state = 24},
  [8192] = {.lex_state = 0, .external_lex_state = 23},
  [8193] = {.lex_state = 91, .external_lex_state = 24},
  [8194] = {.lex_state = 91, .external_lex_state = 24},
  [8195] = {.lex_state = 91, .external_lex_state = 24},
  [8196] = {.lex_state = 91, .external_lex_state = 24},
  [8197] = {.lex_state = 91, .external_lex_state = 2},
  [8198] = {.lex_state = 91},
  [8199] = {.lex_state = 91},
  [8200] = {.lex_state = 91, .external_lex_state = 2},
  [8201] = {.lex_state = 91, .external_lex_state = 24},
  [8202] = {.lex_state = 91, .external_lex_state = 2},
  [8203] = {.lex_state = 0, .external_lex_state = 23},
  [8204] = {.lex_state = 0, .external_lex_state = 23},
  [8205] = {.lex_state = 91, .external_lex_state = 24},
  [8206] = {.lex_state = 91, .external_lex_state = 24},
  [8207] = {.lex_state = 91, .external_lex_state = 24},
  [8208] = {.lex_state = 91, .external_lex_state = 24},
  [8209] = {.lex_state = 91, .external_lex_state = 24},
  [8210] = {.lex_state = 91, .external_lex_state = 24},
  [8211] = {.lex_state = 91},
  [8212] = {.lex_state = 0, .external_lex_state = 23},
  [8213] = {.lex_state = 91, .external_lex_state = 24},
  [8214] = {.lex_state = 0, .external_lex_state = 23},
  [8215] = {.lex_state = 91},
  [8216] = {.lex_state = 91},
  [8217] = {.lex_state = 91},
  [8218] = {.lex_state = 91},
  [8219] = {.lex_state = 91, .external_lex_state = 23},
  [8220] = {.lex_state = 91, .external_lex_state = 24},
  [8221] = {.lex_state = 91, .external_lex_state = 2},
  [8222] = {.lex_state = 91, .external_lex_state = 2},
  [8223] = {.lex_state = 91, .external_lex_state = 23},
  [8224] = {.lex_state = 91, .external_lex_state = 2},
  [8225] = {.lex_state = 91, .external_lex_state = 24},
  [8226] = {.lex_state = 91, .external_lex_state = 24},
  [8227] = {.lex_state = 91, .external_lex_state = 2},
  [8228] = {.lex_state = 91, .external_lex_state = 24},
  [8229] = {.lex_state = 91, .external_lex_state = 2},
  [8230] = {.lex_state = 91, .external_lex_state = 24},
  [8231] = {.lex_state = 91, .external_lex_state = 23},
  [8232] = {.lex_state = 91, .external_lex_state = 24},
  [8233] = {.lex_state = 91, .external_lex_state = 24},
  [8234] = {.lex_state = 91, .external_lex_state = 24},
  [8235] = {.lex_state = 91, .external_lex_state = 23},
  [8236] = {.lex_state = 91, .external_lex_state = 2},
  [8237] = {.lex_state = 91, .external_lex_state = 24},
  [8238] = {.lex_state = 91, .external_lex_state = 24},
  [8239] = {.lex_state = 91, .external_lex_state = 24},
  [8240] = {.lex_state = 91, .external_lex_state = 2},
  [8241] = {.lex_state = 91, .external_lex_state = 2},
  [8242] = {.lex_state = 91, .external_lex_state = 23},
  [8243] = {.lex_state = 91, .external_lex_state = 24},
  [8244] = {.lex_state = 0, .external_lex_state = 23},
  [8245] = {.lex_state = 91},
  [8246] = {.lex_state = 91, .external_lex_state = 24},
  [8247] = {.lex_state = 91, .external_lex_state = 24},
  [8248] = {.lex_state = 91, .external_lex_state = 24},
  [8249] = {.lex_state = 91, .external_lex_state = 2},
  [8250] = {.lex_state = 91, .external_lex_state = 24},
  [8251] = {.lex_state = 91, .external_lex_state = 2},
  [8252] = {.lex_state = 91, .external_lex_state = 24},
  [8253] = {.lex_state = 91, .external_lex_state = 24},
  [8254] = {.lex_state = 0, .external_lex_state = 23},
  [8255] = {.lex_state = 91, .external_lex_state = 24},
  [8256] = {.lex_state = 91, .external_lex_state = 2},
  [8257] = {.lex_state = 91, .external_lex_state = 23},
  [8258] = {.lex_state = 91, .external_lex_state = 24},
  [8259] = {.lex_state = 91, .external_lex_state = 24},
  [8260] = {.lex_state = 91, .external_lex_state = 24},
  [8261] = {.lex_state = 91, .external_lex_state = 24},
  [8262] = {.lex_state = 91, .external_lex_state = 24},
  [8263] = {.lex_state = 91, .external_lex_state = 24},
  [8264] = {.lex_state = 91},
  [8265] = {.lex_state = 91, .external_lex_state = 2},
  [8266] = {.lex_state = 91, .external_lex_state = 24},
  [8267] = {.lex_state = 91, .external_lex_state = 24},
  [8268] = {.lex_state = 91, .external_lex_state = 24},
  [8269] = {.lex_state = 91, .external_lex_state = 24},
  [8270] = {.lex_state = 91},
  [8271] = {.lex_state = 91},
  [8272] = {.lex_state = 91, .external_lex_state = 24},
  [8273] = {.lex_state = 91, .external_lex_state = 24},
  [8274] = {.lex_state = 91, .external_lex_state = 24},
  [8275] = {.lex_state = 91, .external_lex_state = 2},
  [8276] = {.lex_state = 91, .external_lex_state = 24},
  [8277] = {.lex_state = 91},
  [8278] = {.lex_state = 91, .external_lex_state = 24},
  [8279] = {.lex_state = 91, .external_lex_state = 23},
  [8280] = {.lex_state = 91, .external_lex_state = 24},
  [8281] = {.lex_state = 91},
  [8282] = {.lex_state = 91, .external_lex_state = 24},
  [8283] = {.lex_state = 91, .external_lex_state = 24},
  [8284] = {.lex_state = 91, .external_lex_state = 24},
  [8285] = {.lex_state = 91, .external_lex_state = 24},
  [8286] = {.lex_state = 91, .external_lex_state = 24},
  [8287] = {.lex_state = 91},
  [8288] = {.lex_state = 91},
  [8289] = {.lex_state = 91, .external_lex_state = 24},
  [8290] = {.lex_state = 91, .external_lex_state = 24},
  [8291] = {.lex_state = 91},
  [8292] = {.lex_state = 91},
  [8293] = {.lex_state = 91, .external_lex_state = 24},
  [8294] = {.lex_state = 91, .external_lex_state = 24},
  [8295] = {.lex_state = 91},
  [8296] = {.lex_state = 91},
  [8297] = {.lex_state = 91, .external_lex_state = 24},
  [8298] = {.lex_state = 91},
  [8299] = {.lex_state = 91},
  [8300] = {.lex_state = 91, .external_lex_state = 23},
  [8301] = {.lex_state = 91, .external_lex_state = 24},
  [8302] = {.lex_state = 91, .external_lex_state = 24},
  [8303] = {.lex_state = 91, .external_lex_state = 24},
  [8304] = {.lex_state = 91, .external_lex_state = 24},
  [8305] = {.lex_state = 91, .external_lex_state = 24},
  [8306] = {.lex_state = 91, .external_lex_state = 24},
  [8307] = {.lex_state = 91, .external_lex_state = 24},
  [8308] = {.lex_state = 91, .external_lex_state = 24},
  [8309] = {.lex_state = 91, .external_lex_state = 24},
  [8310] = {.lex_state = 91, .external_lex_state = 24},
  [8311] = {.lex_state = 91, .external_lex_state = 24},
  [8312] = {.lex_state = 91, .external_lex_state = 24},
  [8313] = {.lex_state = 91, .external_lex_state = 24},
  [8314] = {.lex_state = 91, .external_lex_state = 24},
  [8315] = {.lex_state = 91, .external_lex_state = 24},
  [8316] = {.lex_state = 91, .external_lex_state = 24},
  [8317] = {.lex_state = 91, .external_lex_state = 24},
  [8318] = {.lex_state = 91, .external_lex_state = 24},
  [8319] = {.lex_state = 91, .external_lex_state = 24},
  [8320] = {.lex_state = 91, .external_lex_state = 24},
  [8321] = {.lex_state = 91},
  [8322] = {.lex_state = 91, .external_lex_state = 24},
  [8323] = {.lex_state = 91},
  [8324] = {.lex_state = 91, .external_lex_state = 24},
  [8325] = {.lex_state = 91, .external_lex_state = 24},
  [8326] = {.lex_state = 91, .external_lex_state = 24},
  [8327] = {.lex_state = 91, .external_lex_state = 24},
  [8328] = {.lex_state = 91},
  [8329] = {.lex_state = 91},
  [8330] = {.lex_state = 91},
  [8331] = {.lex_state = 0, .external_lex_state = 23},
  [8332] = {.lex_state = 0, .external_lex_state = 23},
  [8333] = {.lex_state = 91},
  [8334] = {.lex_state = 0, .external_lex_state = 23},
  [8335] = {.lex_state = 12, .external_lex_state = 23},
  [8336] = {.lex_state = 91},
  [8337] = {.lex_state = 91},
  [8338] = {.lex_state = 91},
  [8339] = {.lex_state = 91},
  [8340] = {.lex_state = 91},
  [8341] = {.lex_state = 91},
  [8342] = {.lex_state = 91, .external_lex_state = 2},
  [8343] = {.lex_state = 91},
  [8344] = {.lex_state = 91},
  [8345] = {.lex_state = 0, .external_lex_state = 23},
  [8346] = {.lex_state = 91, .external_lex_state = 2},
  [8347] = {.lex_state = 91},
  [8348] = {.lex_state = 91},
  [8349] = {.lex_state = 0, .external_lex_state = 23},
  [8350] = {.lex_state = 91},
  [8351] = {.lex_state = 91},
  [8352] = {.lex_state = 0, .external_lex_state = 23},
  [8353] = {.lex_state = 12, .external_lex_state = 23},
  [8354] = {.lex_state = 91},
  [8355] = {.lex_state = 91, .external_lex_state = 23},
  [8356] = {.lex_state = 91},
  [8357] = {.lex_state = 91},
  [8358] = {.lex_state = 0, .external_lex_state = 23},
  [8359] = {.lex_state = 91},
  [8360] = {.lex_state = 91},
  [8361] = {.lex_state = 91},
  [8362] = {.lex_state = 91, .external_lex_state = 24},
  [8363] = {.lex_state = 91},
  [8364] = {.lex_state = 91},
  [8365] = {.lex_state = 91},
  [8366] = {.lex_state = 91, .external_lex_state = 24},
  [8367] = {.lex_state = 91},
  [8368] = {.lex_state = 91},
  [8369] = {.lex_state = 91},
  [8370] = {.lex_state = 91},
  [8371] = {.lex_state = 0, .external_lex_state = 23},
  [8372] = {.lex_state = 91},
  [8373] = {.lex_state = 91},
  [8374] = {.lex_state = 91},
  [8375] = {.lex_state = 91},
  [8376] = {.lex_state = 91},
  [8377] = {.lex_state = 91},
  [8378] = {.lex_state = 91, .external_lex_state = 2},
  [8379] = {.lex_state = 91},
  [8380] = {.lex_state = 91},
  [8381] = {.lex_state = 91, .external_lex_state = 2},
  [8382] = {.lex_state = 91, .external_lex_state = 24},
  [8383] = {.lex_state = 91},
  [8384] = {.lex_state = 91},
  [8385] = {.lex_state = 91},
  [8386] = {.lex_state = 91},
  [8387] = {.lex_state = 91},
  [8388] = {.lex_state = 91, .external_lex_state = 24},
  [8389] = {.lex_state = 91, .external_lex_state = 24},
  [8390] = {.lex_state = 91},
  [8391] = {.lex_state = 91},
  [8392] = {.lex_state = 91},
  [8393] = {.lex_state = 0, .external_lex_state = 23},
  [8394] = {.lex_state = 91},
  [8395] = {.lex_state = 91},
  [8396] = {.lex_state = 0, .external_lex_state = 23},
  [8397] = {.lex_state = 0, .external_lex_state = 23},
  [8398] = {.lex_state = 91},
  [8399] = {.lex_state = 91},
  [8400] = {.lex_state = 91},
  [8401] = {.lex_state = 91},
  [8402] = {.lex_state = 0, .external_lex_state = 23},
  [8403] = {.lex_state = 0, .external_lex_state = 23},
  [8404] = {.lex_state = 91},
  [8405] = {.lex_state = 91},
  [8406] = {.lex_state = 91},
  [8407] = {.lex_state = 91},
  [8408] = {.lex_state = 0, .external_lex_state = 23},
  [8409] = {.lex_state = 91, .external_lex_state = 23},
  [8410] = {.lex_state = 91},
  [8411] = {.lex_state = 91},
  [8412] = {.lex_state = 91},
  [8413] = {.lex_state = 91},
  [8414] = {.lex_state = 91},
  [8415] = {.lex_state = 91},
  [8416] = {.lex_state = 91},
  [8417] = {.lex_state = 0, .external_lex_state = 23},
  [8418] = {.lex_state = 91},
  [8419] = {.lex_state = 91},
  [8420] = {.lex_state = 91},
  [8421] = {.lex_state = 91},
  [8422] = {.lex_state = 91},
  [8423] = {.lex_state = 91},
  [8424] = {.lex_state = 91},
  [8425] = {.lex_state = 91},
  [8426] = {.lex_state = 91},
  [8427] = {.lex_state = 91},
  [8428] = {.lex_state = 91},
  [8429] = {.lex_state = 91},
  [8430] = {.lex_state = 91},
  [8431] = {.lex_state = 91},
  [8432] = {.lex_state = 91},
  [8433] = {.lex_state = 91},
  [8434] = {.lex_state = 91},
  [8435] = {.lex_state = 91},
  [8436] = {.lex_state = 91},
  [8437] = {.lex_state = 91},
  [8438] = {.lex_state = 91},
  [8439] = {.lex_state = 91},
  [8440] = {.lex_state = 91},
  [8441] = {.lex_state = 91},
  [8442] = {.lex_state = 91},
  [8443] = {.lex_state = 91, .external_lex_state = 2},
  [8444] = {.lex_state = 91},
  [8445] = {.lex_state = 91},
  [8446] = {.lex_state = 91},
  [8447] = {.lex_state = 0, .external_lex_state = 23},
  [8448] = {.lex_state = 91, .external_lex_state = 2},
  [8449] = {.lex_state = 0, .external_lex_state = 23},
  [8450] = {.lex_state = 0, .external_lex_state = 23},
  [8451] = {.lex_state = 91},
  [8452] = {.lex_state = 91},
  [8453] = {.lex_state = 0, .external_lex_state = 23},
  [8454] = {.lex_state = 91},
  [8455] = {.lex_state = 91},
  [8456] = {.lex_state = 91},
  [8457] = {.lex_state = 91},
  [8458] = {.lex_state = 91},
  [8459] = {.lex_state = 91},
  [8460] = {.lex_state = 91},
  [8461] = {.lex_state = 91},
  [8462] = {.lex_state = 91, .external_lex_state = 2},
  [8463] = {.lex_state = 91, .external_lex_state = 23},
  [8464] = {.lex_state = 91},
  [8465] = {.lex_state = 91},
  [8466] = {.lex_state = 91, .external_lex_state = 23},
  [8467] = {.lex_state = 0, .external_lex_state = 23},
  [8468] = {.lex_state = 91},
  [8469] = {.lex_state = 0, .external_lex_state = 23},
  [8470] = {.lex_state = 91, .external_lex_state = 2},
  [8471] = {.lex_state = 91},
  [8472] = {.lex_state = 91},
  [8473] = {.lex_state = 91},
  [8474] = {.lex_state = 91},
  [8475] = {.lex_state = 91},
  [8476] = {.lex_state = 91},
  [8477] = {.lex_state = 91},
  [8478] = {.lex_state = 91, .external_lex_state = 23},
  [8479] = {.lex_state = 91, .external_lex_state = 23},
  [8480] = {.lex_state = 91},
  [8481] = {.lex_state = 91},
  [8482] = {.lex_state = 91, .external_lex_state = 23},
  [8483] = {.lex_state = 91, .external_lex_state = 23},
  [8484] = {.lex_state = 91},
  [8485] = {.lex_state = 91},
  [8486] = {.lex_state = 91},
  [8487] = {.lex_state = 91},
  [8488] = {.lex_state = 91},
  [8489] = {.lex_state = 91},
  [8490] = {.lex_state = 91},
  [8491] = {.lex_state = 91},
  [8492] = {.lex_state = 91},
  [8493] = {.lex_state = 91},
  [8494] = {.lex_state = 91},
  [8495] = {.lex_state = 91},
  [8496] = {.lex_state = 91},
  [8497] = {.lex_state = 91},
  [8498] = {.lex_state = 91},
  [8499] = {.lex_state = 91},
  [8500] = {.lex_state = 12, .external_lex_state = 23},
  [8501] = {.lex_state = 91},
  [8502] = {.lex_state = 91},
  [8503] = {.lex_state = 91},
  [8504] = {.lex_state = 91},
  [8505] = {.lex_state = 91},
  [8506] = {.lex_state = 91},
  [8507] = {.lex_state = 91},
  [8508] = {.lex_state = 0, .external_lex_state = 23},
  [8509] = {.lex_state = 0, .external_lex_state = 23},
  [8510] = {.lex_state = 0, .external_lex_state = 23},
  [8511] = {.lex_state = 0, .external_lex_state = 23},
  [8512] = {.lex_state = 0, .external_lex_state = 23},
  [8513] = {.lex_state = 0, .external_lex_state = 23},
  [8514] = {.lex_state = 91},
  [8515] = {.lex_state = 91},
  [8516] = {.lex_state = 91},
  [8517] = {.lex_state = 91},
  [8518] = {.lex_state = 0, .external_lex_state = 23},
  [8519] = {.lex_state = 91},
  [8520] = {.lex_state = 0, .external_lex_state = 23},
  [8521] = {.lex_state = 91},
  [8522] = {.lex_state = 91},
  [8523] = {.lex_state = 91},
  [8524] = {.lex_state = 91},
  [8525] = {.lex_state = 91},
  [8526] = {.lex_state = 91},
  [8527] = {.lex_state = 91},
  [8528] = {.lex_state = 91},
  [8529] = {.lex_state = 91},
  [8530] = {.lex_state = 91},
  [8531] = {.lex_state = 91},
  [8532] = {.lex_state = 91},
  [8533] = {.lex_state = 91},
  [8534] = {.lex_state = 91},
  [8535] = {.lex_state = 91},
  [8536] = {.lex_state = 91},
  [8537] = {.lex_state = 91},
  [8538] = {.lex_state = 5},
  [8539] = {.lex_state = 5},
  [8540] = {.lex_state = 91},
  [8541] = {.lex_state = 91},
  [8542] = {.lex_state = 91},
  [8543] = {.lex_state = 0, .external_lex_state = 23},
  [8544] = {.lex_state = 91},
  [8545] = {.lex_state = 91},
  [8546] = {.lex_state = 91},
  [8547] = {.lex_state = 91},
  [8548] = {.lex_state = 91},
  [8549] = {.lex_state = 91},
  [8550] = {.lex_state = 91},
  [8551] = {.lex_state = 91},
  [8552] = {.lex_state = 91},
  [8553] = {.lex_state = 91},
  [8554] = {.lex_state = 91},
  [8555] = {.lex_state = 91},
  [8556] = {.lex_state = 91},
  [8557] = {.lex_state = 91},
  [8558] = {.lex_state = 91},
  [8559] = {.lex_state = 91},
  [8560] = {.lex_state = 91},
  [8561] = {.lex_state = 91},
  [8562] = {.lex_state = 91},
  [8563] = {.lex_state = 91},
  [8564] = {.lex_state = 91},
  [8565] = {.lex_state = 91, .external_lex_state = 24},
  [8566] = {.lex_state = 91},
  [8567] = {.lex_state = 91},
  [8568] = {.lex_state = 91},
  [8569] = {.lex_state = 91},
  [8570] = {.lex_state = 91},
  [8571] = {.lex_state = 0, .external_lex_state = 23},
  [8572] = {.lex_state = 91},
  [8573] = {.lex_state = 91},
  [8574] = {.lex_state = 0, .external_lex_state = 23},
  [8575] = {.lex_state = 0, .external_lex_state = 23},
  [8576] = {.lex_state = 91},
  [8577] = {.lex_state = 91},
  [8578] = {.lex_state = 91},
  [8579] = {.lex_state = 91},
  [8580] = {.lex_state = 91},
  [8581] = {.lex_state = 91},
  [8582] = {.lex_state = 91, .external_lex_state = 23},
  [8583] = {.lex_state = 91},
  [8584] = {.lex_state = 91},
  [8585] = {.lex_state = 91},
  [8586] = {.lex_state = 91},
  [8587] = {.lex_state = 91},
  [8588] = {.lex_state = 91},
  [8589] = {.lex_state = 91},
  [8590] = {.lex_state = 91},
  [8591] = {.lex_state = 91},
  [8592] = {.lex_state = 91},
  [8593] = {.lex_state = 91},
  [8594] = {.lex_state = 91},
  [8595] = {.lex_state = 91},
  [8596] = {.lex_state = 91},
  [8597] = {.lex_state = 91},
  [8598] = {.lex_state = 91},
  [8599] = {.lex_state = 91},
  [8600] = {.lex_state = 91},
  [8601] = {.lex_state = 91},
  [8602] = {.lex_state = 91},
  [8603] = {.lex_state = 91},
  [8604] = {.lex_state = 91},
  [8605] = {.lex_state = 91},
  [8606] = {.lex_state = 91},
  [8607] = {.lex_state = 91},
  [8608] = {.lex_state = 91},
  [8609] = {.lex_state = 91},
  [8610] = {.lex_state = 91},
  [8611] = {.lex_state = 91},
  [8612] = {.lex_state = 91},
  [8613] = {.lex_state = 91},
  [8614] = {.lex_state = 91},
  [8615] = {.lex_state = 91},
  [8616] = {.lex_state = 91},
  [8617] = {.lex_state = 91},
  [8618] = {.lex_state = 91},
  [8619] = {.lex_state = 91},
  [8620] = {.lex_state = 91},
  [8621] = {.lex_state = 91},
  [8622] = {.lex_state = 91},
  [8623] = {.lex_state = 91},
  [8624] = {.lex_state = 91},
  [8625] = {.lex_state = 91},
  [8626] = {.lex_state = 91},
  [8627] = {.lex_state = 91},
  [8628] = {.lex_state = 0, .external_lex_state = 23},
  [8629] = {.lex_state = 91},
  [8630] = {.lex_state = 91},
  [8631] = {.lex_state = 91},
  [8632] = {.lex_state = 91},
  [8633] = {.lex_state = 91},
  [8634] = {.lex_state = 91},
  [8635] = {.lex_state = 91},
  [8636] = {.lex_state = 91},
  [8637] = {.lex_state = 91},
  [8638] = {.lex_state = 91},
  [8639] = {.lex_state = 91},
  [8640] = {.lex_state = 91},
  [8641] = {.lex_state = 91},
  [8642] = {.lex_state = 91},
  [8643] = {.lex_state = 91},
  [8644] = {.lex_state = 91},
  [8645] = {.lex_state = 91},
  [8646] = {.lex_state = 91},
  [8647] = {.lex_state = 91},
  [8648] = {.lex_state = 91},
  [8649] = {.lex_state = 91},
  [8650] = {.lex_state = 91},
  [8651] = {.lex_state = 91},
  [8652] = {.lex_state = 91},
  [8653] = {.lex_state = 91},
  [8654] = {.lex_state = 91},
  [8655] = {.lex_state = 91},
  [8656] = {.lex_state = 91},
  [8657] = {.lex_state = 91},
  [8658] = {.lex_state = 91},
  [8659] = {.lex_state = 91},
  [8660] = {.lex_state = 91},
  [8661] = {.lex_state = 91},
  [8662] = {.lex_state = 91},
  [8663] = {.lex_state = 91},
  [8664] = {.lex_state = 91},
  [8665] = {.lex_state = 91},
  [8666] = {.lex_state = 91},
  [8667] = {.lex_state = 91},
  [8668] = {.lex_state = 91},
  [8669] = {.lex_state = 91},
  [8670] = {.lex_state = 91},
  [8671] = {.lex_state = 91},
  [8672] = {.lex_state = 91},
  [8673] = {.lex_state = 91},
  [8674] = {.lex_state = 91},
  [8675] = {.lex_state = 91},
  [8676] = {.lex_state = 91},
  [8677] = {.lex_state = 91},
  [8678] = {.lex_state = 91},
  [8679] = {.lex_state = 91},
  [8680] = {.lex_state = 91},
  [8681] = {.lex_state = 91},
  [8682] = {.lex_state = 91},
  [8683] = {.lex_state = 91},
  [8684] = {.lex_state = 91},
  [8685] = {.lex_state = 91},
  [8686] = {.lex_state = 91},
  [8687] = {.lex_state = 91},
  [8688] = {.lex_state = 91},
  [8689] = {.lex_state = 91},
  [8690] = {.lex_state = 91},
  [8691] = {.lex_state = 91},
  [8692] = {.lex_state = 91},
  [8693] = {.lex_state = 91},
  [8694] = {.lex_state = 91},
  [8695] = {.lex_state = 91},
  [8696] = {.lex_state = 91},
  [8697] = {.lex_state = 91},
  [8698] = {.lex_state = 0, .external_lex_state = 23},
  [8699] = {.lex_state = 91},
  [8700] = {.lex_state = 0, .external_lex_state = 23},
  [8701] = {.lex_state = 91},
  [8702] = {.lex_state = 91},
  [8703] = {.lex_state = 91},
  [8704] = {.lex_state = 91},
  [8705] = {.lex_state = 91},
  [8706] = {.lex_state = 91},
  [8707] = {.lex_state = 91},
  [8708] = {.lex_state = 91},
  [8709] = {.lex_state = 91},
  [8710] = {.lex_state = 91},
  [8711] = {.lex_state = 91, .external_lex_state = 23},
  [8712] = {.lex_state = 0, .external_lex_state = 23},
  [8713] = {.lex_state = 91},
  [8714] = {.lex_state = 91, .external_lex_state = 2},
  [8715] = {.lex_state = 91},
  [8716] = {.lex_state = 91},
  [8717] = {.lex_state = 91},
  [8718] = {.lex_state = 91},
  [8719] = {.lex_state = 91, .external_lex_state = 2},
  [8720] = {.lex_state = 0, .external_lex_state = 23},
  [8721] = {.lex_state = 91},
  [8722] = {.lex_state = 91},
  [8723] = {.lex_state = 91},
  [8724] = {.lex_state = 91},
  [8725] = {.lex_state = 91},
  [8726] = {.lex_state = 91},
  [8727] = {.lex_state = 91},
  [8728] = {.lex_state = 91, .external_lex_state = 23},
  [8729] = {.lex_state = 91},
  [8730] = {.lex_state = 91},
  [8731] = {.lex_state = 91},
  [8732] = {.lex_state = 91},
  [8733] = {.lex_state = 91},
  [8734] = {.lex_state = 91, .external_lex_state = 23},
  [8735] = {.lex_state = 91, .external_lex_state = 2},
  [8736] = {.lex_state = 91},
  [8737] = {.lex_state = 91},
  [8738] = {.lex_state = 0, .external_lex_state = 23},
  [8739] = {.lex_state = 91},
  [8740] = {.lex_state = 91},
  [8741] = {.lex_state = 91},
  [8742] = {.lex_state = 91},
  [8743] = {.lex_state = 91},
  [8744] = {.lex_state = 91},
  [8745] = {.lex_state = 91},
  [8746] = {.lex_state = 91},
  [8747] = {.lex_state = 91},
  [8748] = {.lex_state = 91},
  [8749] = {.lex_state = 91},
  [8750] = {.lex_state = 91},
  [8751] = {.lex_state = 91},
  [8752] = {.lex_state = 91},
  [8753] = {.lex_state = 91},
  [8754] = {.lex_state = 91},
  [8755] = {.lex_state = 91},
  [8756] = {.lex_state = 91},
  [8757] = {.lex_state = 91},
  [8758] = {.lex_state = 91},
  [8759] = {.lex_state = 91},
  [8760] = {.lex_state = 91},
  [8761] = {.lex_state = 91},
  [8762] = {.lex_state = 0, .external_lex_state = 23},
  [8763] = {.lex_state = 91},
  [8764] = {.lex_state = 91},
  [8765] = {.lex_state = 91},
  [8766] = {.lex_state = 91},
  [8767] = {.lex_state = 91},
  [8768] = {.lex_state = 91},
  [8769] = {.lex_state = 0, .external_lex_state = 23},
  [8770] = {.lex_state = 0, .external_lex_state = 23},
  [8771] = {.lex_state = 0, .external_lex_state = 23},
  [8772] = {.lex_state = 0, .external_lex_state = 23},
  [8773] = {.lex_state = 0, .external_lex_state = 23},
  [8774] = {.lex_state = 0, .external_lex_state = 23},
  [8775] = {.lex_state = 91},
  [8776] = {.lex_state = 0, .external_lex_state = 23},
  [8777] = {.lex_state = 0, .external_lex_state = 23},
  [8778] = {.lex_state = 0, .external_lex_state = 23},
  [8779] = {.lex_state = 0, .external_lex_state = 23},
  [8780] = {.lex_state = 0, .external_lex_state = 23},
  [8781] = {.lex_state = 0, .external_lex_state = 23},
  [8782] = {.lex_state = 91, .external_lex_state = 24},
  [8783] = {.lex_state = 0, .external_lex_state = 23},
  [8784] = {.lex_state = 0, .external_lex_state = 23},
  [8785] = {.lex_state = 0, .external_lex_state = 23},
  [8786] = {.lex_state = 0, .external_lex_state = 23},
  [8787] = {.lex_state = 91, .external_lex_state = 24},
  [8788] = {.lex_state = 0, .external_lex_state = 23},
  [8789] = {.lex_state = 0, .external_lex_state = 23},
  [8790] = {.lex_state = 91},
  [8791] = {.lex_state = 0, .external_lex_state = 23},
  [8792] = {.lex_state = 0, .external_lex_state = 23},
  [8793] = {.lex_state = 0, .external_lex_state = 23},
  [8794] = {.lex_state = 0, .external_lex_state = 23},
  [8795] = {.lex_state = 0, .external_lex_state = 23},
  [8796] = {.lex_state = 91, .external_lex_state = 24},
  [8797] = {.lex_state = 0, .external_lex_state = 23},
  [8798] = {.lex_state = 0, .external_lex_state = 23},
  [8799] = {.lex_state = 0, .external_lex_state = 23},
  [8800] = {.lex_state = 0, .external_lex_state = 23},
  [8801] = {.lex_state = 0, .external_lex_state = 23},
  [8802] = {.lex_state = 0, .external_lex_state = 23},
  [8803] = {.lex_state = 0, .external_lex_state = 23},
  [8804] = {.lex_state = 91, .external_lex_state = 24},
  [8805] = {.lex_state = 0, .external_lex_state = 23},
  [8806] = {.lex_state = 0, .external_lex_state = 23},
  [8807] = {.lex_state = 0, .external_lex_state = 23},
  [8808] = {.lex_state = 0, .external_lex_state = 23},
  [8809] = {.lex_state = 0, .external_lex_state = 23},
  [8810] = {.lex_state = 0, .external_lex_state = 23},
  [8811] = {.lex_state = 0, .external_lex_state = 23},
  [8812] = {.lex_state = 0, .external_lex_state = 23},
  [8813] = {.lex_state = 91, .external_lex_state = 24},
  [8814] = {.lex_state = 0, .external_lex_state = 23},
  [8815] = {.lex_state = 0, .external_lex_state = 23},
  [8816] = {.lex_state = 0, .external_lex_state = 23},
  [8817] = {.lex_state = 0, .external_lex_state = 23},
  [8818] = {.lex_state = 0, .external_lex_state = 23},
  [8819] = {.lex_state = 0, .external_lex_state = 23},
  [8820] = {.lex_state = 0, .external_lex_state = 23},
  [8821] = {.lex_state = 0, .external_lex_state = 23},
  [8822] = {.lex_state = 0, .external_lex_state = 23},
  [8823] = {.lex_state = 0, .external_lex_state = 23},
  [8824] = {.lex_state = 0, .external_lex_state = 23},
  [8825] = {.lex_state = 0, .external_lex_state = 23},
  [8826] = {.lex_state = 0, .external_lex_state = 23},
  [8827] = {.lex_state = 91, .external_lex_state = 24},
  [8828] = {.lex_state = 0, .external_lex_state = 23},
  [8829] = {.lex_state = 0, .external_lex_state = 23},
  [8830] = {.lex_state = 0, .external_lex_state = 23},
  [8831] = {.lex_state = 91, .external_lex_state = 24},
  [8832] = {.lex_state = 0, .external_lex_state = 23},
  [8833] = {.lex_state = 6},
  [8834] = {.lex_state = 0, .external_lex_state = 23},
  [8835] = {.lex_state = 0, .external_lex_state = 23},
  [8836] = {.lex_state = 91, .external_lex_state = 24},
  [8837] = {.lex_state = 0, .external_lex_state = 23},
  [8838] = {.lex_state = 91, .external_lex_state = 24},
  [8839] = {.lex_state = 0, .external_lex_state = 23},
  [8840] = {.lex_state = 0, .external_lex_state = 23},
  [8841] = {.lex_state = 91, .external_lex_state = 24},
  [8842] = {.lex_state = 0, .external_lex_state = 23},
  [8843] = {.lex_state = 91, .external_lex_state = 24},
  [8844] = {.lex_state = 91, .external_lex_state = 24},
  [8845] = {.lex_state = 91, .external_lex_state = 23},
  [8846] = {.lex_state = 91, .external_lex_state = 24},
  [8847] = {.lex_state = 0, .external_lex_state = 23},
  [8848] = {.lex_state = 0, .external_lex_state = 23},
  [8849] = {.lex_state = 0, .external_lex_state = 23},
  [8850] = {.lex_state = 91, .external_lex_state = 23},
  [8851] = {.lex_state = 91, .external_lex_state = 23},
  [8852] = {.lex_state = 91, .external_lex_state = 23},
  [8853] = {.lex_state = 0, .external_lex_state = 23},
  [8854] = {.lex_state = 91, .external_lex_state = 23},
  [8855] = {.lex_state = 91, .external_lex_state = 23},
  [8856] = {.lex_state = 91, .external_lex_state = 23},
  [8857] = {.lex_state = 91, .external_lex_state = 24},
  [8858] = {.lex_state = 0, .external_lex_state = 23},
  [8859] = {.lex_state = 0, .external_lex_state = 23},
  [8860] = {.lex_state = 0, .external_lex_state = 23},
  [8861] = {.lex_state = 0, .external_lex_state = 23},
  [8862] = {.lex_state = 91, .external_lex_state = 23},
  [8863] = {.lex_state = 91, .external_lex_state = 23},
  [8864] = {.lex_state = 91, .external_lex_state = 24},
  [8865] = {.lex_state = 91, .external_lex_state = 24},
  [8866] = {.lex_state = 0, .external_lex_state = 23},
  [8867] = {.lex_state = 0, .external_lex_state = 23},
  [8868] = {.lex_state = 91, .external_lex_state = 23},
  [8869] = {.lex_state = 91, .external_lex_state = 23},
  [8870] = {.lex_state = 91, .external_lex_state = 23},
  [8871] = {.lex_state = 0, .external_lex_state = 23},
  [8872] = {.lex_state = 91, .external_lex_state = 23},
  [8873] = {.lex_state = 91, .external_lex_state = 23},
  [8874] = {.lex_state = 91, .external_lex_state = 23},
  [8875] = {.lex_state = 91},
  [8876] = {.lex_state = 91, .external_lex_state = 23},
  [8877] = {.lex_state = 91, .external_lex_state = 23},
  [8878] = {.lex_state = 91, .external_lex_state = 23},
  [8879] = {.lex_state = 91, .external_lex_state = 23},
  [8880] = {.lex_state = 91, .external_lex_state = 23},
  [8881] = {.lex_state = 0, .external_lex_state = 23},
  [8882] = {.lex_state = 91, .external_lex_state = 23},
  [8883] = {.lex_state = 0, .external_lex_state = 23},
  [8884] = {.lex_state = 0, .external_lex_state = 23},
  [8885] = {.lex_state = 91, .external_lex_state = 24},
  [8886] = {.lex_state = 0, .external_lex_state = 23},
  [8887] = {.lex_state = 91, .external_lex_state = 24},
  [8888] = {.lex_state = 91, .external_lex_state = 24},
  [8889] = {.lex_state = 0, .external_lex_state = 23},
  [8890] = {.lex_state = 0, .external_lex_state = 23},
  [8891] = {.lex_state = 0, .external_lex_state = 23},
  [8892] = {.lex_state = 0, .external_lex_state = 23},
  [8893] = {.lex_state = 0, .external_lex_state = 23},
  [8894] = {.lex_state = 91, .external_lex_state = 23},
  [8895] = {.lex_state = 91, .external_lex_state = 24},
  [8896] = {.lex_state = 91, .external_lex_state = 23},
  [8897] = {.lex_state = 0, .external_lex_state = 23},
  [8898] = {.lex_state = 0, .external_lex_state = 23},
  [8899] = {.lex_state = 0, .external_lex_state = 23},
  [8900] = {.lex_state = 0, .external_lex_state = 23},
  [8901] = {.lex_state = 0, .external_lex_state = 23},
  [8902] = {.lex_state = 0, .external_lex_state = 23},
  [8903] = {.lex_state = 0, .external_lex_state = 23},
  [8904] = {.lex_state = 0, .external_lex_state = 23},
  [8905] = {.lex_state = 91, .external_lex_state = 24},
  [8906] = {.lex_state = 0, .external_lex_state = 23},
  [8907] = {.lex_state = 0, .external_lex_state = 23},
  [8908] = {.lex_state = 0, .external_lex_state = 23},
  [8909] = {.lex_state = 0, .external_lex_state = 23},
  [8910] = {.lex_state = 0, .external_lex_state = 23},
  [8911] = {.lex_state = 0, .external_lex_state = 23},
  [8912] = {.lex_state = 91, .external_lex_state = 24},
  [8913] = {.lex_state = 0, .external_lex_state = 23},
  [8914] = {.lex_state = 0, .external_lex_state = 23},
  [8915] = {.lex_state = 0, .external_lex_state = 23},
  [8916] = {.lex_state = 91, .external_lex_state = 23},
  [8917] = {.lex_state = 91, .external_lex_state = 23},
  [8918] = {.lex_state = 91, .external_lex_state = 24},
  [8919] = {.lex_state = 91},
  [8920] = {.lex_state = 0, .external_lex_state = 23},
  [8921] = {.lex_state = 0, .external_lex_state = 23},
  [8922] = {.lex_state = 91, .external_lex_state = 23},
  [8923] = {.lex_state = 0, .external_lex_state = 23},
  [8924] = {.lex_state = 91, .external_lex_state = 24},
  [8925] = {.lex_state = 91, .external_lex_state = 24},
  [8926] = {.lex_state = 91, .external_lex_state = 24},
  [8927] = {.lex_state = 0, .external_lex_state = 23},
  [8928] = {.lex_state = 0, .external_lex_state = 23},
  [8929] = {.lex_state = 0, .external_lex_state = 23},
  [8930] = {.lex_state = 0, .external_lex_state = 23},
  [8931] = {.lex_state = 0, .external_lex_state = 23},
  [8932] = {.lex_state = 91, .external_lex_state = 24},
  [8933] = {.lex_state = 91, .external_lex_state = 23},
  [8934] = {.lex_state = 91, .external_lex_state = 24},
  [8935] = {.lex_state = 91, .external_lex_state = 24},
  [8936] = {.lex_state = 91, .external_lex_state = 23},
  [8937] = {.lex_state = 0, .external_lex_state = 23},
  [8938] = {.lex_state = 0, .external_lex_state = 23},
  [8939] = {.lex_state = 0, .external_lex_state = 23},
  [8940] = {.lex_state = 0, .external_lex_state = 23},
  [8941] = {.lex_state = 91, .external_lex_state = 24},
  [8942] = {.lex_state = 91, .external_lex_state = 23},
  [8943] = {.lex_state = 0, .external_lex_state = 23},
  [8944] = {.lex_state = 0, .external_lex_state = 23},
  [8945] = {.lex_state = 0, .external_lex_state = 23},
  [8946] = {.lex_state = 91, .external_lex_state = 23},
  [8947] = {.lex_state = 91, .external_lex_state = 24},
  [8948] = {.lex_state = 91, .external_lex_state = 23},
  [8949] = {.lex_state = 91, .external_lex_state = 23},
  [8950] = {.lex_state = 91, .external_lex_state = 23},
  [8951] = {.lex_state = 91, .external_lex_state = 23},
  [8952] = {.lex_state = 91, .external_lex_state = 23},
  [8953] = {.lex_state = 91, .external_lex_state = 23},
  [8954] = {.lex_state = 91, .external_lex_state = 23},
  [8955] = {.lex_state = 0, .external_lex_state = 23},
  [8956] = {.lex_state = 91, .external_lex_state = 23},
  [8957] = {.lex_state = 91, .external_lex_state = 23},
  [8958] = {.lex_state = 91, .external_lex_state = 23},
  [8959] = {.lex_state = 91, .external_lex_state = 23},
  [8960] = {.lex_state = 91, .external_lex_state = 23},
  [8961] = {.lex_state = 91, .external_lex_state = 23},
  [8962] = {.lex_state = 91, .external_lex_state = 23},
  [8963] = {.lex_state = 0, .external_lex_state = 23},
  [8964] = {.lex_state = 0, .external_lex_state = 23},
  [8965] = {.lex_state = 91},
  [8966] = {.lex_state = 91},
  [8967] = {.lex_state = 91},
  [8968] = {.lex_state = 91},
  [8969] = {.lex_state = 91},
  [8970] = {.lex_state = 91},
  [8971] = {.lex_state = 91},
  [8972] = {.lex_state = 91},
  [8973] = {.lex_state = 91},
  [8974] = {.lex_state = 91},
  [8975] = {.lex_state = 91},
  [8976] = {.lex_state = 91},
  [8977] = {.lex_state = 91},
  [8978] = {.lex_state = 91},
  [8979] = {.lex_state = 91},
  [8980] = {.lex_state = 91},
  [8981] = {.lex_state = 91, .external_lex_state = 23},
  [8982] = {.lex_state = 91},
  [8983] = {.lex_state = 91},
  [8984] = {.lex_state = 91},
  [8985] = {.lex_state = 91, .external_lex_state = 23},
  [8986] = {.lex_state = 91, .external_lex_state = 2},
  [8987] = {.lex_state = 91},
  [8988] = {.lex_state = 91, .external_lex_state = 2},
  [8989] = {.lex_state = 91, .external_lex_state = 2},
  [8990] = {.lex_state = 91, .external_lex_state = 2},
  [8991] = {.lex_state = 91},
  [8992] = {.lex_state = 91, .external_lex_state = 23},
  [8993] = {.lex_state = 91},
  [8994] = {.lex_state = 91},
  [8995] = {.lex_state = 91},
  [8996] = {.lex_state = 91},
  [8997] = {.lex_state = 91},
  [8998] = {.lex_state = 91},
  [8999] = {.lex_state = 91},
  [9000] = {.lex_state = 91},
  [9001] = {.lex_state = 91, .external_lex_state = 28},
  [9002] = {.lex_state = 91, .external_lex_state = 28},
  [9003] = {.lex_state = 91, .external_lex_state = 2},
  [9004] = {.lex_state = 91, .external_lex_state = 28},
  [9005] = {.lex_state = 91},
  [9006] = {.lex_state = 91, .external_lex_state = 28},
  [9007] = {.lex_state = 91, .external_lex_state = 2},
  [9008] = {.lex_state = 91, .external_lex_state = 2},
  [9009] = {.lex_state = 91, .external_lex_state = 2},
  [9010] = {.lex_state = 91, .external_lex_state = 2},
  [9011] = {.lex_state = 91, .external_lex_state = 2},
  [9012] = {.lex_state = 91, .external_lex_state = 2},
  [9013] = {.lex_state = 91, .external_lex_state = 2},
  [9014] = {.lex_state = 91, .external_lex_state = 2},
  [9015] = {.lex_state = 91, .external_lex_state = 2},
  [9016] = {.lex_state = 91, .external_lex_state = 2},
  [9017] = {.lex_state = 91, .external_lex_state = 28},
  [9018] = {.lex_state = 91, .external_lex_state = 28},
  [9019] = {.lex_state = 91, .external_lex_state = 2},
  [9020] = {.lex_state = 91, .external_lex_state = 2},
  [9021] = {.lex_state = 91, .external_lex_state = 2},
  [9022] = {.lex_state = 91, .external_lex_state = 28},
  [9023] = {.lex_state = 91, .external_lex_state = 2},
  [9024] = {.lex_state = 91, .external_lex_state = 2},
  [9025] = {.lex_state = 91, .external_lex_state = 28},
  [9026] = {.lex_state = 91, .external_lex_state = 28},
  [9027] = {.lex_state = 91, .external_lex_state = 28},
  [9028] = {.lex_state = 91, .external_lex_state = 28},
  [9029] = {.lex_state = 91, .external_lex_state = 28},
  [9030] = {.lex_state = 91, .external_lex_state = 2},
  [9031] = {.lex_state = 91, .external_lex_state = 28},
  [9032] = {.lex_state = 91, .external_lex_state = 2},
  [9033] = {.lex_state = 91},
  [9034] = {.lex_state = 91},
  [9035] = {.lex_state = 91},
  [9036] = {.lex_state = 91},
  [9037] = {.lex_state = 91},
  [9038] = {.lex_state = 91, .external_lex_state = 2},
  [9039] = {.lex_state = 91},
  [9040] = {.lex_state = 91},
  [9041] = {.lex_state = 91},
  [9042] = {.lex_state = 91},
  [9043] = {.lex_state = 91, .external_lex_state = 2},
  [9044] = {.lex_state = 91},
  [9045] = {.lex_state = 91, .external_lex_state = 2},
  [9046] = {.lex_state = 91},
  [9047] = {.lex_state = 91},
  [9048] = {.lex_state = 91},
  [9049] = {.lex_state = 91, .external_lex_state = 2},
  [9050] = {.lex_state = 91, .external_lex_state = 2},
  [9051] = {.lex_state = 91},
  [9052] = {.lex_state = 91, .external_lex_state = 2},
  [9053] = {.lex_state = 91},
  [9054] = {.lex_state = 91},
  [9055] = {.lex_state = 91},
  [9056] = {.lex_state = 91},
  [9057] = {.lex_state = 91, .external_lex_state = 2},
  [9058] = {.lex_state = 0, .external_lex_state = 23},
  [9059] = {.lex_state = 0, .external_lex_state = 23},
  [9060] = {.lex_state = 0, .external_lex_state = 23},
  [9061] = {.lex_state = 0, .external_lex_state = 23},
  [9062] = {.lex_state = 0, .external_lex_state = 23},
  [9063] = {.lex_state = 0, .external_lex_state = 23},
  [9064] = {.lex_state = 0, .external_lex_state = 23},
  [9065] = {.lex_state = 0, .external_lex_state = 23},
  [9066] = {.lex_state = 0, .external_lex_state = 23},
  [9067] = {.lex_state = 0, .external_lex_state = 23},
  [9068] = {.lex_state = 0, .external_lex_state = 23},
  [9069] = {.lex_state = 0, .external_lex_state = 23},
  [9070] = {.lex_state = 0, .external_lex_state = 23},
  [9071] = {.lex_state = 0, .external_lex_state = 23},
  [9072] = {.lex_state = 0, .external_lex_state = 23},
  [9073] = {.lex_state = 0, .external_lex_state = 23},
  [9074] = {.lex_state = 0, .external_lex_state = 23},
  [9075] = {.lex_state = 0, .external_lex_state = 23},
  [9076] = {.lex_state = 0, .external_lex_state = 23},
  [9077] = {.lex_state = 0, .external_lex_state = 23},
  [9078] = {.lex_state = 0, .external_lex_state = 23},
  [9079] = {.lex_state = 0, .external_lex_state = 23},
  [9080] = {.lex_state = 0, .external_lex_state = 23},
  [9081] = {.lex_state = 0, .external_lex_state = 23},
  [9082] = {.lex_state = 0, .external_lex_state = 23},
  [9083] = {.lex_state = 0, .external_lex_state = 23},
  [9084] = {.lex_state = 0, .external_lex_state = 23},
  [9085] = {.lex_state = 0, .external_lex_state = 23},
  [9086] = {.lex_state = 0, .external_lex_state = 23},
  [9087] = {.lex_state = 0, .external_lex_state = 23},
  [9088] = {.lex_state = 0, .external_lex_state = 23},
  [9089] = {.lex_state = 0, .external_lex_state = 23},
  [9090] = {.lex_state = 0, .external_lex_state = 23},
  [9091] = {.lex_state = 0, .external_lex_state = 23},
  [9092] = {.lex_state = 0, .external_lex_state = 23},
  [9093] = {.lex_state = 0, .external_lex_state = 23},
  [9094] = {.lex_state = 0, .external_lex_state = 23},
  [9095] = {.lex_state = 91},
  [9096] = {.lex_state = 0, .external_lex_state = 23},
  [9097] = {.lex_state = 0, .external_lex_state = 23},
  [9098] = {.lex_state = 0, .external_lex_state = 23},
  [9099] = {.lex_state = 0, .external_lex_state = 23},
  [9100] = {.lex_state = 0, .external_lex_state = 23},
  [9101] = {.lex_state = 0, .external_lex_state = 23},
  [9102] = {.lex_state = 0, .external_lex_state = 23},
  [9103] = {.lex_state = 0, .external_lex_state = 23},
  [9104] = {.lex_state = 0, .external_lex_state = 23},
  [9105] = {.lex_state = 0, .external_lex_state = 23},
  [9106] = {.lex_state = 0, .external_lex_state = 23},
  [9107] = {.lex_state = 0, .external_lex_state = 23},
  [9108] = {.lex_state = 0, .external_lex_state = 23},
  [9109] = {.lex_state = 0, .external_lex_state = 23},
  [9110] = {.lex_state = 0, .external_lex_state = 23},
  [9111] = {.lex_state = 0, .external_lex_state = 23},
  [9112] = {.lex_state = 0, .external_lex_state = 23},
  [9113] = {.lex_state = 0, .external_lex_state = 23},
  [9114] = {.lex_state = 0, .external_lex_state = 23},
  [9115] = {.lex_state = 0, .external_lex_state = 23},
  [9116] = {.lex_state = 0, .external_lex_state = 23},
  [9117] = {.lex_state = 91},
  [9118] = {.lex_state = 0, .external_lex_state = 23},
  [9119] = {.lex_state = 0, .external_lex_state = 23},
  [9120] = {.lex_state = 0, .external_lex_state = 23},
  [9121] = {.lex_state = 91},
  [9122] = {.lex_state = 0, .external_lex_state = 23},
  [9123] = {.lex_state = 0, .external_lex_state = 23},
  [9124] = {.lex_state = 0, .external_lex_state = 23},
  [9125] = {.lex_state = 0, .external_lex_state = 23},
  [9126] = {.lex_state = 0, .external_lex_state = 23},
  [9127] = {.lex_state = 0, .external_lex_state = 23},
  [9128] = {.lex_state = 0, .external_lex_state = 23},
  [9129] = {.lex_state = 0, .external_lex_state = 23},
  [9130] = {.lex_state = 0, .external_lex_state = 23},
  [9131] = {.lex_state = 0, .external_lex_state = 23},
  [9132] = {.lex_state = 0, .external_lex_state = 23},
  [9133] = {.lex_state = 0, .external_lex_state = 23},
  [9134] = {.lex_state = 0, .external_lex_state = 23},
  [9135] = {.lex_state = 0, .external_lex_state = 23},
  [9136] = {.lex_state = 0, .external_lex_state = 23},
  [9137] = {.lex_state = 0, .external_lex_state = 23},
  [9138] = {.lex_state = 0, .external_lex_state = 23},
  [9139] = {.lex_state = 0, .external_lex_state = 23},
  [9140] = {.lex_state = 0, .external_lex_state = 23},
  [9141] = {.lex_state = 0, .external_lex_state = 23},
  [9142] = {.lex_state = 0, .external_lex_state = 23},
  [9143] = {.lex_state = 0, .external_lex_state = 23},
  [9144] = {.lex_state = 0, .external_lex_state = 23},
  [9145] = {.lex_state = 0, .external_lex_state = 23},
  [9146] = {.lex_state = 0, .external_lex_state = 23},
  [9147] = {.lex_state = 0, .external_lex_state = 23},
  [9148] = {.lex_state = 0, .external_lex_state = 23},
  [9149] = {.lex_state = 0, .external_lex_state = 23},
  [9150] = {.lex_state = 0, .external_lex_state = 23},
  [9151] = {.lex_state = 0, .external_lex_state = 23},
  [9152] = {.lex_state = 0, .external_lex_state = 23},
  [9153] = {.lex_state = 0, .external_lex_state = 23},
  [9154] = {.lex_state = 0, .external_lex_state = 23},
  [9155] = {.lex_state = 0, .external_lex_state = 23},
  [9156] = {.lex_state = 0, .external_lex_state = 23},
  [9157] = {.lex_state = 0, .external_lex_state = 23},
  [9158] = {.lex_state = 0, .external_lex_state = 23},
  [9159] = {.lex_state = 0, .external_lex_state = 23},
  [9160] = {.lex_state = 0, .external_lex_state = 23},
  [9161] = {.lex_state = 0, .external_lex_state = 23},
  [9162] = {.lex_state = 0, .external_lex_state = 23},
  [9163] = {.lex_state = 0, .external_lex_state = 23},
  [9164] = {.lex_state = 0, .external_lex_state = 23},
  [9165] = {.lex_state = 0, .external_lex_state = 23},
  [9166] = {.lex_state = 0, .external_lex_state = 23},
  [9167] = {.lex_state = 0, .external_lex_state = 23},
  [9168] = {.lex_state = 0, .external_lex_state = 23},
  [9169] = {.lex_state = 0, .external_lex_state = 23},
  [9170] = {.lex_state = 0, .external_lex_state = 23},
  [9171] = {.lex_state = 0, .external_lex_state = 23},
  [9172] = {.lex_state = 0, .external_lex_state = 23},
  [9173] = {.lex_state = 0, .external_lex_state = 23},
  [9174] = {.lex_state = 0, .external_lex_state = 23},
  [9175] = {.lex_state = 91},
  [9176] = {.lex_state = 0, .external_lex_state = 23},
  [9177] = {.lex_state = 0, .external_lex_state = 23},
  [9178] = {.lex_state = 0, .external_lex_state = 23},
  [9179] = {.lex_state = 0, .external_lex_state = 23},
  [9180] = {.lex_state = 0, .external_lex_state = 23},
  [9181] = {.lex_state = 0, .external_lex_state = 23},
  [9182] = {.lex_state = 0, .external_lex_state = 23},
  [9183] = {.lex_state = 0, .external_lex_state = 23},
  [9184] = {.lex_state = 0, .external_lex_state = 23},
  [9185] = {.lex_state = 0, .external_lex_state = 23},
  [9186] = {.lex_state = 0, .external_lex_state = 23},
  [9187] = {.lex_state = 0, .external_lex_state = 23},
  [9188] = {.lex_state = 0, .external_lex_state = 23},
  [9189] = {.lex_state = 0, .external_lex_state = 23},
  [9190] = {.lex_state = 0, .external_lex_state = 23},
  [9191] = {.lex_state = 0, .external_lex_state = 23},
  [9192] = {.lex_state = 0, .external_lex_state = 23},
  [9193] = {.lex_state = 0, .external_lex_state = 23},
  [9194] = {.lex_state = 0, .external_lex_state = 23},
  [9195] = {.lex_state = 0, .external_lex_state = 23},
  [9196] = {.lex_state = 91},
  [9197] = {.lex_state = 0, .external_lex_state = 23},
  [9198] = {.lex_state = 0, .external_lex_state = 23},
  [9199] = {.lex_state = 0, .external_lex_state = 23},
  [9200] = {.lex_state = 0, .external_lex_state = 23},
  [9201] = {.lex_state = 0, .external_lex_state = 23},
  [9202] = {.lex_state = 0, .external_lex_state = 23},
  [9203] = {.lex_state = 0, .external_lex_state = 23},
  [9204] = {.lex_state = 0, .external_lex_state = 23},
  [9205] = {.lex_state = 0, .external_lex_state = 23},
  [9206] = {.lex_state = 0, .external_lex_state = 23},
  [9207] = {.lex_state = 0, .external_lex_state = 23},
  [9208] = {.lex_state = 0, .external_lex_state = 23},
  [9209] = {.lex_state = 0, .external_lex_state = 23},
  [9210] = {.lex_state = 0, .external_lex_state = 23},
  [9211] = {.lex_state = 91},
  [9212] = {.lex_state = 0, .external_lex_state = 23},
  [9213] = {.lex_state = 0, .external_lex_state = 23},
  [9214] = {.lex_state = 0, .external_lex_state = 23},
  [9215] = {.lex_state = 0, .external_lex_state = 23},
  [9216] = {.lex_state = 0, .external_lex_state = 23},
  [9217] = {.lex_state = 0, .external_lex_state = 23},
  [9218] = {.lex_state = 0, .external_lex_state = 23},
  [9219] = {.lex_state = 0, .external_lex_state = 23},
  [9220] = {.lex_state = 91},
  [9221] = {.lex_state = 0, .external_lex_state = 23},
  [9222] = {.lex_state = 0, .external_lex_state = 23},
  [9223] = {.lex_state = 0, .external_lex_state = 23},
  [9224] = {.lex_state = 0, .external_lex_state = 23},
  [9225] = {.lex_state = 0, .external_lex_state = 23},
  [9226] = {.lex_state = 0, .external_lex_state = 23},
  [9227] = {.lex_state = 0, .external_lex_state = 23},
  [9228] = {.lex_state = 0, .external_lex_state = 23},
  [9229] = {.lex_state = 0, .external_lex_state = 23},
  [9230] = {.lex_state = 0, .external_lex_state = 23},
  [9231] = {.lex_state = 0, .external_lex_state = 23},
  [9232] = {.lex_state = 0, .external_lex_state = 23},
  [9233] = {.lex_state = 91},
  [9234] = {.lex_state = 0, .external_lex_state = 23},
  [9235] = {.lex_state = 0, .external_lex_state = 23},
  [9236] = {.lex_state = 0, .external_lex_state = 23},
  [9237] = {.lex_state = 0, .external_lex_state = 23},
  [9238] = {.lex_state = 0, .external_lex_state = 23},
  [9239] = {.lex_state = 0, .external_lex_state = 23},
  [9240] = {.lex_state = 0, .external_lex_state = 23},
  [9241] = {.lex_state = 0, .external_lex_state = 23},
  [9242] = {.lex_state = 0, .external_lex_state = 23},
  [9243] = {.lex_state = 0, .external_lex_state = 23},
  [9244] = {.lex_state = 0, .external_lex_state = 23},
  [9245] = {.lex_state = 0, .external_lex_state = 23},
  [9246] = {.lex_state = 0, .external_lex_state = 23},
  [9247] = {.lex_state = 0, .external_lex_state = 23},
  [9248] = {.lex_state = 0, .external_lex_state = 23},
  [9249] = {.lex_state = 0, .external_lex_state = 23},
  [9250] = {.lex_state = 0, .external_lex_state = 23},
  [9251] = {.lex_state = 0, .external_lex_state = 23},
  [9252] = {.lex_state = 0, .external_lex_state = 23},
  [9253] = {.lex_state = 0, .external_lex_state = 23},
  [9254] = {.lex_state = 0, .external_lex_state = 23},
  [9255] = {.lex_state = 0, .external_lex_state = 23},
  [9256] = {.lex_state = 0, .external_lex_state = 23},
  [9257] = {.lex_state = 91},
  [9258] = {.lex_state = 0, .external_lex_state = 23},
  [9259] = {.lex_state = 0, .external_lex_state = 23},
  [9260] = {.lex_state = 0, .external_lex_state = 23},
  [9261] = {.lex_state = 0, .external_lex_state = 23},
  [9262] = {.lex_state = 0, .external_lex_state = 23},
  [9263] = {.lex_state = 0, .external_lex_state = 23},
  [9264] = {.lex_state = 0, .external_lex_state = 23},
  [9265] = {.lex_state = 0, .external_lex_state = 23},
  [9266] = {.lex_state = 0, .external_lex_state = 23},
  [9267] = {.lex_state = 0, .external_lex_state = 23},
  [9268] = {.lex_state = 0, .external_lex_state = 23},
  [9269] = {.lex_state = 0, .external_lex_state = 23},
  [9270] = {.lex_state = 0, .external_lex_state = 23},
  [9271] = {.lex_state = 0, .external_lex_state = 23},
  [9272] = {.lex_state = 0, .external_lex_state = 23},
  [9273] = {.lex_state = 0, .external_lex_state = 23},
  [9274] = {.lex_state = 0, .external_lex_state = 23},
  [9275] = {.lex_state = 0, .external_lex_state = 23},
  [9276] = {.lex_state = 91},
  [9277] = {.lex_state = 91},
  [9278] = {.lex_state = 0, .external_lex_state = 23},
  [9279] = {.lex_state = 0, .external_lex_state = 23},
  [9280] = {.lex_state = 0, .external_lex_state = 23},
  [9281] = {.lex_state = 0, .external_lex_state = 23},
  [9282] = {.lex_state = 0, .external_lex_state = 23},
  [9283] = {.lex_state = 0, .external_lex_state = 23},
  [9284] = {.lex_state = 0, .external_lex_state = 23},
  [9285] = {.lex_state = 0, .external_lex_state = 23},
  [9286] = {.lex_state = 0, .external_lex_state = 23},
  [9287] = {.lex_state = 0, .external_lex_state = 23},
  [9288] = {.lex_state = 0, .external_lex_state = 23},
  [9289] = {.lex_state = 0, .external_lex_state = 23},
  [9290] = {.lex_state = 0, .external_lex_state = 23},
  [9291] = {.lex_state = 91},
  [9292] = {.lex_state = 0, .external_lex_state = 23},
  [9293] = {.lex_state = 0, .external_lex_state = 23},
  [9294] = {.lex_state = 0, .external_lex_state = 23},
  [9295] = {.lex_state = 0, .external_lex_state = 23},
  [9296] = {.lex_state = 0, .external_lex_state = 23},
  [9297] = {.lex_state = 0, .external_lex_state = 23},
  [9298] = {.lex_state = 0, .external_lex_state = 23},
  [9299] = {.lex_state = 0, .external_lex_state = 23},
  [9300] = {.lex_state = 0, .external_lex_state = 23},
  [9301] = {.lex_state = 0, .external_lex_state = 23},
  [9302] = {.lex_state = 0},
  [9303] = {.lex_state = 0, .external_lex_state = 23},
  [9304] = {.lex_state = 0, .external_lex_state = 23},
  [9305] = {.lex_state = 91},
  [9306] = {.lex_state = 0, .external_lex_state = 23},
  [9307] = {.lex_state = 0, .external_lex_state = 23},
  [9308] = {.lex_state = 0, .external_lex_state = 23},
  [9309] = {.lex_state = 0, .external_lex_state = 23},
  [9310] = {.lex_state = 0, .external_lex_state = 23},
  [9311] = {.lex_state = 0, .external_lex_state = 23},
  [9312] = {.lex_state = 0, .external_lex_state = 23},
  [9313] = {.lex_state = 0, .external_lex_state = 23},
  [9314] = {.lex_state = 0, .external_lex_state = 23},
  [9315] = {.lex_state = 0, .external_lex_state = 23},
  [9316] = {.lex_state = 0, .external_lex_state = 23},
  [9317] = {.lex_state = 0, .external_lex_state = 23},
  [9318] = {.lex_state = 0, .external_lex_state = 23},
  [9319] = {.lex_state = 0, .external_lex_state = 23},
  [9320] = {.lex_state = 0, .external_lex_state = 23},
  [9321] = {.lex_state = 0, .external_lex_state = 23},
  [9322] = {.lex_state = 0, .external_lex_state = 23},
  [9323] = {.lex_state = 0, .external_lex_state = 23},
  [9324] = {.lex_state = 0, .external_lex_state = 23},
  [9325] = {.lex_state = 0, .external_lex_state = 23},
  [9326] = {.lex_state = 0, .external_lex_state = 23},
  [9327] = {.lex_state = 91},
  [9328] = {.lex_state = 91},
  [9329] = {.lex_state = 0, .external_lex_state = 23},
  [9330] = {.lex_state = 0, .external_lex_state = 23},
  [9331] = {.lex_state = 0, .external_lex_state = 23},
  [9332] = {.lex_state = 0, .external_lex_state = 23},
  [9333] = {.lex_state = 0, .external_lex_state = 23},
  [9334] = {.lex_state = 91},
  [9335] = {.lex_state = 91},
  [9336] = {.lex_state = 91},
  [9337] = {.lex_state = 91},
  [9338] = {.lex_state = 0, .external_lex_state = 23},
  [9339] = {.lex_state = 0, .external_lex_state = 23},
  [9340] = {.lex_state = 0, .external_lex_state = 23},
  [9341] = {.lex_state = 0, .external_lex_state = 23},
  [9342] = {.lex_state = 0, .external_lex_state = 23},
  [9343] = {.lex_state = 0, .external_lex_state = 23},
  [9344] = {.lex_state = 0, .external_lex_state = 23},
  [9345] = {.lex_state = 0, .external_lex_state = 23},
  [9346] = {.lex_state = 0, .external_lex_state = 23},
  [9347] = {.lex_state = 0, .external_lex_state = 23},
  [9348] = {.lex_state = 0, .external_lex_state = 23},
  [9349] = {.lex_state = 6},
  [9350] = {.lex_state = 0, .external_lex_state = 23},
  [9351] = {.lex_state = 0, .external_lex_state = 23},
  [9352] = {.lex_state = 0, .external_lex_state = 23},
  [9353] = {.lex_state = 0, .external_lex_state = 23},
  [9354] = {.lex_state = 0, .external_lex_state = 23},
  [9355] = {.lex_state = 0, .external_lex_state = 23},
  [9356] = {.lex_state = 0, .external_lex_state = 23},
  [9357] = {.lex_state = 0, .external_lex_state = 23},
  [9358] = {.lex_state = 0, .external_lex_state = 23},
  [9359] = {.lex_state = 0, .external_lex_state = 23},
  [9360] = {.lex_state = 0, .external_lex_state = 23},
  [9361] = {.lex_state = 0, .external_lex_state = 23},
  [9362] = {.lex_state = 0, .external_lex_state = 23},
  [9363] = {.lex_state = 0, .external_lex_state = 23},
  [9364] = {.lex_state = 0, .external_lex_state = 23},
  [9365] = {.lex_state = 0, .external_lex_state = 23},
  [9366] = {.lex_state = 91},
  [9367] = {.lex_state = 0, .external_lex_state = 23},
  [9368] = {.lex_state = 91},
  [9369] = {.lex_state = 0, .external_lex_state = 23},
  [9370] = {.lex_state = 0, .external_lex_state = 23},
  [9371] = {.lex_state = 0, .external_lex_state = 23},
  [9372] = {.lex_state = 0, .external_lex_state = 23},
  [9373] = {.lex_state = 0, .external_lex_state = 23},
  [9374] = {.lex_state = 0, .external_lex_state = 23},
  [9375] = {.lex_state = 0, .external_lex_state = 23},
  [9376] = {.lex_state = 0, .external_lex_state = 23},
  [9377] = {.lex_state = 0, .external_lex_state = 23},
  [9378] = {.lex_state = 0, .external_lex_state = 23},
  [9379] = {.lex_state = 0, .external_lex_state = 23},
  [9380] = {.lex_state = 0, .external_lex_state = 23},
  [9381] = {.lex_state = 0, .external_lex_state = 23},
  [9382] = {.lex_state = 0, .external_lex_state = 23},
  [9383] = {.lex_state = 0, .external_lex_state = 23},
  [9384] = {.lex_state = 0, .external_lex_state = 23},
  [9385] = {.lex_state = 0, .external_lex_state = 23},
  [9386] = {.lex_state = 0, .external_lex_state = 23},
  [9387] = {.lex_state = 91},
  [9388] = {.lex_state = 91},
  [9389] = {.lex_state = 91},
  [9390] = {.lex_state = 91},
  [9391] = {.lex_state = 0, .external_lex_state = 23},
  [9392] = {.lex_state = 91},
  [9393] = {.lex_state = 91},
  [9394] = {.lex_state = 91},
  [9395] = {.lex_state = 91},
  [9396] = {.lex_state = 0, .external_lex_state = 23},
  [9397] = {.lex_state = 0, .external_lex_state = 23},
  [9398] = {.lex_state = 0, .external_lex_state = 23},
  [9399] = {.lex_state = 0, .external_lex_state = 23},
  [9400] = {.lex_state = 0, .external_lex_state = 23},
  [9401] = {.lex_state = 0, .external_lex_state = 23},
  [9402] = {.lex_state = 91},
  [9403] = {.lex_state = 91},
  [9404] = {.lex_state = 0, .external_lex_state = 23},
  [9405] = {.lex_state = 0, .external_lex_state = 23},
  [9406] = {.lex_state = 0, .external_lex_state = 23},
  [9407] = {.lex_state = 0, .external_lex_state = 23},
  [9408] = {.lex_state = 0, .external_lex_state = 23},
  [9409] = {.lex_state = 0, .external_lex_state = 23},
  [9410] = {.lex_state = 0, .external_lex_state = 23},
  [9411] = {.lex_state = 0, .external_lex_state = 23},
  [9412] = {.lex_state = 0, .external_lex_state = 23},
  [9413] = {.lex_state = 0, .external_lex_state = 23},
  [9414] = {.lex_state = 0, .external_lex_state = 23},
  [9415] = {.lex_state = 0, .external_lex_state = 23},
  [9416] = {.lex_state = 91},
  [9417] = {.lex_state = 91},
  [9418] = {.lex_state = 0, .external_lex_state = 23},
  [9419] = {.lex_state = 91},
  [9420] = {.lex_state = 91},
  [9421] = {.lex_state = 0, .external_lex_state = 23},
  [9422] = {.lex_state = 0, .external_lex_state = 23},
  [9423] = {.lex_state = 0, .external_lex_state = 23},
  [9424] = {.lex_state = 91},
  [9425] = {.lex_state = 91},
  [9426] = {.lex_state = 91},
  [9427] = {.lex_state = 91},
  [9428] = {.lex_state = 0, .external_lex_state = 23},
  [9429] = {.lex_state = 0, .external_lex_state = 23},
  [9430] = {.lex_state = 0, .external_lex_state = 23},
  [9431] = {.lex_state = 0, .external_lex_state = 23},
  [9432] = {.lex_state = 0, .external_lex_state = 23},
  [9433] = {.lex_state = 0, .external_lex_state = 23},
  [9434] = {.lex_state = 91},
  [9435] = {.lex_state = 0, .external_lex_state = 23},
  [9436] = {.lex_state = 0, .external_lex_state = 23},
  [9437] = {.lex_state = 0, .external_lex_state = 23},
  [9438] = {.lex_state = 0, .external_lex_state = 23},
  [9439] = {.lex_state = 91},
  [9440] = {.lex_state = 91},
  [9441] = {.lex_state = 91},
  [9442] = {.lex_state = 91},
  [9443] = {.lex_state = 0, .external_lex_state = 23},
  [9444] = {.lex_state = 91},
  [9445] = {.lex_state = 91},
  [9446] = {.lex_state = 91},
  [9447] = {.lex_state = 91},
  [9448] = {.lex_state = 0, .external_lex_state = 23},
  [9449] = {.lex_state = 0, .external_lex_state = 23},
  [9450] = {.lex_state = 0, .external_lex_state = 23},
  [9451] = {.lex_state = 0, .external_lex_state = 23},
  [9452] = {.lex_state = 0, .external_lex_state = 23},
  [9453] = {.lex_state = 91},
  [9454] = {.lex_state = 91},
  [9455] = {.lex_state = 0, .external_lex_state = 23},
  [9456] = {.lex_state = 0, .external_lex_state = 23},
  [9457] = {.lex_state = 0, .external_lex_state = 23},
  [9458] = {.lex_state = 0, .external_lex_state = 23},
  [9459] = {.lex_state = 0, .external_lex_state = 23},
  [9460] = {.lex_state = 0, .external_lex_state = 23},
  [9461] = {.lex_state = 0, .external_lex_state = 23},
  [9462] = {.lex_state = 0, .external_lex_state = 23},
  [9463] = {.lex_state = 0, .external_lex_state = 23},
  [9464] = {.lex_state = 0, .external_lex_state = 23},
  [9465] = {.lex_state = 0, .external_lex_state = 23},
  [9466] = {.lex_state = 0, .external_lex_state = 23},
  [9467] = {.lex_state = 0, .external_lex_state = 23},
  [9468] = {.lex_state = 0, .external_lex_state = 23},
  [9469] = {.lex_state = 91},
  [9470] = {.lex_state = 0, .external_lex_state = 23},
  [9471] = {.lex_state = 91},
  [9472] = {.lex_state = 0, .external_lex_state = 23},
  [9473] = {.lex_state = 0, .external_lex_state = 23},
  [9474] = {.lex_state = 0, .external_lex_state = 23},
  [9475] = {.lex_state = 0, .external_lex_state = 23},
  [9476] = {.lex_state = 0, .external_lex_state = 23},
  [9477] = {.lex_state = 0, .external_lex_state = 23},
  [9478] = {.lex_state = 0, .external_lex_state = 23},
  [9479] = {.lex_state = 0, .external_lex_state = 23},
  [9480] = {.lex_state = 0, .external_lex_state = 23},
  [9481] = {.lex_state = 0, .external_lex_state = 23},
  [9482] = {.lex_state = 0, .external_lex_state = 23},
  [9483] = {.lex_state = 0, .external_lex_state = 23},
  [9484] = {.lex_state = 0, .external_lex_state = 23},
  [9485] = {.lex_state = 0, .external_lex_state = 23},
  [9486] = {.lex_state = 0, .external_lex_state = 23},
  [9487] = {.lex_state = 0, .external_lex_state = 23},
  [9488] = {.lex_state = 0, .external_lex_state = 23},
  [9489] = {.lex_state = 91},
  [9490] = {.lex_state = 0, .external_lex_state = 23},
  [9491] = {.lex_state = 91},
  [9492] = {.lex_state = 0, .external_lex_state = 23},
  [9493] = {.lex_state = 0, .external_lex_state = 23},
  [9494] = {.lex_state = 0, .external_lex_state = 23},
  [9495] = {.lex_state = 0, .external_lex_state = 23},
  [9496] = {.lex_state = 91},
  [9497] = {.lex_state = 91},
  [9498] = {.lex_state = 91},
  [9499] = {.lex_state = 91},
  [9500] = {.lex_state = 0, .external_lex_state = 23},
  [9501] = {.lex_state = 0, .external_lex_state = 23},
  [9502] = {.lex_state = 0, .external_lex_state = 23},
  [9503] = {.lex_state = 0, .external_lex_state = 23},
  [9504] = {.lex_state = 0, .external_lex_state = 23},
  [9505] = {.lex_state = 0, .external_lex_state = 23},
  [9506] = {.lex_state = 0, .external_lex_state = 23},
  [9507] = {.lex_state = 0, .external_lex_state = 23},
  [9508] = {.lex_state = 0, .external_lex_state = 23},
  [9509] = {.lex_state = 0, .external_lex_state = 23},
  [9510] = {.lex_state = 0, .external_lex_state = 23},
  [9511] = {.lex_state = 0, .external_lex_state = 23},
  [9512] = {.lex_state = 0, .external_lex_state = 23},
  [9513] = {.lex_state = 0, .external_lex_state = 23},
  [9514] = {.lex_state = 0, .external_lex_state = 23},
  [9515] = {.lex_state = 0, .external_lex_state = 23},
  [9516] = {.lex_state = 0, .external_lex_state = 23},
  [9517] = {.lex_state = 0},
  [9518] = {.lex_state = 0, .external_lex_state = 23},
  [9519] = {.lex_state = 0, .external_lex_state = 23},
  [9520] = {.lex_state = 0, .external_lex_state = 23},
  [9521] = {.lex_state = 0, .external_lex_state = 23},
  [9522] = {.lex_state = 0, .external_lex_state = 23},
  [9523] = {.lex_state = 0, .external_lex_state = 23},
  [9524] = {.lex_state = 0, .external_lex_state = 23},
  [9525] = {.lex_state = 0, .external_lex_state = 23},
  [9526] = {.lex_state = 0, .external_lex_state = 23},
  [9527] = {.lex_state = 0, .external_lex_state = 23},
  [9528] = {.lex_state = 0, .external_lex_state = 23},
  [9529] = {.lex_state = 0},
  [9530] = {.lex_state = 0, .external_lex_state = 23},
  [9531] = {.lex_state = 0, .external_lex_state = 23},
  [9532] = {.lex_state = 0, .external_lex_state = 23},
  [9533] = {.lex_state = 0, .external_lex_state = 23},
  [9534] = {.lex_state = 0, .external_lex_state = 23},
  [9535] = {.lex_state = 0, .external_lex_state = 23},
  [9536] = {.lex_state = 0, .external_lex_state = 23},
  [9537] = {.lex_state = 0, .external_lex_state = 23},
  [9538] = {.lex_state = 0, .external_lex_state = 23},
  [9539] = {.lex_state = 0},
  [9540] = {.lex_state = 0, .external_lex_state = 23},
  [9541] = {.lex_state = 0, .external_lex_state = 23},
  [9542] = {.lex_state = 0, .external_lex_state = 23},
  [9543] = {.lex_state = 0, .external_lex_state = 23},
  [9544] = {.lex_state = 0, .external_lex_state = 23},
  [9545] = {.lex_state = 0, .external_lex_state = 23},
  [9546] = {.lex_state = 0, .external_lex_state = 23},
  [9547] = {.lex_state = 0, .external_lex_state = 23},
  [9548] = {.lex_state = 0, .external_lex_state = 23},
  [9549] = {.lex_state = 0, .external_lex_state = 23},
  [9550] = {.lex_state = 0, .external_lex_state = 23},
  [9551] = {.lex_state = 0, .external_lex_state = 23},
  [9552] = {.lex_state = 0, .external_lex_state = 23},
  [9553] = {.lex_state = 0, .external_lex_state = 23},
  [9554] = {.lex_state = 0, .external_lex_state = 23},
  [9555] = {.lex_state = 0, .external_lex_state = 23},
  [9556] = {.lex_state = 0, .external_lex_state = 23},
  [9557] = {.lex_state = 0, .external_lex_state = 23},
  [9558] = {.lex_state = 0, .external_lex_state = 23},
  [9559] = {.lex_state = 0, .external_lex_state = 23},
  [9560] = {.lex_state = 0, .external_lex_state = 23},
  [9561] = {.lex_state = 0, .external_lex_state = 23},
  [9562] = {.lex_state = 0, .external_lex_state = 23},
  [9563] = {.lex_state = 0, .external_lex_state = 23},
  [9564] = {.lex_state = 0, .external_lex_state = 23},
  [9565] = {.lex_state = 0, .external_lex_state = 23},
  [9566] = {.lex_state = 0, .external_lex_state = 23},
  [9567] = {.lex_state = 0, .external_lex_state = 23},
  [9568] = {.lex_state = 0, .external_lex_state = 23},
  [9569] = {.lex_state = 0, .external_lex_state = 23},
  [9570] = {.lex_state = 0, .external_lex_state = 23},
  [9571] = {.lex_state = 0, .external_lex_state = 23},
  [9572] = {.lex_state = 0, .external_lex_state = 23},
  [9573] = {.lex_state = 91},
  [9574] = {.lex_state = 91},
  [9575] = {.lex_state = 0, .external_lex_state = 23},
  [9576] = {.lex_state = 0, .external_lex_state = 23},
  [9577] = {.lex_state = 0, .external_lex_state = 23},
  [9578] = {.lex_state = 0, .external_lex_state = 23},
  [9579] = {.lex_state = 0, .external_lex_state = 23},
  [9580] = {.lex_state = 0, .external_lex_state = 23},
  [9581] = {.lex_state = 0, .external_lex_state = 23},
  [9582] = {.lex_state = 0},
  [9583] = {.lex_state = 0, .external_lex_state = 23},
  [9584] = {.lex_state = 0, .external_lex_state = 23},
  [9585] = {.lex_state = 0, .external_lex_state = 23},
  [9586] = {.lex_state = 0, .external_lex_state = 23},
  [9587] = {.lex_state = 0, .external_lex_state = 23},
  [9588] = {.lex_state = 0, .external_lex_state = 23},
  [9589] = {.lex_state = 0, .external_lex_state = 23},
  [9590] = {.lex_state = 0, .external_lex_state = 23},
  [9591] = {.lex_state = 0, .external_lex_state = 23},
  [9592] = {.lex_state = 0, .external_lex_state = 23},
  [9593] = {.lex_state = 0, .external_lex_state = 23},
  [9594] = {.lex_state = 0, .external_lex_state = 23},
  [9595] = {.lex_state = 0, .external_lex_state = 23},
  [9596] = {.lex_state = 0, .external_lex_state = 23},
  [9597] = {.lex_state = 0, .external_lex_state = 23},
  [9598] = {.lex_state = 0, .external_lex_state = 23},
  [9599] = {.lex_state = 0, .external_lex_state = 23},
  [9600] = {.lex_state = 0, .external_lex_state = 23},
  [9601] = {.lex_state = 0, .external_lex_state = 23},
  [9602] = {.lex_state = 0, .external_lex_state = 23},
  [9603] = {.lex_state = 0, .external_lex_state = 23},
  [9604] = {.lex_state = 0, .external_lex_state = 23},
  [9605] = {.lex_state = 0, .external_lex_state = 23},
  [9606] = {.lex_state = 0, .external_lex_state = 23},
  [9607] = {.lex_state = 0, .external_lex_state = 23},
  [9608] = {.lex_state = 0, .external_lex_state = 23},
  [9609] = {.lex_state = 0, .external_lex_state = 23},
  [9610] = {.lex_state = 0, .external_lex_state = 23},
  [9611] = {.lex_state = 0, .external_lex_state = 23},
  [9612] = {.lex_state = 0, .external_lex_state = 23},
  [9613] = {.lex_state = 0, .external_lex_state = 23},
  [9614] = {.lex_state = 0, .external_lex_state = 23},
  [9615] = {.lex_state = 0, .external_lex_state = 23},
  [9616] = {.lex_state = 91},
  [9617] = {.lex_state = 0, .external_lex_state = 23},
  [9618] = {.lex_state = 0, .external_lex_state = 23},
  [9619] = {.lex_state = 91},
  [9620] = {.lex_state = 91},
  [9621] = {.lex_state = 91},
  [9622] = {.lex_state = 0, .external_lex_state = 23},
  [9623] = {.lex_state = 91},
  [9624] = {.lex_state = 91},
  [9625] = {.lex_state = 91},
  [9626] = {.lex_state = 0, .external_lex_state = 23},
  [9627] = {.lex_state = 0, .external_lex_state = 23},
  [9628] = {.lex_state = 0, .external_lex_state = 23},
  [9629] = {.lex_state = 91},
  [9630] = {.lex_state = 0, .external_lex_state = 23},
  [9631] = {.lex_state = 0, .external_lex_state = 23},
  [9632] = {.lex_state = 91},
  [9633] = {.lex_state = 91},
  [9634] = {.lex_state = 0, .external_lex_state = 23},
  [9635] = {.lex_state = 0, .external_lex_state = 23},
  [9636] = {.lex_state = 0, .external_lex_state = 23},
  [9637] = {.lex_state = 0, .external_lex_state = 23},
  [9638] = {.lex_state = 91},
  [9639] = {.lex_state = 91},
  [9640] = {.lex_state = 0, .external_lex_state = 23},
  [9641] = {.lex_state = 0},
  [9642] = {.lex_state = 91},
  [9643] = {.lex_state = 91},
  [9644] = {.lex_state = 91},
  [9645] = {.lex_state = 91},
  [9646] = {.lex_state = 91},
  [9647] = {.lex_state = 91},
  [9648] = {.lex_state = 91},
  [9649] = {.lex_state = 0, .external_lex_state = 23},
  [9650] = {.lex_state = 91},
  [9651] = {.lex_state = 0, .external_lex_state = 23},
  [9652] = {.lex_state = 0, .external_lex_state = 23},
  [9653] = {.lex_state = 91},
  [9654] = {.lex_state = 91},
  [9655] = {.lex_state = 91},
  [9656] = {.lex_state = 91},
  [9657] = {.lex_state = 0, .external_lex_state = 23},
  [9658] = {.lex_state = 91},
  [9659] = {.lex_state = 91},
  [9660] = {.lex_state = 91},
  [9661] = {.lex_state = 91},
  [9662] = {.lex_state = 0, .external_lex_state = 23},
  [9663] = {.lex_state = 0, .external_lex_state = 23},
  [9664] = {.lex_state = 91},
  [9665] = {.lex_state = 91},
  [9666] = {.lex_state = 91},
  [9667] = {.lex_state = 91},
  [9668] = {.lex_state = 91},
  [9669] = {.lex_state = 91},
  [9670] = {.lex_state = 91},
  [9671] = {.lex_state = 91},
  [9672] = {.lex_state = 0, .external_lex_state = 23},
  [9673] = {.lex_state = 0, .external_lex_state = 23},
  [9674] = {.lex_state = 0, .external_lex_state = 23},
  [9675] = {.lex_state = 0, .external_lex_state = 23},
  [9676] = {.lex_state = 0, .external_lex_state = 23},
  [9677] = {.lex_state = 0, .external_lex_state = 23},
  [9678] = {.lex_state = 0, .external_lex_state = 23},
  [9679] = {.lex_state = 0, .external_lex_state = 23},
  [9680] = {.lex_state = 0, .external_lex_state = 23},
  [9681] = {.lex_state = 0, .external_lex_state = 23},
  [9682] = {.lex_state = 0, .external_lex_state = 23},
  [9683] = {.lex_state = 0, .external_lex_state = 23},
  [9684] = {.lex_state = 0, .external_lex_state = 23},
  [9685] = {.lex_state = 0, .external_lex_state = 23},
  [9686] = {.lex_state = 91},
  [9687] = {.lex_state = 0, .external_lex_state = 23},
  [9688] = {.lex_state = 0, .external_lex_state = 23},
  [9689] = {.lex_state = 0, .external_lex_state = 23},
  [9690] = {.lex_state = 0, .external_lex_state = 23},
  [9691] = {.lex_state = 0, .external_lex_state = 23},
  [9692] = {.lex_state = 0, .external_lex_state = 23},
  [9693] = {.lex_state = 0, .external_lex_state = 23},
  [9694] = {.lex_state = 6},
  [9695] = {.lex_state = 0, .external_lex_state = 23},
  [9696] = {.lex_state = 91},
  [9697] = {.lex_state = 0, .external_lex_state = 23},
  [9698] = {.lex_state = 0, .external_lex_state = 23},
  [9699] = {.lex_state = 2},
  [9700] = {.lex_state = 0, .external_lex_state = 23},
  [9701] = {.lex_state = 0, .external_lex_state = 23},
  [9702] = {.lex_state = 0, .external_lex_state = 23},
  [9703] = {.lex_state = 0, .external_lex_state = 23},
  [9704] = {.lex_state = 0, .external_lex_state = 23},
  [9705] = {.lex_state = 0, .external_lex_state = 23},
  [9706] = {.lex_state = 0, .external_lex_state = 23},
  [9707] = {.lex_state = 0, .external_lex_state = 23},
  [9708] = {.lex_state = 0, .external_lex_state = 23},
  [9709] = {.lex_state = 91},
  [9710] = {.lex_state = 91},
  [9711] = {.lex_state = 2},
  [9712] = {.lex_state = 0, .external_lex_state = 23},
  [9713] = {.lex_state = 0, .external_lex_state = 23},
  [9714] = {.lex_state = 0, .external_lex_state = 23},
  [9715] = {.lex_state = 91},
  [9716] = {.lex_state = 0, .external_lex_state = 23},
  [9717] = {.lex_state = 0, .external_lex_state = 23},
  [9718] = {.lex_state = 0, .external_lex_state = 23},
  [9719] = {.lex_state = 0, .external_lex_state = 23},
  [9720] = {.lex_state = 0, .external_lex_state = 23},
  [9721] = {.lex_state = 0, .external_lex_state = 23},
  [9722] = {.lex_state = 0, .external_lex_state = 23},
  [9723] = {.lex_state = 0, .external_lex_state = 23},
  [9724] = {.lex_state = 0, .external_lex_state = 23},
  [9725] = {.lex_state = 0, .external_lex_state = 23},
  [9726] = {.lex_state = 0, .external_lex_state = 23},
  [9727] = {.lex_state = 0, .external_lex_state = 23},
  [9728] = {.lex_state = 0, .external_lex_state = 23},
  [9729] = {.lex_state = 0, .external_lex_state = 23},
  [9730] = {.lex_state = 0, .external_lex_state = 23},
  [9731] = {.lex_state = 0, .external_lex_state = 23},
  [9732] = {.lex_state = 0, .external_lex_state = 23},
  [9733] = {.lex_state = 0, .external_lex_state = 23},
  [9734] = {.lex_state = 0, .external_lex_state = 23},
  [9735] = {.lex_state = 0, .external_lex_state = 23},
  [9736] = {.lex_state = 0, .external_lex_state = 23},
  [9737] = {.lex_state = 0, .external_lex_state = 23},
  [9738] = {.lex_state = 0, .external_lex_state = 23},
  [9739] = {.lex_state = 0, .external_lex_state = 23},
  [9740] = {.lex_state = 0, .external_lex_state = 23},
  [9741] = {.lex_state = 0, .external_lex_state = 23},
  [9742] = {.lex_state = 0, .external_lex_state = 23},
  [9743] = {.lex_state = 91},
  [9744] = {.lex_state = 91},
  [9745] = {.lex_state = 0, .external_lex_state = 23},
  [9746] = {.lex_state = 0, .external_lex_state = 23},
  [9747] = {.lex_state = 91},
  [9748] = {.lex_state = 0, .external_lex_state = 23},
  [9749] = {.lex_state = 0, .external_lex_state = 23},
  [9750] = {.lex_state = 0, .external_lex_state = 23},
  [9751] = {.lex_state = 0, .external_lex_state = 23},
  [9752] = {.lex_state = 0, .external_lex_state = 23},
  [9753] = {.lex_state = 0, .external_lex_state = 23},
  [9754] = {.lex_state = 0, .external_lex_state = 23},
  [9755] = {.lex_state = 0, .external_lex_state = 23},
  [9756] = {.lex_state = 0, .external_lex_state = 23},
  [9757] = {.lex_state = 0, .external_lex_state = 23},
  [9758] = {.lex_state = 0, .external_lex_state = 23},
  [9759] = {.lex_state = 0, .external_lex_state = 23},
  [9760] = {.lex_state = 0, .external_lex_state = 23},
  [9761] = {.lex_state = 0, .external_lex_state = 23},
  [9762] = {.lex_state = 0, .external_lex_state = 23},
  [9763] = {.lex_state = 0, .external_lex_state = 23},
  [9764] = {.lex_state = 0, .external_lex_state = 23},
  [9765] = {.lex_state = 0, .external_lex_state = 23},
  [9766] = {.lex_state = 0, .external_lex_state = 23},
  [9767] = {.lex_state = 0, .external_lex_state = 23},
  [9768] = {.lex_state = 0, .external_lex_state = 23},
  [9769] = {.lex_state = 91},
  [9770] = {.lex_state = 91},
  [9771] = {.lex_state = 91},
  [9772] = {.lex_state = 0, .external_lex_state = 23},
  [9773] = {.lex_state = 0, .external_lex_state = 23},
  [9774] = {.lex_state = 0, .external_lex_state = 23},
  [9775] = {.lex_state = 0, .external_lex_state = 23},
  [9776] = {.lex_state = 0, .external_lex_state = 23},
  [9777] = {.lex_state = 91},
  [9778] = {.lex_state = 0, .external_lex_state = 23},
  [9779] = {.lex_state = 0, .external_lex_state = 23},
  [9780] = {.lex_state = 0, .external_lex_state = 23},
  [9781] = {.lex_state = 0, .external_lex_state = 23},
  [9782] = {.lex_state = 0, .external_lex_state = 23},
  [9783] = {.lex_state = 0, .external_lex_state = 23},
  [9784] = {.lex_state = 0, .external_lex_state = 23},
  [9785] = {.lex_state = 0, .external_lex_state = 23},
  [9786] = {.lex_state = 0, .external_lex_state = 23},
  [9787] = {.lex_state = 0, .external_lex_state = 23},
  [9788] = {.lex_state = 0, .external_lex_state = 23},
  [9789] = {.lex_state = 0, .external_lex_state = 23},
  [9790] = {.lex_state = 0, .external_lex_state = 23},
  [9791] = {.lex_state = 0, .external_lex_state = 23},
  [9792] = {.lex_state = 0, .external_lex_state = 23},
  [9793] = {.lex_state = 0, .external_lex_state = 23},
  [9794] = {.lex_state = 0, .external_lex_state = 23},
  [9795] = {.lex_state = 0, .external_lex_state = 23},
  [9796] = {.lex_state = 0, .external_lex_state = 23},
  [9797] = {.lex_state = 0, .external_lex_state = 23},
  [9798] = {.lex_state = 0, .external_lex_state = 23},
  [9799] = {.lex_state = 0, .external_lex_state = 23},
  [9800] = {.lex_state = 1},
  [9801] = {.lex_state = 0, .external_lex_state = 23},
  [9802] = {.lex_state = 0, .external_lex_state = 23},
  [9803] = {.lex_state = 0, .external_lex_state = 23},
  [9804] = {.lex_state = 0, .external_lex_state = 23},
  [9805] = {.lex_state = 0, .external_lex_state = 23},
  [9806] = {.lex_state = 0, .external_lex_state = 23},
  [9807] = {.lex_state = 0, .external_lex_state = 23},
  [9808] = {.lex_state = 91},
  [9809] = {.lex_state = 0, .external_lex_state = 23},
  [9810] = {.lex_state = 0, .external_lex_state = 23},
  [9811] = {.lex_state = 0, .external_lex_state = 23},
  [9812] = {.lex_state = 0, .external_lex_state = 23},
  [9813] = {.lex_state = 0, .external_lex_state = 23},
  [9814] = {.lex_state = 0, .external_lex_state = 23},
  [9815] = {.lex_state = 0, .external_lex_state = 23},
  [9816] = {.lex_state = 0, .external_lex_state = 23},
  [9817] = {.lex_state = 0, .external_lex_state = 23},
  [9818] = {.lex_state = 0, .external_lex_state = 23},
  [9819] = {.lex_state = 0, .external_lex_state = 23},
  [9820] = {.lex_state = 0, .external_lex_state = 23},
  [9821] = {.lex_state = 0, .external_lex_state = 23},
  [9822] = {.lex_state = 0, .external_lex_state = 23},
  [9823] = {.lex_state = 0, .external_lex_state = 23},
  [9824] = {.lex_state = 1},
  [9825] = {.lex_state = 0, .external_lex_state = 23},
  [9826] = {.lex_state = 0, .external_lex_state = 23},
  [9827] = {.lex_state = 0, .external_lex_state = 23},
  [9828] = {.lex_state = 0, .external_lex_state = 23},
  [9829] = {.lex_state = 0, .external_lex_state = 23},
  [9830] = {.lex_state = 0, .external_lex_state = 23},
  [9831] = {.lex_state = 0, .external_lex_state = 23},
  [9832] = {.lex_state = 91},
  [9833] = {.lex_state = 0, .external_lex_state = 23},
  [9834] = {.lex_state = 0, .external_lex_state = 23},
  [9835] = {.lex_state = 0, .external_lex_state = 23},
  [9836] = {.lex_state = 91},
  [9837] = {.lex_state = 91},
  [9838] = {.lex_state = 0, .external_lex_state = 23},
  [9839] = {.lex_state = 0, .external_lex_state = 23},
  [9840] = {.lex_state = 91},
  [9841] = {.lex_state = 0, .external_lex_state = 23},
  [9842] = {.lex_state = 0, .external_lex_state = 23},
  [9843] = {.lex_state = 0, .external_lex_state = 23},
  [9844] = {.lex_state = 0, .external_lex_state = 23},
  [9845] = {.lex_state = 0, .external_lex_state = 23},
  [9846] = {.lex_state = 0, .external_lex_state = 23},
  [9847] = {.lex_state = 0, .external_lex_state = 23},
  [9848] = {.lex_state = 0, .external_lex_state = 23},
  [9849] = {.lex_state = 0, .external_lex_state = 23},
  [9850] = {.lex_state = 0, .external_lex_state = 23},
  [9851] = {.lex_state = 0, .external_lex_state = 23},
  [9852] = {.lex_state = 0, .external_lex_state = 23},
  [9853] = {.lex_state = 0, .external_lex_state = 23},
  [9854] = {.lex_state = 0, .external_lex_state = 23},
  [9855] = {.lex_state = 0, .external_lex_state = 23},
  [9856] = {.lex_state = 0, .external_lex_state = 23},
  [9857] = {.lex_state = 0, .external_lex_state = 23},
  [9858] = {.lex_state = 0, .external_lex_state = 23},
  [9859] = {.lex_state = 0, .external_lex_state = 23},
  [9860] = {.lex_state = 0, .external_lex_state = 23},
  [9861] = {.lex_state = 0, .external_lex_state = 23},
  [9862] = {.lex_state = 0, .external_lex_state = 23},
  [9863] = {.lex_state = 0, .external_lex_state = 23},
  [9864] = {.lex_state = 0, .external_lex_state = 23},
  [9865] = {.lex_state = 0, .external_lex_state = 23},
  [9866] = {.lex_state = 0, .external_lex_state = 23},
  [9867] = {.lex_state = 91},
  [9868] = {.lex_state = 0, .external_lex_state = 23},
  [9869] = {.lex_state = 0, .external_lex_state = 23},
  [9870] = {.lex_state = 0, .external_lex_state = 23},
  [9871] = {.lex_state = 0, .external_lex_state = 23},
  [9872] = {.lex_state = 0, .external_lex_state = 23},
  [9873] = {.lex_state = 91},
  [9874] = {.lex_state = 0, .external_lex_state = 23},
  [9875] = {.lex_state = 0, .external_lex_state = 23},
  [9876] = {.lex_state = 0, .external_lex_state = 23},
  [9877] = {.lex_state = 0, .external_lex_state = 23},
  [9878] = {.lex_state = 91},
  [9879] = {.lex_state = 0, .external_lex_state = 23},
  [9880] = {.lex_state = 0, .external_lex_state = 23},
  [9881] = {.lex_state = 0, .external_lex_state = 23},
  [9882] = {.lex_state = 0, .external_lex_state = 23},
  [9883] = {.lex_state = 0, .external_lex_state = 23},
  [9884] = {.lex_state = 0, .external_lex_state = 23},
  [9885] = {.lex_state = 0, .external_lex_state = 23},
  [9886] = {.lex_state = 91},
  [9887] = {.lex_state = 0, .external_lex_state = 23},
  [9888] = {.lex_state = 0, .external_lex_state = 23},
  [9889] = {.lex_state = 0, .external_lex_state = 23},
  [9890] = {.lex_state = 0, .external_lex_state = 23},
  [9891] = {.lex_state = 0, .external_lex_state = 23},
  [9892] = {.lex_state = 91},
  [9893] = {.lex_state = 0, .external_lex_state = 23},
  [9894] = {.lex_state = 0, .external_lex_state = 23},
  [9895] = {.lex_state = 0, .external_lex_state = 23},
  [9896] = {.lex_state = 0, .external_lex_state = 23},
  [9897] = {.lex_state = 0, .external_lex_state = 23},
  [9898] = {.lex_state = 0},
  [9899] = {.lex_state = 0, .external_lex_state = 23},
  [9900] = {.lex_state = 91},
  [9901] = {.lex_state = 0, .external_lex_state = 23},
  [9902] = {.lex_state = 0, .external_lex_state = 23},
  [9903] = {.lex_state = 0, .external_lex_state = 23},
  [9904] = {.lex_state = 0, .external_lex_state = 23},
  [9905] = {.lex_state = 0, .external_lex_state = 23},
  [9906] = {.lex_state = 0},
  [9907] = {.lex_state = 0, .external_lex_state = 23},
  [9908] = {.lex_state = 91},
  [9909] = {.lex_state = 91},
  [9910] = {.lex_state = 0, .external_lex_state = 23},
  [9911] = {.lex_state = 0, .external_lex_state = 23},
  [9912] = {.lex_state = 0, .external_lex_state = 23},
  [9913] = {.lex_state = 0},
  [9914] = {.lex_state = 0, .external_lex_state = 23},
  [9915] = {.lex_state = 0},
  [9916] = {.lex_state = 0, .external_lex_state = 23},
  [9917] = {.lex_state = 0},
  [9918] = {.lex_state = 0},
  [9919] = {.lex_state = 0},
  [9920] = {.lex_state = 0},
  [9921] = {.lex_state = 0},
  [9922] = {.lex_state = 0},
  [9923] = {.lex_state = 0},
  [9924] = {.lex_state = 0},
  [9925] = {.lex_state = 0},
  [9926] = {.lex_state = 0},
  [9927] = {.lex_state = 0},
  [9928] = {.lex_state = 0},
  [9929] = {.lex_state = 0},
  [9930] = {.lex_state = 0},
  [9931] = {.lex_state = 0, .external_lex_state = 23},
  [9932] = {.lex_state = 0, .external_lex_state = 23},
  [9933] = {.lex_state = 0, .external_lex_state = 23},
  [9934] = {.lex_state = 0, .external_lex_state = 23},
  [9935] = {.lex_state = 0, .external_lex_state = 23},
  [9936] = {.lex_state = 0, .external_lex_state = 23},
  [9937] = {.lex_state = 0, .external_lex_state = 23},
  [9938] = {.lex_state = 91},
  [9939] = {.lex_state = 91},
  [9940] = {.lex_state = 91},
  [9941] = {.lex_state = 91},
  [9942] = {.lex_state = 91},
  [9943] = {.lex_state = 91},
  [9944] = {.lex_state = 91},
  [9945] = {.lex_state = 91},
  [9946] = {.lex_state = 91},
  [9947] = {.lex_state = 0},
  [9948] = {.lex_state = 91},
  [9949] = {.lex_state = 91},
  [9950] = {.lex_state = 91},
  [9951] = {.lex_state = 0},
  [9952] = {.lex_state = 0},
  [9953] = {.lex_state = 91},
  [9954] = {.lex_state = 91},
  [9955] = {.lex_state = 91},
  [9956] = {.lex_state = 0},
  [9957] = {.lex_state = 91},
  [9958] = {.lex_state = 91},
  [9959] = {.lex_state = 91},
  [9960] = {.lex_state = 91},
  [9961] = {.lex_state = 91},
  [9962] = {.lex_state = 91},
  [9963] = {.lex_state = 91},
  [9964] = {.lex_state = 91},
  [9965] = {.lex_state = 91},
  [9966] = {.lex_state = 91},
  [9967] = {.lex_state = 91},
  [9968] = {.lex_state = 91},
  [9969] = {.lex_state = 91},
  [9970] = {.lex_state = 91},
  [9971] = {.lex_state = 91},
  [9972] = {.lex_state = 91},
  [9973] = {.lex_state = 91},
  [9974] = {.lex_state = 91},
  [9975] = {.lex_state = 91},
  [9976] = {.lex_state = 91},
  [9977] = {.lex_state = 91},
  [9978] = {.lex_state = 91},
  [9979] = {.lex_state = 91},
  [9980] = {.lex_state = 91},
  [9981] = {.lex_state = 91},
  [9982] = {.lex_state = 91},
  [9983] = {.lex_state = 91},
  [9984] = {.lex_state = 91},
  [9985] = {.lex_state = 0},
  [9986] = {.lex_state = 91},
  [9987] = {.lex_state = 91},
  [9988] = {.lex_state = 91},
  [9989] = {.lex_state = 91},
  [9990] = {.lex_state = 91, .external_lex_state = 28},
  [9991] = {.lex_state = 91},
  [9992] = {.lex_state = 91},
  [9993] = {.lex_state = 91},
  [9994] = {.lex_state = 91},
  [9995] = {.lex_state = 91},
  [9996] = {.lex_state = 91},
  [9997] = {.lex_state = 0},
  [9998] = {.lex_state = 91},
  [9999] = {.lex_state = 91},
  [10000] = {.lex_state = 91},
  [10001] = {.lex_state = 91},
  [10002] = {.lex_state = 91},
  [10003] = {.lex_state = 91},
  [10004] = {.lex_state = 91},
  [10005] = {.lex_state = 91},
  [10006] = {.lex_state = 91},
  [10007] = {.lex_state = 91},
  [10008] = {.lex_state = 91},
  [10009] = {.lex_state = 91},
  [10010] = {.lex_state = 91},
  [10011] = {.lex_state = 91},
  [10012] = {.lex_state = 91},
  [10013] = {.lex_state = 91},
  [10014] = {.lex_state = 91},
  [10015] = {.lex_state = 91},
  [10016] = {.lex_state = 91},
  [10017] = {.lex_state = 91},
  [10018] = {.lex_state = 91},
  [10019] = {.lex_state = 91},
  [10020] = {.lex_state = 91},
  [10021] = {.lex_state = 91},
  [10022] = {.lex_state = 91},
  [10023] = {.lex_state = 91},
  [10024] = {.lex_state = 91},
  [10025] = {.lex_state = 91},
  [10026] = {.lex_state = 91},
  [10027] = {.lex_state = 91},
  [10028] = {.lex_state = 0},
  [10029] = {.lex_state = 91},
  [10030] = {.lex_state = 91},
  [10031] = {.lex_state = 91},
  [10032] = {.lex_state = 91},
  [10033] = {.lex_state = 0},
  [10034] = {.lex_state = 0},
  [10035] = {.lex_state = 91},
  [10036] = {.lex_state = 91},
  [10037] = {.lex_state = 0},
  [10038] = {.lex_state = 91},
  [10039] = {.lex_state = 91},
  [10040] = {.lex_state = 91},
  [10041] = {.lex_state = 91},
  [10042] = {.lex_state = 91},
  [10043] = {.lex_state = 91},
  [10044] = {.lex_state = 91},
  [10045] = {.lex_state = 91},
  [10046] = {.lex_state = 91},
  [10047] = {.lex_state = 91},
  [10048] = {.lex_state = 0},
  [10049] = {.lex_state = 91},
  [10050] = {.lex_state = 91},
  [10051] = {.lex_state = 91},
  [10052] = {.lex_state = 91},
  [10053] = {.lex_state = 91},
  [10054] = {.lex_state = 91},
  [10055] = {.lex_state = 91},
  [10056] = {.lex_state = 91},
  [10057] = {.lex_state = 91},
  [10058] = {.lex_state = 91},
  [10059] = {.lex_state = 91},
  [10060] = {.lex_state = 91},
  [10061] = {.lex_state = 91},
  [10062] = {.lex_state = 91},
  [10063] = {.lex_state = 91},
  [10064] = {.lex_state = 91},
  [10065] = {.lex_state = 91},
  [10066] = {.lex_state = 91},
  [10067] = {.lex_state = 91},
  [10068] = {.lex_state = 91},
  [10069] = {.lex_state = 91},
  [10070] = {.lex_state = 91},
  [10071] = {.lex_state = 91},
  [10072] = {.lex_state = 91},
  [10073] = {.lex_state = 91},
  [10074] = {.lex_state = 91},
  [10075] = {.lex_state = 0},
  [10076] = {.lex_state = 91},
  [10077] = {.lex_state = 91},
  [10078] = {.lex_state = 91},
  [10079] = {.lex_state = 91},
  [10080] = {.lex_state = 0},
  [10081] = {.lex_state = 0},
  [10082] = {.lex_state = 91},
  [10083] = {.lex_state = 0},
  [10084] = {.lex_state = 91},
  [10085] = {.lex_state = 91},
  [10086] = {.lex_state = 91},
  [10087] = {.lex_state = 91},
  [10088] = {.lex_state = 91},
  [10089] = {.lex_state = 91},
  [10090] = {.lex_state = 91},
  [10091] = {.lex_state = 91},
  [10092] = {.lex_state = 91},
  [10093] = {.lex_state = 91},
  [10094] = {.lex_state = 91},
  [10095] = {.lex_state = 91},
  [10096] = {.lex_state = 91},
  [10097] = {.lex_state = 91},
  [10098] = {.lex_state = 91},
  [10099] = {.lex_state = 91},
  [10100] = {.lex_state = 0},
  [10101] = {.lex_state = 91},
  [10102] = {.lex_state = 91, .external_lex_state = 28},
  [10103] = {.lex_state = 91},
  [10104] = {.lex_state = 0},
  [10105] = {.lex_state = 0},
  [10106] = {.lex_state = 91},
  [10107] = {.lex_state = 91},
  [10108] = {.lex_state = 0},
  [10109] = {.lex_state = 91},
  [10110] = {.lex_state = 91},
  [10111] = {.lex_state = 91},
  [10112] = {.lex_state = 91},
  [10113] = {.lex_state = 91},
  [10114] = {.lex_state = 91},
  [10115] = {.lex_state = 91},
  [10116] = {.lex_state = 91},
  [10117] = {.lex_state = 91},
  [10118] = {.lex_state = 91},
  [10119] = {.lex_state = 91},
  [10120] = {.lex_state = 91},
  [10121] = {.lex_state = 91},
  [10122] = {.lex_state = 91},
  [10123] = {.lex_state = 91},
  [10124] = {.lex_state = 91},
  [10125] = {.lex_state = 91},
  [10126] = {.lex_state = 91},
  [10127] = {.lex_state = 91},
  [10128] = {.lex_state = 91},
  [10129] = {.lex_state = 91},
  [10130] = {.lex_state = 91},
  [10131] = {.lex_state = 91},
  [10132] = {.lex_state = 91},
  [10133] = {.lex_state = 91},
  [10134] = {.lex_state = 91},
  [10135] = {.lex_state = 91},
  [10136] = {.lex_state = 91},
  [10137] = {.lex_state = 91},
  [10138] = {.lex_state = 91},
  [10139] = {.lex_state = 91},
  [10140] = {.lex_state = 91},
  [10141] = {.lex_state = 91},
  [10142] = {.lex_state = 91},
  [10143] = {.lex_state = 91},
  [10144] = {.lex_state = 91},
  [10145] = {.lex_state = 91},
  [10146] = {.lex_state = 91},
  [10147] = {.lex_state = 91},
  [10148] = {.lex_state = 91},
  [10149] = {.lex_state = 91},
  [10150] = {.lex_state = 91},
  [10151] = {.lex_state = 91},
  [10152] = {.lex_state = 91},
  [10153] = {.lex_state = 91},
  [10154] = {.lex_state = 91},
  [10155] = {.lex_state = 91},
  [10156] = {.lex_state = 91},
  [10157] = {.lex_state = 91},
  [10158] = {.lex_state = 91},
  [10159] = {.lex_state = 91},
  [10160] = {.lex_state = 91},
  [10161] = {.lex_state = 91},
  [10162] = {.lex_state = 91},
  [10163] = {.lex_state = 91},
  [10164] = {.lex_state = 91},
  [10165] = {.lex_state = 91},
  [10166] = {.lex_state = 91},
  [10167] = {.lex_state = 91},
  [10168] = {.lex_state = 0, .external_lex_state = 23},
  [10169] = {.lex_state = 91},
  [10170] = {.lex_state = 91},
  [10171] = {.lex_state = 91},
  [10172] = {.lex_state = 91},
  [10173] = {.lex_state = 91},
  [10174] = {.lex_state = 91},
  [10175] = {.lex_state = 91},
  [10176] = {.lex_state = 91},
  [10177] = {.lex_state = 91},
  [10178] = {.lex_state = 91},
  [10179] = {.lex_state = 91, .external_lex_state = 28},
  [10180] = {.lex_state = 91},
  [10181] = {.lex_state = 91},
  [10182] = {.lex_state = 91},
  [10183] = {.lex_state = 91},
  [10184] = {.lex_state = 91},
  [10185] = {.lex_state = 0},
  [10186] = {.lex_state = 91},
  [10187] = {.lex_state = 91},
  [10188] = {.lex_state = 91},
  [10189] = {.lex_state = 91, .external_lex_state = 28},
  [10190] = {.lex_state = 91},
  [10191] = {.lex_state = 91},
  [10192] = {.lex_state = 0},
  [10193] = {.lex_state = 91},
  [10194] = {.lex_state = 91},
  [10195] = {.lex_state = 91, .external_lex_state = 28},
  [10196] = {.lex_state = 91},
  [10197] = {.lex_state = 91},
  [10198] = {.lex_state = 91},
  [10199] = {.lex_state = 91},
  [10200] = {.lex_state = 91},
  [10201] = {.lex_state = 91},
  [10202] = {.lex_state = 91},
  [10203] = {.lex_state = 91},
  [10204] = {.lex_state = 91},
  [10205] = {.lex_state = 91},
  [10206] = {.lex_state = 91},
  [10207] = {.lex_state = 91},
  [10208] = {.lex_state = 91},
  [10209] = {.lex_state = 91},
  [10210] = {.lex_state = 91},
  [10211] = {.lex_state = 91},
  [10212] = {.lex_state = 91},
  [10213] = {.lex_state = 91},
  [10214] = {.lex_state = 91},
  [10215] = {.lex_state = 91},
  [10216] = {.lex_state = 91},
  [10217] = {.lex_state = 91},
  [10218] = {.lex_state = 91},
  [10219] = {.lex_state = 91},
  [10220] = {.lex_state = 91},
  [10221] = {.lex_state = 91},
  [10222] = {.lex_state = 91},
  [10223] = {.lex_state = 91},
  [10224] = {.lex_state = 91},
  [10225] = {.lex_state = 91},
  [10226] = {.lex_state = 91},
  [10227] = {.lex_state = 91},
  [10228] = {.lex_state = 91},
  [10229] = {.lex_state = 91},
  [10230] = {.lex_state = 91},
  [10231] = {.lex_state = 11},
  [10232] = {.lex_state = 0},
  [10233] = {.lex_state = 91},
  [10234] = {.lex_state = 91},
  [10235] = {.lex_state = 91},
  [10236] = {.lex_state = 91},
  [10237] = {.lex_state = 91},
  [10238] = {.lex_state = 91},
  [10239] = {.lex_state = 91},
  [10240] = {.lex_state = 91},
  [10241] = {.lex_state = 91},
  [10242] = {.lex_state = 91},
  [10243] = {.lex_state = 91},
  [10244] = {.lex_state = 91},
  [10245] = {.lex_state = 91},
  [10246] = {.lex_state = 91},
  [10247] = {.lex_state = 91},
  [10248] = {.lex_state = 91},
  [10249] = {.lex_state = 91},
  [10250] = {.lex_state = 0},
  [10251] = {.lex_state = 91},
  [10252] = {.lex_state = 91},
  [10253] = {.lex_state = 91},
  [10254] = {.lex_state = 91},
  [10255] = {.lex_state = 91},
  [10256] = {.lex_state = 91},
  [10257] = {.lex_state = 91},
  [10258] = {.lex_state = 91},
  [10259] = {.lex_state = 91},
  [10260] = {.lex_state = 91},
  [10261] = {.lex_state = 91},
  [10262] = {.lex_state = 91},
  [10263] = {.lex_state = 91},
  [10264] = {.lex_state = 91},
  [10265] = {.lex_state = 91},
  [10266] = {.lex_state = 91},
  [10267] = {.lex_state = 91},
  [10268] = {.lex_state = 91},
  [10269] = {.lex_state = 91},
  [10270] = {.lex_state = 91},
  [10271] = {.lex_state = 91},
  [10272] = {.lex_state = 91},
  [10273] = {.lex_state = 0},
  [10274] = {.lex_state = 91},
  [10275] = {.lex_state = 0},
  [10276] = {.lex_state = 0},
  [10277] = {.lex_state = 91},
  [10278] = {.lex_state = 91},
  [10279] = {.lex_state = 91},
  [10280] = {.lex_state = 91},
  [10281] = {.lex_state = 91},
  [10282] = {.lex_state = 91},
  [10283] = {.lex_state = 0},
  [10284] = {.lex_state = 91},
  [10285] = {.lex_state = 91},
  [10286] = {.lex_state = 91},
  [10287] = {.lex_state = 91},
  [10288] = {.lex_state = 91},
  [10289] = {.lex_state = 0},
  [10290] = {.lex_state = 91},
  [10291] = {.lex_state = 91},
  [10292] = {.lex_state = 91},
  [10293] = {.lex_state = 91},
  [10294] = {.lex_state = 91},
  [10295] = {.lex_state = 0},
  [10296] = {.lex_state = 91},
  [10297] = {.lex_state = 91},
  [10298] = {.lex_state = 91},
  [10299] = {.lex_state = 91},
  [10300] = {.lex_state = 0},
  [10301] = {.lex_state = 0},
  [10302] = {.lex_state = 91},
  [10303] = {.lex_state = 91},
  [10304] = {.lex_state = 91},
  [10305] = {.lex_state = 91},
  [10306] = {.lex_state = 91},
  [10307] = {.lex_state = 0},
  [10308] = {.lex_state = 0},
  [10309] = {.lex_state = 91},
  [10310] = {.lex_state = 91},
  [10311] = {.lex_state = 91},
  [10312] = {.lex_state = 91},
  [10313] = {.lex_state = 91},
  [10314] = {.lex_state = 91},
  [10315] = {.lex_state = 0},
  [10316] = {.lex_state = 91},
  [10317] = {.lex_state = 91},
  [10318] = {.lex_state = 91},
  [10319] = {.lex_state = 91},
  [10320] = {.lex_state = 0},
  [10321] = {.lex_state = 0},
  [10322] = {.lex_state = 91},
  [10323] = {.lex_state = 0},
  [10324] = {.lex_state = 91},
  [10325] = {.lex_state = 0},
  [10326] = {.lex_state = 91},
  [10327] = {.lex_state = 0},
  [10328] = {.lex_state = 91},
  [10329] = {.lex_state = 0},
  [10330] = {.lex_state = 91},
  [10331] = {.lex_state = 0},
  [10332] = {.lex_state = 91},
  [10333] = {.lex_state = 0},
  [10334] = {.lex_state = 91},
  [10335] = {.lex_state = 0},
  [10336] = {.lex_state = 91},
  [10337] = {.lex_state = 0},
  [10338] = {.lex_state = 91},
  [10339] = {.lex_state = 0},
  [10340] = {.lex_state = 91},
  [10341] = {.lex_state = 0},
  [10342] = {.lex_state = 91},
  [10343] = {.lex_state = 0},
  [10344] = {.lex_state = 91},
  [10345] = {.lex_state = 0},
  [10346] = {.lex_state = 91},
  [10347] = {.lex_state = 91},
  [10348] = {.lex_state = 91},
  [10349] = {.lex_state = 91},
  [10350] = {.lex_state = 91},
  [10351] = {.lex_state = 91},
  [10352] = {.lex_state = 91},
  [10353] = {.lex_state = 91},
  [10354] = {.lex_state = 91},
  [10355] = {.lex_state = 91},
  [10356] = {.lex_state = 91, .external_lex_state = 29},
  [10357] = {.lex_state = 91, .external_lex_state = 29},
  [10358] = {.lex_state = 91, .external_lex_state = 29},
  [10359] = {.lex_state = 91, .external_lex_state = 29},
  [10360] = {.lex_state = 91, .external_lex_state = 29},
  [10361] = {.lex_state = 0},
  [10362] = {.lex_state = 0},
  [10363] = {.lex_state = 91, .external_lex_state = 29},
  [10364] = {.lex_state = 91, .external_lex_state = 29},
  [10365] = {.lex_state = 91, .external_lex_state = 29},
  [10366] = {.lex_state = 91, .external_lex_state = 29},
  [10367] = {.lex_state = 91, .external_lex_state = 29},
  [10368] = {.lex_state = 91, .external_lex_state = 29},
  [10369] = {.lex_state = 91, .external_lex_state = 29},
  [10370] = {.lex_state = 91, .external_lex_state = 29},
  [10371] = {.lex_state = 91, .external_lex_state = 29},
  [10372] = {.lex_state = 91, .external_lex_state = 29},
  [10373] = {.lex_state = 91, .external_lex_state = 29},
  [10374] = {.lex_state = 91, .external_lex_state = 29},
  [10375] = {.lex_state = 91, .external_lex_state = 29},
  [10376] = {.lex_state = 91, .external_lex_state = 29},
  [10377] = {.lex_state = 91},
  [10378] = {.lex_state = 91, .external_lex_state = 29},
  [10379] = {.lex_state = 91, .external_lex_state = 29},
  [10380] = {.lex_state = 91},
  [10381] = {.lex_state = 91, .external_lex_state = 29},
  [10382] = {.lex_state = 91, .external_lex_state = 29},
  [10383] = {.lex_state = 91, .external_lex_state = 29},
  [10384] = {.lex_state = 0},
  [10385] = {.lex_state = 91, .external_lex_state = 29},
  [10386] = {.lex_state = 91, .external_lex_state = 29},
  [10387] = {.lex_state = 91, .external_lex_state = 29},
  [10388] = {.lex_state = 91, .external_lex_state = 29},
  [10389] = {.lex_state = 91, .external_lex_state = 29},
  [10390] = {.lex_state = 0},
  [10391] = {.lex_state = 91, .external_lex_state = 29},
  [10392] = {.lex_state = 91, .external_lex_state = 29},
  [10393] = {.lex_state = 91, .external_lex_state = 29},
  [10394] = {.lex_state = 91, .external_lex_state = 29},
  [10395] = {.lex_state = 91, .external_lex_state = 29},
  [10396] = {.lex_state = 91, .external_lex_state = 29},
  [10397] = {.lex_state = 91, .external_lex_state = 29},
  [10398] = {.lex_state = 91, .external_lex_state = 29},
  [10399] = {.lex_state = 91, .external_lex_state = 29},
  [10400] = {.lex_state = 91, .external_lex_state = 29},
  [10401] = {.lex_state = 91, .external_lex_state = 29},
  [10402] = {.lex_state = 91, .external_lex_state = 29},
  [10403] = {.lex_state = 91, .external_lex_state = 29},
  [10404] = {.lex_state = 91, .external_lex_state = 29},
  [10405] = {.lex_state = 91, .external_lex_state = 29},
  [10406] = {.lex_state = 91},
  [10407] = {.lex_state = 91, .external_lex_state = 29},
  [10408] = {.lex_state = 91, .external_lex_state = 29},
  [10409] = {.lex_state = 91, .external_lex_state = 29},
  [10410] = {.lex_state = 91, .external_lex_state = 29},
  [10411] = {.lex_state = 0},
  [10412] = {.lex_state = 91, .external_lex_state = 29},
  [10413] = {.lex_state = 91, .external_lex_state = 29},
  [10414] = {.lex_state = 91, .external_lex_state = 29},
  [10415] = {.lex_state = 91, .external_lex_state = 29},
  [10416] = {.lex_state = 91, .external_lex_state = 29},
  [10417] = {.lex_state = 91, .external_lex_state = 29},
  [10418] = {.lex_state = 0},
  [10419] = {.lex_state = 91, .external_lex_state = 29},
  [10420] = {.lex_state = 91, .external_lex_state = 29},
  [10421] = {.lex_state = 91, .external_lex_state = 29},
  [10422] = {.lex_state = 91, .external_lex_state = 29},
  [10423] = {.lex_state = 91},
  [10424] = {.lex_state = 91},
  [10425] = {.lex_state = 91},
  [10426] = {.lex_state = 91, .external_lex_state = 29},
  [10427] = {.lex_state = 91, .external_lex_state = 29},
  [10428] = {.lex_state = 91, .external_lex_state = 29},
  [10429] = {.lex_state = 91, .external_lex_state = 29},
  [10430] = {.lex_state = 91, .external_lex_state = 29},
  [10431] = {.lex_state = 91, .external_lex_state = 29},
  [10432] = {.lex_state = 91, .external_lex_state = 29},
  [10433] = {.lex_state = 0},
  [10434] = {.lex_state = 91, .external_lex_state = 29},
  [10435] = {.lex_state = 91, .external_lex_state = 29},
  [10436] = {.lex_state = 91, .external_lex_state = 29},
  [10437] = {.lex_state = 91, .external_lex_state = 29},
  [10438] = {.lex_state = 91, .external_lex_state = 29},
  [10439] = {.lex_state = 91, .external_lex_state = 29},
  [10440] = {.lex_state = 91, .external_lex_state = 29},
  [10441] = {.lex_state = 91, .external_lex_state = 29},
  [10442] = {.lex_state = 91, .external_lex_state = 29},
  [10443] = {.lex_state = 0},
  [10444] = {.lex_state = 0},
  [10445] = {.lex_state = 91, .external_lex_state = 29},
  [10446] = {.lex_state = 91, .external_lex_state = 29},
  [10447] = {.lex_state = 91, .external_lex_state = 29},
  [10448] = {.lex_state = 91, .external_lex_state = 29},
  [10449] = {.lex_state = 0},
  [10450] = {.lex_state = 91, .external_lex_state = 29},
  [10451] = {.lex_state = 91, .external_lex_state = 29},
  [10452] = {.lex_state = 91, .external_lex_state = 29},
  [10453] = {.lex_state = 91, .external_lex_state = 29},
  [10454] = {.lex_state = 91, .external_lex_state = 29},
  [10455] = {.lex_state = 91, .external_lex_state = 29},
  [10456] = {.lex_state = 91, .external_lex_state = 29},
  [10457] = {.lex_state = 91, .external_lex_state = 29},
  [10458] = {.lex_state = 0},
  [10459] = {.lex_state = 0},
  [10460] = {.lex_state = 91, .external_lex_state = 29},
  [10461] = {.lex_state = 91, .external_lex_state = 29},
  [10462] = {.lex_state = 91, .external_lex_state = 29},
  [10463] = {.lex_state = 0},
  [10464] = {.lex_state = 91, .external_lex_state = 29},
  [10465] = {.lex_state = 91, .external_lex_state = 29},
  [10466] = {.lex_state = 91, .external_lex_state = 29},
  [10467] = {.lex_state = 91, .external_lex_state = 29},
  [10468] = {.lex_state = 91, .external_lex_state = 29},
  [10469] = {.lex_state = 91, .external_lex_state = 29},
  [10470] = {.lex_state = 91, .external_lex_state = 29},
  [10471] = {.lex_state = 91, .external_lex_state = 29},
  [10472] = {.lex_state = 91, .external_lex_state = 29},
  [10473] = {.lex_state = 91, .external_lex_state = 29},
  [10474] = {.lex_state = 91, .external_lex_state = 29},
  [10475] = {.lex_state = 91, .external_lex_state = 29},
  [10476] = {.lex_state = 91, .external_lex_state = 29},
  [10477] = {.lex_state = 91, .external_lex_state = 29},
  [10478] = {.lex_state = 91, .external_lex_state = 29},
  [10479] = {.lex_state = 91, .external_lex_state = 29},
  [10480] = {.lex_state = 91, .external_lex_state = 29},
  [10481] = {.lex_state = 91, .external_lex_state = 29},
  [10482] = {.lex_state = 91, .external_lex_state = 29},
  [10483] = {.lex_state = 91, .external_lex_state = 29},
  [10484] = {.lex_state = 91, .external_lex_state = 29},
  [10485] = {.lex_state = 91, .external_lex_state = 29},
  [10486] = {.lex_state = 91, .external_lex_state = 29},
  [10487] = {.lex_state = 91, .external_lex_state = 29},
  [10488] = {.lex_state = 91, .external_lex_state = 29},
  [10489] = {.lex_state = 91, .external_lex_state = 29},
  [10490] = {.lex_state = 91, .external_lex_state = 29},
  [10491] = {.lex_state = 0},
  [10492] = {.lex_state = 91, .external_lex_state = 29},
  [10493] = {.lex_state = 91, .external_lex_state = 29},
  [10494] = {.lex_state = 91, .external_lex_state = 29},
  [10495] = {.lex_state = 91, .external_lex_state = 29},
  [10496] = {.lex_state = 91, .external_lex_state = 29},
  [10497] = {.lex_state = 91, .external_lex_state = 29},
  [10498] = {.lex_state = 91},
  [10499] = {.lex_state = 91},
  [10500] = {.lex_state = 91, .external_lex_state = 29},
  [10501] = {.lex_state = 91, .external_lex_state = 29},
  [10502] = {.lex_state = 91},
  [10503] = {.lex_state = 91, .external_lex_state = 29},
  [10504] = {.lex_state = 91, .external_lex_state = 29},
  [10505] = {.lex_state = 91, .external_lex_state = 29},
  [10506] = {.lex_state = 91, .external_lex_state = 29},
  [10507] = {.lex_state = 91, .external_lex_state = 29},
  [10508] = {.lex_state = 91, .external_lex_state = 29},
  [10509] = {.lex_state = 0},
  [10510] = {.lex_state = 0},
  [10511] = {.lex_state = 91, .external_lex_state = 29},
  [10512] = {.lex_state = 91, .external_lex_state = 29},
  [10513] = {.lex_state = 91, .external_lex_state = 29},
  [10514] = {.lex_state = 91, .external_lex_state = 29},
  [10515] = {.lex_state = 91, .external_lex_state = 29},
  [10516] = {.lex_state = 0},
  [10517] = {.lex_state = 91, .external_lex_state = 29},
  [10518] = {.lex_state = 91, .external_lex_state = 29},
  [10519] = {.lex_state = 91, .external_lex_state = 29},
  [10520] = {.lex_state = 91, .external_lex_state = 29},
  [10521] = {.lex_state = 91},
  [10522] = {.lex_state = 91},
  [10523] = {.lex_state = 91, .external_lex_state = 29},
  [10524] = {.lex_state = 91, .external_lex_state = 29},
  [10525] = {.lex_state = 91, .external_lex_state = 29},
  [10526] = {.lex_state = 91, .external_lex_state = 29},
  [10527] = {.lex_state = 91, .external_lex_state = 29},
  [10528] = {.lex_state = 91, .external_lex_state = 29},
  [10529] = {.lex_state = 91, .external_lex_state = 29},
  [10530] = {.lex_state = 0},
  [10531] = {.lex_state = 0},
  [10532] = {.lex_state = 91, .external_lex_state = 29},
  [10533] = {.lex_state = 0},
  [10534] = {.lex_state = 91, .external_lex_state = 29},
  [10535] = {.lex_state = 91, .external_lex_state = 29},
  [10536] = {.lex_state = 91, .external_lex_state = 29},
  [10537] = {.lex_state = 91, .external_lex_state = 29},
  [10538] = {.lex_state = 91, .external_lex_state = 29},
  [10539] = {.lex_state = 91, .external_lex_state = 29},
  [10540] = {.lex_state = 91, .external_lex_state = 29},
  [10541] = {.lex_state = 91, .external_lex_state = 29},
  [10542] = {.lex_state = 91, .external_lex_state = 29},
  [10543] = {.lex_state = 91, .external_lex_state = 29},
  [10544] = {.lex_state = 91, .external_lex_state = 29},
  [10545] = {.lex_state = 91},
  [10546] = {.lex_state = 91, .external_lex_state = 29},
  [10547] = {.lex_state = 91},
  [10548] = {.lex_state = 91, .external_lex_state = 29},
  [10549] = {.lex_state = 91, .external_lex_state = 29},
  [10550] = {.lex_state = 91, .external_lex_state = 29},
  [10551] = {.lex_state = 0},
  [10552] = {.lex_state = 91, .external_lex_state = 29},
  [10553] = {.lex_state = 91, .external_lex_state = 29},
  [10554] = {.lex_state = 0},
  [10555] = {.lex_state = 0},
  [10556] = {.lex_state = 91, .external_lex_state = 29},
  [10557] = {.lex_state = 91, .external_lex_state = 29},
  [10558] = {.lex_state = 91, .external_lex_state = 29},
  [10559] = {.lex_state = 91, .external_lex_state = 29},
  [10560] = {.lex_state = 91, .external_lex_state = 29},
  [10561] = {.lex_state = 91, .external_lex_state = 29},
  [10562] = {.lex_state = 91, .external_lex_state = 29},
  [10563] = {.lex_state = 91, .external_lex_state = 29},
  [10564] = {.lex_state = 91},
  [10565] = {.lex_state = 91, .external_lex_state = 29},
  [10566] = {.lex_state = 91, .external_lex_state = 29},
  [10567] = {.lex_state = 91, .external_lex_state = 29},
  [10568] = {.lex_state = 91, .external_lex_state = 29},
  [10569] = {.lex_state = 91, .external_lex_state = 29},
  [10570] = {.lex_state = 91, .external_lex_state = 29},
  [10571] = {.lex_state = 91, .external_lex_state = 29},
  [10572] = {.lex_state = 91, .external_lex_state = 29},
  [10573] = {.lex_state = 91, .external_lex_state = 29},
  [10574] = {.lex_state = 91, .external_lex_state = 29},
  [10575] = {.lex_state = 91, .external_lex_state = 29},
  [10576] = {.lex_state = 91, .external_lex_state = 29},
  [10577] = {.lex_state = 7},
  [10578] = {.lex_state = 91, .external_lex_state = 29},
  [10579] = {.lex_state = 91, .external_lex_state = 29},
  [10580] = {.lex_state = 91, .external_lex_state = 29},
  [10581] = {.lex_state = 0},
  [10582] = {.lex_state = 91, .external_lex_state = 29},
  [10583] = {.lex_state = 91, .external_lex_state = 29},
  [10584] = {.lex_state = 91, .external_lex_state = 29},
  [10585] = {.lex_state = 91, .external_lex_state = 29},
  [10586] = {.lex_state = 0},
  [10587] = {.lex_state = 91, .external_lex_state = 29},
  [10588] = {.lex_state = 91, .external_lex_state = 29},
  [10589] = {.lex_state = 91, .external_lex_state = 29},
  [10590] = {.lex_state = 0},
  [10591] = {.lex_state = 0},
  [10592] = {.lex_state = 0},
  [10593] = {.lex_state = 0},
  [10594] = {.lex_state = 91, .external_lex_state = 29},
  [10595] = {.lex_state = 91, .external_lex_state = 29},
  [10596] = {.lex_state = 91, .external_lex_state = 29},
  [10597] = {.lex_state = 91, .external_lex_state = 29},
  [10598] = {.lex_state = 0},
  [10599] = {.lex_state = 91},
  [10600] = {.lex_state = 91, .external_lex_state = 29},
  [10601] = {.lex_state = 0},
  [10602] = {.lex_state = 91, .external_lex_state = 29},
  [10603] = {.lex_state = 91, .external_lex_state = 29},
  [10604] = {.lex_state = 91, .external_lex_state = 29},
  [10605] = {.lex_state = 91, .external_lex_state = 29},
  [10606] = {.lex_state = 91, .external_lex_state = 29},
  [10607] = {.lex_state = 91, .external_lex_state = 29},
  [10608] = {.lex_state = 91, .external_lex_state = 29},
  [10609] = {.lex_state = 0},
  [10610] = {.lex_state = 0},
  [10611] = {.lex_state = 91, .external_lex_state = 29},
  [10612] = {.lex_state = 91, .external_lex_state = 29},
  [10613] = {.lex_state = 91, .external_lex_state = 29},
  [10614] = {.lex_state = 91, .external_lex_state = 29},
  [10615] = {.lex_state = 91, .external_lex_state = 29},
  [10616] = {.lex_state = 91, .external_lex_state = 29},
  [10617] = {.lex_state = 91, .external_lex_state = 29},
  [10618] = {.lex_state = 91, .external_lex_state = 29},
  [10619] = {.lex_state = 91, .external_lex_state = 29},
  [10620] = {.lex_state = 91, .external_lex_state = 29},
  [10621] = {.lex_state = 91, .external_lex_state = 29},
  [10622] = {.lex_state = 0},
  [10623] = {.lex_state = 91},
  [10624] = {.lex_state = 91},
  [10625] = {.lex_state = 0},
  [10626] = {.lex_state = 91, .external_lex_state = 29},
  [10627] = {.lex_state = 0},
  [10628] = {.lex_state = 91},
  [10629] = {.lex_state = 91, .external_lex_state = 29},
  [10630] = {.lex_state = 91, .external_lex_state = 29},
  [10631] = {.lex_state = 91, .external_lex_state = 29},
  [10632] = {.lex_state = 91, .external_lex_state = 29},
  [10633] = {.lex_state = 91, .external_lex_state = 29},
  [10634] = {.lex_state = 91},
  [10635] = {.lex_state = 0},
  [10636] = {.lex_state = 91, .external_lex_state = 29},
  [10637] = {.lex_state = 91, .external_lex_state = 29},
  [10638] = {.lex_state = 91, .external_lex_state = 29},
  [10639] = {.lex_state = 91, .external_lex_state = 29},
  [10640] = {.lex_state = 91},
  [10641] = {.lex_state = 91, .external_lex_state = 29},
  [10642] = {.lex_state = 91, .external_lex_state = 29},
  [10643] = {.lex_state = 91, .external_lex_state = 29},
  [10644] = {.lex_state = 91, .external_lex_state = 29},
  [10645] = {.lex_state = 91, .external_lex_state = 29},
  [10646] = {.lex_state = 91, .external_lex_state = 29},
  [10647] = {.lex_state = 91, .external_lex_state = 29},
  [10648] = {.lex_state = 0},
  [10649] = {.lex_state = 0},
  [10650] = {.lex_state = 91, .external_lex_state = 29},
  [10651] = {.lex_state = 91, .external_lex_state = 29},
  [10652] = {.lex_state = 91, .external_lex_state = 29},
  [10653] = {.lex_state = 91, .external_lex_state = 29},
  [10654] = {.lex_state = 91, .external_lex_state = 29},
  [10655] = {.lex_state = 91, .external_lex_state = 29},
  [10656] = {.lex_state = 91, .external_lex_state = 29},
  [10657] = {.lex_state = 91, .external_lex_state = 29},
  [10658] = {.lex_state = 91, .external_lex_state = 29},
  [10659] = {.lex_state = 91, .external_lex_state = 29},
  [10660] = {.lex_state = 91, .external_lex_state = 29},
  [10661] = {.lex_state = 91, .external_lex_state = 29},
  [10662] = {.lex_state = 0},
  [10663] = {.lex_state = 0},
  [10664] = {.lex_state = 91, .external_lex_state = 29},
  [10665] = {.lex_state = 91, .external_lex_state = 29},
  [10666] = {.lex_state = 0},
  [10667] = {.lex_state = 91, .external_lex_state = 29},
  [10668] = {.lex_state = 91, .external_lex_state = 29},
  [10669] = {.lex_state = 91, .external_lex_state = 29},
  [10670] = {.lex_state = 91, .external_lex_state = 29},
  [10671] = {.lex_state = 0},
  [10672] = {.lex_state = 91, .external_lex_state = 29},
  [10673] = {.lex_state = 0},
  [10674] = {.lex_state = 91, .external_lex_state = 29},
  [10675] = {.lex_state = 91, .external_lex_state = 29},
  [10676] = {.lex_state = 91, .external_lex_state = 29},
  [10677] = {.lex_state = 91, .external_lex_state = 29},
  [10678] = {.lex_state = 91, .external_lex_state = 29},
  [10679] = {.lex_state = 91, .external_lex_state = 29},
  [10680] = {.lex_state = 91, .external_lex_state = 29},
  [10681] = {.lex_state = 0},
  [10682] = {.lex_state = 0},
  [10683] = {.lex_state = 91, .external_lex_state = 29},
  [10684] = {.lex_state = 91, .external_lex_state = 29},
  [10685] = {.lex_state = 91, .external_lex_state = 29},
  [10686] = {.lex_state = 91, .external_lex_state = 29},
  [10687] = {.lex_state = 91, .external_lex_state = 29},
  [10688] = {.lex_state = 91, .external_lex_state = 29},
  [10689] = {.lex_state = 0},
  [10690] = {.lex_state = 0},
  [10691] = {.lex_state = 91, .external_lex_state = 29},
  [10692] = {.lex_state = 91, .external_lex_state = 29},
  [10693] = {.lex_state = 91, .external_lex_state = 29},
  [10694] = {.lex_state = 91, .external_lex_state = 29},
  [10695] = {.lex_state = 91, .external_lex_state = 29},
  [10696] = {.lex_state = 91, .external_lex_state = 29},
  [10697] = {.lex_state = 91, .external_lex_state = 29},
  [10698] = {.lex_state = 91, .external_lex_state = 29},
  [10699] = {.lex_state = 91, .external_lex_state = 29},
  [10700] = {.lex_state = 0},
  [10701] = {.lex_state = 91, .external_lex_state = 29},
  [10702] = {.lex_state = 0},
  [10703] = {.lex_state = 0},
  [10704] = {.lex_state = 91, .external_lex_state = 29},
  [10705] = {.lex_state = 91, .external_lex_state = 29},
  [10706] = {.lex_state = 0},
  [10707] = {.lex_state = 91, .external_lex_state = 29},
  [10708] = {.lex_state = 0},
  [10709] = {.lex_state = 0},
  [10710] = {.lex_state = 91, .external_lex_state = 29},
  [10711] = {.lex_state = 91, .external_lex_state = 29},
  [10712] = {.lex_state = 91, .external_lex_state = 29},
  [10713] = {.lex_state = 91, .external_lex_state = 29},
  [10714] = {.lex_state = 91, .external_lex_state = 29},
  [10715] = {.lex_state = 0},
  [10716] = {.lex_state = 0},
  [10717] = {.lex_state = 91, .external_lex_state = 29},
  [10718] = {.lex_state = 91, .external_lex_state = 29},
  [10719] = {.lex_state = 91, .external_lex_state = 29},
  [10720] = {.lex_state = 91, .external_lex_state = 29},
  [10721] = {.lex_state = 91, .external_lex_state = 29},
  [10722] = {.lex_state = 91, .external_lex_state = 29},
  [10723] = {.lex_state = 12},
  [10724] = {.lex_state = 0},
  [10725] = {.lex_state = 0},
  [10726] = {.lex_state = 91, .external_lex_state = 29},
  [10727] = {.lex_state = 91, .external_lex_state = 29},
  [10728] = {.lex_state = 91, .external_lex_state = 29},
  [10729] = {.lex_state = 91, .external_lex_state = 29},
  [10730] = {.lex_state = 91, .external_lex_state = 29},
  [10731] = {.lex_state = 91, .external_lex_state = 29},
  [10732] = {.lex_state = 0},
  [10733] = {.lex_state = 91, .external_lex_state = 29},
  [10734] = {.lex_state = 91, .external_lex_state = 29},
  [10735] = {.lex_state = 91, .external_lex_state = 29},
  [10736] = {.lex_state = 91, .external_lex_state = 29},
  [10737] = {.lex_state = 91, .external_lex_state = 29},
  [10738] = {.lex_state = 91, .external_lex_state = 29},
  [10739] = {.lex_state = 91, .external_lex_state = 29},
  [10740] = {.lex_state = 91, .external_lex_state = 29},
  [10741] = {.lex_state = 91, .external_lex_state = 29},
  [10742] = {.lex_state = 91, .external_lex_state = 29},
  [10743] = {.lex_state = 91, .external_lex_state = 29},
  [10744] = {.lex_state = 91, .external_lex_state = 29},
  [10745] = {.lex_state = 91, .external_lex_state = 29},
  [10746] = {.lex_state = 91, .external_lex_state = 29},
  [10747] = {.lex_state = 91, .external_lex_state = 29},
  [10748] = {.lex_state = 91, .external_lex_state = 29},
  [10749] = {.lex_state = 91, .external_lex_state = 29},
  [10750] = {.lex_state = 91, .external_lex_state = 29},
  [10751] = {.lex_state = 91, .external_lex_state = 29},
  [10752] = {.lex_state = 91, .external_lex_state = 29},
  [10753] = {.lex_state = 91, .external_lex_state = 29},
  [10754] = {.lex_state = 91, .external_lex_state = 29},
  [10755] = {.lex_state = 0},
  [10756] = {.lex_state = 91, .external_lex_state = 29},
  [10757] = {.lex_state = 91},
  [10758] = {.lex_state = 0},
  [10759] = {.lex_state = 91, .external_lex_state = 29},
  [10760] = {.lex_state = 91, .external_lex_state = 29},
  [10761] = {.lex_state = 91},
  [10762] = {.lex_state = 0},
  [10763] = {.lex_state = 91},
  [10764] = {.lex_state = 91, .external_lex_state = 29},
  [10765] = {.lex_state = 91},
  [10766] = {.lex_state = 91},
  [10767] = {.lex_state = 91, .external_lex_state = 29},
  [10768] = {.lex_state = 91, .external_lex_state = 29},
  [10769] = {.lex_state = 0},
  [10770] = {.lex_state = 91, .external_lex_state = 29},
  [10771] = {.lex_state = 91, .external_lex_state = 29},
  [10772] = {.lex_state = 91, .external_lex_state = 29},
  [10773] = {.lex_state = 91, .external_lex_state = 29},
  [10774] = {.lex_state = 91, .external_lex_state = 29},
  [10775] = {.lex_state = 91, .external_lex_state = 29},
  [10776] = {.lex_state = 91, .external_lex_state = 29},
  [10777] = {.lex_state = 91, .external_lex_state = 29},
  [10778] = {.lex_state = 91, .external_lex_state = 29},
  [10779] = {.lex_state = 91, .external_lex_state = 29},
  [10780] = {.lex_state = 91, .external_lex_state = 29},
  [10781] = {.lex_state = 91, .external_lex_state = 29},
  [10782] = {.lex_state = 91, .external_lex_state = 29},
  [10783] = {.lex_state = 91, .external_lex_state = 29},
  [10784] = {.lex_state = 0},
  [10785] = {.lex_state = 0},
  [10786] = {.lex_state = 0},
  [10787] = {.lex_state = 91, .external_lex_state = 29},
  [10788] = {.lex_state = 91, .external_lex_state = 29},
  [10789] = {.lex_state = 91, .external_lex_state = 29},
  [10790] = {.lex_state = 91},
  [10791] = {.lex_state = 91},
  [10792] = {.lex_state = 91, .external_lex_state = 29},
  [10793] = {.lex_state = 91, .external_lex_state = 29},
  [10794] = {.lex_state = 91, .external_lex_state = 29},
  [10795] = {.lex_state = 91, .external_lex_state = 29},
  [10796] = {.lex_state = 91, .external_lex_state = 29},
  [10797] = {.lex_state = 91, .external_lex_state = 29},
  [10798] = {.lex_state = 0},
  [10799] = {.lex_state = 0},
  [10800] = {.lex_state = 91},
  [10801] = {.lex_state = 91},
  [10802] = {.lex_state = 91, .external_lex_state = 29},
  [10803] = {.lex_state = 0},
  [10804] = {.lex_state = 0},
  [10805] = {.lex_state = 91, .external_lex_state = 29},
  [10806] = {.lex_state = 91, .external_lex_state = 29},
  [10807] = {.lex_state = 91, .external_lex_state = 29},
  [10808] = {.lex_state = 91},
  [10809] = {.lex_state = 91, .external_lex_state = 29},
  [10810] = {.lex_state = 91, .external_lex_state = 29},
  [10811] = {.lex_state = 0},
  [10812] = {.lex_state = 0},
  [10813] = {.lex_state = 91},
  [10814] = {.lex_state = 91, .external_lex_state = 29},
  [10815] = {.lex_state = 91, .external_lex_state = 29},
  [10816] = {.lex_state = 91, .external_lex_state = 29},
  [10817] = {.lex_state = 91, .external_lex_state = 29},
  [10818] = {.lex_state = 91, .external_lex_state = 29},
  [10819] = {.lex_state = 91, .external_lex_state = 29},
  [10820] = {.lex_state = 91},
  [10821] = {.lex_state = 91},
  [10822] = {.lex_state = 91, .external_lex_state = 29},
  [10823] = {.lex_state = 91, .external_lex_state = 29},
  [10824] = {.lex_state = 91},
  [10825] = {.lex_state = 91, .external_lex_state = 29},
  [10826] = {.lex_state = 91, .external_lex_state = 29},
  [10827] = {.lex_state = 91, .external_lex_state = 29},
  [10828] = {.lex_state = 91, .external_lex_state = 29},
  [10829] = {.lex_state = 91, .external_lex_state = 29},
  [10830] = {.lex_state = 91, .external_lex_state = 29},
  [10831] = {.lex_state = 91, .external_lex_state = 29},
  [10832] = {.lex_state = 91},
  [10833] = {.lex_state = 91},
  [10834] = {.lex_state = 91, .external_lex_state = 29},
  [10835] = {.lex_state = 91, .external_lex_state = 29},
  [10836] = {.lex_state = 91, .external_lex_state = 29},
  [10837] = {.lex_state = 91, .external_lex_state = 29},
  [10838] = {.lex_state = 91, .external_lex_state = 29},
  [10839] = {.lex_state = 91, .external_lex_state = 29},
  [10840] = {.lex_state = 91, .external_lex_state = 29},
  [10841] = {.lex_state = 91, .external_lex_state = 29},
  [10842] = {.lex_state = 91, .external_lex_state = 29},
  [10843] = {.lex_state = 91},
  [10844] = {.lex_state = 91},
  [10845] = {.lex_state = 91, .external_lex_state = 29},
  [10846] = {.lex_state = 91, .external_lex_state = 29},
  [10847] = {.lex_state = 91},
  [10848] = {.lex_state = 91},
  [10849] = {.lex_state = 91, .external_lex_state = 29},
  [10850] = {.lex_state = 91, .external_lex_state = 29},
  [10851] = {.lex_state = 0},
  [10852] = {.lex_state = 91, .external_lex_state = 29},
  [10853] = {.lex_state = 91, .external_lex_state = 29},
  [10854] = {.lex_state = 91, .external_lex_state = 29},
  [10855] = {.lex_state = 91, .external_lex_state = 29},
  [10856] = {.lex_state = 91, .external_lex_state = 29},
  [10857] = {.lex_state = 91, .external_lex_state = 29},
  [10858] = {.lex_state = 91, .external_lex_state = 29},
  [10859] = {.lex_state = 91, .external_lex_state = 29},
  [10860] = {.lex_state = 7},
  [10861] = {.lex_state = 91, .external_lex_state = 29},
  [10862] = {.lex_state = 0},
  [10863] = {.lex_state = 91, .external_lex_state = 29},
  [10864] = {.lex_state = 91, .external_lex_state = 29},
  [10865] = {.lex_state = 91, .external_lex_state = 29},
  [10866] = {.lex_state = 91, .external_lex_state = 29},
  [10867] = {.lex_state = 91, .external_lex_state = 29},
  [10868] = {.lex_state = 91, .external_lex_state = 29},
  [10869] = {.lex_state = 91, .external_lex_state = 29},
  [10870] = {.lex_state = 91, .external_lex_state = 29},
  [10871] = {.lex_state = 91, .external_lex_state = 29},
  [10872] = {.lex_state = 91, .external_lex_state = 29},
  [10873] = {.lex_state = 0},
  [10874] = {.lex_state = 0},
  [10875] = {.lex_state = 91, .external_lex_state = 29},
  [10876] = {.lex_state = 91, .external_lex_state = 29},
  [10877] = {.lex_state = 7},
  [10878] = {.lex_state = 91, .external_lex_state = 29},
  [10879] = {.lex_state = 91, .external_lex_state = 29},
  [10880] = {.lex_state = 5},
  [10881] = {.lex_state = 91, .external_lex_state = 29},
  [10882] = {.lex_state = 91, .external_lex_state = 29},
  [10883] = {.lex_state = 0},
  [10884] = {.lex_state = 91, .external_lex_state = 29},
  [10885] = {.lex_state = 0},
  [10886] = {.lex_state = 91, .external_lex_state = 29},
  [10887] = {.lex_state = 91, .external_lex_state = 29},
  [10888] = {.lex_state = 91, .external_lex_state = 29},
  [10889] = {.lex_state = 0},
  [10890] = {.lex_state = 91, .external_lex_state = 29},
  [10891] = {.lex_state = 91, .external_lex_state = 29},
  [10892] = {.lex_state = 91, .external_lex_state = 29},
  [10893] = {.lex_state = 91, .external_lex_state = 29},
  [10894] = {.lex_state = 91, .external_lex_state = 29},
  [10895] = {.lex_state = 7},
  [10896] = {.lex_state = 0},
  [10897] = {.lex_state = 0},
  [10898] = {.lex_state = 91},
  [10899] = {.lex_state = 91, .external_lex_state = 29},
  [10900] = {.lex_state = 91, .external_lex_state = 29},
  [10901] = {.lex_state = 91, .external_lex_state = 29},
  [10902] = {.lex_state = 91, .external_lex_state = 29},
  [10903] = {.lex_state = 91, .external_lex_state = 29},
  [10904] = {.lex_state = 91, .external_lex_state = 29},
  [10905] = {.lex_state = 91, .external_lex_state = 29},
  [10906] = {.lex_state = 0},
  [10907] = {.lex_state = 91},
  [10908] = {.lex_state = 91, .external_lex_state = 29},
  [10909] = {.lex_state = 91, .external_lex_state = 29},
  [10910] = {.lex_state = 91, .external_lex_state = 29},
  [10911] = {.lex_state = 91, .external_lex_state = 29},
  [10912] = {.lex_state = 91, .external_lex_state = 29},
  [10913] = {.lex_state = 91, .external_lex_state = 29},
  [10914] = {.lex_state = 91, .external_lex_state = 29},
  [10915] = {.lex_state = 91, .external_lex_state = 29},
  [10916] = {.lex_state = 91, .external_lex_state = 29},
  [10917] = {.lex_state = 91, .external_lex_state = 29},
  [10918] = {.lex_state = 91, .external_lex_state = 29},
  [10919] = {.lex_state = 91, .external_lex_state = 29},
  [10920] = {.lex_state = 91, .external_lex_state = 29},
  [10921] = {.lex_state = 91, .external_lex_state = 29},
  [10922] = {.lex_state = 0},
  [10923] = {.lex_state = 91, .external_lex_state = 29},
  [10924] = {.lex_state = 91, .external_lex_state = 29},
  [10925] = {.lex_state = 91, .external_lex_state = 29},
  [10926] = {.lex_state = 91, .external_lex_state = 29},
  [10927] = {.lex_state = 91, .external_lex_state = 29},
  [10928] = {.lex_state = 91, .external_lex_state = 29},
  [10929] = {.lex_state = 91, .external_lex_state = 29},
  [10930] = {.lex_state = 91, .external_lex_state = 29},
  [10931] = {.lex_state = 0},
  [10932] = {.lex_state = 91, .external_lex_state = 29},
  [10933] = {.lex_state = 91, .external_lex_state = 29},
  [10934] = {.lex_state = 91, .external_lex_state = 29},
  [10935] = {.lex_state = 0},
  [10936] = {.lex_state = 91, .external_lex_state = 29},
  [10937] = {.lex_state = 91, .external_lex_state = 29},
  [10938] = {.lex_state = 91, .external_lex_state = 29},
  [10939] = {.lex_state = 91, .external_lex_state = 29},
  [10940] = {.lex_state = 91, .external_lex_state = 29},
  [10941] = {.lex_state = 91, .external_lex_state = 29},
  [10942] = {.lex_state = 91, .external_lex_state = 29},
  [10943] = {.lex_state = 7},
  [10944] = {.lex_state = 91, .external_lex_state = 29},
  [10945] = {.lex_state = 91, .external_lex_state = 29},
  [10946] = {.lex_state = 91, .external_lex_state = 29},
  [10947] = {.lex_state = 0},
  [10948] = {.lex_state = 91},
  [10949] = {.lex_state = 0},
  [10950] = {.lex_state = 0},
  [10951] = {.lex_state = 91, .external_lex_state = 29},
  [10952] = {.lex_state = 91, .external_lex_state = 29},
  [10953] = {.lex_state = 0},
  [10954] = {.lex_state = 91, .external_lex_state = 29},
  [10955] = {.lex_state = 91, .external_lex_state = 29},
  [10956] = {.lex_state = 91, .external_lex_state = 29},
  [10957] = {.lex_state = 91, .external_lex_state = 29},
  [10958] = {.lex_state = 0},
  [10959] = {.lex_state = 0},
  [10960] = {.lex_state = 91},
  [10961] = {.lex_state = 91, .external_lex_state = 29},
  [10962] = {.lex_state = 91, .external_lex_state = 29},
  [10963] = {.lex_state = 7},
  [10964] = {.lex_state = 91, .external_lex_state = 29},
  [10965] = {.lex_state = 91, .external_lex_state = 29},
  [10966] = {.lex_state = 91, .external_lex_state = 29},
  [10967] = {.lex_state = 91, .external_lex_state = 29},
  [10968] = {.lex_state = 91, .external_lex_state = 29},
  [10969] = {.lex_state = 0},
  [10970] = {.lex_state = 0},
  [10971] = {.lex_state = 91},
  [10972] = {.lex_state = 91},
  [10973] = {.lex_state = 91, .external_lex_state = 29},
  [10974] = {.lex_state = 91, .external_lex_state = 29},
  [10975] = {.lex_state = 91, .external_lex_state = 29},
  [10976] = {.lex_state = 91, .external_lex_state = 29},
  [10977] = {.lex_state = 7},
  [10978] = {.lex_state = 0},
  [10979] = {.lex_state = 91, .external_lex_state = 29},
  [10980] = {.lex_state = 91, .external_lex_state = 29},
  [10981] = {.lex_state = 0},
  [10982] = {.lex_state = 91, .external_lex_state = 29},
  [10983] = {.lex_state = 0},
  [10984] = {.lex_state = 91, .external_lex_state = 29},
  [10985] = {.lex_state = 0},
  [10986] = {.lex_state = 91, .external_lex_state = 29},
  [10987] = {.lex_state = 91, .external_lex_state = 29},
  [10988] = {.lex_state = 0},
  [10989] = {.lex_state = 91, .external_lex_state = 29},
  [10990] = {.lex_state = 0},
  [10991] = {.lex_state = 91, .external_lex_state = 29},
  [10992] = {.lex_state = 91, .external_lex_state = 29},
  [10993] = {.lex_state = 91, .external_lex_state = 29},
  [10994] = {.lex_state = 91, .external_lex_state = 29},
  [10995] = {.lex_state = 91, .external_lex_state = 29},
  [10996] = {.lex_state = 91},
  [10997] = {.lex_state = 91},
  [10998] = {.lex_state = 91, .external_lex_state = 29},
  [10999] = {.lex_state = 0},
  [11000] = {.lex_state = 91, .external_lex_state = 29},
  [11001] = {.lex_state = 91, .external_lex_state = 29},
  [11002] = {.lex_state = 91, .external_lex_state = 29},
  [11003] = {.lex_state = 91, .external_lex_state = 29},
  [11004] = {.lex_state = 91, .external_lex_state = 29},
  [11005] = {.lex_state = 91, .external_lex_state = 29},
  [11006] = {.lex_state = 91, .external_lex_state = 29},
  [11007] = {.lex_state = 91, .external_lex_state = 29},
  [11008] = {.lex_state = 91, .external_lex_state = 29},
  [11009] = {.lex_state = 91, .external_lex_state = 29},
  [11010] = {.lex_state = 91, .external_lex_state = 29},
  [11011] = {.lex_state = 91, .external_lex_state = 29},
  [11012] = {.lex_state = 91, .external_lex_state = 29},
  [11013] = {.lex_state = 91, .external_lex_state = 29},
  [11014] = {.lex_state = 91, .external_lex_state = 29},
  [11015] = {.lex_state = 91, .external_lex_state = 29},
  [11016] = {.lex_state = 91, .external_lex_state = 29},
  [11017] = {.lex_state = 91, .external_lex_state = 29},
  [11018] = {.lex_state = 91, .external_lex_state = 29},
  [11019] = {.lex_state = 91, .external_lex_state = 29},
  [11020] = {.lex_state = 91, .external_lex_state = 29},
  [11021] = {.lex_state = 0},
  [11022] = {.lex_state = 91, .external_lex_state = 29},
  [11023] = {.lex_state = 0},
  [11024] = {.lex_state = 0},
  [11025] = {.lex_state = 91, .external_lex_state = 29},
  [11026] = {.lex_state = 91, .external_lex_state = 29},
  [11027] = {.lex_state = 91, .external_lex_state = 29},
  [11028] = {.lex_state = 91, .external_lex_state = 29},
  [11029] = {.lex_state = 91, .external_lex_state = 29},
  [11030] = {.lex_state = 91, .external_lex_state = 29},
  [11031] = {.lex_state = 91, .external_lex_state = 29},
  [11032] = {.lex_state = 91, .external_lex_state = 29},
  [11033] = {.lex_state = 91, .external_lex_state = 29},
  [11034] = {.lex_state = 91, .external_lex_state = 29},
  [11035] = {.lex_state = 91, .external_lex_state = 29},
  [11036] = {.lex_state = 91, .external_lex_state = 29},
  [11037] = {.lex_state = 91, .external_lex_state = 29},
  [11038] = {.lex_state = 91, .external_lex_state = 29},
  [11039] = {.lex_state = 91, .external_lex_state = 29},
  [11040] = {.lex_state = 91, .external_lex_state = 29},
  [11041] = {.lex_state = 91, .external_lex_state = 29},
  [11042] = {.lex_state = 91, .external_lex_state = 29},
  [11043] = {.lex_state = 91, .external_lex_state = 29},
  [11044] = {.lex_state = 91, .external_lex_state = 29},
  [11045] = {.lex_state = 91, .external_lex_state = 29},
  [11046] = {.lex_state = 91, .external_lex_state = 29},
  [11047] = {.lex_state = 91, .external_lex_state = 29},
  [11048] = {.lex_state = 91, .external_lex_state = 29},
  [11049] = {.lex_state = 91, .external_lex_state = 29},
  [11050] = {.lex_state = 91, .external_lex_state = 29},
  [11051] = {.lex_state = 91, .external_lex_state = 29},
  [11052] = {.lex_state = 91, .external_lex_state = 29},
  [11053] = {.lex_state = 91, .external_lex_state = 29},
  [11054] = {.lex_state = 91, .external_lex_state = 29},
  [11055] = {.lex_state = 91},
  [11056] = {.lex_state = 91, .external_lex_state = 29},
  [11057] = {.lex_state = 91, .external_lex_state = 29},
  [11058] = {.lex_state = 91, .external_lex_state = 29},
  [11059] = {.lex_state = 91, .external_lex_state = 29},
  [11060] = {.lex_state = 91, .external_lex_state = 29},
  [11061] = {.lex_state = 91, .external_lex_state = 29},
  [11062] = {.lex_state = 91, .external_lex_state = 29},
  [11063] = {.lex_state = 91, .external_lex_state = 29},
  [11064] = {.lex_state = 91, .external_lex_state = 29},
  [11065] = {.lex_state = 91, .external_lex_state = 29},
  [11066] = {.lex_state = 91, .external_lex_state = 29},
  [11067] = {.lex_state = 91, .external_lex_state = 29},
  [11068] = {.lex_state = 91, .external_lex_state = 29},
  [11069] = {.lex_state = 91, .external_lex_state = 29},
  [11070] = {.lex_state = 91, .external_lex_state = 29},
  [11071] = {.lex_state = 91, .external_lex_state = 29},
  [11072] = {.lex_state = 91, .external_lex_state = 29},
  [11073] = {.lex_state = 91, .external_lex_state = 29},
  [11074] = {.lex_state = 91, .external_lex_state = 29},
  [11075] = {.lex_state = 91, .external_lex_state = 29},
  [11076] = {.lex_state = 91, .external_lex_state = 29},
  [11077] = {.lex_state = 91, .external_lex_state = 29},
  [11078] = {.lex_state = 91, .external_lex_state = 29},
  [11079] = {.lex_state = 91, .external_lex_state = 29},
  [11080] = {.lex_state = 91, .external_lex_state = 29},
  [11081] = {.lex_state = 91, .external_lex_state = 29},
  [11082] = {.lex_state = 91, .external_lex_state = 29},
  [11083] = {.lex_state = 91, .external_lex_state = 29},
  [11084] = {.lex_state = 91, .external_lex_state = 29},
  [11085] = {.lex_state = 0},
  [11086] = {.lex_state = 91, .external_lex_state = 29},
  [11087] = {.lex_state = 91, .external_lex_state = 29},
  [11088] = {.lex_state = 91, .external_lex_state = 29},
  [11089] = {.lex_state = 91, .external_lex_state = 29},
  [11090] = {.lex_state = 91, .external_lex_state = 29},
  [11091] = {.lex_state = 91, .external_lex_state = 29},
  [11092] = {.lex_state = 91, .external_lex_state = 29},
  [11093] = {.lex_state = 91, .external_lex_state = 29},
  [11094] = {.lex_state = 91, .external_lex_state = 29},
  [11095] = {.lex_state = 0},
  [11096] = {.lex_state = 91, .external_lex_state = 29},
  [11097] = {.lex_state = 91, .external_lex_state = 29},
  [11098] = {.lex_state = 91, .external_lex_state = 29},
  [11099] = {.lex_state = 91, .external_lex_state = 29},
  [11100] = {.lex_state = 91, .external_lex_state = 29},
  [11101] = {.lex_state = 91, .external_lex_state = 29},
  [11102] = {.lex_state = 91, .external_lex_state = 29},
  [11103] = {.lex_state = 91, .external_lex_state = 29},
  [11104] = {.lex_state = 91, .external_lex_state = 29},
  [11105] = {.lex_state = 91, .external_lex_state = 29},
  [11106] = {.lex_state = 91, .external_lex_state = 29},
  [11107] = {.lex_state = 91, .external_lex_state = 29},
  [11108] = {.lex_state = 91, .external_lex_state = 29},
  [11109] = {.lex_state = 91, .external_lex_state = 29},
  [11110] = {.lex_state = 91, .external_lex_state = 29},
  [11111] = {.lex_state = 91, .external_lex_state = 29},
  [11112] = {.lex_state = 0},
  [11113] = {.lex_state = 91, .external_lex_state = 29},
  [11114] = {.lex_state = 91, .external_lex_state = 29},
  [11115] = {.lex_state = 91},
  [11116] = {.lex_state = 0},
  [11117] = {.lex_state = 0},
  [11118] = {.lex_state = 0},
  [11119] = {.lex_state = 91, .external_lex_state = 29},
  [11120] = {.lex_state = 0},
  [11121] = {.lex_state = 0},
  [11122] = {.lex_state = 0},
  [11123] = {.lex_state = 91},
  [11124] = {.lex_state = 91},
  [11125] = {.lex_state = 91},
  [11126] = {.lex_state = 91},
  [11127] = {.lex_state = 91},
  [11128] = {.lex_state = 0},
  [11129] = {.lex_state = 91},
  [11130] = {.lex_state = 91},
  [11131] = {.lex_state = 12},
  [11132] = {.lex_state = 91, .external_lex_state = 29},
  [11133] = {.lex_state = 91},
  [11134] = {.lex_state = 91},
  [11135] = {.lex_state = 91},
  [11136] = {.lex_state = 91},
  [11137] = {.lex_state = 0},
  [11138] = {.lex_state = 91},
  [11139] = {.lex_state = 91, .external_lex_state = 29},
  [11140] = {.lex_state = 91},
  [11141] = {.lex_state = 91},
  [11142] = {.lex_state = 91},
  [11143] = {.lex_state = 0},
  [11144] = {.lex_state = 0},
  [11145] = {.lex_state = 91},
  [11146] = {.lex_state = 91},
  [11147] = {.lex_state = 91},
  [11148] = {.lex_state = 91},
  [11149] = {.lex_state = 91},
  [11150] = {.lex_state = 91},
  [11151] = {.lex_state = 91},
  [11152] = {.lex_state = 91},
  [11153] = {.lex_state = 0},
  [11154] = {.lex_state = 0},
  [11155] = {.lex_state = 6},
  [11156] = {.lex_state = 0},
  [11157] = {.lex_state = 91},
  [11158] = {.lex_state = 0},
  [11159] = {.lex_state = 91},
  [11160] = {.lex_state = 91},
  [11161] = {.lex_state = 0},
  [11162] = {.lex_state = 91},
  [11163] = {.lex_state = 0},
  [11164] = {.lex_state = 91},
  [11165] = {.lex_state = 91},
  [11166] = {.lex_state = 91},
  [11167] = {.lex_state = 91},
  [11168] = {.lex_state = 91},
  [11169] = {.lex_state = 0},
  [11170] = {.lex_state = 91, .external_lex_state = 29},
  [11171] = {.lex_state = 91},
  [11172] = {.lex_state = 91, .external_lex_state = 29},
  [11173] = {.lex_state = 91},
  [11174] = {.lex_state = 0},
  [11175] = {.lex_state = 91},
  [11176] = {.lex_state = 0},
  [11177] = {.lex_state = 91},
  [11178] = {.lex_state = 91},
  [11179] = {.lex_state = 91},
  [11180] = {.lex_state = 91},
  [11181] = {.lex_state = 91},
  [11182] = {.lex_state = 0},
  [11183] = {.lex_state = 91},
  [11184] = {.lex_state = 0},
  [11185] = {.lex_state = 91},
  [11186] = {.lex_state = 91},
  [11187] = {.lex_state = 91},
  [11188] = {.lex_state = 0},
  [11189] = {.lex_state = 0},
  [11190] = {.lex_state = 91},
  [11191] = {.lex_state = 0},
  [11192] = {.lex_state = 91},
  [11193] = {.lex_state = 12},
  [11194] = {.lex_state = 0},
  [11195] = {.lex_state = 0},
  [11196] = {.lex_state = 0},
  [11197] = {.lex_state = 0},
  [11198] = {.lex_state = 0},
  [11199] = {.lex_state = 91},
  [11200] = {.lex_state = 91},
  [11201] = {.lex_state = 0},
  [11202] = {.lex_state = 0},
  [11203] = {.lex_state = 91},
  [11204] = {.lex_state = 0},
  [11205] = {.lex_state = 12},
  [11206] = {.lex_state = 0},
  [11207] = {.lex_state = 0},
  [11208] = {.lex_state = 91},
  [11209] = {.lex_state = 91},
  [11210] = {.lex_state = 0},
  [11211] = {.lex_state = 0},
  [11212] = {.lex_state = 0},
  [11213] = {.lex_state = 0, .external_lex_state = 28},
  [11214] = {.lex_state = 91},
  [11215] = {.lex_state = 91},
  [11216] = {.lex_state = 0},
  [11217] = {.lex_state = 0},
  [11218] = {.lex_state = 91},
  [11219] = {.lex_state = 91},
  [11220] = {.lex_state = 0},
  [11221] = {.lex_state = 91, .external_lex_state = 29},
  [11222] = {.lex_state = 0},
  [11223] = {.lex_state = 0},
  [11224] = {.lex_state = 0},
  [11225] = {.lex_state = 91},
  [11226] = {.lex_state = 0},
  [11227] = {.lex_state = 0},
  [11228] = {.lex_state = 0, .external_lex_state = 28},
  [11229] = {.lex_state = 0},
  [11230] = {.lex_state = 0},
  [11231] = {.lex_state = 0},
  [11232] = {.lex_state = 91},
  [11233] = {.lex_state = 91},
  [11234] = {.lex_state = 91},
  [11235] = {.lex_state = 12},
  [11236] = {.lex_state = 0},
  [11237] = {.lex_state = 91},
  [11238] = {.lex_state = 91},
  [11239] = {.lex_state = 91},
  [11240] = {.lex_state = 0},
  [11241] = {.lex_state = 0},
  [11242] = {.lex_state = 91},
  [11243] = {.lex_state = 91},
  [11244] = {.lex_state = 0},
  [11245] = {.lex_state = 0},
  [11246] = {.lex_state = 91},
  [11247] = {.lex_state = 91},
  [11248] = {.lex_state = 0},
  [11249] = {.lex_state = 0},
  [11250] = {.lex_state = 0},
  [11251] = {.lex_state = 0},
  [11252] = {.lex_state = 0},
  [11253] = {.lex_state = 0},
  [11254] = {.lex_state = 91},
  [11255] = {.lex_state = 0},
  [11256] = {.lex_state = 6},
  [11257] = {.lex_state = 0},
  [11258] = {.lex_state = 12},
  [11259] = {.lex_state = 0},
  [11260] = {.lex_state = 91},
  [11261] = {.lex_state = 0},
  [11262] = {.lex_state = 0},
  [11263] = {.lex_state = 0},
  [11264] = {.lex_state = 0},
  [11265] = {.lex_state = 0},
  [11266] = {.lex_state = 0},
  [11267] = {.lex_state = 0},
  [11268] = {.lex_state = 91},
  [11269] = {.lex_state = 0},
  [11270] = {.lex_state = 0},
  [11271] = {.lex_state = 6},
  [11272] = {.lex_state = 6},
  [11273] = {.lex_state = 0},
  [11274] = {.lex_state = 0},
  [11275] = {.lex_state = 0},
  [11276] = {.lex_state = 0},
  [11277] = {.lex_state = 0},
  [11278] = {.lex_state = 0},
  [11279] = {.lex_state = 0},
  [11280] = {.lex_state = 0},
  [11281] = {.lex_state = 0},
  [11282] = {.lex_state = 0},
  [11283] = {.lex_state = 91},
  [11284] = {.lex_state = 0},
  [11285] = {.lex_state = 91},
  [11286] = {.lex_state = 0},
  [11287] = {.lex_state = 0},
  [11288] = {.lex_state = 0},
  [11289] = {.lex_state = 6},
  [11290] = {.lex_state = 6},
  [11291] = {.lex_state = 91},
  [11292] = {.lex_state = 0},
  [11293] = {.lex_state = 6},
  [11294] = {.lex_state = 0},
  [11295] = {.lex_state = 6},
  [11296] = {.lex_state = 0},
  [11297] = {.lex_state = 91},
  [11298] = {.lex_state = 0},
  [11299] = {.lex_state = 6},
  [11300] = {.lex_state = 0},
  [11301] = {.lex_state = 0},
  [11302] = {.lex_state = 0},
  [11303] = {.lex_state = 0},
  [11304] = {.lex_state = 0},
  [11305] = {.lex_state = 0},
  [11306] = {.lex_state = 0},
  [11307] = {.lex_state = 6},
  [11308] = {.lex_state = 6},
  [11309] = {.lex_state = 0},
  [11310] = {.lex_state = 0},
  [11311] = {.lex_state = 0},
  [11312] = {.lex_state = 0},
  [11313] = {.lex_state = 12},
  [11314] = {.lex_state = 0},
  [11315] = {.lex_state = 0},
  [11316] = {.lex_state = 91},
  [11317] = {.lex_state = 91},
  [11318] = {.lex_state = 91},
  [11319] = {.lex_state = 0},
  [11320] = {.lex_state = 0},
  [11321] = {.lex_state = 0},
  [11322] = {.lex_state = 6},
  [11323] = {.lex_state = 6},
  [11324] = {.lex_state = 0},
  [11325] = {.lex_state = 0},
  [11326] = {.lex_state = 0},
  [11327] = {.lex_state = 91},
  [11328] = {.lex_state = 91},
  [11329] = {.lex_state = 0},
  [11330] = {.lex_state = 0},
  [11331] = {.lex_state = 0},
  [11332] = {.lex_state = 0},
  [11333] = {.lex_state = 0},
  [11334] = {.lex_state = 0},
  [11335] = {.lex_state = 12},
  [11336] = {.lex_state = 0},
  [11337] = {.lex_state = 0},
  [11338] = {.lex_state = 0},
  [11339] = {.lex_state = 0},
  [11340] = {.lex_state = 0},
  [11341] = {.lex_state = 0},
  [11342] = {.lex_state = 0},
  [11343] = {.lex_state = 0},
  [11344] = {.lex_state = 0},
  [11345] = {.lex_state = 0},
  [11346] = {.lex_state = 0},
  [11347] = {.lex_state = 6},
  [11348] = {.lex_state = 91},
  [11349] = {.lex_state = 0},
  [11350] = {.lex_state = 0},
  [11351] = {.lex_state = 6},
  [11352] = {.lex_state = 0},
  [11353] = {.lex_state = 6},
  [11354] = {.lex_state = 0},
  [11355] = {.lex_state = 0},
  [11356] = {.lex_state = 0},
  [11357] = {.lex_state = 0},
  [11358] = {.lex_state = 91},
  [11359] = {.lex_state = 0},
  [11360] = {.lex_state = 91},
  [11361] = {.lex_state = 0},
  [11362] = {.lex_state = 91},
  [11363] = {.lex_state = 6},
  [11364] = {.lex_state = 0},
  [11365] = {.lex_state = 0},
  [11366] = {.lex_state = 91},
  [11367] = {.lex_state = 0},
  [11368] = {.lex_state = 6},
  [11369] = {.lex_state = 0},
  [11370] = {.lex_state = 6},
  [11371] = {.lex_state = 0},
  [11372] = {.lex_state = 0},
  [11373] = {.lex_state = 91},
  [11374] = {.lex_state = 0},
  [11375] = {.lex_state = 0},
  [11376] = {.lex_state = 0},
  [11377] = {.lex_state = 0},
  [11378] = {.lex_state = 91},
  [11379] = {.lex_state = 0},
  [11380] = {.lex_state = 0},
  [11381] = {.lex_state = 6},
  [11382] = {.lex_state = 0},
  [11383] = {.lex_state = 0},
  [11384] = {.lex_state = 0},
  [11385] = {.lex_state = 6},
  [11386] = {.lex_state = 0},
  [11387] = {.lex_state = 91},
  [11388] = {.lex_state = 0},
  [11389] = {.lex_state = 0},
  [11390] = {.lex_state = 0},
  [11391] = {.lex_state = 0},
  [11392] = {.lex_state = 12},
  [11393] = {.lex_state = 0},
  [11394] = {.lex_state = 0},
  [11395] = {.lex_state = 91},
  [11396] = {.lex_state = 0},
  [11397] = {.lex_state = 91},
  [11398] = {.lex_state = 0},
  [11399] = {.lex_state = 91},
  [11400] = {.lex_state = 0},
  [11401] = {.lex_state = 6},
  [11402] = {.lex_state = 0},
  [11403] = {.lex_state = 0},
  [11404] = {.lex_state = 0},
  [11405] = {.lex_state = 0},
  [11406] = {.lex_state = 0},
  [11407] = {.lex_state = 0},
  [11408] = {.lex_state = 91},
  [11409] = {.lex_state = 0},
  [11410] = {.lex_state = 0},
  [11411] = {.lex_state = 0},
  [11412] = {.lex_state = 0},
  [11413] = {.lex_state = 0},
  [11414] = {.lex_state = 91},
  [11415] = {.lex_state = 0},
  [11416] = {.lex_state = 91},
  [11417] = {.lex_state = 0},
  [11418] = {.lex_state = 0},
  [11419] = {.lex_state = 91},
  [11420] = {.lex_state = 91},
  [11421] = {.lex_state = 0},
  [11422] = {.lex_state = 0},
  [11423] = {.lex_state = 0},
  [11424] = {.lex_state = 0},
  [11425] = {.lex_state = 91},
  [11426] = {.lex_state = 91},
  [11427] = {.lex_state = 0},
  [11428] = {.lex_state = 0},
  [11429] = {.lex_state = 0},
  [11430] = {.lex_state = 0},
  [11431] = {.lex_state = 0},
  [11432] = {.lex_state = 91},
  [11433] = {.lex_state = 0},
  [11434] = {.lex_state = 0},
  [11435] = {.lex_state = 91},
  [11436] = {.lex_state = 91},
  [11437] = {.lex_state = 0},
  [11438] = {.lex_state = 6},
  [11439] = {.lex_state = 0},
  [11440] = {.lex_state = 0},
  [11441] = {.lex_state = 0},
  [11442] = {.lex_state = 0},
  [11443] = {.lex_state = 0},
  [11444] = {.lex_state = 0},
  [11445] = {.lex_state = 0},
  [11446] = {.lex_state = 0},
  [11447] = {.lex_state = 0},
  [11448] = {.lex_state = 0},
  [11449] = {.lex_state = 0},
  [11450] = {.lex_state = 0},
  [11451] = {.lex_state = 0},
  [11452] = {.lex_state = 0},
  [11453] = {.lex_state = 0},
  [11454] = {.lex_state = 0},
  [11455] = {.lex_state = 0},
  [11456] = {.lex_state = 0},
  [11457] = {.lex_state = 0},
  [11458] = {.lex_state = 0},
  [11459] = {.lex_state = 0},
  [11460] = {.lex_state = 0},
  [11461] = {.lex_state = 0},
  [11462] = {.lex_state = 0},
  [11463] = {.lex_state = 0},
  [11464] = {.lex_state = 0},
  [11465] = {.lex_state = 0},
  [11466] = {.lex_state = 0},
  [11467] = {.lex_state = 0},
  [11468] = {.lex_state = 0},
  [11469] = {.lex_state = 0},
  [11470] = {.lex_state = 0},
  [11471] = {.lex_state = 0},
  [11472] = {.lex_state = 0},
  [11473] = {.lex_state = 0},
  [11474] = {.lex_state = 0},
  [11475] = {.lex_state = 0},
  [11476] = {.lex_state = 91},
  [11477] = {.lex_state = 0},
  [11478] = {.lex_state = 0},
  [11479] = {.lex_state = 91},
  [11480] = {.lex_state = 91},
  [11481] = {.lex_state = 0},
  [11482] = {.lex_state = 0},
  [11483] = {.lex_state = 0},
  [11484] = {.lex_state = 0},
  [11485] = {.lex_state = 0},
  [11486] = {.lex_state = 0},
  [11487] = {.lex_state = 0},
  [11488] = {.lex_state = 0},
  [11489] = {.lex_state = 0},
  [11490] = {.lex_state = 0},
  [11491] = {.lex_state = 0},
  [11492] = {.lex_state = 0},
  [11493] = {.lex_state = 0},
  [11494] = {.lex_state = 91},
  [11495] = {.lex_state = 0},
  [11496] = {.lex_state = 0},
  [11497] = {.lex_state = 0},
  [11498] = {.lex_state = 0},
  [11499] = {.lex_state = 0},
  [11500] = {.lex_state = 0},
  [11501] = {.lex_state = 91},
  [11502] = {.lex_state = 91},
  [11503] = {.lex_state = 0},
  [11504] = {.lex_state = 91},
  [11505] = {.lex_state = 0},
  [11506] = {.lex_state = 0},
  [11507] = {.lex_state = 0},
  [11508] = {.lex_state = 0},
  [11509] = {.lex_state = 91},
  [11510] = {.lex_state = 10},
  [11511] = {.lex_state = 0},
  [11512] = {.lex_state = 91},
  [11513] = {.lex_state = 91},
  [11514] = {.lex_state = 91},
  [11515] = {.lex_state = 91},
  [11516] = {.lex_state = 0},
  [11517] = {.lex_state = 0},
  [11518] = {.lex_state = 91},
  [11519] = {.lex_state = 91},
  [11520] = {.lex_state = 0},
  [11521] = {.lex_state = 91},
  [11522] = {.lex_state = 0},
  [11523] = {.lex_state = 0},
  [11524] = {.lex_state = 0},
  [11525] = {.lex_state = 91},
  [11526] = {.lex_state = 91},
  [11527] = {.lex_state = 91},
  [11528] = {.lex_state = 0},
  [11529] = {.lex_state = 0},
  [11530] = {.lex_state = 0},
  [11531] = {.lex_state = 91},
  [11532] = {.lex_state = 91},
  [11533] = {.lex_state = 91},
  [11534] = {.lex_state = 0},
  [11535] = {.lex_state = 0},
  [11536] = {.lex_state = 91},
  [11537] = {.lex_state = 0},
  [11538] = {.lex_state = 0},
  [11539] = {.lex_state = 0},
  [11540] = {.lex_state = 0},
  [11541] = {.lex_state = 91},
  [11542] = {.lex_state = 0},
  [11543] = {.lex_state = 0},
  [11544] = {.lex_state = 0},
  [11545] = {.lex_state = 0},
  [11546] = {.lex_state = 91},
  [11547] = {.lex_state = 91},
  [11548] = {.lex_state = 0},
  [11549] = {.lex_state = 0},
  [11550] = {.lex_state = 91},
  [11551] = {.lex_state = 91},
  [11552] = {.lex_state = 0},
  [11553] = {.lex_state = 0},
  [11554] = {.lex_state = 91},
  [11555] = {.lex_state = 91},
  [11556] = {.lex_state = 91},
  [11557] = {.lex_state = 0},
  [11558] = {.lex_state = 91},
  [11559] = {.lex_state = 0},
  [11560] = {.lex_state = 91},
  [11561] = {.lex_state = 0},
  [11562] = {.lex_state = 0},
  [11563] = {.lex_state = 91},
  [11564] = {.lex_state = 91},
  [11565] = {.lex_state = 91},
  [11566] = {.lex_state = 0},
  [11567] = {.lex_state = 0},
  [11568] = {.lex_state = 0},
  [11569] = {.lex_state = 91},
  [11570] = {.lex_state = 0},
  [11571] = {.lex_state = 6},
  [11572] = {.lex_state = 0},
  [11573] = {.lex_state = 0},
  [11574] = {.lex_state = 0},
  [11575] = {.lex_state = 0},
  [11576] = {.lex_state = 0},
  [11577] = {.lex_state = 0},
  [11578] = {.lex_state = 0},
  [11579] = {.lex_state = 0},
  [11580] = {.lex_state = 0},
  [11581] = {.lex_state = 0},
  [11582] = {.lex_state = 0},
  [11583] = {.lex_state = 0},
  [11584] = {.lex_state = 0},
  [11585] = {.lex_state = 0},
  [11586] = {.lex_state = 0},
  [11587] = {.lex_state = 0},
  [11588] = {.lex_state = 0},
  [11589] = {.lex_state = 0},
  [11590] = {.lex_state = 0},
  [11591] = {.lex_state = 0},
  [11592] = {.lex_state = 0},
  [11593] = {.lex_state = 0},
  [11594] = {.lex_state = 0},
  [11595] = {.lex_state = 0},
  [11596] = {.lex_state = 0},
  [11597] = {.lex_state = 0},
  [11598] = {.lex_state = 0},
  [11599] = {.lex_state = 0},
  [11600] = {.lex_state = 0},
  [11601] = {.lex_state = 6},
  [11602] = {.lex_state = 6},
  [11603] = {.lex_state = 0},
  [11604] = {.lex_state = 0},
  [11605] = {.lex_state = 0},
  [11606] = {.lex_state = 0},
  [11607] = {.lex_state = 0},
  [11608] = {.lex_state = 0},
  [11609] = {.lex_state = 0},
  [11610] = {.lex_state = 0},
  [11611] = {.lex_state = 0},
  [11612] = {.lex_state = 91},
  [11613] = {.lex_state = 0},
  [11614] = {.lex_state = 0},
  [11615] = {.lex_state = 0},
  [11616] = {.lex_state = 0},
  [11617] = {.lex_state = 0},
  [11618] = {.lex_state = 12},
  [11619] = {.lex_state = 91},
  [11620] = {.lex_state = 91},
  [11621] = {.lex_state = 0},
  [11622] = {.lex_state = 91},
  [11623] = {.lex_state = 0},
  [11624] = {.lex_state = 0},
  [11625] = {.lex_state = 0},
  [11626] = {.lex_state = 91},
  [11627] = {.lex_state = 91},
  [11628] = {.lex_state = 91},
  [11629] = {.lex_state = 91},
  [11630] = {.lex_state = 91},
  [11631] = {.lex_state = 91},
  [11632] = {.lex_state = 91},
  [11633] = {.lex_state = 12},
  [11634] = {.lex_state = 91},
  [11635] = {.lex_state = 91},
  [11636] = {.lex_state = 91},
  [11637] = {.lex_state = 91},
  [11638] = {.lex_state = 0},
  [11639] = {.lex_state = 91},
  [11640] = {.lex_state = 91},
  [11641] = {.lex_state = 0},
  [11642] = {.lex_state = 91},
  [11643] = {.lex_state = 91},
  [11644] = {.lex_state = 0},
  [11645] = {.lex_state = 0},
  [11646] = {.lex_state = 91},
  [11647] = {.lex_state = 91},
  [11648] = {.lex_state = 0},
  [11649] = {.lex_state = 0},
  [11650] = {.lex_state = 91},
  [11651] = {.lex_state = 91},
  [11652] = {.lex_state = 91},
  [11653] = {.lex_state = 0},
  [11654] = {.lex_state = 91},
  [11655] = {.lex_state = 0},
  [11656] = {.lex_state = 91},
  [11657] = {.lex_state = 0},
  [11658] = {.lex_state = 0},
  [11659] = {.lex_state = 0},
  [11660] = {.lex_state = 91},
  [11661] = {.lex_state = 0},
  [11662] = {.lex_state = 0},
  [11663] = {.lex_state = 0},
  [11664] = {.lex_state = 6},
  [11665] = {.lex_state = 0},
  [11666] = {.lex_state = 0},
  [11667] = {.lex_state = 0},
  [11668] = {.lex_state = 0},
  [11669] = {.lex_state = 0},
  [11670] = {.lex_state = 0},
  [11671] = {.lex_state = 0},
  [11672] = {.lex_state = 91},
  [11673] = {.lex_state = 0},
  [11674] = {.lex_state = 0},
  [11675] = {.lex_state = 0},
  [11676] = {.lex_state = 0},
  [11677] = {.lex_state = 0},
  [11678] = {.lex_state = 0},
  [11679] = {.lex_state = 0},
  [11680] = {.lex_state = 0},
  [11681] = {.lex_state = 0},
  [11682] = {.lex_state = 0},
  [11683] = {.lex_state = 0},
  [11684] = {.lex_state = 0, .external_lex_state = 28},
  [11685] = {.lex_state = 0},
  [11686] = {.lex_state = 0},
  [11687] = {.lex_state = 0},
  [11688] = {.lex_state = 0},
  [11689] = {.lex_state = 0},
  [11690] = {.lex_state = 91},
  [11691] = {.lex_state = 6},
  [11692] = {.lex_state = 0},
  [11693] = {.lex_state = 0},
  [11694] = {.lex_state = 6},
  [11695] = {.lex_state = 0},
  [11696] = {.lex_state = 0},
  [11697] = {.lex_state = 91},
  [11698] = {.lex_state = 91},
  [11699] = {.lex_state = 91},
  [11700] = {.lex_state = 91},
  [11701] = {.lex_state = 0},
  [11702] = {.lex_state = 0},
  [11703] = {.lex_state = 0},
  [11704] = {.lex_state = 91},
  [11705] = {.lex_state = 91},
  [11706] = {.lex_state = 91},
  [11707] = {.lex_state = 91},
  [11708] = {.lex_state = 0},
  [11709] = {.lex_state = 91},
  [11710] = {.lex_state = 91},
  [11711] = {.lex_state = 0},
  [11712] = {.lex_state = 91},
  [11713] = {.lex_state = 91},
  [11714] = {.lex_state = 0},
  [11715] = {.lex_state = 0},
  [11716] = {.lex_state = 0},
  [11717] = {.lex_state = 0},
  [11718] = {.lex_state = 91},
  [11719] = {.lex_state = 0},
  [11720] = {.lex_state = 91},
  [11721] = {.lex_state = 91},
  [11722] = {.lex_state = 0},
  [11723] = {.lex_state = 91},
  [11724] = {.lex_state = 91},
  [11725] = {.lex_state = 91},
  [11726] = {.lex_state = 0},
  [11727] = {.lex_state = 0},
  [11728] = {.lex_state = 91},
  [11729] = {.lex_state = 91},
  [11730] = {.lex_state = 91},
  [11731] = {.lex_state = 0},
  [11732] = {.lex_state = 91},
  [11733] = {.lex_state = 0},
  [11734] = {.lex_state = 91},
  [11735] = {.lex_state = 0},
  [11736] = {.lex_state = 0},
  [11737] = {.lex_state = 0},
  [11738] = {.lex_state = 91},
  [11739] = {.lex_state = 91},
  [11740] = {.lex_state = 0},
  [11741] = {.lex_state = 0},
  [11742] = {.lex_state = 6},
  [11743] = {.lex_state = 0},
  [11744] = {.lex_state = 0},
  [11745] = {.lex_state = 0},
  [11746] = {.lex_state = 0},
  [11747] = {.lex_state = 0},
  [11748] = {.lex_state = 0},
  [11749] = {.lex_state = 91},
  [11750] = {.lex_state = 0},
  [11751] = {.lex_state = 91},
  [11752] = {.lex_state = 91},
  [11753] = {.lex_state = 6},
  [11754] = {.lex_state = 0},
  [11755] = {.lex_state = 91},
  [11756] = {.lex_state = 91},
  [11757] = {.lex_state = 0},
  [11758] = {.lex_state = 91},
  [11759] = {.lex_state = 6},
  [11760] = {.lex_state = 0},
  [11761] = {.lex_state = 91},
  [11762] = {.lex_state = 91},
  [11763] = {.lex_state = 91},
  [11764] = {.lex_state = 91},
  [11765] = {.lex_state = 0},
  [11766] = {.lex_state = 91},
  [11767] = {.lex_state = 91},
  [11768] = {.lex_state = 91},
  [11769] = {.lex_state = 91},
  [11770] = {.lex_state = 0},
  [11771] = {.lex_state = 0},
  [11772] = {.lex_state = 0},
  [11773] = {.lex_state = 0},
  [11774] = {.lex_state = 91},
  [11775] = {.lex_state = 0},
  [11776] = {.lex_state = 0},
  [11777] = {.lex_state = 0},
  [11778] = {.lex_state = 0},
  [11779] = {.lex_state = 0},
  [11780] = {.lex_state = 0},
  [11781] = {.lex_state = 6},
  [11782] = {.lex_state = 0},
  [11783] = {.lex_state = 0},
  [11784] = {.lex_state = 0},
  [11785] = {.lex_state = 0},
  [11786] = {.lex_state = 0},
  [11787] = {.lex_state = 91},
  [11788] = {.lex_state = 91},
  [11789] = {.lex_state = 91},
  [11790] = {.lex_state = 91},
  [11791] = {.lex_state = 0},
  [11792] = {.lex_state = 0},
  [11793] = {.lex_state = 0},
  [11794] = {.lex_state = 0},
  [11795] = {.lex_state = 91},
  [11796] = {.lex_state = 91},
  [11797] = {.lex_state = 0},
  [11798] = {.lex_state = 6},
  [11799] = {.lex_state = 91},
  [11800] = {.lex_state = 91},
  [11801] = {.lex_state = 6},
  [11802] = {.lex_state = 0},
  [11803] = {.lex_state = 0},
  [11804] = {.lex_state = 91},
  [11805] = {.lex_state = 91},
  [11806] = {.lex_state = 91},
  [11807] = {.lex_state = 91},
  [11808] = {.lex_state = 0},
  [11809] = {.lex_state = 0},
  [11810] = {.lex_state = 91},
  [11811] = {.lex_state = 0},
  [11812] = {.lex_state = 0},
  [11813] = {.lex_state = 6},
  [11814] = {.lex_state = 0},
  [11815] = {.lex_state = 0},
  [11816] = {.lex_state = 91},
  [11817] = {.lex_state = 91},
  [11818] = {.lex_state = 91},
  [11819] = {.lex_state = 91},
  [11820] = {.lex_state = 0},
  [11821] = {.lex_state = 12},
  [11822] = {.lex_state = 0},
  [11823] = {.lex_state = 6},
  [11824] = {.lex_state = 0},
  [11825] = {.lex_state = 0},
  [11826] = {.lex_state = 91},
  [11827] = {.lex_state = 91},
  [11828] = {.lex_state = 91},
  [11829] = {.lex_state = 91},
  [11830] = {.lex_state = 0},
  [11831] = {.lex_state = 0},
  [11832] = {.lex_state = 6},
  [11833] = {.lex_state = 0},
  [11834] = {.lex_state = 0},
  [11835] = {.lex_state = 91},
  [11836] = {.lex_state = 91},
  [11837] = {.lex_state = 91},
  [11838] = {.lex_state = 91},
  [11839] = {.lex_state = 0},
  [11840] = {.lex_state = 0},
  [11841] = {.lex_state = 6},
  [11842] = {.lex_state = 0},
  [11843] = {.lex_state = 0},
  [11844] = {.lex_state = 91},
  [11845] = {.lex_state = 91},
  [11846] = {.lex_state = 91},
  [11847] = {.lex_state = 91},
  [11848] = {.lex_state = 91},
  [11849] = {.lex_state = 91},
  [11850] = {.lex_state = 6},
  [11851] = {.lex_state = 0},
  [11852] = {.lex_state = 0},
  [11853] = {.lex_state = 91},
  [11854] = {.lex_state = 91},
  [11855] = {.lex_state = 91},
  [11856] = {.lex_state = 91},
  [11857] = {.lex_state = 6},
  [11858] = {.lex_state = 0},
  [11859] = {.lex_state = 0},
  [11860] = {.lex_state = 91},
  [11861] = {.lex_state = 91},
  [11862] = {.lex_state = 91},
  [11863] = {.lex_state = 91},
  [11864] = {.lex_state = 6},
  [11865] = {.lex_state = 91},
  [11866] = {.lex_state = 91},
  [11867] = {.lex_state = 91},
  [11868] = {.lex_state = 91},
  [11869] = {.lex_state = 6},
  [11870] = {.lex_state = 91},
  [11871] = {.lex_state = 91},
  [11872] = {.lex_state = 91},
  [11873] = {.lex_state = 91},
  [11874] = {.lex_state = 91},
  [11875] = {.lex_state = 91},
  [11876] = {.lex_state = 91},
  [11877] = {.lex_state = 91},
  [11878] = {.lex_state = 91},
  [11879] = {.lex_state = 91},
  [11880] = {.lex_state = 91},
  [11881] = {.lex_state = 91},
  [11882] = {.lex_state = 91},
  [11883] = {.lex_state = 91},
  [11884] = {.lex_state = 91},
  [11885] = {.lex_state = 91},
  [11886] = {.lex_state = 91},
  [11887] = {.lex_state = 91},
  [11888] = {.lex_state = 91},
  [11889] = {.lex_state = 91},
  [11890] = {.lex_state = 6},
  [11891] = {.lex_state = 6},
  [11892] = {.lex_state = 6},
  [11893] = {.lex_state = 6},
  [11894] = {.lex_state = 6},
  [11895] = {.lex_state = 6},
  [11896] = {.lex_state = 6},
  [11897] = {.lex_state = 6},
  [11898] = {.lex_state = 91},
  [11899] = {.lex_state = 91},
  [11900] = {.lex_state = 0},
  [11901] = {.lex_state = 12},
  [11902] = {.lex_state = 91},
  [11903] = {.lex_state = 91},
  [11904] = {.lex_state = 91},
  [11905] = {.lex_state = 91},
  [11906] = {.lex_state = 91},
  [11907] = {.lex_state = 0},
  [11908] = {.lex_state = 0},
  [11909] = {.lex_state = 0},
  [11910] = {.lex_state = 6},
  [11911] = {.lex_state = 6},
  [11912] = {.lex_state = 12},
  [11913] = {.lex_state = 0},
  [11914] = {.lex_state = 0},
  [11915] = {.lex_state = 0},
  [11916] = {.lex_state = 0},
  [11917] = {.lex_state = 0},
  [11918] = {.lex_state = 0},
  [11919] = {.lex_state = 0},
  [11920] = {.lex_state = 0},
  [11921] = {.lex_state = 12},
  [11922] = {.lex_state = 91},
  [11923] = {.lex_state = 0},
  [11924] = {.lex_state = 0},
  [11925] = {.lex_state = 0},
  [11926] = {.lex_state = 0},
  [11927] = {.lex_state = 0},
  [11928] = {.lex_state = 0},
  [11929] = {.lex_state = 0},
  [11930] = {.lex_state = 0},
  [11931] = {.lex_state = 0},
  [11932] = {.lex_state = 0},
  [11933] = {.lex_state = 0},
  [11934] = {.lex_state = 12},
  [11935] = {.lex_state = 0},
  [11936] = {.lex_state = 0},
  [11937] = {.lex_state = 0},
  [11938] = {.lex_state = 91},
  [11939] = {.lex_state = 0},
  [11940] = {.lex_state = 12},
  [11941] = {.lex_state = 0},
  [11942] = {.lex_state = 0},
  [11943] = {.lex_state = 0},
  [11944] = {.lex_state = 0},
  [11945] = {.lex_state = 91},
  [11946] = {.lex_state = 6},
  [11947] = {.lex_state = 0},
  [11948] = {.lex_state = 0},
  [11949] = {.lex_state = 0},
  [11950] = {.lex_state = 0},
  [11951] = {.lex_state = 0},
  [11952] = {.lex_state = 91},
  [11953] = {.lex_state = 0},
  [11954] = {.lex_state = 0},
  [11955] = {.lex_state = 0},
  [11956] = {.lex_state = 91},
  [11957] = {.lex_state = 0},
  [11958] = {.lex_state = 91},
  [11959] = {.lex_state = 91},
  [11960] = {.lex_state = 91},
  [11961] = {.lex_state = 0},
  [11962] = {.lex_state = 91},
  [11963] = {.lex_state = 0},
  [11964] = {.lex_state = 0},
  [11965] = {.lex_state = 91},
  [11966] = {.lex_state = 0},
  [11967] = {.lex_state = 0},
  [11968] = {.lex_state = 0},
  [11969] = {.lex_state = 91},
  [11970] = {.lex_state = 0},
  [11971] = {.lex_state = 91},
  [11972] = {.lex_state = 91},
  [11973] = {.lex_state = 0},
  [11974] = {.lex_state = 0},
  [11975] = {.lex_state = 0},
  [11976] = {.lex_state = 0},
  [11977] = {.lex_state = 6},
  [11978] = {.lex_state = 0},
  [11979] = {.lex_state = 0},
  [11980] = {.lex_state = 0},
  [11981] = {.lex_state = 6},
  [11982] = {.lex_state = 0},
  [11983] = {.lex_state = 91},
  [11984] = {.lex_state = 91},
  [11985] = {.lex_state = 0},
  [11986] = {.lex_state = 0},
  [11987] = {.lex_state = 91},
  [11988] = {.lex_state = 0},
  [11989] = {.lex_state = 0},
  [11990] = {.lex_state = 0},
  [11991] = {.lex_state = 91},
  [11992] = {.lex_state = 91},
  [11993] = {.lex_state = 0},
  [11994] = {.lex_state = 0},
  [11995] = {.lex_state = 6},
  [11996] = {.lex_state = 0},
  [11997] = {.lex_state = 0},
  [11998] = {.lex_state = 0},
  [11999] = {.lex_state = 0},
  [12000] = {.lex_state = 91},
  [12001] = {.lex_state = 0},
  [12002] = {.lex_state = 0},
  [12003] = {.lex_state = 0},
  [12004] = {.lex_state = 0},
  [12005] = {.lex_state = 91},
  [12006] = {.lex_state = 0},
  [12007] = {.lex_state = 0},
  [12008] = {.lex_state = 0},
  [12009] = {.lex_state = 0},
  [12010] = {.lex_state = 0},
  [12011] = {.lex_state = 0},
  [12012] = {.lex_state = 0},
  [12013] = {.lex_state = 0},
  [12014] = {.lex_state = 0},
  [12015] = {.lex_state = 0},
  [12016] = {.lex_state = 0},
  [12017] = {.lex_state = 0},
  [12018] = {.lex_state = 6},
  [12019] = {.lex_state = 0},
  [12020] = {.lex_state = 0},
  [12021] = {.lex_state = 91},
  [12022] = {.lex_state = 0},
  [12023] = {.lex_state = 12},
  [12024] = {.lex_state = 0},
  [12025] = {.lex_state = 0},
  [12026] = {.lex_state = 0},
  [12027] = {.lex_state = 0},
  [12028] = {.lex_state = 0},
  [12029] = {.lex_state = 0},
  [12030] = {.lex_state = 6},
  [12031] = {.lex_state = 0},
  [12032] = {.lex_state = 0},
  [12033] = {.lex_state = 0},
  [12034] = {.lex_state = 0},
  [12035] = {.lex_state = 91},
  [12036] = {.lex_state = 0},
  [12037] = {.lex_state = 0},
  [12038] = {.lex_state = 0},
  [12039] = {.lex_state = 0},
  [12040] = {.lex_state = 0},
  [12041] = {.lex_state = 0},
  [12042] = {.lex_state = 91},
  [12043] = {.lex_state = 91},
  [12044] = {.lex_state = 0},
  [12045] = {.lex_state = 0},
  [12046] = {.lex_state = 0},
  [12047] = {.lex_state = 0},
  [12048] = {.lex_state = 6},
  [12049] = {.lex_state = 0},
  [12050] = {.lex_state = 0},
  [12051] = {.lex_state = 91},
  [12052] = {.lex_state = 0},
  [12053] = {.lex_state = 0},
  [12054] = {.lex_state = 12},
  [12055] = {.lex_state = 0},
  [12056] = {.lex_state = 91},
  [12057] = {.lex_state = 6},
  [12058] = {.lex_state = 0},
  [12059] = {.lex_state = 0},
  [12060] = {.lex_state = 0},
  [12061] = {.lex_state = 0},
  [12062] = {.lex_state = 0},
  [12063] = {.lex_state = 0},
  [12064] = {.lex_state = 0},
  [12065] = {.lex_state = 0},
  [12066] = {.lex_state = 12},
  [12067] = {.lex_state = 0},
  [12068] = {.lex_state = 0},
  [12069] = {.lex_state = 91},
  [12070] = {.lex_state = 0},
  [12071] = {.lex_state = 91},
  [12072] = {.lex_state = 0},
  [12073] = {.lex_state = 0},
  [12074] = {.lex_state = 0},
  [12075] = {.lex_state = 6},
  [12076] = {.lex_state = 91},
  [12077] = {.lex_state = 91},
  [12078] = {.lex_state = 0},
  [12079] = {.lex_state = 12},
  [12080] = {.lex_state = 0},
  [12081] = {.lex_state = 91},
  [12082] = {.lex_state = 0},
  [12083] = {.lex_state = 0},
  [12084] = {.lex_state = 91},
  [12085] = {.lex_state = 0},
  [12086] = {.lex_state = 0},
  [12087] = {.lex_state = 0},
  [12088] = {.lex_state = 0},
  [12089] = {.lex_state = 12},
  [12090] = {.lex_state = 0},
  [12091] = {.lex_state = 0},
  [12092] = {.lex_state = 0},
  [12093] = {.lex_state = 0},
  [12094] = {.lex_state = 91},
  [12095] = {.lex_state = 91},
  [12096] = {.lex_state = 91},
  [12097] = {.lex_state = 91},
  [12098] = {.lex_state = 0},
  [12099] = {.lex_state = 0},
  [12100] = {.lex_state = 10},
  [12101] = {.lex_state = 0},
  [12102] = {.lex_state = 0},
  [12103] = {.lex_state = 91},
  [12104] = {.lex_state = 0},
  [12105] = {.lex_state = 91},
  [12106] = {.lex_state = 91},
  [12107] = {.lex_state = 0},
  [12108] = {.lex_state = 0},
  [12109] = {.lex_state = 6},
  [12110] = {.lex_state = 0},
  [12111] = {.lex_state = 6},
  [12112] = {.lex_state = 0},
  [12113] = {.lex_state = 0},
  [12114] = {.lex_state = 6},
  [12115] = {.lex_state = 0},
  [12116] = {.lex_state = 0},
  [12117] = {.lex_state = 0},
  [12118] = {.lex_state = 0},
  [12119] = {.lex_state = 0},
  [12120] = {.lex_state = 0},
  [12121] = {.lex_state = 0},
  [12122] = {.lex_state = 0},
  [12123] = {.lex_state = 0},
  [12124] = {.lex_state = 0},
  [12125] = {.lex_state = 91},
  [12126] = {.lex_state = 0},
  [12127] = {.lex_state = 91},
  [12128] = {.lex_state = 0},
  [12129] = {.lex_state = 0},
  [12130] = {.lex_state = 91},
  [12131] = {.lex_state = 0},
  [12132] = {.lex_state = 0},
  [12133] = {.lex_state = 91},
  [12134] = {.lex_state = 0},
  [12135] = {.lex_state = 0},
  [12136] = {.lex_state = 0},
  [12137] = {.lex_state = 0},
  [12138] = {.lex_state = 0},
  [12139] = {.lex_state = 0},
  [12140] = {.lex_state = 12},
  [12141] = {.lex_state = 0},
  [12142] = {.lex_state = 0},
  [12143] = {.lex_state = 0},
  [12144] = {.lex_state = 0},
  [12145] = {.lex_state = 0},
  [12146] = {.lex_state = 0},
  [12147] = {.lex_state = 6},
  [12148] = {.lex_state = 0},
  [12149] = {.lex_state = 12},
  [12150] = {.lex_state = 0},
  [12151] = {.lex_state = 0},
  [12152] = {.lex_state = 0},
  [12153] = {.lex_state = 0},
  [12154] = {.lex_state = 0},
  [12155] = {.lex_state = 6},
  [12156] = {.lex_state = 91},
  [12157] = {.lex_state = 6},
  [12158] = {.lex_state = 0},
  [12159] = {.lex_state = 0},
  [12160] = {.lex_state = 0},
  [12161] = {.lex_state = 0},
  [12162] = {.lex_state = 91},
  [12163] = {.lex_state = 12},
  [12164] = {.lex_state = 0},
  [12165] = {.lex_state = 0},
  [12166] = {.lex_state = 0},
  [12167] = {.lex_state = 12},
  [12168] = {.lex_state = 0},
  [12169] = {.lex_state = 91},
  [12170] = {.lex_state = 91},
  [12171] = {.lex_state = 0},
  [12172] = {.lex_state = 0},
  [12173] = {.lex_state = 0},
  [12174] = {.lex_state = 0},
  [12175] = {.lex_state = 0},
  [12176] = {.lex_state = 91},
  [12177] = {.lex_state = 0},
  [12178] = {.lex_state = 0},
  [12179] = {.lex_state = 0},
  [12180] = {.lex_state = 0},
  [12181] = {.lex_state = 12},
  [12182] = {.lex_state = 0},
  [12183] = {.lex_state = 12},
  [12184] = {.lex_state = 0},
  [12185] = {.lex_state = 0},
  [12186] = {.lex_state = 91},
  [12187] = {.lex_state = 0},
  [12188] = {.lex_state = 0},
  [12189] = {.lex_state = 0},
  [12190] = {.lex_state = 0},
  [12191] = {.lex_state = 12},
  [12192] = {.lex_state = 0},
  [12193] = {.lex_state = 0},
  [12194] = {.lex_state = 0},
  [12195] = {.lex_state = 0},
  [12196] = {.lex_state = 91},
  [12197] = {.lex_state = 0},
  [12198] = {.lex_state = 0},
  [12199] = {.lex_state = 12},
  [12200] = {.lex_state = 0},
  [12201] = {.lex_state = 0},
  [12202] = {.lex_state = 0},
  [12203] = {.lex_state = 0},
  [12204] = {.lex_state = 91},
  [12205] = {.lex_state = 0},
  [12206] = {.lex_state = 12},
  [12207] = {.lex_state = 0},
  [12208] = {.lex_state = 0},
  [12209] = {.lex_state = 6},
  [12210] = {.lex_state = 0},
  [12211] = {.lex_state = 12},
  [12212] = {.lex_state = 0},
  [12213] = {.lex_state = 12},
  [12214] = {.lex_state = 0},
  [12215] = {.lex_state = 91},
  [12216] = {.lex_state = 0},
  [12217] = {.lex_state = 0},
  [12218] = {.lex_state = 0},
  [12219] = {.lex_state = 0},
  [12220] = {.lex_state = 12},
  [12221] = {.lex_state = 0},
  [12222] = {.lex_state = 0},
  [12223] = {.lex_state = 0},
  [12224] = {.lex_state = 0},
  [12225] = {.lex_state = 91},
  [12226] = {.lex_state = 0},
  [12227] = {.lex_state = 12},
  [12228] = {.lex_state = 91},
  [12229] = {.lex_state = 12},
  [12230] = {.lex_state = 0},
  [12231] = {.lex_state = 0},
  [12232] = {.lex_state = 0},
  [12233] = {.lex_state = 0},
  [12234] = {.lex_state = 91},
  [12235] = {.lex_state = 6},
  [12236] = {.lex_state = 0},
  [12237] = {.lex_state = 0},
  [12238] = {.lex_state = 0},
  [12239] = {.lex_state = 0},
  [12240] = {.lex_state = 0},
  [12241] = {.lex_state = 0},
  [12242] = {.lex_state = 0},
  [12243] = {.lex_state = 0},
  [12244] = {.lex_state = 0},
  [12245] = {.lex_state = 0},
  [12246] = {.lex_state = 91},
  [12247] = {.lex_state = 0},
  [12248] = {.lex_state = 91},
  [12249] = {.lex_state = 0},
  [12250] = {.lex_state = 91},
  [12251] = {.lex_state = 0},
  [12252] = {.lex_state = 0},
  [12253] = {.lex_state = 91},
  [12254] = {.lex_state = 91},
  [12255] = {.lex_state = 91},
  [12256] = {.lex_state = 91},
  [12257] = {.lex_state = 91},
  [12258] = {.lex_state = 0},
  [12259] = {.lex_state = 12},
  [12260] = {.lex_state = 0},
  [12261] = {.lex_state = 91},
  [12262] = {.lex_state = 0},
  [12263] = {.lex_state = 0},
  [12264] = {.lex_state = 0},
  [12265] = {.lex_state = 0},
  [12266] = {.lex_state = 91},
  [12267] = {.lex_state = 91},
  [12268] = {.lex_state = 91},
  [12269] = {.lex_state = 12},
  [12270] = {.lex_state = 91},
  [12271] = {.lex_state = 0},
  [12272] = {.lex_state = 0},
  [12273] = {.lex_state = 91},
  [12274] = {.lex_state = 91},
  [12275] = {.lex_state = 91},
  [12276] = {.lex_state = 91},
  [12277] = {.lex_state = 91},
  [12278] = {.lex_state = 91},
  [12279] = {.lex_state = 91},
  [12280] = {.lex_state = 91},
  [12281] = {.lex_state = 91},
  [12282] = {.lex_state = 91},
  [12283] = {.lex_state = 91},
  [12284] = {.lex_state = 91},
  [12285] = {.lex_state = 91},
  [12286] = {.lex_state = 91},
  [12287] = {.lex_state = 91},
  [12288] = {.lex_state = 91},
  [12289] = {.lex_state = 91},
  [12290] = {.lex_state = 91},
  [12291] = {.lex_state = 91},
  [12292] = {.lex_state = 91},
  [12293] = {.lex_state = 91},
  [12294] = {.lex_state = 91},
  [12295] = {.lex_state = 91},
  [12296] = {.lex_state = 91},
  [12297] = {.lex_state = 91},
  [12298] = {.lex_state = 91},
  [12299] = {.lex_state = 91},
  [12300] = {.lex_state = 91},
  [12301] = {.lex_state = 91},
  [12302] = {.lex_state = 91},
  [12303] = {.lex_state = 6},
  [12304] = {.lex_state = 91},
  [12305] = {.lex_state = 0},
  [12306] = {.lex_state = 0},
  [12307] = {.lex_state = 0},
  [12308] = {.lex_state = 0},
  [12309] = {.lex_state = 0},
  [12310] = {.lex_state = 0},
  [12311] = {.lex_state = 0},
  [12312] = {.lex_state = 0},
  [12313] = {.lex_state = 0},
  [12314] = {.lex_state = 0},
  [12315] = {.lex_state = 0},
  [12316] = {.lex_state = 12},
  [12317] = {.lex_state = 91},
  [12318] = {.lex_state = 0},
  [12319] = {.lex_state = 0},
  [12320] = {.lex_state = 91},
  [12321] = {.lex_state = 0},
  [12322] = {.lex_state = 0},
  [12323] = {.lex_state = 91},
  [12324] = {.lex_state = 91},
  [12325] = {.lex_state = 0},
  [12326] = {.lex_state = 0},
  [12327] = {.lex_state = 91},
  [12328] = {.lex_state = 0},
  [12329] = {.lex_state = 0},
  [12330] = {.lex_state = 91},
  [12331] = {.lex_state = 91},
  [12332] = {.lex_state = 0},
  [12333] = {.lex_state = 6},
  [12334] = {.lex_state = 0},
  [12335] = {.lex_state = 91},
  [12336] = {.lex_state = 0},
  [12337] = {.lex_state = 91},
  [12338] = {.lex_state = 91},
  [12339] = {.lex_state = 91},
  [12340] = {.lex_state = 91},
  [12341] = {.lex_state = 0},
  [12342] = {.lex_state = 91},
  [12343] = {.lex_state = 91},
  [12344] = {.lex_state = 91},
  [12345] = {.lex_state = 91},
  [12346] = {.lex_state = 91},
  [12347] = {.lex_state = 91},
  [12348] = {.lex_state = 91},
  [12349] = {.lex_state = 91},
  [12350] = {.lex_state = 91},
  [12351] = {.lex_state = 91},
  [12352] = {.lex_state = 91},
  [12353] = {.lex_state = 91},
  [12354] = {.lex_state = 91},
  [12355] = {.lex_state = 91},
  [12356] = {.lex_state = 91},
  [12357] = {.lex_state = 91},
  [12358] = {.lex_state = 91},
  [12359] = {.lex_state = 91},
  [12360] = {.lex_state = 91},
  [12361] = {.lex_state = 91},
  [12362] = {.lex_state = 91},
  [12363] = {.lex_state = 91},
  [12364] = {.lex_state = 91},
  [12365] = {.lex_state = 91},
  [12366] = {.lex_state = 91},
  [12367] = {.lex_state = 91},
  [12368] = {.lex_state = 91},
  [12369] = {.lex_state = 0},
  [12370] = {.lex_state = 0},
  [12371] = {.lex_state = 0},
  [12372] = {.lex_state = 0},
  [12373] = {.lex_state = 0},
  [12374] = {.lex_state = 0},
  [12375] = {.lex_state = 0},
  [12376] = {.lex_state = 0},
  [12377] = {.lex_state = 6},
  [12378] = {.lex_state = 91},
  [12379] = {.lex_state = 0},
  [12380] = {.lex_state = 91},
  [12381] = {.lex_state = 0},
  [12382] = {.lex_state = 91},
  [12383] = {.lex_state = 91},
  [12384] = {.lex_state = 0},
  [12385] = {.lex_state = 0},
  [12386] = {.lex_state = 91},
  [12387] = {.lex_state = 6},
  [12388] = {.lex_state = 0},
  [12389] = {.lex_state = 6},
  [12390] = {.lex_state = 91},
  [12391] = {.lex_state = 91},
  [12392] = {.lex_state = 91},
  [12393] = {.lex_state = 0},
  [12394] = {.lex_state = 91},
  [12395] = {.lex_state = 91},
  [12396] = {.lex_state = 91},
  [12397] = {.lex_state = 91},
  [12398] = {.lex_state = 91},
  [12399] = {.lex_state = 91},
  [12400] = {.lex_state = 91},
  [12401] = {.lex_state = 91},
  [12402] = {.lex_state = 91},
  [12403] = {.lex_state = 91},
  [12404] = {.lex_state = 91},
  [12405] = {.lex_state = 91},
  [12406] = {.lex_state = 91},
  [12407] = {.lex_state = 91},
  [12408] = {.lex_state = 91},
  [12409] = {.lex_state = 91},
  [12410] = {.lex_state = 91},
  [12411] = {.lex_state = 0},
  [12412] = {.lex_state = 0},
  [12413] = {.lex_state = 0},
  [12414] = {.lex_state = 0},
  [12415] = {.lex_state = 0},
  [12416] = {.lex_state = 0},
  [12417] = {.lex_state = 0},
  [12418] = {.lex_state = 0},
  [12419] = {.lex_state = 0},
  [12420] = {.lex_state = 0},
  [12421] = {.lex_state = 91},
  [12422] = {.lex_state = 0},
  [12423] = {.lex_state = 6},
  [12424] = {.lex_state = 91},
  [12425] = {.lex_state = 91},
  [12426] = {.lex_state = 0},
  [12427] = {.lex_state = 0},
  [12428] = {.lex_state = 6},
  [12429] = {.lex_state = 91},
  [12430] = {.lex_state = 91},
  [12431] = {.lex_state = 91},
  [12432] = {.lex_state = 0},
  [12433] = {.lex_state = 6},
  [12434] = {.lex_state = 0},
  [12435] = {.lex_state = 0},
  [12436] = {.lex_state = 0},
  [12437] = {.lex_state = 0},
  [12438] = {.lex_state = 0},
  [12439] = {.lex_state = 91},
  [12440] = {.lex_state = 6},
  [12441] = {.lex_state = 6},
  [12442] = {.lex_state = 6},
  [12443] = {.lex_state = 91},
  [12444] = {.lex_state = 0},
  [12445] = {.lex_state = 0},
  [12446] = {.lex_state = 0},
  [12447] = {.lex_state = 91},
  [12448] = {.lex_state = 91},
  [12449] = {.lex_state = 0},
  [12450] = {.lex_state = 0},
  [12451] = {.lex_state = 0},
  [12452] = {.lex_state = 0},
  [12453] = {.lex_state = 91},
  [12454] = {.lex_state = 0},
  [12455] = {.lex_state = 0},
  [12456] = {.lex_state = 0},
  [12457] = {.lex_state = 0},
  [12458] = {.lex_state = 0},
  [12459] = {.lex_state = 91},
  [12460] = {.lex_state = 0},
  [12461] = {.lex_state = 91},
  [12462] = {.lex_state = 0},
  [12463] = {.lex_state = 12},
  [12464] = {.lex_state = 0},
  [12465] = {.lex_state = 12},
  [12466] = {.lex_state = 0},
  [12467] = {.lex_state = 91},
  [12468] = {.lex_state = 0},
  [12469] = {.lex_state = 0},
  [12470] = {.lex_state = 0},
  [12471] = {.lex_state = 6},
  [12472] = {.lex_state = 0},
  [12473] = {.lex_state = 91},
  [12474] = {.lex_state = 0},
  [12475] = {.lex_state = 0},
  [12476] = {.lex_state = 91},
  [12477] = {.lex_state = 0},
  [12478] = {.lex_state = 91},
  [12479] = {.lex_state = 0},
  [12480] = {.lex_state = 0},
  [12481] = {.lex_state = 12},
  [12482] = {.lex_state = 91},
  [12483] = {.lex_state = 91},
  [12484] = {.lex_state = 0},
  [12485] = {.lex_state = 91},
  [12486] = {.lex_state = 6},
  [12487] = {.lex_state = 0},
  [12488] = {.lex_state = 0},
  [12489] = {.lex_state = 0},
  [12490] = {.lex_state = 0},
  [12491] = {.lex_state = 0},
  [12492] = {.lex_state = 0},
  [12493] = {.lex_state = 91},
  [12494] = {.lex_state = 0},
  [12495] = {.lex_state = 6},
  [12496] = {.lex_state = 0},
  [12497] = {.lex_state = 91},
  [12498] = {.lex_state = 0},
  [12499] = {.lex_state = 6},
  [12500] = {.lex_state = 6},
  [12501] = {.lex_state = 0},
  [12502] = {.lex_state = 0},
  [12503] = {.lex_state = 0},
  [12504] = {.lex_state = 91},
  [12505] = {.lex_state = 6},
  [12506] = {.lex_state = 6},
  [12507] = {.lex_state = 0},
  [12508] = {.lex_state = 0},
  [12509] = {.lex_state = 91},
  [12510] = {.lex_state = 0},
  [12511] = {.lex_state = 91},
  [12512] = {.lex_state = 91},
  [12513] = {.lex_state = 91},
  [12514] = {.lex_state = 0},
  [12515] = {.lex_state = 0},
  [12516] = {.lex_state = 6},
  [12517] = {.lex_state = 0},
  [12518] = {.lex_state = 91},
  [12519] = {.lex_state = 0},
  [12520] = {.lex_state = 91},
  [12521] = {.lex_state = 91},
  [12522] = {.lex_state = 0},
  [12523] = {.lex_state = 6},
  [12524] = {.lex_state = 6},
  [12525] = {.lex_state = 6},
  [12526] = {.lex_state = 6},
  [12527] = {.lex_state = 6},
  [12528] = {.lex_state = 6},
  [12529] = {.lex_state = 12},
  [12530] = {.lex_state = 6},
  [12531] = {.lex_state = 6},
  [12532] = {.lex_state = 6},
  [12533] = {.lex_state = 0},
  [12534] = {.lex_state = 91},
  [12535] = {.lex_state = 0},
  [12536] = {.lex_state = 0},
  [12537] = {.lex_state = 0},
  [12538] = {.lex_state = 6},
  [12539] = {.lex_state = 6},
  [12540] = {.lex_state = 91},
  [12541] = {.lex_state = 0},
  [12542] = {.lex_state = 0},
  [12543] = {.lex_state = 0},
  [12544] = {.lex_state = 0},
  [12545] = {.lex_state = 91},
  [12546] = {.lex_state = 0},
  [12547] = {.lex_state = 6},
  [12548] = {.lex_state = 12},
  [12549] = {.lex_state = 0},
  [12550] = {.lex_state = 0},
  [12551] = {.lex_state = 12},
  [12552] = {.lex_state = 6},
  [12553] = {.lex_state = 0},
  [12554] = {.lex_state = 6},
  [12555] = {.lex_state = 0},
  [12556] = {.lex_state = 12},
  [12557] = {.lex_state = 0},
  [12558] = {.lex_state = 91},
  [12559] = {.lex_state = 0},
  [12560] = {.lex_state = 0},
  [12561] = {.lex_state = 0},
  [12562] = {.lex_state = 0},
  [12563] = {.lex_state = 6},
  [12564] = {.lex_state = 12},
  [12565] = {.lex_state = 12},
  [12566] = {.lex_state = 0},
  [12567] = {.lex_state = 0},
  [12568] = {.lex_state = 0},
  [12569] = {.lex_state = 0},
  [12570] = {.lex_state = 0},
  [12571] = {.lex_state = 0},
  [12572] = {.lex_state = 91},
  [12573] = {.lex_state = 91},
  [12574] = {.lex_state = 0},
  [12575] = {.lex_state = 0},
  [12576] = {.lex_state = 91},
  [12577] = {.lex_state = 6},
  [12578] = {.lex_state = 12},
  [12579] = {.lex_state = 0},
  [12580] = {.lex_state = 91},
  [12581] = {.lex_state = 91},
  [12582] = {.lex_state = 0},
  [12583] = {.lex_state = 91},
  [12584] = {.lex_state = 91},
  [12585] = {.lex_state = 91},
  [12586] = {.lex_state = 12},
  [12587] = {.lex_state = 91},
  [12588] = {.lex_state = 6},
  [12589] = {.lex_state = 91},
  [12590] = {.lex_state = 0},
  [12591] = {.lex_state = 91},
  [12592] = {.lex_state = 0},
  [12593] = {.lex_state = 91},
  [12594] = {.lex_state = 12},
  [12595] = {.lex_state = 6},
  [12596] = {.lex_state = 0},
  [12597] = {.lex_state = 12},
  [12598] = {.lex_state = 0},
  [12599] = {.lex_state = 91},
  [12600] = {.lex_state = 12},
  [12601] = {.lex_state = 0},
  [12602] = {.lex_state = 91},
  [12603] = {.lex_state = 12},
  [12604] = {.lex_state = 0},
  [12605] = {.lex_state = 0},
  [12606] = {.lex_state = 12},
  [12607] = {.lex_state = 0},
  [12608] = {.lex_state = 0},
  [12609] = {.lex_state = 12},
  [12610] = {.lex_state = 0},
  [12611] = {.lex_state = 6},
  [12612] = {.lex_state = 12},
  [12613] = {.lex_state = 0},
  [12614] = {.lex_state = 0},
  [12615] = {.lex_state = 0},
  [12616] = {.lex_state = 6},
  [12617] = {.lex_state = 6},
  [12618] = {.lex_state = 91},
  [12619] = {.lex_state = 0},
  [12620] = {.lex_state = 0},
  [12621] = {.lex_state = 0},
  [12622] = {.lex_state = 12},
  [12623] = {.lex_state = 0},
  [12624] = {.lex_state = 0},
  [12625] = {.lex_state = 91},
  [12626] = {.lex_state = 0},
  [12627] = {.lex_state = 91},
  [12628] = {.lex_state = 91},
  [12629] = {.lex_state = 91},
  [12630] = {.lex_state = 91},
  [12631] = {.lex_state = 91},
  [12632] = {.lex_state = 91},
  [12633] = {.lex_state = 91},
  [12634] = {.lex_state = 91},
  [12635] = {.lex_state = 91},
  [12636] = {.lex_state = 91},
  [12637] = {.lex_state = 12},
  [12638] = {.lex_state = 91},
  [12639] = {.lex_state = 91},
  [12640] = {.lex_state = 91},
  [12641] = {.lex_state = 91},
  [12642] = {.lex_state = 91},
  [12643] = {.lex_state = 91},
  [12644] = {.lex_state = 91},
  [12645] = {.lex_state = 91},
  [12646] = {.lex_state = 0},
  [12647] = {.lex_state = 91},
  [12648] = {.lex_state = 91},
  [12649] = {.lex_state = 91},
  [12650] = {.lex_state = 91},
  [12651] = {.lex_state = 91},
  [12652] = {.lex_state = 91},
  [12653] = {.lex_state = 12},
  [12654] = {.lex_state = 0},
  [12655] = {.lex_state = 91},
  [12656] = {.lex_state = 6},
  [12657] = {.lex_state = 91},
  [12658] = {.lex_state = 0},
  [12659] = {.lex_state = 6},
  [12660] = {.lex_state = 12},
  [12661] = {.lex_state = 0},
  [12662] = {.lex_state = 0},
  [12663] = {.lex_state = 0},
  [12664] = {.lex_state = 0},
  [12665] = {.lex_state = 0},
  [12666] = {.lex_state = 0},
  [12667] = {.lex_state = 0},
  [12668] = {.lex_state = 6},
  [12669] = {.lex_state = 0},
  [12670] = {.lex_state = 0},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [aux_sym_interface_declaration_token1] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [aux_sym_interface_declaration_token2] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [aux_sym_boolean_token1] = ACTIONS(1),
    [aux_sym_boolean_token2] = ACTIONS(1),
    [sym_decimal] = ACTIONS(1),
    [aux_sym_ml_value_list_token1] = ACTIONS(1),
    [aux_sym_lookup_formula_token1] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [aux_sym_where_clause_token1] = ACTIONS(1),
    [aux_sym_where_condition_token1] = ACTIONS(1),
    [aux_sym_where_condition_token2] = ACTIONS(1),
    [aux_sym_where_condition_token3] = ACTIONS(1),
    [anon_sym_DOT_DOT] = ACTIONS(1),
    [aux_sym_filter_value_token1] = ACTIONS(1),
    [aux_sym_sorting_value_token1] = ACTIONS(1),
    [aux_sym_sorting_value_token2] = ACTIONS(1),
    [aux_sym_sorting_value_token3] = ACTIONS(1),
    [aux_sym_sorting_value_token4] = ACTIONS(1),
    [aux_sym_if_table_relation_token1] = ACTIONS(1),
    [aux_sym_if_table_relation_token2] = ACTIONS(1),
    [aux_sym_tabledata_permission_token1] = ACTIONS(1),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [sym_permission_type] = ACTIONS(1),
    [aux_sym_order_by_item_token1] = ACTIONS(1),
    [aux_sym_order_by_item_token2] = ACTIONS(1),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(1),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(1),
    [aux_sym_text_type_token1] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [aux_sym_code_type_token1] = ACTIONS(1),
    [aux_sym_option_type_token1] = ACTIONS(1),
    [aux_sym_record_type_token1] = ACTIONS(1),
    [aux_sym_object_reference_type_token1] = ACTIONS(1),
    [aux_sym_object_reference_type_token2] = ACTIONS(1),
    [aux_sym_array_type_token1] = ACTIONS(1),
    [aux_sym_array_type_token2] = ACTIONS(1),
    [aux_sym_list_type_token1] = ACTIONS(1),
    [aux_sym_dictionary_type_token1] = ACTIONS(1),
    [aux_sym_basic_type_token1] = ACTIONS(1),
    [aux_sym_basic_type_token2] = ACTIONS(1),
    [aux_sym_basic_type_token3] = ACTIONS(1),
    [aux_sym_basic_type_token4] = ACTIONS(1),
    [aux_sym_basic_type_token5] = ACTIONS(1),
    [aux_sym_basic_type_token6] = ACTIONS(1),
    [aux_sym_basic_type_token7] = ACTIONS(1),
    [aux_sym_basic_type_token8] = ACTIONS(1),
    [aux_sym_basic_type_token9] = ACTIONS(1),
    [aux_sym_basic_type_token10] = ACTIONS(1),
    [aux_sym_basic_type_token11] = ACTIONS(1),
    [aux_sym_basic_type_token12] = ACTIONS(1),
    [aux_sym_basic_type_token13] = ACTIONS(1),
    [aux_sym_basic_type_token14] = ACTIONS(1),
    [aux_sym_basic_type_token15] = ACTIONS(1),
    [aux_sym_basic_type_token16] = ACTIONS(1),
    [aux_sym_basic_type_token17] = ACTIONS(1),
    [aux_sym_basic_type_token18] = ACTIONS(1),
    [aux_sym_basic_type_token19] = ACTIONS(1),
    [aux_sym_basic_type_token20] = ACTIONS(1),
    [aux_sym_basic_type_token21] = ACTIONS(1),
    [aux_sym_basic_type_token22] = ACTIONS(1),
    [aux_sym_basic_type_token23] = ACTIONS(1),
    [aux_sym_basic_type_token24] = ACTIONS(1),
    [aux_sym_basic_type_token25] = ACTIONS(1),
    [aux_sym_basic_type_token26] = ACTIONS(1),
    [aux_sym_basic_type_token27] = ACTIONS(1),
    [aux_sym_basic_type_token28] = ACTIONS(1),
    [aux_sym_basic_type_token29] = ACTIONS(1),
    [aux_sym_basic_type_token30] = ACTIONS(1),
    [aux_sym_basic_type_token31] = ACTIONS(1),
    [aux_sym_basic_type_token32] = ACTIONS(1),
    [aux_sym_basic_type_token33] = ACTIONS(1),
    [aux_sym_basic_type_token34] = ACTIONS(1),
    [aux_sym_basic_type_token35] = ACTIONS(1),
    [aux_sym_basic_type_token36] = ACTIONS(1),
    [aux_sym_basic_type_token37] = ACTIONS(1),
    [aux_sym_basic_type_token38] = ACTIONS(1),
    [aux_sym_basic_type_token39] = ACTIONS(1),
    [aux_sym_basic_type_token40] = ACTIONS(1),
    [aux_sym_basic_type_token41] = ACTIONS(1),
    [aux_sym_basic_type_token42] = ACTIONS(1),
    [aux_sym_basic_type_token43] = ACTIONS(1),
    [aux_sym_basic_type_token44] = ACTIONS(1),
    [aux_sym_basic_type_token45] = ACTIONS(1),
    [aux_sym_basic_type_token46] = ACTIONS(1),
    [aux_sym_basic_type_token47] = ACTIONS(1),
    [aux_sym_basic_type_token48] = ACTIONS(1),
    [aux_sym_basic_type_token49] = ACTIONS(1),
    [aux_sym_basic_type_token50] = ACTIONS(1),
    [aux_sym_basic_type_token51] = ACTIONS(1),
    [aux_sym_basic_type_token52] = ACTIONS(1),
    [aux_sym_basic_type_token53] = ACTIONS(1),
    [aux_sym_basic_type_token54] = ACTIONS(1),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(1),
    [aux_sym_label_declaration_token1] = ACTIONS(1),
    [aux_sym_label_declaration_token2] = ACTIONS(1),
    [aux_sym_area_section_token1] = ACTIONS(1),
    [aux_sym_area_section_token2] = ACTIONS(1),
    [aux_sym_area_section_token3] = ACTIONS(1),
    [aux_sym_area_section_token4] = ACTIONS(1),
    [aux_sym_area_section_token5] = ACTIONS(1),
    [aux_sym_area_section_token6] = ACTIONS(1),
    [aux_sym_area_section_token7] = ACTIONS(1),
    [aux_sym_area_section_token8] = ACTIONS(1),
    [aux_sym_addafter_modification_token1] = ACTIONS(1),
    [aux_sym_addbefore_modification_token1] = ACTIONS(1),
    [aux_sym_modify_modification_token1] = ACTIONS(1),
    [aux_sym_movefirst_modification_token1] = ACTIONS(1),
    [aux_sym_movelast_modification_token1] = ACTIONS(1),
    [aux_sym_moveafter_modification_token1] = ACTIONS(1),
    [aux_sym_movebefore_modification_token1] = ACTIONS(1),
    [aux_sym_action_area_section_token1] = ACTIONS(1),
    [aux_sym_action_area_section_token2] = ACTIONS(1),
    [aux_sym_action_area_section_token3] = ACTIONS(1),
    [aux_sym_action_area_section_token4] = ACTIONS(1),
    [aux_sym_action_area_section_token5] = ACTIONS(1),
    [aux_sym_action_area_section_token6] = ACTIONS(1),
    [aux_sym_action_area_section_token7] = ACTIONS(1),
    [aux_sym_separator_action_token1] = ACTIONS(1),
    [aux_sym_actionref_declaration_token1] = ACTIONS(1),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(1),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(1),
    [aux_sym_customaction_declaration_token1] = ACTIONS(1),
    [aux_sym_add_dataset_modification_token1] = ACTIONS(1),
    [aux_sym_xmlport_element_token1] = ACTIONS(1),
    [aux_sym_xmlport_element_token2] = ACTIONS(1),
    [aux_sym_xmlport_element_token3] = ACTIONS(1),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(1),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(1),
    [aux_sym_assembly_declaration_token1] = ACTIONS(1),
    [aux_sym_type_declaration_token1] = ACTIONS(1),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_POUNDif] = ACTIONS(1),
    [anon_sym_POUNDIF] = ACTIONS(1),
    [anon_sym_POUNDIf] = ACTIONS(1),
    [anon_sym_not] = ACTIONS(1),
    [anon_sym_NOT] = ACTIONS(1),
    [anon_sym_Not] = ACTIONS(1),
    [anon_sym_POUNDelif] = ACTIONS(1),
    [anon_sym_POUNDELIF] = ACTIONS(1),
    [anon_sym_POUNDElif] = ACTIONS(1),
    [anon_sym_POUNDelse] = ACTIONS(1),
    [anon_sym_POUNDELSE] = ACTIONS(1),
    [anon_sym_POUNDElse] = ACTIONS(1),
    [anon_sym_POUNDendif] = ACTIONS(1),
    [anon_sym_POUNDENDIF] = ACTIONS(1),
    [anon_sym_POUNDEndif] = ACTIONS(1),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(1),
    [anon_sym_COLON_EQ] = ACTIONS(1),
    [anon_sym_LPAREN2] = ACTIONS(1),
    [aux_sym__expression_token1] = ACTIONS(1),
    [aux_sym__expression_token2] = ACTIONS(1),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_div] = ACTIONS(1),
    [anon_sym_DIV] = ACTIONS(1),
    [anon_sym_Div] = ACTIONS(1),
    [anon_sym_mod] = ACTIONS(1),
    [anon_sym_MOD] = ACTIONS(1),
    [anon_sym_Mod] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_GT] = ACTIONS(1),
    [anon_sym_and] = ACTIONS(1),
    [anon_sym_AND] = ACTIONS(1),
    [anon_sym_And] = ACTIONS(1),
    [anon_sym_or] = ACTIONS(1),
    [anon_sym_OR] = ACTIONS(1),
    [anon_sym_Or] = ACTIONS(1),
    [anon_sym_xor] = ACTIONS(1),
    [anon_sym_XOR] = ACTIONS(1),
    [anon_sym_Xor] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [sym_datetime_literal] = ACTIONS(1),
    [sym_date_literal] = ACTIONS(1),
    [sym_time_literal] = ACTIONS(1),
    [sym_biginteger_literal] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_IF] = ACTIONS(1),
    [anon_sym_If] = ACTIONS(1),
    [anon_sym_then] = ACTIONS(1),
    [anon_sym_THEN] = ACTIONS(1),
    [anon_sym_Then] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_ELSE] = ACTIONS(1),
    [anon_sym_Else] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_CASE] = ACTIONS(1),
    [anon_sym_Case] = ACTIONS(1),
    [anon_sym_of] = ACTIONS(1),
    [anon_sym_OF] = ACTIONS(1),
    [anon_sym_Of] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_FOR] = ACTIONS(1),
    [anon_sym_For] = ACTIONS(1),
    [anon_sym_foreach] = ACTIONS(1),
    [anon_sym_FOREACH] = ACTIONS(1),
    [anon_sym_Foreach] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_WHILE] = ACTIONS(1),
    [anon_sym_While] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_DO] = ACTIONS(1),
    [anon_sym_Do] = ACTIONS(1),
    [anon_sym_repeat] = ACTIONS(1),
    [anon_sym_REPEAT] = ACTIONS(1),
    [anon_sym_Repeat] = ACTIONS(1),
    [anon_sym_until] = ACTIONS(1),
    [anon_sym_UNTIL] = ACTIONS(1),
    [anon_sym_Until] = ACTIONS(1),
    [anon_sym_exit] = ACTIONS(1),
    [anon_sym_EXIT] = ACTIONS(1),
    [anon_sym_Exit] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_CONTINUE] = ACTIONS(1),
    [anon_sym_Continue] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_BREAK] = ACTIONS(1),
    [anon_sym_Break] = ACTIONS(1),
    [anon_sym_with] = ACTIONS(1),
    [anon_sym_WITH] = ACTIONS(1),
    [anon_sym_With] = ACTIONS(1),
    [sym_asserterror_keyword] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_IN] = ACTIONS(1),
    [anon_sym_In] = ACTIONS(1),
    [anon_sym_to] = ACTIONS(1),
    [anon_sym_TO] = ACTIONS(1),
    [anon_sym_To] = ACTIONS(1),
    [anon_sym_downto] = ACTIONS(1),
    [anon_sym_DOWNTO] = ACTIONS(1),
    [anon_sym_Downto] = ACTIONS(1),
    [sym_table_keyword] = ACTIONS(1),
    [anon_sym_tableextension] = ACTIONS(1),
    [anon_sym_TABLEEXTENSION] = ACTIONS(1),
    [anon_sym_Tableextension] = ACTIONS(1),
    [anon_sym_TableExtension] = ACTIONS(1),
    [anon_sym_tableExtension] = ACTIONS(1),
    [sym_page_keyword] = ACTIONS(1),
    [anon_sym_pageextension] = ACTIONS(1),
    [anon_sym_PAGEEXTENSION] = ACTIONS(1),
    [anon_sym_Pageextension] = ACTIONS(1),
    [anon_sym_PageExtension] = ACTIONS(1),
    [anon_sym_pageExtension] = ACTIONS(1),
    [anon_sym_codeunit] = ACTIONS(1),
    [anon_sym_CODEUNIT] = ACTIONS(1),
    [anon_sym_Codeunit] = ACTIONS(1),
    [anon_sym_CodeUnit] = ACTIONS(1),
    [anon_sym_COdeunit] = ACTIONS(1),
    [anon_sym_codeUnit] = ACTIONS(1),
    [sym_report_keyword] = ACTIONS(1),
    [anon_sym_reportextension] = ACTIONS(1),
    [anon_sym_REPORTEXTENSION] = ACTIONS(1),
    [anon_sym_Reportextension] = ACTIONS(1),
    [anon_sym_ReportExtension] = ACTIONS(1),
    [anon_sym_reportExtension] = ACTIONS(1),
    [sym_query_keyword] = ACTIONS(1),
    [anon_sym_xmlport] = ACTIONS(1),
    [anon_sym_XMLPORT] = ACTIONS(1),
    [anon_sym_Xmlport] = ACTIONS(1),
    [anon_sym_XMLport] = ACTIONS(1),
    [anon_sym_XMLPort] = ACTIONS(1),
    [anon_sym_XmlPort] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_ENUM] = ACTIONS(1),
    [anon_sym_Enum] = ACTIONS(1),
    [anon_sym_eNUM] = ACTIONS(1),
    [anon_sym_eNum] = ACTIONS(1),
    [anon_sym_ENum] = ACTIONS(1),
    [anon_sym_enumextension] = ACTIONS(1),
    [anon_sym_ENUMEXTENSION] = ACTIONS(1),
    [anon_sym_Enumextension] = ACTIONS(1),
    [anon_sym_EnumExtension] = ACTIONS(1),
    [anon_sym_enumExtension] = ACTIONS(1),
    [sym_interface_keyword] = ACTIONS(1),
    [anon_sym_controladdin] = ACTIONS(1),
    [anon_sym_CONTROLADDIN] = ACTIONS(1),
    [anon_sym_Controladdin] = ACTIONS(1),
    [anon_sym_ControlAddIn] = ACTIONS(1),
    [anon_sym_ControlAddin] = ACTIONS(1),
    [anon_sym_controlAddIn] = ACTIONS(1),
    [anon_sym_controlAddin] = ACTIONS(1),
    [anon_sym_dotnet] = ACTIONS(1),
    [anon_sym_DOTNET] = ACTIONS(1),
    [anon_sym_Dotnet] = ACTIONS(1),
    [anon_sym_DotNet] = ACTIONS(1),
    [anon_sym_dotNet] = ACTIONS(1),
    [sym_profile_keyword] = ACTIONS(1),
    [anon_sym_profileextension] = ACTIONS(1),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(1),
    [anon_sym_Profileextension] = ACTIONS(1),
    [anon_sym_ProfileExtension] = ACTIONS(1),
    [anon_sym_profileExtension] = ACTIONS(1),
    [anon_sym_permissionset] = ACTIONS(1),
    [anon_sym_PERMISSIONSET] = ACTIONS(1),
    [anon_sym_Permissionset] = ACTIONS(1),
    [anon_sym_PermissionSet] = ACTIONS(1),
    [anon_sym_permissionSet] = ACTIONS(1),
    [anon_sym_permissionsetextension] = ACTIONS(1),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(1),
    [anon_sym_Permissionsetextension] = ACTIONS(1),
    [anon_sym_PermissionSetExtension] = ACTIONS(1),
    [anon_sym_permissionSetExtension] = ACTIONS(1),
    [sym_entitlement_keyword] = ACTIONS(1),
    [anon_sym_pagecustomization] = ACTIONS(1),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(1),
    [anon_sym_Pagecustomization] = ACTIONS(1),
    [anon_sym_PageCustomization] = ACTIONS(1),
    [anon_sym_pageCustomization] = ACTIONS(1),
    [sym_namespace_keyword] = ACTIONS(1),
    [sym_using_keyword] = ACTIONS(1),
    [sym_implements_keyword] = ACTIONS(1),
    [sym_extends_keyword] = ACTIONS(1),
    [sym_customizes_keyword] = ACTIONS(1),
    [sym_procedure_keyword] = ACTIONS(1),
    [sym_trigger_keyword] = ACTIONS(1),
    [sym_var_keyword] = ACTIONS(1),
    [sym_local_keyword] = ACTIONS(1),
    [sym_internal_keyword] = ACTIONS(1),
    [sym_protected_keyword] = ACTIONS(1),
    [sym_event_keyword] = ACTIONS(1),
    [sym_temporary_keyword] = ACTIONS(1),
    [sym_fields_keyword] = ACTIONS(1),
    [sym_keys_keyword] = ACTIONS(1),
    [sym_key_keyword] = ACTIONS(1),
    [sym_fieldgroups_keyword] = ACTIONS(1),
    [sym_fieldgroup_keyword] = ACTIONS(1),
    [sym_actions_keyword] = ACTIONS(1),
    [sym_layout_keyword] = ACTIONS(1),
    [sym_area_keyword] = ACTIONS(1),
    [sym_group_keyword] = ACTIONS(1),
    [sym_repeater_keyword] = ACTIONS(1),
    [sym_cuegroup_keyword] = ACTIONS(1),
    [sym_fixed_keyword] = ACTIONS(1),
    [sym_grid_keyword] = ACTIONS(1),
    [sym_part_keyword] = ACTIONS(1),
    [sym_systempart_keyword] = ACTIONS(1),
    [sym_usercontrol_keyword] = ACTIONS(1),
    [sym_dataset_keyword] = ACTIONS(1),
    [sym_elements_keyword] = ACTIONS(1),
    [sym_dataitem_keyword] = ACTIONS(1),
    [sym_column_keyword] = ACTIONS(1),
    [sym_filter_keyword] = ACTIONS(1),
    [sym_labels_keyword] = ACTIONS(1),
    [sym_rendering_keyword] = ACTIONS(1),
    [sym_requestpage_keyword] = ACTIONS(1),
    [sym_schema_keyword] = ACTIONS(1),
    [sym_views_keyword] = ACTIONS(1),
    [sym_view_keyword] = ACTIONS(1),
    [sym_quoted_identifier] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1),
    [sym_integer] = ACTIONS(1),
    [sym_property_name] = ACTIONS(1),
    [sym_continue_as_identifier] = ACTIONS(1),
    [sym_preproc_open] = ACTIONS(1),
    [sym_preproc_close] = ACTIONS(1),
    [sym_begin_keyword] = ACTIONS(1),
    [sym_end_keyword] = ACTIONS(1),
    [sym_preproc_split_begin] = ACTIONS(1),
    [sym_preproc_split_end] = ACTIONS(1),
    [sym_var_attribute_open] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(11754),
    [sym_preproc_conditional_object] = STATE(1164),
    [sym_namespace_declaration] = STATE(1179),
    [sym_using_statement] = STATE(1164),
    [sym__object] = STATE(1164),
    [sym_preproc_split_declaration] = STATE(1164),
    [sym_table_declaration] = STATE(1164),
    [sym_page_declaration] = STATE(1164),
    [sym_report_declaration] = STATE(1164),
    [sym_query_declaration] = STATE(1164),
    [sym_xmlport_declaration] = STATE(1164),
    [sym_permissionset_declaration] = STATE(1164),
    [sym_codeunit_declaration] = STATE(1164),
    [sym_enum_declaration] = STATE(1164),
    [sym_tableextension_declaration] = STATE(1164),
    [sym_pageextension_declaration] = STATE(1164),
    [sym_reportextension_declaration] = STATE(1164),
    [sym_enumextension_declaration] = STATE(1164),
    [sym_permissionsetextension_declaration] = STATE(1164),
    [sym_controladdin_declaration] = STATE(1164),
    [sym_profile_declaration] = STATE(1164),
    [sym_entitlement_declaration] = STATE(1164),
    [sym_profileextension_declaration] = STATE(1164),
    [sym_interface_declaration] = STATE(1164),
    [sym_pagecustomization_declaration] = STATE(1164),
    [sym_dotnet_declaration] = STATE(1164),
    [sym_preproc_if] = STATE(620),
    [sym_tableextension_keyword] = STATE(12387),
    [sym_pageextension_keyword] = STATE(12389),
    [sym_codeunit_keyword] = STATE(12423),
    [sym_reportextension_keyword] = STATE(12428),
    [sym_xmlport_keyword] = STATE(12505),
    [sym_enum_keyword] = STATE(12506),
    [sym_enumextension_keyword] = STATE(12516),
    [sym_controladdin_keyword] = STATE(8740),
    [sym_dotnet_keyword] = STATE(11413),
    [sym_profileextension_keyword] = STATE(8726),
    [sym_permissionset_keyword] = STATE(12440),
    [sym_permissionsetextension_keyword] = STATE(12495),
    [sym_pagecustomization_keyword] = STATE(8356),
    [aux_sym_source_file_repeat1] = STATE(1164),
    [ts_builtin_sym_end] = ACTIONS(5),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(13),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(19),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(23),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(33),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(39),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(47),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(51),
    [sym_using_keyword] = ACTIONS(53),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
  },
  [STATE(2)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(79),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(71),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1702),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(9941),
    [sym_preproc_else] = STATE(9942),
    [sym_preproc_endif] = STATE(556),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_fragmented_else_tail] = STATE(2385),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1703),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1704),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(8106),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(119),
    [anon_sym_POUNDELIF] = ACTIONS(119),
    [anon_sym_POUNDElif] = ACTIONS(119),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [anon_sym_POUNDendif] = ACTIONS(123),
    [anon_sym_POUNDENDIF] = ACTIONS(123),
    [anon_sym_POUNDEndif] = ACTIONS(123),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(123),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(127),
  },
  [STATE(4)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1705),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(9941),
    [sym_preproc_else] = STATE(10006),
    [sym_preproc_endif] = STATE(557),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_fragmented_else_tail] = STATE(2388),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1706),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1707),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(8107),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(119),
    [anon_sym_POUNDELIF] = ACTIONS(119),
    [anon_sym_POUNDElif] = ACTIONS(119),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [anon_sym_POUNDendif] = ACTIONS(123),
    [anon_sym_POUNDENDIF] = ACTIONS(123),
    [anon_sym_POUNDEndif] = ACTIONS(123),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(123),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(127),
  },
  [STATE(5)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(66),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(129),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(6)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(70),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(131),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(7)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(72),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(133),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(8)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(79),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(135),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(9)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(75),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(137),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(10)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(79),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(139),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(11)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1702),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(9941),
    [sym_preproc_else] = STATE(10277),
    [sym_preproc_endif] = STATE(256),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_fragmented_else_tail] = STATE(1717),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1703),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1704),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(7834),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(119),
    [anon_sym_POUNDELIF] = ACTIONS(119),
    [anon_sym_POUNDElif] = ACTIONS(119),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [anon_sym_POUNDendif] = ACTIONS(123),
    [anon_sym_POUNDENDIF] = ACTIONS(123),
    [anon_sym_POUNDEndif] = ACTIONS(123),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(123),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(141),
  },
  [STATE(12)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1705),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(9941),
    [sym_preproc_else] = STATE(10278),
    [sym_preproc_endif] = STATE(257),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_fragmented_else_tail] = STATE(1718),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1706),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1707),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(7835),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(119),
    [anon_sym_POUNDELIF] = ACTIONS(119),
    [anon_sym_POUNDElif] = ACTIONS(119),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [anon_sym_POUNDendif] = ACTIONS(123),
    [anon_sym_POUNDENDIF] = ACTIONS(123),
    [anon_sym_POUNDEndif] = ACTIONS(123),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(123),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(141),
  },
  [STATE(13)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1702),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(9941),
    [sym_preproc_else] = STATE(10291),
    [sym_preproc_endif] = STATE(289),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_fragmented_else_tail] = STATE(1947),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1703),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1704),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(7917),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(119),
    [anon_sym_POUNDELIF] = ACTIONS(119),
    [anon_sym_POUNDElif] = ACTIONS(119),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [anon_sym_POUNDendif] = ACTIONS(123),
    [anon_sym_POUNDENDIF] = ACTIONS(123),
    [anon_sym_POUNDEndif] = ACTIONS(123),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(123),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(143),
  },
  [STATE(14)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1705),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(9941),
    [sym_preproc_else] = STATE(10292),
    [sym_preproc_endif] = STATE(290),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_fragmented_else_tail] = STATE(1789),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1706),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1707),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(7918),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(119),
    [anon_sym_POUNDELIF] = ACTIONS(119),
    [anon_sym_POUNDElif] = ACTIONS(119),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [anon_sym_POUNDendif] = ACTIONS(123),
    [anon_sym_POUNDENDIF] = ACTIONS(123),
    [anon_sym_POUNDEndif] = ACTIONS(123),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(123),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(143),
  },
  [STATE(15)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1702),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(9941),
    [sym_preproc_else] = STATE(10302),
    [sym_preproc_endif] = STATE(427),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_fragmented_else_tail] = STATE(1947),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1703),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1704),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(7972),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(119),
    [anon_sym_POUNDELIF] = ACTIONS(119),
    [anon_sym_POUNDElif] = ACTIONS(119),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [anon_sym_POUNDendif] = ACTIONS(123),
    [anon_sym_POUNDENDIF] = ACTIONS(123),
    [anon_sym_POUNDEndif] = ACTIONS(123),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(123),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(143),
  },
  [STATE(16)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1705),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(9941),
    [sym_preproc_else] = STATE(10303),
    [sym_preproc_endif] = STATE(428),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_fragmented_else_tail] = STATE(1789),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1706),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1707),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(7973),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(119),
    [anon_sym_POUNDELIF] = ACTIONS(119),
    [anon_sym_POUNDElif] = ACTIONS(119),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [anon_sym_POUNDendif] = ACTIONS(123),
    [anon_sym_POUNDENDIF] = ACTIONS(123),
    [anon_sym_POUNDEndif] = ACTIONS(123),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(123),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(143),
  },
  [STATE(17)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1702),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(9941),
    [sym_preproc_else] = STATE(10309),
    [sym_preproc_endif] = STATE(397),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_fragmented_else_tail] = STATE(1717),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1703),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1704),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(8012),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(119),
    [anon_sym_POUNDELIF] = ACTIONS(119),
    [anon_sym_POUNDElif] = ACTIONS(119),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [anon_sym_POUNDendif] = ACTIONS(123),
    [anon_sym_POUNDENDIF] = ACTIONS(123),
    [anon_sym_POUNDEndif] = ACTIONS(123),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(123),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(141),
  },
  [STATE(18)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1705),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(9941),
    [sym_preproc_else] = STATE(10310),
    [sym_preproc_endif] = STATE(398),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_fragmented_else_tail] = STATE(1718),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1706),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1707),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(8013),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(119),
    [anon_sym_POUNDELIF] = ACTIONS(119),
    [anon_sym_POUNDElif] = ACTIONS(119),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [anon_sym_POUNDendif] = ACTIONS(123),
    [anon_sym_POUNDENDIF] = ACTIONS(123),
    [anon_sym_POUNDEndif] = ACTIONS(123),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(123),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(141),
  },
  [STATE(19)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1702),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(9941),
    [sym_preproc_else] = STATE(10316),
    [sym_preproc_endif] = STATE(322),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_fragmented_else_tail] = STATE(9999),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1703),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1704),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(8030),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(119),
    [anon_sym_POUNDELIF] = ACTIONS(119),
    [anon_sym_POUNDElif] = ACTIONS(119),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [anon_sym_POUNDendif] = ACTIONS(123),
    [anon_sym_POUNDENDIF] = ACTIONS(123),
    [anon_sym_POUNDEndif] = ACTIONS(123),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(123),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(145),
  },
  [STATE(20)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1705),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(9941),
    [sym_preproc_else] = STATE(10317),
    [sym_preproc_endif] = STATE(323),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_fragmented_else_tail] = STATE(10003),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1706),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1707),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(8031),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(119),
    [anon_sym_POUNDELIF] = ACTIONS(119),
    [anon_sym_POUNDElif] = ACTIONS(119),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [anon_sym_POUNDendif] = ACTIONS(123),
    [anon_sym_POUNDENDIF] = ACTIONS(123),
    [anon_sym_POUNDEndif] = ACTIONS(123),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(123),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(145),
  },
  [STATE(21)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(149),
  },
  [STATE(22)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(77),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(151),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(23)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(76),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(153),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(24)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(78),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(155),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(25)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(79),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(157),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(26)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(159),
  },
  [STATE(27)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(161),
  },
  [STATE(28)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(68),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(163),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(29)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(74),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(165),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(30)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(65),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(167),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(31)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(79),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(169),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(32)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(64),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(171),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(33)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(79),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(173),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(34)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(69),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(175),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(35)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(67),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(177),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(36)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(71),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(179),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(37)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(79),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(181),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(38)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(73),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(183),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(39)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(79),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(185),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(40)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(187),
  },
  [STATE(41)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(189),
  },
  [STATE(42)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(191),
  },
  [STATE(43)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(193),
  },
  [STATE(44)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(195),
  },
  [STATE(45)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(197),
  },
  [STATE(46)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(199),
  },
  [STATE(47)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(201),
  },
  [STATE(48)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(203),
  },
  [STATE(49)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(205),
  },
  [STATE(50)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(207),
  },
  [STATE(51)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(209),
  },
  [STATE(52)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(211),
  },
  [STATE(53)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(213),
  },
  [STATE(54)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(215),
  },
  [STATE(55)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
    [sym_preproc_split_end] = ACTIONS(217),
  },
  [STATE(56)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(63),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(219),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(57)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(122),
    [sym_preproc_endif] = STATE(1666),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7999),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9772),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3227),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(81),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7809),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(221),
    [anon_sym_POUNDENDIF] = ACTIONS(221),
    [anon_sym_POUNDEndif] = ACTIONS(221),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(221),
  },
  [STATE(58)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7946),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9662),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3221),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(79),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(59)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(150),
    [sym_preproc_endif] = STATE(1912),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7884),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9630),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3213),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(79),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7885),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(60)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(115),
    [sym_preproc_endif] = STATE(2283),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8123),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9538),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(2999),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(80),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(8124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
  },
  [STATE(61)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(106),
    [sym_preproc_endif] = STATE(10284),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(8026),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9373),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3234),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(82),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7947),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(223),
    [anon_sym_POUNDENDIF] = ACTIONS(223),
    [anon_sym_POUNDEndif] = ACTIONS(223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(223),
  },
  [STATE(62)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(122),
    [sym_preproc_endif] = STATE(1666),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym__preproc_if_header] = STATE(7808),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym__preproc_guard_block] = STATE(9912),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1757),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3206),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(81),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2645),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7809),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(221),
    [anon_sym_POUNDENDIF] = ACTIONS(221),
    [anon_sym_POUNDEndif] = ACTIONS(221),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(221),
  },
  [STATE(63)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(225),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(64)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(227),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(65)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(229),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(66)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(231),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(67)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(233),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(68)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(235),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(69)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(237),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(70)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(239),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(71)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(241),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(72)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(243),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(73)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(245),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(74)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(247),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(75)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(249),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(76)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(251),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(77)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(253),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(78)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(255),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(79)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(152),
    [sym_preproc_endif] = STATE(1916),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3249),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7896),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(80)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(132),
    [sym_preproc_endif] = STATE(2355),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3149),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7821),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
  },
  [STATE(81)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(153),
    [sym_preproc_endif] = STATE(1672),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3248),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7818),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(221),
    [anon_sym_POUNDENDIF] = ACTIONS(221),
    [anon_sym_POUNDEndif] = ACTIONS(221),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(221),
  },
  [STATE(82)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elif] = STATE(95),
    [sym_preproc_else] = STATE(109),
    [sym_preproc_endif] = STATE(9979),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3250),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(7958),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(223),
    [anon_sym_POUNDENDIF] = ACTIONS(223),
    [anon_sym_POUNDEndif] = ACTIONS(223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(223),
  },
  [STATE(83)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1655),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1656),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(257),
    [anon_sym_POUNDELIF] = ACTIONS(257),
    [anon_sym_POUNDElif] = ACTIONS(257),
    [anon_sym_POUNDelse] = ACTIONS(257),
    [anon_sym_POUNDELSE] = ACTIONS(257),
    [anon_sym_POUNDElse] = ACTIONS(257),
    [anon_sym_POUNDendif] = ACTIONS(257),
    [anon_sym_POUNDENDIF] = ACTIONS(257),
    [anon_sym_POUNDEndif] = ACTIONS(257),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(257),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(259),
  },
  [STATE(84)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1674),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1675),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(257),
    [anon_sym_POUNDELIF] = ACTIONS(257),
    [anon_sym_POUNDElif] = ACTIONS(257),
    [anon_sym_POUNDelse] = ACTIONS(257),
    [anon_sym_POUNDELSE] = ACTIONS(257),
    [anon_sym_POUNDElse] = ACTIONS(257),
    [anon_sym_POUNDendif] = ACTIONS(257),
    [anon_sym_POUNDENDIF] = ACTIONS(257),
    [anon_sym_POUNDEndif] = ACTIONS(257),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(257),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(261),
  },
  [STATE(85)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1531),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1532),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(257),
    [anon_sym_POUNDELIF] = ACTIONS(257),
    [anon_sym_POUNDElif] = ACTIONS(257),
    [anon_sym_POUNDelse] = ACTIONS(257),
    [anon_sym_POUNDELSE] = ACTIONS(257),
    [anon_sym_POUNDElse] = ACTIONS(257),
    [anon_sym_POUNDendif] = ACTIONS(257),
    [anon_sym_POUNDENDIF] = ACTIONS(257),
    [anon_sym_POUNDEndif] = ACTIONS(257),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(257),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(263),
  },
  [STATE(86)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1549),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1550),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(257),
    [anon_sym_POUNDELIF] = ACTIONS(257),
    [anon_sym_POUNDElif] = ACTIONS(257),
    [anon_sym_POUNDelse] = ACTIONS(257),
    [anon_sym_POUNDELSE] = ACTIONS(257),
    [anon_sym_POUNDElse] = ACTIONS(257),
    [anon_sym_POUNDendif] = ACTIONS(257),
    [anon_sym_POUNDENDIF] = ACTIONS(257),
    [anon_sym_POUNDEndif] = ACTIONS(257),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(257),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(265),
  },
  [STATE(87)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(8955),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(94),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(267),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(269),
    [anon_sym_POUNDELIF] = ACTIONS(269),
    [anon_sym_POUNDElif] = ACTIONS(269),
    [anon_sym_POUNDelse] = ACTIONS(269),
    [anon_sym_POUNDELSE] = ACTIONS(269),
    [anon_sym_POUNDElse] = ACTIONS(269),
    [anon_sym_POUNDendif] = ACTIONS(269),
    [anon_sym_POUNDENDIF] = ACTIONS(269),
    [anon_sym_POUNDEndif] = ACTIONS(269),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(269),
    [sym_begin_keyword] = ACTIONS(271),
  },
  [STATE(88)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1667),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1668),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(257),
    [anon_sym_POUNDELIF] = ACTIONS(257),
    [anon_sym_POUNDElif] = ACTIONS(257),
    [anon_sym_POUNDelse] = ACTIONS(257),
    [anon_sym_POUNDELSE] = ACTIONS(257),
    [anon_sym_POUNDElse] = ACTIONS(257),
    [anon_sym_POUNDendif] = ACTIONS(257),
    [anon_sym_POUNDENDIF] = ACTIONS(257),
    [anon_sym_POUNDEndif] = ACTIONS(257),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(257),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(263),
  },
  [STATE(89)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1669),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1670),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(257),
    [anon_sym_POUNDELIF] = ACTIONS(257),
    [anon_sym_POUNDElif] = ACTIONS(257),
    [anon_sym_POUNDelse] = ACTIONS(257),
    [anon_sym_POUNDELSE] = ACTIONS(257),
    [anon_sym_POUNDElse] = ACTIONS(257),
    [anon_sym_POUNDendif] = ACTIONS(257),
    [anon_sym_POUNDENDIF] = ACTIONS(257),
    [anon_sym_POUNDEndif] = ACTIONS(257),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(257),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(259),
  },
  [STATE(90)] = {
    [sym_boolean] = STATE(1005),
    [sym_option_member_list] = STATE(1040),
    [sym_option_member] = STATE(984),
    [sym_keyword_identifier] = STATE(1005),
    [sym_codeunit_keyword] = STATE(991),
    [sym_xmlport_keyword] = STATE(991),
    [sym_enum_keyword] = STATE(991),
    [sym_keyword_as_identifier] = STATE(1005),
    [aux_sym_option_member_list_repeat2] = STATE(92),
    [sym_identifier] = ACTIONS(273),
    [anon_sym_SEMI] = ACTIONS(275),
    [anon_sym_DOT] = ACTIONS(277),
    [anon_sym_EQ] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(279),
    [anon_sym_DASH] = ACTIONS(281),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(275),
    [aux_sym_where_condition_token1] = ACTIONS(283),
    [anon_sym_DOT_DOT] = ACTIONS(275),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(275),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(285),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_basic_type_token53] = ACTIONS(283),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(283),
    [aux_sym_separator_action_token1] = ACTIONS(283),
    [aux_sym_type_declaration_token1] = ACTIONS(283),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(277),
    [anon_sym_POUNDif] = ACTIONS(275),
    [anon_sym_POUNDIF] = ACTIONS(275),
    [anon_sym_POUNDIf] = ACTIONS(275),
    [anon_sym_not] = ACTIONS(277),
    [anon_sym_NOT] = ACTIONS(277),
    [anon_sym_Not] = ACTIONS(277),
    [anon_sym_POUNDelif] = ACTIONS(275),
    [anon_sym_POUNDELIF] = ACTIONS(275),
    [anon_sym_POUNDElif] = ACTIONS(275),
    [anon_sym_POUNDelse] = ACTIONS(275),
    [anon_sym_POUNDELSE] = ACTIONS(275),
    [anon_sym_POUNDElse] = ACTIONS(275),
    [anon_sym_POUNDendif] = ACTIONS(275),
    [anon_sym_POUNDENDIF] = ACTIONS(275),
    [anon_sym_POUNDEndif] = ACTIONS(275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(275),
    [aux_sym__expression_token1] = ACTIONS(275),
    [aux_sym__expression_token2] = ACTIONS(277),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(277),
    [anon_sym_div] = ACTIONS(277),
    [anon_sym_DIV] = ACTIONS(277),
    [anon_sym_Div] = ACTIONS(277),
    [anon_sym_mod] = ACTIONS(277),
    [anon_sym_MOD] = ACTIONS(277),
    [anon_sym_Mod] = ACTIONS(277),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(275),
    [anon_sym_LT_EQ] = ACTIONS(275),
    [anon_sym_GT] = ACTIONS(277),
    [anon_sym_LT] = ACTIONS(277),
    [anon_sym_LT_GT] = ACTIONS(275),
    [anon_sym_and] = ACTIONS(277),
    [anon_sym_AND] = ACTIONS(277),
    [anon_sym_And] = ACTIONS(277),
    [anon_sym_or] = ACTIONS(277),
    [anon_sym_OR] = ACTIONS(277),
    [anon_sym_Or] = ACTIONS(277),
    [anon_sym_xor] = ACTIONS(277),
    [anon_sym_XOR] = ACTIONS(277),
    [anon_sym_Xor] = ACTIONS(277),
    [anon_sym_QMARK] = ACTIONS(275),
    [sym_datetime_literal] = ACTIONS(275),
    [sym_date_literal] = ACTIONS(277),
    [sym_time_literal] = ACTIONS(277),
    [sym_biginteger_literal] = ACTIONS(275),
    [anon_sym_if] = ACTIONS(277),
    [anon_sym_IF] = ACTIONS(277),
    [anon_sym_If] = ACTIONS(277),
    [anon_sym_else] = ACTIONS(277),
    [anon_sym_ELSE] = ACTIONS(277),
    [anon_sym_Else] = ACTIONS(277),
    [anon_sym_case] = ACTIONS(277),
    [anon_sym_CASE] = ACTIONS(277),
    [anon_sym_Case] = ACTIONS(277),
    [anon_sym_for] = ACTIONS(277),
    [anon_sym_FOR] = ACTIONS(277),
    [anon_sym_For] = ACTIONS(277),
    [anon_sym_foreach] = ACTIONS(277),
    [anon_sym_FOREACH] = ACTIONS(277),
    [anon_sym_Foreach] = ACTIONS(277),
    [anon_sym_while] = ACTIONS(277),
    [anon_sym_WHILE] = ACTIONS(277),
    [anon_sym_While] = ACTIONS(277),
    [anon_sym_repeat] = ACTIONS(277),
    [anon_sym_REPEAT] = ACTIONS(277),
    [anon_sym_Repeat] = ACTIONS(277),
    [anon_sym_exit] = ACTIONS(277),
    [anon_sym_EXIT] = ACTIONS(277),
    [anon_sym_Exit] = ACTIONS(277),
    [anon_sym_continue] = ACTIONS(277),
    [anon_sym_CONTINUE] = ACTIONS(277),
    [anon_sym_Continue] = ACTIONS(277),
    [anon_sym_break] = ACTIONS(277),
    [anon_sym_BREAK] = ACTIONS(277),
    [anon_sym_Break] = ACTIONS(277),
    [anon_sym_with] = ACTIONS(277),
    [anon_sym_WITH] = ACTIONS(277),
    [anon_sym_With] = ACTIONS(277),
    [sym_asserterror_keyword] = ACTIONS(275),
    [anon_sym_in] = ACTIONS(277),
    [anon_sym_IN] = ACTIONS(277),
    [anon_sym_In] = ACTIONS(277),
    [sym_page_keyword] = ACTIONS(67),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(67),
    [sym_query_keyword] = ACTIONS(67),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_local_keyword] = ACTIONS(273),
    [sym_internal_keyword] = ACTIONS(273),
    [sym_protected_keyword] = ACTIONS(273),
    [sym_key_keyword] = ACTIONS(283),
    [sym_dataset_keyword] = ACTIONS(283),
    [sym_quoted_identifier] = ACTIONS(287),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(287),
    [sym_integer] = ACTIONS(273),
    [sym_continue_as_identifier] = ACTIONS(275),
    [sym_preproc_open] = ACTIONS(275),
    [sym_preproc_close] = ACTIONS(275),
  },
  [STATE(91)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(289),
    [anon_sym_SEMI] = ACTIONS(292),
    [anon_sym_DASH] = ACTIONS(295),
    [aux_sym_boolean_token1] = ACTIONS(298),
    [aux_sym_boolean_token2] = ACTIONS(298),
    [sym_decimal] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(304),
    [aux_sym_tabledata_permission_token2] = ACTIONS(307),
    [anon_sym_LBRACK] = ACTIONS(310),
    [aux_sym_record_type_token1] = ACTIONS(307),
    [aux_sym_basic_type_token21] = ACTIONS(307),
    [aux_sym_basic_type_token22] = ACTIONS(307),
    [aux_sym_basic_type_token48] = ACTIONS(307),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(313),
    [anon_sym_POUNDif] = ACTIONS(315),
    [anon_sym_POUNDIF] = ACTIONS(315),
    [anon_sym_POUNDIf] = ACTIONS(315),
    [anon_sym_not] = ACTIONS(318),
    [anon_sym_NOT] = ACTIONS(318),
    [anon_sym_Not] = ACTIONS(318),
    [anon_sym_POUNDelif] = ACTIONS(321),
    [anon_sym_POUNDELIF] = ACTIONS(321),
    [anon_sym_POUNDElif] = ACTIONS(321),
    [anon_sym_POUNDelse] = ACTIONS(321),
    [anon_sym_POUNDELSE] = ACTIONS(321),
    [anon_sym_POUNDElse] = ACTIONS(321),
    [anon_sym_POUNDendif] = ACTIONS(321),
    [anon_sym_POUNDENDIF] = ACTIONS(321),
    [anon_sym_POUNDEndif] = ACTIONS(321),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(307),
    [aux_sym_keyword_identifier_token2] = ACTIONS(323),
    [anon_sym_PLUS] = ACTIONS(295),
    [sym_datetime_literal] = ACTIONS(326),
    [sym_date_literal] = ACTIONS(301),
    [sym_time_literal] = ACTIONS(301),
    [sym_biginteger_literal] = ACTIONS(326),
    [anon_sym_if] = ACTIONS(329),
    [anon_sym_IF] = ACTIONS(329),
    [anon_sym_If] = ACTIONS(329),
    [anon_sym_case] = ACTIONS(332),
    [anon_sym_CASE] = ACTIONS(332),
    [anon_sym_Case] = ACTIONS(332),
    [anon_sym_for] = ACTIONS(335),
    [anon_sym_FOR] = ACTIONS(335),
    [anon_sym_For] = ACTIONS(335),
    [anon_sym_foreach] = ACTIONS(338),
    [anon_sym_FOREACH] = ACTIONS(338),
    [anon_sym_Foreach] = ACTIONS(338),
    [anon_sym_while] = ACTIONS(341),
    [anon_sym_WHILE] = ACTIONS(341),
    [anon_sym_While] = ACTIONS(341),
    [anon_sym_repeat] = ACTIONS(344),
    [anon_sym_REPEAT] = ACTIONS(344),
    [anon_sym_Repeat] = ACTIONS(344),
    [anon_sym_exit] = ACTIONS(347),
    [anon_sym_EXIT] = ACTIONS(347),
    [anon_sym_Exit] = ACTIONS(347),
    [anon_sym_continue] = ACTIONS(350),
    [anon_sym_CONTINUE] = ACTIONS(350),
    [anon_sym_Continue] = ACTIONS(350),
    [anon_sym_break] = ACTIONS(353),
    [anon_sym_BREAK] = ACTIONS(353),
    [anon_sym_Break] = ACTIONS(353),
    [anon_sym_with] = ACTIONS(356),
    [anon_sym_WITH] = ACTIONS(356),
    [anon_sym_With] = ACTIONS(356),
    [sym_asserterror_keyword] = ACTIONS(359),
    [sym_page_keyword] = ACTIONS(323),
    [anon_sym_codeunit] = ACTIONS(362),
    [anon_sym_CODEUNIT] = ACTIONS(362),
    [anon_sym_Codeunit] = ACTIONS(362),
    [anon_sym_CodeUnit] = ACTIONS(362),
    [anon_sym_COdeunit] = ACTIONS(362),
    [anon_sym_codeUnit] = ACTIONS(362),
    [sym_report_keyword] = ACTIONS(323),
    [sym_query_keyword] = ACTIONS(323),
    [anon_sym_xmlport] = ACTIONS(365),
    [anon_sym_XMLPORT] = ACTIONS(365),
    [anon_sym_Xmlport] = ACTIONS(365),
    [anon_sym_XMLport] = ACTIONS(365),
    [anon_sym_XMLPort] = ACTIONS(365),
    [anon_sym_XmlPort] = ACTIONS(365),
    [anon_sym_enum] = ACTIONS(368),
    [anon_sym_ENUM] = ACTIONS(368),
    [anon_sym_Enum] = ACTIONS(368),
    [anon_sym_eNUM] = ACTIONS(368),
    [anon_sym_eNum] = ACTIONS(368),
    [anon_sym_ENum] = ACTIONS(368),
    [sym_quoted_identifier] = ACTIONS(371),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(326),
    [sym_integer] = ACTIONS(301),
    [sym_continue_as_identifier] = ACTIONS(326),
    [sym_preproc_open] = ACTIONS(315),
    [sym_preproc_close] = ACTIONS(321),
  },
  [STATE(92)] = {
    [sym_boolean] = STATE(1005),
    [sym_option_member] = STATE(961),
    [sym_keyword_identifier] = STATE(1005),
    [sym_codeunit_keyword] = STATE(991),
    [sym_xmlport_keyword] = STATE(991),
    [sym_enum_keyword] = STATE(991),
    [sym_keyword_as_identifier] = STATE(1005),
    [aux_sym_option_member_list_repeat2] = STATE(167),
    [sym_identifier] = ACTIONS(273),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(378),
    [anon_sym_DASH] = ACTIONS(281),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(376),
    [anon_sym_LPAREN] = ACTIONS(374),
    [aux_sym_where_condition_token1] = ACTIONS(283),
    [anon_sym_DOT_DOT] = ACTIONS(374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(285),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_basic_type_token53] = ACTIONS(283),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(283),
    [aux_sym_separator_action_token1] = ACTIONS(283),
    [aux_sym_type_declaration_token1] = ACTIONS(283),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(376),
    [anon_sym_POUNDif] = ACTIONS(374),
    [anon_sym_POUNDIF] = ACTIONS(374),
    [anon_sym_POUNDIf] = ACTIONS(374),
    [anon_sym_not] = ACTIONS(376),
    [anon_sym_NOT] = ACTIONS(376),
    [anon_sym_Not] = ACTIONS(376),
    [anon_sym_POUNDelif] = ACTIONS(374),
    [anon_sym_POUNDELIF] = ACTIONS(374),
    [anon_sym_POUNDElif] = ACTIONS(374),
    [anon_sym_POUNDelse] = ACTIONS(374),
    [anon_sym_POUNDELSE] = ACTIONS(374),
    [anon_sym_POUNDElse] = ACTIONS(374),
    [anon_sym_POUNDendif] = ACTIONS(374),
    [anon_sym_POUNDENDIF] = ACTIONS(374),
    [anon_sym_POUNDEndif] = ACTIONS(374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(374),
    [aux_sym__expression_token1] = ACTIONS(374),
    [aux_sym__expression_token2] = ACTIONS(376),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(376),
    [anon_sym_div] = ACTIONS(376),
    [anon_sym_DIV] = ACTIONS(376),
    [anon_sym_Div] = ACTIONS(376),
    [anon_sym_mod] = ACTIONS(376),
    [anon_sym_MOD] = ACTIONS(376),
    [anon_sym_Mod] = ACTIONS(376),
    [anon_sym_PLUS] = ACTIONS(376),
    [anon_sym_GT_EQ] = ACTIONS(374),
    [anon_sym_LT_EQ] = ACTIONS(374),
    [anon_sym_GT] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(376),
    [anon_sym_LT_GT] = ACTIONS(374),
    [anon_sym_and] = ACTIONS(376),
    [anon_sym_AND] = ACTIONS(376),
    [anon_sym_And] = ACTIONS(376),
    [anon_sym_or] = ACTIONS(376),
    [anon_sym_OR] = ACTIONS(376),
    [anon_sym_Or] = ACTIONS(376),
    [anon_sym_xor] = ACTIONS(376),
    [anon_sym_XOR] = ACTIONS(376),
    [anon_sym_Xor] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(374),
    [sym_datetime_literal] = ACTIONS(374),
    [sym_date_literal] = ACTIONS(376),
    [sym_time_literal] = ACTIONS(376),
    [sym_biginteger_literal] = ACTIONS(374),
    [anon_sym_if] = ACTIONS(376),
    [anon_sym_IF] = ACTIONS(376),
    [anon_sym_If] = ACTIONS(376),
    [anon_sym_else] = ACTIONS(376),
    [anon_sym_ELSE] = ACTIONS(376),
    [anon_sym_Else] = ACTIONS(376),
    [anon_sym_case] = ACTIONS(376),
    [anon_sym_CASE] = ACTIONS(376),
    [anon_sym_Case] = ACTIONS(376),
    [anon_sym_for] = ACTIONS(376),
    [anon_sym_FOR] = ACTIONS(376),
    [anon_sym_For] = ACTIONS(376),
    [anon_sym_foreach] = ACTIONS(376),
    [anon_sym_FOREACH] = ACTIONS(376),
    [anon_sym_Foreach] = ACTIONS(376),
    [anon_sym_while] = ACTIONS(376),
    [anon_sym_WHILE] = ACTIONS(376),
    [anon_sym_While] = ACTIONS(376),
    [anon_sym_repeat] = ACTIONS(376),
    [anon_sym_REPEAT] = ACTIONS(376),
    [anon_sym_Repeat] = ACTIONS(376),
    [anon_sym_exit] = ACTIONS(376),
    [anon_sym_EXIT] = ACTIONS(376),
    [anon_sym_Exit] = ACTIONS(376),
    [anon_sym_continue] = ACTIONS(376),
    [anon_sym_CONTINUE] = ACTIONS(376),
    [anon_sym_Continue] = ACTIONS(376),
    [anon_sym_break] = ACTIONS(376),
    [anon_sym_BREAK] = ACTIONS(376),
    [anon_sym_Break] = ACTIONS(376),
    [anon_sym_with] = ACTIONS(376),
    [anon_sym_WITH] = ACTIONS(376),
    [anon_sym_With] = ACTIONS(376),
    [sym_asserterror_keyword] = ACTIONS(374),
    [anon_sym_in] = ACTIONS(376),
    [anon_sym_IN] = ACTIONS(376),
    [anon_sym_In] = ACTIONS(376),
    [sym_page_keyword] = ACTIONS(67),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(67),
    [sym_query_keyword] = ACTIONS(67),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_local_keyword] = ACTIONS(273),
    [sym_internal_keyword] = ACTIONS(273),
    [sym_protected_keyword] = ACTIONS(273),
    [sym_key_keyword] = ACTIONS(283),
    [sym_dataset_keyword] = ACTIONS(283),
    [sym_quoted_identifier] = ACTIONS(287),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(287),
    [sym_integer] = ACTIONS(273),
    [sym_continue_as_identifier] = ACTIONS(374),
    [sym_preproc_open] = ACTIONS(374),
    [sym_preproc_close] = ACTIONS(374),
  },
  [STATE(93)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(380),
    [anon_sym_POUNDELIF] = ACTIONS(380),
    [anon_sym_POUNDElif] = ACTIONS(380),
    [anon_sym_POUNDelse] = ACTIONS(380),
    [anon_sym_POUNDELSE] = ACTIONS(380),
    [anon_sym_POUNDElse] = ACTIONS(380),
    [anon_sym_POUNDendif] = ACTIONS(380),
    [anon_sym_POUNDENDIF] = ACTIONS(380),
    [anon_sym_POUNDEndif] = ACTIONS(380),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(380),
  },
  [STATE(94)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(382),
    [anon_sym_POUNDELIF] = ACTIONS(382),
    [anon_sym_POUNDElif] = ACTIONS(382),
    [anon_sym_POUNDelse] = ACTIONS(382),
    [anon_sym_POUNDELSE] = ACTIONS(382),
    [anon_sym_POUNDElse] = ACTIONS(382),
    [anon_sym_POUNDendif] = ACTIONS(382),
    [anon_sym_POUNDENDIF] = ACTIONS(382),
    [anon_sym_POUNDEndif] = ACTIONS(382),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(382),
  },
  [STATE(95)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(93),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(384),
    [anon_sym_POUNDELIF] = ACTIONS(384),
    [anon_sym_POUNDElif] = ACTIONS(384),
    [anon_sym_POUNDelse] = ACTIONS(384),
    [anon_sym_POUNDELSE] = ACTIONS(384),
    [anon_sym_POUNDElse] = ACTIONS(384),
    [anon_sym_POUNDendif] = ACTIONS(384),
    [anon_sym_POUNDENDIF] = ACTIONS(384),
    [anon_sym_POUNDEndif] = ACTIONS(384),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(384),
  },
  [STATE(96)] = {
    [sym_boolean] = STATE(1005),
    [sym_option_member] = STATE(1001),
    [sym_keyword_identifier] = STATE(1005),
    [sym_codeunit_keyword] = STATE(991),
    [sym_xmlport_keyword] = STATE(991),
    [sym_enum_keyword] = STATE(991),
    [sym_keyword_as_identifier] = STATE(1005),
    [sym_identifier] = ACTIONS(386),
    [anon_sym_SEMI] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(391),
    [anon_sym_EQ] = ACTIONS(389),
    [anon_sym_COMMA] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(393),
    [aux_sym_boolean_token1] = ACTIONS(396),
    [aux_sym_boolean_token2] = ACTIONS(396),
    [sym_decimal] = ACTIONS(391),
    [anon_sym_LPAREN] = ACTIONS(389),
    [aux_sym_where_condition_token1] = ACTIONS(283),
    [anon_sym_DOT_DOT] = ACTIONS(389),
    [aux_sym_tabledata_permission_token2] = ACTIONS(399),
    [anon_sym_STAR] = ACTIONS(391),
    [anon_sym_LBRACK] = ACTIONS(389),
    [aux_sym_record_type_token1] = ACTIONS(399),
    [aux_sym_basic_type_token21] = ACTIONS(399),
    [aux_sym_basic_type_token22] = ACTIONS(402),
    [aux_sym_basic_type_token48] = ACTIONS(399),
    [aux_sym_basic_type_token53] = ACTIONS(283),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(283),
    [aux_sym_separator_action_token1] = ACTIONS(283),
    [aux_sym_type_declaration_token1] = ACTIONS(283),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(391),
    [anon_sym_POUNDif] = ACTIONS(389),
    [anon_sym_POUNDIF] = ACTIONS(389),
    [anon_sym_POUNDIf] = ACTIONS(389),
    [anon_sym_not] = ACTIONS(391),
    [anon_sym_NOT] = ACTIONS(391),
    [anon_sym_Not] = ACTIONS(391),
    [anon_sym_POUNDelif] = ACTIONS(389),
    [anon_sym_POUNDELIF] = ACTIONS(389),
    [anon_sym_POUNDElif] = ACTIONS(389),
    [anon_sym_POUNDelse] = ACTIONS(389),
    [anon_sym_POUNDELSE] = ACTIONS(389),
    [anon_sym_POUNDElse] = ACTIONS(389),
    [anon_sym_POUNDendif] = ACTIONS(389),
    [anon_sym_POUNDENDIF] = ACTIONS(389),
    [anon_sym_POUNDEndif] = ACTIONS(389),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(389),
    [aux_sym__expression_token1] = ACTIONS(389),
    [aux_sym__expression_token2] = ACTIONS(391),
    [aux_sym_keyword_identifier_token1] = ACTIONS(399),
    [aux_sym_keyword_identifier_token2] = ACTIONS(399),
    [anon_sym_SLASH] = ACTIONS(391),
    [anon_sym_div] = ACTIONS(391),
    [anon_sym_DIV] = ACTIONS(391),
    [anon_sym_Div] = ACTIONS(391),
    [anon_sym_mod] = ACTIONS(391),
    [anon_sym_MOD] = ACTIONS(391),
    [anon_sym_Mod] = ACTIONS(391),
    [anon_sym_PLUS] = ACTIONS(391),
    [anon_sym_GT_EQ] = ACTIONS(389),
    [anon_sym_LT_EQ] = ACTIONS(389),
    [anon_sym_GT] = ACTIONS(391),
    [anon_sym_LT] = ACTIONS(391),
    [anon_sym_LT_GT] = ACTIONS(389),
    [anon_sym_and] = ACTIONS(391),
    [anon_sym_AND] = ACTIONS(391),
    [anon_sym_And] = ACTIONS(391),
    [anon_sym_or] = ACTIONS(391),
    [anon_sym_OR] = ACTIONS(391),
    [anon_sym_Or] = ACTIONS(391),
    [anon_sym_xor] = ACTIONS(391),
    [anon_sym_XOR] = ACTIONS(391),
    [anon_sym_Xor] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(389),
    [sym_datetime_literal] = ACTIONS(389),
    [sym_date_literal] = ACTIONS(391),
    [sym_time_literal] = ACTIONS(391),
    [sym_biginteger_literal] = ACTIONS(389),
    [anon_sym_if] = ACTIONS(391),
    [anon_sym_IF] = ACTIONS(391),
    [anon_sym_If] = ACTIONS(391),
    [anon_sym_else] = ACTIONS(391),
    [anon_sym_ELSE] = ACTIONS(391),
    [anon_sym_Else] = ACTIONS(391),
    [anon_sym_case] = ACTIONS(391),
    [anon_sym_CASE] = ACTIONS(391),
    [anon_sym_Case] = ACTIONS(391),
    [anon_sym_for] = ACTIONS(391),
    [anon_sym_FOR] = ACTIONS(391),
    [anon_sym_For] = ACTIONS(391),
    [anon_sym_foreach] = ACTIONS(391),
    [anon_sym_FOREACH] = ACTIONS(391),
    [anon_sym_Foreach] = ACTIONS(391),
    [anon_sym_while] = ACTIONS(391),
    [anon_sym_WHILE] = ACTIONS(391),
    [anon_sym_While] = ACTIONS(391),
    [anon_sym_repeat] = ACTIONS(391),
    [anon_sym_REPEAT] = ACTIONS(391),
    [anon_sym_Repeat] = ACTIONS(391),
    [anon_sym_exit] = ACTIONS(391),
    [anon_sym_EXIT] = ACTIONS(391),
    [anon_sym_Exit] = ACTIONS(391),
    [anon_sym_continue] = ACTIONS(391),
    [anon_sym_CONTINUE] = ACTIONS(391),
    [anon_sym_Continue] = ACTIONS(391),
    [anon_sym_break] = ACTIONS(391),
    [anon_sym_BREAK] = ACTIONS(391),
    [anon_sym_Break] = ACTIONS(391),
    [anon_sym_with] = ACTIONS(391),
    [anon_sym_WITH] = ACTIONS(391),
    [anon_sym_With] = ACTIONS(391),
    [sym_asserterror_keyword] = ACTIONS(389),
    [anon_sym_in] = ACTIONS(391),
    [anon_sym_IN] = ACTIONS(391),
    [anon_sym_In] = ACTIONS(391),
    [sym_page_keyword] = ACTIONS(399),
    [anon_sym_codeunit] = ACTIONS(405),
    [anon_sym_CODEUNIT] = ACTIONS(405),
    [anon_sym_Codeunit] = ACTIONS(405),
    [anon_sym_CodeUnit] = ACTIONS(405),
    [anon_sym_COdeunit] = ACTIONS(405),
    [anon_sym_codeUnit] = ACTIONS(405),
    [sym_report_keyword] = ACTIONS(399),
    [sym_query_keyword] = ACTIONS(399),
    [anon_sym_xmlport] = ACTIONS(408),
    [anon_sym_XMLPORT] = ACTIONS(408),
    [anon_sym_Xmlport] = ACTIONS(408),
    [anon_sym_XMLport] = ACTIONS(408),
    [anon_sym_XMLPort] = ACTIONS(408),
    [anon_sym_XmlPort] = ACTIONS(408),
    [anon_sym_enum] = ACTIONS(411),
    [anon_sym_ENUM] = ACTIONS(411),
    [anon_sym_Enum] = ACTIONS(411),
    [anon_sym_eNUM] = ACTIONS(411),
    [anon_sym_eNum] = ACTIONS(411),
    [anon_sym_ENum] = ACTIONS(411),
    [sym_local_keyword] = ACTIONS(273),
    [sym_internal_keyword] = ACTIONS(273),
    [sym_protected_keyword] = ACTIONS(273),
    [sym_key_keyword] = ACTIONS(283),
    [sym_dataset_keyword] = ACTIONS(283),
    [sym_quoted_identifier] = ACTIONS(414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(414),
    [sym_integer] = ACTIONS(386),
    [sym_continue_as_identifier] = ACTIONS(389),
    [sym_preproc_open] = ACTIONS(389),
    [sym_preproc_close] = ACTIONS(389),
  },
  [STATE(97)] = {
    [sym_boolean] = STATE(1092),
    [sym_option_member_list] = STATE(1138),
    [sym_option_member] = STATE(1086),
    [sym_keyword_identifier] = STATE(1092),
    [sym_codeunit_keyword] = STATE(1050),
    [sym_xmlport_keyword] = STATE(1050),
    [sym_enum_keyword] = STATE(1050),
    [sym_keyword_as_identifier] = STATE(1092),
    [aux_sym_option_member_list_repeat2] = STATE(99),
    [sym_identifier] = ACTIONS(417),
    [anon_sym_SEMI] = ACTIONS(275),
    [anon_sym_DOT] = ACTIONS(277),
    [anon_sym_EQ] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(419),
    [anon_sym_DASH] = ACTIONS(421),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(275),
    [aux_sym_where_condition_token1] = ACTIONS(425),
    [anon_sym_DOT_DOT] = ACTIONS(275),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(275),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(429),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_basic_type_token53] = ACTIONS(425),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(425),
    [aux_sym_separator_action_token1] = ACTIONS(425),
    [aux_sym_type_declaration_token1] = ACTIONS(425),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(277),
    [anon_sym_POUNDif] = ACTIONS(275),
    [anon_sym_POUNDIF] = ACTIONS(275),
    [anon_sym_POUNDIf] = ACTIONS(275),
    [anon_sym_not] = ACTIONS(277),
    [anon_sym_NOT] = ACTIONS(277),
    [anon_sym_Not] = ACTIONS(277),
    [anon_sym_POUNDelse] = ACTIONS(275),
    [anon_sym_POUNDELSE] = ACTIONS(275),
    [anon_sym_POUNDElse] = ACTIONS(275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(275),
    [aux_sym__expression_token1] = ACTIONS(275),
    [aux_sym__expression_token2] = ACTIONS(277),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(427),
    [anon_sym_SLASH] = ACTIONS(277),
    [anon_sym_div] = ACTIONS(277),
    [anon_sym_DIV] = ACTIONS(277),
    [anon_sym_Div] = ACTIONS(277),
    [anon_sym_mod] = ACTIONS(277),
    [anon_sym_MOD] = ACTIONS(277),
    [anon_sym_Mod] = ACTIONS(277),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(275),
    [anon_sym_LT_EQ] = ACTIONS(275),
    [anon_sym_GT] = ACTIONS(277),
    [anon_sym_LT] = ACTIONS(277),
    [anon_sym_LT_GT] = ACTIONS(275),
    [anon_sym_and] = ACTIONS(277),
    [anon_sym_AND] = ACTIONS(277),
    [anon_sym_And] = ACTIONS(277),
    [anon_sym_or] = ACTIONS(277),
    [anon_sym_OR] = ACTIONS(277),
    [anon_sym_Or] = ACTIONS(277),
    [anon_sym_xor] = ACTIONS(277),
    [anon_sym_XOR] = ACTIONS(277),
    [anon_sym_Xor] = ACTIONS(277),
    [anon_sym_QMARK] = ACTIONS(275),
    [sym_datetime_literal] = ACTIONS(275),
    [sym_date_literal] = ACTIONS(277),
    [sym_time_literal] = ACTIONS(277),
    [sym_biginteger_literal] = ACTIONS(275),
    [anon_sym_if] = ACTIONS(277),
    [anon_sym_IF] = ACTIONS(277),
    [anon_sym_If] = ACTIONS(277),
    [anon_sym_else] = ACTIONS(277),
    [anon_sym_ELSE] = ACTIONS(277),
    [anon_sym_Else] = ACTIONS(277),
    [anon_sym_case] = ACTIONS(277),
    [anon_sym_CASE] = ACTIONS(277),
    [anon_sym_Case] = ACTIONS(277),
    [anon_sym_for] = ACTIONS(277),
    [anon_sym_FOR] = ACTIONS(277),
    [anon_sym_For] = ACTIONS(277),
    [anon_sym_foreach] = ACTIONS(277),
    [anon_sym_FOREACH] = ACTIONS(277),
    [anon_sym_Foreach] = ACTIONS(277),
    [anon_sym_while] = ACTIONS(277),
    [anon_sym_WHILE] = ACTIONS(277),
    [anon_sym_While] = ACTIONS(277),
    [anon_sym_repeat] = ACTIONS(277),
    [anon_sym_REPEAT] = ACTIONS(277),
    [anon_sym_Repeat] = ACTIONS(277),
    [anon_sym_until] = ACTIONS(277),
    [anon_sym_UNTIL] = ACTIONS(277),
    [anon_sym_Until] = ACTIONS(277),
    [anon_sym_exit] = ACTIONS(277),
    [anon_sym_EXIT] = ACTIONS(277),
    [anon_sym_Exit] = ACTIONS(277),
    [anon_sym_continue] = ACTIONS(277),
    [anon_sym_CONTINUE] = ACTIONS(277),
    [anon_sym_Continue] = ACTIONS(277),
    [anon_sym_break] = ACTIONS(277),
    [anon_sym_BREAK] = ACTIONS(277),
    [anon_sym_Break] = ACTIONS(277),
    [anon_sym_with] = ACTIONS(277),
    [anon_sym_WITH] = ACTIONS(277),
    [anon_sym_With] = ACTIONS(277),
    [sym_asserterror_keyword] = ACTIONS(275),
    [anon_sym_in] = ACTIONS(277),
    [anon_sym_IN] = ACTIONS(277),
    [anon_sym_In] = ACTIONS(277),
    [sym_page_keyword] = ACTIONS(427),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(427),
    [sym_query_keyword] = ACTIONS(427),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_local_keyword] = ACTIONS(417),
    [sym_internal_keyword] = ACTIONS(417),
    [sym_protected_keyword] = ACTIONS(417),
    [sym_key_keyword] = ACTIONS(425),
    [sym_dataset_keyword] = ACTIONS(425),
    [sym_quoted_identifier] = ACTIONS(437),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(437),
    [sym_integer] = ACTIONS(417),
    [sym_continue_as_identifier] = ACTIONS(275),
    [sym_preproc_open] = ACTIONS(275),
  },
  [STATE(98)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(439),
    [anon_sym_SEMI] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(445),
    [aux_sym_boolean_token1] = ACTIONS(448),
    [aux_sym_boolean_token2] = ACTIONS(448),
    [sym_decimal] = ACTIONS(451),
    [anon_sym_LPAREN] = ACTIONS(454),
    [aux_sym_tabledata_permission_token2] = ACTIONS(457),
    [anon_sym_LBRACK] = ACTIONS(460),
    [aux_sym_record_type_token1] = ACTIONS(457),
    [aux_sym_basic_type_token21] = ACTIONS(457),
    [aux_sym_basic_type_token22] = ACTIONS(457),
    [aux_sym_basic_type_token48] = ACTIONS(457),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(313),
    [anon_sym_POUNDif] = ACTIONS(315),
    [anon_sym_POUNDIF] = ACTIONS(315),
    [anon_sym_POUNDIf] = ACTIONS(315),
    [anon_sym_not] = ACTIONS(463),
    [anon_sym_NOT] = ACTIONS(463),
    [anon_sym_Not] = ACTIONS(463),
    [anon_sym_POUNDelse] = ACTIONS(321),
    [anon_sym_POUNDELSE] = ACTIONS(321),
    [anon_sym_POUNDElse] = ACTIONS(321),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(457),
    [aux_sym_keyword_identifier_token2] = ACTIONS(466),
    [anon_sym_PLUS] = ACTIONS(445),
    [sym_datetime_literal] = ACTIONS(469),
    [sym_date_literal] = ACTIONS(451),
    [sym_time_literal] = ACTIONS(451),
    [sym_biginteger_literal] = ACTIONS(469),
    [anon_sym_if] = ACTIONS(329),
    [anon_sym_IF] = ACTIONS(329),
    [anon_sym_If] = ACTIONS(329),
    [anon_sym_case] = ACTIONS(332),
    [anon_sym_CASE] = ACTIONS(332),
    [anon_sym_Case] = ACTIONS(332),
    [anon_sym_for] = ACTIONS(335),
    [anon_sym_FOR] = ACTIONS(335),
    [anon_sym_For] = ACTIONS(335),
    [anon_sym_foreach] = ACTIONS(338),
    [anon_sym_FOREACH] = ACTIONS(338),
    [anon_sym_Foreach] = ACTIONS(338),
    [anon_sym_while] = ACTIONS(341),
    [anon_sym_WHILE] = ACTIONS(341),
    [anon_sym_While] = ACTIONS(341),
    [anon_sym_repeat] = ACTIONS(344),
    [anon_sym_REPEAT] = ACTIONS(344),
    [anon_sym_Repeat] = ACTIONS(344),
    [anon_sym_until] = ACTIONS(313),
    [anon_sym_UNTIL] = ACTIONS(313),
    [anon_sym_Until] = ACTIONS(313),
    [anon_sym_exit] = ACTIONS(472),
    [anon_sym_EXIT] = ACTIONS(472),
    [anon_sym_Exit] = ACTIONS(472),
    [anon_sym_continue] = ACTIONS(475),
    [anon_sym_CONTINUE] = ACTIONS(475),
    [anon_sym_Continue] = ACTIONS(475),
    [anon_sym_break] = ACTIONS(478),
    [anon_sym_BREAK] = ACTIONS(478),
    [anon_sym_Break] = ACTIONS(478),
    [anon_sym_with] = ACTIONS(356),
    [anon_sym_WITH] = ACTIONS(356),
    [anon_sym_With] = ACTIONS(356),
    [sym_asserterror_keyword] = ACTIONS(481),
    [sym_page_keyword] = ACTIONS(466),
    [anon_sym_codeunit] = ACTIONS(484),
    [anon_sym_CODEUNIT] = ACTIONS(484),
    [anon_sym_Codeunit] = ACTIONS(484),
    [anon_sym_CodeUnit] = ACTIONS(484),
    [anon_sym_COdeunit] = ACTIONS(484),
    [anon_sym_codeUnit] = ACTIONS(484),
    [sym_report_keyword] = ACTIONS(466),
    [sym_query_keyword] = ACTIONS(466),
    [anon_sym_xmlport] = ACTIONS(487),
    [anon_sym_XMLPORT] = ACTIONS(487),
    [anon_sym_Xmlport] = ACTIONS(487),
    [anon_sym_XMLport] = ACTIONS(487),
    [anon_sym_XMLPort] = ACTIONS(487),
    [anon_sym_XmlPort] = ACTIONS(487),
    [anon_sym_enum] = ACTIONS(490),
    [anon_sym_ENUM] = ACTIONS(490),
    [anon_sym_Enum] = ACTIONS(490),
    [anon_sym_eNUM] = ACTIONS(490),
    [anon_sym_eNum] = ACTIONS(490),
    [anon_sym_ENum] = ACTIONS(490),
    [sym_quoted_identifier] = ACTIONS(493),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(469),
    [sym_integer] = ACTIONS(451),
    [sym_continue_as_identifier] = ACTIONS(469),
    [sym_preproc_open] = ACTIONS(315),
  },
  [STATE(99)] = {
    [sym_boolean] = STATE(1092),
    [sym_option_member] = STATE(1069),
    [sym_keyword_identifier] = STATE(1092),
    [sym_codeunit_keyword] = STATE(1050),
    [sym_xmlport_keyword] = STATE(1050),
    [sym_enum_keyword] = STATE(1050),
    [sym_keyword_as_identifier] = STATE(1092),
    [aux_sym_option_member_list_repeat2] = STATE(917),
    [sym_identifier] = ACTIONS(417),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(496),
    [anon_sym_DASH] = ACTIONS(421),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(376),
    [anon_sym_LPAREN] = ACTIONS(374),
    [aux_sym_where_condition_token1] = ACTIONS(425),
    [anon_sym_DOT_DOT] = ACTIONS(374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(429),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_basic_type_token53] = ACTIONS(425),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(425),
    [aux_sym_separator_action_token1] = ACTIONS(425),
    [aux_sym_type_declaration_token1] = ACTIONS(425),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(376),
    [anon_sym_POUNDif] = ACTIONS(374),
    [anon_sym_POUNDIF] = ACTIONS(374),
    [anon_sym_POUNDIf] = ACTIONS(374),
    [anon_sym_not] = ACTIONS(376),
    [anon_sym_NOT] = ACTIONS(376),
    [anon_sym_Not] = ACTIONS(376),
    [anon_sym_POUNDelse] = ACTIONS(374),
    [anon_sym_POUNDELSE] = ACTIONS(374),
    [anon_sym_POUNDElse] = ACTIONS(374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(374),
    [aux_sym__expression_token1] = ACTIONS(374),
    [aux_sym__expression_token2] = ACTIONS(376),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(427),
    [anon_sym_SLASH] = ACTIONS(376),
    [anon_sym_div] = ACTIONS(376),
    [anon_sym_DIV] = ACTIONS(376),
    [anon_sym_Div] = ACTIONS(376),
    [anon_sym_mod] = ACTIONS(376),
    [anon_sym_MOD] = ACTIONS(376),
    [anon_sym_Mod] = ACTIONS(376),
    [anon_sym_PLUS] = ACTIONS(376),
    [anon_sym_GT_EQ] = ACTIONS(374),
    [anon_sym_LT_EQ] = ACTIONS(374),
    [anon_sym_GT] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(376),
    [anon_sym_LT_GT] = ACTIONS(374),
    [anon_sym_and] = ACTIONS(376),
    [anon_sym_AND] = ACTIONS(376),
    [anon_sym_And] = ACTIONS(376),
    [anon_sym_or] = ACTIONS(376),
    [anon_sym_OR] = ACTIONS(376),
    [anon_sym_Or] = ACTIONS(376),
    [anon_sym_xor] = ACTIONS(376),
    [anon_sym_XOR] = ACTIONS(376),
    [anon_sym_Xor] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(374),
    [sym_datetime_literal] = ACTIONS(374),
    [sym_date_literal] = ACTIONS(376),
    [sym_time_literal] = ACTIONS(376),
    [sym_biginteger_literal] = ACTIONS(374),
    [anon_sym_if] = ACTIONS(376),
    [anon_sym_IF] = ACTIONS(376),
    [anon_sym_If] = ACTIONS(376),
    [anon_sym_else] = ACTIONS(376),
    [anon_sym_ELSE] = ACTIONS(376),
    [anon_sym_Else] = ACTIONS(376),
    [anon_sym_case] = ACTIONS(376),
    [anon_sym_CASE] = ACTIONS(376),
    [anon_sym_Case] = ACTIONS(376),
    [anon_sym_for] = ACTIONS(376),
    [anon_sym_FOR] = ACTIONS(376),
    [anon_sym_For] = ACTIONS(376),
    [anon_sym_foreach] = ACTIONS(376),
    [anon_sym_FOREACH] = ACTIONS(376),
    [anon_sym_Foreach] = ACTIONS(376),
    [anon_sym_while] = ACTIONS(376),
    [anon_sym_WHILE] = ACTIONS(376),
    [anon_sym_While] = ACTIONS(376),
    [anon_sym_repeat] = ACTIONS(376),
    [anon_sym_REPEAT] = ACTIONS(376),
    [anon_sym_Repeat] = ACTIONS(376),
    [anon_sym_until] = ACTIONS(376),
    [anon_sym_UNTIL] = ACTIONS(376),
    [anon_sym_Until] = ACTIONS(376),
    [anon_sym_exit] = ACTIONS(376),
    [anon_sym_EXIT] = ACTIONS(376),
    [anon_sym_Exit] = ACTIONS(376),
    [anon_sym_continue] = ACTIONS(376),
    [anon_sym_CONTINUE] = ACTIONS(376),
    [anon_sym_Continue] = ACTIONS(376),
    [anon_sym_break] = ACTIONS(376),
    [anon_sym_BREAK] = ACTIONS(376),
    [anon_sym_Break] = ACTIONS(376),
    [anon_sym_with] = ACTIONS(376),
    [anon_sym_WITH] = ACTIONS(376),
    [anon_sym_With] = ACTIONS(376),
    [sym_asserterror_keyword] = ACTIONS(374),
    [anon_sym_in] = ACTIONS(376),
    [anon_sym_IN] = ACTIONS(376),
    [anon_sym_In] = ACTIONS(376),
    [sym_page_keyword] = ACTIONS(427),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(427),
    [sym_query_keyword] = ACTIONS(427),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_local_keyword] = ACTIONS(417),
    [sym_internal_keyword] = ACTIONS(417),
    [sym_protected_keyword] = ACTIONS(417),
    [sym_key_keyword] = ACTIONS(425),
    [sym_dataset_keyword] = ACTIONS(425),
    [sym_quoted_identifier] = ACTIONS(437),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(437),
    [sym_integer] = ACTIONS(417),
    [sym_continue_as_identifier] = ACTIONS(374),
    [sym_preproc_open] = ACTIONS(374),
  },
  [STATE(100)] = {
    [sym_boolean] = STATE(1092),
    [sym_option_member] = STATE(1099),
    [sym_keyword_identifier] = STATE(1092),
    [sym_codeunit_keyword] = STATE(1050),
    [sym_xmlport_keyword] = STATE(1050),
    [sym_enum_keyword] = STATE(1050),
    [sym_keyword_as_identifier] = STATE(1092),
    [sym_identifier] = ACTIONS(498),
    [anon_sym_SEMI] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(391),
    [anon_sym_EQ] = ACTIONS(389),
    [anon_sym_COMMA] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(501),
    [aux_sym_boolean_token1] = ACTIONS(504),
    [aux_sym_boolean_token2] = ACTIONS(504),
    [sym_decimal] = ACTIONS(391),
    [anon_sym_LPAREN] = ACTIONS(389),
    [aux_sym_where_condition_token1] = ACTIONS(425),
    [anon_sym_DOT_DOT] = ACTIONS(389),
    [aux_sym_tabledata_permission_token2] = ACTIONS(507),
    [anon_sym_STAR] = ACTIONS(391),
    [anon_sym_LBRACK] = ACTIONS(389),
    [aux_sym_record_type_token1] = ACTIONS(507),
    [aux_sym_basic_type_token21] = ACTIONS(507),
    [aux_sym_basic_type_token22] = ACTIONS(510),
    [aux_sym_basic_type_token48] = ACTIONS(507),
    [aux_sym_basic_type_token53] = ACTIONS(425),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(425),
    [aux_sym_separator_action_token1] = ACTIONS(425),
    [aux_sym_type_declaration_token1] = ACTIONS(425),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(391),
    [anon_sym_POUNDif] = ACTIONS(389),
    [anon_sym_POUNDIF] = ACTIONS(389),
    [anon_sym_POUNDIf] = ACTIONS(389),
    [anon_sym_not] = ACTIONS(391),
    [anon_sym_NOT] = ACTIONS(391),
    [anon_sym_Not] = ACTIONS(391),
    [anon_sym_POUNDelse] = ACTIONS(389),
    [anon_sym_POUNDELSE] = ACTIONS(389),
    [anon_sym_POUNDElse] = ACTIONS(389),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(389),
    [aux_sym__expression_token1] = ACTIONS(389),
    [aux_sym__expression_token2] = ACTIONS(391),
    [aux_sym_keyword_identifier_token1] = ACTIONS(507),
    [aux_sym_keyword_identifier_token2] = ACTIONS(507),
    [anon_sym_SLASH] = ACTIONS(391),
    [anon_sym_div] = ACTIONS(391),
    [anon_sym_DIV] = ACTIONS(391),
    [anon_sym_Div] = ACTIONS(391),
    [anon_sym_mod] = ACTIONS(391),
    [anon_sym_MOD] = ACTIONS(391),
    [anon_sym_Mod] = ACTIONS(391),
    [anon_sym_PLUS] = ACTIONS(391),
    [anon_sym_GT_EQ] = ACTIONS(389),
    [anon_sym_LT_EQ] = ACTIONS(389),
    [anon_sym_GT] = ACTIONS(391),
    [anon_sym_LT] = ACTIONS(391),
    [anon_sym_LT_GT] = ACTIONS(389),
    [anon_sym_and] = ACTIONS(391),
    [anon_sym_AND] = ACTIONS(391),
    [anon_sym_And] = ACTIONS(391),
    [anon_sym_or] = ACTIONS(391),
    [anon_sym_OR] = ACTIONS(391),
    [anon_sym_Or] = ACTIONS(391),
    [anon_sym_xor] = ACTIONS(391),
    [anon_sym_XOR] = ACTIONS(391),
    [anon_sym_Xor] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(389),
    [sym_datetime_literal] = ACTIONS(389),
    [sym_date_literal] = ACTIONS(391),
    [sym_time_literal] = ACTIONS(391),
    [sym_biginteger_literal] = ACTIONS(389),
    [anon_sym_if] = ACTIONS(391),
    [anon_sym_IF] = ACTIONS(391),
    [anon_sym_If] = ACTIONS(391),
    [anon_sym_else] = ACTIONS(391),
    [anon_sym_ELSE] = ACTIONS(391),
    [anon_sym_Else] = ACTIONS(391),
    [anon_sym_case] = ACTIONS(391),
    [anon_sym_CASE] = ACTIONS(391),
    [anon_sym_Case] = ACTIONS(391),
    [anon_sym_for] = ACTIONS(391),
    [anon_sym_FOR] = ACTIONS(391),
    [anon_sym_For] = ACTIONS(391),
    [anon_sym_foreach] = ACTIONS(391),
    [anon_sym_FOREACH] = ACTIONS(391),
    [anon_sym_Foreach] = ACTIONS(391),
    [anon_sym_while] = ACTIONS(391),
    [anon_sym_WHILE] = ACTIONS(391),
    [anon_sym_While] = ACTIONS(391),
    [anon_sym_repeat] = ACTIONS(391),
    [anon_sym_REPEAT] = ACTIONS(391),
    [anon_sym_Repeat] = ACTIONS(391),
    [anon_sym_until] = ACTIONS(391),
    [anon_sym_UNTIL] = ACTIONS(391),
    [anon_sym_Until] = ACTIONS(391),
    [anon_sym_exit] = ACTIONS(391),
    [anon_sym_EXIT] = ACTIONS(391),
    [anon_sym_Exit] = ACTIONS(391),
    [anon_sym_continue] = ACTIONS(391),
    [anon_sym_CONTINUE] = ACTIONS(391),
    [anon_sym_Continue] = ACTIONS(391),
    [anon_sym_break] = ACTIONS(391),
    [anon_sym_BREAK] = ACTIONS(391),
    [anon_sym_Break] = ACTIONS(391),
    [anon_sym_with] = ACTIONS(391),
    [anon_sym_WITH] = ACTIONS(391),
    [anon_sym_With] = ACTIONS(391),
    [sym_asserterror_keyword] = ACTIONS(389),
    [anon_sym_in] = ACTIONS(391),
    [anon_sym_IN] = ACTIONS(391),
    [anon_sym_In] = ACTIONS(391),
    [sym_page_keyword] = ACTIONS(507),
    [anon_sym_codeunit] = ACTIONS(513),
    [anon_sym_CODEUNIT] = ACTIONS(513),
    [anon_sym_Codeunit] = ACTIONS(513),
    [anon_sym_CodeUnit] = ACTIONS(513),
    [anon_sym_COdeunit] = ACTIONS(513),
    [anon_sym_codeUnit] = ACTIONS(513),
    [sym_report_keyword] = ACTIONS(507),
    [sym_query_keyword] = ACTIONS(507),
    [anon_sym_xmlport] = ACTIONS(516),
    [anon_sym_XMLPORT] = ACTIONS(516),
    [anon_sym_Xmlport] = ACTIONS(516),
    [anon_sym_XMLport] = ACTIONS(516),
    [anon_sym_XMLPort] = ACTIONS(516),
    [anon_sym_XmlPort] = ACTIONS(516),
    [anon_sym_enum] = ACTIONS(519),
    [anon_sym_ENUM] = ACTIONS(519),
    [anon_sym_Enum] = ACTIONS(519),
    [anon_sym_eNUM] = ACTIONS(519),
    [anon_sym_eNum] = ACTIONS(519),
    [anon_sym_ENum] = ACTIONS(519),
    [sym_local_keyword] = ACTIONS(417),
    [sym_internal_keyword] = ACTIONS(417),
    [sym_protected_keyword] = ACTIONS(417),
    [sym_key_keyword] = ACTIONS(425),
    [sym_dataset_keyword] = ACTIONS(425),
    [sym_quoted_identifier] = ACTIONS(522),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(522),
    [sym_integer] = ACTIONS(498),
    [sym_continue_as_identifier] = ACTIONS(389),
    [sym_preproc_open] = ACTIONS(389),
  },
  [STATE(101)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(2277),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
  },
  [STATE(102)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(1862),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(104),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(103)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(1938),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(104)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(1944),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(105)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(2384),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(117),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
  },
  [STATE(106)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(9972),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(108),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(223),
    [anon_sym_POUNDENDIF] = ACTIONS(223),
    [anon_sym_POUNDEndif] = ACTIONS(223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(223),
  },
  [STATE(107)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9900),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(10273),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(108)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(10299),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(223),
    [anon_sym_POUNDENDIF] = ACTIONS(223),
    [anon_sym_POUNDEndif] = ACTIONS(223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(223),
  },
  [STATE(109)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(10332),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(111),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(223),
    [anon_sym_POUNDENDIF] = ACTIONS(223),
    [anon_sym_POUNDEndif] = ACTIONS(223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(223),
  },
  [STATE(110)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(9943),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(113),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(223),
    [anon_sym_POUNDENDIF] = ACTIONS(223),
    [anon_sym_POUNDEndif] = ACTIONS(223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(223),
  },
  [STATE(111)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(9978),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(223),
    [anon_sym_POUNDENDIF] = ACTIONS(223),
    [anon_sym_POUNDEndif] = ACTIONS(223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(223),
  },
  [STATE(112)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(10000),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(114),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(223),
    [anon_sym_POUNDENDIF] = ACTIONS(223),
    [anon_sym_POUNDEndif] = ACTIONS(223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(223),
  },
  [STATE(113)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(10001),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(223),
    [anon_sym_POUNDENDIF] = ACTIONS(223),
    [anon_sym_POUNDEndif] = ACTIONS(223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(223),
  },
  [STATE(114)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(10223),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(223),
    [anon_sym_POUNDENDIF] = ACTIONS(223),
    [anon_sym_POUNDEndif] = ACTIONS(223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(223),
  },
  [STATE(115)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(2327),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(131),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
  },
  [STATE(116)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(2282),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(119),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
  },
  [STATE(117)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(2286),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
  },
  [STATE(118)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1758),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1759),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(257),
    [anon_sym_POUNDELSE] = ACTIONS(257),
    [anon_sym_POUNDElse] = ACTIONS(257),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(119)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(2326),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
  },
  [STATE(120)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9771),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(10048),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(121)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9832),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(10192),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(107),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(122)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(1671),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(124),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(221),
    [anon_sym_POUNDENDIF] = ACTIONS(221),
    [anon_sym_POUNDEndif] = ACTIONS(221),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(221),
  },
  [STATE(123)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9867),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(10232),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(120),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(124)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(1677),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(221),
    [anon_sym_POUNDENDIF] = ACTIONS(221),
    [anon_sym_POUNDEndif] = ACTIONS(221),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(221),
  },
  [STATE(125)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(1810),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(126)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(1682),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(129),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(221),
    [anon_sym_POUNDENDIF] = ACTIONS(221),
    [anon_sym_POUNDEndif] = ACTIONS(221),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(221),
  },
  [STATE(127)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(1690),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(221),
    [anon_sym_POUNDENDIF] = ACTIONS(221),
    [anon_sym_POUNDEndif] = ACTIONS(221),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(221),
  },
  [STATE(128)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(1691),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(130),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(221),
    [anon_sym_POUNDENDIF] = ACTIONS(221),
    [anon_sym_POUNDEndif] = ACTIONS(221),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(221),
  },
  [STATE(129)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(1692),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(221),
    [anon_sym_POUNDENDIF] = ACTIONS(221),
    [anon_sym_POUNDEndif] = ACTIONS(221),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(221),
  },
  [STATE(130)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(1701),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(221),
    [anon_sym_POUNDENDIF] = ACTIONS(221),
    [anon_sym_POUNDEndif] = ACTIONS(221),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(221),
  },
  [STATE(131)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(2301),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
  },
  [STATE(132)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(2380),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(101),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(147),
    [anon_sym_POUNDENDIF] = ACTIONS(147),
    [anon_sym_POUNDEndif] = ACTIONS(147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(147),
  },
  [STATE(133)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9616),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(9947),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(134),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(134)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9620),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(9951),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(135)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9621),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(9952),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(136),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(136)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9625),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(9956),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(137)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9642),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(10028),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(138),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(138)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9644),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(10033),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(139)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9645),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(10034),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(140),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(140)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9648),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(10037),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(141)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9653),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(10075),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(142),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(142)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9655),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(10080),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(143)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9656),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(10081),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(144),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(144)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9660),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(10083),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(145)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9664),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(10100),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(146),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(146)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9666),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(10104),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(147)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9667),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(10105),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(148)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_else] = STATE(9670),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym__preproc_if_header] = STATE(10108),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3035),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(121),
    [anon_sym_POUNDELSE] = ACTIONS(121),
    [anon_sym_POUNDElse] = ACTIONS(121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(149)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(1931),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(103),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(150)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(1915),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(151),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(151)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(1919),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(152)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(1927),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(125),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(153)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_endif] = STATE(1680),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1770),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(127),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(221),
    [anon_sym_POUNDENDIF] = ACTIONS(221),
    [anon_sym_POUNDEndif] = ACTIONS(221),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(221),
  },
  [STATE(154)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_until_keyword] = STATE(3229),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(557),
    [anon_sym_UNTIL] = ACTIONS(557),
    [anon_sym_Until] = ACTIONS(557),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(155)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_until_keyword] = STATE(2911),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(163),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(557),
    [anon_sym_UNTIL] = ACTIONS(557),
    [anon_sym_Until] = ACTIONS(557),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(156)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(12035),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(621),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(561),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(157)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_until_keyword] = STATE(3082),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(164),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(557),
    [anon_sym_UNTIL] = ACTIONS(557),
    [anon_sym_Until] = ACTIONS(557),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(158)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_until_keyword] = STATE(2931),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(159),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(557),
    [anon_sym_UNTIL] = ACTIONS(557),
    [anon_sym_Until] = ACTIONS(557),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(159)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_until_keyword] = STATE(2932),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(557),
    [anon_sym_UNTIL] = ACTIONS(557),
    [anon_sym_Until] = ACTIONS(557),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(160)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_until_keyword] = STATE(3004),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(154),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(557),
    [anon_sym_UNTIL] = ACTIONS(557),
    [anon_sym_Until] = ACTIONS(557),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(161)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_until_keyword] = STATE(2887),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(162),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(557),
    [anon_sym_UNTIL] = ACTIONS(557),
    [anon_sym_Until] = ACTIONS(557),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(162)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_until_keyword] = STATE(2898),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(557),
    [anon_sym_UNTIL] = ACTIONS(557),
    [anon_sym_Until] = ACTIONS(557),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(163)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_until_keyword] = STATE(2923),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(557),
    [anon_sym_UNTIL] = ACTIONS(557),
    [anon_sym_Until] = ACTIONS(557),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(164)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_until_keyword] = STATE(3119),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(557),
    [anon_sym_UNTIL] = ACTIONS(557),
    [anon_sym_Until] = ACTIONS(557),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(165)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_until_keyword] = STATE(2839),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(166),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(557),
    [anon_sym_UNTIL] = ACTIONS(557),
    [anon_sym_Until] = ACTIONS(557),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(166)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_until_keyword] = STATE(2843),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(557),
    [anon_sym_UNTIL] = ACTIONS(557),
    [anon_sym_Until] = ACTIONS(557),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(167)] = {
    [aux_sym_option_member_list_repeat2] = STATE(167),
    [sym_identifier] = ACTIONS(565),
    [anon_sym_SEMI] = ACTIONS(567),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_EQ] = ACTIONS(567),
    [anon_sym_COMMA] = ACTIONS(569),
    [anon_sym_DASH] = ACTIONS(565),
    [aux_sym_boolean_token1] = ACTIONS(565),
    [aux_sym_boolean_token2] = ACTIONS(565),
    [sym_decimal] = ACTIONS(565),
    [anon_sym_LPAREN] = ACTIONS(567),
    [aux_sym_where_condition_token1] = ACTIONS(565),
    [anon_sym_DOT_DOT] = ACTIONS(567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(565),
    [anon_sym_STAR] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [aux_sym_record_type_token1] = ACTIONS(565),
    [aux_sym_basic_type_token21] = ACTIONS(565),
    [aux_sym_basic_type_token22] = ACTIONS(565),
    [aux_sym_basic_type_token48] = ACTIONS(565),
    [aux_sym_basic_type_token53] = ACTIONS(565),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(565),
    [aux_sym_separator_action_token1] = ACTIONS(565),
    [aux_sym_type_declaration_token1] = ACTIONS(565),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(565),
    [anon_sym_POUNDif] = ACTIONS(567),
    [anon_sym_POUNDIF] = ACTIONS(567),
    [anon_sym_POUNDIf] = ACTIONS(567),
    [anon_sym_not] = ACTIONS(565),
    [anon_sym_NOT] = ACTIONS(565),
    [anon_sym_Not] = ACTIONS(565),
    [anon_sym_POUNDelif] = ACTIONS(567),
    [anon_sym_POUNDELIF] = ACTIONS(567),
    [anon_sym_POUNDElif] = ACTIONS(567),
    [anon_sym_POUNDelse] = ACTIONS(567),
    [anon_sym_POUNDELSE] = ACTIONS(567),
    [anon_sym_POUNDElse] = ACTIONS(567),
    [anon_sym_POUNDendif] = ACTIONS(567),
    [anon_sym_POUNDENDIF] = ACTIONS(567),
    [anon_sym_POUNDEndif] = ACTIONS(567),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(567),
    [aux_sym__expression_token1] = ACTIONS(567),
    [aux_sym__expression_token2] = ACTIONS(565),
    [aux_sym_keyword_identifier_token1] = ACTIONS(565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(565),
    [anon_sym_SLASH] = ACTIONS(565),
    [anon_sym_div] = ACTIONS(565),
    [anon_sym_DIV] = ACTIONS(565),
    [anon_sym_Div] = ACTIONS(565),
    [anon_sym_mod] = ACTIONS(565),
    [anon_sym_MOD] = ACTIONS(565),
    [anon_sym_Mod] = ACTIONS(565),
    [anon_sym_PLUS] = ACTIONS(565),
    [anon_sym_GT_EQ] = ACTIONS(567),
    [anon_sym_LT_EQ] = ACTIONS(567),
    [anon_sym_GT] = ACTIONS(565),
    [anon_sym_LT] = ACTIONS(565),
    [anon_sym_LT_GT] = ACTIONS(567),
    [anon_sym_and] = ACTIONS(565),
    [anon_sym_AND] = ACTIONS(565),
    [anon_sym_And] = ACTIONS(565),
    [anon_sym_or] = ACTIONS(565),
    [anon_sym_OR] = ACTIONS(565),
    [anon_sym_Or] = ACTIONS(565),
    [anon_sym_xor] = ACTIONS(565),
    [anon_sym_XOR] = ACTIONS(565),
    [anon_sym_Xor] = ACTIONS(565),
    [anon_sym_QMARK] = ACTIONS(567),
    [sym_datetime_literal] = ACTIONS(567),
    [sym_date_literal] = ACTIONS(565),
    [sym_time_literal] = ACTIONS(565),
    [sym_biginteger_literal] = ACTIONS(567),
    [anon_sym_if] = ACTIONS(565),
    [anon_sym_IF] = ACTIONS(565),
    [anon_sym_If] = ACTIONS(565),
    [anon_sym_else] = ACTIONS(565),
    [anon_sym_ELSE] = ACTIONS(565),
    [anon_sym_Else] = ACTIONS(565),
    [anon_sym_case] = ACTIONS(565),
    [anon_sym_CASE] = ACTIONS(565),
    [anon_sym_Case] = ACTIONS(565),
    [anon_sym_for] = ACTIONS(565),
    [anon_sym_FOR] = ACTIONS(565),
    [anon_sym_For] = ACTIONS(565),
    [anon_sym_foreach] = ACTIONS(565),
    [anon_sym_FOREACH] = ACTIONS(565),
    [anon_sym_Foreach] = ACTIONS(565),
    [anon_sym_while] = ACTIONS(565),
    [anon_sym_WHILE] = ACTIONS(565),
    [anon_sym_While] = ACTIONS(565),
    [anon_sym_repeat] = ACTIONS(565),
    [anon_sym_REPEAT] = ACTIONS(565),
    [anon_sym_Repeat] = ACTIONS(565),
    [anon_sym_exit] = ACTIONS(565),
    [anon_sym_EXIT] = ACTIONS(565),
    [anon_sym_Exit] = ACTIONS(565),
    [anon_sym_continue] = ACTIONS(565),
    [anon_sym_CONTINUE] = ACTIONS(565),
    [anon_sym_Continue] = ACTIONS(565),
    [anon_sym_break] = ACTIONS(565),
    [anon_sym_BREAK] = ACTIONS(565),
    [anon_sym_Break] = ACTIONS(565),
    [anon_sym_with] = ACTIONS(565),
    [anon_sym_WITH] = ACTIONS(565),
    [anon_sym_With] = ACTIONS(565),
    [sym_asserterror_keyword] = ACTIONS(567),
    [anon_sym_in] = ACTIONS(565),
    [anon_sym_IN] = ACTIONS(565),
    [anon_sym_In] = ACTIONS(565),
    [sym_page_keyword] = ACTIONS(565),
    [anon_sym_codeunit] = ACTIONS(565),
    [anon_sym_CODEUNIT] = ACTIONS(565),
    [anon_sym_Codeunit] = ACTIONS(565),
    [anon_sym_CodeUnit] = ACTIONS(565),
    [anon_sym_COdeunit] = ACTIONS(565),
    [anon_sym_codeUnit] = ACTIONS(565),
    [sym_report_keyword] = ACTIONS(565),
    [sym_query_keyword] = ACTIONS(565),
    [anon_sym_xmlport] = ACTIONS(565),
    [anon_sym_XMLPORT] = ACTIONS(565),
    [anon_sym_Xmlport] = ACTIONS(565),
    [anon_sym_XMLport] = ACTIONS(565),
    [anon_sym_XMLPort] = ACTIONS(565),
    [anon_sym_XmlPort] = ACTIONS(565),
    [anon_sym_enum] = ACTIONS(565),
    [anon_sym_ENUM] = ACTIONS(565),
    [anon_sym_Enum] = ACTIONS(565),
    [anon_sym_eNUM] = ACTIONS(565),
    [anon_sym_eNum] = ACTIONS(565),
    [anon_sym_ENum] = ACTIONS(565),
    [sym_local_keyword] = ACTIONS(565),
    [sym_internal_keyword] = ACTIONS(565),
    [sym_protected_keyword] = ACTIONS(565),
    [sym_key_keyword] = ACTIONS(565),
    [sym_dataset_keyword] = ACTIONS(565),
    [sym_quoted_identifier] = ACTIONS(567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(567),
    [sym_integer] = ACTIONS(565),
    [sym_continue_as_identifier] = ACTIONS(567),
    [sym_preproc_open] = ACTIONS(567),
    [sym_preproc_close] = ACTIONS(567),
  },
  [STATE(168)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3443),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3378),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym__if_statement_no_else] = STATE(3429),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3157),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(169)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4659),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4660),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym__if_statement_no_else] = STATE(4661),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3029),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(170)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4663),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4664),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym__if_statement_no_else] = STATE(4665),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3029),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(171)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(44),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(7344),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(172),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(648),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(674),
  },
  [STATE(172)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(44),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(7346),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(676),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(678),
  },
  [STATE(173)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4648),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4649),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym__if_statement_no_else] = STATE(4650),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3029),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(174)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4666),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4667),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym__if_statement_no_else] = STATE(4668),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3029),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(175)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(3242),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(680),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(682),
  },
  [STATE(176)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(45),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(1598),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(178),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(684),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(686),
  },
  [STATE(177)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(40),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(3860),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(688),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(690),
  },
  [STATE(178)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(45),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(1602),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(692),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(694),
  },
  [STATE(179)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(40),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(3861),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(696),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(698),
  },
  [STATE(180)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4654),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4662),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym__if_statement_no_else] = STATE(4672),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3029),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(181)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(46),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(1839),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(182),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(700),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(702),
  },
  [STATE(182)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(46),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(1843),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(704),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(706),
  },
  [STATE(183)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(47),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(6895),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(184),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(708),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(710),
  },
  [STATE(184)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(47),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(6934),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(712),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(714),
  },
  [STATE(185)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(48),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(7518),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(186),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(716),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(718),
  },
  [STATE(186)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(48),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(7520),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(720),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(722),
  },
  [STATE(187)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(49),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(9390),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(188),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(724),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(726),
  },
  [STATE(188)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(49),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(9395),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(728),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(730),
  },
  [STATE(189)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(50),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(7057),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(190),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(732),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(734),
  },
  [STATE(190)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(50),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(7059),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(736),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(738),
  },
  [STATE(191)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(51),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(8889),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(192),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(740),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(742),
  },
  [STATE(192)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(51),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(8891),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(744),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(746),
  },
  [STATE(193)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3413),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3414),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym__if_statement_no_else] = STATE(3416),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3157),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(194)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(52),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(6511),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(195),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(748),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(750),
  },
  [STATE(195)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(52),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(6516),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(752),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(754),
  },
  [STATE(196)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(53),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(7570),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(197),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(756),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(758),
  },
  [STATE(197)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(53),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(7630),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(760),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(762),
  },
  [STATE(198)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3434),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3435),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym__if_statement_no_else] = STATE(3436),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3157),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(199)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3444),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3411),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym__if_statement_no_else] = STATE(3420),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3157),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(200)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3440),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3382),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym__if_statement_no_else] = STATE(3397),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3157),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(201)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(54),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(4978),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(202),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(764),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(766),
  },
  [STATE(202)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(54),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(4988),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(768),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(770),
  },
  [STATE(203)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(55),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(5827),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(236),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(772),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(774),
  },
  [STATE(204)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1533),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1535),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(776),
  },
  [STATE(205)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(21),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(5475),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(206),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(778),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(780),
  },
  [STATE(206)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(21),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(5480),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(782),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(784),
  },
  [STATE(207)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(26),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(4738),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(208),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(786),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(788),
  },
  [STATE(208)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(26),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(4742),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(790),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(792),
  },
  [STATE(209)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(27),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(4196),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(234),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(794),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(796),
  },
  [STATE(210)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4640),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4686),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym__if_statement_no_else] = STATE(4647),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3029),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(211)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(3140),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(175),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(798),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(800),
  },
  [STATE(212)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4677),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4678),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym__if_statement_no_else] = STATE(4679),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3029),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(213)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4680),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4681),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym__if_statement_no_else] = STATE(4682),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3029),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(214)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4683),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4684),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym__if_statement_no_else] = STATE(4638),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3029),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(215)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4644),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4645),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym__if_statement_no_else] = STATE(4646),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3029),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(216)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4655),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4656),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym__if_statement_no_else] = STATE(4657),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3029),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(217)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1533),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1535),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(802),
  },
  [STATE(218)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1533),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1535),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(804),
  },
  [STATE(219)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1533),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1535),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
    [sym_preproc_split_begin] = ACTIONS(806),
  },
  [STATE(220)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3385),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3386),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym__if_statement_no_else] = STATE(3399),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3157),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(221)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3421),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3380),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym__if_statement_no_else] = STATE(3389),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3157),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(222)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3426),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3394),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym__if_statement_no_else] = STATE(3398),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3157),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(223)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3423),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3441),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym__if_statement_no_else] = STATE(3442),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3157),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(224)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3391),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3392),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym__if_statement_no_else] = STATE(3393),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3157),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(225)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3431),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3432),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym__if_statement_no_else] = STATE(3438),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3157),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(226)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3408),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3415),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym__if_statement_no_else] = STATE(3433),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3157),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(227)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(43),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(2394),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(232),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(808),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(810),
  },
  [STATE(228)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3400),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3401),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym__if_statement_no_else] = STATE(3439),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3157),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(229)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(41),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(3341),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(230),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(812),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(814),
  },
  [STATE(230)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(41),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(3307),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(816),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(818),
  },
  [STATE(231)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4651),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4652),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym__if_statement_no_else] = STATE(4670),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3029),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(232)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(43),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(2402),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(820),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(822),
  },
  [STATE(233)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4674),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4675),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym__if_statement_no_else] = STATE(4639),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3029),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(234)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(27),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(4505),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(824),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(826),
  },
  [STATE(235)] = {
    [sym_boolean] = STATE(1212),
    [sym_option_member_list] = STATE(1234),
    [sym_option_member] = STATE(1187),
    [sym_keyword_identifier] = STATE(1212),
    [sym_codeunit_keyword] = STATE(1157),
    [sym_xmlport_keyword] = STATE(1157),
    [sym_enum_keyword] = STATE(1157),
    [sym_keyword_as_identifier] = STATE(1212),
    [aux_sym_option_member_list_repeat2] = STATE(341),
    [sym_identifier] = ACTIONS(828),
    [anon_sym_SEMI] = ACTIONS(275),
    [anon_sym_DOT] = ACTIONS(277),
    [anon_sym_EQ] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(830),
    [anon_sym_DASH] = ACTIONS(832),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(275),
    [aux_sym_where_condition_token1] = ACTIONS(834),
    [anon_sym_DOT_DOT] = ACTIONS(275),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(275),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(836),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_basic_type_token53] = ACTIONS(834),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(834),
    [aux_sym_separator_action_token1] = ACTIONS(834),
    [aux_sym_type_declaration_token1] = ACTIONS(834),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(277),
    [anon_sym_POUNDif] = ACTIONS(275),
    [anon_sym_POUNDIF] = ACTIONS(275),
    [anon_sym_POUNDIf] = ACTIONS(275),
    [anon_sym_not] = ACTIONS(277),
    [anon_sym_NOT] = ACTIONS(277),
    [anon_sym_Not] = ACTIONS(277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(275),
    [aux_sym__expression_token1] = ACTIONS(275),
    [aux_sym__expression_token2] = ACTIONS(277),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(644),
    [anon_sym_SLASH] = ACTIONS(277),
    [anon_sym_div] = ACTIONS(277),
    [anon_sym_DIV] = ACTIONS(277),
    [anon_sym_Div] = ACTIONS(277),
    [anon_sym_mod] = ACTIONS(277),
    [anon_sym_MOD] = ACTIONS(277),
    [anon_sym_Mod] = ACTIONS(277),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(275),
    [anon_sym_LT_EQ] = ACTIONS(275),
    [anon_sym_GT] = ACTIONS(277),
    [anon_sym_LT] = ACTIONS(277),
    [anon_sym_LT_GT] = ACTIONS(275),
    [anon_sym_and] = ACTIONS(277),
    [anon_sym_AND] = ACTIONS(277),
    [anon_sym_And] = ACTIONS(277),
    [anon_sym_or] = ACTIONS(277),
    [anon_sym_OR] = ACTIONS(277),
    [anon_sym_Or] = ACTIONS(277),
    [anon_sym_xor] = ACTIONS(277),
    [anon_sym_XOR] = ACTIONS(277),
    [anon_sym_Xor] = ACTIONS(277),
    [anon_sym_QMARK] = ACTIONS(275),
    [sym_datetime_literal] = ACTIONS(275),
    [sym_date_literal] = ACTIONS(277),
    [sym_time_literal] = ACTIONS(277),
    [sym_biginteger_literal] = ACTIONS(275),
    [anon_sym_if] = ACTIONS(277),
    [anon_sym_IF] = ACTIONS(277),
    [anon_sym_If] = ACTIONS(277),
    [anon_sym_else] = ACTIONS(277),
    [anon_sym_ELSE] = ACTIONS(277),
    [anon_sym_Else] = ACTIONS(277),
    [anon_sym_case] = ACTIONS(277),
    [anon_sym_CASE] = ACTIONS(277),
    [anon_sym_Case] = ACTIONS(277),
    [anon_sym_for] = ACTIONS(277),
    [anon_sym_FOR] = ACTIONS(277),
    [anon_sym_For] = ACTIONS(277),
    [anon_sym_foreach] = ACTIONS(277),
    [anon_sym_FOREACH] = ACTIONS(277),
    [anon_sym_Foreach] = ACTIONS(277),
    [anon_sym_while] = ACTIONS(277),
    [anon_sym_WHILE] = ACTIONS(277),
    [anon_sym_While] = ACTIONS(277),
    [anon_sym_repeat] = ACTIONS(277),
    [anon_sym_REPEAT] = ACTIONS(277),
    [anon_sym_Repeat] = ACTIONS(277),
    [anon_sym_exit] = ACTIONS(277),
    [anon_sym_EXIT] = ACTIONS(277),
    [anon_sym_Exit] = ACTIONS(277),
    [anon_sym_continue] = ACTIONS(277),
    [anon_sym_CONTINUE] = ACTIONS(277),
    [anon_sym_Continue] = ACTIONS(277),
    [anon_sym_break] = ACTIONS(277),
    [anon_sym_BREAK] = ACTIONS(277),
    [anon_sym_Break] = ACTIONS(277),
    [anon_sym_with] = ACTIONS(277),
    [anon_sym_WITH] = ACTIONS(277),
    [anon_sym_With] = ACTIONS(277),
    [sym_asserterror_keyword] = ACTIONS(275),
    [anon_sym_in] = ACTIONS(277),
    [anon_sym_IN] = ACTIONS(277),
    [anon_sym_In] = ACTIONS(277),
    [sym_page_keyword] = ACTIONS(644),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(644),
    [sym_query_keyword] = ACTIONS(644),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_local_keyword] = ACTIONS(828),
    [sym_internal_keyword] = ACTIONS(828),
    [sym_protected_keyword] = ACTIONS(828),
    [sym_key_keyword] = ACTIONS(834),
    [sym_dataset_keyword] = ACTIONS(834),
    [sym_quoted_identifier] = ACTIONS(838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(838),
    [sym_integer] = ACTIONS(828),
    [sym_continue_as_identifier] = ACTIONS(275),
    [sym_preproc_open] = ACTIONS(275),
    [sym_end_keyword] = ACTIONS(275),
  },
  [STATE(236)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(55),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_split_code_block_end] = STATE(5836),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(840),
    [anon_sym_POUNDif] = ACTIONS(650),
    [anon_sym_POUNDIF] = ACTIONS(650),
    [anon_sym_POUNDIf] = ACTIONS(650),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(650),
    [sym_end_keyword] = ACTIONS(842),
  },
  [STATE(237)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2320),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2405),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2323),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(238)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1538),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1539),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(239)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1678),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1679),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(240)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1758),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1759),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(241)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1685),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1686),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(242)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1688),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1689),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(243)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1540),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1541),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(244)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1542),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1543),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(245)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1695),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1696),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1697),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(246)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1698),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1699),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1700),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(247)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1945),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1946),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1788),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(248)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1774),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1775),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1776),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(249)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(848),
    [anon_sym_SEMI] = ACTIONS(851),
    [anon_sym_DASH] = ACTIONS(854),
    [aux_sym_boolean_token1] = ACTIONS(857),
    [aux_sym_boolean_token2] = ACTIONS(857),
    [sym_decimal] = ACTIONS(860),
    [anon_sym_LPAREN] = ACTIONS(863),
    [aux_sym_tabledata_permission_token2] = ACTIONS(866),
    [anon_sym_LBRACK] = ACTIONS(869),
    [aux_sym_record_type_token1] = ACTIONS(866),
    [aux_sym_basic_type_token21] = ACTIONS(866),
    [aux_sym_basic_type_token22] = ACTIONS(866),
    [aux_sym_basic_type_token48] = ACTIONS(866),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(313),
    [anon_sym_POUNDif] = ACTIONS(315),
    [anon_sym_POUNDIF] = ACTIONS(315),
    [anon_sym_POUNDIf] = ACTIONS(315),
    [anon_sym_not] = ACTIONS(872),
    [anon_sym_NOT] = ACTIONS(872),
    [anon_sym_Not] = ACTIONS(872),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(866),
    [aux_sym_keyword_identifier_token2] = ACTIONS(875),
    [anon_sym_PLUS] = ACTIONS(854),
    [sym_datetime_literal] = ACTIONS(878),
    [sym_date_literal] = ACTIONS(860),
    [sym_time_literal] = ACTIONS(860),
    [sym_biginteger_literal] = ACTIONS(878),
    [anon_sym_if] = ACTIONS(329),
    [anon_sym_IF] = ACTIONS(329),
    [anon_sym_If] = ACTIONS(329),
    [anon_sym_case] = ACTIONS(332),
    [anon_sym_CASE] = ACTIONS(332),
    [anon_sym_Case] = ACTIONS(332),
    [anon_sym_for] = ACTIONS(335),
    [anon_sym_FOR] = ACTIONS(335),
    [anon_sym_For] = ACTIONS(335),
    [anon_sym_foreach] = ACTIONS(338),
    [anon_sym_FOREACH] = ACTIONS(338),
    [anon_sym_Foreach] = ACTIONS(338),
    [anon_sym_while] = ACTIONS(341),
    [anon_sym_WHILE] = ACTIONS(341),
    [anon_sym_While] = ACTIONS(341),
    [anon_sym_repeat] = ACTIONS(344),
    [anon_sym_REPEAT] = ACTIONS(344),
    [anon_sym_Repeat] = ACTIONS(344),
    [anon_sym_exit] = ACTIONS(881),
    [anon_sym_EXIT] = ACTIONS(881),
    [anon_sym_Exit] = ACTIONS(881),
    [anon_sym_continue] = ACTIONS(884),
    [anon_sym_CONTINUE] = ACTIONS(884),
    [anon_sym_Continue] = ACTIONS(884),
    [anon_sym_break] = ACTIONS(887),
    [anon_sym_BREAK] = ACTIONS(887),
    [anon_sym_Break] = ACTIONS(887),
    [anon_sym_with] = ACTIONS(356),
    [anon_sym_WITH] = ACTIONS(356),
    [anon_sym_With] = ACTIONS(356),
    [sym_asserterror_keyword] = ACTIONS(890),
    [sym_page_keyword] = ACTIONS(875),
    [anon_sym_codeunit] = ACTIONS(893),
    [anon_sym_CODEUNIT] = ACTIONS(893),
    [anon_sym_Codeunit] = ACTIONS(893),
    [anon_sym_CodeUnit] = ACTIONS(893),
    [anon_sym_COdeunit] = ACTIONS(893),
    [anon_sym_codeUnit] = ACTIONS(893),
    [sym_report_keyword] = ACTIONS(875),
    [sym_query_keyword] = ACTIONS(875),
    [anon_sym_xmlport] = ACTIONS(896),
    [anon_sym_XMLPORT] = ACTIONS(896),
    [anon_sym_Xmlport] = ACTIONS(896),
    [anon_sym_XMLport] = ACTIONS(896),
    [anon_sym_XMLPort] = ACTIONS(896),
    [anon_sym_XmlPort] = ACTIONS(896),
    [anon_sym_enum] = ACTIONS(899),
    [anon_sym_ENUM] = ACTIONS(899),
    [anon_sym_Enum] = ACTIONS(899),
    [anon_sym_eNUM] = ACTIONS(899),
    [anon_sym_eNum] = ACTIONS(899),
    [anon_sym_ENum] = ACTIONS(899),
    [sym_quoted_identifier] = ACTIONS(902),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(878),
    [sym_integer] = ACTIONS(860),
    [sym_continue_as_identifier] = ACTIONS(878),
    [sym_preproc_open] = ACTIONS(315),
    [sym_end_keyword] = ACTIONS(321),
  },
  [STATE(250)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1709),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1710),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(251)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1544),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1534),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(252)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1711),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1712),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1713),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(253)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1714),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1715),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1716),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(254)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1719),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1720),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1721),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(255)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1722),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1723),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1724),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(256)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1725),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1726),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(257)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1727),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1728),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(258)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1729),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1546),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(259)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1551),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1662),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(260)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1548),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1645),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1646),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(261)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1647),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1648),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1649),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(262)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1545),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1663),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(263)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1547),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1730),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(264)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1584),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1585),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(265)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1586),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1587),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(266)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1588),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1589),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(267)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1590),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1591),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(268)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1625),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1626),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(269)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1627),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1628),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(270)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1629),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1630),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(271)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1631),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1632),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(272)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1754),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1755),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(273)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1922),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1923),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(274)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1533),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1535),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(275)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1936),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1940),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(276)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1942),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1943),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(277)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1751),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1743),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(278)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1771),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1745),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(279)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1876),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1926),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1928),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(280)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1932),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1935),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1937),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(281)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1702),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1703),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1704),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(282)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(979),
    [sym_code_block] = STATE(1705),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1706),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(979),
    [sym_if_statement] = STATE(1707),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(979),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(979),
    [sym_multiplicative_expression] = STATE(979),
    [sym_additive_expression] = STATE(979),
    [sym_comparison_expression] = STATE(979),
    [sym_logical_expression] = STATE(979),
    [sym_ternary_expression] = STATE(979),
    [sym_unary_expression] = STATE(979),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(979),
    [sym_list_literal] = STATE(979),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(979),
    [sym__literal_value] = STATE(979),
    [sym_if_keyword] = STATE(3057),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3243),
    [sym_foreach_keyword] = STATE(11218),
    [sym_while_keyword] = STATE(3010),
    [sym_repeat_keyword] = STATE(155),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3012),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(283)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1778),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1779),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(284)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1761),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1746),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(285)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1782),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1783),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1784),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(286)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1785),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1786),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1787),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(287)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1790),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1792),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1793),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(288)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1794),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1795),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1796),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(289)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1797),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1798),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(290)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1799),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1800),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(291)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1801),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1802),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(292)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1803),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1804),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(293)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1805),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1806),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1807),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(294)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1808),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1809),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1773),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(295)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1812),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1813),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(296)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1814),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1815),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(297)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1871),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1872),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(298)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1874),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1875),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(299)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1877),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1878),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(300)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1879),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1880),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(301)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1890),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1891),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(302)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1893),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1894),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(303)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1895),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1896),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(304)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_code_block] = STATE(1897),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1898),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(305)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(9334),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9335),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(306)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10328),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10330),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(307)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3354),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3345),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(308)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10058),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10074),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(309)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10221),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10233),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(310)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(9387),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9388),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(311)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(9453),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9454),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(312)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10093),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10112),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10191),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(313)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10193),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10196),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10199),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(314)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1702),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1703),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1704),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(315)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1705),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1706),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1707),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(316)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10256),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10257),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(317)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(9489),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9491),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(318)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(9986),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9988),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(9992),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(319)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(9994),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9995),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(9998),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(320)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10057),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10059),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10060),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(321)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10066),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10068),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10071),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(322)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10088),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10089),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(323)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10095),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10096),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(324)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10097),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10099),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(325)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10113),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10180),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(326)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10334),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10336),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10338),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(327)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10340),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10342),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10344),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(328)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10347),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10348),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(329)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10349),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10350),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(330)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10262),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10351),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(331)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10352),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9945),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(332)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(9949),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9950),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(333)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(9953),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9954),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(334)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(9981),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9982),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(335)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(9983),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10019),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(336)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10020),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10027),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(337)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10029),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10030),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(338)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(9336),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9337),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(339)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10224),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10225),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10226),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(340)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10243),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10244),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10254),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(341)] = {
    [sym_boolean] = STATE(1212),
    [sym_option_member] = STATE(1188),
    [sym_keyword_identifier] = STATE(1212),
    [sym_codeunit_keyword] = STATE(1157),
    [sym_xmlport_keyword] = STATE(1157),
    [sym_enum_keyword] = STATE(1157),
    [sym_keyword_as_identifier] = STATE(1212),
    [aux_sym_option_member_list_repeat2] = STATE(950),
    [sym_identifier] = ACTIONS(828),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(941),
    [anon_sym_DASH] = ACTIONS(832),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(376),
    [anon_sym_LPAREN] = ACTIONS(374),
    [aux_sym_where_condition_token1] = ACTIONS(834),
    [anon_sym_DOT_DOT] = ACTIONS(374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(836),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_basic_type_token53] = ACTIONS(834),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(834),
    [aux_sym_separator_action_token1] = ACTIONS(834),
    [aux_sym_type_declaration_token1] = ACTIONS(834),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(376),
    [anon_sym_POUNDif] = ACTIONS(374),
    [anon_sym_POUNDIF] = ACTIONS(374),
    [anon_sym_POUNDIf] = ACTIONS(374),
    [anon_sym_not] = ACTIONS(376),
    [anon_sym_NOT] = ACTIONS(376),
    [anon_sym_Not] = ACTIONS(376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(374),
    [aux_sym__expression_token1] = ACTIONS(374),
    [aux_sym__expression_token2] = ACTIONS(376),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(644),
    [anon_sym_SLASH] = ACTIONS(376),
    [anon_sym_div] = ACTIONS(376),
    [anon_sym_DIV] = ACTIONS(376),
    [anon_sym_Div] = ACTIONS(376),
    [anon_sym_mod] = ACTIONS(376),
    [anon_sym_MOD] = ACTIONS(376),
    [anon_sym_Mod] = ACTIONS(376),
    [anon_sym_PLUS] = ACTIONS(376),
    [anon_sym_GT_EQ] = ACTIONS(374),
    [anon_sym_LT_EQ] = ACTIONS(374),
    [anon_sym_GT] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(376),
    [anon_sym_LT_GT] = ACTIONS(374),
    [anon_sym_and] = ACTIONS(376),
    [anon_sym_AND] = ACTIONS(376),
    [anon_sym_And] = ACTIONS(376),
    [anon_sym_or] = ACTIONS(376),
    [anon_sym_OR] = ACTIONS(376),
    [anon_sym_Or] = ACTIONS(376),
    [anon_sym_xor] = ACTIONS(376),
    [anon_sym_XOR] = ACTIONS(376),
    [anon_sym_Xor] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(374),
    [sym_datetime_literal] = ACTIONS(374),
    [sym_date_literal] = ACTIONS(376),
    [sym_time_literal] = ACTIONS(376),
    [sym_biginteger_literal] = ACTIONS(374),
    [anon_sym_if] = ACTIONS(376),
    [anon_sym_IF] = ACTIONS(376),
    [anon_sym_If] = ACTIONS(376),
    [anon_sym_else] = ACTIONS(376),
    [anon_sym_ELSE] = ACTIONS(376),
    [anon_sym_Else] = ACTIONS(376),
    [anon_sym_case] = ACTIONS(376),
    [anon_sym_CASE] = ACTIONS(376),
    [anon_sym_Case] = ACTIONS(376),
    [anon_sym_for] = ACTIONS(376),
    [anon_sym_FOR] = ACTIONS(376),
    [anon_sym_For] = ACTIONS(376),
    [anon_sym_foreach] = ACTIONS(376),
    [anon_sym_FOREACH] = ACTIONS(376),
    [anon_sym_Foreach] = ACTIONS(376),
    [anon_sym_while] = ACTIONS(376),
    [anon_sym_WHILE] = ACTIONS(376),
    [anon_sym_While] = ACTIONS(376),
    [anon_sym_repeat] = ACTIONS(376),
    [anon_sym_REPEAT] = ACTIONS(376),
    [anon_sym_Repeat] = ACTIONS(376),
    [anon_sym_exit] = ACTIONS(376),
    [anon_sym_EXIT] = ACTIONS(376),
    [anon_sym_Exit] = ACTIONS(376),
    [anon_sym_continue] = ACTIONS(376),
    [anon_sym_CONTINUE] = ACTIONS(376),
    [anon_sym_Continue] = ACTIONS(376),
    [anon_sym_break] = ACTIONS(376),
    [anon_sym_BREAK] = ACTIONS(376),
    [anon_sym_Break] = ACTIONS(376),
    [anon_sym_with] = ACTIONS(376),
    [anon_sym_WITH] = ACTIONS(376),
    [anon_sym_With] = ACTIONS(376),
    [sym_asserterror_keyword] = ACTIONS(374),
    [anon_sym_in] = ACTIONS(376),
    [anon_sym_IN] = ACTIONS(376),
    [anon_sym_In] = ACTIONS(376),
    [sym_page_keyword] = ACTIONS(644),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(644),
    [sym_query_keyword] = ACTIONS(644),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_local_keyword] = ACTIONS(828),
    [sym_internal_keyword] = ACTIONS(828),
    [sym_protected_keyword] = ACTIONS(828),
    [sym_key_keyword] = ACTIONS(834),
    [sym_dataset_keyword] = ACTIONS(834),
    [sym_quoted_identifier] = ACTIONS(838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(838),
    [sym_integer] = ACTIONS(828),
    [sym_continue_as_identifier] = ACTIONS(374),
    [sym_preproc_open] = ACTIONS(374),
    [sym_end_keyword] = ACTIONS(374),
  },
  [STATE(342)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2230),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2228),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(343)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2378),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2379),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(344)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2217),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2220),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(345)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2392),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2395),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(346)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2246),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2247),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(347)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(349),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(943),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(945),
  },
  [STATE(348)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2221),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2227),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(349)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(947),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(949),
  },
  [STATE(350)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(353),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(951),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(953),
  },
  [STATE(351)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(354),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(955),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(957),
  },
  [STATE(352)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(356),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(959),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(961),
  },
  [STATE(353)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(963),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(965),
  },
  [STATE(354)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(967),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(969),
  },
  [STATE(355)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(362),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(971),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(973),
  },
  [STATE(356)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(975),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(977),
  },
  [STATE(357)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(363),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(979),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(981),
  },
  [STATE(358)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(364),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(983),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(985),
  },
  [STATE(359)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(366),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(987),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(989),
  },
  [STATE(360)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(367),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(991),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(993),
  },
  [STATE(361)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(369),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(995),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(997),
  },
  [STATE(362)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(999),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1001),
  },
  [STATE(363)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1003),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1005),
  },
  [STATE(364)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1007),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1009),
  },
  [STATE(365)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(373),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1011),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1013),
  },
  [STATE(366)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1015),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1017),
  },
  [STATE(367)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1019),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1021),
  },
  [STATE(368)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(374),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1023),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1025),
  },
  [STATE(369)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1027),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1029),
  },
  [STATE(370)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(375),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1031),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1033),
  },
  [STATE(371)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(376),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1035),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1037),
  },
  [STATE(372)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3351),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3349),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(373)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1039),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1041),
  },
  [STATE(374)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1043),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1045),
  },
  [STATE(375)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1047),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1049),
  },
  [STATE(376)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1051),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1053),
  },
  [STATE(377)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(379),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1055),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1057),
  },
  [STATE(378)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(448),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1059),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1061),
  },
  [STATE(379)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1063),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1065),
  },
  [STATE(380)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3355),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3356),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(381)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1678),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1679),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(382)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4626),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4627),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(383)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1685),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1686),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(384)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1688),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1689),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(385)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3346),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3357),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(386)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3358),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3359),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(387)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1695),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1696),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1697),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(388)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1698),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1699),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1700),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(389)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1945),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1946),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1788),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(390)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1774),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1775),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1776),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(391)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1709),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1710),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(392)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(3360),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(3361),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(393)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1711),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1712),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1713),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(394)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1714),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1715),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1716),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(395)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1719),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1720),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1721),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(396)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1722),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1723),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1724),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(397)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1725),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1726),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(398)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1727),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1728),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(399)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1729),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1546),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(400)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1551),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1662),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(401)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1548),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1645),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1646),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(402)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1647),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1648),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1649),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(403)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1545),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1663),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(404)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1547),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1730),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(405)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1584),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1585),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(406)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1586),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1587),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(407)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1588),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1589),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(408)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1590),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1591),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(409)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1625),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1626),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(410)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1627),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1628),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(411)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1629),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1630),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(412)] = {
    [sym_empty_statement] = STATE(1659),
    [sym_boolean] = STATE(1524),
    [sym_code_block] = STATE(1631),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(1659),
    [sym_preproc_guarded_statement] = STATE(1659),
    [sym_preproc_split_if_else_statement] = STATE(1659),
    [sym_preproc_split_if_then_begin] = STATE(1659),
    [sym_preproc_conditional_statement] = STATE(1659),
    [sym__statement] = STATE(1632),
    [sym__expression_statement] = STATE(1651),
    [sym_assignment_statement] = STATE(1659),
    [sym_assignment_expression] = STATE(1524),
    [sym_if_statement] = STATE(1659),
    [sym_case_statement] = STATE(1659),
    [sym_for_statement] = STATE(1659),
    [sym_foreach_statement] = STATE(1659),
    [sym_while_statement] = STATE(1659),
    [sym_repeat_statement] = STATE(1659),
    [sym_with_statement] = STATE(1659),
    [sym_exit_statement] = STATE(1659),
    [sym_continue_statement] = STATE(1659),
    [sym_break_statement] = STATE(1659),
    [sym_asserterror_statement] = STATE(1659),
    [sym__expression] = STATE(1524),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1524),
    [sym_multiplicative_expression] = STATE(1524),
    [sym_additive_expression] = STATE(1524),
    [sym_comparison_expression] = STATE(1524),
    [sym_logical_expression] = STATE(1524),
    [sym_ternary_expression] = STATE(1524),
    [sym_unary_expression] = STATE(1524),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1524),
    [sym_list_literal] = STATE(1524),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1524),
    [sym__literal_value] = STATE(1524),
    [sym_if_keyword] = STATE(3100),
    [sym_case_keyword] = STATE(3153),
    [sym_for_keyword] = STATE(3246),
    [sym_foreach_keyword] = STATE(11209),
    [sym_while_keyword] = STATE(3101),
    [sym_repeat_keyword] = STATE(158),
    [sym_exit_keyword] = STATE(1537),
    [sym_continue_keyword] = STATE(1660),
    [sym_break_keyword] = STATE(1661),
    [sym_with_keyword] = STATE(3102),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(590),
    [sym_date_literal] = ACTIONS(578),
    [sym_time_literal] = ACTIONS(578),
    [sym_biginteger_literal] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(592),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(590),
    [sym_integer] = ACTIONS(578),
    [sym_continue_as_identifier] = ACTIONS(590),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(413)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4628),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4629),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(414)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1922),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1923),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(415)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1936),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1940),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(416)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1942),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1943),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(417)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4630),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4631),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(418)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4632),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4633),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(419)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1876),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1926),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1928),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(420)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1932),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1935),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1937),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(421)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1778),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1779),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(422)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4634),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4635),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(423)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1782),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1783),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1784),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(424)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1785),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1786),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1787),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(425)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1790),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1792),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1793),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(426)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1794),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1795),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1796),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(427)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1797),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1798),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(428)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1799),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1800),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(429)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1801),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1802),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(430)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1803),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1804),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(431)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1805),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1806),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1807),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(432)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1808),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1809),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1773),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(433)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1812),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1813),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(434)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1814),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1815),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(435)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1871),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1872),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(436)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1874),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1875),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(437)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1877),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1878),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(438)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1879),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1880),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(439)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1890),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1891),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(440)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1893),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1894),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(441)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1895),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1896),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(442)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(1897),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(1898),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(443)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2224),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2225),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(444)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2313),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2314),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2319),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(445)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2361),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2363),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(446)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2338),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2339),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2340),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(447)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2359),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2360),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(448)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1067),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1069),
  },
  [STATE(449)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(451),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1071),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1073),
  },
  [STATE(450)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(515),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1075),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1077),
  },
  [STATE(451)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1079),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1081),
  },
  [STATE(452)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(457),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1083),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1085),
  },
  [STATE(453)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(458),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1087),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1089),
  },
  [STATE(454)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(460),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1091),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1093),
  },
  [STATE(455)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(516),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1095),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1097),
  },
  [STATE(456)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(523),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1099),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1101),
  },
  [STATE(457)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1103),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1105),
  },
  [STATE(458)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1107),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1109),
  },
  [STATE(459)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(466),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1111),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1113),
  },
  [STATE(460)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1115),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1117),
  },
  [STATE(461)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(467),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1119),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1121),
  },
  [STATE(462)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(468),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1123),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1125),
  },
  [STATE(463)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(470),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1127),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1129),
  },
  [STATE(464)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(471),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1131),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1133),
  },
  [STATE(465)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(473),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1135),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1137),
  },
  [STATE(466)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1139),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1141),
  },
  [STATE(467)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1143),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1145),
  },
  [STATE(468)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1147),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1149),
  },
  [STATE(469)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(476),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1151),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1153),
  },
  [STATE(470)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1155),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1157),
  },
  [STATE(471)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1159),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1161),
  },
  [STATE(472)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(477),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1163),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1165),
  },
  [STATE(473)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1167),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1169),
  },
  [STATE(474)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(478),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1171),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1173),
  },
  [STATE(475)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(479),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1175),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1177),
  },
  [STATE(476)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1179),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1181),
  },
  [STATE(477)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1183),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1185),
  },
  [STATE(478)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1187),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1189),
  },
  [STATE(479)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1191),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1193),
  },
  [STATE(480)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(481),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1195),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1197),
  },
  [STATE(481)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1199),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1201),
  },
  [STATE(482)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2219),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2223),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(483)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2297),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2348),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2322),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(484)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2251),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2252),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2272),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(485)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(486),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1203),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1205),
  },
  [STATE(486)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1207),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1209),
  },
  [STATE(487)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(490),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1211),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1213),
  },
  [STATE(488)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(491),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1215),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1217),
  },
  [STATE(489)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(493),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1219),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1221),
  },
  [STATE(490)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1223),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1225),
  },
  [STATE(491)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1227),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1229),
  },
  [STATE(492)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(499),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1231),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1233),
  },
  [STATE(493)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1235),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1237),
  },
  [STATE(494)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(500),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1239),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1241),
  },
  [STATE(495)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(501),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1243),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1245),
  },
  [STATE(496)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(503),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1247),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1249),
  },
  [STATE(497)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(504),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1251),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1253),
  },
  [STATE(498)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(506),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1255),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1257),
  },
  [STATE(499)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1259),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1261),
  },
  [STATE(500)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1263),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1265),
  },
  [STATE(501)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1267),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1269),
  },
  [STATE(502)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1271),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1273),
  },
  [STATE(503)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1275),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1277),
  },
  [STATE(504)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1279),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1281),
  },
  [STATE(505)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(510),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1283),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1285),
  },
  [STATE(506)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1287),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1289),
  },
  [STATE(507)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(511),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1291),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1293),
  },
  [STATE(508)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(512),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1295),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1297),
  },
  [STATE(509)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1299),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1301),
  },
  [STATE(510)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1303),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1305),
  },
  [STATE(511)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1307),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1309),
  },
  [STATE(512)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1311),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1313),
  },
  [STATE(513)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(514),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1315),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1317),
  },
  [STATE(514)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1319),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1321),
  },
  [STATE(515)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1323),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1325),
  },
  [STATE(516)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1327),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1329),
  },
  [STATE(517)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(518),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1331),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1333),
  },
  [STATE(518)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1335),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1337),
  },
  [STATE(519)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(524),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1339),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1341),
  },
  [STATE(520)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(525),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1343),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1345),
  },
  [STATE(521)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(527),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1347),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1349),
  },
  [STATE(522)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(560),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1351),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1353),
  },
  [STATE(523)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1355),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1357),
  },
  [STATE(524)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1359),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1361),
  },
  [STATE(525)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1363),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1365),
  },
  [STATE(526)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(533),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1367),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1369),
  },
  [STATE(527)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1371),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1373),
  },
  [STATE(528)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(534),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1375),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1377),
  },
  [STATE(529)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(535),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1379),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1381),
  },
  [STATE(530)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(537),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1383),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1385),
  },
  [STATE(531)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(538),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1387),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1389),
  },
  [STATE(532)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(540),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1391),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1393),
  },
  [STATE(533)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1395),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1397),
  },
  [STATE(534)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1399),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1401),
  },
  [STATE(535)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1403),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1405),
  },
  [STATE(536)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(543),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1407),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1409),
  },
  [STATE(537)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1411),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1413),
  },
  [STATE(538)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1415),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1417),
  },
  [STATE(539)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(544),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1419),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1421),
  },
  [STATE(540)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1423),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1425),
  },
  [STATE(541)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(545),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1429),
  },
  [STATE(542)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(546),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1431),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1433),
  },
  [STATE(543)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1435),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1437),
  },
  [STATE(544)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1439),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1441),
  },
  [STATE(545)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1443),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1445),
  },
  [STATE(546)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1447),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1449),
  },
  [STATE(547)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(548),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1451),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1453),
  },
  [STATE(548)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1455),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1457),
  },
  [STATE(549)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(561),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1459),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1461),
  },
  [STATE(550)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(562),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1463),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1465),
  },
  [STATE(551)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(564),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1467),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1469),
  },
  [STATE(552)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(565),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1471),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1473),
  },
  [STATE(553)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(567),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1475),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1477),
  },
  [STATE(554)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2311),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2234),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2249),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(555)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2308),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2390),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2397),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(556)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2235),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2236),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(557)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2237),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2238),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(558)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2381),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2382),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(559)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2386),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2387),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(560)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1479),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1481),
  },
  [STATE(561)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1483),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1485),
  },
  [STATE(562)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1487),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1489),
  },
  [STATE(563)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(575),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1491),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1493),
  },
  [STATE(564)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1495),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1497),
  },
  [STATE(565)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1499),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1501),
  },
  [STATE(566)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(576),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1503),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1505),
  },
  [STATE(567)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1507),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1509),
  },
  [STATE(568)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(577),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1511),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1513),
  },
  [STATE(569)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(578),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1515),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1517),
  },
  [STATE(570)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2243),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2248),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2250),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(571)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2258),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2296),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2377),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(572)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2239),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2240),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(573)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2244),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2245),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(574)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(2157),
    [sym_code_block] = STATE(4616),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(4617),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(2157),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(2157),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2157),
    [sym_multiplicative_expression] = STATE(2157),
    [sym_additive_expression] = STATE(2157),
    [sym_comparison_expression] = STATE(2157),
    [sym_logical_expression] = STATE(2157),
    [sym_ternary_expression] = STATE(2157),
    [sym_unary_expression] = STATE(2157),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2157),
    [sym_list_literal] = STATE(2157),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2157),
    [sym__literal_value] = STATE(2157),
    [sym_if_keyword] = STATE(3086),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3245),
    [sym_foreach_keyword] = STATE(11186),
    [sym_while_keyword] = STATE(3087),
    [sym_repeat_keyword] = STATE(161),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3088),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(620),
    [sym_date_literal] = ACTIONS(608),
    [sym_time_literal] = ACTIONS(608),
    [sym_biginteger_literal] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(622),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(620),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(620),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(575)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1519),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1521),
  },
  [STATE(576)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1523),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1525),
  },
  [STATE(577)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1527),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1529),
  },
  [STATE(578)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1531),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1533),
  },
  [STATE(579)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(580),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1535),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1537),
  },
  [STATE(580)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2444),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1539),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1541),
  },
  [STATE(581)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10101),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10298),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(582)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10268),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9965),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(583)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10072),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9993),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(584)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10002),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10008),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(585)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10009),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10010),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(586)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10079),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10086),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(587)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10103),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10106),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(588)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10012),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10013),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(589)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10043),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10049),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(590)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10050),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10051),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(591)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10054),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10055),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(592)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10186),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10187),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(593)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10188),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10190),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(594)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10212),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10213),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(595)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10218),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10219),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(596)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(9944),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9946),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(597)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(9957),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9962),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(598)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(9963),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9968),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(599)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(9970),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(9976),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(600)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10014),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10015),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(601)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10021),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10022),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(602)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10023),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10024),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(603)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10040),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10042),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(604)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10211),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10227),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(605)] = {
    [sym_empty_statement] = STATE(10098),
    [sym_boolean] = STATE(6083),
    [sym_code_block] = STATE(10267),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(10098),
    [sym_preproc_guarded_statement] = STATE(10098),
    [sym_preproc_split_if_else_statement] = STATE(10098),
    [sym_preproc_split_if_then_begin] = STATE(10098),
    [sym_preproc_conditional_statement] = STATE(10098),
    [sym__statement] = STATE(10270),
    [sym__expression_statement] = STATE(10122),
    [sym_assignment_statement] = STATE(10098),
    [sym_assignment_expression] = STATE(6083),
    [sym_if_statement] = STATE(10098),
    [sym_case_statement] = STATE(10098),
    [sym_for_statement] = STATE(10098),
    [sym_foreach_statement] = STATE(10098),
    [sym_while_statement] = STATE(10098),
    [sym_repeat_statement] = STATE(10098),
    [sym_with_statement] = STATE(10098),
    [sym_exit_statement] = STATE(10098),
    [sym_continue_statement] = STATE(10098),
    [sym_break_statement] = STATE(10098),
    [sym_asserterror_statement] = STATE(10098),
    [sym__expression] = STATE(6083),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6083),
    [sym_multiplicative_expression] = STATE(6083),
    [sym_additive_expression] = STATE(6083),
    [sym_comparison_expression] = STATE(6083),
    [sym_logical_expression] = STATE(6083),
    [sym_ternary_expression] = STATE(6083),
    [sym_unary_expression] = STATE(6083),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6083),
    [sym_list_literal] = STATE(6083),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6083),
    [sym__literal_value] = STATE(6083),
    [sym_if_keyword] = STATE(3114),
    [sym_case_keyword] = STATE(3173),
    [sym_for_keyword] = STATE(3247),
    [sym_foreach_keyword] = STATE(11225),
    [sym_while_keyword] = STATE(3115),
    [sym_repeat_keyword] = STATE(157),
    [sym_exit_keyword] = STATE(9824),
    [sym_continue_keyword] = STATE(10181),
    [sym_break_keyword] = STATE(10183),
    [sym_with_keyword] = STATE(3116),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(925),
    [sym_date_literal] = ACTIONS(913),
    [sym_time_literal] = ACTIONS(913),
    [sym_biginteger_literal] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(927),
    [anon_sym_EXIT] = ACTIONS(927),
    [anon_sym_Exit] = ACTIONS(927),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_CONTINUE] = ACTIONS(929),
    [anon_sym_Continue] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(931),
    [anon_sym_BREAK] = ACTIONS(931),
    [anon_sym_Break] = ACTIONS(931),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(933),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(925),
    [sym_integer] = ACTIONS(913),
    [sym_continue_as_identifier] = ACTIONS(925),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(606)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2328),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2329),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(607)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2330),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2331),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(608)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2332),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2334),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(609)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2335),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2341),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(610)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2351),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2352),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(611)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2353),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2354),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(612)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2356),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2357),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2266),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(613)] = {
    [sym_empty_statement] = STATE(2266),
    [sym_boolean] = STATE(1161),
    [sym_code_block] = STATE(2333),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2266),
    [sym_preproc_guarded_statement] = STATE(2266),
    [sym_preproc_split_if_else_statement] = STATE(2266),
    [sym_preproc_split_if_then_begin] = STATE(2266),
    [sym_preproc_conditional_statement] = STATE(2266),
    [sym__statement] = STATE(2336),
    [sym__expression_statement] = STATE(2280),
    [sym_assignment_statement] = STATE(2266),
    [sym_assignment_expression] = STATE(1161),
    [sym_if_statement] = STATE(2337),
    [sym_case_statement] = STATE(2266),
    [sym_for_statement] = STATE(2266),
    [sym_foreach_statement] = STATE(2266),
    [sym_while_statement] = STATE(2266),
    [sym_repeat_statement] = STATE(2266),
    [sym_with_statement] = STATE(2266),
    [sym_exit_statement] = STATE(2266),
    [sym_continue_statement] = STATE(2266),
    [sym_break_statement] = STATE(2266),
    [sym_asserterror_statement] = STATE(2266),
    [sym__expression] = STATE(1161),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1161),
    [sym_multiplicative_expression] = STATE(1161),
    [sym_additive_expression] = STATE(1161),
    [sym_comparison_expression] = STATE(1161),
    [sym_logical_expression] = STATE(1161),
    [sym_ternary_expression] = STATE(1161),
    [sym_unary_expression] = STATE(1161),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1161),
    [sym_list_literal] = STATE(1161),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1161),
    [sym__literal_value] = STATE(1161),
    [sym_if_keyword] = STATE(3130),
    [sym_case_keyword] = STATE(3131),
    [sym_for_keyword] = STATE(3135),
    [sym_foreach_keyword] = STATE(11135),
    [sym_while_keyword] = STATE(3137),
    [sym_repeat_keyword] = STATE(160),
    [sym_exit_keyword] = STATE(2222),
    [sym_continue_keyword] = STATE(2309),
    [sym_break_keyword] = STATE(2310),
    [sym_with_keyword] = STATE(3139),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(640),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(656),
    [sym_date_literal] = ACTIONS(640),
    [sym_time_literal] = ACTIONS(640),
    [sym_biginteger_literal] = ACTIONS(656),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(658),
    [anon_sym_EXIT] = ACTIONS(658),
    [anon_sym_Exit] = ACTIONS(658),
    [anon_sym_continue] = ACTIONS(660),
    [anon_sym_CONTINUE] = ACTIONS(660),
    [anon_sym_Continue] = ACTIONS(660),
    [anon_sym_break] = ACTIONS(662),
    [anon_sym_BREAK] = ACTIONS(662),
    [anon_sym_Break] = ACTIONS(662),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(664),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(656),
    [sym_integer] = ACTIONS(640),
    [sym_continue_as_identifier] = ACTIONS(656),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(846),
  },
  [STATE(614)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(864),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1543),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(615)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1545),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(616)] = {
    [sym_preproc_conditional_object] = STATE(940),
    [sym_namespace_declaration] = STATE(939),
    [sym_using_statement] = STATE(940),
    [sym__object] = STATE(940),
    [sym_preproc_split_declaration] = STATE(940),
    [sym__object_header] = STATE(8129),
    [sym_table_declaration] = STATE(940),
    [sym_page_declaration] = STATE(940),
    [sym_report_declaration] = STATE(940),
    [sym_query_declaration] = STATE(940),
    [sym_xmlport_declaration] = STATE(940),
    [sym_permissionset_declaration] = STATE(940),
    [sym_codeunit_declaration] = STATE(940),
    [sym_enum_declaration] = STATE(940),
    [sym_tableextension_declaration] = STATE(940),
    [sym_pageextension_declaration] = STATE(940),
    [sym_reportextension_declaration] = STATE(940),
    [sym_enumextension_declaration] = STATE(940),
    [sym_permissionsetextension_declaration] = STATE(940),
    [sym_controladdin_declaration] = STATE(940),
    [sym_profile_declaration] = STATE(940),
    [sym_entitlement_declaration] = STATE(940),
    [sym_profileextension_declaration] = STATE(940),
    [sym_interface_declaration] = STATE(940),
    [sym_pagecustomization_declaration] = STATE(940),
    [sym_dotnet_declaration] = STATE(940),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_elif] = STATE(948),
    [sym_preproc_else] = STATE(1045),
    [sym_preproc_endif] = STATE(1950),
    [sym_tableextension_keyword] = STATE(11368),
    [sym_pageextension_keyword] = STATE(11370),
    [sym_codeunit_keyword] = STATE(11381),
    [sym_reportextension_keyword] = STATE(11385),
    [sym_xmlport_keyword] = STATE(11401),
    [sym_enum_keyword] = STATE(11602),
    [sym_enumextension_keyword] = STATE(11977),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11691),
    [sym_permissionsetextension_keyword] = STATE(12147),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(940),
    [aux_sym_preproc_conditional_object_repeat1] = STATE(7846),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(1547),
    [anon_sym_POUNDELIF] = ACTIONS(1547),
    [anon_sym_POUNDElif] = ACTIONS(1547),
    [anon_sym_POUNDelse] = ACTIONS(1549),
    [anon_sym_POUNDELSE] = ACTIONS(1549),
    [anon_sym_POUNDElse] = ACTIONS(1549),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(1553),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(1555),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(1557),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(1559),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(1561),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1567),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(617)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(619),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1571),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(618)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1573),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(619)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1575),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(620)] = {
    [sym_preproc_conditional_object] = STATE(935),
    [sym_namespace_declaration] = STATE(936),
    [sym_using_statement] = STATE(935),
    [sym__object] = STATE(935),
    [sym_preproc_split_declaration] = STATE(935),
    [sym__object_header] = STATE(7988),
    [sym_table_declaration] = STATE(935),
    [sym_page_declaration] = STATE(935),
    [sym_report_declaration] = STATE(935),
    [sym_query_declaration] = STATE(935),
    [sym_xmlport_declaration] = STATE(935),
    [sym_permissionset_declaration] = STATE(935),
    [sym_codeunit_declaration] = STATE(935),
    [sym_enum_declaration] = STATE(935),
    [sym_tableextension_declaration] = STATE(935),
    [sym_pageextension_declaration] = STATE(935),
    [sym_reportextension_declaration] = STATE(935),
    [sym_enumextension_declaration] = STATE(935),
    [sym_permissionsetextension_declaration] = STATE(935),
    [sym_controladdin_declaration] = STATE(935),
    [sym_profile_declaration] = STATE(935),
    [sym_entitlement_declaration] = STATE(935),
    [sym_profileextension_declaration] = STATE(935),
    [sym_interface_declaration] = STATE(935),
    [sym_pagecustomization_declaration] = STATE(935),
    [sym_dotnet_declaration] = STATE(935),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_elif] = STATE(948),
    [sym_preproc_else] = STATE(1043),
    [sym_preproc_endif] = STATE(2539),
    [sym_tableextension_keyword] = STATE(11368),
    [sym_pageextension_keyword] = STATE(11370),
    [sym_codeunit_keyword] = STATE(11381),
    [sym_reportextension_keyword] = STATE(11385),
    [sym_xmlport_keyword] = STATE(11401),
    [sym_enum_keyword] = STATE(11602),
    [sym_enumextension_keyword] = STATE(11977),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11691),
    [sym_permissionsetextension_keyword] = STATE(12147),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(935),
    [aux_sym_preproc_conditional_object_repeat1] = STATE(8071),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(1547),
    [anon_sym_POUNDELIF] = ACTIONS(1547),
    [anon_sym_POUNDElif] = ACTIONS(1547),
    [anon_sym_POUNDelse] = ACTIONS(1549),
    [anon_sym_POUNDELSE] = ACTIONS(1549),
    [anon_sym_POUNDElse] = ACTIONS(1549),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(1553),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(1555),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(1557),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(1559),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(1561),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1567),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(621)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1579),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(622)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(625),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1581),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(623)] = {
    [sym_boolean] = STATE(1212),
    [sym_option_member] = STATE(1214),
    [sym_keyword_identifier] = STATE(1212),
    [sym_codeunit_keyword] = STATE(1157),
    [sym_xmlport_keyword] = STATE(1157),
    [sym_enum_keyword] = STATE(1157),
    [sym_keyword_as_identifier] = STATE(1212),
    [sym_identifier] = ACTIONS(1583),
    [anon_sym_SEMI] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(391),
    [anon_sym_EQ] = ACTIONS(389),
    [anon_sym_COMMA] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(1586),
    [aux_sym_boolean_token1] = ACTIONS(1589),
    [aux_sym_boolean_token2] = ACTIONS(1589),
    [sym_decimal] = ACTIONS(391),
    [anon_sym_LPAREN] = ACTIONS(389),
    [aux_sym_where_condition_token1] = ACTIONS(834),
    [anon_sym_DOT_DOT] = ACTIONS(389),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1592),
    [anon_sym_STAR] = ACTIONS(391),
    [anon_sym_LBRACK] = ACTIONS(389),
    [aux_sym_record_type_token1] = ACTIONS(1592),
    [aux_sym_basic_type_token21] = ACTIONS(1592),
    [aux_sym_basic_type_token22] = ACTIONS(1595),
    [aux_sym_basic_type_token48] = ACTIONS(1592),
    [aux_sym_basic_type_token53] = ACTIONS(834),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(834),
    [aux_sym_separator_action_token1] = ACTIONS(834),
    [aux_sym_type_declaration_token1] = ACTIONS(834),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(391),
    [anon_sym_POUNDif] = ACTIONS(389),
    [anon_sym_POUNDIF] = ACTIONS(389),
    [anon_sym_POUNDIf] = ACTIONS(389),
    [anon_sym_not] = ACTIONS(391),
    [anon_sym_NOT] = ACTIONS(391),
    [anon_sym_Not] = ACTIONS(391),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(389),
    [aux_sym__expression_token1] = ACTIONS(389),
    [aux_sym__expression_token2] = ACTIONS(391),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1592),
    [anon_sym_SLASH] = ACTIONS(391),
    [anon_sym_div] = ACTIONS(391),
    [anon_sym_DIV] = ACTIONS(391),
    [anon_sym_Div] = ACTIONS(391),
    [anon_sym_mod] = ACTIONS(391),
    [anon_sym_MOD] = ACTIONS(391),
    [anon_sym_Mod] = ACTIONS(391),
    [anon_sym_PLUS] = ACTIONS(391),
    [anon_sym_GT_EQ] = ACTIONS(389),
    [anon_sym_LT_EQ] = ACTIONS(389),
    [anon_sym_GT] = ACTIONS(391),
    [anon_sym_LT] = ACTIONS(391),
    [anon_sym_LT_GT] = ACTIONS(389),
    [anon_sym_and] = ACTIONS(391),
    [anon_sym_AND] = ACTIONS(391),
    [anon_sym_And] = ACTIONS(391),
    [anon_sym_or] = ACTIONS(391),
    [anon_sym_OR] = ACTIONS(391),
    [anon_sym_Or] = ACTIONS(391),
    [anon_sym_xor] = ACTIONS(391),
    [anon_sym_XOR] = ACTIONS(391),
    [anon_sym_Xor] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(389),
    [sym_datetime_literal] = ACTIONS(389),
    [sym_date_literal] = ACTIONS(391),
    [sym_time_literal] = ACTIONS(391),
    [sym_biginteger_literal] = ACTIONS(389),
    [anon_sym_if] = ACTIONS(391),
    [anon_sym_IF] = ACTIONS(391),
    [anon_sym_If] = ACTIONS(391),
    [anon_sym_else] = ACTIONS(391),
    [anon_sym_ELSE] = ACTIONS(391),
    [anon_sym_Else] = ACTIONS(391),
    [anon_sym_case] = ACTIONS(391),
    [anon_sym_CASE] = ACTIONS(391),
    [anon_sym_Case] = ACTIONS(391),
    [anon_sym_for] = ACTIONS(391),
    [anon_sym_FOR] = ACTIONS(391),
    [anon_sym_For] = ACTIONS(391),
    [anon_sym_foreach] = ACTIONS(391),
    [anon_sym_FOREACH] = ACTIONS(391),
    [anon_sym_Foreach] = ACTIONS(391),
    [anon_sym_while] = ACTIONS(391),
    [anon_sym_WHILE] = ACTIONS(391),
    [anon_sym_While] = ACTIONS(391),
    [anon_sym_repeat] = ACTIONS(391),
    [anon_sym_REPEAT] = ACTIONS(391),
    [anon_sym_Repeat] = ACTIONS(391),
    [anon_sym_exit] = ACTIONS(391),
    [anon_sym_EXIT] = ACTIONS(391),
    [anon_sym_Exit] = ACTIONS(391),
    [anon_sym_continue] = ACTIONS(391),
    [anon_sym_CONTINUE] = ACTIONS(391),
    [anon_sym_Continue] = ACTIONS(391),
    [anon_sym_break] = ACTIONS(391),
    [anon_sym_BREAK] = ACTIONS(391),
    [anon_sym_Break] = ACTIONS(391),
    [anon_sym_with] = ACTIONS(391),
    [anon_sym_WITH] = ACTIONS(391),
    [anon_sym_With] = ACTIONS(391),
    [sym_asserterror_keyword] = ACTIONS(389),
    [anon_sym_in] = ACTIONS(391),
    [anon_sym_IN] = ACTIONS(391),
    [anon_sym_In] = ACTIONS(391),
    [sym_page_keyword] = ACTIONS(1592),
    [anon_sym_codeunit] = ACTIONS(1598),
    [anon_sym_CODEUNIT] = ACTIONS(1598),
    [anon_sym_Codeunit] = ACTIONS(1598),
    [anon_sym_CodeUnit] = ACTIONS(1598),
    [anon_sym_COdeunit] = ACTIONS(1598),
    [anon_sym_codeUnit] = ACTIONS(1598),
    [sym_report_keyword] = ACTIONS(1592),
    [sym_query_keyword] = ACTIONS(1592),
    [anon_sym_xmlport] = ACTIONS(1601),
    [anon_sym_XMLPORT] = ACTIONS(1601),
    [anon_sym_Xmlport] = ACTIONS(1601),
    [anon_sym_XMLport] = ACTIONS(1601),
    [anon_sym_XMLPort] = ACTIONS(1601),
    [anon_sym_XmlPort] = ACTIONS(1601),
    [anon_sym_enum] = ACTIONS(1604),
    [anon_sym_ENUM] = ACTIONS(1604),
    [anon_sym_Enum] = ACTIONS(1604),
    [anon_sym_eNUM] = ACTIONS(1604),
    [anon_sym_eNum] = ACTIONS(1604),
    [anon_sym_ENum] = ACTIONS(1604),
    [sym_local_keyword] = ACTIONS(828),
    [sym_internal_keyword] = ACTIONS(828),
    [sym_protected_keyword] = ACTIONS(828),
    [sym_key_keyword] = ACTIONS(834),
    [sym_dataset_keyword] = ACTIONS(834),
    [sym_quoted_identifier] = ACTIONS(1607),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1607),
    [sym_integer] = ACTIONS(1583),
    [sym_continue_as_identifier] = ACTIONS(389),
    [sym_preproc_open] = ACTIONS(389),
    [sym_end_keyword] = ACTIONS(389),
  },
  [STATE(624)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(627),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1610),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(625)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1612),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(626)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(633),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1614),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(627)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1616),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(628)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(663),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1618),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(629)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(631),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1620),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(630)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(634),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1622),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(631)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1624),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(632)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(636),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1626),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(633)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1628),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(634)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1630),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(635)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(637),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1632),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(636)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1634),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(637)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1636),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(638)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(639),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1638),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(639)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1640),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(640)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(643),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1642),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(641)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(644),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1644),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(642)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(646),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1646),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(643)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1648),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(644)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1650),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(645)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(649),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1652),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(646)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1654),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(647)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(650),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1656),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(648)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(651),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1658),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(649)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1660),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(650)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1662),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(651)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1664),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(652)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(653),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1666),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(653)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1668),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(654)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(656),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1670),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(655)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(658),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1672),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(656)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1674),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(657)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(660),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1676),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(658)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1678),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(659)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(661),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1680),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(660)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1682),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(661)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1684),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(662)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(618),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1686),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(663)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1688),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(664)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(665),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1690),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(665)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1692),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(666)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(669),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1694),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(667)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(670),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1696),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(668)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(672),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1698),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(669)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1700),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(670)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1702),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(671)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(675),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1704),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(672)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1706),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(673)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(676),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1708),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(674)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(677),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1710),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(675)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1712),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(676)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1714),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(677)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1716),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(678)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(679),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1718),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(679)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1720),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(680)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(683),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1722),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(681)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1724),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(682)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(685),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1726),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(683)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1728),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(684)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(686),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1730),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(685)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1732),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(686)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1734),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(687)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(824),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1736),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(688)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(689),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1738),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(689)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1740),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(690)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(693),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1742),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(691)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(694),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1744),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(692)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(696),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1746),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(693)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1748),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(694)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1750),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(695)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(699),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1752),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(696)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1754),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(697)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(700),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1756),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(698)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(701),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1758),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(699)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1760),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(700)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1762),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(701)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1764),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(702)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(703),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1766),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(703)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1768),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(704)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(706),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1770),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(705)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(708),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1772),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(706)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1774),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(707)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(710),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1776),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(708)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1778),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(709)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(711),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1780),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(710)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1782),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(711)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1784),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(712)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(714),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1786),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(713)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(716),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1788),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(714)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1790),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(715)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(718),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1792),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(716)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1794),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(717)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(719),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1796),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(718)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1798),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(719)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1800),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(720)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(722),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1802),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(721)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(724),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1804),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(722)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1806),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(723)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(726),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1808),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(724)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1810),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(725)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(727),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1812),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(726)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1814),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(727)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1816),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(728)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(730),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1818),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(729)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(732),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1820),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(730)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1822),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(731)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(734),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1824),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(732)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1826),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(733)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(735),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1828),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(734)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1830),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(735)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1832),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(736)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(738),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1834),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(737)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(740),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1836),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(738)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1838),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(739)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(742),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1840),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(740)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1842),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(741)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(743),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1844),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(742)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1846),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(743)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1848),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(744)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(746),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1850),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(745)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(748),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1852),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(746)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1854),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(747)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(750),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1856),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(748)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1858),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(749)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(751),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1860),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(750)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1862),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(751)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1864),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(752)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(754),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1866),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(753)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(756),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1868),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(754)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1870),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(755)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(758),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1872),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(756)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1874),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(757)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(759),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1876),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(758)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1878),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(759)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1880),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(760)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(762),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1882),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(761)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(764),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1884),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(762)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1886),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(763)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(766),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1888),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(764)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1890),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(765)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(767),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1892),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(766)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1894),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(767)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1896),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(768)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(770),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1898),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(769)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(772),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1900),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(770)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1902),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(771)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1904),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(772)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1906),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(773)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(775),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1908),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(774)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1910),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(775)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1912),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(776)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(778),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1914),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(777)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(780),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1916),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(778)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1918),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(779)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(782),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1920),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(780)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1922),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(781)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(783),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1924),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(782)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1926),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(783)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1928),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(784)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(786),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1930),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(785)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(788),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1932),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(786)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1934),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(787)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(790),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1936),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(788)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1938),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(789)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(791),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1940),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(790)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1942),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(791)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1944),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(792)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(794),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1946),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(793)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(796),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1948),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(794)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1950),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(795)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(798),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1952),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(796)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1954),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(797)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(799),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1956),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(798)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1958),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(799)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1960),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(800)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(802),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1962),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(801)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(804),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1964),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(802)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1966),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(803)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(806),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1968),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(804)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1970),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(805)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(807),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1972),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(806)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1974),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(807)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1976),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(808)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(810),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(809)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(812),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1980),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(810)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1982),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(811)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(814),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1984),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(812)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1986),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(813)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(815),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1988),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(814)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1990),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(815)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1992),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(816)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(818),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1994),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(817)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(820),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1996),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(818)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1998),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(819)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(822),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2000),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(820)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2002),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(821)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(823),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2004),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(822)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2006),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(823)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2008),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(824)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2010),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(825)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(828),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2012),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(826)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(829),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2014),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(827)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(831),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2016),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(828)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2018),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(829)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2020),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(830)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(834),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2022),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(831)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2024),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(832)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(835),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2026),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(833)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(840),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2028),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(834)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2030),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(835)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2032),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(836)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(838),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2034),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(837)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(839),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2036),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(838)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2038),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(839)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2040),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(840)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2042),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(841)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(843),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2044),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(842)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(844),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2046),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(843)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2048),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(844)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2050),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(845)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(615),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2052),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(846)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(848),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2054),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(847)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(849),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2056),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(848)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2058),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(849)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2060),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(850)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(852),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2062),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(851)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(853),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2064),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(852)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2066),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(853)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2068),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(854)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(856),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2070),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(855)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(857),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2072),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(856)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2074),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(857)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2076),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(858)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(860),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2078),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(859)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(861),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2080),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(860)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2082),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(861)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2084),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(862)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(863),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2086),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(863)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2088),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(864)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2090),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(865)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(867),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2092),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(866)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(868),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2094),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(867)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2096),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(868)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2098),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(869)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(871),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2100),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(870)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(872),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2102),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(871)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2104),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(872)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2106),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(873)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(875),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2108),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(874)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(876),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2110),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(875)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2112),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(876)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2114),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(877)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(879),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2116),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(878)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(880),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2118),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(879)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2120),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(880)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2122),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(881)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(883),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2124),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(882)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(884),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2126),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(883)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2128),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(884)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2130),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(885)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(887),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2132),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(886)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(888),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2134),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(887)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2136),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(888)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2138),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(889)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(891),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2140),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(890)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(892),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2142),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(891)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2144),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(892)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2146),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(893)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(895),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2148),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(894)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(896),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2150),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(895)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2152),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(896)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2154),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(897)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(899),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2156),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(898)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(900),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2158),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(899)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2160),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(900)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2162),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(901)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(903),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2164),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(902)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(904),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2166),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(903)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2168),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(904)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2170),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(905)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(907),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2172),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(906)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(908),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2174),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(907)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2176),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(908)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2178),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(909)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(681),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2180),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(910)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(24),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(920),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(911)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(5),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(912),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(912)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(6),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(913)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(7),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(915),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(914)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(8),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(916),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(915)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(9),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(916)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(10),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(917)] = {
    [aux_sym_option_member_list_repeat2] = STATE(917),
    [sym_identifier] = ACTIONS(565),
    [anon_sym_SEMI] = ACTIONS(567),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_EQ] = ACTIONS(567),
    [anon_sym_COMMA] = ACTIONS(2182),
    [anon_sym_DASH] = ACTIONS(565),
    [aux_sym_boolean_token1] = ACTIONS(565),
    [aux_sym_boolean_token2] = ACTIONS(565),
    [sym_decimal] = ACTIONS(565),
    [anon_sym_LPAREN] = ACTIONS(567),
    [aux_sym_where_condition_token1] = ACTIONS(565),
    [anon_sym_DOT_DOT] = ACTIONS(567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(565),
    [anon_sym_STAR] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [aux_sym_record_type_token1] = ACTIONS(565),
    [aux_sym_basic_type_token21] = ACTIONS(565),
    [aux_sym_basic_type_token22] = ACTIONS(565),
    [aux_sym_basic_type_token48] = ACTIONS(565),
    [aux_sym_basic_type_token53] = ACTIONS(565),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(565),
    [aux_sym_separator_action_token1] = ACTIONS(565),
    [aux_sym_type_declaration_token1] = ACTIONS(565),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(565),
    [anon_sym_POUNDif] = ACTIONS(567),
    [anon_sym_POUNDIF] = ACTIONS(567),
    [anon_sym_POUNDIf] = ACTIONS(567),
    [anon_sym_not] = ACTIONS(565),
    [anon_sym_NOT] = ACTIONS(565),
    [anon_sym_Not] = ACTIONS(565),
    [anon_sym_POUNDelse] = ACTIONS(567),
    [anon_sym_POUNDELSE] = ACTIONS(567),
    [anon_sym_POUNDElse] = ACTIONS(567),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(567),
    [aux_sym__expression_token1] = ACTIONS(567),
    [aux_sym__expression_token2] = ACTIONS(565),
    [aux_sym_keyword_identifier_token1] = ACTIONS(565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(565),
    [anon_sym_SLASH] = ACTIONS(565),
    [anon_sym_div] = ACTIONS(565),
    [anon_sym_DIV] = ACTIONS(565),
    [anon_sym_Div] = ACTIONS(565),
    [anon_sym_mod] = ACTIONS(565),
    [anon_sym_MOD] = ACTIONS(565),
    [anon_sym_Mod] = ACTIONS(565),
    [anon_sym_PLUS] = ACTIONS(565),
    [anon_sym_GT_EQ] = ACTIONS(567),
    [anon_sym_LT_EQ] = ACTIONS(567),
    [anon_sym_GT] = ACTIONS(565),
    [anon_sym_LT] = ACTIONS(565),
    [anon_sym_LT_GT] = ACTIONS(567),
    [anon_sym_and] = ACTIONS(565),
    [anon_sym_AND] = ACTIONS(565),
    [anon_sym_And] = ACTIONS(565),
    [anon_sym_or] = ACTIONS(565),
    [anon_sym_OR] = ACTIONS(565),
    [anon_sym_Or] = ACTIONS(565),
    [anon_sym_xor] = ACTIONS(565),
    [anon_sym_XOR] = ACTIONS(565),
    [anon_sym_Xor] = ACTIONS(565),
    [anon_sym_QMARK] = ACTIONS(567),
    [sym_datetime_literal] = ACTIONS(567),
    [sym_date_literal] = ACTIONS(565),
    [sym_time_literal] = ACTIONS(565),
    [sym_biginteger_literal] = ACTIONS(567),
    [anon_sym_if] = ACTIONS(565),
    [anon_sym_IF] = ACTIONS(565),
    [anon_sym_If] = ACTIONS(565),
    [anon_sym_else] = ACTIONS(565),
    [anon_sym_ELSE] = ACTIONS(565),
    [anon_sym_Else] = ACTIONS(565),
    [anon_sym_case] = ACTIONS(565),
    [anon_sym_CASE] = ACTIONS(565),
    [anon_sym_Case] = ACTIONS(565),
    [anon_sym_for] = ACTIONS(565),
    [anon_sym_FOR] = ACTIONS(565),
    [anon_sym_For] = ACTIONS(565),
    [anon_sym_foreach] = ACTIONS(565),
    [anon_sym_FOREACH] = ACTIONS(565),
    [anon_sym_Foreach] = ACTIONS(565),
    [anon_sym_while] = ACTIONS(565),
    [anon_sym_WHILE] = ACTIONS(565),
    [anon_sym_While] = ACTIONS(565),
    [anon_sym_repeat] = ACTIONS(565),
    [anon_sym_REPEAT] = ACTIONS(565),
    [anon_sym_Repeat] = ACTIONS(565),
    [anon_sym_until] = ACTIONS(565),
    [anon_sym_UNTIL] = ACTIONS(565),
    [anon_sym_Until] = ACTIONS(565),
    [anon_sym_exit] = ACTIONS(565),
    [anon_sym_EXIT] = ACTIONS(565),
    [anon_sym_Exit] = ACTIONS(565),
    [anon_sym_continue] = ACTIONS(565),
    [anon_sym_CONTINUE] = ACTIONS(565),
    [anon_sym_Continue] = ACTIONS(565),
    [anon_sym_break] = ACTIONS(565),
    [anon_sym_BREAK] = ACTIONS(565),
    [anon_sym_Break] = ACTIONS(565),
    [anon_sym_with] = ACTIONS(565),
    [anon_sym_WITH] = ACTIONS(565),
    [anon_sym_With] = ACTIONS(565),
    [sym_asserterror_keyword] = ACTIONS(567),
    [anon_sym_in] = ACTIONS(565),
    [anon_sym_IN] = ACTIONS(565),
    [anon_sym_In] = ACTIONS(565),
    [sym_page_keyword] = ACTIONS(565),
    [anon_sym_codeunit] = ACTIONS(565),
    [anon_sym_CODEUNIT] = ACTIONS(565),
    [anon_sym_Codeunit] = ACTIONS(565),
    [anon_sym_CodeUnit] = ACTIONS(565),
    [anon_sym_COdeunit] = ACTIONS(565),
    [anon_sym_codeUnit] = ACTIONS(565),
    [sym_report_keyword] = ACTIONS(565),
    [sym_query_keyword] = ACTIONS(565),
    [anon_sym_xmlport] = ACTIONS(565),
    [anon_sym_XMLPORT] = ACTIONS(565),
    [anon_sym_Xmlport] = ACTIONS(565),
    [anon_sym_XMLport] = ACTIONS(565),
    [anon_sym_XMLPort] = ACTIONS(565),
    [anon_sym_XmlPort] = ACTIONS(565),
    [anon_sym_enum] = ACTIONS(565),
    [anon_sym_ENUM] = ACTIONS(565),
    [anon_sym_Enum] = ACTIONS(565),
    [anon_sym_eNUM] = ACTIONS(565),
    [anon_sym_eNum] = ACTIONS(565),
    [anon_sym_ENum] = ACTIONS(565),
    [sym_local_keyword] = ACTIONS(565),
    [sym_internal_keyword] = ACTIONS(565),
    [sym_protected_keyword] = ACTIONS(565),
    [sym_key_keyword] = ACTIONS(565),
    [sym_dataset_keyword] = ACTIONS(565),
    [sym_quoted_identifier] = ACTIONS(567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(567),
    [sym_integer] = ACTIONS(565),
    [sym_continue_as_identifier] = ACTIONS(567),
    [sym_preproc_open] = ACTIONS(567),
  },
  [STATE(918)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(22),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(919),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(919)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(23),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(920)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(56),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(921)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(2),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(922)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(28),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(923),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(923)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(29),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(924)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(30),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(926),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(925)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(31),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(927),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(926)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(32),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(927)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(928)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(34),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(929),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(929)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(35),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(930)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(36),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(932),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(931)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(933),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(932)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(38),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(933)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(39),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(934)] = {
    [sym_empty_statement] = STATE(1902),
    [sym_boolean] = STATE(1078),
    [sym_preproc_if] = STATE(25),
    [sym_preproc_split_if_statement] = STATE(1902),
    [sym_preproc_guarded_statement] = STATE(1902),
    [sym_preproc_split_if_else_statement] = STATE(1902),
    [sym_preproc_split_if_then_begin] = STATE(1902),
    [sym_preproc_conditional_statement] = STATE(1902),
    [sym__statement] = STATE(2212),
    [sym__expression_statement] = STATE(1929),
    [sym_assignment_statement] = STATE(1902),
    [sym_assignment_expression] = STATE(1078),
    [sym_if_statement] = STATE(1902),
    [sym_case_statement] = STATE(1902),
    [sym_for_statement] = STATE(1902),
    [sym_foreach_statement] = STATE(1902),
    [sym_while_statement] = STATE(1902),
    [sym_repeat_statement] = STATE(1902),
    [sym_with_statement] = STATE(1902),
    [sym_exit_statement] = STATE(1902),
    [sym_continue_statement] = STATE(1902),
    [sym_break_statement] = STATE(1902),
    [sym_asserterror_statement] = STATE(1902),
    [sym__expression] = STATE(1078),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1078),
    [sym_multiplicative_expression] = STATE(1078),
    [sym_additive_expression] = STATE(1078),
    [sym_comparison_expression] = STATE(1078),
    [sym_logical_expression] = STATE(1078),
    [sym_ternary_expression] = STATE(1078),
    [sym_unary_expression] = STATE(1078),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1078),
    [sym_list_literal] = STATE(1078),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1078),
    [sym__literal_value] = STATE(1078),
    [sym_if_keyword] = STATE(3009),
    [sym_case_keyword] = STATE(3170),
    [sym_for_keyword] = STATE(3244),
    [sym_foreach_keyword] = STATE(11152),
    [sym_while_keyword] = STATE(3058),
    [sym_repeat_keyword] = STATE(165),
    [sym_exit_keyword] = STATE(1747),
    [sym_continue_keyword] = STATE(1907),
    [sym_break_keyword] = STATE(1909),
    [sym_with_keyword] = STATE(3060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(921),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(527),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(541),
    [sym_date_literal] = ACTIONS(531),
    [sym_time_literal] = ACTIONS(531),
    [sym_biginteger_literal] = ACTIONS(541),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_EXIT] = ACTIONS(543),
    [anon_sym_Exit] = ACTIONS(543),
    [anon_sym_continue] = ACTIONS(545),
    [anon_sym_CONTINUE] = ACTIONS(545),
    [anon_sym_Continue] = ACTIONS(545),
    [anon_sym_break] = ACTIONS(547),
    [anon_sym_BREAK] = ACTIONS(547),
    [anon_sym_Break] = ACTIONS(547),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(549),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(541),
    [sym_integer] = ACTIONS(531),
    [sym_continue_as_identifier] = ACTIONS(541),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(935)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_elif] = STATE(948),
    [sym_preproc_else] = STATE(1047),
    [sym_preproc_endif] = STATE(2522),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [aux_sym_preproc_conditional_object_repeat1] = STATE(7779),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(1547),
    [anon_sym_POUNDELIF] = ACTIONS(1547),
    [anon_sym_POUNDElif] = ACTIONS(1547),
    [anon_sym_POUNDelse] = ACTIONS(1549),
    [anon_sym_POUNDELSE] = ACTIONS(1549),
    [anon_sym_POUNDElse] = ACTIONS(1549),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(936)] = {
    [sym_preproc_conditional_object] = STATE(938),
    [sym_using_statement] = STATE(938),
    [sym__object] = STATE(938),
    [sym_preproc_split_declaration] = STATE(938),
    [sym_table_declaration] = STATE(938),
    [sym_page_declaration] = STATE(938),
    [sym_report_declaration] = STATE(938),
    [sym_query_declaration] = STATE(938),
    [sym_xmlport_declaration] = STATE(938),
    [sym_permissionset_declaration] = STATE(938),
    [sym_codeunit_declaration] = STATE(938),
    [sym_enum_declaration] = STATE(938),
    [sym_tableextension_declaration] = STATE(938),
    [sym_pageextension_declaration] = STATE(938),
    [sym_reportextension_declaration] = STATE(938),
    [sym_enumextension_declaration] = STATE(938),
    [sym_permissionsetextension_declaration] = STATE(938),
    [sym_controladdin_declaration] = STATE(938),
    [sym_profile_declaration] = STATE(938),
    [sym_entitlement_declaration] = STATE(938),
    [sym_profileextension_declaration] = STATE(938),
    [sym_interface_declaration] = STATE(938),
    [sym_pagecustomization_declaration] = STATE(938),
    [sym_dotnet_declaration] = STATE(938),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_elif] = STATE(948),
    [sym_preproc_else] = STATE(1047),
    [sym_preproc_endif] = STATE(2522),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(938),
    [aux_sym_preproc_conditional_object_repeat1] = STATE(7779),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(1547),
    [anon_sym_POUNDELIF] = ACTIONS(1547),
    [anon_sym_POUNDElif] = ACTIONS(1547),
    [anon_sym_POUNDelse] = ACTIONS(1549),
    [anon_sym_POUNDELSE] = ACTIONS(1549),
    [anon_sym_POUNDElse] = ACTIONS(1549),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(937)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_elif] = STATE(948),
    [sym_preproc_else] = STATE(1046),
    [sym_preproc_endif] = STATE(1959),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [aux_sym_preproc_conditional_object_repeat1] = STATE(7850),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(1547),
    [anon_sym_POUNDELIF] = ACTIONS(1547),
    [anon_sym_POUNDElif] = ACTIONS(1547),
    [anon_sym_POUNDelse] = ACTIONS(1549),
    [anon_sym_POUNDELSE] = ACTIONS(1549),
    [anon_sym_POUNDElse] = ACTIONS(1549),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(938)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_elif] = STATE(948),
    [sym_preproc_else] = STATE(1041),
    [sym_preproc_endif] = STATE(2496),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [aux_sym_preproc_conditional_object_repeat1] = STATE(7910),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(1547),
    [anon_sym_POUNDELIF] = ACTIONS(1547),
    [anon_sym_POUNDElif] = ACTIONS(1547),
    [anon_sym_POUNDelse] = ACTIONS(1549),
    [anon_sym_POUNDELSE] = ACTIONS(1549),
    [anon_sym_POUNDElse] = ACTIONS(1549),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(939)] = {
    [sym_preproc_conditional_object] = STATE(937),
    [sym_using_statement] = STATE(937),
    [sym__object] = STATE(937),
    [sym_preproc_split_declaration] = STATE(937),
    [sym_table_declaration] = STATE(937),
    [sym_page_declaration] = STATE(937),
    [sym_report_declaration] = STATE(937),
    [sym_query_declaration] = STATE(937),
    [sym_xmlport_declaration] = STATE(937),
    [sym_permissionset_declaration] = STATE(937),
    [sym_codeunit_declaration] = STATE(937),
    [sym_enum_declaration] = STATE(937),
    [sym_tableextension_declaration] = STATE(937),
    [sym_pageextension_declaration] = STATE(937),
    [sym_reportextension_declaration] = STATE(937),
    [sym_enumextension_declaration] = STATE(937),
    [sym_permissionsetextension_declaration] = STATE(937),
    [sym_controladdin_declaration] = STATE(937),
    [sym_profile_declaration] = STATE(937),
    [sym_entitlement_declaration] = STATE(937),
    [sym_profileextension_declaration] = STATE(937),
    [sym_interface_declaration] = STATE(937),
    [sym_pagecustomization_declaration] = STATE(937),
    [sym_dotnet_declaration] = STATE(937),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_elif] = STATE(948),
    [sym_preproc_else] = STATE(1048),
    [sym_preproc_endif] = STATE(1953),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(937),
    [aux_sym_preproc_conditional_object_repeat1] = STATE(7848),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(1547),
    [anon_sym_POUNDELIF] = ACTIONS(1547),
    [anon_sym_POUNDElif] = ACTIONS(1547),
    [anon_sym_POUNDelse] = ACTIONS(1549),
    [anon_sym_POUNDELSE] = ACTIONS(1549),
    [anon_sym_POUNDElse] = ACTIONS(1549),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(940)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_elif] = STATE(948),
    [sym_preproc_else] = STATE(1048),
    [sym_preproc_endif] = STATE(1953),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [aux_sym_preproc_conditional_object_repeat1] = STATE(7848),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(1547),
    [anon_sym_POUNDELIF] = ACTIONS(1547),
    [anon_sym_POUNDElif] = ACTIONS(1547),
    [anon_sym_POUNDelse] = ACTIONS(1549),
    [anon_sym_POUNDELSE] = ACTIONS(1549),
    [anon_sym_POUNDElse] = ACTIONS(1549),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(941)] = {
    [sym__property_value] = STATE(11964),
    [sym_decimal_range_value] = STATE(11964),
    [sym_signed_integer_list] = STATE(11964),
    [sym__signed_integer] = STATE(11220),
    [sym_object_reference_value] = STATE(11964),
    [sym_property_expression] = STATE(11964),
    [sym_boolean] = STATE(6352),
    [sym_caption_value] = STATE(11964),
    [sym_ml_value_list] = STATE(11964),
    [sym_ml_value_pair] = STATE(10906),
    [sym__calc_formula_expression] = STATE(11964),
    [sym_lookup_formula] = STATE(11964),
    [sym_aggregate_formula] = STATE(11964),
    [sym_where_clause] = STATE(11964),
    [sym_sorting_value] = STATE(11964),
    [sym_link_value_list] = STATE(11964),
    [sym_preproc_conditional_link_values] = STATE(7337),
    [sym_link_value] = STATE(7624),
    [sym_table_relation_value] = STATE(11964),
    [sym_preproc_conditional_table_relation] = STATE(12050),
    [sym_table_relation_expression] = STATE(12090),
    [sym_if_table_relation] = STATE(12091),
    [sym_simple_table_relation] = STATE(12091),
    [sym_tabledata_permission_list] = STATE(11964),
    [sym_preproc_conditional_permissions] = STATE(7010),
    [sym_tabledata_permission] = STATE(7218),
    [sym_order_by_list] = STATE(11964),
    [sym_order_by_item] = STATE(10949),
    [sym_implementation_value_list] = STATE(11964),
    [sym_preproc_conditional_impl_values] = STATE(7340),
    [sym_implementation_value] = STATE(7583),
    [sym_option_member_list] = STATE(11964),
    [sym_option_member] = STATE(9302),
    [sym__namespaced_or_simple_ref] = STATE(10231),
    [sym_preproc_if] = STATE(1257),
    [sym_assignment_expression] = STATE(6355),
    [sym__expression] = STATE(6355),
    [sym_keyword_identifier] = STATE(6207),
    [sym_range_expression] = STATE(6355),
    [sym_multiplicative_expression] = STATE(6371),
    [sym_additive_expression] = STATE(6371),
    [sym_comparison_expression] = STATE(6371),
    [sym_logical_expression] = STATE(6371),
    [sym_ternary_expression] = STATE(6355),
    [sym_unary_expression] = STATE(6371),
    [sym_call_expression] = STATE(6356),
    [sym_member_expression] = STATE(6127),
    [sym_subscript_expression] = STATE(6265),
    [sym_parenthesized_expression] = STATE(6371),
    [sym_list_literal] = STATE(6355),
    [sym_qualified_enum_value] = STATE(6265),
    [sym_database_reference] = STATE(6371),
    [sym__literal_value] = STATE(6355),
    [sym_codeunit_keyword] = STATE(4782),
    [sym_xmlport_keyword] = STATE(4782),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(9699),
    [sym_keyword_as_identifier] = STATE(9711),
    [aux_sym_link_value_list_repeat1] = STATE(7337),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(7010),
    [aux_sym_implementation_value_list_repeat1] = STATE(7340),
    [aux_sym_option_member_list_repeat2] = STATE(4624),
    [sym_identifier] = ACTIONS(2195),
    [anon_sym_SEMI] = ACTIONS(2197),
    [anon_sym_COMMA] = ACTIONS(2199),
    [anon_sym_DASH] = ACTIONS(2201),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(2203),
    [aux_sym_lookup_formula_token1] = ACTIONS(2205),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_clause_token1] = ACTIONS(2207),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_sorting_value_token1] = ACTIONS(2211),
    [aux_sym_if_table_relation_token1] = ACTIONS(2213),
    [aux_sym_tabledata_permission_token1] = ACTIONS(2215),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2217),
    [aux_sym_order_by_item_token1] = ACTIONS(2219),
    [aux_sym_order_by_item_token2] = ACTIONS(2219),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(2221),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(2231),
    [sym_date_literal] = ACTIONS(2203),
    [sym_time_literal] = ACTIONS(2203),
    [sym_biginteger_literal] = ACTIONS(2233),
    [sym_table_keyword] = ACTIONS(2235),
    [sym_page_keyword] = ACTIONS(2237),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2237),
    [sym_query_keyword] = ACTIONS(2237),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(2239),
    [sym_internal_keyword] = ACTIONS(2239),
    [sym_protected_keyword] = ACTIONS(2239),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_quoted_identifier] = ACTIONS(2241),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2243),
    [sym_integer] = ACTIONS(2245),
    [sym_continue_as_identifier] = ACTIONS(2233),
    [sym_preproc_open] = ACTIONS(2223),
  },
  [STATE(942)] = {
    [sym__property_value] = STATE(11966),
    [sym_decimal_range_value] = STATE(11966),
    [sym_signed_integer_list] = STATE(11966),
    [sym__signed_integer] = STATE(11220),
    [sym_object_reference_value] = STATE(11966),
    [sym_property_expression] = STATE(11966),
    [sym_boolean] = STATE(6352),
    [sym_caption_value] = STATE(11966),
    [sym_ml_value_list] = STATE(11966),
    [sym_ml_value_pair] = STATE(10906),
    [sym__calc_formula_expression] = STATE(11966),
    [sym_lookup_formula] = STATE(11966),
    [sym_aggregate_formula] = STATE(11966),
    [sym_where_clause] = STATE(11966),
    [sym_sorting_value] = STATE(11966),
    [sym_link_value_list] = STATE(11966),
    [sym_preproc_conditional_link_values] = STATE(7337),
    [sym_link_value] = STATE(7624),
    [sym_table_relation_value] = STATE(11966),
    [sym_preproc_conditional_table_relation] = STATE(12050),
    [sym_table_relation_expression] = STATE(12090),
    [sym_if_table_relation] = STATE(12091),
    [sym_simple_table_relation] = STATE(12091),
    [sym_tabledata_permission_list] = STATE(11966),
    [sym_preproc_conditional_permissions] = STATE(7010),
    [sym_tabledata_permission] = STATE(7218),
    [sym_order_by_list] = STATE(11966),
    [sym_order_by_item] = STATE(10949),
    [sym_implementation_value_list] = STATE(11966),
    [sym_preproc_conditional_impl_values] = STATE(7340),
    [sym_implementation_value] = STATE(7583),
    [sym_option_member_list] = STATE(11966),
    [sym_option_member] = STATE(9302),
    [sym__namespaced_or_simple_ref] = STATE(10231),
    [sym_preproc_if] = STATE(1257),
    [sym_assignment_expression] = STATE(6355),
    [sym__expression] = STATE(6355),
    [sym_keyword_identifier] = STATE(6207),
    [sym_range_expression] = STATE(6355),
    [sym_multiplicative_expression] = STATE(6371),
    [sym_additive_expression] = STATE(6371),
    [sym_comparison_expression] = STATE(6371),
    [sym_logical_expression] = STATE(6371),
    [sym_ternary_expression] = STATE(6355),
    [sym_unary_expression] = STATE(6371),
    [sym_call_expression] = STATE(6356),
    [sym_member_expression] = STATE(6127),
    [sym_subscript_expression] = STATE(6265),
    [sym_parenthesized_expression] = STATE(6371),
    [sym_list_literal] = STATE(6355),
    [sym_qualified_enum_value] = STATE(6265),
    [sym_database_reference] = STATE(6371),
    [sym__literal_value] = STATE(6355),
    [sym_codeunit_keyword] = STATE(4782),
    [sym_xmlport_keyword] = STATE(4782),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(9699),
    [sym_keyword_as_identifier] = STATE(9711),
    [aux_sym_link_value_list_repeat1] = STATE(7337),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(7010),
    [aux_sym_implementation_value_list_repeat1] = STATE(7340),
    [aux_sym_option_member_list_repeat2] = STATE(4624),
    [sym_identifier] = ACTIONS(2195),
    [anon_sym_SEMI] = ACTIONS(2247),
    [anon_sym_COMMA] = ACTIONS(2199),
    [anon_sym_DASH] = ACTIONS(2201),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(2203),
    [aux_sym_lookup_formula_token1] = ACTIONS(2205),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_clause_token1] = ACTIONS(2207),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_sorting_value_token1] = ACTIONS(2211),
    [aux_sym_if_table_relation_token1] = ACTIONS(2213),
    [aux_sym_tabledata_permission_token1] = ACTIONS(2215),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2217),
    [aux_sym_order_by_item_token1] = ACTIONS(2219),
    [aux_sym_order_by_item_token2] = ACTIONS(2219),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(2221),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(2231),
    [sym_date_literal] = ACTIONS(2203),
    [sym_time_literal] = ACTIONS(2203),
    [sym_biginteger_literal] = ACTIONS(2233),
    [sym_table_keyword] = ACTIONS(2235),
    [sym_page_keyword] = ACTIONS(2237),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2237),
    [sym_query_keyword] = ACTIONS(2237),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(2239),
    [sym_internal_keyword] = ACTIONS(2239),
    [sym_protected_keyword] = ACTIONS(2239),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_quoted_identifier] = ACTIONS(2241),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2243),
    [sym_integer] = ACTIONS(2245),
    [sym_continue_as_identifier] = ACTIONS(2233),
    [sym_preproc_open] = ACTIONS(2223),
  },
  [STATE(943)] = {
    [sym__property_value] = STATE(12101),
    [sym_decimal_range_value] = STATE(12101),
    [sym_signed_integer_list] = STATE(12101),
    [sym__signed_integer] = STATE(11220),
    [sym_object_reference_value] = STATE(12101),
    [sym_property_expression] = STATE(12101),
    [sym_boolean] = STATE(6352),
    [sym_caption_value] = STATE(12101),
    [sym_ml_value_list] = STATE(12101),
    [sym_ml_value_pair] = STATE(10906),
    [sym__calc_formula_expression] = STATE(12101),
    [sym_lookup_formula] = STATE(12101),
    [sym_aggregate_formula] = STATE(12101),
    [sym_where_clause] = STATE(12101),
    [sym_sorting_value] = STATE(12101),
    [sym_link_value_list] = STATE(12101),
    [sym_preproc_conditional_link_values] = STATE(7337),
    [sym_link_value] = STATE(7624),
    [sym_table_relation_value] = STATE(12101),
    [sym_preproc_conditional_table_relation] = STATE(12050),
    [sym_table_relation_expression] = STATE(12090),
    [sym_if_table_relation] = STATE(12091),
    [sym_simple_table_relation] = STATE(12091),
    [sym_tabledata_permission_list] = STATE(12101),
    [sym_preproc_conditional_permissions] = STATE(7010),
    [sym_tabledata_permission] = STATE(7218),
    [sym_order_by_list] = STATE(12101),
    [sym_order_by_item] = STATE(10949),
    [sym_implementation_value_list] = STATE(12101),
    [sym_preproc_conditional_impl_values] = STATE(7340),
    [sym_implementation_value] = STATE(7583),
    [sym_option_member_list] = STATE(12101),
    [sym_option_member] = STATE(9302),
    [sym__namespaced_or_simple_ref] = STATE(10231),
    [sym_preproc_if] = STATE(1257),
    [sym_assignment_expression] = STATE(6355),
    [sym__expression] = STATE(6355),
    [sym_keyword_identifier] = STATE(6207),
    [sym_range_expression] = STATE(6355),
    [sym_multiplicative_expression] = STATE(6371),
    [sym_additive_expression] = STATE(6371),
    [sym_comparison_expression] = STATE(6371),
    [sym_logical_expression] = STATE(6371),
    [sym_ternary_expression] = STATE(6355),
    [sym_unary_expression] = STATE(6371),
    [sym_call_expression] = STATE(6356),
    [sym_member_expression] = STATE(6127),
    [sym_subscript_expression] = STATE(6265),
    [sym_parenthesized_expression] = STATE(6371),
    [sym_list_literal] = STATE(6355),
    [sym_qualified_enum_value] = STATE(6265),
    [sym_database_reference] = STATE(6371),
    [sym__literal_value] = STATE(6355),
    [sym_codeunit_keyword] = STATE(4782),
    [sym_xmlport_keyword] = STATE(4782),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(9699),
    [sym_keyword_as_identifier] = STATE(9711),
    [aux_sym_link_value_list_repeat1] = STATE(7337),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(7010),
    [aux_sym_implementation_value_list_repeat1] = STATE(7340),
    [aux_sym_option_member_list_repeat2] = STATE(4624),
    [sym_identifier] = ACTIONS(2195),
    [anon_sym_SEMI] = ACTIONS(2249),
    [anon_sym_COMMA] = ACTIONS(2199),
    [anon_sym_DASH] = ACTIONS(2201),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(2203),
    [aux_sym_lookup_formula_token1] = ACTIONS(2205),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_clause_token1] = ACTIONS(2207),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_sorting_value_token1] = ACTIONS(2211),
    [aux_sym_if_table_relation_token1] = ACTIONS(2213),
    [aux_sym_tabledata_permission_token1] = ACTIONS(2215),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2217),
    [aux_sym_order_by_item_token1] = ACTIONS(2219),
    [aux_sym_order_by_item_token2] = ACTIONS(2219),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(2221),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(2231),
    [sym_date_literal] = ACTIONS(2203),
    [sym_time_literal] = ACTIONS(2203),
    [sym_biginteger_literal] = ACTIONS(2233),
    [sym_table_keyword] = ACTIONS(2235),
    [sym_page_keyword] = ACTIONS(2237),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2237),
    [sym_query_keyword] = ACTIONS(2237),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(2239),
    [sym_internal_keyword] = ACTIONS(2239),
    [sym_protected_keyword] = ACTIONS(2239),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_quoted_identifier] = ACTIONS(2241),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2243),
    [sym_integer] = ACTIONS(2245),
    [sym_continue_as_identifier] = ACTIONS(2233),
    [sym_preproc_open] = ACTIONS(2223),
  },
  [STATE(944)] = {
    [sym__property_value] = STATE(12058),
    [sym_decimal_range_value] = STATE(12058),
    [sym_signed_integer_list] = STATE(12058),
    [sym__signed_integer] = STATE(11220),
    [sym_object_reference_value] = STATE(12058),
    [sym_property_expression] = STATE(12058),
    [sym_boolean] = STATE(6352),
    [sym_caption_value] = STATE(12058),
    [sym_ml_value_list] = STATE(12058),
    [sym_ml_value_pair] = STATE(10906),
    [sym__calc_formula_expression] = STATE(12058),
    [sym_lookup_formula] = STATE(12058),
    [sym_aggregate_formula] = STATE(12058),
    [sym_where_clause] = STATE(12058),
    [sym_sorting_value] = STATE(12058),
    [sym_link_value_list] = STATE(12058),
    [sym_preproc_conditional_link_values] = STATE(7337),
    [sym_link_value] = STATE(7624),
    [sym_table_relation_value] = STATE(12058),
    [sym_preproc_conditional_table_relation] = STATE(12050),
    [sym_table_relation_expression] = STATE(12090),
    [sym_if_table_relation] = STATE(12091),
    [sym_simple_table_relation] = STATE(12091),
    [sym_tabledata_permission_list] = STATE(12058),
    [sym_preproc_conditional_permissions] = STATE(7010),
    [sym_tabledata_permission] = STATE(7218),
    [sym_order_by_list] = STATE(12058),
    [sym_order_by_item] = STATE(10949),
    [sym_implementation_value_list] = STATE(12058),
    [sym_preproc_conditional_impl_values] = STATE(7340),
    [sym_implementation_value] = STATE(7583),
    [sym_option_member_list] = STATE(12058),
    [sym_option_member] = STATE(9302),
    [sym__namespaced_or_simple_ref] = STATE(10231),
    [sym_preproc_if] = STATE(1257),
    [sym_assignment_expression] = STATE(6355),
    [sym__expression] = STATE(6355),
    [sym_keyword_identifier] = STATE(6207),
    [sym_range_expression] = STATE(6355),
    [sym_multiplicative_expression] = STATE(6371),
    [sym_additive_expression] = STATE(6371),
    [sym_comparison_expression] = STATE(6371),
    [sym_logical_expression] = STATE(6371),
    [sym_ternary_expression] = STATE(6355),
    [sym_unary_expression] = STATE(6371),
    [sym_call_expression] = STATE(6356),
    [sym_member_expression] = STATE(6127),
    [sym_subscript_expression] = STATE(6265),
    [sym_parenthesized_expression] = STATE(6371),
    [sym_list_literal] = STATE(6355),
    [sym_qualified_enum_value] = STATE(6265),
    [sym_database_reference] = STATE(6371),
    [sym__literal_value] = STATE(6355),
    [sym_codeunit_keyword] = STATE(4782),
    [sym_xmlport_keyword] = STATE(4782),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(9699),
    [sym_keyword_as_identifier] = STATE(9711),
    [aux_sym_link_value_list_repeat1] = STATE(7337),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(7010),
    [aux_sym_implementation_value_list_repeat1] = STATE(7340),
    [aux_sym_option_member_list_repeat2] = STATE(4624),
    [sym_identifier] = ACTIONS(2195),
    [anon_sym_SEMI] = ACTIONS(2251),
    [anon_sym_COMMA] = ACTIONS(2199),
    [anon_sym_DASH] = ACTIONS(2201),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(2203),
    [aux_sym_lookup_formula_token1] = ACTIONS(2205),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_clause_token1] = ACTIONS(2207),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_sorting_value_token1] = ACTIONS(2211),
    [aux_sym_if_table_relation_token1] = ACTIONS(2213),
    [aux_sym_tabledata_permission_token1] = ACTIONS(2215),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2217),
    [aux_sym_order_by_item_token1] = ACTIONS(2219),
    [aux_sym_order_by_item_token2] = ACTIONS(2219),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(2221),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(2231),
    [sym_date_literal] = ACTIONS(2203),
    [sym_time_literal] = ACTIONS(2203),
    [sym_biginteger_literal] = ACTIONS(2233),
    [sym_table_keyword] = ACTIONS(2235),
    [sym_page_keyword] = ACTIONS(2237),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2237),
    [sym_query_keyword] = ACTIONS(2237),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(2239),
    [sym_internal_keyword] = ACTIONS(2239),
    [sym_protected_keyword] = ACTIONS(2239),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_quoted_identifier] = ACTIONS(2241),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2243),
    [sym_integer] = ACTIONS(2245),
    [sym_continue_as_identifier] = ACTIONS(2233),
    [sym_preproc_open] = ACTIONS(2223),
  },
  [STATE(945)] = {
    [sym__property_value] = STATE(11537),
    [sym_decimal_range_value] = STATE(11537),
    [sym_signed_integer_list] = STATE(11537),
    [sym__signed_integer] = STATE(11220),
    [sym_object_reference_value] = STATE(11537),
    [sym_property_expression] = STATE(11537),
    [sym_boolean] = STATE(6352),
    [sym_caption_value] = STATE(11537),
    [sym_ml_value_list] = STATE(11537),
    [sym_ml_value_pair] = STATE(10906),
    [sym__calc_formula_expression] = STATE(11537),
    [sym_lookup_formula] = STATE(11537),
    [sym_aggregate_formula] = STATE(11537),
    [sym_where_clause] = STATE(11537),
    [sym_sorting_value] = STATE(11537),
    [sym_link_value_list] = STATE(11537),
    [sym_preproc_conditional_link_values] = STATE(7337),
    [sym_link_value] = STATE(7624),
    [sym_table_relation_value] = STATE(11537),
    [sym_preproc_conditional_table_relation] = STATE(12050),
    [sym_table_relation_expression] = STATE(12090),
    [sym_if_table_relation] = STATE(12091),
    [sym_simple_table_relation] = STATE(12091),
    [sym_tabledata_permission_list] = STATE(11537),
    [sym_preproc_conditional_permissions] = STATE(7010),
    [sym_tabledata_permission] = STATE(7218),
    [sym_order_by_list] = STATE(11537),
    [sym_order_by_item] = STATE(10949),
    [sym_implementation_value_list] = STATE(11537),
    [sym_preproc_conditional_impl_values] = STATE(7340),
    [sym_implementation_value] = STATE(7583),
    [sym_option_member_list] = STATE(11537),
    [sym_option_member] = STATE(9302),
    [sym__namespaced_or_simple_ref] = STATE(10231),
    [sym_preproc_if] = STATE(1257),
    [sym_assignment_expression] = STATE(6355),
    [sym__expression] = STATE(6355),
    [sym_keyword_identifier] = STATE(6207),
    [sym_range_expression] = STATE(6355),
    [sym_multiplicative_expression] = STATE(6371),
    [sym_additive_expression] = STATE(6371),
    [sym_comparison_expression] = STATE(6371),
    [sym_logical_expression] = STATE(6371),
    [sym_ternary_expression] = STATE(6355),
    [sym_unary_expression] = STATE(6371),
    [sym_call_expression] = STATE(6356),
    [sym_member_expression] = STATE(6127),
    [sym_subscript_expression] = STATE(6265),
    [sym_parenthesized_expression] = STATE(6371),
    [sym_list_literal] = STATE(6355),
    [sym_qualified_enum_value] = STATE(6265),
    [sym_database_reference] = STATE(6371),
    [sym__literal_value] = STATE(6355),
    [sym_codeunit_keyword] = STATE(4782),
    [sym_xmlport_keyword] = STATE(4782),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(9699),
    [sym_keyword_as_identifier] = STATE(9711),
    [aux_sym_link_value_list_repeat1] = STATE(7337),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(7010),
    [aux_sym_implementation_value_list_repeat1] = STATE(7340),
    [aux_sym_option_member_list_repeat2] = STATE(4624),
    [sym_identifier] = ACTIONS(2195),
    [anon_sym_SEMI] = ACTIONS(2253),
    [anon_sym_COMMA] = ACTIONS(2199),
    [anon_sym_DASH] = ACTIONS(2201),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(2203),
    [aux_sym_lookup_formula_token1] = ACTIONS(2205),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_clause_token1] = ACTIONS(2207),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_sorting_value_token1] = ACTIONS(2211),
    [aux_sym_if_table_relation_token1] = ACTIONS(2213),
    [aux_sym_tabledata_permission_token1] = ACTIONS(2215),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2217),
    [aux_sym_order_by_item_token1] = ACTIONS(2219),
    [aux_sym_order_by_item_token2] = ACTIONS(2219),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(2221),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(2231),
    [sym_date_literal] = ACTIONS(2203),
    [sym_time_literal] = ACTIONS(2203),
    [sym_biginteger_literal] = ACTIONS(2233),
    [sym_table_keyword] = ACTIONS(2235),
    [sym_page_keyword] = ACTIONS(2237),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2237),
    [sym_query_keyword] = ACTIONS(2237),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(2239),
    [sym_internal_keyword] = ACTIONS(2239),
    [sym_protected_keyword] = ACTIONS(2239),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_quoted_identifier] = ACTIONS(2241),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2243),
    [sym_integer] = ACTIONS(2245),
    [sym_continue_as_identifier] = ACTIONS(2233),
    [sym_preproc_open] = ACTIONS(2223),
  },
  [STATE(946)] = {
    [sym__property_value] = STATE(12466),
    [sym_decimal_range_value] = STATE(12466),
    [sym_signed_integer_list] = STATE(12466),
    [sym__signed_integer] = STATE(11220),
    [sym_object_reference_value] = STATE(12466),
    [sym_property_expression] = STATE(12466),
    [sym_boolean] = STATE(6352),
    [sym_caption_value] = STATE(12466),
    [sym_ml_value_list] = STATE(12466),
    [sym_ml_value_pair] = STATE(10906),
    [sym__calc_formula_expression] = STATE(12466),
    [sym_lookup_formula] = STATE(12466),
    [sym_aggregate_formula] = STATE(12466),
    [sym_where_clause] = STATE(12466),
    [sym_sorting_value] = STATE(12466),
    [sym_link_value_list] = STATE(12466),
    [sym_preproc_conditional_link_values] = STATE(7337),
    [sym_link_value] = STATE(7624),
    [sym_table_relation_value] = STATE(12466),
    [sym_preproc_conditional_table_relation] = STATE(12050),
    [sym_table_relation_expression] = STATE(12090),
    [sym_if_table_relation] = STATE(12091),
    [sym_simple_table_relation] = STATE(12091),
    [sym_tabledata_permission_list] = STATE(12466),
    [sym_preproc_conditional_permissions] = STATE(7010),
    [sym_tabledata_permission] = STATE(7218),
    [sym_order_by_list] = STATE(12466),
    [sym_order_by_item] = STATE(10949),
    [sym_implementation_value_list] = STATE(12466),
    [sym_preproc_conditional_impl_values] = STATE(7340),
    [sym_implementation_value] = STATE(7583),
    [sym_option_member_list] = STATE(12466),
    [sym_option_member] = STATE(9302),
    [sym__namespaced_or_simple_ref] = STATE(10231),
    [sym_preproc_if] = STATE(1257),
    [sym_assignment_expression] = STATE(6355),
    [sym__expression] = STATE(6355),
    [sym_keyword_identifier] = STATE(6207),
    [sym_range_expression] = STATE(6355),
    [sym_multiplicative_expression] = STATE(6371),
    [sym_additive_expression] = STATE(6371),
    [sym_comparison_expression] = STATE(6371),
    [sym_logical_expression] = STATE(6371),
    [sym_ternary_expression] = STATE(6355),
    [sym_unary_expression] = STATE(6371),
    [sym_call_expression] = STATE(6356),
    [sym_member_expression] = STATE(6127),
    [sym_subscript_expression] = STATE(6265),
    [sym_parenthesized_expression] = STATE(6371),
    [sym_list_literal] = STATE(6355),
    [sym_qualified_enum_value] = STATE(6265),
    [sym_database_reference] = STATE(6371),
    [sym__literal_value] = STATE(6355),
    [sym_codeunit_keyword] = STATE(4782),
    [sym_xmlport_keyword] = STATE(4782),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(9699),
    [sym_keyword_as_identifier] = STATE(9711),
    [aux_sym_link_value_list_repeat1] = STATE(7337),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(7010),
    [aux_sym_implementation_value_list_repeat1] = STATE(7340),
    [aux_sym_option_member_list_repeat2] = STATE(4624),
    [sym_identifier] = ACTIONS(2195),
    [anon_sym_SEMI] = ACTIONS(2255),
    [anon_sym_COMMA] = ACTIONS(2199),
    [anon_sym_DASH] = ACTIONS(2201),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(2203),
    [aux_sym_lookup_formula_token1] = ACTIONS(2205),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_clause_token1] = ACTIONS(2207),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_sorting_value_token1] = ACTIONS(2211),
    [aux_sym_if_table_relation_token1] = ACTIONS(2213),
    [aux_sym_tabledata_permission_token1] = ACTIONS(2215),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2217),
    [aux_sym_order_by_item_token1] = ACTIONS(2219),
    [aux_sym_order_by_item_token2] = ACTIONS(2219),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(2221),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(2231),
    [sym_date_literal] = ACTIONS(2203),
    [sym_time_literal] = ACTIONS(2203),
    [sym_biginteger_literal] = ACTIONS(2233),
    [sym_table_keyword] = ACTIONS(2235),
    [sym_page_keyword] = ACTIONS(2237),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2237),
    [sym_query_keyword] = ACTIONS(2237),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(2239),
    [sym_internal_keyword] = ACTIONS(2239),
    [sym_protected_keyword] = ACTIONS(2239),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_quoted_identifier] = ACTIONS(2241),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2243),
    [sym_integer] = ACTIONS(2245),
    [sym_continue_as_identifier] = ACTIONS(2233),
    [sym_preproc_open] = ACTIONS(2223),
  },
  [STATE(947)] = {
    [sym__property_value] = STATE(12446),
    [sym_decimal_range_value] = STATE(12446),
    [sym_signed_integer_list] = STATE(12446),
    [sym__signed_integer] = STATE(11220),
    [sym_object_reference_value] = STATE(12446),
    [sym_property_expression] = STATE(12446),
    [sym_boolean] = STATE(6352),
    [sym_caption_value] = STATE(12446),
    [sym_ml_value_list] = STATE(12446),
    [sym_ml_value_pair] = STATE(10906),
    [sym__calc_formula_expression] = STATE(12446),
    [sym_lookup_formula] = STATE(12446),
    [sym_aggregate_formula] = STATE(12446),
    [sym_where_clause] = STATE(12446),
    [sym_sorting_value] = STATE(12446),
    [sym_link_value_list] = STATE(12446),
    [sym_preproc_conditional_link_values] = STATE(7337),
    [sym_link_value] = STATE(7624),
    [sym_table_relation_value] = STATE(12446),
    [sym_preproc_conditional_table_relation] = STATE(12050),
    [sym_table_relation_expression] = STATE(12090),
    [sym_if_table_relation] = STATE(12091),
    [sym_simple_table_relation] = STATE(12091),
    [sym_tabledata_permission_list] = STATE(12446),
    [sym_preproc_conditional_permissions] = STATE(7010),
    [sym_tabledata_permission] = STATE(7218),
    [sym_order_by_list] = STATE(12446),
    [sym_order_by_item] = STATE(10949),
    [sym_implementation_value_list] = STATE(12446),
    [sym_preproc_conditional_impl_values] = STATE(7340),
    [sym_implementation_value] = STATE(7583),
    [sym_option_member_list] = STATE(12446),
    [sym_option_member] = STATE(9302),
    [sym__namespaced_or_simple_ref] = STATE(10231),
    [sym_preproc_if] = STATE(1257),
    [sym_assignment_expression] = STATE(6355),
    [sym__expression] = STATE(6355),
    [sym_keyword_identifier] = STATE(6207),
    [sym_range_expression] = STATE(6355),
    [sym_multiplicative_expression] = STATE(6371),
    [sym_additive_expression] = STATE(6371),
    [sym_comparison_expression] = STATE(6371),
    [sym_logical_expression] = STATE(6371),
    [sym_ternary_expression] = STATE(6355),
    [sym_unary_expression] = STATE(6371),
    [sym_call_expression] = STATE(6356),
    [sym_member_expression] = STATE(6127),
    [sym_subscript_expression] = STATE(6265),
    [sym_parenthesized_expression] = STATE(6371),
    [sym_list_literal] = STATE(6355),
    [sym_qualified_enum_value] = STATE(6265),
    [sym_database_reference] = STATE(6371),
    [sym__literal_value] = STATE(6355),
    [sym_codeunit_keyword] = STATE(4782),
    [sym_xmlport_keyword] = STATE(4782),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(9699),
    [sym_keyword_as_identifier] = STATE(9711),
    [aux_sym_link_value_list_repeat1] = STATE(7337),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(7010),
    [aux_sym_implementation_value_list_repeat1] = STATE(7340),
    [aux_sym_option_member_list_repeat2] = STATE(4624),
    [sym_identifier] = ACTIONS(2195),
    [anon_sym_SEMI] = ACTIONS(2257),
    [anon_sym_COMMA] = ACTIONS(2199),
    [anon_sym_DASH] = ACTIONS(2201),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(2203),
    [aux_sym_lookup_formula_token1] = ACTIONS(2205),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_clause_token1] = ACTIONS(2207),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_sorting_value_token1] = ACTIONS(2211),
    [aux_sym_if_table_relation_token1] = ACTIONS(2213),
    [aux_sym_tabledata_permission_token1] = ACTIONS(2215),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2217),
    [aux_sym_order_by_item_token1] = ACTIONS(2219),
    [aux_sym_order_by_item_token2] = ACTIONS(2219),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(2221),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(2231),
    [sym_date_literal] = ACTIONS(2203),
    [sym_time_literal] = ACTIONS(2203),
    [sym_biginteger_literal] = ACTIONS(2233),
    [sym_table_keyword] = ACTIONS(2235),
    [sym_page_keyword] = ACTIONS(2237),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2237),
    [sym_query_keyword] = ACTIONS(2237),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(2239),
    [sym_internal_keyword] = ACTIONS(2239),
    [sym_protected_keyword] = ACTIONS(2239),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_quoted_identifier] = ACTIONS(2241),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2243),
    [sym_integer] = ACTIONS(2245),
    [sym_continue_as_identifier] = ACTIONS(2233),
    [sym_preproc_open] = ACTIONS(2223),
  },
  [STATE(948)] = {
    [sym_preproc_conditional_object] = STATE(958),
    [sym_namespace_declaration] = STATE(994),
    [sym_using_statement] = STATE(958),
    [sym__object] = STATE(958),
    [sym_preproc_split_declaration] = STATE(958),
    [sym_table_declaration] = STATE(958),
    [sym_page_declaration] = STATE(958),
    [sym_report_declaration] = STATE(958),
    [sym_query_declaration] = STATE(958),
    [sym_xmlport_declaration] = STATE(958),
    [sym_permissionset_declaration] = STATE(958),
    [sym_codeunit_declaration] = STATE(958),
    [sym_enum_declaration] = STATE(958),
    [sym_tableextension_declaration] = STATE(958),
    [sym_pageextension_declaration] = STATE(958),
    [sym_reportextension_declaration] = STATE(958),
    [sym_enumextension_declaration] = STATE(958),
    [sym_permissionsetextension_declaration] = STATE(958),
    [sym_controladdin_declaration] = STATE(958),
    [sym_profile_declaration] = STATE(958),
    [sym_entitlement_declaration] = STATE(958),
    [sym_profileextension_declaration] = STATE(958),
    [sym_interface_declaration] = STATE(958),
    [sym_pagecustomization_declaration] = STATE(958),
    [sym_dotnet_declaration] = STATE(958),
    [sym_preproc_if] = STATE(616),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(958),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(2259),
    [anon_sym_POUNDELIF] = ACTIONS(2259),
    [anon_sym_POUNDElif] = ACTIONS(2259),
    [anon_sym_POUNDelse] = ACTIONS(2259),
    [anon_sym_POUNDELSE] = ACTIONS(2259),
    [anon_sym_POUNDElse] = ACTIONS(2259),
    [anon_sym_POUNDendif] = ACTIONS(2259),
    [anon_sym_POUNDENDIF] = ACTIONS(2259),
    [anon_sym_POUNDEndif] = ACTIONS(2259),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1567),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(2259),
  },
  [STATE(949)] = {
    [sym__property_value] = STATE(12037),
    [sym_decimal_range_value] = STATE(12037),
    [sym_signed_integer_list] = STATE(12037),
    [sym__signed_integer] = STATE(11220),
    [sym_object_reference_value] = STATE(12037),
    [sym_property_expression] = STATE(12037),
    [sym_boolean] = STATE(6352),
    [sym_caption_value] = STATE(12037),
    [sym_ml_value_list] = STATE(12037),
    [sym_ml_value_pair] = STATE(10906),
    [sym__calc_formula_expression] = STATE(12037),
    [sym_lookup_formula] = STATE(12037),
    [sym_aggregate_formula] = STATE(12037),
    [sym_where_clause] = STATE(12037),
    [sym_sorting_value] = STATE(12037),
    [sym_link_value_list] = STATE(12037),
    [sym_preproc_conditional_link_values] = STATE(7337),
    [sym_link_value] = STATE(7624),
    [sym_table_relation_value] = STATE(12037),
    [sym_preproc_conditional_table_relation] = STATE(12050),
    [sym_table_relation_expression] = STATE(12090),
    [sym_if_table_relation] = STATE(12091),
    [sym_simple_table_relation] = STATE(12091),
    [sym_tabledata_permission_list] = STATE(12037),
    [sym_preproc_conditional_permissions] = STATE(7010),
    [sym_tabledata_permission] = STATE(7218),
    [sym_order_by_list] = STATE(12037),
    [sym_order_by_item] = STATE(10949),
    [sym_implementation_value_list] = STATE(12037),
    [sym_preproc_conditional_impl_values] = STATE(7340),
    [sym_implementation_value] = STATE(7583),
    [sym_option_member_list] = STATE(12037),
    [sym_option_member] = STATE(9302),
    [sym__namespaced_or_simple_ref] = STATE(10231),
    [sym_preproc_if] = STATE(1257),
    [sym_assignment_expression] = STATE(6355),
    [sym__expression] = STATE(6355),
    [sym_keyword_identifier] = STATE(6207),
    [sym_range_expression] = STATE(6355),
    [sym_multiplicative_expression] = STATE(6371),
    [sym_additive_expression] = STATE(6371),
    [sym_comparison_expression] = STATE(6371),
    [sym_logical_expression] = STATE(6371),
    [sym_ternary_expression] = STATE(6355),
    [sym_unary_expression] = STATE(6371),
    [sym_call_expression] = STATE(6356),
    [sym_member_expression] = STATE(6127),
    [sym_subscript_expression] = STATE(6265),
    [sym_parenthesized_expression] = STATE(6371),
    [sym_list_literal] = STATE(6355),
    [sym_qualified_enum_value] = STATE(6265),
    [sym_database_reference] = STATE(6371),
    [sym__literal_value] = STATE(6355),
    [sym_codeunit_keyword] = STATE(4782),
    [sym_xmlport_keyword] = STATE(4782),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(9699),
    [sym_keyword_as_identifier] = STATE(9711),
    [aux_sym_link_value_list_repeat1] = STATE(7337),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(7010),
    [aux_sym_implementation_value_list_repeat1] = STATE(7340),
    [aux_sym_option_member_list_repeat2] = STATE(4624),
    [sym_identifier] = ACTIONS(2195),
    [anon_sym_SEMI] = ACTIONS(2261),
    [anon_sym_COMMA] = ACTIONS(2199),
    [anon_sym_DASH] = ACTIONS(2201),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(2203),
    [aux_sym_lookup_formula_token1] = ACTIONS(2205),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_clause_token1] = ACTIONS(2207),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_sorting_value_token1] = ACTIONS(2211),
    [aux_sym_if_table_relation_token1] = ACTIONS(2213),
    [aux_sym_tabledata_permission_token1] = ACTIONS(2215),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2217),
    [aux_sym_order_by_item_token1] = ACTIONS(2219),
    [aux_sym_order_by_item_token2] = ACTIONS(2219),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(2221),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(2231),
    [sym_date_literal] = ACTIONS(2203),
    [sym_time_literal] = ACTIONS(2203),
    [sym_biginteger_literal] = ACTIONS(2233),
    [sym_table_keyword] = ACTIONS(2235),
    [sym_page_keyword] = ACTIONS(2237),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2237),
    [sym_query_keyword] = ACTIONS(2237),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(2239),
    [sym_internal_keyword] = ACTIONS(2239),
    [sym_protected_keyword] = ACTIONS(2239),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_quoted_identifier] = ACTIONS(2241),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2243),
    [sym_integer] = ACTIONS(2245),
    [sym_continue_as_identifier] = ACTIONS(2233),
    [sym_preproc_open] = ACTIONS(2223),
  },
  [STATE(950)] = {
    [aux_sym_option_member_list_repeat2] = STATE(950),
    [sym_identifier] = ACTIONS(565),
    [anon_sym_SEMI] = ACTIONS(567),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_EQ] = ACTIONS(567),
    [anon_sym_COMMA] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(565),
    [aux_sym_boolean_token1] = ACTIONS(565),
    [aux_sym_boolean_token2] = ACTIONS(565),
    [sym_decimal] = ACTIONS(565),
    [anon_sym_LPAREN] = ACTIONS(567),
    [aux_sym_where_condition_token1] = ACTIONS(565),
    [anon_sym_DOT_DOT] = ACTIONS(567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(565),
    [anon_sym_STAR] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [aux_sym_record_type_token1] = ACTIONS(565),
    [aux_sym_basic_type_token21] = ACTIONS(565),
    [aux_sym_basic_type_token22] = ACTIONS(565),
    [aux_sym_basic_type_token48] = ACTIONS(565),
    [aux_sym_basic_type_token53] = ACTIONS(565),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(565),
    [aux_sym_separator_action_token1] = ACTIONS(565),
    [aux_sym_type_declaration_token1] = ACTIONS(565),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(565),
    [anon_sym_POUNDif] = ACTIONS(567),
    [anon_sym_POUNDIF] = ACTIONS(567),
    [anon_sym_POUNDIf] = ACTIONS(567),
    [anon_sym_not] = ACTIONS(565),
    [anon_sym_NOT] = ACTIONS(565),
    [anon_sym_Not] = ACTIONS(565),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(567),
    [aux_sym__expression_token1] = ACTIONS(567),
    [aux_sym__expression_token2] = ACTIONS(565),
    [aux_sym_keyword_identifier_token1] = ACTIONS(565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(565),
    [anon_sym_SLASH] = ACTIONS(565),
    [anon_sym_div] = ACTIONS(565),
    [anon_sym_DIV] = ACTIONS(565),
    [anon_sym_Div] = ACTIONS(565),
    [anon_sym_mod] = ACTIONS(565),
    [anon_sym_MOD] = ACTIONS(565),
    [anon_sym_Mod] = ACTIONS(565),
    [anon_sym_PLUS] = ACTIONS(565),
    [anon_sym_GT_EQ] = ACTIONS(567),
    [anon_sym_LT_EQ] = ACTIONS(567),
    [anon_sym_GT] = ACTIONS(565),
    [anon_sym_LT] = ACTIONS(565),
    [anon_sym_LT_GT] = ACTIONS(567),
    [anon_sym_and] = ACTIONS(565),
    [anon_sym_AND] = ACTIONS(565),
    [anon_sym_And] = ACTIONS(565),
    [anon_sym_or] = ACTIONS(565),
    [anon_sym_OR] = ACTIONS(565),
    [anon_sym_Or] = ACTIONS(565),
    [anon_sym_xor] = ACTIONS(565),
    [anon_sym_XOR] = ACTIONS(565),
    [anon_sym_Xor] = ACTIONS(565),
    [anon_sym_QMARK] = ACTIONS(567),
    [sym_datetime_literal] = ACTIONS(567),
    [sym_date_literal] = ACTIONS(565),
    [sym_time_literal] = ACTIONS(565),
    [sym_biginteger_literal] = ACTIONS(567),
    [anon_sym_if] = ACTIONS(565),
    [anon_sym_IF] = ACTIONS(565),
    [anon_sym_If] = ACTIONS(565),
    [anon_sym_else] = ACTIONS(565),
    [anon_sym_ELSE] = ACTIONS(565),
    [anon_sym_Else] = ACTIONS(565),
    [anon_sym_case] = ACTIONS(565),
    [anon_sym_CASE] = ACTIONS(565),
    [anon_sym_Case] = ACTIONS(565),
    [anon_sym_for] = ACTIONS(565),
    [anon_sym_FOR] = ACTIONS(565),
    [anon_sym_For] = ACTIONS(565),
    [anon_sym_foreach] = ACTIONS(565),
    [anon_sym_FOREACH] = ACTIONS(565),
    [anon_sym_Foreach] = ACTIONS(565),
    [anon_sym_while] = ACTIONS(565),
    [anon_sym_WHILE] = ACTIONS(565),
    [anon_sym_While] = ACTIONS(565),
    [anon_sym_repeat] = ACTIONS(565),
    [anon_sym_REPEAT] = ACTIONS(565),
    [anon_sym_Repeat] = ACTIONS(565),
    [anon_sym_exit] = ACTIONS(565),
    [anon_sym_EXIT] = ACTIONS(565),
    [anon_sym_Exit] = ACTIONS(565),
    [anon_sym_continue] = ACTIONS(565),
    [anon_sym_CONTINUE] = ACTIONS(565),
    [anon_sym_Continue] = ACTIONS(565),
    [anon_sym_break] = ACTIONS(565),
    [anon_sym_BREAK] = ACTIONS(565),
    [anon_sym_Break] = ACTIONS(565),
    [anon_sym_with] = ACTIONS(565),
    [anon_sym_WITH] = ACTIONS(565),
    [anon_sym_With] = ACTIONS(565),
    [sym_asserterror_keyword] = ACTIONS(567),
    [anon_sym_in] = ACTIONS(565),
    [anon_sym_IN] = ACTIONS(565),
    [anon_sym_In] = ACTIONS(565),
    [sym_page_keyword] = ACTIONS(565),
    [anon_sym_codeunit] = ACTIONS(565),
    [anon_sym_CODEUNIT] = ACTIONS(565),
    [anon_sym_Codeunit] = ACTIONS(565),
    [anon_sym_CodeUnit] = ACTIONS(565),
    [anon_sym_COdeunit] = ACTIONS(565),
    [anon_sym_codeUnit] = ACTIONS(565),
    [sym_report_keyword] = ACTIONS(565),
    [sym_query_keyword] = ACTIONS(565),
    [anon_sym_xmlport] = ACTIONS(565),
    [anon_sym_XMLPORT] = ACTIONS(565),
    [anon_sym_Xmlport] = ACTIONS(565),
    [anon_sym_XMLport] = ACTIONS(565),
    [anon_sym_XMLPort] = ACTIONS(565),
    [anon_sym_XmlPort] = ACTIONS(565),
    [anon_sym_enum] = ACTIONS(565),
    [anon_sym_ENUM] = ACTIONS(565),
    [anon_sym_Enum] = ACTIONS(565),
    [anon_sym_eNUM] = ACTIONS(565),
    [anon_sym_eNum] = ACTIONS(565),
    [anon_sym_ENum] = ACTIONS(565),
    [sym_local_keyword] = ACTIONS(565),
    [sym_internal_keyword] = ACTIONS(565),
    [sym_protected_keyword] = ACTIONS(565),
    [sym_key_keyword] = ACTIONS(565),
    [sym_dataset_keyword] = ACTIONS(565),
    [sym_quoted_identifier] = ACTIONS(567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(567),
    [sym_integer] = ACTIONS(565),
    [sym_continue_as_identifier] = ACTIONS(567),
    [sym_preproc_open] = ACTIONS(567),
    [sym_end_keyword] = ACTIONS(567),
  },
  [STATE(951)] = {
    [sym_identifier] = ACTIONS(2266),
    [anon_sym_SEMI] = ACTIONS(2268),
    [anon_sym_DOT] = ACTIONS(2266),
    [anon_sym_EQ] = ACTIONS(2268),
    [anon_sym_COMMA] = ACTIONS(2268),
    [anon_sym_DASH] = ACTIONS(2266),
    [aux_sym_boolean_token1] = ACTIONS(2266),
    [aux_sym_boolean_token2] = ACTIONS(2266),
    [sym_decimal] = ACTIONS(2266),
    [anon_sym_LPAREN] = ACTIONS(2268),
    [anon_sym_DOT_DOT] = ACTIONS(2268),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2266),
    [anon_sym_STAR] = ACTIONS(2266),
    [anon_sym_LBRACK] = ACTIONS(2268),
    [aux_sym_record_type_token1] = ACTIONS(2266),
    [aux_sym_basic_type_token21] = ACTIONS(2266),
    [aux_sym_basic_type_token22] = ACTIONS(2266),
    [aux_sym_basic_type_token48] = ACTIONS(2266),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2266),
    [anon_sym_COLON_COLON] = ACTIONS(2268),
    [anon_sym_POUNDif] = ACTIONS(2268),
    [anon_sym_POUNDIF] = ACTIONS(2268),
    [anon_sym_POUNDIf] = ACTIONS(2268),
    [anon_sym_not] = ACTIONS(2266),
    [anon_sym_NOT] = ACTIONS(2266),
    [anon_sym_Not] = ACTIONS(2266),
    [anon_sym_POUNDelif] = ACTIONS(2268),
    [anon_sym_POUNDELIF] = ACTIONS(2268),
    [anon_sym_POUNDElif] = ACTIONS(2268),
    [anon_sym_POUNDelse] = ACTIONS(2268),
    [anon_sym_POUNDELSE] = ACTIONS(2268),
    [anon_sym_POUNDElse] = ACTIONS(2268),
    [anon_sym_POUNDendif] = ACTIONS(2268),
    [anon_sym_POUNDENDIF] = ACTIONS(2268),
    [anon_sym_POUNDEndif] = ACTIONS(2268),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2268),
    [aux_sym__expression_token1] = ACTIONS(2268),
    [aux_sym__expression_token2] = ACTIONS(2266),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2266),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2266),
    [anon_sym_SLASH] = ACTIONS(2266),
    [anon_sym_div] = ACTIONS(2266),
    [anon_sym_DIV] = ACTIONS(2266),
    [anon_sym_Div] = ACTIONS(2266),
    [anon_sym_mod] = ACTIONS(2266),
    [anon_sym_MOD] = ACTIONS(2266),
    [anon_sym_Mod] = ACTIONS(2266),
    [anon_sym_PLUS] = ACTIONS(2266),
    [anon_sym_GT_EQ] = ACTIONS(2268),
    [anon_sym_LT_EQ] = ACTIONS(2268),
    [anon_sym_GT] = ACTIONS(2266),
    [anon_sym_LT] = ACTIONS(2266),
    [anon_sym_LT_GT] = ACTIONS(2268),
    [anon_sym_and] = ACTIONS(2266),
    [anon_sym_AND] = ACTIONS(2266),
    [anon_sym_And] = ACTIONS(2266),
    [anon_sym_or] = ACTIONS(2266),
    [anon_sym_OR] = ACTIONS(2266),
    [anon_sym_Or] = ACTIONS(2266),
    [anon_sym_xor] = ACTIONS(2266),
    [anon_sym_XOR] = ACTIONS(2266),
    [anon_sym_Xor] = ACTIONS(2266),
    [anon_sym_QMARK] = ACTIONS(2268),
    [sym_datetime_literal] = ACTIONS(2268),
    [sym_date_literal] = ACTIONS(2266),
    [sym_time_literal] = ACTIONS(2266),
    [sym_biginteger_literal] = ACTIONS(2268),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_IF] = ACTIONS(2266),
    [anon_sym_If] = ACTIONS(2266),
    [anon_sym_else] = ACTIONS(2266),
    [anon_sym_ELSE] = ACTIONS(2266),
    [anon_sym_Else] = ACTIONS(2266),
    [anon_sym_case] = ACTIONS(2266),
    [anon_sym_CASE] = ACTIONS(2266),
    [anon_sym_Case] = ACTIONS(2266),
    [anon_sym_for] = ACTIONS(2266),
    [anon_sym_FOR] = ACTIONS(2266),
    [anon_sym_For] = ACTIONS(2266),
    [anon_sym_foreach] = ACTIONS(2266),
    [anon_sym_FOREACH] = ACTIONS(2266),
    [anon_sym_Foreach] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2266),
    [anon_sym_WHILE] = ACTIONS(2266),
    [anon_sym_While] = ACTIONS(2266),
    [anon_sym_repeat] = ACTIONS(2266),
    [anon_sym_REPEAT] = ACTIONS(2266),
    [anon_sym_Repeat] = ACTIONS(2266),
    [anon_sym_exit] = ACTIONS(2266),
    [anon_sym_EXIT] = ACTIONS(2266),
    [anon_sym_Exit] = ACTIONS(2266),
    [anon_sym_continue] = ACTIONS(2266),
    [anon_sym_CONTINUE] = ACTIONS(2266),
    [anon_sym_Continue] = ACTIONS(2266),
    [anon_sym_break] = ACTIONS(2266),
    [anon_sym_BREAK] = ACTIONS(2266),
    [anon_sym_Break] = ACTIONS(2266),
    [anon_sym_with] = ACTIONS(2266),
    [anon_sym_WITH] = ACTIONS(2266),
    [anon_sym_With] = ACTIONS(2266),
    [sym_asserterror_keyword] = ACTIONS(2268),
    [anon_sym_in] = ACTIONS(2266),
    [anon_sym_IN] = ACTIONS(2266),
    [anon_sym_In] = ACTIONS(2266),
    [sym_page_keyword] = ACTIONS(2266),
    [anon_sym_codeunit] = ACTIONS(2266),
    [anon_sym_CODEUNIT] = ACTIONS(2266),
    [anon_sym_Codeunit] = ACTIONS(2266),
    [anon_sym_CodeUnit] = ACTIONS(2266),
    [anon_sym_COdeunit] = ACTIONS(2266),
    [anon_sym_codeUnit] = ACTIONS(2266),
    [sym_report_keyword] = ACTIONS(2266),
    [sym_query_keyword] = ACTIONS(2266),
    [anon_sym_xmlport] = ACTIONS(2266),
    [anon_sym_XMLPORT] = ACTIONS(2266),
    [anon_sym_Xmlport] = ACTIONS(2266),
    [anon_sym_XMLport] = ACTIONS(2266),
    [anon_sym_XMLPort] = ACTIONS(2266),
    [anon_sym_XmlPort] = ACTIONS(2266),
    [anon_sym_enum] = ACTIONS(2266),
    [anon_sym_ENUM] = ACTIONS(2266),
    [anon_sym_Enum] = ACTIONS(2266),
    [anon_sym_eNUM] = ACTIONS(2266),
    [anon_sym_eNum] = ACTIONS(2266),
    [anon_sym_ENum] = ACTIONS(2266),
    [sym_temporary_keyword] = ACTIONS(2266),
    [sym_quoted_identifier] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2268),
    [sym_integer] = ACTIONS(2266),
    [sym_continue_as_identifier] = ACTIONS(2268),
    [sym_preproc_open] = ACTIONS(2268),
    [sym_preproc_close] = ACTIONS(2268),
  },
  [STATE(952)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2278),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2308),
    [anon_sym_AND] = ACTIONS(2310),
    [anon_sym_And] = ACTIONS(2312),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(953)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2316),
    [anon_sym_SEMI] = ACTIONS(2318),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2318),
    [anon_sym_DASH] = ACTIONS(2316),
    [aux_sym_boolean_token1] = ACTIONS(2316),
    [aux_sym_boolean_token2] = ACTIONS(2316),
    [sym_decimal] = ACTIONS(2316),
    [anon_sym_LPAREN] = ACTIONS(2318),
    [anon_sym_DOT_DOT] = ACTIONS(2318),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2316),
    [anon_sym_STAR] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2316),
    [aux_sym_basic_type_token21] = ACTIONS(2316),
    [aux_sym_basic_type_token22] = ACTIONS(2316),
    [aux_sym_basic_type_token48] = ACTIONS(2316),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2316),
    [anon_sym_POUNDif] = ACTIONS(2318),
    [anon_sym_POUNDIF] = ACTIONS(2318),
    [anon_sym_POUNDIf] = ACTIONS(2318),
    [anon_sym_not] = ACTIONS(2316),
    [anon_sym_NOT] = ACTIONS(2316),
    [anon_sym_Not] = ACTIONS(2316),
    [anon_sym_POUNDelif] = ACTIONS(2318),
    [anon_sym_POUNDELIF] = ACTIONS(2318),
    [anon_sym_POUNDElif] = ACTIONS(2318),
    [anon_sym_POUNDelse] = ACTIONS(2318),
    [anon_sym_POUNDELSE] = ACTIONS(2318),
    [anon_sym_POUNDElse] = ACTIONS(2318),
    [anon_sym_POUNDendif] = ACTIONS(2318),
    [anon_sym_POUNDENDIF] = ACTIONS(2318),
    [anon_sym_POUNDEndif] = ACTIONS(2318),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2318),
    [aux_sym__expression_token1] = ACTIONS(2318),
    [aux_sym__expression_token2] = ACTIONS(2316),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2316),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2316),
    [anon_sym_SLASH] = ACTIONS(2316),
    [anon_sym_div] = ACTIONS(2316),
    [anon_sym_DIV] = ACTIONS(2316),
    [anon_sym_Div] = ACTIONS(2316),
    [anon_sym_mod] = ACTIONS(2316),
    [anon_sym_MOD] = ACTIONS(2316),
    [anon_sym_Mod] = ACTIONS(2316),
    [anon_sym_PLUS] = ACTIONS(2316),
    [anon_sym_GT_EQ] = ACTIONS(2318),
    [anon_sym_LT_EQ] = ACTIONS(2318),
    [anon_sym_GT] = ACTIONS(2316),
    [anon_sym_LT] = ACTIONS(2316),
    [anon_sym_LT_GT] = ACTIONS(2318),
    [anon_sym_and] = ACTIONS(2316),
    [anon_sym_AND] = ACTIONS(2316),
    [anon_sym_And] = ACTIONS(2316),
    [anon_sym_or] = ACTIONS(2316),
    [anon_sym_OR] = ACTIONS(2316),
    [anon_sym_Or] = ACTIONS(2316),
    [anon_sym_xor] = ACTIONS(2316),
    [anon_sym_XOR] = ACTIONS(2316),
    [anon_sym_Xor] = ACTIONS(2316),
    [anon_sym_QMARK] = ACTIONS(2318),
    [sym_datetime_literal] = ACTIONS(2318),
    [sym_date_literal] = ACTIONS(2316),
    [sym_time_literal] = ACTIONS(2316),
    [sym_biginteger_literal] = ACTIONS(2318),
    [anon_sym_if] = ACTIONS(2316),
    [anon_sym_IF] = ACTIONS(2316),
    [anon_sym_If] = ACTIONS(2316),
    [anon_sym_else] = ACTIONS(2316),
    [anon_sym_ELSE] = ACTIONS(2316),
    [anon_sym_Else] = ACTIONS(2316),
    [anon_sym_case] = ACTIONS(2316),
    [anon_sym_CASE] = ACTIONS(2316),
    [anon_sym_Case] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2316),
    [anon_sym_FOR] = ACTIONS(2316),
    [anon_sym_For] = ACTIONS(2316),
    [anon_sym_foreach] = ACTIONS(2316),
    [anon_sym_FOREACH] = ACTIONS(2316),
    [anon_sym_Foreach] = ACTIONS(2316),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_WHILE] = ACTIONS(2316),
    [anon_sym_While] = ACTIONS(2316),
    [anon_sym_repeat] = ACTIONS(2316),
    [anon_sym_REPEAT] = ACTIONS(2316),
    [anon_sym_Repeat] = ACTIONS(2316),
    [anon_sym_exit] = ACTIONS(2316),
    [anon_sym_EXIT] = ACTIONS(2316),
    [anon_sym_Exit] = ACTIONS(2316),
    [anon_sym_continue] = ACTIONS(2316),
    [anon_sym_CONTINUE] = ACTIONS(2316),
    [anon_sym_Continue] = ACTIONS(2316),
    [anon_sym_break] = ACTIONS(2316),
    [anon_sym_BREAK] = ACTIONS(2316),
    [anon_sym_Break] = ACTIONS(2316),
    [anon_sym_with] = ACTIONS(2316),
    [anon_sym_WITH] = ACTIONS(2316),
    [anon_sym_With] = ACTIONS(2316),
    [sym_asserterror_keyword] = ACTIONS(2318),
    [anon_sym_in] = ACTIONS(2316),
    [anon_sym_IN] = ACTIONS(2316),
    [anon_sym_In] = ACTIONS(2316),
    [sym_page_keyword] = ACTIONS(2316),
    [anon_sym_codeunit] = ACTIONS(2316),
    [anon_sym_CODEUNIT] = ACTIONS(2316),
    [anon_sym_Codeunit] = ACTIONS(2316),
    [anon_sym_CodeUnit] = ACTIONS(2316),
    [anon_sym_COdeunit] = ACTIONS(2316),
    [anon_sym_codeUnit] = ACTIONS(2316),
    [sym_report_keyword] = ACTIONS(2316),
    [sym_query_keyword] = ACTIONS(2316),
    [anon_sym_xmlport] = ACTIONS(2316),
    [anon_sym_XMLPORT] = ACTIONS(2316),
    [anon_sym_Xmlport] = ACTIONS(2316),
    [anon_sym_XMLport] = ACTIONS(2316),
    [anon_sym_XMLPort] = ACTIONS(2316),
    [anon_sym_XmlPort] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_ENUM] = ACTIONS(2316),
    [anon_sym_Enum] = ACTIONS(2316),
    [anon_sym_eNUM] = ACTIONS(2316),
    [anon_sym_eNum] = ACTIONS(2316),
    [anon_sym_ENum] = ACTIONS(2316),
    [sym_quoted_identifier] = ACTIONS(2318),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2318),
    [sym_integer] = ACTIONS(2316),
    [sym_continue_as_identifier] = ACTIONS(2318),
    [sym_preproc_open] = ACTIONS(2318),
    [sym_preproc_close] = ACTIONS(2318),
  },
  [STATE(954)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(955)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(2324),
    [anon_sym_POUNDELIF] = ACTIONS(2324),
    [anon_sym_POUNDElif] = ACTIONS(2324),
    [anon_sym_POUNDelse] = ACTIONS(2324),
    [anon_sym_POUNDELSE] = ACTIONS(2324),
    [anon_sym_POUNDElse] = ACTIONS(2324),
    [anon_sym_POUNDendif] = ACTIONS(2324),
    [anon_sym_POUNDENDIF] = ACTIONS(2324),
    [anon_sym_POUNDEndif] = ACTIONS(2324),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(2324),
  },
  [STATE(956)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2326),
    [anon_sym_SEMI] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2278),
    [aux_sym_boolean_token1] = ACTIONS(2326),
    [aux_sym_boolean_token2] = ACTIONS(2326),
    [sym_decimal] = ACTIONS(2326),
    [anon_sym_LPAREN] = ACTIONS(2328),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2326),
    [aux_sym_basic_type_token21] = ACTIONS(2326),
    [aux_sym_basic_type_token22] = ACTIONS(2326),
    [aux_sym_basic_type_token48] = ACTIONS(2326),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2326),
    [anon_sym_POUNDif] = ACTIONS(2328),
    [anon_sym_POUNDIF] = ACTIONS(2328),
    [anon_sym_POUNDIf] = ACTIONS(2328),
    [anon_sym_not] = ACTIONS(2326),
    [anon_sym_NOT] = ACTIONS(2326),
    [anon_sym_Not] = ACTIONS(2326),
    [anon_sym_POUNDelif] = ACTIONS(2328),
    [anon_sym_POUNDELIF] = ACTIONS(2328),
    [anon_sym_POUNDElif] = ACTIONS(2328),
    [anon_sym_POUNDelse] = ACTIONS(2328),
    [anon_sym_POUNDELSE] = ACTIONS(2328),
    [anon_sym_POUNDElse] = ACTIONS(2328),
    [anon_sym_POUNDendif] = ACTIONS(2328),
    [anon_sym_POUNDENDIF] = ACTIONS(2328),
    [anon_sym_POUNDEndif] = ACTIONS(2328),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2330),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2326),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2326),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2308),
    [anon_sym_AND] = ACTIONS(2310),
    [anon_sym_And] = ACTIONS(2312),
    [anon_sym_or] = ACTIONS(2332),
    [anon_sym_OR] = ACTIONS(2334),
    [anon_sym_Or] = ACTIONS(2336),
    [anon_sym_xor] = ACTIONS(2338),
    [anon_sym_XOR] = ACTIONS(2340),
    [anon_sym_Xor] = ACTIONS(2342),
    [anon_sym_QMARK] = ACTIONS(2344),
    [sym_datetime_literal] = ACTIONS(2328),
    [sym_date_literal] = ACTIONS(2326),
    [sym_time_literal] = ACTIONS(2326),
    [sym_biginteger_literal] = ACTIONS(2328),
    [anon_sym_if] = ACTIONS(2326),
    [anon_sym_IF] = ACTIONS(2326),
    [anon_sym_If] = ACTIONS(2326),
    [anon_sym_else] = ACTIONS(2326),
    [anon_sym_ELSE] = ACTIONS(2326),
    [anon_sym_Else] = ACTIONS(2326),
    [anon_sym_case] = ACTIONS(2326),
    [anon_sym_CASE] = ACTIONS(2326),
    [anon_sym_Case] = ACTIONS(2326),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_FOR] = ACTIONS(2326),
    [anon_sym_For] = ACTIONS(2326),
    [anon_sym_foreach] = ACTIONS(2326),
    [anon_sym_FOREACH] = ACTIONS(2326),
    [anon_sym_Foreach] = ACTIONS(2326),
    [anon_sym_while] = ACTIONS(2326),
    [anon_sym_WHILE] = ACTIONS(2326),
    [anon_sym_While] = ACTIONS(2326),
    [anon_sym_repeat] = ACTIONS(2326),
    [anon_sym_REPEAT] = ACTIONS(2326),
    [anon_sym_Repeat] = ACTIONS(2326),
    [anon_sym_exit] = ACTIONS(2326),
    [anon_sym_EXIT] = ACTIONS(2326),
    [anon_sym_Exit] = ACTIONS(2326),
    [anon_sym_continue] = ACTIONS(2326),
    [anon_sym_CONTINUE] = ACTIONS(2326),
    [anon_sym_Continue] = ACTIONS(2326),
    [anon_sym_break] = ACTIONS(2326),
    [anon_sym_BREAK] = ACTIONS(2326),
    [anon_sym_Break] = ACTIONS(2326),
    [anon_sym_with] = ACTIONS(2326),
    [anon_sym_WITH] = ACTIONS(2326),
    [anon_sym_With] = ACTIONS(2326),
    [sym_asserterror_keyword] = ACTIONS(2328),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2326),
    [anon_sym_codeunit] = ACTIONS(2326),
    [anon_sym_CODEUNIT] = ACTIONS(2326),
    [anon_sym_Codeunit] = ACTIONS(2326),
    [anon_sym_CodeUnit] = ACTIONS(2326),
    [anon_sym_COdeunit] = ACTIONS(2326),
    [anon_sym_codeUnit] = ACTIONS(2326),
    [sym_report_keyword] = ACTIONS(2326),
    [sym_query_keyword] = ACTIONS(2326),
    [anon_sym_xmlport] = ACTIONS(2326),
    [anon_sym_XMLPORT] = ACTIONS(2326),
    [anon_sym_Xmlport] = ACTIONS(2326),
    [anon_sym_XMLport] = ACTIONS(2326),
    [anon_sym_XMLPort] = ACTIONS(2326),
    [anon_sym_XmlPort] = ACTIONS(2326),
    [anon_sym_enum] = ACTIONS(2326),
    [anon_sym_ENUM] = ACTIONS(2326),
    [anon_sym_Enum] = ACTIONS(2326),
    [anon_sym_eNUM] = ACTIONS(2326),
    [anon_sym_eNum] = ACTIONS(2326),
    [anon_sym_ENum] = ACTIONS(2326),
    [sym_quoted_identifier] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2328),
    [sym_integer] = ACTIONS(2326),
    [sym_continue_as_identifier] = ACTIONS(2328),
    [sym_preproc_open] = ACTIONS(2328),
    [sym_preproc_close] = ACTIONS(2328),
  },
  [STATE(957)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(995),
    [sym_identifier] = ACTIONS(2346),
    [anon_sym_SEMI] = ACTIONS(2348),
    [anon_sym_DOT] = ACTIONS(2350),
    [anon_sym_EQ] = ACTIONS(2348),
    [anon_sym_DASH] = ACTIONS(2346),
    [aux_sym_boolean_token1] = ACTIONS(2346),
    [aux_sym_boolean_token2] = ACTIONS(2346),
    [sym_decimal] = ACTIONS(2346),
    [anon_sym_LPAREN] = ACTIONS(2348),
    [anon_sym_DOT_DOT] = ACTIONS(2348),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2346),
    [anon_sym_STAR] = ACTIONS(2346),
    [anon_sym_LBRACK] = ACTIONS(2348),
    [aux_sym_record_type_token1] = ACTIONS(2346),
    [aux_sym_basic_type_token21] = ACTIONS(2346),
    [aux_sym_basic_type_token22] = ACTIONS(2346),
    [aux_sym_basic_type_token48] = ACTIONS(2346),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2346),
    [anon_sym_POUNDif] = ACTIONS(2348),
    [anon_sym_POUNDIF] = ACTIONS(2348),
    [anon_sym_POUNDIf] = ACTIONS(2348),
    [anon_sym_not] = ACTIONS(2346),
    [anon_sym_NOT] = ACTIONS(2346),
    [anon_sym_Not] = ACTIONS(2346),
    [anon_sym_POUNDelif] = ACTIONS(2348),
    [anon_sym_POUNDELIF] = ACTIONS(2348),
    [anon_sym_POUNDElif] = ACTIONS(2348),
    [anon_sym_POUNDelse] = ACTIONS(2348),
    [anon_sym_POUNDELSE] = ACTIONS(2348),
    [anon_sym_POUNDElse] = ACTIONS(2348),
    [anon_sym_POUNDendif] = ACTIONS(2348),
    [anon_sym_POUNDENDIF] = ACTIONS(2348),
    [anon_sym_POUNDEndif] = ACTIONS(2348),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2348),
    [aux_sym__expression_token1] = ACTIONS(2348),
    [aux_sym__expression_token2] = ACTIONS(2346),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2346),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2346),
    [anon_sym_SLASH] = ACTIONS(2346),
    [anon_sym_div] = ACTIONS(2346),
    [anon_sym_DIV] = ACTIONS(2346),
    [anon_sym_Div] = ACTIONS(2346),
    [anon_sym_mod] = ACTIONS(2346),
    [anon_sym_MOD] = ACTIONS(2346),
    [anon_sym_Mod] = ACTIONS(2346),
    [anon_sym_PLUS] = ACTIONS(2346),
    [anon_sym_GT_EQ] = ACTIONS(2348),
    [anon_sym_LT_EQ] = ACTIONS(2348),
    [anon_sym_GT] = ACTIONS(2346),
    [anon_sym_LT] = ACTIONS(2346),
    [anon_sym_LT_GT] = ACTIONS(2348),
    [anon_sym_and] = ACTIONS(2346),
    [anon_sym_AND] = ACTIONS(2346),
    [anon_sym_And] = ACTIONS(2346),
    [anon_sym_or] = ACTIONS(2346),
    [anon_sym_OR] = ACTIONS(2346),
    [anon_sym_Or] = ACTIONS(2346),
    [anon_sym_xor] = ACTIONS(2346),
    [anon_sym_XOR] = ACTIONS(2346),
    [anon_sym_Xor] = ACTIONS(2346),
    [anon_sym_QMARK] = ACTIONS(2348),
    [sym_datetime_literal] = ACTIONS(2348),
    [sym_date_literal] = ACTIONS(2346),
    [sym_time_literal] = ACTIONS(2346),
    [sym_biginteger_literal] = ACTIONS(2348),
    [anon_sym_if] = ACTIONS(2346),
    [anon_sym_IF] = ACTIONS(2346),
    [anon_sym_If] = ACTIONS(2346),
    [anon_sym_else] = ACTIONS(2346),
    [anon_sym_ELSE] = ACTIONS(2346),
    [anon_sym_Else] = ACTIONS(2346),
    [anon_sym_case] = ACTIONS(2346),
    [anon_sym_CASE] = ACTIONS(2346),
    [anon_sym_Case] = ACTIONS(2346),
    [anon_sym_for] = ACTIONS(2346),
    [anon_sym_FOR] = ACTIONS(2346),
    [anon_sym_For] = ACTIONS(2346),
    [anon_sym_foreach] = ACTIONS(2346),
    [anon_sym_FOREACH] = ACTIONS(2346),
    [anon_sym_Foreach] = ACTIONS(2346),
    [anon_sym_while] = ACTIONS(2346),
    [anon_sym_WHILE] = ACTIONS(2346),
    [anon_sym_While] = ACTIONS(2346),
    [anon_sym_repeat] = ACTIONS(2346),
    [anon_sym_REPEAT] = ACTIONS(2346),
    [anon_sym_Repeat] = ACTIONS(2346),
    [anon_sym_exit] = ACTIONS(2346),
    [anon_sym_EXIT] = ACTIONS(2346),
    [anon_sym_Exit] = ACTIONS(2346),
    [anon_sym_continue] = ACTIONS(2346),
    [anon_sym_CONTINUE] = ACTIONS(2346),
    [anon_sym_Continue] = ACTIONS(2346),
    [anon_sym_break] = ACTIONS(2346),
    [anon_sym_BREAK] = ACTIONS(2346),
    [anon_sym_Break] = ACTIONS(2346),
    [anon_sym_with] = ACTIONS(2346),
    [anon_sym_WITH] = ACTIONS(2346),
    [anon_sym_With] = ACTIONS(2346),
    [sym_asserterror_keyword] = ACTIONS(2348),
    [anon_sym_in] = ACTIONS(2346),
    [anon_sym_IN] = ACTIONS(2346),
    [anon_sym_In] = ACTIONS(2346),
    [sym_page_keyword] = ACTIONS(2346),
    [anon_sym_codeunit] = ACTIONS(2346),
    [anon_sym_CODEUNIT] = ACTIONS(2346),
    [anon_sym_Codeunit] = ACTIONS(2346),
    [anon_sym_CodeUnit] = ACTIONS(2346),
    [anon_sym_COdeunit] = ACTIONS(2346),
    [anon_sym_codeUnit] = ACTIONS(2346),
    [sym_report_keyword] = ACTIONS(2346),
    [sym_query_keyword] = ACTIONS(2346),
    [anon_sym_xmlport] = ACTIONS(2346),
    [anon_sym_XMLPORT] = ACTIONS(2346),
    [anon_sym_Xmlport] = ACTIONS(2346),
    [anon_sym_XMLport] = ACTIONS(2346),
    [anon_sym_XMLPort] = ACTIONS(2346),
    [anon_sym_XmlPort] = ACTIONS(2346),
    [anon_sym_enum] = ACTIONS(2346),
    [anon_sym_ENUM] = ACTIONS(2346),
    [anon_sym_Enum] = ACTIONS(2346),
    [anon_sym_eNUM] = ACTIONS(2346),
    [anon_sym_eNum] = ACTIONS(2346),
    [anon_sym_ENum] = ACTIONS(2346),
    [sym_temporary_keyword] = ACTIONS(2346),
    [sym_quoted_identifier] = ACTIONS(2348),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2348),
    [sym_integer] = ACTIONS(2346),
    [sym_continue_as_identifier] = ACTIONS(2348),
    [sym_preproc_open] = ACTIONS(2348),
    [sym_preproc_close] = ACTIONS(2348),
  },
  [STATE(958)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(2352),
    [anon_sym_POUNDELIF] = ACTIONS(2352),
    [anon_sym_POUNDElif] = ACTIONS(2352),
    [anon_sym_POUNDelse] = ACTIONS(2352),
    [anon_sym_POUNDELSE] = ACTIONS(2352),
    [anon_sym_POUNDElse] = ACTIONS(2352),
    [anon_sym_POUNDendif] = ACTIONS(2352),
    [anon_sym_POUNDENDIF] = ACTIONS(2352),
    [anon_sym_POUNDEndif] = ACTIONS(2352),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(2352),
  },
  [STATE(959)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(960)] = {
    [aux_sym_option_member_list_repeat1] = STATE(986),
    [sym_identifier] = ACTIONS(2354),
    [anon_sym_SEMI] = ACTIONS(2356),
    [anon_sym_DOT] = ACTIONS(2354),
    [anon_sym_EQ] = ACTIONS(2356),
    [anon_sym_COMMA] = ACTIONS(2358),
    [anon_sym_DASH] = ACTIONS(2354),
    [aux_sym_boolean_token1] = ACTIONS(2354),
    [aux_sym_boolean_token2] = ACTIONS(2354),
    [sym_decimal] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(2356),
    [anon_sym_DOT_DOT] = ACTIONS(2356),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2354),
    [anon_sym_STAR] = ACTIONS(2354),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [aux_sym_record_type_token1] = ACTIONS(2354),
    [aux_sym_basic_type_token21] = ACTIONS(2354),
    [aux_sym_basic_type_token22] = ACTIONS(2354),
    [aux_sym_basic_type_token48] = ACTIONS(2354),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2354),
    [anon_sym_POUNDif] = ACTIONS(2356),
    [anon_sym_POUNDIF] = ACTIONS(2356),
    [anon_sym_POUNDIf] = ACTIONS(2356),
    [anon_sym_not] = ACTIONS(2354),
    [anon_sym_NOT] = ACTIONS(2354),
    [anon_sym_Not] = ACTIONS(2354),
    [anon_sym_POUNDelif] = ACTIONS(2356),
    [anon_sym_POUNDELIF] = ACTIONS(2356),
    [anon_sym_POUNDElif] = ACTIONS(2356),
    [anon_sym_POUNDelse] = ACTIONS(2356),
    [anon_sym_POUNDELSE] = ACTIONS(2356),
    [anon_sym_POUNDElse] = ACTIONS(2356),
    [anon_sym_POUNDendif] = ACTIONS(2356),
    [anon_sym_POUNDENDIF] = ACTIONS(2356),
    [anon_sym_POUNDEndif] = ACTIONS(2356),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2356),
    [aux_sym__expression_token1] = ACTIONS(2356),
    [aux_sym__expression_token2] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2354),
    [anon_sym_SLASH] = ACTIONS(2354),
    [anon_sym_div] = ACTIONS(2354),
    [anon_sym_DIV] = ACTIONS(2354),
    [anon_sym_Div] = ACTIONS(2354),
    [anon_sym_mod] = ACTIONS(2354),
    [anon_sym_MOD] = ACTIONS(2354),
    [anon_sym_Mod] = ACTIONS(2354),
    [anon_sym_PLUS] = ACTIONS(2354),
    [anon_sym_GT_EQ] = ACTIONS(2356),
    [anon_sym_LT_EQ] = ACTIONS(2356),
    [anon_sym_GT] = ACTIONS(2354),
    [anon_sym_LT] = ACTIONS(2354),
    [anon_sym_LT_GT] = ACTIONS(2356),
    [anon_sym_and] = ACTIONS(2354),
    [anon_sym_AND] = ACTIONS(2354),
    [anon_sym_And] = ACTIONS(2354),
    [anon_sym_or] = ACTIONS(2354),
    [anon_sym_OR] = ACTIONS(2354),
    [anon_sym_Or] = ACTIONS(2354),
    [anon_sym_xor] = ACTIONS(2354),
    [anon_sym_XOR] = ACTIONS(2354),
    [anon_sym_Xor] = ACTIONS(2354),
    [anon_sym_QMARK] = ACTIONS(2356),
    [sym_datetime_literal] = ACTIONS(2356),
    [sym_date_literal] = ACTIONS(2354),
    [sym_time_literal] = ACTIONS(2354),
    [sym_biginteger_literal] = ACTIONS(2356),
    [anon_sym_if] = ACTIONS(2354),
    [anon_sym_IF] = ACTIONS(2354),
    [anon_sym_If] = ACTIONS(2354),
    [anon_sym_else] = ACTIONS(2354),
    [anon_sym_ELSE] = ACTIONS(2354),
    [anon_sym_Else] = ACTIONS(2354),
    [anon_sym_case] = ACTIONS(2354),
    [anon_sym_CASE] = ACTIONS(2354),
    [anon_sym_Case] = ACTIONS(2354),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_FOR] = ACTIONS(2354),
    [anon_sym_For] = ACTIONS(2354),
    [anon_sym_foreach] = ACTIONS(2354),
    [anon_sym_FOREACH] = ACTIONS(2354),
    [anon_sym_Foreach] = ACTIONS(2354),
    [anon_sym_while] = ACTIONS(2354),
    [anon_sym_WHILE] = ACTIONS(2354),
    [anon_sym_While] = ACTIONS(2354),
    [anon_sym_repeat] = ACTIONS(2354),
    [anon_sym_REPEAT] = ACTIONS(2354),
    [anon_sym_Repeat] = ACTIONS(2354),
    [anon_sym_exit] = ACTIONS(2354),
    [anon_sym_EXIT] = ACTIONS(2354),
    [anon_sym_Exit] = ACTIONS(2354),
    [anon_sym_continue] = ACTIONS(2354),
    [anon_sym_CONTINUE] = ACTIONS(2354),
    [anon_sym_Continue] = ACTIONS(2354),
    [anon_sym_break] = ACTIONS(2354),
    [anon_sym_BREAK] = ACTIONS(2354),
    [anon_sym_Break] = ACTIONS(2354),
    [anon_sym_with] = ACTIONS(2354),
    [anon_sym_WITH] = ACTIONS(2354),
    [anon_sym_With] = ACTIONS(2354),
    [sym_asserterror_keyword] = ACTIONS(2356),
    [anon_sym_in] = ACTIONS(2354),
    [anon_sym_IN] = ACTIONS(2354),
    [anon_sym_In] = ACTIONS(2354),
    [sym_page_keyword] = ACTIONS(2354),
    [anon_sym_codeunit] = ACTIONS(2354),
    [anon_sym_CODEUNIT] = ACTIONS(2354),
    [anon_sym_Codeunit] = ACTIONS(2354),
    [anon_sym_CodeUnit] = ACTIONS(2354),
    [anon_sym_COdeunit] = ACTIONS(2354),
    [anon_sym_codeUnit] = ACTIONS(2354),
    [sym_report_keyword] = ACTIONS(2354),
    [sym_query_keyword] = ACTIONS(2354),
    [anon_sym_xmlport] = ACTIONS(2354),
    [anon_sym_XMLPORT] = ACTIONS(2354),
    [anon_sym_Xmlport] = ACTIONS(2354),
    [anon_sym_XMLport] = ACTIONS(2354),
    [anon_sym_XMLPort] = ACTIONS(2354),
    [anon_sym_XmlPort] = ACTIONS(2354),
    [anon_sym_enum] = ACTIONS(2354),
    [anon_sym_ENUM] = ACTIONS(2354),
    [anon_sym_Enum] = ACTIONS(2354),
    [anon_sym_eNUM] = ACTIONS(2354),
    [anon_sym_eNum] = ACTIONS(2354),
    [anon_sym_ENum] = ACTIONS(2354),
    [sym_quoted_identifier] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2356),
    [sym_integer] = ACTIONS(2354),
    [sym_continue_as_identifier] = ACTIONS(2356),
    [sym_preproc_open] = ACTIONS(2356),
    [sym_preproc_close] = ACTIONS(2356),
  },
  [STATE(961)] = {
    [aux_sym_option_member_list_repeat1] = STATE(987),
    [sym_identifier] = ACTIONS(2354),
    [anon_sym_SEMI] = ACTIONS(2356),
    [anon_sym_DOT] = ACTIONS(2354),
    [anon_sym_EQ] = ACTIONS(2356),
    [anon_sym_COMMA] = ACTIONS(2358),
    [anon_sym_DASH] = ACTIONS(2354),
    [aux_sym_boolean_token1] = ACTIONS(2354),
    [aux_sym_boolean_token2] = ACTIONS(2354),
    [sym_decimal] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(2356),
    [anon_sym_DOT_DOT] = ACTIONS(2356),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2354),
    [anon_sym_STAR] = ACTIONS(2354),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [aux_sym_record_type_token1] = ACTIONS(2354),
    [aux_sym_basic_type_token21] = ACTIONS(2354),
    [aux_sym_basic_type_token22] = ACTIONS(2354),
    [aux_sym_basic_type_token48] = ACTIONS(2354),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2354),
    [anon_sym_POUNDif] = ACTIONS(2356),
    [anon_sym_POUNDIF] = ACTIONS(2356),
    [anon_sym_POUNDIf] = ACTIONS(2356),
    [anon_sym_not] = ACTIONS(2354),
    [anon_sym_NOT] = ACTIONS(2354),
    [anon_sym_Not] = ACTIONS(2354),
    [anon_sym_POUNDelif] = ACTIONS(2356),
    [anon_sym_POUNDELIF] = ACTIONS(2356),
    [anon_sym_POUNDElif] = ACTIONS(2356),
    [anon_sym_POUNDelse] = ACTIONS(2356),
    [anon_sym_POUNDELSE] = ACTIONS(2356),
    [anon_sym_POUNDElse] = ACTIONS(2356),
    [anon_sym_POUNDendif] = ACTIONS(2356),
    [anon_sym_POUNDENDIF] = ACTIONS(2356),
    [anon_sym_POUNDEndif] = ACTIONS(2356),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2356),
    [aux_sym__expression_token1] = ACTIONS(2356),
    [aux_sym__expression_token2] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2354),
    [anon_sym_SLASH] = ACTIONS(2354),
    [anon_sym_div] = ACTIONS(2354),
    [anon_sym_DIV] = ACTIONS(2354),
    [anon_sym_Div] = ACTIONS(2354),
    [anon_sym_mod] = ACTIONS(2354),
    [anon_sym_MOD] = ACTIONS(2354),
    [anon_sym_Mod] = ACTIONS(2354),
    [anon_sym_PLUS] = ACTIONS(2354),
    [anon_sym_GT_EQ] = ACTIONS(2356),
    [anon_sym_LT_EQ] = ACTIONS(2356),
    [anon_sym_GT] = ACTIONS(2354),
    [anon_sym_LT] = ACTIONS(2354),
    [anon_sym_LT_GT] = ACTIONS(2356),
    [anon_sym_and] = ACTIONS(2354),
    [anon_sym_AND] = ACTIONS(2354),
    [anon_sym_And] = ACTIONS(2354),
    [anon_sym_or] = ACTIONS(2354),
    [anon_sym_OR] = ACTIONS(2354),
    [anon_sym_Or] = ACTIONS(2354),
    [anon_sym_xor] = ACTIONS(2354),
    [anon_sym_XOR] = ACTIONS(2354),
    [anon_sym_Xor] = ACTIONS(2354),
    [anon_sym_QMARK] = ACTIONS(2356),
    [sym_datetime_literal] = ACTIONS(2356),
    [sym_date_literal] = ACTIONS(2354),
    [sym_time_literal] = ACTIONS(2354),
    [sym_biginteger_literal] = ACTIONS(2356),
    [anon_sym_if] = ACTIONS(2354),
    [anon_sym_IF] = ACTIONS(2354),
    [anon_sym_If] = ACTIONS(2354),
    [anon_sym_else] = ACTIONS(2354),
    [anon_sym_ELSE] = ACTIONS(2354),
    [anon_sym_Else] = ACTIONS(2354),
    [anon_sym_case] = ACTIONS(2354),
    [anon_sym_CASE] = ACTIONS(2354),
    [anon_sym_Case] = ACTIONS(2354),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_FOR] = ACTIONS(2354),
    [anon_sym_For] = ACTIONS(2354),
    [anon_sym_foreach] = ACTIONS(2354),
    [anon_sym_FOREACH] = ACTIONS(2354),
    [anon_sym_Foreach] = ACTIONS(2354),
    [anon_sym_while] = ACTIONS(2354),
    [anon_sym_WHILE] = ACTIONS(2354),
    [anon_sym_While] = ACTIONS(2354),
    [anon_sym_repeat] = ACTIONS(2354),
    [anon_sym_REPEAT] = ACTIONS(2354),
    [anon_sym_Repeat] = ACTIONS(2354),
    [anon_sym_exit] = ACTIONS(2354),
    [anon_sym_EXIT] = ACTIONS(2354),
    [anon_sym_Exit] = ACTIONS(2354),
    [anon_sym_continue] = ACTIONS(2354),
    [anon_sym_CONTINUE] = ACTIONS(2354),
    [anon_sym_Continue] = ACTIONS(2354),
    [anon_sym_break] = ACTIONS(2354),
    [anon_sym_BREAK] = ACTIONS(2354),
    [anon_sym_Break] = ACTIONS(2354),
    [anon_sym_with] = ACTIONS(2354),
    [anon_sym_WITH] = ACTIONS(2354),
    [anon_sym_With] = ACTIONS(2354),
    [sym_asserterror_keyword] = ACTIONS(2356),
    [anon_sym_in] = ACTIONS(2354),
    [anon_sym_IN] = ACTIONS(2354),
    [anon_sym_In] = ACTIONS(2354),
    [sym_page_keyword] = ACTIONS(2354),
    [anon_sym_codeunit] = ACTIONS(2354),
    [anon_sym_CODEUNIT] = ACTIONS(2354),
    [anon_sym_Codeunit] = ACTIONS(2354),
    [anon_sym_CodeUnit] = ACTIONS(2354),
    [anon_sym_COdeunit] = ACTIONS(2354),
    [anon_sym_codeUnit] = ACTIONS(2354),
    [sym_report_keyword] = ACTIONS(2354),
    [sym_query_keyword] = ACTIONS(2354),
    [anon_sym_xmlport] = ACTIONS(2354),
    [anon_sym_XMLPORT] = ACTIONS(2354),
    [anon_sym_Xmlport] = ACTIONS(2354),
    [anon_sym_XMLport] = ACTIONS(2354),
    [anon_sym_XMLPort] = ACTIONS(2354),
    [anon_sym_XmlPort] = ACTIONS(2354),
    [anon_sym_enum] = ACTIONS(2354),
    [anon_sym_ENUM] = ACTIONS(2354),
    [anon_sym_Enum] = ACTIONS(2354),
    [anon_sym_eNUM] = ACTIONS(2354),
    [anon_sym_eNum] = ACTIONS(2354),
    [anon_sym_ENum] = ACTIONS(2354),
    [sym_quoted_identifier] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2356),
    [sym_integer] = ACTIONS(2354),
    [sym_continue_as_identifier] = ACTIONS(2356),
    [sym_preproc_open] = ACTIONS(2356),
    [sym_preproc_close] = ACTIONS(2356),
  },
  [STATE(962)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(963)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(964)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(965)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(966)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(967)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(968)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2360),
    [anon_sym_SEMI] = ACTIONS(2362),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2362),
    [anon_sym_DASH] = ACTIONS(2360),
    [aux_sym_boolean_token1] = ACTIONS(2360),
    [aux_sym_boolean_token2] = ACTIONS(2360),
    [sym_decimal] = ACTIONS(2360),
    [anon_sym_LPAREN] = ACTIONS(2362),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2360),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2360),
    [aux_sym_basic_type_token21] = ACTIONS(2360),
    [aux_sym_basic_type_token22] = ACTIONS(2360),
    [aux_sym_basic_type_token48] = ACTIONS(2360),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2360),
    [anon_sym_POUNDif] = ACTIONS(2362),
    [anon_sym_POUNDIF] = ACTIONS(2362),
    [anon_sym_POUNDIf] = ACTIONS(2362),
    [anon_sym_not] = ACTIONS(2360),
    [anon_sym_NOT] = ACTIONS(2360),
    [anon_sym_Not] = ACTIONS(2360),
    [anon_sym_POUNDelif] = ACTIONS(2362),
    [anon_sym_POUNDELIF] = ACTIONS(2362),
    [anon_sym_POUNDElif] = ACTIONS(2362),
    [anon_sym_POUNDelse] = ACTIONS(2362),
    [anon_sym_POUNDELSE] = ACTIONS(2362),
    [anon_sym_POUNDElse] = ACTIONS(2362),
    [anon_sym_POUNDendif] = ACTIONS(2362),
    [anon_sym_POUNDENDIF] = ACTIONS(2362),
    [anon_sym_POUNDEndif] = ACTIONS(2362),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2362),
    [aux_sym__expression_token1] = ACTIONS(2362),
    [aux_sym__expression_token2] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2360),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2360),
    [anon_sym_GT_EQ] = ACTIONS(2362),
    [anon_sym_LT_EQ] = ACTIONS(2362),
    [anon_sym_GT] = ACTIONS(2360),
    [anon_sym_LT] = ACTIONS(2360),
    [anon_sym_LT_GT] = ACTIONS(2362),
    [anon_sym_and] = ACTIONS(2360),
    [anon_sym_AND] = ACTIONS(2360),
    [anon_sym_And] = ACTIONS(2360),
    [anon_sym_or] = ACTIONS(2360),
    [anon_sym_OR] = ACTIONS(2360),
    [anon_sym_Or] = ACTIONS(2360),
    [anon_sym_xor] = ACTIONS(2360),
    [anon_sym_XOR] = ACTIONS(2360),
    [anon_sym_Xor] = ACTIONS(2360),
    [anon_sym_QMARK] = ACTIONS(2362),
    [sym_datetime_literal] = ACTIONS(2362),
    [sym_date_literal] = ACTIONS(2360),
    [sym_time_literal] = ACTIONS(2360),
    [sym_biginteger_literal] = ACTIONS(2362),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_IF] = ACTIONS(2360),
    [anon_sym_If] = ACTIONS(2360),
    [anon_sym_else] = ACTIONS(2360),
    [anon_sym_ELSE] = ACTIONS(2360),
    [anon_sym_Else] = ACTIONS(2360),
    [anon_sym_case] = ACTIONS(2360),
    [anon_sym_CASE] = ACTIONS(2360),
    [anon_sym_Case] = ACTIONS(2360),
    [anon_sym_for] = ACTIONS(2360),
    [anon_sym_FOR] = ACTIONS(2360),
    [anon_sym_For] = ACTIONS(2360),
    [anon_sym_foreach] = ACTIONS(2360),
    [anon_sym_FOREACH] = ACTIONS(2360),
    [anon_sym_Foreach] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2360),
    [anon_sym_WHILE] = ACTIONS(2360),
    [anon_sym_While] = ACTIONS(2360),
    [anon_sym_repeat] = ACTIONS(2360),
    [anon_sym_REPEAT] = ACTIONS(2360),
    [anon_sym_Repeat] = ACTIONS(2360),
    [anon_sym_exit] = ACTIONS(2360),
    [anon_sym_EXIT] = ACTIONS(2360),
    [anon_sym_Exit] = ACTIONS(2360),
    [anon_sym_continue] = ACTIONS(2360),
    [anon_sym_CONTINUE] = ACTIONS(2360),
    [anon_sym_Continue] = ACTIONS(2360),
    [anon_sym_break] = ACTIONS(2360),
    [anon_sym_BREAK] = ACTIONS(2360),
    [anon_sym_Break] = ACTIONS(2360),
    [anon_sym_with] = ACTIONS(2360),
    [anon_sym_WITH] = ACTIONS(2360),
    [anon_sym_With] = ACTIONS(2360),
    [sym_asserterror_keyword] = ACTIONS(2362),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_IN] = ACTIONS(2360),
    [anon_sym_In] = ACTIONS(2360),
    [sym_page_keyword] = ACTIONS(2360),
    [anon_sym_codeunit] = ACTIONS(2360),
    [anon_sym_CODEUNIT] = ACTIONS(2360),
    [anon_sym_Codeunit] = ACTIONS(2360),
    [anon_sym_CodeUnit] = ACTIONS(2360),
    [anon_sym_COdeunit] = ACTIONS(2360),
    [anon_sym_codeUnit] = ACTIONS(2360),
    [sym_report_keyword] = ACTIONS(2360),
    [sym_query_keyword] = ACTIONS(2360),
    [anon_sym_xmlport] = ACTIONS(2360),
    [anon_sym_XMLPORT] = ACTIONS(2360),
    [anon_sym_Xmlport] = ACTIONS(2360),
    [anon_sym_XMLport] = ACTIONS(2360),
    [anon_sym_XMLPort] = ACTIONS(2360),
    [anon_sym_XmlPort] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_ENUM] = ACTIONS(2360),
    [anon_sym_Enum] = ACTIONS(2360),
    [anon_sym_eNUM] = ACTIONS(2360),
    [anon_sym_eNum] = ACTIONS(2360),
    [anon_sym_ENum] = ACTIONS(2360),
    [sym_quoted_identifier] = ACTIONS(2362),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2362),
    [sym_integer] = ACTIONS(2360),
    [sym_continue_as_identifier] = ACTIONS(2362),
    [sym_preproc_open] = ACTIONS(2362),
    [sym_preproc_close] = ACTIONS(2362),
  },
  [STATE(969)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2278),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(970)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2278),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(971)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2278),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(972)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2360),
    [anon_sym_SEMI] = ACTIONS(2362),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2362),
    [anon_sym_DASH] = ACTIONS(2360),
    [aux_sym_boolean_token1] = ACTIONS(2360),
    [aux_sym_boolean_token2] = ACTIONS(2360),
    [sym_decimal] = ACTIONS(2360),
    [anon_sym_LPAREN] = ACTIONS(2362),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2360),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2360),
    [aux_sym_basic_type_token21] = ACTIONS(2360),
    [aux_sym_basic_type_token22] = ACTIONS(2360),
    [aux_sym_basic_type_token48] = ACTIONS(2360),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2360),
    [anon_sym_POUNDif] = ACTIONS(2362),
    [anon_sym_POUNDIF] = ACTIONS(2362),
    [anon_sym_POUNDIf] = ACTIONS(2362),
    [anon_sym_not] = ACTIONS(2360),
    [anon_sym_NOT] = ACTIONS(2360),
    [anon_sym_Not] = ACTIONS(2360),
    [anon_sym_POUNDelif] = ACTIONS(2362),
    [anon_sym_POUNDELIF] = ACTIONS(2362),
    [anon_sym_POUNDElif] = ACTIONS(2362),
    [anon_sym_POUNDelse] = ACTIONS(2362),
    [anon_sym_POUNDELSE] = ACTIONS(2362),
    [anon_sym_POUNDElse] = ACTIONS(2362),
    [anon_sym_POUNDendif] = ACTIONS(2362),
    [anon_sym_POUNDENDIF] = ACTIONS(2362),
    [anon_sym_POUNDEndif] = ACTIONS(2362),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2362),
    [aux_sym__expression_token1] = ACTIONS(2362),
    [aux_sym__expression_token2] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2360),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2360),
    [anon_sym_GT_EQ] = ACTIONS(2362),
    [anon_sym_LT_EQ] = ACTIONS(2362),
    [anon_sym_GT] = ACTIONS(2360),
    [anon_sym_LT] = ACTIONS(2360),
    [anon_sym_LT_GT] = ACTIONS(2362),
    [anon_sym_and] = ACTIONS(2360),
    [anon_sym_AND] = ACTIONS(2360),
    [anon_sym_And] = ACTIONS(2360),
    [anon_sym_or] = ACTIONS(2360),
    [anon_sym_OR] = ACTIONS(2360),
    [anon_sym_Or] = ACTIONS(2360),
    [anon_sym_xor] = ACTIONS(2360),
    [anon_sym_XOR] = ACTIONS(2360),
    [anon_sym_Xor] = ACTIONS(2360),
    [anon_sym_QMARK] = ACTIONS(2362),
    [sym_datetime_literal] = ACTIONS(2362),
    [sym_date_literal] = ACTIONS(2360),
    [sym_time_literal] = ACTIONS(2360),
    [sym_biginteger_literal] = ACTIONS(2362),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_IF] = ACTIONS(2360),
    [anon_sym_If] = ACTIONS(2360),
    [anon_sym_else] = ACTIONS(2360),
    [anon_sym_ELSE] = ACTIONS(2360),
    [anon_sym_Else] = ACTIONS(2360),
    [anon_sym_case] = ACTIONS(2360),
    [anon_sym_CASE] = ACTIONS(2360),
    [anon_sym_Case] = ACTIONS(2360),
    [anon_sym_for] = ACTIONS(2360),
    [anon_sym_FOR] = ACTIONS(2360),
    [anon_sym_For] = ACTIONS(2360),
    [anon_sym_foreach] = ACTIONS(2360),
    [anon_sym_FOREACH] = ACTIONS(2360),
    [anon_sym_Foreach] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2360),
    [anon_sym_WHILE] = ACTIONS(2360),
    [anon_sym_While] = ACTIONS(2360),
    [anon_sym_repeat] = ACTIONS(2360),
    [anon_sym_REPEAT] = ACTIONS(2360),
    [anon_sym_Repeat] = ACTIONS(2360),
    [anon_sym_exit] = ACTIONS(2360),
    [anon_sym_EXIT] = ACTIONS(2360),
    [anon_sym_Exit] = ACTIONS(2360),
    [anon_sym_continue] = ACTIONS(2360),
    [anon_sym_CONTINUE] = ACTIONS(2360),
    [anon_sym_Continue] = ACTIONS(2360),
    [anon_sym_break] = ACTIONS(2360),
    [anon_sym_BREAK] = ACTIONS(2360),
    [anon_sym_Break] = ACTIONS(2360),
    [anon_sym_with] = ACTIONS(2360),
    [anon_sym_WITH] = ACTIONS(2360),
    [anon_sym_With] = ACTIONS(2360),
    [sym_asserterror_keyword] = ACTIONS(2362),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_IN] = ACTIONS(2360),
    [anon_sym_In] = ACTIONS(2360),
    [sym_page_keyword] = ACTIONS(2360),
    [anon_sym_codeunit] = ACTIONS(2360),
    [anon_sym_CODEUNIT] = ACTIONS(2360),
    [anon_sym_Codeunit] = ACTIONS(2360),
    [anon_sym_CodeUnit] = ACTIONS(2360),
    [anon_sym_COdeunit] = ACTIONS(2360),
    [anon_sym_codeUnit] = ACTIONS(2360),
    [sym_report_keyword] = ACTIONS(2360),
    [sym_query_keyword] = ACTIONS(2360),
    [anon_sym_xmlport] = ACTIONS(2360),
    [anon_sym_XMLPORT] = ACTIONS(2360),
    [anon_sym_Xmlport] = ACTIONS(2360),
    [anon_sym_XMLport] = ACTIONS(2360),
    [anon_sym_XMLPort] = ACTIONS(2360),
    [anon_sym_XmlPort] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_ENUM] = ACTIONS(2360),
    [anon_sym_Enum] = ACTIONS(2360),
    [anon_sym_eNUM] = ACTIONS(2360),
    [anon_sym_eNum] = ACTIONS(2360),
    [anon_sym_ENum] = ACTIONS(2360),
    [sym_quoted_identifier] = ACTIONS(2362),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2362),
    [sym_integer] = ACTIONS(2360),
    [sym_continue_as_identifier] = ACTIONS(2362),
    [sym_preproc_open] = ACTIONS(2362),
    [sym_preproc_close] = ACTIONS(2362),
  },
  [STATE(973)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2278),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2308),
    [anon_sym_AND] = ACTIONS(2310),
    [anon_sym_And] = ACTIONS(2312),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(974)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2278),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2308),
    [anon_sym_AND] = ACTIONS(2310),
    [anon_sym_And] = ACTIONS(2312),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(975)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2278),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2308),
    [anon_sym_AND] = ACTIONS(2310),
    [anon_sym_And] = ACTIONS(2312),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(976)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2278),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2308),
    [anon_sym_AND] = ACTIONS(2310),
    [anon_sym_And] = ACTIONS(2312),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(977)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2364),
    [anon_sym_SEMI] = ACTIONS(2366),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2366),
    [anon_sym_DASH] = ACTIONS(2278),
    [aux_sym_boolean_token1] = ACTIONS(2364),
    [aux_sym_boolean_token2] = ACTIONS(2364),
    [sym_decimal] = ACTIONS(2364),
    [anon_sym_LPAREN] = ACTIONS(2366),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2364),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2364),
    [aux_sym_basic_type_token21] = ACTIONS(2364),
    [aux_sym_basic_type_token22] = ACTIONS(2364),
    [aux_sym_basic_type_token48] = ACTIONS(2364),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2364),
    [anon_sym_POUNDif] = ACTIONS(2366),
    [anon_sym_POUNDIF] = ACTIONS(2366),
    [anon_sym_POUNDIf] = ACTIONS(2366),
    [anon_sym_not] = ACTIONS(2364),
    [anon_sym_NOT] = ACTIONS(2364),
    [anon_sym_Not] = ACTIONS(2364),
    [anon_sym_POUNDelif] = ACTIONS(2366),
    [anon_sym_POUNDELIF] = ACTIONS(2366),
    [anon_sym_POUNDElif] = ACTIONS(2366),
    [anon_sym_POUNDelse] = ACTIONS(2366),
    [anon_sym_POUNDELSE] = ACTIONS(2366),
    [anon_sym_POUNDElse] = ACTIONS(2366),
    [anon_sym_POUNDendif] = ACTIONS(2366),
    [anon_sym_POUNDENDIF] = ACTIONS(2366),
    [anon_sym_POUNDEndif] = ACTIONS(2366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2366),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2364),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2364),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_GT_EQ] = ACTIONS(2366),
    [anon_sym_LT_EQ] = ACTIONS(2366),
    [anon_sym_GT] = ACTIONS(2364),
    [anon_sym_LT] = ACTIONS(2364),
    [anon_sym_LT_GT] = ACTIONS(2366),
    [anon_sym_and] = ACTIONS(2364),
    [anon_sym_AND] = ACTIONS(2364),
    [anon_sym_And] = ACTIONS(2364),
    [anon_sym_or] = ACTIONS(2364),
    [anon_sym_OR] = ACTIONS(2364),
    [anon_sym_Or] = ACTIONS(2364),
    [anon_sym_xor] = ACTIONS(2364),
    [anon_sym_XOR] = ACTIONS(2364),
    [anon_sym_Xor] = ACTIONS(2364),
    [anon_sym_QMARK] = ACTIONS(2366),
    [sym_datetime_literal] = ACTIONS(2366),
    [sym_date_literal] = ACTIONS(2364),
    [sym_time_literal] = ACTIONS(2364),
    [sym_biginteger_literal] = ACTIONS(2366),
    [anon_sym_if] = ACTIONS(2364),
    [anon_sym_IF] = ACTIONS(2364),
    [anon_sym_If] = ACTIONS(2364),
    [anon_sym_else] = ACTIONS(2364),
    [anon_sym_ELSE] = ACTIONS(2364),
    [anon_sym_Else] = ACTIONS(2364),
    [anon_sym_case] = ACTIONS(2364),
    [anon_sym_CASE] = ACTIONS(2364),
    [anon_sym_Case] = ACTIONS(2364),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_FOR] = ACTIONS(2364),
    [anon_sym_For] = ACTIONS(2364),
    [anon_sym_foreach] = ACTIONS(2364),
    [anon_sym_FOREACH] = ACTIONS(2364),
    [anon_sym_Foreach] = ACTIONS(2364),
    [anon_sym_while] = ACTIONS(2364),
    [anon_sym_WHILE] = ACTIONS(2364),
    [anon_sym_While] = ACTIONS(2364),
    [anon_sym_repeat] = ACTIONS(2364),
    [anon_sym_REPEAT] = ACTIONS(2364),
    [anon_sym_Repeat] = ACTIONS(2364),
    [anon_sym_exit] = ACTIONS(2364),
    [anon_sym_EXIT] = ACTIONS(2364),
    [anon_sym_Exit] = ACTIONS(2364),
    [anon_sym_continue] = ACTIONS(2364),
    [anon_sym_CONTINUE] = ACTIONS(2364),
    [anon_sym_Continue] = ACTIONS(2364),
    [anon_sym_break] = ACTIONS(2364),
    [anon_sym_BREAK] = ACTIONS(2364),
    [anon_sym_Break] = ACTIONS(2364),
    [anon_sym_with] = ACTIONS(2364),
    [anon_sym_WITH] = ACTIONS(2364),
    [anon_sym_With] = ACTIONS(2364),
    [sym_asserterror_keyword] = ACTIONS(2366),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2364),
    [anon_sym_codeunit] = ACTIONS(2364),
    [anon_sym_CODEUNIT] = ACTIONS(2364),
    [anon_sym_Codeunit] = ACTIONS(2364),
    [anon_sym_CodeUnit] = ACTIONS(2364),
    [anon_sym_COdeunit] = ACTIONS(2364),
    [anon_sym_codeUnit] = ACTIONS(2364),
    [sym_report_keyword] = ACTIONS(2364),
    [sym_query_keyword] = ACTIONS(2364),
    [anon_sym_xmlport] = ACTIONS(2364),
    [anon_sym_XMLPORT] = ACTIONS(2364),
    [anon_sym_Xmlport] = ACTIONS(2364),
    [anon_sym_XMLport] = ACTIONS(2364),
    [anon_sym_XMLPort] = ACTIONS(2364),
    [anon_sym_XmlPort] = ACTIONS(2364),
    [anon_sym_enum] = ACTIONS(2364),
    [anon_sym_ENUM] = ACTIONS(2364),
    [anon_sym_Enum] = ACTIONS(2364),
    [anon_sym_eNUM] = ACTIONS(2364),
    [anon_sym_eNum] = ACTIONS(2364),
    [anon_sym_ENum] = ACTIONS(2364),
    [sym_quoted_identifier] = ACTIONS(2366),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2366),
    [sym_integer] = ACTIONS(2364),
    [sym_continue_as_identifier] = ACTIONS(2366),
    [sym_preproc_open] = ACTIONS(2366),
    [sym_preproc_close] = ACTIONS(2366),
  },
  [STATE(978)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2368),
    [anon_sym_SEMI] = ACTIONS(2370),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2278),
    [aux_sym_boolean_token1] = ACTIONS(2368),
    [aux_sym_boolean_token2] = ACTIONS(2368),
    [sym_decimal] = ACTIONS(2368),
    [anon_sym_LPAREN] = ACTIONS(2370),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2368),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2368),
    [aux_sym_basic_type_token21] = ACTIONS(2368),
    [aux_sym_basic_type_token22] = ACTIONS(2368),
    [aux_sym_basic_type_token48] = ACTIONS(2368),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2368),
    [anon_sym_POUNDif] = ACTIONS(2370),
    [anon_sym_POUNDIF] = ACTIONS(2370),
    [anon_sym_POUNDIf] = ACTIONS(2370),
    [anon_sym_not] = ACTIONS(2368),
    [anon_sym_NOT] = ACTIONS(2368),
    [anon_sym_Not] = ACTIONS(2368),
    [anon_sym_POUNDelif] = ACTIONS(2370),
    [anon_sym_POUNDELIF] = ACTIONS(2370),
    [anon_sym_POUNDElif] = ACTIONS(2370),
    [anon_sym_POUNDelse] = ACTIONS(2370),
    [anon_sym_POUNDELSE] = ACTIONS(2370),
    [anon_sym_POUNDElse] = ACTIONS(2370),
    [anon_sym_POUNDendif] = ACTIONS(2370),
    [anon_sym_POUNDENDIF] = ACTIONS(2370),
    [anon_sym_POUNDEndif] = ACTIONS(2370),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2370),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2368),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2368),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2308),
    [anon_sym_AND] = ACTIONS(2310),
    [anon_sym_And] = ACTIONS(2312),
    [anon_sym_or] = ACTIONS(2332),
    [anon_sym_OR] = ACTIONS(2334),
    [anon_sym_Or] = ACTIONS(2336),
    [anon_sym_xor] = ACTIONS(2338),
    [anon_sym_XOR] = ACTIONS(2340),
    [anon_sym_Xor] = ACTIONS(2342),
    [anon_sym_QMARK] = ACTIONS(2344),
    [sym_datetime_literal] = ACTIONS(2370),
    [sym_date_literal] = ACTIONS(2368),
    [sym_time_literal] = ACTIONS(2368),
    [sym_biginteger_literal] = ACTIONS(2370),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_IF] = ACTIONS(2368),
    [anon_sym_If] = ACTIONS(2368),
    [anon_sym_else] = ACTIONS(2368),
    [anon_sym_ELSE] = ACTIONS(2368),
    [anon_sym_Else] = ACTIONS(2368),
    [anon_sym_case] = ACTIONS(2368),
    [anon_sym_CASE] = ACTIONS(2368),
    [anon_sym_Case] = ACTIONS(2368),
    [anon_sym_for] = ACTIONS(2368),
    [anon_sym_FOR] = ACTIONS(2368),
    [anon_sym_For] = ACTIONS(2368),
    [anon_sym_foreach] = ACTIONS(2368),
    [anon_sym_FOREACH] = ACTIONS(2368),
    [anon_sym_Foreach] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2368),
    [anon_sym_WHILE] = ACTIONS(2368),
    [anon_sym_While] = ACTIONS(2368),
    [anon_sym_repeat] = ACTIONS(2368),
    [anon_sym_REPEAT] = ACTIONS(2368),
    [anon_sym_Repeat] = ACTIONS(2368),
    [anon_sym_exit] = ACTIONS(2368),
    [anon_sym_EXIT] = ACTIONS(2368),
    [anon_sym_Exit] = ACTIONS(2368),
    [anon_sym_continue] = ACTIONS(2368),
    [anon_sym_CONTINUE] = ACTIONS(2368),
    [anon_sym_Continue] = ACTIONS(2368),
    [anon_sym_break] = ACTIONS(2368),
    [anon_sym_BREAK] = ACTIONS(2368),
    [anon_sym_Break] = ACTIONS(2368),
    [anon_sym_with] = ACTIONS(2368),
    [anon_sym_WITH] = ACTIONS(2368),
    [anon_sym_With] = ACTIONS(2368),
    [sym_asserterror_keyword] = ACTIONS(2370),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2368),
    [anon_sym_codeunit] = ACTIONS(2368),
    [anon_sym_CODEUNIT] = ACTIONS(2368),
    [anon_sym_Codeunit] = ACTIONS(2368),
    [anon_sym_CodeUnit] = ACTIONS(2368),
    [anon_sym_COdeunit] = ACTIONS(2368),
    [anon_sym_codeUnit] = ACTIONS(2368),
    [sym_report_keyword] = ACTIONS(2368),
    [sym_query_keyword] = ACTIONS(2368),
    [anon_sym_xmlport] = ACTIONS(2368),
    [anon_sym_XMLPORT] = ACTIONS(2368),
    [anon_sym_Xmlport] = ACTIONS(2368),
    [anon_sym_XMLport] = ACTIONS(2368),
    [anon_sym_XMLPort] = ACTIONS(2368),
    [anon_sym_XmlPort] = ACTIONS(2368),
    [anon_sym_enum] = ACTIONS(2368),
    [anon_sym_ENUM] = ACTIONS(2368),
    [anon_sym_Enum] = ACTIONS(2368),
    [anon_sym_eNUM] = ACTIONS(2368),
    [anon_sym_eNum] = ACTIONS(2368),
    [anon_sym_ENum] = ACTIONS(2368),
    [sym_quoted_identifier] = ACTIONS(2370),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2370),
    [sym_integer] = ACTIONS(2368),
    [sym_continue_as_identifier] = ACTIONS(2370),
    [sym_preproc_open] = ACTIONS(2370),
    [sym_preproc_close] = ACTIONS(2370),
  },
  [STATE(979)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2372),
    [anon_sym_SEMI] = ACTIONS(2374),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2278),
    [aux_sym_boolean_token1] = ACTIONS(2372),
    [aux_sym_boolean_token2] = ACTIONS(2372),
    [sym_decimal] = ACTIONS(2372),
    [anon_sym_LPAREN] = ACTIONS(2374),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2372),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2372),
    [aux_sym_basic_type_token21] = ACTIONS(2372),
    [aux_sym_basic_type_token22] = ACTIONS(2372),
    [aux_sym_basic_type_token48] = ACTIONS(2372),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2372),
    [anon_sym_POUNDif] = ACTIONS(2374),
    [anon_sym_POUNDIF] = ACTIONS(2374),
    [anon_sym_POUNDIf] = ACTIONS(2374),
    [anon_sym_not] = ACTIONS(2372),
    [anon_sym_NOT] = ACTIONS(2372),
    [anon_sym_Not] = ACTIONS(2372),
    [anon_sym_POUNDelif] = ACTIONS(2374),
    [anon_sym_POUNDELIF] = ACTIONS(2374),
    [anon_sym_POUNDElif] = ACTIONS(2374),
    [anon_sym_POUNDelse] = ACTIONS(2374),
    [anon_sym_POUNDELSE] = ACTIONS(2374),
    [anon_sym_POUNDElse] = ACTIONS(2374),
    [anon_sym_POUNDendif] = ACTIONS(2374),
    [anon_sym_POUNDENDIF] = ACTIONS(2374),
    [anon_sym_POUNDEndif] = ACTIONS(2374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2376),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2372),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2372),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2308),
    [anon_sym_AND] = ACTIONS(2310),
    [anon_sym_And] = ACTIONS(2312),
    [anon_sym_or] = ACTIONS(2332),
    [anon_sym_OR] = ACTIONS(2334),
    [anon_sym_Or] = ACTIONS(2336),
    [anon_sym_xor] = ACTIONS(2338),
    [anon_sym_XOR] = ACTIONS(2340),
    [anon_sym_Xor] = ACTIONS(2342),
    [anon_sym_QMARK] = ACTIONS(2344),
    [sym_datetime_literal] = ACTIONS(2374),
    [sym_date_literal] = ACTIONS(2372),
    [sym_time_literal] = ACTIONS(2372),
    [sym_biginteger_literal] = ACTIONS(2374),
    [anon_sym_if] = ACTIONS(2372),
    [anon_sym_IF] = ACTIONS(2372),
    [anon_sym_If] = ACTIONS(2372),
    [anon_sym_else] = ACTIONS(2372),
    [anon_sym_ELSE] = ACTIONS(2372),
    [anon_sym_Else] = ACTIONS(2372),
    [anon_sym_case] = ACTIONS(2372),
    [anon_sym_CASE] = ACTIONS(2372),
    [anon_sym_Case] = ACTIONS(2372),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_FOR] = ACTIONS(2372),
    [anon_sym_For] = ACTIONS(2372),
    [anon_sym_foreach] = ACTIONS(2372),
    [anon_sym_FOREACH] = ACTIONS(2372),
    [anon_sym_Foreach] = ACTIONS(2372),
    [anon_sym_while] = ACTIONS(2372),
    [anon_sym_WHILE] = ACTIONS(2372),
    [anon_sym_While] = ACTIONS(2372),
    [anon_sym_repeat] = ACTIONS(2372),
    [anon_sym_REPEAT] = ACTIONS(2372),
    [anon_sym_Repeat] = ACTIONS(2372),
    [anon_sym_exit] = ACTIONS(2372),
    [anon_sym_EXIT] = ACTIONS(2372),
    [anon_sym_Exit] = ACTIONS(2372),
    [anon_sym_continue] = ACTIONS(2372),
    [anon_sym_CONTINUE] = ACTIONS(2372),
    [anon_sym_Continue] = ACTIONS(2372),
    [anon_sym_break] = ACTIONS(2372),
    [anon_sym_BREAK] = ACTIONS(2372),
    [anon_sym_Break] = ACTIONS(2372),
    [anon_sym_with] = ACTIONS(2372),
    [anon_sym_WITH] = ACTIONS(2372),
    [anon_sym_With] = ACTIONS(2372),
    [sym_asserterror_keyword] = ACTIONS(2374),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2372),
    [anon_sym_codeunit] = ACTIONS(2372),
    [anon_sym_CODEUNIT] = ACTIONS(2372),
    [anon_sym_Codeunit] = ACTIONS(2372),
    [anon_sym_CodeUnit] = ACTIONS(2372),
    [anon_sym_COdeunit] = ACTIONS(2372),
    [anon_sym_codeUnit] = ACTIONS(2372),
    [sym_report_keyword] = ACTIONS(2372),
    [sym_query_keyword] = ACTIONS(2372),
    [anon_sym_xmlport] = ACTIONS(2372),
    [anon_sym_XMLPORT] = ACTIONS(2372),
    [anon_sym_Xmlport] = ACTIONS(2372),
    [anon_sym_XMLport] = ACTIONS(2372),
    [anon_sym_XMLPort] = ACTIONS(2372),
    [anon_sym_XmlPort] = ACTIONS(2372),
    [anon_sym_enum] = ACTIONS(2372),
    [anon_sym_ENUM] = ACTIONS(2372),
    [anon_sym_Enum] = ACTIONS(2372),
    [anon_sym_eNUM] = ACTIONS(2372),
    [anon_sym_eNum] = ACTIONS(2372),
    [anon_sym_ENum] = ACTIONS(2372),
    [sym_quoted_identifier] = ACTIONS(2374),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2374),
    [sym_integer] = ACTIONS(2372),
    [sym_continue_as_identifier] = ACTIONS(2374),
    [sym_preproc_open] = ACTIONS(2374),
    [sym_preproc_close] = ACTIONS(2374),
  },
  [STATE(980)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2378),
    [anon_sym_SEMI] = ACTIONS(2380),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2378),
    [aux_sym_boolean_token1] = ACTIONS(2378),
    [aux_sym_boolean_token2] = ACTIONS(2378),
    [sym_decimal] = ACTIONS(2378),
    [anon_sym_LPAREN] = ACTIONS(2380),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2378),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2380),
    [aux_sym_record_type_token1] = ACTIONS(2378),
    [aux_sym_basic_type_token21] = ACTIONS(2378),
    [aux_sym_basic_type_token22] = ACTIONS(2378),
    [aux_sym_basic_type_token48] = ACTIONS(2378),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2378),
    [anon_sym_POUNDif] = ACTIONS(2380),
    [anon_sym_POUNDIF] = ACTIONS(2380),
    [anon_sym_POUNDIf] = ACTIONS(2380),
    [anon_sym_not] = ACTIONS(2378),
    [anon_sym_NOT] = ACTIONS(2378),
    [anon_sym_Not] = ACTIONS(2378),
    [anon_sym_POUNDelif] = ACTIONS(2380),
    [anon_sym_POUNDELIF] = ACTIONS(2380),
    [anon_sym_POUNDElif] = ACTIONS(2380),
    [anon_sym_POUNDelse] = ACTIONS(2380),
    [anon_sym_POUNDELSE] = ACTIONS(2380),
    [anon_sym_POUNDElse] = ACTIONS(2380),
    [anon_sym_POUNDendif] = ACTIONS(2380),
    [anon_sym_POUNDENDIF] = ACTIONS(2380),
    [anon_sym_POUNDEndif] = ACTIONS(2380),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2330),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2378),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2378),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2378),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2308),
    [anon_sym_AND] = ACTIONS(2310),
    [anon_sym_And] = ACTIONS(2312),
    [anon_sym_or] = ACTIONS(2332),
    [anon_sym_OR] = ACTIONS(2334),
    [anon_sym_Or] = ACTIONS(2336),
    [anon_sym_xor] = ACTIONS(2338),
    [anon_sym_XOR] = ACTIONS(2340),
    [anon_sym_Xor] = ACTIONS(2342),
    [anon_sym_QMARK] = ACTIONS(2344),
    [sym_datetime_literal] = ACTIONS(2380),
    [sym_date_literal] = ACTIONS(2378),
    [sym_time_literal] = ACTIONS(2378),
    [sym_biginteger_literal] = ACTIONS(2380),
    [anon_sym_if] = ACTIONS(2378),
    [anon_sym_IF] = ACTIONS(2378),
    [anon_sym_If] = ACTIONS(2378),
    [anon_sym_else] = ACTIONS(2378),
    [anon_sym_ELSE] = ACTIONS(2378),
    [anon_sym_Else] = ACTIONS(2378),
    [anon_sym_case] = ACTIONS(2378),
    [anon_sym_CASE] = ACTIONS(2378),
    [anon_sym_Case] = ACTIONS(2378),
    [anon_sym_for] = ACTIONS(2378),
    [anon_sym_FOR] = ACTIONS(2378),
    [anon_sym_For] = ACTIONS(2378),
    [anon_sym_foreach] = ACTIONS(2378),
    [anon_sym_FOREACH] = ACTIONS(2378),
    [anon_sym_Foreach] = ACTIONS(2378),
    [anon_sym_while] = ACTIONS(2378),
    [anon_sym_WHILE] = ACTIONS(2378),
    [anon_sym_While] = ACTIONS(2378),
    [anon_sym_repeat] = ACTIONS(2378),
    [anon_sym_REPEAT] = ACTIONS(2378),
    [anon_sym_Repeat] = ACTIONS(2378),
    [anon_sym_exit] = ACTIONS(2378),
    [anon_sym_EXIT] = ACTIONS(2378),
    [anon_sym_Exit] = ACTIONS(2378),
    [anon_sym_continue] = ACTIONS(2378),
    [anon_sym_CONTINUE] = ACTIONS(2378),
    [anon_sym_Continue] = ACTIONS(2378),
    [anon_sym_break] = ACTIONS(2378),
    [anon_sym_BREAK] = ACTIONS(2378),
    [anon_sym_Break] = ACTIONS(2378),
    [anon_sym_with] = ACTIONS(2378),
    [anon_sym_WITH] = ACTIONS(2378),
    [anon_sym_With] = ACTIONS(2378),
    [sym_asserterror_keyword] = ACTIONS(2380),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2378),
    [anon_sym_codeunit] = ACTIONS(2378),
    [anon_sym_CODEUNIT] = ACTIONS(2378),
    [anon_sym_Codeunit] = ACTIONS(2378),
    [anon_sym_CodeUnit] = ACTIONS(2378),
    [anon_sym_COdeunit] = ACTIONS(2378),
    [anon_sym_codeUnit] = ACTIONS(2378),
    [sym_report_keyword] = ACTIONS(2378),
    [sym_query_keyword] = ACTIONS(2378),
    [anon_sym_xmlport] = ACTIONS(2378),
    [anon_sym_XMLPORT] = ACTIONS(2378),
    [anon_sym_Xmlport] = ACTIONS(2378),
    [anon_sym_XMLport] = ACTIONS(2378),
    [anon_sym_XMLPort] = ACTIONS(2378),
    [anon_sym_XmlPort] = ACTIONS(2378),
    [anon_sym_enum] = ACTIONS(2378),
    [anon_sym_ENUM] = ACTIONS(2378),
    [anon_sym_Enum] = ACTIONS(2378),
    [anon_sym_eNUM] = ACTIONS(2378),
    [anon_sym_eNum] = ACTIONS(2378),
    [anon_sym_ENum] = ACTIONS(2378),
    [sym_quoted_identifier] = ACTIONS(2380),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2380),
    [sym_integer] = ACTIONS(2378),
    [sym_continue_as_identifier] = ACTIONS(2380),
    [sym_preproc_open] = ACTIONS(2380),
    [sym_preproc_close] = ACTIONS(2380),
  },
  [STATE(981)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2382),
    [anon_sym_SEMI] = ACTIONS(2385),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2278),
    [aux_sym_boolean_token1] = ACTIONS(2382),
    [aux_sym_boolean_token2] = ACTIONS(2382),
    [sym_decimal] = ACTIONS(2382),
    [anon_sym_LPAREN] = ACTIONS(2385),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2382),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2382),
    [aux_sym_basic_type_token21] = ACTIONS(2382),
    [aux_sym_basic_type_token22] = ACTIONS(2382),
    [aux_sym_basic_type_token48] = ACTIONS(2382),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2382),
    [anon_sym_POUNDif] = ACTIONS(2385),
    [anon_sym_POUNDIF] = ACTIONS(2385),
    [anon_sym_POUNDIf] = ACTIONS(2385),
    [anon_sym_not] = ACTIONS(2382),
    [anon_sym_NOT] = ACTIONS(2382),
    [anon_sym_Not] = ACTIONS(2382),
    [anon_sym_POUNDelif] = ACTIONS(2385),
    [anon_sym_POUNDELIF] = ACTIONS(2385),
    [anon_sym_POUNDElif] = ACTIONS(2385),
    [anon_sym_POUNDelse] = ACTIONS(2385),
    [anon_sym_POUNDELSE] = ACTIONS(2385),
    [anon_sym_POUNDElse] = ACTIONS(2385),
    [anon_sym_POUNDendif] = ACTIONS(2385),
    [anon_sym_POUNDENDIF] = ACTIONS(2385),
    [anon_sym_POUNDEndif] = ACTIONS(2385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2330),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2382),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2308),
    [anon_sym_AND] = ACTIONS(2310),
    [anon_sym_And] = ACTIONS(2312),
    [anon_sym_or] = ACTIONS(2332),
    [anon_sym_OR] = ACTIONS(2334),
    [anon_sym_Or] = ACTIONS(2336),
    [anon_sym_xor] = ACTIONS(2338),
    [anon_sym_XOR] = ACTIONS(2340),
    [anon_sym_Xor] = ACTIONS(2342),
    [anon_sym_QMARK] = ACTIONS(2344),
    [sym_datetime_literal] = ACTIONS(2385),
    [sym_date_literal] = ACTIONS(2382),
    [sym_time_literal] = ACTIONS(2382),
    [sym_biginteger_literal] = ACTIONS(2385),
    [anon_sym_if] = ACTIONS(2382),
    [anon_sym_IF] = ACTIONS(2382),
    [anon_sym_If] = ACTIONS(2382),
    [anon_sym_else] = ACTIONS(2382),
    [anon_sym_ELSE] = ACTIONS(2382),
    [anon_sym_Else] = ACTIONS(2382),
    [anon_sym_case] = ACTIONS(2382),
    [anon_sym_CASE] = ACTIONS(2382),
    [anon_sym_Case] = ACTIONS(2382),
    [anon_sym_for] = ACTIONS(2382),
    [anon_sym_FOR] = ACTIONS(2382),
    [anon_sym_For] = ACTIONS(2382),
    [anon_sym_foreach] = ACTIONS(2382),
    [anon_sym_FOREACH] = ACTIONS(2382),
    [anon_sym_Foreach] = ACTIONS(2382),
    [anon_sym_while] = ACTIONS(2382),
    [anon_sym_WHILE] = ACTIONS(2382),
    [anon_sym_While] = ACTIONS(2382),
    [anon_sym_repeat] = ACTIONS(2382),
    [anon_sym_REPEAT] = ACTIONS(2382),
    [anon_sym_Repeat] = ACTIONS(2382),
    [anon_sym_exit] = ACTIONS(2382),
    [anon_sym_EXIT] = ACTIONS(2382),
    [anon_sym_Exit] = ACTIONS(2382),
    [anon_sym_continue] = ACTIONS(2382),
    [anon_sym_CONTINUE] = ACTIONS(2382),
    [anon_sym_Continue] = ACTIONS(2382),
    [anon_sym_break] = ACTIONS(2382),
    [anon_sym_BREAK] = ACTIONS(2382),
    [anon_sym_Break] = ACTIONS(2382),
    [anon_sym_with] = ACTIONS(2382),
    [anon_sym_WITH] = ACTIONS(2382),
    [anon_sym_With] = ACTIONS(2382),
    [sym_asserterror_keyword] = ACTIONS(2385),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2382),
    [anon_sym_codeunit] = ACTIONS(2382),
    [anon_sym_CODEUNIT] = ACTIONS(2382),
    [anon_sym_Codeunit] = ACTIONS(2382),
    [anon_sym_CodeUnit] = ACTIONS(2382),
    [anon_sym_COdeunit] = ACTIONS(2382),
    [anon_sym_codeUnit] = ACTIONS(2382),
    [sym_report_keyword] = ACTIONS(2382),
    [sym_query_keyword] = ACTIONS(2382),
    [anon_sym_xmlport] = ACTIONS(2382),
    [anon_sym_XMLPORT] = ACTIONS(2382),
    [anon_sym_Xmlport] = ACTIONS(2382),
    [anon_sym_XMLport] = ACTIONS(2382),
    [anon_sym_XMLPort] = ACTIONS(2382),
    [anon_sym_XmlPort] = ACTIONS(2382),
    [anon_sym_enum] = ACTIONS(2382),
    [anon_sym_ENUM] = ACTIONS(2382),
    [anon_sym_Enum] = ACTIONS(2382),
    [anon_sym_eNUM] = ACTIONS(2382),
    [anon_sym_eNum] = ACTIONS(2382),
    [anon_sym_ENum] = ACTIONS(2382),
    [sym_quoted_identifier] = ACTIONS(2385),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2385),
    [sym_integer] = ACTIONS(2382),
    [sym_continue_as_identifier] = ACTIONS(2385),
    [sym_preproc_open] = ACTIONS(2385),
    [sym_preproc_close] = ACTIONS(2385),
  },
  [STATE(982)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2388),
    [anon_sym_SEMI] = ACTIONS(2390),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2278),
    [aux_sym_boolean_token1] = ACTIONS(2388),
    [aux_sym_boolean_token2] = ACTIONS(2388),
    [sym_decimal] = ACTIONS(2388),
    [anon_sym_LPAREN] = ACTIONS(2390),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2388),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2388),
    [aux_sym_basic_type_token21] = ACTIONS(2388),
    [aux_sym_basic_type_token22] = ACTIONS(2388),
    [aux_sym_basic_type_token48] = ACTIONS(2388),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2388),
    [anon_sym_POUNDif] = ACTIONS(2390),
    [anon_sym_POUNDIF] = ACTIONS(2390),
    [anon_sym_POUNDIf] = ACTIONS(2390),
    [anon_sym_not] = ACTIONS(2388),
    [anon_sym_NOT] = ACTIONS(2388),
    [anon_sym_Not] = ACTIONS(2388),
    [anon_sym_POUNDelif] = ACTIONS(2390),
    [anon_sym_POUNDELIF] = ACTIONS(2390),
    [anon_sym_POUNDElif] = ACTIONS(2390),
    [anon_sym_POUNDelse] = ACTIONS(2390),
    [anon_sym_POUNDELSE] = ACTIONS(2390),
    [anon_sym_POUNDElse] = ACTIONS(2390),
    [anon_sym_POUNDendif] = ACTIONS(2390),
    [anon_sym_POUNDENDIF] = ACTIONS(2390),
    [anon_sym_POUNDEndif] = ACTIONS(2390),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2330),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2388),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2388),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2308),
    [anon_sym_AND] = ACTIONS(2310),
    [anon_sym_And] = ACTIONS(2312),
    [anon_sym_or] = ACTIONS(2332),
    [anon_sym_OR] = ACTIONS(2334),
    [anon_sym_Or] = ACTIONS(2336),
    [anon_sym_xor] = ACTIONS(2338),
    [anon_sym_XOR] = ACTIONS(2340),
    [anon_sym_Xor] = ACTIONS(2342),
    [anon_sym_QMARK] = ACTIONS(2344),
    [sym_datetime_literal] = ACTIONS(2390),
    [sym_date_literal] = ACTIONS(2388),
    [sym_time_literal] = ACTIONS(2388),
    [sym_biginteger_literal] = ACTIONS(2390),
    [anon_sym_if] = ACTIONS(2388),
    [anon_sym_IF] = ACTIONS(2388),
    [anon_sym_If] = ACTIONS(2388),
    [anon_sym_else] = ACTIONS(2388),
    [anon_sym_ELSE] = ACTIONS(2388),
    [anon_sym_Else] = ACTIONS(2388),
    [anon_sym_case] = ACTIONS(2388),
    [anon_sym_CASE] = ACTIONS(2388),
    [anon_sym_Case] = ACTIONS(2388),
    [anon_sym_for] = ACTIONS(2388),
    [anon_sym_FOR] = ACTIONS(2388),
    [anon_sym_For] = ACTIONS(2388),
    [anon_sym_foreach] = ACTIONS(2388),
    [anon_sym_FOREACH] = ACTIONS(2388),
    [anon_sym_Foreach] = ACTIONS(2388),
    [anon_sym_while] = ACTIONS(2388),
    [anon_sym_WHILE] = ACTIONS(2388),
    [anon_sym_While] = ACTIONS(2388),
    [anon_sym_repeat] = ACTIONS(2388),
    [anon_sym_REPEAT] = ACTIONS(2388),
    [anon_sym_Repeat] = ACTIONS(2388),
    [anon_sym_exit] = ACTIONS(2388),
    [anon_sym_EXIT] = ACTIONS(2388),
    [anon_sym_Exit] = ACTIONS(2388),
    [anon_sym_continue] = ACTIONS(2388),
    [anon_sym_CONTINUE] = ACTIONS(2388),
    [anon_sym_Continue] = ACTIONS(2388),
    [anon_sym_break] = ACTIONS(2388),
    [anon_sym_BREAK] = ACTIONS(2388),
    [anon_sym_Break] = ACTIONS(2388),
    [anon_sym_with] = ACTIONS(2388),
    [anon_sym_WITH] = ACTIONS(2388),
    [anon_sym_With] = ACTIONS(2388),
    [sym_asserterror_keyword] = ACTIONS(2390),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2388),
    [anon_sym_codeunit] = ACTIONS(2388),
    [anon_sym_CODEUNIT] = ACTIONS(2388),
    [anon_sym_Codeunit] = ACTIONS(2388),
    [anon_sym_CodeUnit] = ACTIONS(2388),
    [anon_sym_COdeunit] = ACTIONS(2388),
    [anon_sym_codeUnit] = ACTIONS(2388),
    [sym_report_keyword] = ACTIONS(2388),
    [sym_query_keyword] = ACTIONS(2388),
    [anon_sym_xmlport] = ACTIONS(2388),
    [anon_sym_XMLPORT] = ACTIONS(2388),
    [anon_sym_Xmlport] = ACTIONS(2388),
    [anon_sym_XMLport] = ACTIONS(2388),
    [anon_sym_XMLPort] = ACTIONS(2388),
    [anon_sym_XmlPort] = ACTIONS(2388),
    [anon_sym_enum] = ACTIONS(2388),
    [anon_sym_ENUM] = ACTIONS(2388),
    [anon_sym_Enum] = ACTIONS(2388),
    [anon_sym_eNUM] = ACTIONS(2388),
    [anon_sym_eNum] = ACTIONS(2388),
    [anon_sym_ENum] = ACTIONS(2388),
    [sym_quoted_identifier] = ACTIONS(2390),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2390),
    [sym_integer] = ACTIONS(2388),
    [sym_continue_as_identifier] = ACTIONS(2390),
    [sym_preproc_open] = ACTIONS(2390),
    [sym_preproc_close] = ACTIONS(2390),
  },
  [STATE(983)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2392),
    [anon_sym_SEMI] = ACTIONS(2394),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2278),
    [aux_sym_boolean_token1] = ACTIONS(2392),
    [aux_sym_boolean_token2] = ACTIONS(2392),
    [sym_decimal] = ACTIONS(2392),
    [anon_sym_LPAREN] = ACTIONS(2394),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2392),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2392),
    [aux_sym_basic_type_token21] = ACTIONS(2392),
    [aux_sym_basic_type_token22] = ACTIONS(2392),
    [aux_sym_basic_type_token48] = ACTIONS(2392),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2392),
    [anon_sym_POUNDif] = ACTIONS(2394),
    [anon_sym_POUNDIF] = ACTIONS(2394),
    [anon_sym_POUNDIf] = ACTIONS(2394),
    [anon_sym_not] = ACTIONS(2392),
    [anon_sym_NOT] = ACTIONS(2392),
    [anon_sym_Not] = ACTIONS(2392),
    [anon_sym_POUNDelif] = ACTIONS(2394),
    [anon_sym_POUNDELIF] = ACTIONS(2394),
    [anon_sym_POUNDElif] = ACTIONS(2394),
    [anon_sym_POUNDelse] = ACTIONS(2394),
    [anon_sym_POUNDELSE] = ACTIONS(2394),
    [anon_sym_POUNDElse] = ACTIONS(2394),
    [anon_sym_POUNDendif] = ACTIONS(2394),
    [anon_sym_POUNDENDIF] = ACTIONS(2394),
    [anon_sym_POUNDEndif] = ACTIONS(2394),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2330),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2392),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2392),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2308),
    [anon_sym_AND] = ACTIONS(2310),
    [anon_sym_And] = ACTIONS(2312),
    [anon_sym_or] = ACTIONS(2332),
    [anon_sym_OR] = ACTIONS(2334),
    [anon_sym_Or] = ACTIONS(2336),
    [anon_sym_xor] = ACTIONS(2338),
    [anon_sym_XOR] = ACTIONS(2340),
    [anon_sym_Xor] = ACTIONS(2342),
    [anon_sym_QMARK] = ACTIONS(2344),
    [sym_datetime_literal] = ACTIONS(2394),
    [sym_date_literal] = ACTIONS(2392),
    [sym_time_literal] = ACTIONS(2392),
    [sym_biginteger_literal] = ACTIONS(2394),
    [anon_sym_if] = ACTIONS(2392),
    [anon_sym_IF] = ACTIONS(2392),
    [anon_sym_If] = ACTIONS(2392),
    [anon_sym_else] = ACTIONS(2392),
    [anon_sym_ELSE] = ACTIONS(2392),
    [anon_sym_Else] = ACTIONS(2392),
    [anon_sym_case] = ACTIONS(2392),
    [anon_sym_CASE] = ACTIONS(2392),
    [anon_sym_Case] = ACTIONS(2392),
    [anon_sym_for] = ACTIONS(2392),
    [anon_sym_FOR] = ACTIONS(2392),
    [anon_sym_For] = ACTIONS(2392),
    [anon_sym_foreach] = ACTIONS(2392),
    [anon_sym_FOREACH] = ACTIONS(2392),
    [anon_sym_Foreach] = ACTIONS(2392),
    [anon_sym_while] = ACTIONS(2392),
    [anon_sym_WHILE] = ACTIONS(2392),
    [anon_sym_While] = ACTIONS(2392),
    [anon_sym_repeat] = ACTIONS(2392),
    [anon_sym_REPEAT] = ACTIONS(2392),
    [anon_sym_Repeat] = ACTIONS(2392),
    [anon_sym_exit] = ACTIONS(2392),
    [anon_sym_EXIT] = ACTIONS(2392),
    [anon_sym_Exit] = ACTIONS(2392),
    [anon_sym_continue] = ACTIONS(2392),
    [anon_sym_CONTINUE] = ACTIONS(2392),
    [anon_sym_Continue] = ACTIONS(2392),
    [anon_sym_break] = ACTIONS(2392),
    [anon_sym_BREAK] = ACTIONS(2392),
    [anon_sym_Break] = ACTIONS(2392),
    [anon_sym_with] = ACTIONS(2392),
    [anon_sym_WITH] = ACTIONS(2392),
    [anon_sym_With] = ACTIONS(2392),
    [sym_asserterror_keyword] = ACTIONS(2394),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2392),
    [anon_sym_codeunit] = ACTIONS(2392),
    [anon_sym_CODEUNIT] = ACTIONS(2392),
    [anon_sym_Codeunit] = ACTIONS(2392),
    [anon_sym_CodeUnit] = ACTIONS(2392),
    [anon_sym_COdeunit] = ACTIONS(2392),
    [anon_sym_codeUnit] = ACTIONS(2392),
    [sym_report_keyword] = ACTIONS(2392),
    [sym_query_keyword] = ACTIONS(2392),
    [anon_sym_xmlport] = ACTIONS(2392),
    [anon_sym_XMLPORT] = ACTIONS(2392),
    [anon_sym_Xmlport] = ACTIONS(2392),
    [anon_sym_XMLport] = ACTIONS(2392),
    [anon_sym_XMLPort] = ACTIONS(2392),
    [anon_sym_XmlPort] = ACTIONS(2392),
    [anon_sym_enum] = ACTIONS(2392),
    [anon_sym_ENUM] = ACTIONS(2392),
    [anon_sym_Enum] = ACTIONS(2392),
    [anon_sym_eNUM] = ACTIONS(2392),
    [anon_sym_eNum] = ACTIONS(2392),
    [anon_sym_ENum] = ACTIONS(2392),
    [sym_quoted_identifier] = ACTIONS(2394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2394),
    [sym_integer] = ACTIONS(2392),
    [sym_continue_as_identifier] = ACTIONS(2394),
    [sym_preproc_open] = ACTIONS(2394),
    [sym_preproc_close] = ACTIONS(2394),
  },
  [STATE(984)] = {
    [aux_sym_option_member_list_repeat1] = STATE(960),
    [sym_identifier] = ACTIONS(376),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(2358),
    [anon_sym_DASH] = ACTIONS(376),
    [aux_sym_boolean_token1] = ACTIONS(376),
    [aux_sym_boolean_token2] = ACTIONS(376),
    [sym_decimal] = ACTIONS(376),
    [anon_sym_LPAREN] = ACTIONS(374),
    [anon_sym_DOT_DOT] = ACTIONS(374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(376),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(376),
    [aux_sym_basic_type_token21] = ACTIONS(376),
    [aux_sym_basic_type_token22] = ACTIONS(376),
    [aux_sym_basic_type_token48] = ACTIONS(376),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(376),
    [anon_sym_POUNDif] = ACTIONS(374),
    [anon_sym_POUNDIF] = ACTIONS(374),
    [anon_sym_POUNDIf] = ACTIONS(374),
    [anon_sym_not] = ACTIONS(376),
    [anon_sym_NOT] = ACTIONS(376),
    [anon_sym_Not] = ACTIONS(376),
    [anon_sym_POUNDelif] = ACTIONS(374),
    [anon_sym_POUNDELIF] = ACTIONS(374),
    [anon_sym_POUNDElif] = ACTIONS(374),
    [anon_sym_POUNDelse] = ACTIONS(374),
    [anon_sym_POUNDELSE] = ACTIONS(374),
    [anon_sym_POUNDElse] = ACTIONS(374),
    [anon_sym_POUNDendif] = ACTIONS(374),
    [anon_sym_POUNDENDIF] = ACTIONS(374),
    [anon_sym_POUNDEndif] = ACTIONS(374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(374),
    [aux_sym__expression_token1] = ACTIONS(374),
    [aux_sym__expression_token2] = ACTIONS(376),
    [aux_sym_keyword_identifier_token1] = ACTIONS(376),
    [aux_sym_keyword_identifier_token2] = ACTIONS(376),
    [anon_sym_SLASH] = ACTIONS(376),
    [anon_sym_div] = ACTIONS(376),
    [anon_sym_DIV] = ACTIONS(376),
    [anon_sym_Div] = ACTIONS(376),
    [anon_sym_mod] = ACTIONS(376),
    [anon_sym_MOD] = ACTIONS(376),
    [anon_sym_Mod] = ACTIONS(376),
    [anon_sym_PLUS] = ACTIONS(376),
    [anon_sym_GT_EQ] = ACTIONS(374),
    [anon_sym_LT_EQ] = ACTIONS(374),
    [anon_sym_GT] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(376),
    [anon_sym_LT_GT] = ACTIONS(374),
    [anon_sym_and] = ACTIONS(376),
    [anon_sym_AND] = ACTIONS(376),
    [anon_sym_And] = ACTIONS(376),
    [anon_sym_or] = ACTIONS(376),
    [anon_sym_OR] = ACTIONS(376),
    [anon_sym_Or] = ACTIONS(376),
    [anon_sym_xor] = ACTIONS(376),
    [anon_sym_XOR] = ACTIONS(376),
    [anon_sym_Xor] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(374),
    [sym_datetime_literal] = ACTIONS(374),
    [sym_date_literal] = ACTIONS(376),
    [sym_time_literal] = ACTIONS(376),
    [sym_biginteger_literal] = ACTIONS(374),
    [anon_sym_if] = ACTIONS(376),
    [anon_sym_IF] = ACTIONS(376),
    [anon_sym_If] = ACTIONS(376),
    [anon_sym_else] = ACTIONS(376),
    [anon_sym_ELSE] = ACTIONS(376),
    [anon_sym_Else] = ACTIONS(376),
    [anon_sym_case] = ACTIONS(376),
    [anon_sym_CASE] = ACTIONS(376),
    [anon_sym_Case] = ACTIONS(376),
    [anon_sym_for] = ACTIONS(376),
    [anon_sym_FOR] = ACTIONS(376),
    [anon_sym_For] = ACTIONS(376),
    [anon_sym_foreach] = ACTIONS(376),
    [anon_sym_FOREACH] = ACTIONS(376),
    [anon_sym_Foreach] = ACTIONS(376),
    [anon_sym_while] = ACTIONS(376),
    [anon_sym_WHILE] = ACTIONS(376),
    [anon_sym_While] = ACTIONS(376),
    [anon_sym_repeat] = ACTIONS(376),
    [anon_sym_REPEAT] = ACTIONS(376),
    [anon_sym_Repeat] = ACTIONS(376),
    [anon_sym_exit] = ACTIONS(376),
    [anon_sym_EXIT] = ACTIONS(376),
    [anon_sym_Exit] = ACTIONS(376),
    [anon_sym_continue] = ACTIONS(376),
    [anon_sym_CONTINUE] = ACTIONS(376),
    [anon_sym_Continue] = ACTIONS(376),
    [anon_sym_break] = ACTIONS(376),
    [anon_sym_BREAK] = ACTIONS(376),
    [anon_sym_Break] = ACTIONS(376),
    [anon_sym_with] = ACTIONS(376),
    [anon_sym_WITH] = ACTIONS(376),
    [anon_sym_With] = ACTIONS(376),
    [sym_asserterror_keyword] = ACTIONS(374),
    [anon_sym_in] = ACTIONS(376),
    [anon_sym_IN] = ACTIONS(376),
    [anon_sym_In] = ACTIONS(376),
    [sym_page_keyword] = ACTIONS(376),
    [anon_sym_codeunit] = ACTIONS(376),
    [anon_sym_CODEUNIT] = ACTIONS(376),
    [anon_sym_Codeunit] = ACTIONS(376),
    [anon_sym_CodeUnit] = ACTIONS(376),
    [anon_sym_COdeunit] = ACTIONS(376),
    [anon_sym_codeUnit] = ACTIONS(376),
    [sym_report_keyword] = ACTIONS(376),
    [sym_query_keyword] = ACTIONS(376),
    [anon_sym_xmlport] = ACTIONS(376),
    [anon_sym_XMLPORT] = ACTIONS(376),
    [anon_sym_Xmlport] = ACTIONS(376),
    [anon_sym_XMLport] = ACTIONS(376),
    [anon_sym_XMLPort] = ACTIONS(376),
    [anon_sym_XmlPort] = ACTIONS(376),
    [anon_sym_enum] = ACTIONS(376),
    [anon_sym_ENUM] = ACTIONS(376),
    [anon_sym_Enum] = ACTIONS(376),
    [anon_sym_eNUM] = ACTIONS(376),
    [anon_sym_eNum] = ACTIONS(376),
    [anon_sym_ENum] = ACTIONS(376),
    [sym_quoted_identifier] = ACTIONS(374),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(374),
    [sym_integer] = ACTIONS(376),
    [sym_continue_as_identifier] = ACTIONS(374),
    [sym_preproc_open] = ACTIONS(374),
    [sym_preproc_close] = ACTIONS(374),
  },
  [STATE(985)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(985),
    [sym_identifier] = ACTIONS(2396),
    [anon_sym_SEMI] = ACTIONS(2398),
    [anon_sym_DOT] = ACTIONS(2400),
    [anon_sym_EQ] = ACTIONS(2398),
    [anon_sym_DASH] = ACTIONS(2396),
    [aux_sym_boolean_token1] = ACTIONS(2396),
    [aux_sym_boolean_token2] = ACTIONS(2396),
    [sym_decimal] = ACTIONS(2396),
    [anon_sym_LPAREN] = ACTIONS(2398),
    [anon_sym_DOT_DOT] = ACTIONS(2398),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2396),
    [anon_sym_STAR] = ACTIONS(2396),
    [anon_sym_LBRACK] = ACTIONS(2398),
    [aux_sym_record_type_token1] = ACTIONS(2396),
    [aux_sym_basic_type_token21] = ACTIONS(2396),
    [aux_sym_basic_type_token22] = ACTIONS(2396),
    [aux_sym_basic_type_token48] = ACTIONS(2396),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2396),
    [anon_sym_POUNDif] = ACTIONS(2398),
    [anon_sym_POUNDIF] = ACTIONS(2398),
    [anon_sym_POUNDIf] = ACTIONS(2398),
    [anon_sym_not] = ACTIONS(2396),
    [anon_sym_NOT] = ACTIONS(2396),
    [anon_sym_Not] = ACTIONS(2396),
    [anon_sym_POUNDelif] = ACTIONS(2398),
    [anon_sym_POUNDELIF] = ACTIONS(2398),
    [anon_sym_POUNDElif] = ACTIONS(2398),
    [anon_sym_POUNDelse] = ACTIONS(2398),
    [anon_sym_POUNDELSE] = ACTIONS(2398),
    [anon_sym_POUNDElse] = ACTIONS(2398),
    [anon_sym_POUNDendif] = ACTIONS(2398),
    [anon_sym_POUNDENDIF] = ACTIONS(2398),
    [anon_sym_POUNDEndif] = ACTIONS(2398),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2398),
    [aux_sym__expression_token1] = ACTIONS(2398),
    [aux_sym__expression_token2] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2396),
    [anon_sym_SLASH] = ACTIONS(2396),
    [anon_sym_div] = ACTIONS(2396),
    [anon_sym_DIV] = ACTIONS(2396),
    [anon_sym_Div] = ACTIONS(2396),
    [anon_sym_mod] = ACTIONS(2396),
    [anon_sym_MOD] = ACTIONS(2396),
    [anon_sym_Mod] = ACTIONS(2396),
    [anon_sym_PLUS] = ACTIONS(2396),
    [anon_sym_GT_EQ] = ACTIONS(2398),
    [anon_sym_LT_EQ] = ACTIONS(2398),
    [anon_sym_GT] = ACTIONS(2396),
    [anon_sym_LT] = ACTIONS(2396),
    [anon_sym_LT_GT] = ACTIONS(2398),
    [anon_sym_and] = ACTIONS(2396),
    [anon_sym_AND] = ACTIONS(2396),
    [anon_sym_And] = ACTIONS(2396),
    [anon_sym_or] = ACTIONS(2396),
    [anon_sym_OR] = ACTIONS(2396),
    [anon_sym_Or] = ACTIONS(2396),
    [anon_sym_xor] = ACTIONS(2396),
    [anon_sym_XOR] = ACTIONS(2396),
    [anon_sym_Xor] = ACTIONS(2396),
    [anon_sym_QMARK] = ACTIONS(2398),
    [sym_datetime_literal] = ACTIONS(2398),
    [sym_date_literal] = ACTIONS(2396),
    [sym_time_literal] = ACTIONS(2396),
    [sym_biginteger_literal] = ACTIONS(2398),
    [anon_sym_if] = ACTIONS(2396),
    [anon_sym_IF] = ACTIONS(2396),
    [anon_sym_If] = ACTIONS(2396),
    [anon_sym_else] = ACTIONS(2396),
    [anon_sym_ELSE] = ACTIONS(2396),
    [anon_sym_Else] = ACTIONS(2396),
    [anon_sym_case] = ACTIONS(2396),
    [anon_sym_CASE] = ACTIONS(2396),
    [anon_sym_Case] = ACTIONS(2396),
    [anon_sym_for] = ACTIONS(2396),
    [anon_sym_FOR] = ACTIONS(2396),
    [anon_sym_For] = ACTIONS(2396),
    [anon_sym_foreach] = ACTIONS(2396),
    [anon_sym_FOREACH] = ACTIONS(2396),
    [anon_sym_Foreach] = ACTIONS(2396),
    [anon_sym_while] = ACTIONS(2396),
    [anon_sym_WHILE] = ACTIONS(2396),
    [anon_sym_While] = ACTIONS(2396),
    [anon_sym_repeat] = ACTIONS(2396),
    [anon_sym_REPEAT] = ACTIONS(2396),
    [anon_sym_Repeat] = ACTIONS(2396),
    [anon_sym_exit] = ACTIONS(2396),
    [anon_sym_EXIT] = ACTIONS(2396),
    [anon_sym_Exit] = ACTIONS(2396),
    [anon_sym_continue] = ACTIONS(2396),
    [anon_sym_CONTINUE] = ACTIONS(2396),
    [anon_sym_Continue] = ACTIONS(2396),
    [anon_sym_break] = ACTIONS(2396),
    [anon_sym_BREAK] = ACTIONS(2396),
    [anon_sym_Break] = ACTIONS(2396),
    [anon_sym_with] = ACTIONS(2396),
    [anon_sym_WITH] = ACTIONS(2396),
    [anon_sym_With] = ACTIONS(2396),
    [sym_asserterror_keyword] = ACTIONS(2398),
    [anon_sym_in] = ACTIONS(2396),
    [anon_sym_IN] = ACTIONS(2396),
    [anon_sym_In] = ACTIONS(2396),
    [sym_page_keyword] = ACTIONS(2396),
    [anon_sym_codeunit] = ACTIONS(2396),
    [anon_sym_CODEUNIT] = ACTIONS(2396),
    [anon_sym_Codeunit] = ACTIONS(2396),
    [anon_sym_CodeUnit] = ACTIONS(2396),
    [anon_sym_COdeunit] = ACTIONS(2396),
    [anon_sym_codeUnit] = ACTIONS(2396),
    [sym_report_keyword] = ACTIONS(2396),
    [sym_query_keyword] = ACTIONS(2396),
    [anon_sym_xmlport] = ACTIONS(2396),
    [anon_sym_XMLPORT] = ACTIONS(2396),
    [anon_sym_Xmlport] = ACTIONS(2396),
    [anon_sym_XMLport] = ACTIONS(2396),
    [anon_sym_XMLPort] = ACTIONS(2396),
    [anon_sym_XmlPort] = ACTIONS(2396),
    [anon_sym_enum] = ACTIONS(2396),
    [anon_sym_ENUM] = ACTIONS(2396),
    [anon_sym_Enum] = ACTIONS(2396),
    [anon_sym_eNUM] = ACTIONS(2396),
    [anon_sym_eNum] = ACTIONS(2396),
    [anon_sym_ENum] = ACTIONS(2396),
    [sym_temporary_keyword] = ACTIONS(2396),
    [sym_quoted_identifier] = ACTIONS(2398),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2398),
    [sym_integer] = ACTIONS(2396),
    [sym_continue_as_identifier] = ACTIONS(2398),
    [sym_preproc_open] = ACTIONS(2398),
    [sym_preproc_close] = ACTIONS(2398),
  },
  [STATE(986)] = {
    [aux_sym_option_member_list_repeat1] = STATE(986),
    [sym_identifier] = ACTIONS(2403),
    [anon_sym_SEMI] = ACTIONS(2405),
    [anon_sym_DOT] = ACTIONS(2403),
    [anon_sym_EQ] = ACTIONS(2405),
    [anon_sym_COMMA] = ACTIONS(2407),
    [anon_sym_DASH] = ACTIONS(2403),
    [aux_sym_boolean_token1] = ACTIONS(2403),
    [aux_sym_boolean_token2] = ACTIONS(2403),
    [sym_decimal] = ACTIONS(2403),
    [anon_sym_LPAREN] = ACTIONS(2405),
    [anon_sym_DOT_DOT] = ACTIONS(2405),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2403),
    [anon_sym_STAR] = ACTIONS(2403),
    [anon_sym_LBRACK] = ACTIONS(2405),
    [aux_sym_record_type_token1] = ACTIONS(2403),
    [aux_sym_basic_type_token21] = ACTIONS(2403),
    [aux_sym_basic_type_token22] = ACTIONS(2403),
    [aux_sym_basic_type_token48] = ACTIONS(2403),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2403),
    [anon_sym_POUNDif] = ACTIONS(2405),
    [anon_sym_POUNDIF] = ACTIONS(2405),
    [anon_sym_POUNDIf] = ACTIONS(2405),
    [anon_sym_not] = ACTIONS(2403),
    [anon_sym_NOT] = ACTIONS(2403),
    [anon_sym_Not] = ACTIONS(2403),
    [anon_sym_POUNDelif] = ACTIONS(2405),
    [anon_sym_POUNDELIF] = ACTIONS(2405),
    [anon_sym_POUNDElif] = ACTIONS(2405),
    [anon_sym_POUNDelse] = ACTIONS(2405),
    [anon_sym_POUNDELSE] = ACTIONS(2405),
    [anon_sym_POUNDElse] = ACTIONS(2405),
    [anon_sym_POUNDendif] = ACTIONS(2405),
    [anon_sym_POUNDENDIF] = ACTIONS(2405),
    [anon_sym_POUNDEndif] = ACTIONS(2405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2405),
    [aux_sym__expression_token1] = ACTIONS(2405),
    [aux_sym__expression_token2] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2403),
    [anon_sym_SLASH] = ACTIONS(2403),
    [anon_sym_div] = ACTIONS(2403),
    [anon_sym_DIV] = ACTIONS(2403),
    [anon_sym_Div] = ACTIONS(2403),
    [anon_sym_mod] = ACTIONS(2403),
    [anon_sym_MOD] = ACTIONS(2403),
    [anon_sym_Mod] = ACTIONS(2403),
    [anon_sym_PLUS] = ACTIONS(2403),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_LT_GT] = ACTIONS(2405),
    [anon_sym_and] = ACTIONS(2403),
    [anon_sym_AND] = ACTIONS(2403),
    [anon_sym_And] = ACTIONS(2403),
    [anon_sym_or] = ACTIONS(2403),
    [anon_sym_OR] = ACTIONS(2403),
    [anon_sym_Or] = ACTIONS(2403),
    [anon_sym_xor] = ACTIONS(2403),
    [anon_sym_XOR] = ACTIONS(2403),
    [anon_sym_Xor] = ACTIONS(2403),
    [anon_sym_QMARK] = ACTIONS(2405),
    [sym_datetime_literal] = ACTIONS(2405),
    [sym_date_literal] = ACTIONS(2403),
    [sym_time_literal] = ACTIONS(2403),
    [sym_biginteger_literal] = ACTIONS(2405),
    [anon_sym_if] = ACTIONS(2403),
    [anon_sym_IF] = ACTIONS(2403),
    [anon_sym_If] = ACTIONS(2403),
    [anon_sym_else] = ACTIONS(2403),
    [anon_sym_ELSE] = ACTIONS(2403),
    [anon_sym_Else] = ACTIONS(2403),
    [anon_sym_case] = ACTIONS(2403),
    [anon_sym_CASE] = ACTIONS(2403),
    [anon_sym_Case] = ACTIONS(2403),
    [anon_sym_for] = ACTIONS(2403),
    [anon_sym_FOR] = ACTIONS(2403),
    [anon_sym_For] = ACTIONS(2403),
    [anon_sym_foreach] = ACTIONS(2403),
    [anon_sym_FOREACH] = ACTIONS(2403),
    [anon_sym_Foreach] = ACTIONS(2403),
    [anon_sym_while] = ACTIONS(2403),
    [anon_sym_WHILE] = ACTIONS(2403),
    [anon_sym_While] = ACTIONS(2403),
    [anon_sym_repeat] = ACTIONS(2403),
    [anon_sym_REPEAT] = ACTIONS(2403),
    [anon_sym_Repeat] = ACTIONS(2403),
    [anon_sym_exit] = ACTIONS(2403),
    [anon_sym_EXIT] = ACTIONS(2403),
    [anon_sym_Exit] = ACTIONS(2403),
    [anon_sym_continue] = ACTIONS(2403),
    [anon_sym_CONTINUE] = ACTIONS(2403),
    [anon_sym_Continue] = ACTIONS(2403),
    [anon_sym_break] = ACTIONS(2403),
    [anon_sym_BREAK] = ACTIONS(2403),
    [anon_sym_Break] = ACTIONS(2403),
    [anon_sym_with] = ACTIONS(2403),
    [anon_sym_WITH] = ACTIONS(2403),
    [anon_sym_With] = ACTIONS(2403),
    [sym_asserterror_keyword] = ACTIONS(2405),
    [anon_sym_in] = ACTIONS(2403),
    [anon_sym_IN] = ACTIONS(2403),
    [anon_sym_In] = ACTIONS(2403),
    [sym_page_keyword] = ACTIONS(2403),
    [anon_sym_codeunit] = ACTIONS(2403),
    [anon_sym_CODEUNIT] = ACTIONS(2403),
    [anon_sym_Codeunit] = ACTIONS(2403),
    [anon_sym_CodeUnit] = ACTIONS(2403),
    [anon_sym_COdeunit] = ACTIONS(2403),
    [anon_sym_codeUnit] = ACTIONS(2403),
    [sym_report_keyword] = ACTIONS(2403),
    [sym_query_keyword] = ACTIONS(2403),
    [anon_sym_xmlport] = ACTIONS(2403),
    [anon_sym_XMLPORT] = ACTIONS(2403),
    [anon_sym_Xmlport] = ACTIONS(2403),
    [anon_sym_XMLport] = ACTIONS(2403),
    [anon_sym_XMLPort] = ACTIONS(2403),
    [anon_sym_XmlPort] = ACTIONS(2403),
    [anon_sym_enum] = ACTIONS(2403),
    [anon_sym_ENUM] = ACTIONS(2403),
    [anon_sym_Enum] = ACTIONS(2403),
    [anon_sym_eNUM] = ACTIONS(2403),
    [anon_sym_eNum] = ACTIONS(2403),
    [anon_sym_ENum] = ACTIONS(2403),
    [sym_quoted_identifier] = ACTIONS(2405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2405),
    [sym_integer] = ACTIONS(2403),
    [sym_continue_as_identifier] = ACTIONS(2405),
    [sym_preproc_open] = ACTIONS(2405),
    [sym_preproc_close] = ACTIONS(2405),
  },
  [STATE(987)] = {
    [aux_sym_option_member_list_repeat1] = STATE(986),
    [sym_identifier] = ACTIONS(2410),
    [anon_sym_SEMI] = ACTIONS(2412),
    [anon_sym_DOT] = ACTIONS(2410),
    [anon_sym_EQ] = ACTIONS(2412),
    [anon_sym_COMMA] = ACTIONS(2358),
    [anon_sym_DASH] = ACTIONS(2410),
    [aux_sym_boolean_token1] = ACTIONS(2410),
    [aux_sym_boolean_token2] = ACTIONS(2410),
    [sym_decimal] = ACTIONS(2410),
    [anon_sym_LPAREN] = ACTIONS(2412),
    [anon_sym_DOT_DOT] = ACTIONS(2412),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2410),
    [anon_sym_STAR] = ACTIONS(2410),
    [anon_sym_LBRACK] = ACTIONS(2412),
    [aux_sym_record_type_token1] = ACTIONS(2410),
    [aux_sym_basic_type_token21] = ACTIONS(2410),
    [aux_sym_basic_type_token22] = ACTIONS(2410),
    [aux_sym_basic_type_token48] = ACTIONS(2410),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2410),
    [anon_sym_POUNDif] = ACTIONS(2412),
    [anon_sym_POUNDIF] = ACTIONS(2412),
    [anon_sym_POUNDIf] = ACTIONS(2412),
    [anon_sym_not] = ACTIONS(2410),
    [anon_sym_NOT] = ACTIONS(2410),
    [anon_sym_Not] = ACTIONS(2410),
    [anon_sym_POUNDelif] = ACTIONS(2412),
    [anon_sym_POUNDELIF] = ACTIONS(2412),
    [anon_sym_POUNDElif] = ACTIONS(2412),
    [anon_sym_POUNDelse] = ACTIONS(2412),
    [anon_sym_POUNDELSE] = ACTIONS(2412),
    [anon_sym_POUNDElse] = ACTIONS(2412),
    [anon_sym_POUNDendif] = ACTIONS(2412),
    [anon_sym_POUNDENDIF] = ACTIONS(2412),
    [anon_sym_POUNDEndif] = ACTIONS(2412),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2412),
    [aux_sym__expression_token1] = ACTIONS(2412),
    [aux_sym__expression_token2] = ACTIONS(2410),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2410),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2410),
    [anon_sym_SLASH] = ACTIONS(2410),
    [anon_sym_div] = ACTIONS(2410),
    [anon_sym_DIV] = ACTIONS(2410),
    [anon_sym_Div] = ACTIONS(2410),
    [anon_sym_mod] = ACTIONS(2410),
    [anon_sym_MOD] = ACTIONS(2410),
    [anon_sym_Mod] = ACTIONS(2410),
    [anon_sym_PLUS] = ACTIONS(2410),
    [anon_sym_GT_EQ] = ACTIONS(2412),
    [anon_sym_LT_EQ] = ACTIONS(2412),
    [anon_sym_GT] = ACTIONS(2410),
    [anon_sym_LT] = ACTIONS(2410),
    [anon_sym_LT_GT] = ACTIONS(2412),
    [anon_sym_and] = ACTIONS(2410),
    [anon_sym_AND] = ACTIONS(2410),
    [anon_sym_And] = ACTIONS(2410),
    [anon_sym_or] = ACTIONS(2410),
    [anon_sym_OR] = ACTIONS(2410),
    [anon_sym_Or] = ACTIONS(2410),
    [anon_sym_xor] = ACTIONS(2410),
    [anon_sym_XOR] = ACTIONS(2410),
    [anon_sym_Xor] = ACTIONS(2410),
    [anon_sym_QMARK] = ACTIONS(2412),
    [sym_datetime_literal] = ACTIONS(2412),
    [sym_date_literal] = ACTIONS(2410),
    [sym_time_literal] = ACTIONS(2410),
    [sym_biginteger_literal] = ACTIONS(2412),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_IF] = ACTIONS(2410),
    [anon_sym_If] = ACTIONS(2410),
    [anon_sym_else] = ACTIONS(2410),
    [anon_sym_ELSE] = ACTIONS(2410),
    [anon_sym_Else] = ACTIONS(2410),
    [anon_sym_case] = ACTIONS(2410),
    [anon_sym_CASE] = ACTIONS(2410),
    [anon_sym_Case] = ACTIONS(2410),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_FOR] = ACTIONS(2410),
    [anon_sym_For] = ACTIONS(2410),
    [anon_sym_foreach] = ACTIONS(2410),
    [anon_sym_FOREACH] = ACTIONS(2410),
    [anon_sym_Foreach] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2410),
    [anon_sym_WHILE] = ACTIONS(2410),
    [anon_sym_While] = ACTIONS(2410),
    [anon_sym_repeat] = ACTIONS(2410),
    [anon_sym_REPEAT] = ACTIONS(2410),
    [anon_sym_Repeat] = ACTIONS(2410),
    [anon_sym_exit] = ACTIONS(2410),
    [anon_sym_EXIT] = ACTIONS(2410),
    [anon_sym_Exit] = ACTIONS(2410),
    [anon_sym_continue] = ACTIONS(2410),
    [anon_sym_CONTINUE] = ACTIONS(2410),
    [anon_sym_Continue] = ACTIONS(2410),
    [anon_sym_break] = ACTIONS(2410),
    [anon_sym_BREAK] = ACTIONS(2410),
    [anon_sym_Break] = ACTIONS(2410),
    [anon_sym_with] = ACTIONS(2410),
    [anon_sym_WITH] = ACTIONS(2410),
    [anon_sym_With] = ACTIONS(2410),
    [sym_asserterror_keyword] = ACTIONS(2412),
    [anon_sym_in] = ACTIONS(2410),
    [anon_sym_IN] = ACTIONS(2410),
    [anon_sym_In] = ACTIONS(2410),
    [sym_page_keyword] = ACTIONS(2410),
    [anon_sym_codeunit] = ACTIONS(2410),
    [anon_sym_CODEUNIT] = ACTIONS(2410),
    [anon_sym_Codeunit] = ACTIONS(2410),
    [anon_sym_CodeUnit] = ACTIONS(2410),
    [anon_sym_COdeunit] = ACTIONS(2410),
    [anon_sym_codeUnit] = ACTIONS(2410),
    [sym_report_keyword] = ACTIONS(2410),
    [sym_query_keyword] = ACTIONS(2410),
    [anon_sym_xmlport] = ACTIONS(2410),
    [anon_sym_XMLPORT] = ACTIONS(2410),
    [anon_sym_Xmlport] = ACTIONS(2410),
    [anon_sym_XMLport] = ACTIONS(2410),
    [anon_sym_XMLPort] = ACTIONS(2410),
    [anon_sym_XmlPort] = ACTIONS(2410),
    [anon_sym_enum] = ACTIONS(2410),
    [anon_sym_ENUM] = ACTIONS(2410),
    [anon_sym_Enum] = ACTIONS(2410),
    [anon_sym_eNUM] = ACTIONS(2410),
    [anon_sym_eNum] = ACTIONS(2410),
    [anon_sym_ENum] = ACTIONS(2410),
    [sym_quoted_identifier] = ACTIONS(2412),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2412),
    [sym_integer] = ACTIONS(2410),
    [sym_continue_as_identifier] = ACTIONS(2412),
    [sym_preproc_open] = ACTIONS(2412),
    [sym_preproc_close] = ACTIONS(2412),
  },
  [STATE(988)] = {
    [sym_identifier] = ACTIONS(2414),
    [anon_sym_SEMI] = ACTIONS(2416),
    [anon_sym_DOT] = ACTIONS(2414),
    [anon_sym_EQ] = ACTIONS(2416),
    [anon_sym_COMMA] = ACTIONS(2416),
    [anon_sym_DASH] = ACTIONS(2414),
    [aux_sym_boolean_token1] = ACTIONS(2414),
    [aux_sym_boolean_token2] = ACTIONS(2414),
    [sym_decimal] = ACTIONS(2414),
    [anon_sym_LPAREN] = ACTIONS(2416),
    [anon_sym_DOT_DOT] = ACTIONS(2416),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2414),
    [anon_sym_STAR] = ACTIONS(2414),
    [anon_sym_LBRACK] = ACTIONS(2416),
    [aux_sym_record_type_token1] = ACTIONS(2414),
    [aux_sym_basic_type_token21] = ACTIONS(2414),
    [aux_sym_basic_type_token22] = ACTIONS(2414),
    [aux_sym_basic_type_token48] = ACTIONS(2414),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2414),
    [anon_sym_COLON_COLON] = ACTIONS(2416),
    [anon_sym_POUNDif] = ACTIONS(2416),
    [anon_sym_POUNDIF] = ACTIONS(2416),
    [anon_sym_POUNDIf] = ACTIONS(2416),
    [anon_sym_not] = ACTIONS(2414),
    [anon_sym_NOT] = ACTIONS(2414),
    [anon_sym_Not] = ACTIONS(2414),
    [anon_sym_POUNDelif] = ACTIONS(2416),
    [anon_sym_POUNDELIF] = ACTIONS(2416),
    [anon_sym_POUNDElif] = ACTIONS(2416),
    [anon_sym_POUNDelse] = ACTIONS(2416),
    [anon_sym_POUNDELSE] = ACTIONS(2416),
    [anon_sym_POUNDElse] = ACTIONS(2416),
    [anon_sym_POUNDendif] = ACTIONS(2416),
    [anon_sym_POUNDENDIF] = ACTIONS(2416),
    [anon_sym_POUNDEndif] = ACTIONS(2416),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2416),
    [aux_sym__expression_token1] = ACTIONS(2416),
    [aux_sym__expression_token2] = ACTIONS(2414),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2414),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2414),
    [anon_sym_SLASH] = ACTIONS(2414),
    [anon_sym_div] = ACTIONS(2414),
    [anon_sym_DIV] = ACTIONS(2414),
    [anon_sym_Div] = ACTIONS(2414),
    [anon_sym_mod] = ACTIONS(2414),
    [anon_sym_MOD] = ACTIONS(2414),
    [anon_sym_Mod] = ACTIONS(2414),
    [anon_sym_PLUS] = ACTIONS(2414),
    [anon_sym_GT_EQ] = ACTIONS(2416),
    [anon_sym_LT_EQ] = ACTIONS(2416),
    [anon_sym_GT] = ACTIONS(2414),
    [anon_sym_LT] = ACTIONS(2414),
    [anon_sym_LT_GT] = ACTIONS(2416),
    [anon_sym_and] = ACTIONS(2414),
    [anon_sym_AND] = ACTIONS(2414),
    [anon_sym_And] = ACTIONS(2414),
    [anon_sym_or] = ACTIONS(2414),
    [anon_sym_OR] = ACTIONS(2414),
    [anon_sym_Or] = ACTIONS(2414),
    [anon_sym_xor] = ACTIONS(2414),
    [anon_sym_XOR] = ACTIONS(2414),
    [anon_sym_Xor] = ACTIONS(2414),
    [anon_sym_QMARK] = ACTIONS(2416),
    [sym_datetime_literal] = ACTIONS(2416),
    [sym_date_literal] = ACTIONS(2414),
    [sym_time_literal] = ACTIONS(2414),
    [sym_biginteger_literal] = ACTIONS(2416),
    [anon_sym_if] = ACTIONS(2414),
    [anon_sym_IF] = ACTIONS(2414),
    [anon_sym_If] = ACTIONS(2414),
    [anon_sym_else] = ACTIONS(2414),
    [anon_sym_ELSE] = ACTIONS(2414),
    [anon_sym_Else] = ACTIONS(2414),
    [anon_sym_case] = ACTIONS(2414),
    [anon_sym_CASE] = ACTIONS(2414),
    [anon_sym_Case] = ACTIONS(2414),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_FOR] = ACTIONS(2414),
    [anon_sym_For] = ACTIONS(2414),
    [anon_sym_foreach] = ACTIONS(2414),
    [anon_sym_FOREACH] = ACTIONS(2414),
    [anon_sym_Foreach] = ACTIONS(2414),
    [anon_sym_while] = ACTIONS(2414),
    [anon_sym_WHILE] = ACTIONS(2414),
    [anon_sym_While] = ACTIONS(2414),
    [anon_sym_repeat] = ACTIONS(2414),
    [anon_sym_REPEAT] = ACTIONS(2414),
    [anon_sym_Repeat] = ACTIONS(2414),
    [anon_sym_exit] = ACTIONS(2414),
    [anon_sym_EXIT] = ACTIONS(2414),
    [anon_sym_Exit] = ACTIONS(2414),
    [anon_sym_continue] = ACTIONS(2414),
    [anon_sym_CONTINUE] = ACTIONS(2414),
    [anon_sym_Continue] = ACTIONS(2414),
    [anon_sym_break] = ACTIONS(2414),
    [anon_sym_BREAK] = ACTIONS(2414),
    [anon_sym_Break] = ACTIONS(2414),
    [anon_sym_with] = ACTIONS(2414),
    [anon_sym_WITH] = ACTIONS(2414),
    [anon_sym_With] = ACTIONS(2414),
    [sym_asserterror_keyword] = ACTIONS(2416),
    [anon_sym_in] = ACTIONS(2414),
    [anon_sym_IN] = ACTIONS(2414),
    [anon_sym_In] = ACTIONS(2414),
    [sym_page_keyword] = ACTIONS(2414),
    [anon_sym_codeunit] = ACTIONS(2414),
    [anon_sym_CODEUNIT] = ACTIONS(2414),
    [anon_sym_Codeunit] = ACTIONS(2414),
    [anon_sym_CodeUnit] = ACTIONS(2414),
    [anon_sym_COdeunit] = ACTIONS(2414),
    [anon_sym_codeUnit] = ACTIONS(2414),
    [sym_report_keyword] = ACTIONS(2414),
    [sym_query_keyword] = ACTIONS(2414),
    [anon_sym_xmlport] = ACTIONS(2414),
    [anon_sym_XMLPORT] = ACTIONS(2414),
    [anon_sym_Xmlport] = ACTIONS(2414),
    [anon_sym_XMLport] = ACTIONS(2414),
    [anon_sym_XMLPort] = ACTIONS(2414),
    [anon_sym_XmlPort] = ACTIONS(2414),
    [anon_sym_enum] = ACTIONS(2414),
    [anon_sym_ENUM] = ACTIONS(2414),
    [anon_sym_Enum] = ACTIONS(2414),
    [anon_sym_eNUM] = ACTIONS(2414),
    [anon_sym_eNum] = ACTIONS(2414),
    [anon_sym_ENum] = ACTIONS(2414),
    [sym_quoted_identifier] = ACTIONS(2416),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2416),
    [sym_integer] = ACTIONS(2414),
    [sym_continue_as_identifier] = ACTIONS(2416),
    [sym_preproc_open] = ACTIONS(2416),
    [sym_preproc_close] = ACTIONS(2416),
  },
  [STATE(989)] = {
    [sym_identifier] = ACTIONS(2418),
    [anon_sym_SEMI] = ACTIONS(2420),
    [anon_sym_DOT] = ACTIONS(2418),
    [anon_sym_EQ] = ACTIONS(2420),
    [anon_sym_COMMA] = ACTIONS(2420),
    [anon_sym_DASH] = ACTIONS(2418),
    [aux_sym_boolean_token1] = ACTIONS(2418),
    [aux_sym_boolean_token2] = ACTIONS(2418),
    [sym_decimal] = ACTIONS(2418),
    [anon_sym_LPAREN] = ACTIONS(2420),
    [anon_sym_DOT_DOT] = ACTIONS(2420),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2418),
    [anon_sym_STAR] = ACTIONS(2418),
    [anon_sym_LBRACK] = ACTIONS(2420),
    [aux_sym_record_type_token1] = ACTIONS(2418),
    [aux_sym_basic_type_token21] = ACTIONS(2418),
    [aux_sym_basic_type_token22] = ACTIONS(2418),
    [aux_sym_basic_type_token48] = ACTIONS(2418),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2418),
    [anon_sym_COLON_COLON] = ACTIONS(2420),
    [anon_sym_POUNDif] = ACTIONS(2420),
    [anon_sym_POUNDIF] = ACTIONS(2420),
    [anon_sym_POUNDIf] = ACTIONS(2420),
    [anon_sym_not] = ACTIONS(2418),
    [anon_sym_NOT] = ACTIONS(2418),
    [anon_sym_Not] = ACTIONS(2418),
    [anon_sym_POUNDelif] = ACTIONS(2420),
    [anon_sym_POUNDELIF] = ACTIONS(2420),
    [anon_sym_POUNDElif] = ACTIONS(2420),
    [anon_sym_POUNDelse] = ACTIONS(2420),
    [anon_sym_POUNDELSE] = ACTIONS(2420),
    [anon_sym_POUNDElse] = ACTIONS(2420),
    [anon_sym_POUNDendif] = ACTIONS(2420),
    [anon_sym_POUNDENDIF] = ACTIONS(2420),
    [anon_sym_POUNDEndif] = ACTIONS(2420),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2420),
    [aux_sym__expression_token1] = ACTIONS(2420),
    [aux_sym__expression_token2] = ACTIONS(2418),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2418),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2418),
    [anon_sym_SLASH] = ACTIONS(2418),
    [anon_sym_div] = ACTIONS(2418),
    [anon_sym_DIV] = ACTIONS(2418),
    [anon_sym_Div] = ACTIONS(2418),
    [anon_sym_mod] = ACTIONS(2418),
    [anon_sym_MOD] = ACTIONS(2418),
    [anon_sym_Mod] = ACTIONS(2418),
    [anon_sym_PLUS] = ACTIONS(2418),
    [anon_sym_GT_EQ] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(2420),
    [anon_sym_GT] = ACTIONS(2418),
    [anon_sym_LT] = ACTIONS(2418),
    [anon_sym_LT_GT] = ACTIONS(2420),
    [anon_sym_and] = ACTIONS(2418),
    [anon_sym_AND] = ACTIONS(2418),
    [anon_sym_And] = ACTIONS(2418),
    [anon_sym_or] = ACTIONS(2418),
    [anon_sym_OR] = ACTIONS(2418),
    [anon_sym_Or] = ACTIONS(2418),
    [anon_sym_xor] = ACTIONS(2418),
    [anon_sym_XOR] = ACTIONS(2418),
    [anon_sym_Xor] = ACTIONS(2418),
    [anon_sym_QMARK] = ACTIONS(2420),
    [sym_datetime_literal] = ACTIONS(2420),
    [sym_date_literal] = ACTIONS(2418),
    [sym_time_literal] = ACTIONS(2418),
    [sym_biginteger_literal] = ACTIONS(2420),
    [anon_sym_if] = ACTIONS(2418),
    [anon_sym_IF] = ACTIONS(2418),
    [anon_sym_If] = ACTIONS(2418),
    [anon_sym_else] = ACTIONS(2418),
    [anon_sym_ELSE] = ACTIONS(2418),
    [anon_sym_Else] = ACTIONS(2418),
    [anon_sym_case] = ACTIONS(2418),
    [anon_sym_CASE] = ACTIONS(2418),
    [anon_sym_Case] = ACTIONS(2418),
    [anon_sym_for] = ACTIONS(2418),
    [anon_sym_FOR] = ACTIONS(2418),
    [anon_sym_For] = ACTIONS(2418),
    [anon_sym_foreach] = ACTIONS(2418),
    [anon_sym_FOREACH] = ACTIONS(2418),
    [anon_sym_Foreach] = ACTIONS(2418),
    [anon_sym_while] = ACTIONS(2418),
    [anon_sym_WHILE] = ACTIONS(2418),
    [anon_sym_While] = ACTIONS(2418),
    [anon_sym_repeat] = ACTIONS(2418),
    [anon_sym_REPEAT] = ACTIONS(2418),
    [anon_sym_Repeat] = ACTIONS(2418),
    [anon_sym_exit] = ACTIONS(2418),
    [anon_sym_EXIT] = ACTIONS(2418),
    [anon_sym_Exit] = ACTIONS(2418),
    [anon_sym_continue] = ACTIONS(2418),
    [anon_sym_CONTINUE] = ACTIONS(2418),
    [anon_sym_Continue] = ACTIONS(2418),
    [anon_sym_break] = ACTIONS(2418),
    [anon_sym_BREAK] = ACTIONS(2418),
    [anon_sym_Break] = ACTIONS(2418),
    [anon_sym_with] = ACTIONS(2418),
    [anon_sym_WITH] = ACTIONS(2418),
    [anon_sym_With] = ACTIONS(2418),
    [sym_asserterror_keyword] = ACTIONS(2420),
    [anon_sym_in] = ACTIONS(2418),
    [anon_sym_IN] = ACTIONS(2418),
    [anon_sym_In] = ACTIONS(2418),
    [sym_page_keyword] = ACTIONS(2418),
    [anon_sym_codeunit] = ACTIONS(2418),
    [anon_sym_CODEUNIT] = ACTIONS(2418),
    [anon_sym_Codeunit] = ACTIONS(2418),
    [anon_sym_CodeUnit] = ACTIONS(2418),
    [anon_sym_COdeunit] = ACTIONS(2418),
    [anon_sym_codeUnit] = ACTIONS(2418),
    [sym_report_keyword] = ACTIONS(2418),
    [sym_query_keyword] = ACTIONS(2418),
    [anon_sym_xmlport] = ACTIONS(2418),
    [anon_sym_XMLPORT] = ACTIONS(2418),
    [anon_sym_Xmlport] = ACTIONS(2418),
    [anon_sym_XMLport] = ACTIONS(2418),
    [anon_sym_XMLPort] = ACTIONS(2418),
    [anon_sym_XmlPort] = ACTIONS(2418),
    [anon_sym_enum] = ACTIONS(2418),
    [anon_sym_ENUM] = ACTIONS(2418),
    [anon_sym_Enum] = ACTIONS(2418),
    [anon_sym_eNUM] = ACTIONS(2418),
    [anon_sym_eNum] = ACTIONS(2418),
    [anon_sym_ENum] = ACTIONS(2418),
    [sym_quoted_identifier] = ACTIONS(2420),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2420),
    [sym_integer] = ACTIONS(2418),
    [sym_continue_as_identifier] = ACTIONS(2420),
    [sym_preproc_open] = ACTIONS(2420),
    [sym_preproc_close] = ACTIONS(2420),
  },
  [STATE(990)] = {
    [sym_identifier] = ACTIONS(2422),
    [anon_sym_SEMI] = ACTIONS(2424),
    [anon_sym_DOT] = ACTIONS(2422),
    [anon_sym_EQ] = ACTIONS(2424),
    [anon_sym_COMMA] = ACTIONS(2424),
    [anon_sym_DASH] = ACTIONS(2422),
    [aux_sym_boolean_token1] = ACTIONS(2422),
    [aux_sym_boolean_token2] = ACTIONS(2422),
    [sym_decimal] = ACTIONS(2422),
    [anon_sym_LPAREN] = ACTIONS(2424),
    [anon_sym_DOT_DOT] = ACTIONS(2424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2422),
    [anon_sym_STAR] = ACTIONS(2422),
    [anon_sym_LBRACK] = ACTIONS(2424),
    [aux_sym_record_type_token1] = ACTIONS(2422),
    [aux_sym_basic_type_token21] = ACTIONS(2422),
    [aux_sym_basic_type_token22] = ACTIONS(2422),
    [aux_sym_basic_type_token48] = ACTIONS(2422),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2422),
    [anon_sym_COLON_COLON] = ACTIONS(2424),
    [anon_sym_POUNDif] = ACTIONS(2424),
    [anon_sym_POUNDIF] = ACTIONS(2424),
    [anon_sym_POUNDIf] = ACTIONS(2424),
    [anon_sym_not] = ACTIONS(2422),
    [anon_sym_NOT] = ACTIONS(2422),
    [anon_sym_Not] = ACTIONS(2422),
    [anon_sym_POUNDelif] = ACTIONS(2424),
    [anon_sym_POUNDELIF] = ACTIONS(2424),
    [anon_sym_POUNDElif] = ACTIONS(2424),
    [anon_sym_POUNDelse] = ACTIONS(2424),
    [anon_sym_POUNDELSE] = ACTIONS(2424),
    [anon_sym_POUNDElse] = ACTIONS(2424),
    [anon_sym_POUNDendif] = ACTIONS(2424),
    [anon_sym_POUNDENDIF] = ACTIONS(2424),
    [anon_sym_POUNDEndif] = ACTIONS(2424),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2424),
    [aux_sym__expression_token1] = ACTIONS(2424),
    [aux_sym__expression_token2] = ACTIONS(2422),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2422),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2422),
    [anon_sym_SLASH] = ACTIONS(2422),
    [anon_sym_div] = ACTIONS(2422),
    [anon_sym_DIV] = ACTIONS(2422),
    [anon_sym_Div] = ACTIONS(2422),
    [anon_sym_mod] = ACTIONS(2422),
    [anon_sym_MOD] = ACTIONS(2422),
    [anon_sym_Mod] = ACTIONS(2422),
    [anon_sym_PLUS] = ACTIONS(2422),
    [anon_sym_GT_EQ] = ACTIONS(2424),
    [anon_sym_LT_EQ] = ACTIONS(2424),
    [anon_sym_GT] = ACTIONS(2422),
    [anon_sym_LT] = ACTIONS(2422),
    [anon_sym_LT_GT] = ACTIONS(2424),
    [anon_sym_and] = ACTIONS(2422),
    [anon_sym_AND] = ACTIONS(2422),
    [anon_sym_And] = ACTIONS(2422),
    [anon_sym_or] = ACTIONS(2422),
    [anon_sym_OR] = ACTIONS(2422),
    [anon_sym_Or] = ACTIONS(2422),
    [anon_sym_xor] = ACTIONS(2422),
    [anon_sym_XOR] = ACTIONS(2422),
    [anon_sym_Xor] = ACTIONS(2422),
    [anon_sym_QMARK] = ACTIONS(2424),
    [sym_datetime_literal] = ACTIONS(2424),
    [sym_date_literal] = ACTIONS(2422),
    [sym_time_literal] = ACTIONS(2422),
    [sym_biginteger_literal] = ACTIONS(2424),
    [anon_sym_if] = ACTIONS(2422),
    [anon_sym_IF] = ACTIONS(2422),
    [anon_sym_If] = ACTIONS(2422),
    [anon_sym_else] = ACTIONS(2422),
    [anon_sym_ELSE] = ACTIONS(2422),
    [anon_sym_Else] = ACTIONS(2422),
    [anon_sym_case] = ACTIONS(2422),
    [anon_sym_CASE] = ACTIONS(2422),
    [anon_sym_Case] = ACTIONS(2422),
    [anon_sym_for] = ACTIONS(2422),
    [anon_sym_FOR] = ACTIONS(2422),
    [anon_sym_For] = ACTIONS(2422),
    [anon_sym_foreach] = ACTIONS(2422),
    [anon_sym_FOREACH] = ACTIONS(2422),
    [anon_sym_Foreach] = ACTIONS(2422),
    [anon_sym_while] = ACTIONS(2422),
    [anon_sym_WHILE] = ACTIONS(2422),
    [anon_sym_While] = ACTIONS(2422),
    [anon_sym_repeat] = ACTIONS(2422),
    [anon_sym_REPEAT] = ACTIONS(2422),
    [anon_sym_Repeat] = ACTIONS(2422),
    [anon_sym_exit] = ACTIONS(2422),
    [anon_sym_EXIT] = ACTIONS(2422),
    [anon_sym_Exit] = ACTIONS(2422),
    [anon_sym_continue] = ACTIONS(2422),
    [anon_sym_CONTINUE] = ACTIONS(2422),
    [anon_sym_Continue] = ACTIONS(2422),
    [anon_sym_break] = ACTIONS(2422),
    [anon_sym_BREAK] = ACTIONS(2422),
    [anon_sym_Break] = ACTIONS(2422),
    [anon_sym_with] = ACTIONS(2422),
    [anon_sym_WITH] = ACTIONS(2422),
    [anon_sym_With] = ACTIONS(2422),
    [sym_asserterror_keyword] = ACTIONS(2424),
    [anon_sym_in] = ACTIONS(2422),
    [anon_sym_IN] = ACTIONS(2422),
    [anon_sym_In] = ACTIONS(2422),
    [sym_page_keyword] = ACTIONS(2422),
    [anon_sym_codeunit] = ACTIONS(2422),
    [anon_sym_CODEUNIT] = ACTIONS(2422),
    [anon_sym_Codeunit] = ACTIONS(2422),
    [anon_sym_CodeUnit] = ACTIONS(2422),
    [anon_sym_COdeunit] = ACTIONS(2422),
    [anon_sym_codeUnit] = ACTIONS(2422),
    [sym_report_keyword] = ACTIONS(2422),
    [sym_query_keyword] = ACTIONS(2422),
    [anon_sym_xmlport] = ACTIONS(2422),
    [anon_sym_XMLPORT] = ACTIONS(2422),
    [anon_sym_Xmlport] = ACTIONS(2422),
    [anon_sym_XMLport] = ACTIONS(2422),
    [anon_sym_XMLPort] = ACTIONS(2422),
    [anon_sym_XmlPort] = ACTIONS(2422),
    [anon_sym_enum] = ACTIONS(2422),
    [anon_sym_ENUM] = ACTIONS(2422),
    [anon_sym_Enum] = ACTIONS(2422),
    [anon_sym_eNUM] = ACTIONS(2422),
    [anon_sym_eNum] = ACTIONS(2422),
    [anon_sym_ENum] = ACTIONS(2422),
    [sym_quoted_identifier] = ACTIONS(2424),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2424),
    [sym_integer] = ACTIONS(2422),
    [sym_continue_as_identifier] = ACTIONS(2424),
    [sym_preproc_open] = ACTIONS(2424),
    [sym_preproc_close] = ACTIONS(2424),
  },
  [STATE(991)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_SEMI] = ACTIONS(2428),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_COMMA] = ACTIONS(2428),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2426),
    [anon_sym_COLON_COLON] = ACTIONS(2428),
    [anon_sym_POUNDif] = ACTIONS(2428),
    [anon_sym_POUNDIF] = ACTIONS(2428),
    [anon_sym_POUNDIf] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [anon_sym_POUNDelif] = ACTIONS(2428),
    [anon_sym_POUNDELIF] = ACTIONS(2428),
    [anon_sym_POUNDElif] = ACTIONS(2428),
    [anon_sym_POUNDelse] = ACTIONS(2428),
    [anon_sym_POUNDELSE] = ACTIONS(2428),
    [anon_sym_POUNDElse] = ACTIONS(2428),
    [anon_sym_POUNDendif] = ACTIONS(2428),
    [anon_sym_POUNDENDIF] = ACTIONS(2428),
    [anon_sym_POUNDEndif] = ACTIONS(2428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_IF] = ACTIONS(2426),
    [anon_sym_If] = ACTIONS(2426),
    [anon_sym_else] = ACTIONS(2426),
    [anon_sym_ELSE] = ACTIONS(2426),
    [anon_sym_Else] = ACTIONS(2426),
    [anon_sym_case] = ACTIONS(2426),
    [anon_sym_CASE] = ACTIONS(2426),
    [anon_sym_Case] = ACTIONS(2426),
    [anon_sym_for] = ACTIONS(2426),
    [anon_sym_FOR] = ACTIONS(2426),
    [anon_sym_For] = ACTIONS(2426),
    [anon_sym_foreach] = ACTIONS(2426),
    [anon_sym_FOREACH] = ACTIONS(2426),
    [anon_sym_Foreach] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(2426),
    [anon_sym_WHILE] = ACTIONS(2426),
    [anon_sym_While] = ACTIONS(2426),
    [anon_sym_repeat] = ACTIONS(2426),
    [anon_sym_REPEAT] = ACTIONS(2426),
    [anon_sym_Repeat] = ACTIONS(2426),
    [anon_sym_exit] = ACTIONS(2426),
    [anon_sym_EXIT] = ACTIONS(2426),
    [anon_sym_Exit] = ACTIONS(2426),
    [anon_sym_continue] = ACTIONS(2426),
    [anon_sym_CONTINUE] = ACTIONS(2426),
    [anon_sym_Continue] = ACTIONS(2426),
    [anon_sym_break] = ACTIONS(2426),
    [anon_sym_BREAK] = ACTIONS(2426),
    [anon_sym_Break] = ACTIONS(2426),
    [anon_sym_with] = ACTIONS(2426),
    [anon_sym_WITH] = ACTIONS(2426),
    [anon_sym_With] = ACTIONS(2426),
    [sym_asserterror_keyword] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_open] = ACTIONS(2428),
    [sym_preproc_close] = ACTIONS(2428),
  },
  [STATE(992)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2430),
    [anon_sym_SEMI] = ACTIONS(2432),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2432),
    [anon_sym_DASH] = ACTIONS(2430),
    [aux_sym_boolean_token1] = ACTIONS(2430),
    [aux_sym_boolean_token2] = ACTIONS(2430),
    [sym_decimal] = ACTIONS(2430),
    [anon_sym_LPAREN] = ACTIONS(2432),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2430),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2430),
    [aux_sym_basic_type_token21] = ACTIONS(2430),
    [aux_sym_basic_type_token22] = ACTIONS(2430),
    [aux_sym_basic_type_token48] = ACTIONS(2430),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2430),
    [anon_sym_POUNDif] = ACTIONS(2432),
    [anon_sym_POUNDIF] = ACTIONS(2432),
    [anon_sym_POUNDIf] = ACTIONS(2432),
    [anon_sym_not] = ACTIONS(2430),
    [anon_sym_NOT] = ACTIONS(2430),
    [anon_sym_Not] = ACTIONS(2430),
    [anon_sym_POUNDelif] = ACTIONS(2432),
    [anon_sym_POUNDELIF] = ACTIONS(2432),
    [anon_sym_POUNDElif] = ACTIONS(2432),
    [anon_sym_POUNDelse] = ACTIONS(2432),
    [anon_sym_POUNDELSE] = ACTIONS(2432),
    [anon_sym_POUNDElse] = ACTIONS(2432),
    [anon_sym_POUNDendif] = ACTIONS(2432),
    [anon_sym_POUNDENDIF] = ACTIONS(2432),
    [anon_sym_POUNDEndif] = ACTIONS(2432),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2432),
    [aux_sym__expression_token1] = ACTIONS(2432),
    [aux_sym__expression_token2] = ACTIONS(2430),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2430),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2430),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2430),
    [anon_sym_GT_EQ] = ACTIONS(2432),
    [anon_sym_LT_EQ] = ACTIONS(2432),
    [anon_sym_GT] = ACTIONS(2430),
    [anon_sym_LT] = ACTIONS(2430),
    [anon_sym_LT_GT] = ACTIONS(2432),
    [anon_sym_and] = ACTIONS(2430),
    [anon_sym_AND] = ACTIONS(2430),
    [anon_sym_And] = ACTIONS(2430),
    [anon_sym_or] = ACTIONS(2430),
    [anon_sym_OR] = ACTIONS(2430),
    [anon_sym_Or] = ACTIONS(2430),
    [anon_sym_xor] = ACTIONS(2430),
    [anon_sym_XOR] = ACTIONS(2430),
    [anon_sym_Xor] = ACTIONS(2430),
    [anon_sym_QMARK] = ACTIONS(2432),
    [sym_datetime_literal] = ACTIONS(2432),
    [sym_date_literal] = ACTIONS(2430),
    [sym_time_literal] = ACTIONS(2430),
    [sym_biginteger_literal] = ACTIONS(2432),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_IF] = ACTIONS(2430),
    [anon_sym_If] = ACTIONS(2430),
    [anon_sym_else] = ACTIONS(2430),
    [anon_sym_ELSE] = ACTIONS(2430),
    [anon_sym_Else] = ACTIONS(2430),
    [anon_sym_case] = ACTIONS(2430),
    [anon_sym_CASE] = ACTIONS(2430),
    [anon_sym_Case] = ACTIONS(2430),
    [anon_sym_for] = ACTIONS(2430),
    [anon_sym_FOR] = ACTIONS(2430),
    [anon_sym_For] = ACTIONS(2430),
    [anon_sym_foreach] = ACTIONS(2430),
    [anon_sym_FOREACH] = ACTIONS(2430),
    [anon_sym_Foreach] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2430),
    [anon_sym_WHILE] = ACTIONS(2430),
    [anon_sym_While] = ACTIONS(2430),
    [anon_sym_repeat] = ACTIONS(2430),
    [anon_sym_REPEAT] = ACTIONS(2430),
    [anon_sym_Repeat] = ACTIONS(2430),
    [anon_sym_exit] = ACTIONS(2430),
    [anon_sym_EXIT] = ACTIONS(2430),
    [anon_sym_Exit] = ACTIONS(2430),
    [anon_sym_continue] = ACTIONS(2430),
    [anon_sym_CONTINUE] = ACTIONS(2430),
    [anon_sym_Continue] = ACTIONS(2430),
    [anon_sym_break] = ACTIONS(2430),
    [anon_sym_BREAK] = ACTIONS(2430),
    [anon_sym_Break] = ACTIONS(2430),
    [anon_sym_with] = ACTIONS(2430),
    [anon_sym_WITH] = ACTIONS(2430),
    [anon_sym_With] = ACTIONS(2430),
    [sym_asserterror_keyword] = ACTIONS(2432),
    [anon_sym_in] = ACTIONS(2430),
    [anon_sym_IN] = ACTIONS(2430),
    [anon_sym_In] = ACTIONS(2430),
    [sym_page_keyword] = ACTIONS(2430),
    [anon_sym_codeunit] = ACTIONS(2430),
    [anon_sym_CODEUNIT] = ACTIONS(2430),
    [anon_sym_Codeunit] = ACTIONS(2430),
    [anon_sym_CodeUnit] = ACTIONS(2430),
    [anon_sym_COdeunit] = ACTIONS(2430),
    [anon_sym_codeUnit] = ACTIONS(2430),
    [sym_report_keyword] = ACTIONS(2430),
    [sym_query_keyword] = ACTIONS(2430),
    [anon_sym_xmlport] = ACTIONS(2430),
    [anon_sym_XMLPORT] = ACTIONS(2430),
    [anon_sym_Xmlport] = ACTIONS(2430),
    [anon_sym_XMLport] = ACTIONS(2430),
    [anon_sym_XMLPort] = ACTIONS(2430),
    [anon_sym_XmlPort] = ACTIONS(2430),
    [anon_sym_enum] = ACTIONS(2430),
    [anon_sym_ENUM] = ACTIONS(2430),
    [anon_sym_Enum] = ACTIONS(2430),
    [anon_sym_eNUM] = ACTIONS(2430),
    [anon_sym_eNum] = ACTIONS(2430),
    [anon_sym_ENum] = ACTIONS(2430),
    [sym_quoted_identifier] = ACTIONS(2432),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2432),
    [sym_integer] = ACTIONS(2430),
    [sym_continue_as_identifier] = ACTIONS(2432),
    [sym_preproc_open] = ACTIONS(2432),
    [sym_preproc_close] = ACTIONS(2432),
  },
  [STATE(993)] = {
    [sym_argument_list] = STATE(1014),
    [sym_identifier] = ACTIONS(2434),
    [anon_sym_SEMI] = ACTIONS(2436),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_DASH] = ACTIONS(2434),
    [aux_sym_boolean_token1] = ACTIONS(2434),
    [aux_sym_boolean_token2] = ACTIONS(2434),
    [sym_decimal] = ACTIONS(2434),
    [anon_sym_LPAREN] = ACTIONS(2438),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2434),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [aux_sym_record_type_token1] = ACTIONS(2434),
    [aux_sym_basic_type_token21] = ACTIONS(2434),
    [aux_sym_basic_type_token22] = ACTIONS(2434),
    [aux_sym_basic_type_token48] = ACTIONS(2434),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2434),
    [anon_sym_COLON_COLON] = ACTIONS(2440),
    [anon_sym_POUNDif] = ACTIONS(2436),
    [anon_sym_POUNDIF] = ACTIONS(2436),
    [anon_sym_POUNDIf] = ACTIONS(2436),
    [anon_sym_not] = ACTIONS(2434),
    [anon_sym_NOT] = ACTIONS(2434),
    [anon_sym_Not] = ACTIONS(2434),
    [anon_sym_POUNDelif] = ACTIONS(2436),
    [anon_sym_POUNDELIF] = ACTIONS(2436),
    [anon_sym_POUNDElif] = ACTIONS(2436),
    [anon_sym_POUNDelse] = ACTIONS(2436),
    [anon_sym_POUNDELSE] = ACTIONS(2436),
    [anon_sym_POUNDElse] = ACTIONS(2436),
    [anon_sym_POUNDendif] = ACTIONS(2436),
    [anon_sym_POUNDENDIF] = ACTIONS(2436),
    [anon_sym_POUNDEndif] = ACTIONS(2436),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2434),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(2434),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(2436),
    [sym_date_literal] = ACTIONS(2434),
    [sym_time_literal] = ACTIONS(2434),
    [sym_biginteger_literal] = ACTIONS(2436),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_IF] = ACTIONS(2434),
    [anon_sym_If] = ACTIONS(2434),
    [anon_sym_else] = ACTIONS(2434),
    [anon_sym_ELSE] = ACTIONS(2434),
    [anon_sym_Else] = ACTIONS(2434),
    [anon_sym_case] = ACTIONS(2434),
    [anon_sym_CASE] = ACTIONS(2434),
    [anon_sym_Case] = ACTIONS(2434),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_FOR] = ACTIONS(2434),
    [anon_sym_For] = ACTIONS(2434),
    [anon_sym_foreach] = ACTIONS(2434),
    [anon_sym_FOREACH] = ACTIONS(2434),
    [anon_sym_Foreach] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(2434),
    [anon_sym_WHILE] = ACTIONS(2434),
    [anon_sym_While] = ACTIONS(2434),
    [anon_sym_repeat] = ACTIONS(2434),
    [anon_sym_REPEAT] = ACTIONS(2434),
    [anon_sym_Repeat] = ACTIONS(2434),
    [anon_sym_exit] = ACTIONS(2434),
    [anon_sym_EXIT] = ACTIONS(2434),
    [anon_sym_Exit] = ACTIONS(2434),
    [anon_sym_continue] = ACTIONS(2434),
    [anon_sym_CONTINUE] = ACTIONS(2434),
    [anon_sym_Continue] = ACTIONS(2434),
    [anon_sym_break] = ACTIONS(2434),
    [anon_sym_BREAK] = ACTIONS(2434),
    [anon_sym_Break] = ACTIONS(2434),
    [anon_sym_with] = ACTIONS(2434),
    [anon_sym_WITH] = ACTIONS(2434),
    [anon_sym_With] = ACTIONS(2434),
    [sym_asserterror_keyword] = ACTIONS(2436),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(2434),
    [anon_sym_codeunit] = ACTIONS(2434),
    [anon_sym_CODEUNIT] = ACTIONS(2434),
    [anon_sym_Codeunit] = ACTIONS(2434),
    [anon_sym_CodeUnit] = ACTIONS(2434),
    [anon_sym_COdeunit] = ACTIONS(2434),
    [anon_sym_codeUnit] = ACTIONS(2434),
    [sym_report_keyword] = ACTIONS(2434),
    [sym_query_keyword] = ACTIONS(2434),
    [anon_sym_xmlport] = ACTIONS(2434),
    [anon_sym_XMLPORT] = ACTIONS(2434),
    [anon_sym_Xmlport] = ACTIONS(2434),
    [anon_sym_XMLport] = ACTIONS(2434),
    [anon_sym_XMLPort] = ACTIONS(2434),
    [anon_sym_XmlPort] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2434),
    [anon_sym_ENUM] = ACTIONS(2434),
    [anon_sym_Enum] = ACTIONS(2434),
    [anon_sym_eNUM] = ACTIONS(2434),
    [anon_sym_eNum] = ACTIONS(2434),
    [anon_sym_ENum] = ACTIONS(2434),
    [sym_quoted_identifier] = ACTIONS(2436),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2436),
    [sym_integer] = ACTIONS(2434),
    [sym_continue_as_identifier] = ACTIONS(2436),
    [sym_preproc_open] = ACTIONS(2436),
    [sym_preproc_close] = ACTIONS(2436),
  },
  [STATE(994)] = {
    [sym_preproc_conditional_object] = STATE(955),
    [sym_using_statement] = STATE(955),
    [sym__object] = STATE(955),
    [sym_preproc_split_declaration] = STATE(955),
    [sym_table_declaration] = STATE(955),
    [sym_page_declaration] = STATE(955),
    [sym_report_declaration] = STATE(955),
    [sym_query_declaration] = STATE(955),
    [sym_xmlport_declaration] = STATE(955),
    [sym_permissionset_declaration] = STATE(955),
    [sym_codeunit_declaration] = STATE(955),
    [sym_enum_declaration] = STATE(955),
    [sym_tableextension_declaration] = STATE(955),
    [sym_pageextension_declaration] = STATE(955),
    [sym_reportextension_declaration] = STATE(955),
    [sym_enumextension_declaration] = STATE(955),
    [sym_permissionsetextension_declaration] = STATE(955),
    [sym_controladdin_declaration] = STATE(955),
    [sym_profile_declaration] = STATE(955),
    [sym_entitlement_declaration] = STATE(955),
    [sym_profileextension_declaration] = STATE(955),
    [sym_interface_declaration] = STATE(955),
    [sym_pagecustomization_declaration] = STATE(955),
    [sym_dotnet_declaration] = STATE(955),
    [sym_preproc_if] = STATE(616),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(955),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(2352),
    [anon_sym_POUNDELIF] = ACTIONS(2352),
    [anon_sym_POUNDElif] = ACTIONS(2352),
    [anon_sym_POUNDelse] = ACTIONS(2352),
    [anon_sym_POUNDELSE] = ACTIONS(2352),
    [anon_sym_POUNDElse] = ACTIONS(2352),
    [anon_sym_POUNDendif] = ACTIONS(2352),
    [anon_sym_POUNDENDIF] = ACTIONS(2352),
    [anon_sym_POUNDEndif] = ACTIONS(2352),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(2352),
  },
  [STATE(995)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(985),
    [sym_identifier] = ACTIONS(2442),
    [anon_sym_SEMI] = ACTIONS(2444),
    [anon_sym_DOT] = ACTIONS(2350),
    [anon_sym_EQ] = ACTIONS(2444),
    [anon_sym_DASH] = ACTIONS(2442),
    [aux_sym_boolean_token1] = ACTIONS(2442),
    [aux_sym_boolean_token2] = ACTIONS(2442),
    [sym_decimal] = ACTIONS(2442),
    [anon_sym_LPAREN] = ACTIONS(2444),
    [anon_sym_DOT_DOT] = ACTIONS(2444),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2442),
    [anon_sym_STAR] = ACTIONS(2442),
    [anon_sym_LBRACK] = ACTIONS(2444),
    [aux_sym_record_type_token1] = ACTIONS(2442),
    [aux_sym_basic_type_token21] = ACTIONS(2442),
    [aux_sym_basic_type_token22] = ACTIONS(2442),
    [aux_sym_basic_type_token48] = ACTIONS(2442),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2442),
    [anon_sym_POUNDif] = ACTIONS(2444),
    [anon_sym_POUNDIF] = ACTIONS(2444),
    [anon_sym_POUNDIf] = ACTIONS(2444),
    [anon_sym_not] = ACTIONS(2442),
    [anon_sym_NOT] = ACTIONS(2442),
    [anon_sym_Not] = ACTIONS(2442),
    [anon_sym_POUNDelif] = ACTIONS(2444),
    [anon_sym_POUNDELIF] = ACTIONS(2444),
    [anon_sym_POUNDElif] = ACTIONS(2444),
    [anon_sym_POUNDelse] = ACTIONS(2444),
    [anon_sym_POUNDELSE] = ACTIONS(2444),
    [anon_sym_POUNDElse] = ACTIONS(2444),
    [anon_sym_POUNDendif] = ACTIONS(2444),
    [anon_sym_POUNDENDIF] = ACTIONS(2444),
    [anon_sym_POUNDEndif] = ACTIONS(2444),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2444),
    [aux_sym__expression_token1] = ACTIONS(2444),
    [aux_sym__expression_token2] = ACTIONS(2442),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2442),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2442),
    [anon_sym_SLASH] = ACTIONS(2442),
    [anon_sym_div] = ACTIONS(2442),
    [anon_sym_DIV] = ACTIONS(2442),
    [anon_sym_Div] = ACTIONS(2442),
    [anon_sym_mod] = ACTIONS(2442),
    [anon_sym_MOD] = ACTIONS(2442),
    [anon_sym_Mod] = ACTIONS(2442),
    [anon_sym_PLUS] = ACTIONS(2442),
    [anon_sym_GT_EQ] = ACTIONS(2444),
    [anon_sym_LT_EQ] = ACTIONS(2444),
    [anon_sym_GT] = ACTIONS(2442),
    [anon_sym_LT] = ACTIONS(2442),
    [anon_sym_LT_GT] = ACTIONS(2444),
    [anon_sym_and] = ACTIONS(2442),
    [anon_sym_AND] = ACTIONS(2442),
    [anon_sym_And] = ACTIONS(2442),
    [anon_sym_or] = ACTIONS(2442),
    [anon_sym_OR] = ACTIONS(2442),
    [anon_sym_Or] = ACTIONS(2442),
    [anon_sym_xor] = ACTIONS(2442),
    [anon_sym_XOR] = ACTIONS(2442),
    [anon_sym_Xor] = ACTIONS(2442),
    [anon_sym_QMARK] = ACTIONS(2444),
    [sym_datetime_literal] = ACTIONS(2444),
    [sym_date_literal] = ACTIONS(2442),
    [sym_time_literal] = ACTIONS(2442),
    [sym_biginteger_literal] = ACTIONS(2444),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_IF] = ACTIONS(2442),
    [anon_sym_If] = ACTIONS(2442),
    [anon_sym_else] = ACTIONS(2442),
    [anon_sym_ELSE] = ACTIONS(2442),
    [anon_sym_Else] = ACTIONS(2442),
    [anon_sym_case] = ACTIONS(2442),
    [anon_sym_CASE] = ACTIONS(2442),
    [anon_sym_Case] = ACTIONS(2442),
    [anon_sym_for] = ACTIONS(2442),
    [anon_sym_FOR] = ACTIONS(2442),
    [anon_sym_For] = ACTIONS(2442),
    [anon_sym_foreach] = ACTIONS(2442),
    [anon_sym_FOREACH] = ACTIONS(2442),
    [anon_sym_Foreach] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2442),
    [anon_sym_WHILE] = ACTIONS(2442),
    [anon_sym_While] = ACTIONS(2442),
    [anon_sym_repeat] = ACTIONS(2442),
    [anon_sym_REPEAT] = ACTIONS(2442),
    [anon_sym_Repeat] = ACTIONS(2442),
    [anon_sym_exit] = ACTIONS(2442),
    [anon_sym_EXIT] = ACTIONS(2442),
    [anon_sym_Exit] = ACTIONS(2442),
    [anon_sym_continue] = ACTIONS(2442),
    [anon_sym_CONTINUE] = ACTIONS(2442),
    [anon_sym_Continue] = ACTIONS(2442),
    [anon_sym_break] = ACTIONS(2442),
    [anon_sym_BREAK] = ACTIONS(2442),
    [anon_sym_Break] = ACTIONS(2442),
    [anon_sym_with] = ACTIONS(2442),
    [anon_sym_WITH] = ACTIONS(2442),
    [anon_sym_With] = ACTIONS(2442),
    [sym_asserterror_keyword] = ACTIONS(2444),
    [anon_sym_in] = ACTIONS(2442),
    [anon_sym_IN] = ACTIONS(2442),
    [anon_sym_In] = ACTIONS(2442),
    [sym_page_keyword] = ACTIONS(2442),
    [anon_sym_codeunit] = ACTIONS(2442),
    [anon_sym_CODEUNIT] = ACTIONS(2442),
    [anon_sym_Codeunit] = ACTIONS(2442),
    [anon_sym_CodeUnit] = ACTIONS(2442),
    [anon_sym_COdeunit] = ACTIONS(2442),
    [anon_sym_codeUnit] = ACTIONS(2442),
    [sym_report_keyword] = ACTIONS(2442),
    [sym_query_keyword] = ACTIONS(2442),
    [anon_sym_xmlport] = ACTIONS(2442),
    [anon_sym_XMLPORT] = ACTIONS(2442),
    [anon_sym_Xmlport] = ACTIONS(2442),
    [anon_sym_XMLport] = ACTIONS(2442),
    [anon_sym_XMLPort] = ACTIONS(2442),
    [anon_sym_XmlPort] = ACTIONS(2442),
    [anon_sym_enum] = ACTIONS(2442),
    [anon_sym_ENUM] = ACTIONS(2442),
    [anon_sym_Enum] = ACTIONS(2442),
    [anon_sym_eNUM] = ACTIONS(2442),
    [anon_sym_eNum] = ACTIONS(2442),
    [anon_sym_ENum] = ACTIONS(2442),
    [sym_temporary_keyword] = ACTIONS(2442),
    [sym_quoted_identifier] = ACTIONS(2444),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2444),
    [sym_integer] = ACTIONS(2442),
    [sym_continue_as_identifier] = ACTIONS(2444),
    [sym_preproc_open] = ACTIONS(2444),
    [sym_preproc_close] = ACTIONS(2444),
  },
  [STATE(996)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [anon_sym_POUNDif] = ACTIONS(2446),
    [anon_sym_POUNDIF] = ACTIONS(2446),
    [anon_sym_POUNDIf] = ACTIONS(2446),
    [anon_sym_POUNDelif] = ACTIONS(2449),
    [anon_sym_POUNDELIF] = ACTIONS(2449),
    [anon_sym_POUNDElif] = ACTIONS(2449),
    [anon_sym_POUNDelse] = ACTIONS(2449),
    [anon_sym_POUNDELSE] = ACTIONS(2449),
    [anon_sym_POUNDElse] = ACTIONS(2449),
    [anon_sym_POUNDendif] = ACTIONS(2449),
    [anon_sym_POUNDENDIF] = ACTIONS(2449),
    [anon_sym_POUNDEndif] = ACTIONS(2449),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2451),
    [anon_sym_tableextension] = ACTIONS(2454),
    [anon_sym_TABLEEXTENSION] = ACTIONS(2454),
    [anon_sym_Tableextension] = ACTIONS(2454),
    [anon_sym_TableExtension] = ACTIONS(2454),
    [anon_sym_tableExtension] = ACTIONS(2454),
    [sym_page_keyword] = ACTIONS(2457),
    [anon_sym_pageextension] = ACTIONS(2460),
    [anon_sym_PAGEEXTENSION] = ACTIONS(2460),
    [anon_sym_Pageextension] = ACTIONS(2460),
    [anon_sym_PageExtension] = ACTIONS(2460),
    [anon_sym_pageExtension] = ACTIONS(2460),
    [anon_sym_codeunit] = ACTIONS(2463),
    [anon_sym_CODEUNIT] = ACTIONS(2463),
    [anon_sym_Codeunit] = ACTIONS(2463),
    [anon_sym_CodeUnit] = ACTIONS(2463),
    [anon_sym_COdeunit] = ACTIONS(2463),
    [anon_sym_codeUnit] = ACTIONS(2463),
    [sym_report_keyword] = ACTIONS(2466),
    [anon_sym_reportextension] = ACTIONS(2469),
    [anon_sym_REPORTEXTENSION] = ACTIONS(2469),
    [anon_sym_Reportextension] = ACTIONS(2469),
    [anon_sym_ReportExtension] = ACTIONS(2469),
    [anon_sym_reportExtension] = ACTIONS(2469),
    [sym_query_keyword] = ACTIONS(2472),
    [anon_sym_xmlport] = ACTIONS(2475),
    [anon_sym_XMLPORT] = ACTIONS(2475),
    [anon_sym_Xmlport] = ACTIONS(2475),
    [anon_sym_XMLport] = ACTIONS(2475),
    [anon_sym_XMLPort] = ACTIONS(2475),
    [anon_sym_XmlPort] = ACTIONS(2475),
    [anon_sym_enum] = ACTIONS(2478),
    [anon_sym_ENUM] = ACTIONS(2478),
    [anon_sym_Enum] = ACTIONS(2478),
    [anon_sym_eNUM] = ACTIONS(2481),
    [anon_sym_eNum] = ACTIONS(2481),
    [anon_sym_ENum] = ACTIONS(2481),
    [anon_sym_enumextension] = ACTIONS(2484),
    [anon_sym_ENUMEXTENSION] = ACTIONS(2484),
    [anon_sym_Enumextension] = ACTIONS(2484),
    [anon_sym_EnumExtension] = ACTIONS(2484),
    [anon_sym_enumExtension] = ACTIONS(2484),
    [sym_interface_keyword] = ACTIONS(2487),
    [anon_sym_controladdin] = ACTIONS(2490),
    [anon_sym_CONTROLADDIN] = ACTIONS(2490),
    [anon_sym_Controladdin] = ACTIONS(2490),
    [anon_sym_ControlAddIn] = ACTIONS(2490),
    [anon_sym_ControlAddin] = ACTIONS(2490),
    [anon_sym_controlAddIn] = ACTIONS(2490),
    [anon_sym_controlAddin] = ACTIONS(2490),
    [anon_sym_dotnet] = ACTIONS(2493),
    [anon_sym_DOTNET] = ACTIONS(2493),
    [anon_sym_Dotnet] = ACTIONS(2493),
    [anon_sym_DotNet] = ACTIONS(2493),
    [anon_sym_dotNet] = ACTIONS(2493),
    [sym_profile_keyword] = ACTIONS(2496),
    [anon_sym_profileextension] = ACTIONS(2499),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(2499),
    [anon_sym_Profileextension] = ACTIONS(2499),
    [anon_sym_ProfileExtension] = ACTIONS(2499),
    [anon_sym_profileExtension] = ACTIONS(2499),
    [anon_sym_permissionset] = ACTIONS(2502),
    [anon_sym_PERMISSIONSET] = ACTIONS(2502),
    [anon_sym_Permissionset] = ACTIONS(2502),
    [anon_sym_PermissionSet] = ACTIONS(2502),
    [anon_sym_permissionSet] = ACTIONS(2502),
    [anon_sym_permissionsetextension] = ACTIONS(2505),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(2505),
    [anon_sym_Permissionsetextension] = ACTIONS(2505),
    [anon_sym_PermissionSetExtension] = ACTIONS(2505),
    [anon_sym_permissionSetExtension] = ACTIONS(2505),
    [sym_entitlement_keyword] = ACTIONS(2508),
    [anon_sym_pagecustomization] = ACTIONS(2511),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(2511),
    [anon_sym_Pagecustomization] = ACTIONS(2511),
    [anon_sym_PageCustomization] = ACTIONS(2511),
    [anon_sym_pageCustomization] = ACTIONS(2511),
    [sym_using_keyword] = ACTIONS(2514),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(2446),
    [sym_preproc_close] = ACTIONS(2449),
  },
  [STATE(997)] = {
    [sym_comparison_operator] = STATE(3124),
    [sym_in_keyword] = STATE(11201),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2274),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2278),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2280),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2286),
    [aux_sym__expression_token2] = ACTIONS(2288),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2290),
    [anon_sym_div] = ACTIONS(2292),
    [anon_sym_DIV] = ACTIONS(2294),
    [anon_sym_Div] = ACTIONS(2296),
    [anon_sym_mod] = ACTIONS(2298),
    [anon_sym_MOD] = ACTIONS(2300),
    [anon_sym_Mod] = ACTIONS(2302),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2308),
    [anon_sym_AND] = ACTIONS(2310),
    [anon_sym_And] = ACTIONS(2312),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(998)] = {
    [sym_identifier] = ACTIONS(2517),
    [anon_sym_SEMI] = ACTIONS(2519),
    [anon_sym_DOT] = ACTIONS(2517),
    [anon_sym_EQ] = ACTIONS(2519),
    [anon_sym_DASH] = ACTIONS(2517),
    [aux_sym_boolean_token1] = ACTIONS(2517),
    [aux_sym_boolean_token2] = ACTIONS(2517),
    [sym_decimal] = ACTIONS(2517),
    [anon_sym_LPAREN] = ACTIONS(2519),
    [anon_sym_DOT_DOT] = ACTIONS(2519),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2517),
    [anon_sym_STAR] = ACTIONS(2517),
    [anon_sym_LBRACK] = ACTIONS(2519),
    [aux_sym_record_type_token1] = ACTIONS(2517),
    [aux_sym_basic_type_token21] = ACTIONS(2517),
    [aux_sym_basic_type_token22] = ACTIONS(2517),
    [aux_sym_basic_type_token48] = ACTIONS(2517),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2517),
    [anon_sym_COLON_COLON] = ACTIONS(2519),
    [anon_sym_POUNDif] = ACTIONS(2519),
    [anon_sym_POUNDIF] = ACTIONS(2519),
    [anon_sym_POUNDIf] = ACTIONS(2519),
    [anon_sym_not] = ACTIONS(2517),
    [anon_sym_NOT] = ACTIONS(2517),
    [anon_sym_Not] = ACTIONS(2517),
    [anon_sym_POUNDelif] = ACTIONS(2519),
    [anon_sym_POUNDELIF] = ACTIONS(2519),
    [anon_sym_POUNDElif] = ACTIONS(2519),
    [anon_sym_POUNDelse] = ACTIONS(2519),
    [anon_sym_POUNDELSE] = ACTIONS(2519),
    [anon_sym_POUNDElse] = ACTIONS(2519),
    [anon_sym_POUNDendif] = ACTIONS(2519),
    [anon_sym_POUNDENDIF] = ACTIONS(2519),
    [anon_sym_POUNDEndif] = ACTIONS(2519),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2519),
    [aux_sym__expression_token1] = ACTIONS(2519),
    [aux_sym__expression_token2] = ACTIONS(2517),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2517),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2517),
    [anon_sym_SLASH] = ACTIONS(2517),
    [anon_sym_div] = ACTIONS(2517),
    [anon_sym_DIV] = ACTIONS(2517),
    [anon_sym_Div] = ACTIONS(2517),
    [anon_sym_mod] = ACTIONS(2517),
    [anon_sym_MOD] = ACTIONS(2517),
    [anon_sym_Mod] = ACTIONS(2517),
    [anon_sym_PLUS] = ACTIONS(2517),
    [anon_sym_GT_EQ] = ACTIONS(2519),
    [anon_sym_LT_EQ] = ACTIONS(2519),
    [anon_sym_GT] = ACTIONS(2517),
    [anon_sym_LT] = ACTIONS(2517),
    [anon_sym_LT_GT] = ACTIONS(2519),
    [anon_sym_and] = ACTIONS(2517),
    [anon_sym_AND] = ACTIONS(2517),
    [anon_sym_And] = ACTIONS(2517),
    [anon_sym_or] = ACTIONS(2517),
    [anon_sym_OR] = ACTIONS(2517),
    [anon_sym_Or] = ACTIONS(2517),
    [anon_sym_xor] = ACTIONS(2517),
    [anon_sym_XOR] = ACTIONS(2517),
    [anon_sym_Xor] = ACTIONS(2517),
    [anon_sym_QMARK] = ACTIONS(2519),
    [sym_datetime_literal] = ACTIONS(2519),
    [sym_date_literal] = ACTIONS(2517),
    [sym_time_literal] = ACTIONS(2517),
    [sym_biginteger_literal] = ACTIONS(2519),
    [anon_sym_if] = ACTIONS(2517),
    [anon_sym_IF] = ACTIONS(2517),
    [anon_sym_If] = ACTIONS(2517),
    [anon_sym_else] = ACTIONS(2517),
    [anon_sym_ELSE] = ACTIONS(2517),
    [anon_sym_Else] = ACTIONS(2517),
    [anon_sym_case] = ACTIONS(2517),
    [anon_sym_CASE] = ACTIONS(2517),
    [anon_sym_Case] = ACTIONS(2517),
    [anon_sym_for] = ACTIONS(2517),
    [anon_sym_FOR] = ACTIONS(2517),
    [anon_sym_For] = ACTIONS(2517),
    [anon_sym_foreach] = ACTIONS(2517),
    [anon_sym_FOREACH] = ACTIONS(2517),
    [anon_sym_Foreach] = ACTIONS(2517),
    [anon_sym_while] = ACTIONS(2517),
    [anon_sym_WHILE] = ACTIONS(2517),
    [anon_sym_While] = ACTIONS(2517),
    [anon_sym_repeat] = ACTIONS(2517),
    [anon_sym_REPEAT] = ACTIONS(2517),
    [anon_sym_Repeat] = ACTIONS(2517),
    [anon_sym_exit] = ACTIONS(2517),
    [anon_sym_EXIT] = ACTIONS(2517),
    [anon_sym_Exit] = ACTIONS(2517),
    [anon_sym_continue] = ACTIONS(2517),
    [anon_sym_CONTINUE] = ACTIONS(2517),
    [anon_sym_Continue] = ACTIONS(2517),
    [anon_sym_break] = ACTIONS(2517),
    [anon_sym_BREAK] = ACTIONS(2517),
    [anon_sym_Break] = ACTIONS(2517),
    [anon_sym_with] = ACTIONS(2517),
    [anon_sym_WITH] = ACTIONS(2517),
    [anon_sym_With] = ACTIONS(2517),
    [sym_asserterror_keyword] = ACTIONS(2519),
    [anon_sym_in] = ACTIONS(2517),
    [anon_sym_IN] = ACTIONS(2517),
    [anon_sym_In] = ACTIONS(2517),
    [sym_page_keyword] = ACTIONS(2517),
    [anon_sym_codeunit] = ACTIONS(2517),
    [anon_sym_CODEUNIT] = ACTIONS(2517),
    [anon_sym_Codeunit] = ACTIONS(2517),
    [anon_sym_CodeUnit] = ACTIONS(2517),
    [anon_sym_COdeunit] = ACTIONS(2517),
    [anon_sym_codeUnit] = ACTIONS(2517),
    [sym_report_keyword] = ACTIONS(2517),
    [sym_query_keyword] = ACTIONS(2517),
    [anon_sym_xmlport] = ACTIONS(2517),
    [anon_sym_XMLPORT] = ACTIONS(2517),
    [anon_sym_Xmlport] = ACTIONS(2517),
    [anon_sym_XMLport] = ACTIONS(2517),
    [anon_sym_XMLPort] = ACTIONS(2517),
    [anon_sym_XmlPort] = ACTIONS(2517),
    [anon_sym_enum] = ACTIONS(2517),
    [anon_sym_ENUM] = ACTIONS(2517),
    [anon_sym_Enum] = ACTIONS(2517),
    [anon_sym_eNUM] = ACTIONS(2517),
    [anon_sym_eNum] = ACTIONS(2517),
    [anon_sym_ENum] = ACTIONS(2517),
    [sym_quoted_identifier] = ACTIONS(2519),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2519),
    [sym_integer] = ACTIONS(2517),
    [sym_continue_as_identifier] = ACTIONS(2519),
    [sym_preproc_open] = ACTIONS(2519),
    [sym_preproc_close] = ACTIONS(2519),
  },
  [STATE(999)] = {
    [sym_identifier] = ACTIONS(2521),
    [anon_sym_SEMI] = ACTIONS(2523),
    [anon_sym_DOT] = ACTIONS(2521),
    [anon_sym_EQ] = ACTIONS(2523),
    [anon_sym_DASH] = ACTIONS(2521),
    [aux_sym_boolean_token1] = ACTIONS(2521),
    [aux_sym_boolean_token2] = ACTIONS(2521),
    [sym_decimal] = ACTIONS(2521),
    [anon_sym_LPAREN] = ACTIONS(2523),
    [anon_sym_DOT_DOT] = ACTIONS(2523),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2521),
    [anon_sym_STAR] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [aux_sym_record_type_token1] = ACTIONS(2521),
    [aux_sym_basic_type_token21] = ACTIONS(2521),
    [aux_sym_basic_type_token22] = ACTIONS(2521),
    [aux_sym_basic_type_token48] = ACTIONS(2521),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2521),
    [anon_sym_COLON_COLON] = ACTIONS(2523),
    [anon_sym_POUNDif] = ACTIONS(2523),
    [anon_sym_POUNDIF] = ACTIONS(2523),
    [anon_sym_POUNDIf] = ACTIONS(2523),
    [anon_sym_not] = ACTIONS(2521),
    [anon_sym_NOT] = ACTIONS(2521),
    [anon_sym_Not] = ACTIONS(2521),
    [anon_sym_POUNDelif] = ACTIONS(2523),
    [anon_sym_POUNDELIF] = ACTIONS(2523),
    [anon_sym_POUNDElif] = ACTIONS(2523),
    [anon_sym_POUNDelse] = ACTIONS(2523),
    [anon_sym_POUNDELSE] = ACTIONS(2523),
    [anon_sym_POUNDElse] = ACTIONS(2523),
    [anon_sym_POUNDendif] = ACTIONS(2523),
    [anon_sym_POUNDENDIF] = ACTIONS(2523),
    [anon_sym_POUNDEndif] = ACTIONS(2523),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2523),
    [aux_sym__expression_token1] = ACTIONS(2523),
    [aux_sym__expression_token2] = ACTIONS(2521),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2521),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2521),
    [anon_sym_SLASH] = ACTIONS(2521),
    [anon_sym_div] = ACTIONS(2521),
    [anon_sym_DIV] = ACTIONS(2521),
    [anon_sym_Div] = ACTIONS(2521),
    [anon_sym_mod] = ACTIONS(2521),
    [anon_sym_MOD] = ACTIONS(2521),
    [anon_sym_Mod] = ACTIONS(2521),
    [anon_sym_PLUS] = ACTIONS(2521),
    [anon_sym_GT_EQ] = ACTIONS(2523),
    [anon_sym_LT_EQ] = ACTIONS(2523),
    [anon_sym_GT] = ACTIONS(2521),
    [anon_sym_LT] = ACTIONS(2521),
    [anon_sym_LT_GT] = ACTIONS(2523),
    [anon_sym_and] = ACTIONS(2521),
    [anon_sym_AND] = ACTIONS(2521),
    [anon_sym_And] = ACTIONS(2521),
    [anon_sym_or] = ACTIONS(2521),
    [anon_sym_OR] = ACTIONS(2521),
    [anon_sym_Or] = ACTIONS(2521),
    [anon_sym_xor] = ACTIONS(2521),
    [anon_sym_XOR] = ACTIONS(2521),
    [anon_sym_Xor] = ACTIONS(2521),
    [anon_sym_QMARK] = ACTIONS(2523),
    [sym_datetime_literal] = ACTIONS(2523),
    [sym_date_literal] = ACTIONS(2521),
    [sym_time_literal] = ACTIONS(2521),
    [sym_biginteger_literal] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2521),
    [anon_sym_IF] = ACTIONS(2521),
    [anon_sym_If] = ACTIONS(2521),
    [anon_sym_else] = ACTIONS(2521),
    [anon_sym_ELSE] = ACTIONS(2521),
    [anon_sym_Else] = ACTIONS(2521),
    [anon_sym_case] = ACTIONS(2521),
    [anon_sym_CASE] = ACTIONS(2521),
    [anon_sym_Case] = ACTIONS(2521),
    [anon_sym_for] = ACTIONS(2521),
    [anon_sym_FOR] = ACTIONS(2521),
    [anon_sym_For] = ACTIONS(2521),
    [anon_sym_foreach] = ACTIONS(2521),
    [anon_sym_FOREACH] = ACTIONS(2521),
    [anon_sym_Foreach] = ACTIONS(2521),
    [anon_sym_while] = ACTIONS(2521),
    [anon_sym_WHILE] = ACTIONS(2521),
    [anon_sym_While] = ACTIONS(2521),
    [anon_sym_repeat] = ACTIONS(2521),
    [anon_sym_REPEAT] = ACTIONS(2521),
    [anon_sym_Repeat] = ACTIONS(2521),
    [anon_sym_exit] = ACTIONS(2521),
    [anon_sym_EXIT] = ACTIONS(2521),
    [anon_sym_Exit] = ACTIONS(2521),
    [anon_sym_continue] = ACTIONS(2521),
    [anon_sym_CONTINUE] = ACTIONS(2521),
    [anon_sym_Continue] = ACTIONS(2521),
    [anon_sym_break] = ACTIONS(2521),
    [anon_sym_BREAK] = ACTIONS(2521),
    [anon_sym_Break] = ACTIONS(2521),
    [anon_sym_with] = ACTIONS(2521),
    [anon_sym_WITH] = ACTIONS(2521),
    [anon_sym_With] = ACTIONS(2521),
    [sym_asserterror_keyword] = ACTIONS(2523),
    [anon_sym_in] = ACTIONS(2521),
    [anon_sym_IN] = ACTIONS(2521),
    [anon_sym_In] = ACTIONS(2521),
    [sym_page_keyword] = ACTIONS(2521),
    [anon_sym_codeunit] = ACTIONS(2521),
    [anon_sym_CODEUNIT] = ACTIONS(2521),
    [anon_sym_Codeunit] = ACTIONS(2521),
    [anon_sym_CodeUnit] = ACTIONS(2521),
    [anon_sym_COdeunit] = ACTIONS(2521),
    [anon_sym_codeUnit] = ACTIONS(2521),
    [sym_report_keyword] = ACTIONS(2521),
    [sym_query_keyword] = ACTIONS(2521),
    [anon_sym_xmlport] = ACTIONS(2521),
    [anon_sym_XMLPORT] = ACTIONS(2521),
    [anon_sym_Xmlport] = ACTIONS(2521),
    [anon_sym_XMLport] = ACTIONS(2521),
    [anon_sym_XMLPort] = ACTIONS(2521),
    [anon_sym_XmlPort] = ACTIONS(2521),
    [anon_sym_enum] = ACTIONS(2521),
    [anon_sym_ENUM] = ACTIONS(2521),
    [anon_sym_Enum] = ACTIONS(2521),
    [anon_sym_eNUM] = ACTIONS(2521),
    [anon_sym_eNum] = ACTIONS(2521),
    [anon_sym_ENum] = ACTIONS(2521),
    [sym_quoted_identifier] = ACTIONS(2523),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2523),
    [sym_integer] = ACTIONS(2521),
    [sym_continue_as_identifier] = ACTIONS(2523),
    [sym_preproc_open] = ACTIONS(2523),
    [sym_preproc_close] = ACTIONS(2523),
  },
  [STATE(1000)] = {
    [sym_identifier] = ACTIONS(2525),
    [anon_sym_SEMI] = ACTIONS(2527),
    [anon_sym_DOT] = ACTIONS(2525),
    [anon_sym_EQ] = ACTIONS(2527),
    [anon_sym_DASH] = ACTIONS(2525),
    [aux_sym_boolean_token1] = ACTIONS(2525),
    [aux_sym_boolean_token2] = ACTIONS(2525),
    [sym_decimal] = ACTIONS(2525),
    [anon_sym_LPAREN] = ACTIONS(2527),
    [anon_sym_DOT_DOT] = ACTIONS(2527),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2525),
    [anon_sym_STAR] = ACTIONS(2525),
    [anon_sym_LBRACK] = ACTIONS(2527),
    [aux_sym_record_type_token1] = ACTIONS(2525),
    [aux_sym_basic_type_token21] = ACTIONS(2525),
    [aux_sym_basic_type_token22] = ACTIONS(2525),
    [aux_sym_basic_type_token48] = ACTIONS(2525),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2525),
    [anon_sym_COLON_COLON] = ACTIONS(2527),
    [anon_sym_POUNDif] = ACTIONS(2527),
    [anon_sym_POUNDIF] = ACTIONS(2527),
    [anon_sym_POUNDIf] = ACTIONS(2527),
    [anon_sym_not] = ACTIONS(2525),
    [anon_sym_NOT] = ACTIONS(2525),
    [anon_sym_Not] = ACTIONS(2525),
    [anon_sym_POUNDelif] = ACTIONS(2527),
    [anon_sym_POUNDELIF] = ACTIONS(2527),
    [anon_sym_POUNDElif] = ACTIONS(2527),
    [anon_sym_POUNDelse] = ACTIONS(2527),
    [anon_sym_POUNDELSE] = ACTIONS(2527),
    [anon_sym_POUNDElse] = ACTIONS(2527),
    [anon_sym_POUNDendif] = ACTIONS(2527),
    [anon_sym_POUNDENDIF] = ACTIONS(2527),
    [anon_sym_POUNDEndif] = ACTIONS(2527),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2527),
    [aux_sym__expression_token1] = ACTIONS(2527),
    [aux_sym__expression_token2] = ACTIONS(2525),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2525),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2525),
    [anon_sym_SLASH] = ACTIONS(2525),
    [anon_sym_div] = ACTIONS(2525),
    [anon_sym_DIV] = ACTIONS(2525),
    [anon_sym_Div] = ACTIONS(2525),
    [anon_sym_mod] = ACTIONS(2525),
    [anon_sym_MOD] = ACTIONS(2525),
    [anon_sym_Mod] = ACTIONS(2525),
    [anon_sym_PLUS] = ACTIONS(2525),
    [anon_sym_GT_EQ] = ACTIONS(2527),
    [anon_sym_LT_EQ] = ACTIONS(2527),
    [anon_sym_GT] = ACTIONS(2525),
    [anon_sym_LT] = ACTIONS(2525),
    [anon_sym_LT_GT] = ACTIONS(2527),
    [anon_sym_and] = ACTIONS(2525),
    [anon_sym_AND] = ACTIONS(2525),
    [anon_sym_And] = ACTIONS(2525),
    [anon_sym_or] = ACTIONS(2525),
    [anon_sym_OR] = ACTIONS(2525),
    [anon_sym_Or] = ACTIONS(2525),
    [anon_sym_xor] = ACTIONS(2525),
    [anon_sym_XOR] = ACTIONS(2525),
    [anon_sym_Xor] = ACTIONS(2525),
    [anon_sym_QMARK] = ACTIONS(2527),
    [sym_datetime_literal] = ACTIONS(2527),
    [sym_date_literal] = ACTIONS(2525),
    [sym_time_literal] = ACTIONS(2525),
    [sym_biginteger_literal] = ACTIONS(2527),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_IF] = ACTIONS(2525),
    [anon_sym_If] = ACTIONS(2525),
    [anon_sym_else] = ACTIONS(2525),
    [anon_sym_ELSE] = ACTIONS(2525),
    [anon_sym_Else] = ACTIONS(2525),
    [anon_sym_case] = ACTIONS(2525),
    [anon_sym_CASE] = ACTIONS(2525),
    [anon_sym_Case] = ACTIONS(2525),
    [anon_sym_for] = ACTIONS(2525),
    [anon_sym_FOR] = ACTIONS(2525),
    [anon_sym_For] = ACTIONS(2525),
    [anon_sym_foreach] = ACTIONS(2525),
    [anon_sym_FOREACH] = ACTIONS(2525),
    [anon_sym_Foreach] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(2525),
    [anon_sym_WHILE] = ACTIONS(2525),
    [anon_sym_While] = ACTIONS(2525),
    [anon_sym_repeat] = ACTIONS(2525),
    [anon_sym_REPEAT] = ACTIONS(2525),
    [anon_sym_Repeat] = ACTIONS(2525),
    [anon_sym_exit] = ACTIONS(2525),
    [anon_sym_EXIT] = ACTIONS(2525),
    [anon_sym_Exit] = ACTIONS(2525),
    [anon_sym_continue] = ACTIONS(2525),
    [anon_sym_CONTINUE] = ACTIONS(2525),
    [anon_sym_Continue] = ACTIONS(2525),
    [anon_sym_break] = ACTIONS(2525),
    [anon_sym_BREAK] = ACTIONS(2525),
    [anon_sym_Break] = ACTIONS(2525),
    [anon_sym_with] = ACTIONS(2525),
    [anon_sym_WITH] = ACTIONS(2525),
    [anon_sym_With] = ACTIONS(2525),
    [sym_asserterror_keyword] = ACTIONS(2527),
    [anon_sym_in] = ACTIONS(2525),
    [anon_sym_IN] = ACTIONS(2525),
    [anon_sym_In] = ACTIONS(2525),
    [sym_page_keyword] = ACTIONS(2525),
    [anon_sym_codeunit] = ACTIONS(2525),
    [anon_sym_CODEUNIT] = ACTIONS(2525),
    [anon_sym_Codeunit] = ACTIONS(2525),
    [anon_sym_CodeUnit] = ACTIONS(2525),
    [anon_sym_COdeunit] = ACTIONS(2525),
    [anon_sym_codeUnit] = ACTIONS(2525),
    [sym_report_keyword] = ACTIONS(2525),
    [sym_query_keyword] = ACTIONS(2525),
    [anon_sym_xmlport] = ACTIONS(2525),
    [anon_sym_XMLPORT] = ACTIONS(2525),
    [anon_sym_Xmlport] = ACTIONS(2525),
    [anon_sym_XMLport] = ACTIONS(2525),
    [anon_sym_XMLPort] = ACTIONS(2525),
    [anon_sym_XmlPort] = ACTIONS(2525),
    [anon_sym_enum] = ACTIONS(2525),
    [anon_sym_ENUM] = ACTIONS(2525),
    [anon_sym_Enum] = ACTIONS(2525),
    [anon_sym_eNUM] = ACTIONS(2525),
    [anon_sym_eNum] = ACTIONS(2525),
    [anon_sym_ENum] = ACTIONS(2525),
    [sym_quoted_identifier] = ACTIONS(2527),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2527),
    [sym_integer] = ACTIONS(2525),
    [sym_continue_as_identifier] = ACTIONS(2527),
    [sym_preproc_open] = ACTIONS(2527),
    [sym_preproc_close] = ACTIONS(2527),
  },
  [STATE(1001)] = {
    [sym_identifier] = ACTIONS(2403),
    [anon_sym_SEMI] = ACTIONS(2405),
    [anon_sym_DOT] = ACTIONS(2403),
    [anon_sym_EQ] = ACTIONS(2405),
    [anon_sym_COMMA] = ACTIONS(2405),
    [anon_sym_DASH] = ACTIONS(2403),
    [aux_sym_boolean_token1] = ACTIONS(2403),
    [aux_sym_boolean_token2] = ACTIONS(2403),
    [sym_decimal] = ACTIONS(2403),
    [anon_sym_LPAREN] = ACTIONS(2405),
    [anon_sym_DOT_DOT] = ACTIONS(2405),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2403),
    [anon_sym_STAR] = ACTIONS(2403),
    [anon_sym_LBRACK] = ACTIONS(2405),
    [aux_sym_record_type_token1] = ACTIONS(2403),
    [aux_sym_basic_type_token21] = ACTIONS(2403),
    [aux_sym_basic_type_token22] = ACTIONS(2403),
    [aux_sym_basic_type_token48] = ACTIONS(2403),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2403),
    [anon_sym_POUNDif] = ACTIONS(2405),
    [anon_sym_POUNDIF] = ACTIONS(2405),
    [anon_sym_POUNDIf] = ACTIONS(2405),
    [anon_sym_not] = ACTIONS(2403),
    [anon_sym_NOT] = ACTIONS(2403),
    [anon_sym_Not] = ACTIONS(2403),
    [anon_sym_POUNDelif] = ACTIONS(2405),
    [anon_sym_POUNDELIF] = ACTIONS(2405),
    [anon_sym_POUNDElif] = ACTIONS(2405),
    [anon_sym_POUNDelse] = ACTIONS(2405),
    [anon_sym_POUNDELSE] = ACTIONS(2405),
    [anon_sym_POUNDElse] = ACTIONS(2405),
    [anon_sym_POUNDendif] = ACTIONS(2405),
    [anon_sym_POUNDENDIF] = ACTIONS(2405),
    [anon_sym_POUNDEndif] = ACTIONS(2405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2405),
    [aux_sym__expression_token1] = ACTIONS(2405),
    [aux_sym__expression_token2] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2403),
    [anon_sym_SLASH] = ACTIONS(2403),
    [anon_sym_div] = ACTIONS(2403),
    [anon_sym_DIV] = ACTIONS(2403),
    [anon_sym_Div] = ACTIONS(2403),
    [anon_sym_mod] = ACTIONS(2403),
    [anon_sym_MOD] = ACTIONS(2403),
    [anon_sym_Mod] = ACTIONS(2403),
    [anon_sym_PLUS] = ACTIONS(2403),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_LT_GT] = ACTIONS(2405),
    [anon_sym_and] = ACTIONS(2403),
    [anon_sym_AND] = ACTIONS(2403),
    [anon_sym_And] = ACTIONS(2403),
    [anon_sym_or] = ACTIONS(2403),
    [anon_sym_OR] = ACTIONS(2403),
    [anon_sym_Or] = ACTIONS(2403),
    [anon_sym_xor] = ACTIONS(2403),
    [anon_sym_XOR] = ACTIONS(2403),
    [anon_sym_Xor] = ACTIONS(2403),
    [anon_sym_QMARK] = ACTIONS(2405),
    [sym_datetime_literal] = ACTIONS(2405),
    [sym_date_literal] = ACTIONS(2403),
    [sym_time_literal] = ACTIONS(2403),
    [sym_biginteger_literal] = ACTIONS(2405),
    [anon_sym_if] = ACTIONS(2403),
    [anon_sym_IF] = ACTIONS(2403),
    [anon_sym_If] = ACTIONS(2403),
    [anon_sym_else] = ACTIONS(2403),
    [anon_sym_ELSE] = ACTIONS(2403),
    [anon_sym_Else] = ACTIONS(2403),
    [anon_sym_case] = ACTIONS(2403),
    [anon_sym_CASE] = ACTIONS(2403),
    [anon_sym_Case] = ACTIONS(2403),
    [anon_sym_for] = ACTIONS(2403),
    [anon_sym_FOR] = ACTIONS(2403),
    [anon_sym_For] = ACTIONS(2403),
    [anon_sym_foreach] = ACTIONS(2403),
    [anon_sym_FOREACH] = ACTIONS(2403),
    [anon_sym_Foreach] = ACTIONS(2403),
    [anon_sym_while] = ACTIONS(2403),
    [anon_sym_WHILE] = ACTIONS(2403),
    [anon_sym_While] = ACTIONS(2403),
    [anon_sym_repeat] = ACTIONS(2403),
    [anon_sym_REPEAT] = ACTIONS(2403),
    [anon_sym_Repeat] = ACTIONS(2403),
    [anon_sym_exit] = ACTIONS(2403),
    [anon_sym_EXIT] = ACTIONS(2403),
    [anon_sym_Exit] = ACTIONS(2403),
    [anon_sym_continue] = ACTIONS(2403),
    [anon_sym_CONTINUE] = ACTIONS(2403),
    [anon_sym_Continue] = ACTIONS(2403),
    [anon_sym_break] = ACTIONS(2403),
    [anon_sym_BREAK] = ACTIONS(2403),
    [anon_sym_Break] = ACTIONS(2403),
    [anon_sym_with] = ACTIONS(2403),
    [anon_sym_WITH] = ACTIONS(2403),
    [anon_sym_With] = ACTIONS(2403),
    [sym_asserterror_keyword] = ACTIONS(2405),
    [anon_sym_in] = ACTIONS(2403),
    [anon_sym_IN] = ACTIONS(2403),
    [anon_sym_In] = ACTIONS(2403),
    [sym_page_keyword] = ACTIONS(2403),
    [anon_sym_codeunit] = ACTIONS(2403),
    [anon_sym_CODEUNIT] = ACTIONS(2403),
    [anon_sym_Codeunit] = ACTIONS(2403),
    [anon_sym_CodeUnit] = ACTIONS(2403),
    [anon_sym_COdeunit] = ACTIONS(2403),
    [anon_sym_codeUnit] = ACTIONS(2403),
    [sym_report_keyword] = ACTIONS(2403),
    [sym_query_keyword] = ACTIONS(2403),
    [anon_sym_xmlport] = ACTIONS(2403),
    [anon_sym_XMLPORT] = ACTIONS(2403),
    [anon_sym_Xmlport] = ACTIONS(2403),
    [anon_sym_XMLport] = ACTIONS(2403),
    [anon_sym_XMLPort] = ACTIONS(2403),
    [anon_sym_XmlPort] = ACTIONS(2403),
    [anon_sym_enum] = ACTIONS(2403),
    [anon_sym_ENUM] = ACTIONS(2403),
    [anon_sym_Enum] = ACTIONS(2403),
    [anon_sym_eNUM] = ACTIONS(2403),
    [anon_sym_eNum] = ACTIONS(2403),
    [anon_sym_ENum] = ACTIONS(2403),
    [sym_quoted_identifier] = ACTIONS(2405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2405),
    [sym_integer] = ACTIONS(2403),
    [sym_continue_as_identifier] = ACTIONS(2405),
    [sym_preproc_open] = ACTIONS(2405),
    [sym_preproc_close] = ACTIONS(2405),
  },
  [STATE(1002)] = {
    [sym_identifier] = ACTIONS(2529),
    [anon_sym_SEMI] = ACTIONS(2531),
    [anon_sym_DOT] = ACTIONS(2529),
    [anon_sym_EQ] = ACTIONS(2531),
    [anon_sym_COMMA] = ACTIONS(2531),
    [anon_sym_DASH] = ACTIONS(2529),
    [aux_sym_boolean_token1] = ACTIONS(2529),
    [aux_sym_boolean_token2] = ACTIONS(2529),
    [sym_decimal] = ACTIONS(2529),
    [anon_sym_LPAREN] = ACTIONS(2531),
    [anon_sym_DOT_DOT] = ACTIONS(2531),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2529),
    [anon_sym_STAR] = ACTIONS(2529),
    [anon_sym_LBRACK] = ACTIONS(2531),
    [aux_sym_record_type_token1] = ACTIONS(2529),
    [aux_sym_basic_type_token21] = ACTIONS(2529),
    [aux_sym_basic_type_token22] = ACTIONS(2529),
    [aux_sym_basic_type_token48] = ACTIONS(2529),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2529),
    [anon_sym_POUNDif] = ACTIONS(2531),
    [anon_sym_POUNDIF] = ACTIONS(2531),
    [anon_sym_POUNDIf] = ACTIONS(2531),
    [anon_sym_not] = ACTIONS(2529),
    [anon_sym_NOT] = ACTIONS(2529),
    [anon_sym_Not] = ACTIONS(2529),
    [anon_sym_POUNDelif] = ACTIONS(2531),
    [anon_sym_POUNDELIF] = ACTIONS(2531),
    [anon_sym_POUNDElif] = ACTIONS(2531),
    [anon_sym_POUNDelse] = ACTIONS(2531),
    [anon_sym_POUNDELSE] = ACTIONS(2531),
    [anon_sym_POUNDElse] = ACTIONS(2531),
    [anon_sym_POUNDendif] = ACTIONS(2531),
    [anon_sym_POUNDENDIF] = ACTIONS(2531),
    [anon_sym_POUNDEndif] = ACTIONS(2531),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2531),
    [aux_sym__expression_token1] = ACTIONS(2531),
    [aux_sym__expression_token2] = ACTIONS(2529),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2529),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2529),
    [anon_sym_SLASH] = ACTIONS(2529),
    [anon_sym_div] = ACTIONS(2529),
    [anon_sym_DIV] = ACTIONS(2529),
    [anon_sym_Div] = ACTIONS(2529),
    [anon_sym_mod] = ACTIONS(2529),
    [anon_sym_MOD] = ACTIONS(2529),
    [anon_sym_Mod] = ACTIONS(2529),
    [anon_sym_PLUS] = ACTIONS(2529),
    [anon_sym_GT_EQ] = ACTIONS(2531),
    [anon_sym_LT_EQ] = ACTIONS(2531),
    [anon_sym_GT] = ACTIONS(2529),
    [anon_sym_LT] = ACTIONS(2529),
    [anon_sym_LT_GT] = ACTIONS(2531),
    [anon_sym_and] = ACTIONS(2529),
    [anon_sym_AND] = ACTIONS(2529),
    [anon_sym_And] = ACTIONS(2529),
    [anon_sym_or] = ACTIONS(2529),
    [anon_sym_OR] = ACTIONS(2529),
    [anon_sym_Or] = ACTIONS(2529),
    [anon_sym_xor] = ACTIONS(2529),
    [anon_sym_XOR] = ACTIONS(2529),
    [anon_sym_Xor] = ACTIONS(2529),
    [anon_sym_QMARK] = ACTIONS(2531),
    [sym_datetime_literal] = ACTIONS(2531),
    [sym_date_literal] = ACTIONS(2529),
    [sym_time_literal] = ACTIONS(2529),
    [sym_biginteger_literal] = ACTIONS(2531),
    [anon_sym_if] = ACTIONS(2529),
    [anon_sym_IF] = ACTIONS(2529),
    [anon_sym_If] = ACTIONS(2529),
    [anon_sym_else] = ACTIONS(2529),
    [anon_sym_ELSE] = ACTIONS(2529),
    [anon_sym_Else] = ACTIONS(2529),
    [anon_sym_case] = ACTIONS(2529),
    [anon_sym_CASE] = ACTIONS(2529),
    [anon_sym_Case] = ACTIONS(2529),
    [anon_sym_for] = ACTIONS(2529),
    [anon_sym_FOR] = ACTIONS(2529),
    [anon_sym_For] = ACTIONS(2529),
    [anon_sym_foreach] = ACTIONS(2529),
    [anon_sym_FOREACH] = ACTIONS(2529),
    [anon_sym_Foreach] = ACTIONS(2529),
    [anon_sym_while] = ACTIONS(2529),
    [anon_sym_WHILE] = ACTIONS(2529),
    [anon_sym_While] = ACTIONS(2529),
    [anon_sym_repeat] = ACTIONS(2529),
    [anon_sym_REPEAT] = ACTIONS(2529),
    [anon_sym_Repeat] = ACTIONS(2529),
    [anon_sym_exit] = ACTIONS(2529),
    [anon_sym_EXIT] = ACTIONS(2529),
    [anon_sym_Exit] = ACTIONS(2529),
    [anon_sym_continue] = ACTIONS(2529),
    [anon_sym_CONTINUE] = ACTIONS(2529),
    [anon_sym_Continue] = ACTIONS(2529),
    [anon_sym_break] = ACTIONS(2529),
    [anon_sym_BREAK] = ACTIONS(2529),
    [anon_sym_Break] = ACTIONS(2529),
    [anon_sym_with] = ACTIONS(2529),
    [anon_sym_WITH] = ACTIONS(2529),
    [anon_sym_With] = ACTIONS(2529),
    [sym_asserterror_keyword] = ACTIONS(2531),
    [anon_sym_in] = ACTIONS(2529),
    [anon_sym_IN] = ACTIONS(2529),
    [anon_sym_In] = ACTIONS(2529),
    [sym_page_keyword] = ACTIONS(2529),
    [anon_sym_codeunit] = ACTIONS(2529),
    [anon_sym_CODEUNIT] = ACTIONS(2529),
    [anon_sym_Codeunit] = ACTIONS(2529),
    [anon_sym_CodeUnit] = ACTIONS(2529),
    [anon_sym_COdeunit] = ACTIONS(2529),
    [anon_sym_codeUnit] = ACTIONS(2529),
    [sym_report_keyword] = ACTIONS(2529),
    [sym_query_keyword] = ACTIONS(2529),
    [anon_sym_xmlport] = ACTIONS(2529),
    [anon_sym_XMLPORT] = ACTIONS(2529),
    [anon_sym_Xmlport] = ACTIONS(2529),
    [anon_sym_XMLport] = ACTIONS(2529),
    [anon_sym_XMLPort] = ACTIONS(2529),
    [anon_sym_XmlPort] = ACTIONS(2529),
    [anon_sym_enum] = ACTIONS(2529),
    [anon_sym_ENUM] = ACTIONS(2529),
    [anon_sym_Enum] = ACTIONS(2529),
    [anon_sym_eNUM] = ACTIONS(2529),
    [anon_sym_eNum] = ACTIONS(2529),
    [anon_sym_ENum] = ACTIONS(2529),
    [sym_quoted_identifier] = ACTIONS(2531),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2531),
    [sym_integer] = ACTIONS(2529),
    [sym_continue_as_identifier] = ACTIONS(2531),
    [sym_preproc_open] = ACTIONS(2531),
    [sym_preproc_close] = ACTIONS(2531),
  },
  [STATE(1003)] = {
    [sym_identifier] = ACTIONS(2533),
    [anon_sym_SEMI] = ACTIONS(2535),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym_EQ] = ACTIONS(2535),
    [anon_sym_DASH] = ACTIONS(2533),
    [aux_sym_boolean_token1] = ACTIONS(2533),
    [aux_sym_boolean_token2] = ACTIONS(2533),
    [sym_decimal] = ACTIONS(2533),
    [anon_sym_LPAREN] = ACTIONS(2535),
    [anon_sym_DOT_DOT] = ACTIONS(2535),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2533),
    [anon_sym_STAR] = ACTIONS(2533),
    [anon_sym_LBRACK] = ACTIONS(2535),
    [aux_sym_record_type_token1] = ACTIONS(2533),
    [aux_sym_basic_type_token21] = ACTIONS(2533),
    [aux_sym_basic_type_token22] = ACTIONS(2533),
    [aux_sym_basic_type_token48] = ACTIONS(2533),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2533),
    [anon_sym_POUNDif] = ACTIONS(2535),
    [anon_sym_POUNDIF] = ACTIONS(2535),
    [anon_sym_POUNDIf] = ACTIONS(2535),
    [anon_sym_not] = ACTIONS(2533),
    [anon_sym_NOT] = ACTIONS(2533),
    [anon_sym_Not] = ACTIONS(2533),
    [anon_sym_POUNDelif] = ACTIONS(2535),
    [anon_sym_POUNDELIF] = ACTIONS(2535),
    [anon_sym_POUNDElif] = ACTIONS(2535),
    [anon_sym_POUNDelse] = ACTIONS(2535),
    [anon_sym_POUNDELSE] = ACTIONS(2535),
    [anon_sym_POUNDElse] = ACTIONS(2535),
    [anon_sym_POUNDendif] = ACTIONS(2535),
    [anon_sym_POUNDENDIF] = ACTIONS(2535),
    [anon_sym_POUNDEndif] = ACTIONS(2535),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2535),
    [aux_sym__expression_token1] = ACTIONS(2535),
    [aux_sym__expression_token2] = ACTIONS(2533),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2533),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2533),
    [anon_sym_SLASH] = ACTIONS(2533),
    [anon_sym_div] = ACTIONS(2533),
    [anon_sym_DIV] = ACTIONS(2533),
    [anon_sym_Div] = ACTIONS(2533),
    [anon_sym_mod] = ACTIONS(2533),
    [anon_sym_MOD] = ACTIONS(2533),
    [anon_sym_Mod] = ACTIONS(2533),
    [anon_sym_PLUS] = ACTIONS(2533),
    [anon_sym_GT_EQ] = ACTIONS(2535),
    [anon_sym_LT_EQ] = ACTIONS(2535),
    [anon_sym_GT] = ACTIONS(2533),
    [anon_sym_LT] = ACTIONS(2533),
    [anon_sym_LT_GT] = ACTIONS(2535),
    [anon_sym_and] = ACTIONS(2533),
    [anon_sym_AND] = ACTIONS(2533),
    [anon_sym_And] = ACTIONS(2533),
    [anon_sym_or] = ACTIONS(2533),
    [anon_sym_OR] = ACTIONS(2533),
    [anon_sym_Or] = ACTIONS(2533),
    [anon_sym_xor] = ACTIONS(2533),
    [anon_sym_XOR] = ACTIONS(2533),
    [anon_sym_Xor] = ACTIONS(2533),
    [anon_sym_QMARK] = ACTIONS(2535),
    [sym_datetime_literal] = ACTIONS(2535),
    [sym_date_literal] = ACTIONS(2533),
    [sym_time_literal] = ACTIONS(2533),
    [sym_biginteger_literal] = ACTIONS(2535),
    [anon_sym_if] = ACTIONS(2533),
    [anon_sym_IF] = ACTIONS(2533),
    [anon_sym_If] = ACTIONS(2533),
    [anon_sym_else] = ACTIONS(2533),
    [anon_sym_ELSE] = ACTIONS(2533),
    [anon_sym_Else] = ACTIONS(2533),
    [anon_sym_case] = ACTIONS(2533),
    [anon_sym_CASE] = ACTIONS(2533),
    [anon_sym_Case] = ACTIONS(2533),
    [anon_sym_for] = ACTIONS(2533),
    [anon_sym_FOR] = ACTIONS(2533),
    [anon_sym_For] = ACTIONS(2533),
    [anon_sym_foreach] = ACTIONS(2533),
    [anon_sym_FOREACH] = ACTIONS(2533),
    [anon_sym_Foreach] = ACTIONS(2533),
    [anon_sym_while] = ACTIONS(2533),
    [anon_sym_WHILE] = ACTIONS(2533),
    [anon_sym_While] = ACTIONS(2533),
    [anon_sym_repeat] = ACTIONS(2533),
    [anon_sym_REPEAT] = ACTIONS(2533),
    [anon_sym_Repeat] = ACTIONS(2533),
    [anon_sym_exit] = ACTIONS(2533),
    [anon_sym_EXIT] = ACTIONS(2533),
    [anon_sym_Exit] = ACTIONS(2533),
    [anon_sym_continue] = ACTIONS(2533),
    [anon_sym_CONTINUE] = ACTIONS(2533),
    [anon_sym_Continue] = ACTIONS(2533),
    [anon_sym_break] = ACTIONS(2533),
    [anon_sym_BREAK] = ACTIONS(2533),
    [anon_sym_Break] = ACTIONS(2533),
    [anon_sym_with] = ACTIONS(2533),
    [anon_sym_WITH] = ACTIONS(2533),
    [anon_sym_With] = ACTIONS(2533),
    [sym_asserterror_keyword] = ACTIONS(2535),
    [anon_sym_in] = ACTIONS(2533),
    [anon_sym_IN] = ACTIONS(2533),
    [anon_sym_In] = ACTIONS(2533),
    [sym_page_keyword] = ACTIONS(2533),
    [anon_sym_codeunit] = ACTIONS(2533),
    [anon_sym_CODEUNIT] = ACTIONS(2533),
    [anon_sym_Codeunit] = ACTIONS(2533),
    [anon_sym_CodeUnit] = ACTIONS(2533),
    [anon_sym_COdeunit] = ACTIONS(2533),
    [anon_sym_codeUnit] = ACTIONS(2533),
    [sym_report_keyword] = ACTIONS(2533),
    [sym_query_keyword] = ACTIONS(2533),
    [anon_sym_xmlport] = ACTIONS(2533),
    [anon_sym_XMLPORT] = ACTIONS(2533),
    [anon_sym_Xmlport] = ACTIONS(2533),
    [anon_sym_XMLport] = ACTIONS(2533),
    [anon_sym_XMLPort] = ACTIONS(2533),
    [anon_sym_XmlPort] = ACTIONS(2533),
    [anon_sym_enum] = ACTIONS(2533),
    [anon_sym_ENUM] = ACTIONS(2533),
    [anon_sym_Enum] = ACTIONS(2533),
    [anon_sym_eNUM] = ACTIONS(2533),
    [anon_sym_eNum] = ACTIONS(2533),
    [anon_sym_ENum] = ACTIONS(2533),
    [sym_temporary_keyword] = ACTIONS(2537),
    [sym_quoted_identifier] = ACTIONS(2535),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2535),
    [sym_integer] = ACTIONS(2533),
    [sym_continue_as_identifier] = ACTIONS(2535),
    [sym_preproc_open] = ACTIONS(2535),
    [sym_preproc_close] = ACTIONS(2535),
  },
  [STATE(1004)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_SEMI] = ACTIONS(2428),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_COMMA] = ACTIONS(2428),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2426),
    [anon_sym_POUNDif] = ACTIONS(2428),
    [anon_sym_POUNDIF] = ACTIONS(2428),
    [anon_sym_POUNDIf] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [anon_sym_POUNDelif] = ACTIONS(2428),
    [anon_sym_POUNDELIF] = ACTIONS(2428),
    [anon_sym_POUNDElif] = ACTIONS(2428),
    [anon_sym_POUNDelse] = ACTIONS(2428),
    [anon_sym_POUNDELSE] = ACTIONS(2428),
    [anon_sym_POUNDElse] = ACTIONS(2428),
    [anon_sym_POUNDendif] = ACTIONS(2428),
    [anon_sym_POUNDENDIF] = ACTIONS(2428),
    [anon_sym_POUNDEndif] = ACTIONS(2428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_IF] = ACTIONS(2426),
    [anon_sym_If] = ACTIONS(2426),
    [anon_sym_else] = ACTIONS(2426),
    [anon_sym_ELSE] = ACTIONS(2426),
    [anon_sym_Else] = ACTIONS(2426),
    [anon_sym_case] = ACTIONS(2426),
    [anon_sym_CASE] = ACTIONS(2426),
    [anon_sym_Case] = ACTIONS(2426),
    [anon_sym_for] = ACTIONS(2426),
    [anon_sym_FOR] = ACTIONS(2426),
    [anon_sym_For] = ACTIONS(2426),
    [anon_sym_foreach] = ACTIONS(2426),
    [anon_sym_FOREACH] = ACTIONS(2426),
    [anon_sym_Foreach] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(2426),
    [anon_sym_WHILE] = ACTIONS(2426),
    [anon_sym_While] = ACTIONS(2426),
    [anon_sym_repeat] = ACTIONS(2426),
    [anon_sym_REPEAT] = ACTIONS(2426),
    [anon_sym_Repeat] = ACTIONS(2426),
    [anon_sym_exit] = ACTIONS(2426),
    [anon_sym_EXIT] = ACTIONS(2426),
    [anon_sym_Exit] = ACTIONS(2426),
    [anon_sym_continue] = ACTIONS(2426),
    [anon_sym_CONTINUE] = ACTIONS(2426),
    [anon_sym_Continue] = ACTIONS(2426),
    [anon_sym_break] = ACTIONS(2426),
    [anon_sym_BREAK] = ACTIONS(2426),
    [anon_sym_Break] = ACTIONS(2426),
    [anon_sym_with] = ACTIONS(2426),
    [anon_sym_WITH] = ACTIONS(2426),
    [anon_sym_With] = ACTIONS(2426),
    [sym_asserterror_keyword] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_open] = ACTIONS(2428),
    [sym_preproc_close] = ACTIONS(2428),
  },
  [STATE(1005)] = {
    [sym_identifier] = ACTIONS(2539),
    [anon_sym_SEMI] = ACTIONS(2541),
    [anon_sym_DOT] = ACTIONS(2539),
    [anon_sym_EQ] = ACTIONS(2541),
    [anon_sym_COMMA] = ACTIONS(2541),
    [anon_sym_DASH] = ACTIONS(2539),
    [aux_sym_boolean_token1] = ACTIONS(2539),
    [aux_sym_boolean_token2] = ACTIONS(2539),
    [sym_decimal] = ACTIONS(2539),
    [anon_sym_LPAREN] = ACTIONS(2541),
    [anon_sym_DOT_DOT] = ACTIONS(2541),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2539),
    [anon_sym_STAR] = ACTIONS(2539),
    [anon_sym_LBRACK] = ACTIONS(2541),
    [aux_sym_record_type_token1] = ACTIONS(2539),
    [aux_sym_basic_type_token21] = ACTIONS(2539),
    [aux_sym_basic_type_token22] = ACTIONS(2539),
    [aux_sym_basic_type_token48] = ACTIONS(2539),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2539),
    [anon_sym_POUNDif] = ACTIONS(2541),
    [anon_sym_POUNDIF] = ACTIONS(2541),
    [anon_sym_POUNDIf] = ACTIONS(2541),
    [anon_sym_not] = ACTIONS(2539),
    [anon_sym_NOT] = ACTIONS(2539),
    [anon_sym_Not] = ACTIONS(2539),
    [anon_sym_POUNDelif] = ACTIONS(2541),
    [anon_sym_POUNDELIF] = ACTIONS(2541),
    [anon_sym_POUNDElif] = ACTIONS(2541),
    [anon_sym_POUNDelse] = ACTIONS(2541),
    [anon_sym_POUNDELSE] = ACTIONS(2541),
    [anon_sym_POUNDElse] = ACTIONS(2541),
    [anon_sym_POUNDendif] = ACTIONS(2541),
    [anon_sym_POUNDENDIF] = ACTIONS(2541),
    [anon_sym_POUNDEndif] = ACTIONS(2541),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2541),
    [aux_sym__expression_token1] = ACTIONS(2541),
    [aux_sym__expression_token2] = ACTIONS(2539),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2539),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2539),
    [anon_sym_SLASH] = ACTIONS(2539),
    [anon_sym_div] = ACTIONS(2539),
    [anon_sym_DIV] = ACTIONS(2539),
    [anon_sym_Div] = ACTIONS(2539),
    [anon_sym_mod] = ACTIONS(2539),
    [anon_sym_MOD] = ACTIONS(2539),
    [anon_sym_Mod] = ACTIONS(2539),
    [anon_sym_PLUS] = ACTIONS(2539),
    [anon_sym_GT_EQ] = ACTIONS(2541),
    [anon_sym_LT_EQ] = ACTIONS(2541),
    [anon_sym_GT] = ACTIONS(2539),
    [anon_sym_LT] = ACTIONS(2539),
    [anon_sym_LT_GT] = ACTIONS(2541),
    [anon_sym_and] = ACTIONS(2539),
    [anon_sym_AND] = ACTIONS(2539),
    [anon_sym_And] = ACTIONS(2539),
    [anon_sym_or] = ACTIONS(2539),
    [anon_sym_OR] = ACTIONS(2539),
    [anon_sym_Or] = ACTIONS(2539),
    [anon_sym_xor] = ACTIONS(2539),
    [anon_sym_XOR] = ACTIONS(2539),
    [anon_sym_Xor] = ACTIONS(2539),
    [anon_sym_QMARK] = ACTIONS(2541),
    [sym_datetime_literal] = ACTIONS(2541),
    [sym_date_literal] = ACTIONS(2539),
    [sym_time_literal] = ACTIONS(2539),
    [sym_biginteger_literal] = ACTIONS(2541),
    [anon_sym_if] = ACTIONS(2539),
    [anon_sym_IF] = ACTIONS(2539),
    [anon_sym_If] = ACTIONS(2539),
    [anon_sym_else] = ACTIONS(2539),
    [anon_sym_ELSE] = ACTIONS(2539),
    [anon_sym_Else] = ACTIONS(2539),
    [anon_sym_case] = ACTIONS(2539),
    [anon_sym_CASE] = ACTIONS(2539),
    [anon_sym_Case] = ACTIONS(2539),
    [anon_sym_for] = ACTIONS(2539),
    [anon_sym_FOR] = ACTIONS(2539),
    [anon_sym_For] = ACTIONS(2539),
    [anon_sym_foreach] = ACTIONS(2539),
    [anon_sym_FOREACH] = ACTIONS(2539),
    [anon_sym_Foreach] = ACTIONS(2539),
    [anon_sym_while] = ACTIONS(2539),
    [anon_sym_WHILE] = ACTIONS(2539),
    [anon_sym_While] = ACTIONS(2539),
    [anon_sym_repeat] = ACTIONS(2539),
    [anon_sym_REPEAT] = ACTIONS(2539),
    [anon_sym_Repeat] = ACTIONS(2539),
    [anon_sym_exit] = ACTIONS(2539),
    [anon_sym_EXIT] = ACTIONS(2539),
    [anon_sym_Exit] = ACTIONS(2539),
    [anon_sym_continue] = ACTIONS(2539),
    [anon_sym_CONTINUE] = ACTIONS(2539),
    [anon_sym_Continue] = ACTIONS(2539),
    [anon_sym_break] = ACTIONS(2539),
    [anon_sym_BREAK] = ACTIONS(2539),
    [anon_sym_Break] = ACTIONS(2539),
    [anon_sym_with] = ACTIONS(2539),
    [anon_sym_WITH] = ACTIONS(2539),
    [anon_sym_With] = ACTIONS(2539),
    [sym_asserterror_keyword] = ACTIONS(2541),
    [anon_sym_in] = ACTIONS(2539),
    [anon_sym_IN] = ACTIONS(2539),
    [anon_sym_In] = ACTIONS(2539),
    [sym_page_keyword] = ACTIONS(2539),
    [anon_sym_codeunit] = ACTIONS(2539),
    [anon_sym_CODEUNIT] = ACTIONS(2539),
    [anon_sym_Codeunit] = ACTIONS(2539),
    [anon_sym_CodeUnit] = ACTIONS(2539),
    [anon_sym_COdeunit] = ACTIONS(2539),
    [anon_sym_codeUnit] = ACTIONS(2539),
    [sym_report_keyword] = ACTIONS(2539),
    [sym_query_keyword] = ACTIONS(2539),
    [anon_sym_xmlport] = ACTIONS(2539),
    [anon_sym_XMLPORT] = ACTIONS(2539),
    [anon_sym_Xmlport] = ACTIONS(2539),
    [anon_sym_XMLport] = ACTIONS(2539),
    [anon_sym_XMLPort] = ACTIONS(2539),
    [anon_sym_XmlPort] = ACTIONS(2539),
    [anon_sym_enum] = ACTIONS(2539),
    [anon_sym_ENUM] = ACTIONS(2539),
    [anon_sym_Enum] = ACTIONS(2539),
    [anon_sym_eNUM] = ACTIONS(2539),
    [anon_sym_eNum] = ACTIONS(2539),
    [anon_sym_ENum] = ACTIONS(2539),
    [sym_quoted_identifier] = ACTIONS(2541),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2541),
    [sym_integer] = ACTIONS(2539),
    [sym_continue_as_identifier] = ACTIONS(2541),
    [sym_preproc_open] = ACTIONS(2541),
    [sym_preproc_close] = ACTIONS(2541),
  },
  [STATE(1006)] = {
    [sym_identifier] = ACTIONS(2396),
    [anon_sym_SEMI] = ACTIONS(2398),
    [anon_sym_DOT] = ACTIONS(2396),
    [anon_sym_EQ] = ACTIONS(2398),
    [anon_sym_DASH] = ACTIONS(2396),
    [aux_sym_boolean_token1] = ACTIONS(2396),
    [aux_sym_boolean_token2] = ACTIONS(2396),
    [sym_decimal] = ACTIONS(2396),
    [anon_sym_LPAREN] = ACTIONS(2398),
    [anon_sym_DOT_DOT] = ACTIONS(2398),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2396),
    [anon_sym_STAR] = ACTIONS(2396),
    [anon_sym_LBRACK] = ACTIONS(2398),
    [aux_sym_record_type_token1] = ACTIONS(2396),
    [aux_sym_basic_type_token21] = ACTIONS(2396),
    [aux_sym_basic_type_token22] = ACTIONS(2396),
    [aux_sym_basic_type_token48] = ACTIONS(2396),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2396),
    [anon_sym_POUNDif] = ACTIONS(2398),
    [anon_sym_POUNDIF] = ACTIONS(2398),
    [anon_sym_POUNDIf] = ACTIONS(2398),
    [anon_sym_not] = ACTIONS(2396),
    [anon_sym_NOT] = ACTIONS(2396),
    [anon_sym_Not] = ACTIONS(2396),
    [anon_sym_POUNDelif] = ACTIONS(2398),
    [anon_sym_POUNDELIF] = ACTIONS(2398),
    [anon_sym_POUNDElif] = ACTIONS(2398),
    [anon_sym_POUNDelse] = ACTIONS(2398),
    [anon_sym_POUNDELSE] = ACTIONS(2398),
    [anon_sym_POUNDElse] = ACTIONS(2398),
    [anon_sym_POUNDendif] = ACTIONS(2398),
    [anon_sym_POUNDENDIF] = ACTIONS(2398),
    [anon_sym_POUNDEndif] = ACTIONS(2398),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2398),
    [aux_sym__expression_token1] = ACTIONS(2398),
    [aux_sym__expression_token2] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2396),
    [anon_sym_SLASH] = ACTIONS(2396),
    [anon_sym_div] = ACTIONS(2396),
    [anon_sym_DIV] = ACTIONS(2396),
    [anon_sym_Div] = ACTIONS(2396),
    [anon_sym_mod] = ACTIONS(2396),
    [anon_sym_MOD] = ACTIONS(2396),
    [anon_sym_Mod] = ACTIONS(2396),
    [anon_sym_PLUS] = ACTIONS(2396),
    [anon_sym_GT_EQ] = ACTIONS(2398),
    [anon_sym_LT_EQ] = ACTIONS(2398),
    [anon_sym_GT] = ACTIONS(2396),
    [anon_sym_LT] = ACTIONS(2396),
    [anon_sym_LT_GT] = ACTIONS(2398),
    [anon_sym_and] = ACTIONS(2396),
    [anon_sym_AND] = ACTIONS(2396),
    [anon_sym_And] = ACTIONS(2396),
    [anon_sym_or] = ACTIONS(2396),
    [anon_sym_OR] = ACTIONS(2396),
    [anon_sym_Or] = ACTIONS(2396),
    [anon_sym_xor] = ACTIONS(2396),
    [anon_sym_XOR] = ACTIONS(2396),
    [anon_sym_Xor] = ACTIONS(2396),
    [anon_sym_QMARK] = ACTIONS(2398),
    [sym_datetime_literal] = ACTIONS(2398),
    [sym_date_literal] = ACTIONS(2396),
    [sym_time_literal] = ACTIONS(2396),
    [sym_biginteger_literal] = ACTIONS(2398),
    [anon_sym_if] = ACTIONS(2396),
    [anon_sym_IF] = ACTIONS(2396),
    [anon_sym_If] = ACTIONS(2396),
    [anon_sym_else] = ACTIONS(2396),
    [anon_sym_ELSE] = ACTIONS(2396),
    [anon_sym_Else] = ACTIONS(2396),
    [anon_sym_case] = ACTIONS(2396),
    [anon_sym_CASE] = ACTIONS(2396),
    [anon_sym_Case] = ACTIONS(2396),
    [anon_sym_for] = ACTIONS(2396),
    [anon_sym_FOR] = ACTIONS(2396),
    [anon_sym_For] = ACTIONS(2396),
    [anon_sym_foreach] = ACTIONS(2396),
    [anon_sym_FOREACH] = ACTIONS(2396),
    [anon_sym_Foreach] = ACTIONS(2396),
    [anon_sym_while] = ACTIONS(2396),
    [anon_sym_WHILE] = ACTIONS(2396),
    [anon_sym_While] = ACTIONS(2396),
    [anon_sym_repeat] = ACTIONS(2396),
    [anon_sym_REPEAT] = ACTIONS(2396),
    [anon_sym_Repeat] = ACTIONS(2396),
    [anon_sym_exit] = ACTIONS(2396),
    [anon_sym_EXIT] = ACTIONS(2396),
    [anon_sym_Exit] = ACTIONS(2396),
    [anon_sym_continue] = ACTIONS(2396),
    [anon_sym_CONTINUE] = ACTIONS(2396),
    [anon_sym_Continue] = ACTIONS(2396),
    [anon_sym_break] = ACTIONS(2396),
    [anon_sym_BREAK] = ACTIONS(2396),
    [anon_sym_Break] = ACTIONS(2396),
    [anon_sym_with] = ACTIONS(2396),
    [anon_sym_WITH] = ACTIONS(2396),
    [anon_sym_With] = ACTIONS(2396),
    [sym_asserterror_keyword] = ACTIONS(2398),
    [anon_sym_in] = ACTIONS(2396),
    [anon_sym_IN] = ACTIONS(2396),
    [anon_sym_In] = ACTIONS(2396),
    [sym_page_keyword] = ACTIONS(2396),
    [anon_sym_codeunit] = ACTIONS(2396),
    [anon_sym_CODEUNIT] = ACTIONS(2396),
    [anon_sym_Codeunit] = ACTIONS(2396),
    [anon_sym_CodeUnit] = ACTIONS(2396),
    [anon_sym_COdeunit] = ACTIONS(2396),
    [anon_sym_codeUnit] = ACTIONS(2396),
    [sym_report_keyword] = ACTIONS(2396),
    [sym_query_keyword] = ACTIONS(2396),
    [anon_sym_xmlport] = ACTIONS(2396),
    [anon_sym_XMLPORT] = ACTIONS(2396),
    [anon_sym_Xmlport] = ACTIONS(2396),
    [anon_sym_XMLport] = ACTIONS(2396),
    [anon_sym_XMLPort] = ACTIONS(2396),
    [anon_sym_XmlPort] = ACTIONS(2396),
    [anon_sym_enum] = ACTIONS(2396),
    [anon_sym_ENUM] = ACTIONS(2396),
    [anon_sym_Enum] = ACTIONS(2396),
    [anon_sym_eNUM] = ACTIONS(2396),
    [anon_sym_eNum] = ACTIONS(2396),
    [anon_sym_ENum] = ACTIONS(2396),
    [sym_temporary_keyword] = ACTIONS(2396),
    [sym_quoted_identifier] = ACTIONS(2398),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2398),
    [sym_integer] = ACTIONS(2396),
    [sym_continue_as_identifier] = ACTIONS(2398),
    [sym_preproc_open] = ACTIONS(2398),
    [sym_preproc_close] = ACTIONS(2398),
  },
  [STATE(1007)] = {
    [sym_identifier] = ACTIONS(2543),
    [anon_sym_SEMI] = ACTIONS(2545),
    [anon_sym_DOT] = ACTIONS(2543),
    [anon_sym_EQ] = ACTIONS(2545),
    [anon_sym_DASH] = ACTIONS(2543),
    [aux_sym_boolean_token1] = ACTIONS(2543),
    [aux_sym_boolean_token2] = ACTIONS(2543),
    [sym_decimal] = ACTIONS(2543),
    [anon_sym_LPAREN] = ACTIONS(2545),
    [anon_sym_DOT_DOT] = ACTIONS(2545),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2543),
    [anon_sym_STAR] = ACTIONS(2543),
    [anon_sym_LBRACK] = ACTIONS(2545),
    [aux_sym_record_type_token1] = ACTIONS(2543),
    [aux_sym_basic_type_token21] = ACTIONS(2543),
    [aux_sym_basic_type_token22] = ACTIONS(2543),
    [aux_sym_basic_type_token48] = ACTIONS(2543),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2543),
    [anon_sym_COLON_COLON] = ACTIONS(2545),
    [anon_sym_POUNDif] = ACTIONS(2545),
    [anon_sym_POUNDIF] = ACTIONS(2545),
    [anon_sym_POUNDIf] = ACTIONS(2545),
    [anon_sym_not] = ACTIONS(2543),
    [anon_sym_NOT] = ACTIONS(2543),
    [anon_sym_Not] = ACTIONS(2543),
    [anon_sym_POUNDelif] = ACTIONS(2545),
    [anon_sym_POUNDELIF] = ACTIONS(2545),
    [anon_sym_POUNDElif] = ACTIONS(2545),
    [anon_sym_POUNDelse] = ACTIONS(2545),
    [anon_sym_POUNDELSE] = ACTIONS(2545),
    [anon_sym_POUNDElse] = ACTIONS(2545),
    [anon_sym_POUNDendif] = ACTIONS(2545),
    [anon_sym_POUNDENDIF] = ACTIONS(2545),
    [anon_sym_POUNDEndif] = ACTIONS(2545),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2545),
    [aux_sym__expression_token1] = ACTIONS(2545),
    [aux_sym__expression_token2] = ACTIONS(2543),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2543),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2543),
    [anon_sym_SLASH] = ACTIONS(2543),
    [anon_sym_div] = ACTIONS(2543),
    [anon_sym_DIV] = ACTIONS(2543),
    [anon_sym_Div] = ACTIONS(2543),
    [anon_sym_mod] = ACTIONS(2543),
    [anon_sym_MOD] = ACTIONS(2543),
    [anon_sym_Mod] = ACTIONS(2543),
    [anon_sym_PLUS] = ACTIONS(2543),
    [anon_sym_GT_EQ] = ACTIONS(2545),
    [anon_sym_LT_EQ] = ACTIONS(2545),
    [anon_sym_GT] = ACTIONS(2543),
    [anon_sym_LT] = ACTIONS(2543),
    [anon_sym_LT_GT] = ACTIONS(2545),
    [anon_sym_and] = ACTIONS(2543),
    [anon_sym_AND] = ACTIONS(2543),
    [anon_sym_And] = ACTIONS(2543),
    [anon_sym_or] = ACTIONS(2543),
    [anon_sym_OR] = ACTIONS(2543),
    [anon_sym_Or] = ACTIONS(2543),
    [anon_sym_xor] = ACTIONS(2543),
    [anon_sym_XOR] = ACTIONS(2543),
    [anon_sym_Xor] = ACTIONS(2543),
    [anon_sym_QMARK] = ACTIONS(2545),
    [sym_datetime_literal] = ACTIONS(2545),
    [sym_date_literal] = ACTIONS(2543),
    [sym_time_literal] = ACTIONS(2543),
    [sym_biginteger_literal] = ACTIONS(2545),
    [anon_sym_if] = ACTIONS(2543),
    [anon_sym_IF] = ACTIONS(2543),
    [anon_sym_If] = ACTIONS(2543),
    [anon_sym_else] = ACTIONS(2543),
    [anon_sym_ELSE] = ACTIONS(2543),
    [anon_sym_Else] = ACTIONS(2543),
    [anon_sym_case] = ACTIONS(2543),
    [anon_sym_CASE] = ACTIONS(2543),
    [anon_sym_Case] = ACTIONS(2543),
    [anon_sym_for] = ACTIONS(2543),
    [anon_sym_FOR] = ACTIONS(2543),
    [anon_sym_For] = ACTIONS(2543),
    [anon_sym_foreach] = ACTIONS(2543),
    [anon_sym_FOREACH] = ACTIONS(2543),
    [anon_sym_Foreach] = ACTIONS(2543),
    [anon_sym_while] = ACTIONS(2543),
    [anon_sym_WHILE] = ACTIONS(2543),
    [anon_sym_While] = ACTIONS(2543),
    [anon_sym_repeat] = ACTIONS(2543),
    [anon_sym_REPEAT] = ACTIONS(2543),
    [anon_sym_Repeat] = ACTIONS(2543),
    [anon_sym_exit] = ACTIONS(2543),
    [anon_sym_EXIT] = ACTIONS(2543),
    [anon_sym_Exit] = ACTIONS(2543),
    [anon_sym_continue] = ACTIONS(2543),
    [anon_sym_CONTINUE] = ACTIONS(2543),
    [anon_sym_Continue] = ACTIONS(2543),
    [anon_sym_break] = ACTIONS(2543),
    [anon_sym_BREAK] = ACTIONS(2543),
    [anon_sym_Break] = ACTIONS(2543),
    [anon_sym_with] = ACTIONS(2543),
    [anon_sym_WITH] = ACTIONS(2543),
    [anon_sym_With] = ACTIONS(2543),
    [sym_asserterror_keyword] = ACTIONS(2545),
    [anon_sym_in] = ACTIONS(2543),
    [anon_sym_IN] = ACTIONS(2543),
    [anon_sym_In] = ACTIONS(2543),
    [sym_page_keyword] = ACTIONS(2543),
    [anon_sym_codeunit] = ACTIONS(2543),
    [anon_sym_CODEUNIT] = ACTIONS(2543),
    [anon_sym_Codeunit] = ACTIONS(2543),
    [anon_sym_CodeUnit] = ACTIONS(2543),
    [anon_sym_COdeunit] = ACTIONS(2543),
    [anon_sym_codeUnit] = ACTIONS(2543),
    [sym_report_keyword] = ACTIONS(2543),
    [sym_query_keyword] = ACTIONS(2543),
    [anon_sym_xmlport] = ACTIONS(2543),
    [anon_sym_XMLPORT] = ACTIONS(2543),
    [anon_sym_Xmlport] = ACTIONS(2543),
    [anon_sym_XMLport] = ACTIONS(2543),
    [anon_sym_XMLPort] = ACTIONS(2543),
    [anon_sym_XmlPort] = ACTIONS(2543),
    [anon_sym_enum] = ACTIONS(2543),
    [anon_sym_ENUM] = ACTIONS(2543),
    [anon_sym_Enum] = ACTIONS(2543),
    [anon_sym_eNUM] = ACTIONS(2543),
    [anon_sym_eNum] = ACTIONS(2543),
    [anon_sym_ENum] = ACTIONS(2543),
    [sym_quoted_identifier] = ACTIONS(2545),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2545),
    [sym_integer] = ACTIONS(2543),
    [sym_continue_as_identifier] = ACTIONS(2545),
    [sym_preproc_open] = ACTIONS(2545),
    [sym_preproc_close] = ACTIONS(2545),
  },
  [STATE(1008)] = {
    [sym_identifier] = ACTIONS(2547),
    [anon_sym_SEMI] = ACTIONS(2549),
    [anon_sym_DOT] = ACTIONS(2547),
    [anon_sym_EQ] = ACTIONS(2549),
    [anon_sym_DASH] = ACTIONS(2547),
    [aux_sym_boolean_token1] = ACTIONS(2547),
    [aux_sym_boolean_token2] = ACTIONS(2547),
    [sym_decimal] = ACTIONS(2547),
    [anon_sym_LPAREN] = ACTIONS(2549),
    [anon_sym_DOT_DOT] = ACTIONS(2549),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2547),
    [anon_sym_STAR] = ACTIONS(2547),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [aux_sym_record_type_token1] = ACTIONS(2547),
    [aux_sym_basic_type_token21] = ACTIONS(2547),
    [aux_sym_basic_type_token22] = ACTIONS(2547),
    [aux_sym_basic_type_token48] = ACTIONS(2547),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2547),
    [anon_sym_COLON_COLON] = ACTIONS(2549),
    [anon_sym_POUNDif] = ACTIONS(2549),
    [anon_sym_POUNDIF] = ACTIONS(2549),
    [anon_sym_POUNDIf] = ACTIONS(2549),
    [anon_sym_not] = ACTIONS(2547),
    [anon_sym_NOT] = ACTIONS(2547),
    [anon_sym_Not] = ACTIONS(2547),
    [anon_sym_POUNDelif] = ACTIONS(2549),
    [anon_sym_POUNDELIF] = ACTIONS(2549),
    [anon_sym_POUNDElif] = ACTIONS(2549),
    [anon_sym_POUNDelse] = ACTIONS(2549),
    [anon_sym_POUNDELSE] = ACTIONS(2549),
    [anon_sym_POUNDElse] = ACTIONS(2549),
    [anon_sym_POUNDendif] = ACTIONS(2549),
    [anon_sym_POUNDENDIF] = ACTIONS(2549),
    [anon_sym_POUNDEndif] = ACTIONS(2549),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2549),
    [aux_sym__expression_token1] = ACTIONS(2549),
    [aux_sym__expression_token2] = ACTIONS(2547),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2547),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2547),
    [anon_sym_SLASH] = ACTIONS(2547),
    [anon_sym_div] = ACTIONS(2547),
    [anon_sym_DIV] = ACTIONS(2547),
    [anon_sym_Div] = ACTIONS(2547),
    [anon_sym_mod] = ACTIONS(2547),
    [anon_sym_MOD] = ACTIONS(2547),
    [anon_sym_Mod] = ACTIONS(2547),
    [anon_sym_PLUS] = ACTIONS(2547),
    [anon_sym_GT_EQ] = ACTIONS(2549),
    [anon_sym_LT_EQ] = ACTIONS(2549),
    [anon_sym_GT] = ACTIONS(2547),
    [anon_sym_LT] = ACTIONS(2547),
    [anon_sym_LT_GT] = ACTIONS(2549),
    [anon_sym_and] = ACTIONS(2547),
    [anon_sym_AND] = ACTIONS(2547),
    [anon_sym_And] = ACTIONS(2547),
    [anon_sym_or] = ACTIONS(2547),
    [anon_sym_OR] = ACTIONS(2547),
    [anon_sym_Or] = ACTIONS(2547),
    [anon_sym_xor] = ACTIONS(2547),
    [anon_sym_XOR] = ACTIONS(2547),
    [anon_sym_Xor] = ACTIONS(2547),
    [anon_sym_QMARK] = ACTIONS(2549),
    [sym_datetime_literal] = ACTIONS(2549),
    [sym_date_literal] = ACTIONS(2547),
    [sym_time_literal] = ACTIONS(2547),
    [sym_biginteger_literal] = ACTIONS(2549),
    [anon_sym_if] = ACTIONS(2547),
    [anon_sym_IF] = ACTIONS(2547),
    [anon_sym_If] = ACTIONS(2547),
    [anon_sym_else] = ACTIONS(2547),
    [anon_sym_ELSE] = ACTIONS(2547),
    [anon_sym_Else] = ACTIONS(2547),
    [anon_sym_case] = ACTIONS(2547),
    [anon_sym_CASE] = ACTIONS(2547),
    [anon_sym_Case] = ACTIONS(2547),
    [anon_sym_for] = ACTIONS(2547),
    [anon_sym_FOR] = ACTIONS(2547),
    [anon_sym_For] = ACTIONS(2547),
    [anon_sym_foreach] = ACTIONS(2547),
    [anon_sym_FOREACH] = ACTIONS(2547),
    [anon_sym_Foreach] = ACTIONS(2547),
    [anon_sym_while] = ACTIONS(2547),
    [anon_sym_WHILE] = ACTIONS(2547),
    [anon_sym_While] = ACTIONS(2547),
    [anon_sym_repeat] = ACTIONS(2547),
    [anon_sym_REPEAT] = ACTIONS(2547),
    [anon_sym_Repeat] = ACTIONS(2547),
    [anon_sym_exit] = ACTIONS(2547),
    [anon_sym_EXIT] = ACTIONS(2547),
    [anon_sym_Exit] = ACTIONS(2547),
    [anon_sym_continue] = ACTIONS(2547),
    [anon_sym_CONTINUE] = ACTIONS(2547),
    [anon_sym_Continue] = ACTIONS(2547),
    [anon_sym_break] = ACTIONS(2547),
    [anon_sym_BREAK] = ACTIONS(2547),
    [anon_sym_Break] = ACTIONS(2547),
    [anon_sym_with] = ACTIONS(2547),
    [anon_sym_WITH] = ACTIONS(2547),
    [anon_sym_With] = ACTIONS(2547),
    [sym_asserterror_keyword] = ACTIONS(2549),
    [anon_sym_in] = ACTIONS(2547),
    [anon_sym_IN] = ACTIONS(2547),
    [anon_sym_In] = ACTIONS(2547),
    [sym_page_keyword] = ACTIONS(2547),
    [anon_sym_codeunit] = ACTIONS(2547),
    [anon_sym_CODEUNIT] = ACTIONS(2547),
    [anon_sym_Codeunit] = ACTIONS(2547),
    [anon_sym_CodeUnit] = ACTIONS(2547),
    [anon_sym_COdeunit] = ACTIONS(2547),
    [anon_sym_codeUnit] = ACTIONS(2547),
    [sym_report_keyword] = ACTIONS(2547),
    [sym_query_keyword] = ACTIONS(2547),
    [anon_sym_xmlport] = ACTIONS(2547),
    [anon_sym_XMLPORT] = ACTIONS(2547),
    [anon_sym_Xmlport] = ACTIONS(2547),
    [anon_sym_XMLport] = ACTIONS(2547),
    [anon_sym_XMLPort] = ACTIONS(2547),
    [anon_sym_XmlPort] = ACTIONS(2547),
    [anon_sym_enum] = ACTIONS(2547),
    [anon_sym_ENUM] = ACTIONS(2547),
    [anon_sym_Enum] = ACTIONS(2547),
    [anon_sym_eNUM] = ACTIONS(2547),
    [anon_sym_eNum] = ACTIONS(2547),
    [anon_sym_ENum] = ACTIONS(2547),
    [sym_quoted_identifier] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2549),
    [sym_integer] = ACTIONS(2547),
    [sym_continue_as_identifier] = ACTIONS(2549),
    [sym_preproc_open] = ACTIONS(2549),
    [sym_preproc_close] = ACTIONS(2549),
  },
  [STATE(1009)] = {
    [sym_identifier] = ACTIONS(2551),
    [anon_sym_SEMI] = ACTIONS(2553),
    [anon_sym_DOT] = ACTIONS(2551),
    [anon_sym_EQ] = ACTIONS(2553),
    [anon_sym_COMMA] = ACTIONS(2553),
    [anon_sym_DASH] = ACTIONS(2551),
    [aux_sym_boolean_token1] = ACTIONS(2551),
    [aux_sym_boolean_token2] = ACTIONS(2551),
    [sym_decimal] = ACTIONS(2551),
    [anon_sym_LPAREN] = ACTIONS(2553),
    [anon_sym_DOT_DOT] = ACTIONS(2553),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2551),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_LBRACK] = ACTIONS(2553),
    [aux_sym_record_type_token1] = ACTIONS(2551),
    [aux_sym_basic_type_token21] = ACTIONS(2551),
    [aux_sym_basic_type_token22] = ACTIONS(2551),
    [aux_sym_basic_type_token48] = ACTIONS(2551),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2551),
    [anon_sym_POUNDif] = ACTIONS(2553),
    [anon_sym_POUNDIF] = ACTIONS(2553),
    [anon_sym_POUNDIf] = ACTIONS(2553),
    [anon_sym_not] = ACTIONS(2551),
    [anon_sym_NOT] = ACTIONS(2551),
    [anon_sym_Not] = ACTIONS(2551),
    [anon_sym_POUNDelif] = ACTIONS(2553),
    [anon_sym_POUNDELIF] = ACTIONS(2553),
    [anon_sym_POUNDElif] = ACTIONS(2553),
    [anon_sym_POUNDelse] = ACTIONS(2553),
    [anon_sym_POUNDELSE] = ACTIONS(2553),
    [anon_sym_POUNDElse] = ACTIONS(2553),
    [anon_sym_POUNDendif] = ACTIONS(2553),
    [anon_sym_POUNDENDIF] = ACTIONS(2553),
    [anon_sym_POUNDEndif] = ACTIONS(2553),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2553),
    [aux_sym__expression_token1] = ACTIONS(2553),
    [aux_sym__expression_token2] = ACTIONS(2551),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2551),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2551),
    [anon_sym_SLASH] = ACTIONS(2551),
    [anon_sym_div] = ACTIONS(2551),
    [anon_sym_DIV] = ACTIONS(2551),
    [anon_sym_Div] = ACTIONS(2551),
    [anon_sym_mod] = ACTIONS(2551),
    [anon_sym_MOD] = ACTIONS(2551),
    [anon_sym_Mod] = ACTIONS(2551),
    [anon_sym_PLUS] = ACTIONS(2551),
    [anon_sym_GT_EQ] = ACTIONS(2553),
    [anon_sym_LT_EQ] = ACTIONS(2553),
    [anon_sym_GT] = ACTIONS(2551),
    [anon_sym_LT] = ACTIONS(2551),
    [anon_sym_LT_GT] = ACTIONS(2553),
    [anon_sym_and] = ACTIONS(2551),
    [anon_sym_AND] = ACTIONS(2551),
    [anon_sym_And] = ACTIONS(2551),
    [anon_sym_or] = ACTIONS(2551),
    [anon_sym_OR] = ACTIONS(2551),
    [anon_sym_Or] = ACTIONS(2551),
    [anon_sym_xor] = ACTIONS(2551),
    [anon_sym_XOR] = ACTIONS(2551),
    [anon_sym_Xor] = ACTIONS(2551),
    [anon_sym_QMARK] = ACTIONS(2553),
    [sym_datetime_literal] = ACTIONS(2553),
    [sym_date_literal] = ACTIONS(2551),
    [sym_time_literal] = ACTIONS(2551),
    [sym_biginteger_literal] = ACTIONS(2553),
    [anon_sym_if] = ACTIONS(2551),
    [anon_sym_IF] = ACTIONS(2551),
    [anon_sym_If] = ACTIONS(2551),
    [anon_sym_else] = ACTIONS(2551),
    [anon_sym_ELSE] = ACTIONS(2551),
    [anon_sym_Else] = ACTIONS(2551),
    [anon_sym_case] = ACTIONS(2551),
    [anon_sym_CASE] = ACTIONS(2551),
    [anon_sym_Case] = ACTIONS(2551),
    [anon_sym_for] = ACTIONS(2551),
    [anon_sym_FOR] = ACTIONS(2551),
    [anon_sym_For] = ACTIONS(2551),
    [anon_sym_foreach] = ACTIONS(2551),
    [anon_sym_FOREACH] = ACTIONS(2551),
    [anon_sym_Foreach] = ACTIONS(2551),
    [anon_sym_while] = ACTIONS(2551),
    [anon_sym_WHILE] = ACTIONS(2551),
    [anon_sym_While] = ACTIONS(2551),
    [anon_sym_repeat] = ACTIONS(2551),
    [anon_sym_REPEAT] = ACTIONS(2551),
    [anon_sym_Repeat] = ACTIONS(2551),
    [anon_sym_exit] = ACTIONS(2551),
    [anon_sym_EXIT] = ACTIONS(2551),
    [anon_sym_Exit] = ACTIONS(2551),
    [anon_sym_continue] = ACTIONS(2551),
    [anon_sym_CONTINUE] = ACTIONS(2551),
    [anon_sym_Continue] = ACTIONS(2551),
    [anon_sym_break] = ACTIONS(2551),
    [anon_sym_BREAK] = ACTIONS(2551),
    [anon_sym_Break] = ACTIONS(2551),
    [anon_sym_with] = ACTIONS(2551),
    [anon_sym_WITH] = ACTIONS(2551),
    [anon_sym_With] = ACTIONS(2551),
    [sym_asserterror_keyword] = ACTIONS(2553),
    [anon_sym_in] = ACTIONS(2551),
    [anon_sym_IN] = ACTIONS(2551),
    [anon_sym_In] = ACTIONS(2551),
    [sym_page_keyword] = ACTIONS(2551),
    [anon_sym_codeunit] = ACTIONS(2551),
    [anon_sym_CODEUNIT] = ACTIONS(2551),
    [anon_sym_Codeunit] = ACTIONS(2551),
    [anon_sym_CodeUnit] = ACTIONS(2551),
    [anon_sym_COdeunit] = ACTIONS(2551),
    [anon_sym_codeUnit] = ACTIONS(2551),
    [sym_report_keyword] = ACTIONS(2551),
    [sym_query_keyword] = ACTIONS(2551),
    [anon_sym_xmlport] = ACTIONS(2551),
    [anon_sym_XMLPORT] = ACTIONS(2551),
    [anon_sym_Xmlport] = ACTIONS(2551),
    [anon_sym_XMLport] = ACTIONS(2551),
    [anon_sym_XMLPort] = ACTIONS(2551),
    [anon_sym_XmlPort] = ACTIONS(2551),
    [anon_sym_enum] = ACTIONS(2551),
    [anon_sym_ENUM] = ACTIONS(2551),
    [anon_sym_Enum] = ACTIONS(2551),
    [anon_sym_eNUM] = ACTIONS(2551),
    [anon_sym_eNum] = ACTIONS(2551),
    [anon_sym_ENum] = ACTIONS(2551),
    [sym_quoted_identifier] = ACTIONS(2553),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2553),
    [sym_integer] = ACTIONS(2551),
    [sym_continue_as_identifier] = ACTIONS(2553),
    [sym_preproc_open] = ACTIONS(2553),
    [sym_preproc_close] = ACTIONS(2553),
  },
  [STATE(1010)] = {
    [sym_identifier] = ACTIONS(2555),
    [anon_sym_SEMI] = ACTIONS(2557),
    [anon_sym_DOT] = ACTIONS(2555),
    [anon_sym_EQ] = ACTIONS(2557),
    [anon_sym_DASH] = ACTIONS(2555),
    [aux_sym_boolean_token1] = ACTIONS(2555),
    [aux_sym_boolean_token2] = ACTIONS(2555),
    [sym_decimal] = ACTIONS(2555),
    [anon_sym_LPAREN] = ACTIONS(2557),
    [anon_sym_DOT_DOT] = ACTIONS(2557),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2555),
    [anon_sym_STAR] = ACTIONS(2555),
    [anon_sym_LBRACK] = ACTIONS(2557),
    [aux_sym_record_type_token1] = ACTIONS(2555),
    [aux_sym_basic_type_token21] = ACTIONS(2555),
    [aux_sym_basic_type_token22] = ACTIONS(2555),
    [aux_sym_basic_type_token48] = ACTIONS(2555),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2555),
    [anon_sym_COLON_COLON] = ACTIONS(2557),
    [anon_sym_POUNDif] = ACTIONS(2557),
    [anon_sym_POUNDIF] = ACTIONS(2557),
    [anon_sym_POUNDIf] = ACTIONS(2557),
    [anon_sym_not] = ACTIONS(2555),
    [anon_sym_NOT] = ACTIONS(2555),
    [anon_sym_Not] = ACTIONS(2555),
    [anon_sym_POUNDelif] = ACTIONS(2557),
    [anon_sym_POUNDELIF] = ACTIONS(2557),
    [anon_sym_POUNDElif] = ACTIONS(2557),
    [anon_sym_POUNDelse] = ACTIONS(2557),
    [anon_sym_POUNDELSE] = ACTIONS(2557),
    [anon_sym_POUNDElse] = ACTIONS(2557),
    [anon_sym_POUNDendif] = ACTIONS(2557),
    [anon_sym_POUNDENDIF] = ACTIONS(2557),
    [anon_sym_POUNDEndif] = ACTIONS(2557),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2557),
    [aux_sym__expression_token1] = ACTIONS(2557),
    [aux_sym__expression_token2] = ACTIONS(2555),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2555),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2555),
    [anon_sym_SLASH] = ACTIONS(2555),
    [anon_sym_div] = ACTIONS(2555),
    [anon_sym_DIV] = ACTIONS(2555),
    [anon_sym_Div] = ACTIONS(2555),
    [anon_sym_mod] = ACTIONS(2555),
    [anon_sym_MOD] = ACTIONS(2555),
    [anon_sym_Mod] = ACTIONS(2555),
    [anon_sym_PLUS] = ACTIONS(2555),
    [anon_sym_GT_EQ] = ACTIONS(2557),
    [anon_sym_LT_EQ] = ACTIONS(2557),
    [anon_sym_GT] = ACTIONS(2555),
    [anon_sym_LT] = ACTIONS(2555),
    [anon_sym_LT_GT] = ACTIONS(2557),
    [anon_sym_and] = ACTIONS(2555),
    [anon_sym_AND] = ACTIONS(2555),
    [anon_sym_And] = ACTIONS(2555),
    [anon_sym_or] = ACTIONS(2555),
    [anon_sym_OR] = ACTIONS(2555),
    [anon_sym_Or] = ACTIONS(2555),
    [anon_sym_xor] = ACTIONS(2555),
    [anon_sym_XOR] = ACTIONS(2555),
    [anon_sym_Xor] = ACTIONS(2555),
    [anon_sym_QMARK] = ACTIONS(2557),
    [sym_datetime_literal] = ACTIONS(2557),
    [sym_date_literal] = ACTIONS(2555),
    [sym_time_literal] = ACTIONS(2555),
    [sym_biginteger_literal] = ACTIONS(2557),
    [anon_sym_if] = ACTIONS(2555),
    [anon_sym_IF] = ACTIONS(2555),
    [anon_sym_If] = ACTIONS(2555),
    [anon_sym_else] = ACTIONS(2555),
    [anon_sym_ELSE] = ACTIONS(2555),
    [anon_sym_Else] = ACTIONS(2555),
    [anon_sym_case] = ACTIONS(2555),
    [anon_sym_CASE] = ACTIONS(2555),
    [anon_sym_Case] = ACTIONS(2555),
    [anon_sym_for] = ACTIONS(2555),
    [anon_sym_FOR] = ACTIONS(2555),
    [anon_sym_For] = ACTIONS(2555),
    [anon_sym_foreach] = ACTIONS(2555),
    [anon_sym_FOREACH] = ACTIONS(2555),
    [anon_sym_Foreach] = ACTIONS(2555),
    [anon_sym_while] = ACTIONS(2555),
    [anon_sym_WHILE] = ACTIONS(2555),
    [anon_sym_While] = ACTIONS(2555),
    [anon_sym_repeat] = ACTIONS(2555),
    [anon_sym_REPEAT] = ACTIONS(2555),
    [anon_sym_Repeat] = ACTIONS(2555),
    [anon_sym_exit] = ACTIONS(2555),
    [anon_sym_EXIT] = ACTIONS(2555),
    [anon_sym_Exit] = ACTIONS(2555),
    [anon_sym_continue] = ACTIONS(2555),
    [anon_sym_CONTINUE] = ACTIONS(2555),
    [anon_sym_Continue] = ACTIONS(2555),
    [anon_sym_break] = ACTIONS(2555),
    [anon_sym_BREAK] = ACTIONS(2555),
    [anon_sym_Break] = ACTIONS(2555),
    [anon_sym_with] = ACTIONS(2555),
    [anon_sym_WITH] = ACTIONS(2555),
    [anon_sym_With] = ACTIONS(2555),
    [sym_asserterror_keyword] = ACTIONS(2557),
    [anon_sym_in] = ACTIONS(2555),
    [anon_sym_IN] = ACTIONS(2555),
    [anon_sym_In] = ACTIONS(2555),
    [sym_page_keyword] = ACTIONS(2555),
    [anon_sym_codeunit] = ACTIONS(2555),
    [anon_sym_CODEUNIT] = ACTIONS(2555),
    [anon_sym_Codeunit] = ACTIONS(2555),
    [anon_sym_CodeUnit] = ACTIONS(2555),
    [anon_sym_COdeunit] = ACTIONS(2555),
    [anon_sym_codeUnit] = ACTIONS(2555),
    [sym_report_keyword] = ACTIONS(2555),
    [sym_query_keyword] = ACTIONS(2555),
    [anon_sym_xmlport] = ACTIONS(2555),
    [anon_sym_XMLPORT] = ACTIONS(2555),
    [anon_sym_Xmlport] = ACTIONS(2555),
    [anon_sym_XMLport] = ACTIONS(2555),
    [anon_sym_XMLPort] = ACTIONS(2555),
    [anon_sym_XmlPort] = ACTIONS(2555),
    [anon_sym_enum] = ACTIONS(2555),
    [anon_sym_ENUM] = ACTIONS(2555),
    [anon_sym_Enum] = ACTIONS(2555),
    [anon_sym_eNUM] = ACTIONS(2555),
    [anon_sym_eNum] = ACTIONS(2555),
    [anon_sym_ENum] = ACTIONS(2555),
    [sym_quoted_identifier] = ACTIONS(2557),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2557),
    [sym_integer] = ACTIONS(2555),
    [sym_continue_as_identifier] = ACTIONS(2557),
    [sym_preproc_open] = ACTIONS(2557),
    [sym_preproc_close] = ACTIONS(2557),
  },
  [STATE(1011)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_SEMI] = ACTIONS(2428),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2426),
    [anon_sym_COLON_COLON] = ACTIONS(2559),
    [anon_sym_POUNDif] = ACTIONS(2428),
    [anon_sym_POUNDIF] = ACTIONS(2428),
    [anon_sym_POUNDIf] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [anon_sym_POUNDelif] = ACTIONS(2428),
    [anon_sym_POUNDELIF] = ACTIONS(2428),
    [anon_sym_POUNDElif] = ACTIONS(2428),
    [anon_sym_POUNDelse] = ACTIONS(2428),
    [anon_sym_POUNDELSE] = ACTIONS(2428),
    [anon_sym_POUNDElse] = ACTIONS(2428),
    [anon_sym_POUNDendif] = ACTIONS(2428),
    [anon_sym_POUNDENDIF] = ACTIONS(2428),
    [anon_sym_POUNDEndif] = ACTIONS(2428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_IF] = ACTIONS(2426),
    [anon_sym_If] = ACTIONS(2426),
    [anon_sym_else] = ACTIONS(2426),
    [anon_sym_ELSE] = ACTIONS(2426),
    [anon_sym_Else] = ACTIONS(2426),
    [anon_sym_case] = ACTIONS(2426),
    [anon_sym_CASE] = ACTIONS(2426),
    [anon_sym_Case] = ACTIONS(2426),
    [anon_sym_for] = ACTIONS(2426),
    [anon_sym_FOR] = ACTIONS(2426),
    [anon_sym_For] = ACTIONS(2426),
    [anon_sym_foreach] = ACTIONS(2426),
    [anon_sym_FOREACH] = ACTIONS(2426),
    [anon_sym_Foreach] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(2426),
    [anon_sym_WHILE] = ACTIONS(2426),
    [anon_sym_While] = ACTIONS(2426),
    [anon_sym_repeat] = ACTIONS(2426),
    [anon_sym_REPEAT] = ACTIONS(2426),
    [anon_sym_Repeat] = ACTIONS(2426),
    [anon_sym_exit] = ACTIONS(2426),
    [anon_sym_EXIT] = ACTIONS(2426),
    [anon_sym_Exit] = ACTIONS(2426),
    [anon_sym_continue] = ACTIONS(2426),
    [anon_sym_CONTINUE] = ACTIONS(2426),
    [anon_sym_Continue] = ACTIONS(2426),
    [anon_sym_break] = ACTIONS(2426),
    [anon_sym_BREAK] = ACTIONS(2426),
    [anon_sym_Break] = ACTIONS(2426),
    [anon_sym_with] = ACTIONS(2426),
    [anon_sym_WITH] = ACTIONS(2426),
    [anon_sym_With] = ACTIONS(2426),
    [sym_asserterror_keyword] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_open] = ACTIONS(2428),
    [sym_preproc_close] = ACTIONS(2428),
  },
  [STATE(1012)] = {
    [sym_identifier] = ACTIONS(2434),
    [anon_sym_SEMI] = ACTIONS(2436),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_DASH] = ACTIONS(2434),
    [aux_sym_boolean_token1] = ACTIONS(2434),
    [aux_sym_boolean_token2] = ACTIONS(2434),
    [sym_decimal] = ACTIONS(2434),
    [anon_sym_LPAREN] = ACTIONS(2436),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2434),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [aux_sym_record_type_token1] = ACTIONS(2434),
    [aux_sym_basic_type_token21] = ACTIONS(2434),
    [aux_sym_basic_type_token22] = ACTIONS(2434),
    [aux_sym_basic_type_token48] = ACTIONS(2434),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2434),
    [anon_sym_COLON_COLON] = ACTIONS(2440),
    [anon_sym_POUNDif] = ACTIONS(2436),
    [anon_sym_POUNDIF] = ACTIONS(2436),
    [anon_sym_POUNDIf] = ACTIONS(2436),
    [anon_sym_not] = ACTIONS(2434),
    [anon_sym_NOT] = ACTIONS(2434),
    [anon_sym_Not] = ACTIONS(2434),
    [anon_sym_POUNDelif] = ACTIONS(2436),
    [anon_sym_POUNDELIF] = ACTIONS(2436),
    [anon_sym_POUNDElif] = ACTIONS(2436),
    [anon_sym_POUNDelse] = ACTIONS(2436),
    [anon_sym_POUNDELSE] = ACTIONS(2436),
    [anon_sym_POUNDElse] = ACTIONS(2436),
    [anon_sym_POUNDendif] = ACTIONS(2436),
    [anon_sym_POUNDENDIF] = ACTIONS(2436),
    [anon_sym_POUNDEndif] = ACTIONS(2436),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2434),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(2434),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(2436),
    [sym_date_literal] = ACTIONS(2434),
    [sym_time_literal] = ACTIONS(2434),
    [sym_biginteger_literal] = ACTIONS(2436),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_IF] = ACTIONS(2434),
    [anon_sym_If] = ACTIONS(2434),
    [anon_sym_else] = ACTIONS(2434),
    [anon_sym_ELSE] = ACTIONS(2434),
    [anon_sym_Else] = ACTIONS(2434),
    [anon_sym_case] = ACTIONS(2434),
    [anon_sym_CASE] = ACTIONS(2434),
    [anon_sym_Case] = ACTIONS(2434),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_FOR] = ACTIONS(2434),
    [anon_sym_For] = ACTIONS(2434),
    [anon_sym_foreach] = ACTIONS(2434),
    [anon_sym_FOREACH] = ACTIONS(2434),
    [anon_sym_Foreach] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(2434),
    [anon_sym_WHILE] = ACTIONS(2434),
    [anon_sym_While] = ACTIONS(2434),
    [anon_sym_repeat] = ACTIONS(2434),
    [anon_sym_REPEAT] = ACTIONS(2434),
    [anon_sym_Repeat] = ACTIONS(2434),
    [anon_sym_exit] = ACTIONS(2434),
    [anon_sym_EXIT] = ACTIONS(2434),
    [anon_sym_Exit] = ACTIONS(2434),
    [anon_sym_continue] = ACTIONS(2434),
    [anon_sym_CONTINUE] = ACTIONS(2434),
    [anon_sym_Continue] = ACTIONS(2434),
    [anon_sym_break] = ACTIONS(2434),
    [anon_sym_BREAK] = ACTIONS(2434),
    [anon_sym_Break] = ACTIONS(2434),
    [anon_sym_with] = ACTIONS(2434),
    [anon_sym_WITH] = ACTIONS(2434),
    [anon_sym_With] = ACTIONS(2434),
    [sym_asserterror_keyword] = ACTIONS(2436),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(2434),
    [anon_sym_codeunit] = ACTIONS(2434),
    [anon_sym_CODEUNIT] = ACTIONS(2434),
    [anon_sym_Codeunit] = ACTIONS(2434),
    [anon_sym_CodeUnit] = ACTIONS(2434),
    [anon_sym_COdeunit] = ACTIONS(2434),
    [anon_sym_codeUnit] = ACTIONS(2434),
    [sym_report_keyword] = ACTIONS(2434),
    [sym_query_keyword] = ACTIONS(2434),
    [anon_sym_xmlport] = ACTIONS(2434),
    [anon_sym_XMLPORT] = ACTIONS(2434),
    [anon_sym_Xmlport] = ACTIONS(2434),
    [anon_sym_XMLport] = ACTIONS(2434),
    [anon_sym_XMLPort] = ACTIONS(2434),
    [anon_sym_XmlPort] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2434),
    [anon_sym_ENUM] = ACTIONS(2434),
    [anon_sym_Enum] = ACTIONS(2434),
    [anon_sym_eNUM] = ACTIONS(2434),
    [anon_sym_eNum] = ACTIONS(2434),
    [anon_sym_ENum] = ACTIONS(2434),
    [sym_quoted_identifier] = ACTIONS(2436),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2436),
    [sym_integer] = ACTIONS(2434),
    [sym_continue_as_identifier] = ACTIONS(2436),
    [sym_preproc_open] = ACTIONS(2436),
    [sym_preproc_close] = ACTIONS(2436),
  },
  [STATE(1013)] = {
    [sym_identifier] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2563),
    [anon_sym_DOT] = ACTIONS(2561),
    [anon_sym_EQ] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2561),
    [aux_sym_boolean_token1] = ACTIONS(2561),
    [aux_sym_boolean_token2] = ACTIONS(2561),
    [sym_decimal] = ACTIONS(2561),
    [anon_sym_LPAREN] = ACTIONS(2563),
    [anon_sym_DOT_DOT] = ACTIONS(2563),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2561),
    [anon_sym_STAR] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2563),
    [aux_sym_record_type_token1] = ACTIONS(2561),
    [aux_sym_basic_type_token21] = ACTIONS(2561),
    [aux_sym_basic_type_token22] = ACTIONS(2561),
    [aux_sym_basic_type_token48] = ACTIONS(2561),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_POUNDif] = ACTIONS(2563),
    [anon_sym_POUNDIF] = ACTIONS(2563),
    [anon_sym_POUNDIf] = ACTIONS(2563),
    [anon_sym_not] = ACTIONS(2561),
    [anon_sym_NOT] = ACTIONS(2561),
    [anon_sym_Not] = ACTIONS(2561),
    [anon_sym_POUNDelif] = ACTIONS(2563),
    [anon_sym_POUNDELIF] = ACTIONS(2563),
    [anon_sym_POUNDElif] = ACTIONS(2563),
    [anon_sym_POUNDelse] = ACTIONS(2563),
    [anon_sym_POUNDELSE] = ACTIONS(2563),
    [anon_sym_POUNDElse] = ACTIONS(2563),
    [anon_sym_POUNDendif] = ACTIONS(2563),
    [anon_sym_POUNDENDIF] = ACTIONS(2563),
    [anon_sym_POUNDEndif] = ACTIONS(2563),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2563),
    [aux_sym__expression_token1] = ACTIONS(2563),
    [aux_sym__expression_token2] = ACTIONS(2561),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2561),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2561),
    [anon_sym_SLASH] = ACTIONS(2561),
    [anon_sym_div] = ACTIONS(2561),
    [anon_sym_DIV] = ACTIONS(2561),
    [anon_sym_Div] = ACTIONS(2561),
    [anon_sym_mod] = ACTIONS(2561),
    [anon_sym_MOD] = ACTIONS(2561),
    [anon_sym_Mod] = ACTIONS(2561),
    [anon_sym_PLUS] = ACTIONS(2561),
    [anon_sym_GT_EQ] = ACTIONS(2563),
    [anon_sym_LT_EQ] = ACTIONS(2563),
    [anon_sym_GT] = ACTIONS(2561),
    [anon_sym_LT] = ACTIONS(2561),
    [anon_sym_LT_GT] = ACTIONS(2563),
    [anon_sym_and] = ACTIONS(2561),
    [anon_sym_AND] = ACTIONS(2561),
    [anon_sym_And] = ACTIONS(2561),
    [anon_sym_or] = ACTIONS(2561),
    [anon_sym_OR] = ACTIONS(2561),
    [anon_sym_Or] = ACTIONS(2561),
    [anon_sym_xor] = ACTIONS(2561),
    [anon_sym_XOR] = ACTIONS(2561),
    [anon_sym_Xor] = ACTIONS(2561),
    [anon_sym_QMARK] = ACTIONS(2563),
    [sym_datetime_literal] = ACTIONS(2563),
    [sym_date_literal] = ACTIONS(2561),
    [sym_time_literal] = ACTIONS(2561),
    [sym_biginteger_literal] = ACTIONS(2563),
    [anon_sym_if] = ACTIONS(2561),
    [anon_sym_IF] = ACTIONS(2561),
    [anon_sym_If] = ACTIONS(2561),
    [anon_sym_else] = ACTIONS(2561),
    [anon_sym_ELSE] = ACTIONS(2561),
    [anon_sym_Else] = ACTIONS(2561),
    [anon_sym_case] = ACTIONS(2561),
    [anon_sym_CASE] = ACTIONS(2561),
    [anon_sym_Case] = ACTIONS(2561),
    [anon_sym_for] = ACTIONS(2561),
    [anon_sym_FOR] = ACTIONS(2561),
    [anon_sym_For] = ACTIONS(2561),
    [anon_sym_foreach] = ACTIONS(2561),
    [anon_sym_FOREACH] = ACTIONS(2561),
    [anon_sym_Foreach] = ACTIONS(2561),
    [anon_sym_while] = ACTIONS(2561),
    [anon_sym_WHILE] = ACTIONS(2561),
    [anon_sym_While] = ACTIONS(2561),
    [anon_sym_repeat] = ACTIONS(2561),
    [anon_sym_REPEAT] = ACTIONS(2561),
    [anon_sym_Repeat] = ACTIONS(2561),
    [anon_sym_exit] = ACTIONS(2561),
    [anon_sym_EXIT] = ACTIONS(2561),
    [anon_sym_Exit] = ACTIONS(2561),
    [anon_sym_continue] = ACTIONS(2561),
    [anon_sym_CONTINUE] = ACTIONS(2561),
    [anon_sym_Continue] = ACTIONS(2561),
    [anon_sym_break] = ACTIONS(2561),
    [anon_sym_BREAK] = ACTIONS(2561),
    [anon_sym_Break] = ACTIONS(2561),
    [anon_sym_with] = ACTIONS(2561),
    [anon_sym_WITH] = ACTIONS(2561),
    [anon_sym_With] = ACTIONS(2561),
    [sym_asserterror_keyword] = ACTIONS(2563),
    [anon_sym_in] = ACTIONS(2561),
    [anon_sym_IN] = ACTIONS(2561),
    [anon_sym_In] = ACTIONS(2561),
    [sym_page_keyword] = ACTIONS(2561),
    [anon_sym_codeunit] = ACTIONS(2561),
    [anon_sym_CODEUNIT] = ACTIONS(2561),
    [anon_sym_Codeunit] = ACTIONS(2561),
    [anon_sym_CodeUnit] = ACTIONS(2561),
    [anon_sym_COdeunit] = ACTIONS(2561),
    [anon_sym_codeUnit] = ACTIONS(2561),
    [sym_report_keyword] = ACTIONS(2561),
    [sym_query_keyword] = ACTIONS(2561),
    [anon_sym_xmlport] = ACTIONS(2561),
    [anon_sym_XMLPORT] = ACTIONS(2561),
    [anon_sym_Xmlport] = ACTIONS(2561),
    [anon_sym_XMLport] = ACTIONS(2561),
    [anon_sym_XMLPort] = ACTIONS(2561),
    [anon_sym_XmlPort] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_ENUM] = ACTIONS(2561),
    [anon_sym_Enum] = ACTIONS(2561),
    [anon_sym_eNUM] = ACTIONS(2561),
    [anon_sym_eNum] = ACTIONS(2561),
    [anon_sym_ENum] = ACTIONS(2561),
    [sym_quoted_identifier] = ACTIONS(2563),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2563),
    [sym_integer] = ACTIONS(2561),
    [sym_continue_as_identifier] = ACTIONS(2563),
    [sym_preproc_open] = ACTIONS(2563),
    [sym_preproc_close] = ACTIONS(2563),
  },
  [STATE(1014)] = {
    [sym_identifier] = ACTIONS(2565),
    [anon_sym_SEMI] = ACTIONS(2567),
    [anon_sym_DOT] = ACTIONS(2565),
    [anon_sym_EQ] = ACTIONS(2567),
    [anon_sym_DASH] = ACTIONS(2565),
    [aux_sym_boolean_token1] = ACTIONS(2565),
    [aux_sym_boolean_token2] = ACTIONS(2565),
    [sym_decimal] = ACTIONS(2565),
    [anon_sym_LPAREN] = ACTIONS(2567),
    [anon_sym_DOT_DOT] = ACTIONS(2567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2565),
    [anon_sym_STAR] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2567),
    [aux_sym_record_type_token1] = ACTIONS(2565),
    [aux_sym_basic_type_token21] = ACTIONS(2565),
    [aux_sym_basic_type_token22] = ACTIONS(2565),
    [aux_sym_basic_type_token48] = ACTIONS(2565),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_POUNDif] = ACTIONS(2567),
    [anon_sym_POUNDIF] = ACTIONS(2567),
    [anon_sym_POUNDIf] = ACTIONS(2567),
    [anon_sym_not] = ACTIONS(2565),
    [anon_sym_NOT] = ACTIONS(2565),
    [anon_sym_Not] = ACTIONS(2565),
    [anon_sym_POUNDelif] = ACTIONS(2567),
    [anon_sym_POUNDELIF] = ACTIONS(2567),
    [anon_sym_POUNDElif] = ACTIONS(2567),
    [anon_sym_POUNDelse] = ACTIONS(2567),
    [anon_sym_POUNDELSE] = ACTIONS(2567),
    [anon_sym_POUNDElse] = ACTIONS(2567),
    [anon_sym_POUNDendif] = ACTIONS(2567),
    [anon_sym_POUNDENDIF] = ACTIONS(2567),
    [anon_sym_POUNDEndif] = ACTIONS(2567),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2567),
    [aux_sym__expression_token1] = ACTIONS(2567),
    [aux_sym__expression_token2] = ACTIONS(2565),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2565),
    [anon_sym_SLASH] = ACTIONS(2565),
    [anon_sym_div] = ACTIONS(2565),
    [anon_sym_DIV] = ACTIONS(2565),
    [anon_sym_Div] = ACTIONS(2565),
    [anon_sym_mod] = ACTIONS(2565),
    [anon_sym_MOD] = ACTIONS(2565),
    [anon_sym_Mod] = ACTIONS(2565),
    [anon_sym_PLUS] = ACTIONS(2565),
    [anon_sym_GT_EQ] = ACTIONS(2567),
    [anon_sym_LT_EQ] = ACTIONS(2567),
    [anon_sym_GT] = ACTIONS(2565),
    [anon_sym_LT] = ACTIONS(2565),
    [anon_sym_LT_GT] = ACTIONS(2567),
    [anon_sym_and] = ACTIONS(2565),
    [anon_sym_AND] = ACTIONS(2565),
    [anon_sym_And] = ACTIONS(2565),
    [anon_sym_or] = ACTIONS(2565),
    [anon_sym_OR] = ACTIONS(2565),
    [anon_sym_Or] = ACTIONS(2565),
    [anon_sym_xor] = ACTIONS(2565),
    [anon_sym_XOR] = ACTIONS(2565),
    [anon_sym_Xor] = ACTIONS(2565),
    [anon_sym_QMARK] = ACTIONS(2567),
    [sym_datetime_literal] = ACTIONS(2567),
    [sym_date_literal] = ACTIONS(2565),
    [sym_time_literal] = ACTIONS(2565),
    [sym_biginteger_literal] = ACTIONS(2567),
    [anon_sym_if] = ACTIONS(2565),
    [anon_sym_IF] = ACTIONS(2565),
    [anon_sym_If] = ACTIONS(2565),
    [anon_sym_else] = ACTIONS(2565),
    [anon_sym_ELSE] = ACTIONS(2565),
    [anon_sym_Else] = ACTIONS(2565),
    [anon_sym_case] = ACTIONS(2565),
    [anon_sym_CASE] = ACTIONS(2565),
    [anon_sym_Case] = ACTIONS(2565),
    [anon_sym_for] = ACTIONS(2565),
    [anon_sym_FOR] = ACTIONS(2565),
    [anon_sym_For] = ACTIONS(2565),
    [anon_sym_foreach] = ACTIONS(2565),
    [anon_sym_FOREACH] = ACTIONS(2565),
    [anon_sym_Foreach] = ACTIONS(2565),
    [anon_sym_while] = ACTIONS(2565),
    [anon_sym_WHILE] = ACTIONS(2565),
    [anon_sym_While] = ACTIONS(2565),
    [anon_sym_repeat] = ACTIONS(2565),
    [anon_sym_REPEAT] = ACTIONS(2565),
    [anon_sym_Repeat] = ACTIONS(2565),
    [anon_sym_exit] = ACTIONS(2565),
    [anon_sym_EXIT] = ACTIONS(2565),
    [anon_sym_Exit] = ACTIONS(2565),
    [anon_sym_continue] = ACTIONS(2565),
    [anon_sym_CONTINUE] = ACTIONS(2565),
    [anon_sym_Continue] = ACTIONS(2565),
    [anon_sym_break] = ACTIONS(2565),
    [anon_sym_BREAK] = ACTIONS(2565),
    [anon_sym_Break] = ACTIONS(2565),
    [anon_sym_with] = ACTIONS(2565),
    [anon_sym_WITH] = ACTIONS(2565),
    [anon_sym_With] = ACTIONS(2565),
    [sym_asserterror_keyword] = ACTIONS(2567),
    [anon_sym_in] = ACTIONS(2565),
    [anon_sym_IN] = ACTIONS(2565),
    [anon_sym_In] = ACTIONS(2565),
    [sym_page_keyword] = ACTIONS(2565),
    [anon_sym_codeunit] = ACTIONS(2565),
    [anon_sym_CODEUNIT] = ACTIONS(2565),
    [anon_sym_Codeunit] = ACTIONS(2565),
    [anon_sym_CodeUnit] = ACTIONS(2565),
    [anon_sym_COdeunit] = ACTIONS(2565),
    [anon_sym_codeUnit] = ACTIONS(2565),
    [sym_report_keyword] = ACTIONS(2565),
    [sym_query_keyword] = ACTIONS(2565),
    [anon_sym_xmlport] = ACTIONS(2565),
    [anon_sym_XMLPORT] = ACTIONS(2565),
    [anon_sym_Xmlport] = ACTIONS(2565),
    [anon_sym_XMLport] = ACTIONS(2565),
    [anon_sym_XMLPort] = ACTIONS(2565),
    [anon_sym_XmlPort] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_ENUM] = ACTIONS(2565),
    [anon_sym_Enum] = ACTIONS(2565),
    [anon_sym_eNUM] = ACTIONS(2565),
    [anon_sym_eNum] = ACTIONS(2565),
    [anon_sym_ENum] = ACTIONS(2565),
    [sym_quoted_identifier] = ACTIONS(2567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2567),
    [sym_integer] = ACTIONS(2565),
    [sym_continue_as_identifier] = ACTIONS(2567),
    [sym_preproc_open] = ACTIONS(2567),
    [sym_preproc_close] = ACTIONS(2567),
  },
  [STATE(1015)] = {
    [sym_identifier] = ACTIONS(2569),
    [anon_sym_SEMI] = ACTIONS(2571),
    [anon_sym_DOT] = ACTIONS(2569),
    [anon_sym_EQ] = ACTIONS(2571),
    [anon_sym_DASH] = ACTIONS(2569),
    [aux_sym_boolean_token1] = ACTIONS(2569),
    [aux_sym_boolean_token2] = ACTIONS(2569),
    [sym_decimal] = ACTIONS(2569),
    [anon_sym_LPAREN] = ACTIONS(2571),
    [anon_sym_DOT_DOT] = ACTIONS(2571),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2569),
    [anon_sym_STAR] = ACTIONS(2569),
    [anon_sym_LBRACK] = ACTIONS(2571),
    [aux_sym_record_type_token1] = ACTIONS(2569),
    [aux_sym_basic_type_token21] = ACTIONS(2569),
    [aux_sym_basic_type_token22] = ACTIONS(2569),
    [aux_sym_basic_type_token48] = ACTIONS(2569),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2569),
    [anon_sym_POUNDif] = ACTIONS(2571),
    [anon_sym_POUNDIF] = ACTIONS(2571),
    [anon_sym_POUNDIf] = ACTIONS(2571),
    [anon_sym_not] = ACTIONS(2569),
    [anon_sym_NOT] = ACTIONS(2569),
    [anon_sym_Not] = ACTIONS(2569),
    [anon_sym_POUNDelif] = ACTIONS(2571),
    [anon_sym_POUNDELIF] = ACTIONS(2571),
    [anon_sym_POUNDElif] = ACTIONS(2571),
    [anon_sym_POUNDelse] = ACTIONS(2571),
    [anon_sym_POUNDELSE] = ACTIONS(2571),
    [anon_sym_POUNDElse] = ACTIONS(2571),
    [anon_sym_POUNDendif] = ACTIONS(2571),
    [anon_sym_POUNDENDIF] = ACTIONS(2571),
    [anon_sym_POUNDEndif] = ACTIONS(2571),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2571),
    [aux_sym__expression_token1] = ACTIONS(2571),
    [aux_sym__expression_token2] = ACTIONS(2569),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2569),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2569),
    [anon_sym_SLASH] = ACTIONS(2569),
    [anon_sym_div] = ACTIONS(2569),
    [anon_sym_DIV] = ACTIONS(2569),
    [anon_sym_Div] = ACTIONS(2569),
    [anon_sym_mod] = ACTIONS(2569),
    [anon_sym_MOD] = ACTIONS(2569),
    [anon_sym_Mod] = ACTIONS(2569),
    [anon_sym_PLUS] = ACTIONS(2569),
    [anon_sym_GT_EQ] = ACTIONS(2571),
    [anon_sym_LT_EQ] = ACTIONS(2571),
    [anon_sym_GT] = ACTIONS(2569),
    [anon_sym_LT] = ACTIONS(2569),
    [anon_sym_LT_GT] = ACTIONS(2571),
    [anon_sym_and] = ACTIONS(2569),
    [anon_sym_AND] = ACTIONS(2569),
    [anon_sym_And] = ACTIONS(2569),
    [anon_sym_or] = ACTIONS(2569),
    [anon_sym_OR] = ACTIONS(2569),
    [anon_sym_Or] = ACTIONS(2569),
    [anon_sym_xor] = ACTIONS(2569),
    [anon_sym_XOR] = ACTIONS(2569),
    [anon_sym_Xor] = ACTIONS(2569),
    [anon_sym_QMARK] = ACTIONS(2571),
    [sym_datetime_literal] = ACTIONS(2571),
    [sym_date_literal] = ACTIONS(2569),
    [sym_time_literal] = ACTIONS(2569),
    [sym_biginteger_literal] = ACTIONS(2571),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_IF] = ACTIONS(2569),
    [anon_sym_If] = ACTIONS(2569),
    [anon_sym_else] = ACTIONS(2569),
    [anon_sym_ELSE] = ACTIONS(2569),
    [anon_sym_Else] = ACTIONS(2569),
    [anon_sym_case] = ACTIONS(2569),
    [anon_sym_CASE] = ACTIONS(2569),
    [anon_sym_Case] = ACTIONS(2569),
    [anon_sym_for] = ACTIONS(2569),
    [anon_sym_FOR] = ACTIONS(2569),
    [anon_sym_For] = ACTIONS(2569),
    [anon_sym_foreach] = ACTIONS(2569),
    [anon_sym_FOREACH] = ACTIONS(2569),
    [anon_sym_Foreach] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2569),
    [anon_sym_WHILE] = ACTIONS(2569),
    [anon_sym_While] = ACTIONS(2569),
    [anon_sym_repeat] = ACTIONS(2569),
    [anon_sym_REPEAT] = ACTIONS(2569),
    [anon_sym_Repeat] = ACTIONS(2569),
    [anon_sym_exit] = ACTIONS(2569),
    [anon_sym_EXIT] = ACTIONS(2569),
    [anon_sym_Exit] = ACTIONS(2569),
    [anon_sym_continue] = ACTIONS(2569),
    [anon_sym_CONTINUE] = ACTIONS(2569),
    [anon_sym_Continue] = ACTIONS(2569),
    [anon_sym_break] = ACTIONS(2569),
    [anon_sym_BREAK] = ACTIONS(2569),
    [anon_sym_Break] = ACTIONS(2569),
    [anon_sym_with] = ACTIONS(2569),
    [anon_sym_WITH] = ACTIONS(2569),
    [anon_sym_With] = ACTIONS(2569),
    [sym_asserterror_keyword] = ACTIONS(2571),
    [anon_sym_in] = ACTIONS(2569),
    [anon_sym_IN] = ACTIONS(2569),
    [anon_sym_In] = ACTIONS(2569),
    [sym_page_keyword] = ACTIONS(2569),
    [anon_sym_codeunit] = ACTIONS(2569),
    [anon_sym_CODEUNIT] = ACTIONS(2569),
    [anon_sym_Codeunit] = ACTIONS(2569),
    [anon_sym_CodeUnit] = ACTIONS(2569),
    [anon_sym_COdeunit] = ACTIONS(2569),
    [anon_sym_codeUnit] = ACTIONS(2569),
    [sym_report_keyword] = ACTIONS(2569),
    [sym_query_keyword] = ACTIONS(2569),
    [anon_sym_xmlport] = ACTIONS(2569),
    [anon_sym_XMLPORT] = ACTIONS(2569),
    [anon_sym_Xmlport] = ACTIONS(2569),
    [anon_sym_XMLport] = ACTIONS(2569),
    [anon_sym_XMLPort] = ACTIONS(2569),
    [anon_sym_XmlPort] = ACTIONS(2569),
    [anon_sym_enum] = ACTIONS(2569),
    [anon_sym_ENUM] = ACTIONS(2569),
    [anon_sym_Enum] = ACTIONS(2569),
    [anon_sym_eNUM] = ACTIONS(2569),
    [anon_sym_eNum] = ACTIONS(2569),
    [anon_sym_ENum] = ACTIONS(2569),
    [sym_quoted_identifier] = ACTIONS(2571),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2571),
    [sym_integer] = ACTIONS(2569),
    [sym_continue_as_identifier] = ACTIONS(2571),
    [sym_preproc_open] = ACTIONS(2571),
    [sym_preproc_close] = ACTIONS(2571),
  },
  [STATE(1016)] = {
    [sym_identifier] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym_DOT] = ACTIONS(2573),
    [anon_sym_EQ] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2573),
    [aux_sym_boolean_token1] = ACTIONS(2573),
    [aux_sym_boolean_token2] = ACTIONS(2573),
    [sym_decimal] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2575),
    [anon_sym_DOT_DOT] = ACTIONS(2575),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2575),
    [aux_sym_record_type_token1] = ACTIONS(2573),
    [aux_sym_basic_type_token21] = ACTIONS(2573),
    [aux_sym_basic_type_token22] = ACTIONS(2573),
    [aux_sym_basic_type_token48] = ACTIONS(2573),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2573),
    [anon_sym_POUNDif] = ACTIONS(2575),
    [anon_sym_POUNDIF] = ACTIONS(2575),
    [anon_sym_POUNDIf] = ACTIONS(2575),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_NOT] = ACTIONS(2573),
    [anon_sym_Not] = ACTIONS(2573),
    [anon_sym_POUNDelif] = ACTIONS(2575),
    [anon_sym_POUNDELIF] = ACTIONS(2575),
    [anon_sym_POUNDElif] = ACTIONS(2575),
    [anon_sym_POUNDelse] = ACTIONS(2575),
    [anon_sym_POUNDELSE] = ACTIONS(2575),
    [anon_sym_POUNDElse] = ACTIONS(2575),
    [anon_sym_POUNDendif] = ACTIONS(2575),
    [anon_sym_POUNDENDIF] = ACTIONS(2575),
    [anon_sym_POUNDEndif] = ACTIONS(2575),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2575),
    [aux_sym__expression_token1] = ACTIONS(2575),
    [aux_sym__expression_token2] = ACTIONS(2573),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2573),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2573),
    [anon_sym_SLASH] = ACTIONS(2573),
    [anon_sym_div] = ACTIONS(2573),
    [anon_sym_DIV] = ACTIONS(2573),
    [anon_sym_Div] = ACTIONS(2573),
    [anon_sym_mod] = ACTIONS(2573),
    [anon_sym_MOD] = ACTIONS(2573),
    [anon_sym_Mod] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_GT_EQ] = ACTIONS(2575),
    [anon_sym_LT_EQ] = ACTIONS(2575),
    [anon_sym_GT] = ACTIONS(2573),
    [anon_sym_LT] = ACTIONS(2573),
    [anon_sym_LT_GT] = ACTIONS(2575),
    [anon_sym_and] = ACTIONS(2573),
    [anon_sym_AND] = ACTIONS(2573),
    [anon_sym_And] = ACTIONS(2573),
    [anon_sym_or] = ACTIONS(2573),
    [anon_sym_OR] = ACTIONS(2573),
    [anon_sym_Or] = ACTIONS(2573),
    [anon_sym_xor] = ACTIONS(2573),
    [anon_sym_XOR] = ACTIONS(2573),
    [anon_sym_Xor] = ACTIONS(2573),
    [anon_sym_QMARK] = ACTIONS(2575),
    [sym_datetime_literal] = ACTIONS(2575),
    [sym_date_literal] = ACTIONS(2573),
    [sym_time_literal] = ACTIONS(2573),
    [sym_biginteger_literal] = ACTIONS(2575),
    [anon_sym_if] = ACTIONS(2573),
    [anon_sym_IF] = ACTIONS(2573),
    [anon_sym_If] = ACTIONS(2573),
    [anon_sym_else] = ACTIONS(2573),
    [anon_sym_ELSE] = ACTIONS(2573),
    [anon_sym_Else] = ACTIONS(2573),
    [anon_sym_case] = ACTIONS(2573),
    [anon_sym_CASE] = ACTIONS(2573),
    [anon_sym_Case] = ACTIONS(2573),
    [anon_sym_for] = ACTIONS(2573),
    [anon_sym_FOR] = ACTIONS(2573),
    [anon_sym_For] = ACTIONS(2573),
    [anon_sym_foreach] = ACTIONS(2573),
    [anon_sym_FOREACH] = ACTIONS(2573),
    [anon_sym_Foreach] = ACTIONS(2573),
    [anon_sym_while] = ACTIONS(2573),
    [anon_sym_WHILE] = ACTIONS(2573),
    [anon_sym_While] = ACTIONS(2573),
    [anon_sym_repeat] = ACTIONS(2573),
    [anon_sym_REPEAT] = ACTIONS(2573),
    [anon_sym_Repeat] = ACTIONS(2573),
    [anon_sym_exit] = ACTIONS(2573),
    [anon_sym_EXIT] = ACTIONS(2573),
    [anon_sym_Exit] = ACTIONS(2573),
    [anon_sym_continue] = ACTIONS(2573),
    [anon_sym_CONTINUE] = ACTIONS(2573),
    [anon_sym_Continue] = ACTIONS(2573),
    [anon_sym_break] = ACTIONS(2573),
    [anon_sym_BREAK] = ACTIONS(2573),
    [anon_sym_Break] = ACTIONS(2573),
    [anon_sym_with] = ACTIONS(2573),
    [anon_sym_WITH] = ACTIONS(2573),
    [anon_sym_With] = ACTIONS(2573),
    [sym_asserterror_keyword] = ACTIONS(2575),
    [anon_sym_in] = ACTIONS(2573),
    [anon_sym_IN] = ACTIONS(2573),
    [anon_sym_In] = ACTIONS(2573),
    [sym_page_keyword] = ACTIONS(2573),
    [anon_sym_codeunit] = ACTIONS(2573),
    [anon_sym_CODEUNIT] = ACTIONS(2573),
    [anon_sym_Codeunit] = ACTIONS(2573),
    [anon_sym_CodeUnit] = ACTIONS(2573),
    [anon_sym_COdeunit] = ACTIONS(2573),
    [anon_sym_codeUnit] = ACTIONS(2573),
    [sym_report_keyword] = ACTIONS(2573),
    [sym_query_keyword] = ACTIONS(2573),
    [anon_sym_xmlport] = ACTIONS(2573),
    [anon_sym_XMLPORT] = ACTIONS(2573),
    [anon_sym_Xmlport] = ACTIONS(2573),
    [anon_sym_XMLport] = ACTIONS(2573),
    [anon_sym_XMLPort] = ACTIONS(2573),
    [anon_sym_XmlPort] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_ENUM] = ACTIONS(2573),
    [anon_sym_Enum] = ACTIONS(2573),
    [anon_sym_eNUM] = ACTIONS(2573),
    [anon_sym_eNum] = ACTIONS(2573),
    [anon_sym_ENum] = ACTIONS(2573),
    [sym_quoted_identifier] = ACTIONS(2575),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2575),
    [sym_integer] = ACTIONS(2573),
    [sym_continue_as_identifier] = ACTIONS(2575),
    [sym_preproc_open] = ACTIONS(2575),
    [sym_preproc_close] = ACTIONS(2575),
  },
  [STATE(1017)] = {
    [sym_identifier] = ACTIONS(2577),
    [anon_sym_SEMI] = ACTIONS(2579),
    [anon_sym_DOT] = ACTIONS(2577),
    [anon_sym_EQ] = ACTIONS(2579),
    [anon_sym_DASH] = ACTIONS(2577),
    [aux_sym_boolean_token1] = ACTIONS(2577),
    [aux_sym_boolean_token2] = ACTIONS(2577),
    [sym_decimal] = ACTIONS(2577),
    [anon_sym_LPAREN] = ACTIONS(2579),
    [anon_sym_DOT_DOT] = ACTIONS(2579),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2577),
    [anon_sym_STAR] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [aux_sym_record_type_token1] = ACTIONS(2577),
    [aux_sym_basic_type_token21] = ACTIONS(2577),
    [aux_sym_basic_type_token22] = ACTIONS(2577),
    [aux_sym_basic_type_token48] = ACTIONS(2577),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2577),
    [anon_sym_POUNDif] = ACTIONS(2579),
    [anon_sym_POUNDIF] = ACTIONS(2579),
    [anon_sym_POUNDIf] = ACTIONS(2579),
    [anon_sym_not] = ACTIONS(2577),
    [anon_sym_NOT] = ACTIONS(2577),
    [anon_sym_Not] = ACTIONS(2577),
    [anon_sym_POUNDelif] = ACTIONS(2579),
    [anon_sym_POUNDELIF] = ACTIONS(2579),
    [anon_sym_POUNDElif] = ACTIONS(2579),
    [anon_sym_POUNDelse] = ACTIONS(2579),
    [anon_sym_POUNDELSE] = ACTIONS(2579),
    [anon_sym_POUNDElse] = ACTIONS(2579),
    [anon_sym_POUNDendif] = ACTIONS(2579),
    [anon_sym_POUNDENDIF] = ACTIONS(2579),
    [anon_sym_POUNDEndif] = ACTIONS(2579),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2579),
    [aux_sym__expression_token1] = ACTIONS(2579),
    [aux_sym__expression_token2] = ACTIONS(2577),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2577),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2577),
    [anon_sym_SLASH] = ACTIONS(2577),
    [anon_sym_div] = ACTIONS(2577),
    [anon_sym_DIV] = ACTIONS(2577),
    [anon_sym_Div] = ACTIONS(2577),
    [anon_sym_mod] = ACTIONS(2577),
    [anon_sym_MOD] = ACTIONS(2577),
    [anon_sym_Mod] = ACTIONS(2577),
    [anon_sym_PLUS] = ACTIONS(2577),
    [anon_sym_GT_EQ] = ACTIONS(2579),
    [anon_sym_LT_EQ] = ACTIONS(2579),
    [anon_sym_GT] = ACTIONS(2577),
    [anon_sym_LT] = ACTIONS(2577),
    [anon_sym_LT_GT] = ACTIONS(2579),
    [anon_sym_and] = ACTIONS(2577),
    [anon_sym_AND] = ACTIONS(2577),
    [anon_sym_And] = ACTIONS(2577),
    [anon_sym_or] = ACTIONS(2577),
    [anon_sym_OR] = ACTIONS(2577),
    [anon_sym_Or] = ACTIONS(2577),
    [anon_sym_xor] = ACTIONS(2577),
    [anon_sym_XOR] = ACTIONS(2577),
    [anon_sym_Xor] = ACTIONS(2577),
    [anon_sym_QMARK] = ACTIONS(2579),
    [sym_datetime_literal] = ACTIONS(2579),
    [sym_date_literal] = ACTIONS(2577),
    [sym_time_literal] = ACTIONS(2577),
    [sym_biginteger_literal] = ACTIONS(2579),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_IF] = ACTIONS(2577),
    [anon_sym_If] = ACTIONS(2577),
    [anon_sym_else] = ACTIONS(2577),
    [anon_sym_ELSE] = ACTIONS(2577),
    [anon_sym_Else] = ACTIONS(2577),
    [anon_sym_case] = ACTIONS(2577),
    [anon_sym_CASE] = ACTIONS(2577),
    [anon_sym_Case] = ACTIONS(2577),
    [anon_sym_for] = ACTIONS(2577),
    [anon_sym_FOR] = ACTIONS(2577),
    [anon_sym_For] = ACTIONS(2577),
    [anon_sym_foreach] = ACTIONS(2577),
    [anon_sym_FOREACH] = ACTIONS(2577),
    [anon_sym_Foreach] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(2577),
    [anon_sym_WHILE] = ACTIONS(2577),
    [anon_sym_While] = ACTIONS(2577),
    [anon_sym_repeat] = ACTIONS(2577),
    [anon_sym_REPEAT] = ACTIONS(2577),
    [anon_sym_Repeat] = ACTIONS(2577),
    [anon_sym_exit] = ACTIONS(2577),
    [anon_sym_EXIT] = ACTIONS(2577),
    [anon_sym_Exit] = ACTIONS(2577),
    [anon_sym_continue] = ACTIONS(2577),
    [anon_sym_CONTINUE] = ACTIONS(2577),
    [anon_sym_Continue] = ACTIONS(2577),
    [anon_sym_break] = ACTIONS(2577),
    [anon_sym_BREAK] = ACTIONS(2577),
    [anon_sym_Break] = ACTIONS(2577),
    [anon_sym_with] = ACTIONS(2577),
    [anon_sym_WITH] = ACTIONS(2577),
    [anon_sym_With] = ACTIONS(2577),
    [sym_asserterror_keyword] = ACTIONS(2579),
    [anon_sym_in] = ACTIONS(2577),
    [anon_sym_IN] = ACTIONS(2577),
    [anon_sym_In] = ACTIONS(2577),
    [sym_page_keyword] = ACTIONS(2577),
    [anon_sym_codeunit] = ACTIONS(2577),
    [anon_sym_CODEUNIT] = ACTIONS(2577),
    [anon_sym_Codeunit] = ACTIONS(2577),
    [anon_sym_CodeUnit] = ACTIONS(2577),
    [anon_sym_COdeunit] = ACTIONS(2577),
    [anon_sym_codeUnit] = ACTIONS(2577),
    [sym_report_keyword] = ACTIONS(2577),
    [sym_query_keyword] = ACTIONS(2577),
    [anon_sym_xmlport] = ACTIONS(2577),
    [anon_sym_XMLPORT] = ACTIONS(2577),
    [anon_sym_Xmlport] = ACTIONS(2577),
    [anon_sym_XMLport] = ACTIONS(2577),
    [anon_sym_XMLPort] = ACTIONS(2577),
    [anon_sym_XmlPort] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_ENUM] = ACTIONS(2577),
    [anon_sym_Enum] = ACTIONS(2577),
    [anon_sym_eNUM] = ACTIONS(2577),
    [anon_sym_eNum] = ACTIONS(2577),
    [anon_sym_ENum] = ACTIONS(2577),
    [sym_quoted_identifier] = ACTIONS(2579),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2579),
    [sym_integer] = ACTIONS(2577),
    [sym_continue_as_identifier] = ACTIONS(2579),
    [sym_preproc_open] = ACTIONS(2579),
    [sym_preproc_close] = ACTIONS(2579),
  },
  [STATE(1018)] = {
    [sym_identifier] = ACTIONS(2581),
    [anon_sym_SEMI] = ACTIONS(2583),
    [anon_sym_DOT] = ACTIONS(2581),
    [anon_sym_EQ] = ACTIONS(2583),
    [anon_sym_DASH] = ACTIONS(2581),
    [aux_sym_boolean_token1] = ACTIONS(2581),
    [aux_sym_boolean_token2] = ACTIONS(2581),
    [sym_decimal] = ACTIONS(2581),
    [anon_sym_LPAREN] = ACTIONS(2583),
    [anon_sym_DOT_DOT] = ACTIONS(2583),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2581),
    [anon_sym_STAR] = ACTIONS(2581),
    [anon_sym_LBRACK] = ACTIONS(2583),
    [aux_sym_record_type_token1] = ACTIONS(2581),
    [aux_sym_basic_type_token21] = ACTIONS(2581),
    [aux_sym_basic_type_token22] = ACTIONS(2581),
    [aux_sym_basic_type_token48] = ACTIONS(2581),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2581),
    [anon_sym_POUNDif] = ACTIONS(2583),
    [anon_sym_POUNDIF] = ACTIONS(2583),
    [anon_sym_POUNDIf] = ACTIONS(2583),
    [anon_sym_not] = ACTIONS(2581),
    [anon_sym_NOT] = ACTIONS(2581),
    [anon_sym_Not] = ACTIONS(2581),
    [anon_sym_POUNDelif] = ACTIONS(2583),
    [anon_sym_POUNDELIF] = ACTIONS(2583),
    [anon_sym_POUNDElif] = ACTIONS(2583),
    [anon_sym_POUNDelse] = ACTIONS(2583),
    [anon_sym_POUNDELSE] = ACTIONS(2583),
    [anon_sym_POUNDElse] = ACTIONS(2583),
    [anon_sym_POUNDendif] = ACTIONS(2583),
    [anon_sym_POUNDENDIF] = ACTIONS(2583),
    [anon_sym_POUNDEndif] = ACTIONS(2583),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2583),
    [aux_sym__expression_token1] = ACTIONS(2583),
    [aux_sym__expression_token2] = ACTIONS(2581),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2581),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2581),
    [anon_sym_SLASH] = ACTIONS(2581),
    [anon_sym_div] = ACTIONS(2581),
    [anon_sym_DIV] = ACTIONS(2581),
    [anon_sym_Div] = ACTIONS(2581),
    [anon_sym_mod] = ACTIONS(2581),
    [anon_sym_MOD] = ACTIONS(2581),
    [anon_sym_Mod] = ACTIONS(2581),
    [anon_sym_PLUS] = ACTIONS(2581),
    [anon_sym_GT_EQ] = ACTIONS(2583),
    [anon_sym_LT_EQ] = ACTIONS(2583),
    [anon_sym_GT] = ACTIONS(2581),
    [anon_sym_LT] = ACTIONS(2581),
    [anon_sym_LT_GT] = ACTIONS(2583),
    [anon_sym_and] = ACTIONS(2581),
    [anon_sym_AND] = ACTIONS(2581),
    [anon_sym_And] = ACTIONS(2581),
    [anon_sym_or] = ACTIONS(2581),
    [anon_sym_OR] = ACTIONS(2581),
    [anon_sym_Or] = ACTIONS(2581),
    [anon_sym_xor] = ACTIONS(2581),
    [anon_sym_XOR] = ACTIONS(2581),
    [anon_sym_Xor] = ACTIONS(2581),
    [anon_sym_QMARK] = ACTIONS(2583),
    [sym_datetime_literal] = ACTIONS(2583),
    [sym_date_literal] = ACTIONS(2581),
    [sym_time_literal] = ACTIONS(2581),
    [sym_biginteger_literal] = ACTIONS(2583),
    [anon_sym_if] = ACTIONS(2581),
    [anon_sym_IF] = ACTIONS(2581),
    [anon_sym_If] = ACTIONS(2581),
    [anon_sym_else] = ACTIONS(2581),
    [anon_sym_ELSE] = ACTIONS(2581),
    [anon_sym_Else] = ACTIONS(2581),
    [anon_sym_case] = ACTIONS(2581),
    [anon_sym_CASE] = ACTIONS(2581),
    [anon_sym_Case] = ACTIONS(2581),
    [anon_sym_for] = ACTIONS(2581),
    [anon_sym_FOR] = ACTIONS(2581),
    [anon_sym_For] = ACTIONS(2581),
    [anon_sym_foreach] = ACTIONS(2581),
    [anon_sym_FOREACH] = ACTIONS(2581),
    [anon_sym_Foreach] = ACTIONS(2581),
    [anon_sym_while] = ACTIONS(2581),
    [anon_sym_WHILE] = ACTIONS(2581),
    [anon_sym_While] = ACTIONS(2581),
    [anon_sym_repeat] = ACTIONS(2581),
    [anon_sym_REPEAT] = ACTIONS(2581),
    [anon_sym_Repeat] = ACTIONS(2581),
    [anon_sym_exit] = ACTIONS(2581),
    [anon_sym_EXIT] = ACTIONS(2581),
    [anon_sym_Exit] = ACTIONS(2581),
    [anon_sym_continue] = ACTIONS(2581),
    [anon_sym_CONTINUE] = ACTIONS(2581),
    [anon_sym_Continue] = ACTIONS(2581),
    [anon_sym_break] = ACTIONS(2581),
    [anon_sym_BREAK] = ACTIONS(2581),
    [anon_sym_Break] = ACTIONS(2581),
    [anon_sym_with] = ACTIONS(2581),
    [anon_sym_WITH] = ACTIONS(2581),
    [anon_sym_With] = ACTIONS(2581),
    [sym_asserterror_keyword] = ACTIONS(2583),
    [anon_sym_in] = ACTIONS(2581),
    [anon_sym_IN] = ACTIONS(2581),
    [anon_sym_In] = ACTIONS(2581),
    [sym_page_keyword] = ACTIONS(2581),
    [anon_sym_codeunit] = ACTIONS(2581),
    [anon_sym_CODEUNIT] = ACTIONS(2581),
    [anon_sym_Codeunit] = ACTIONS(2581),
    [anon_sym_CodeUnit] = ACTIONS(2581),
    [anon_sym_COdeunit] = ACTIONS(2581),
    [anon_sym_codeUnit] = ACTIONS(2581),
    [sym_report_keyword] = ACTIONS(2581),
    [sym_query_keyword] = ACTIONS(2581),
    [anon_sym_xmlport] = ACTIONS(2581),
    [anon_sym_XMLPORT] = ACTIONS(2581),
    [anon_sym_Xmlport] = ACTIONS(2581),
    [anon_sym_XMLport] = ACTIONS(2581),
    [anon_sym_XMLPort] = ACTIONS(2581),
    [anon_sym_XmlPort] = ACTIONS(2581),
    [anon_sym_enum] = ACTIONS(2581),
    [anon_sym_ENUM] = ACTIONS(2581),
    [anon_sym_Enum] = ACTIONS(2581),
    [anon_sym_eNUM] = ACTIONS(2581),
    [anon_sym_eNum] = ACTIONS(2581),
    [anon_sym_ENum] = ACTIONS(2581),
    [sym_quoted_identifier] = ACTIONS(2583),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2583),
    [sym_integer] = ACTIONS(2581),
    [sym_continue_as_identifier] = ACTIONS(2583),
    [sym_preproc_open] = ACTIONS(2583),
    [sym_preproc_close] = ACTIONS(2583),
  },
  [STATE(1019)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2585),
    [anon_sym_POUNDif] = ACTIONS(2587),
    [anon_sym_POUNDIF] = ACTIONS(2587),
    [anon_sym_POUNDIf] = ACTIONS(2587),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [anon_sym_POUNDelif] = ACTIONS(2587),
    [anon_sym_POUNDELIF] = ACTIONS(2587),
    [anon_sym_POUNDElif] = ACTIONS(2587),
    [anon_sym_POUNDelse] = ACTIONS(2587),
    [anon_sym_POUNDELSE] = ACTIONS(2587),
    [anon_sym_POUNDElse] = ACTIONS(2587),
    [anon_sym_POUNDendif] = ACTIONS(2587),
    [anon_sym_POUNDENDIF] = ACTIONS(2587),
    [anon_sym_POUNDEndif] = ACTIONS(2587),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_IF] = ACTIONS(2585),
    [anon_sym_If] = ACTIONS(2585),
    [anon_sym_else] = ACTIONS(2585),
    [anon_sym_ELSE] = ACTIONS(2585),
    [anon_sym_Else] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_CASE] = ACTIONS(2585),
    [anon_sym_Case] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_FOR] = ACTIONS(2585),
    [anon_sym_For] = ACTIONS(2585),
    [anon_sym_foreach] = ACTIONS(2585),
    [anon_sym_FOREACH] = ACTIONS(2585),
    [anon_sym_Foreach] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_WHILE] = ACTIONS(2585),
    [anon_sym_While] = ACTIONS(2585),
    [anon_sym_repeat] = ACTIONS(2585),
    [anon_sym_REPEAT] = ACTIONS(2585),
    [anon_sym_Repeat] = ACTIONS(2585),
    [anon_sym_exit] = ACTIONS(2585),
    [anon_sym_EXIT] = ACTIONS(2585),
    [anon_sym_Exit] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_CONTINUE] = ACTIONS(2585),
    [anon_sym_Continue] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_BREAK] = ACTIONS(2585),
    [anon_sym_Break] = ACTIONS(2585),
    [anon_sym_with] = ACTIONS(2585),
    [anon_sym_WITH] = ACTIONS(2585),
    [anon_sym_With] = ACTIONS(2585),
    [sym_asserterror_keyword] = ACTIONS(2587),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_open] = ACTIONS(2587),
    [sym_preproc_close] = ACTIONS(2587),
  },
  [STATE(1020)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_SEMI] = ACTIONS(2591),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2589),
    [anon_sym_POUNDif] = ACTIONS(2591),
    [anon_sym_POUNDIF] = ACTIONS(2591),
    [anon_sym_POUNDIf] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [anon_sym_POUNDelif] = ACTIONS(2591),
    [anon_sym_POUNDELIF] = ACTIONS(2591),
    [anon_sym_POUNDElif] = ACTIONS(2591),
    [anon_sym_POUNDelse] = ACTIONS(2591),
    [anon_sym_POUNDELSE] = ACTIONS(2591),
    [anon_sym_POUNDElse] = ACTIONS(2591),
    [anon_sym_POUNDendif] = ACTIONS(2591),
    [anon_sym_POUNDENDIF] = ACTIONS(2591),
    [anon_sym_POUNDEndif] = ACTIONS(2591),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_if] = ACTIONS(2589),
    [anon_sym_IF] = ACTIONS(2589),
    [anon_sym_If] = ACTIONS(2589),
    [anon_sym_else] = ACTIONS(2589),
    [anon_sym_ELSE] = ACTIONS(2589),
    [anon_sym_Else] = ACTIONS(2589),
    [anon_sym_case] = ACTIONS(2589),
    [anon_sym_CASE] = ACTIONS(2589),
    [anon_sym_Case] = ACTIONS(2589),
    [anon_sym_for] = ACTIONS(2589),
    [anon_sym_FOR] = ACTIONS(2589),
    [anon_sym_For] = ACTIONS(2589),
    [anon_sym_foreach] = ACTIONS(2589),
    [anon_sym_FOREACH] = ACTIONS(2589),
    [anon_sym_Foreach] = ACTIONS(2589),
    [anon_sym_while] = ACTIONS(2589),
    [anon_sym_WHILE] = ACTIONS(2589),
    [anon_sym_While] = ACTIONS(2589),
    [anon_sym_repeat] = ACTIONS(2589),
    [anon_sym_REPEAT] = ACTIONS(2589),
    [anon_sym_Repeat] = ACTIONS(2589),
    [anon_sym_exit] = ACTIONS(2589),
    [anon_sym_EXIT] = ACTIONS(2589),
    [anon_sym_Exit] = ACTIONS(2589),
    [anon_sym_continue] = ACTIONS(2589),
    [anon_sym_CONTINUE] = ACTIONS(2589),
    [anon_sym_Continue] = ACTIONS(2589),
    [anon_sym_break] = ACTIONS(2589),
    [anon_sym_BREAK] = ACTIONS(2589),
    [anon_sym_Break] = ACTIONS(2589),
    [anon_sym_with] = ACTIONS(2589),
    [anon_sym_WITH] = ACTIONS(2589),
    [anon_sym_With] = ACTIONS(2589),
    [sym_asserterror_keyword] = ACTIONS(2591),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_open] = ACTIONS(2591),
    [sym_preproc_close] = ACTIONS(2591),
  },
  [STATE(1021)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_SEMI] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2593),
    [anon_sym_POUNDif] = ACTIONS(2595),
    [anon_sym_POUNDIF] = ACTIONS(2595),
    [anon_sym_POUNDIf] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [anon_sym_POUNDelif] = ACTIONS(2595),
    [anon_sym_POUNDELIF] = ACTIONS(2595),
    [anon_sym_POUNDElif] = ACTIONS(2595),
    [anon_sym_POUNDelse] = ACTIONS(2595),
    [anon_sym_POUNDELSE] = ACTIONS(2595),
    [anon_sym_POUNDElse] = ACTIONS(2595),
    [anon_sym_POUNDendif] = ACTIONS(2595),
    [anon_sym_POUNDENDIF] = ACTIONS(2595),
    [anon_sym_POUNDEndif] = ACTIONS(2595),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_if] = ACTIONS(2593),
    [anon_sym_IF] = ACTIONS(2593),
    [anon_sym_If] = ACTIONS(2593),
    [anon_sym_else] = ACTIONS(2593),
    [anon_sym_ELSE] = ACTIONS(2593),
    [anon_sym_Else] = ACTIONS(2593),
    [anon_sym_case] = ACTIONS(2593),
    [anon_sym_CASE] = ACTIONS(2593),
    [anon_sym_Case] = ACTIONS(2593),
    [anon_sym_for] = ACTIONS(2593),
    [anon_sym_FOR] = ACTIONS(2593),
    [anon_sym_For] = ACTIONS(2593),
    [anon_sym_foreach] = ACTIONS(2593),
    [anon_sym_FOREACH] = ACTIONS(2593),
    [anon_sym_Foreach] = ACTIONS(2593),
    [anon_sym_while] = ACTIONS(2593),
    [anon_sym_WHILE] = ACTIONS(2593),
    [anon_sym_While] = ACTIONS(2593),
    [anon_sym_repeat] = ACTIONS(2593),
    [anon_sym_REPEAT] = ACTIONS(2593),
    [anon_sym_Repeat] = ACTIONS(2593),
    [anon_sym_exit] = ACTIONS(2593),
    [anon_sym_EXIT] = ACTIONS(2593),
    [anon_sym_Exit] = ACTIONS(2593),
    [anon_sym_continue] = ACTIONS(2593),
    [anon_sym_CONTINUE] = ACTIONS(2593),
    [anon_sym_Continue] = ACTIONS(2593),
    [anon_sym_break] = ACTIONS(2593),
    [anon_sym_BREAK] = ACTIONS(2593),
    [anon_sym_Break] = ACTIONS(2593),
    [anon_sym_with] = ACTIONS(2593),
    [anon_sym_WITH] = ACTIONS(2593),
    [anon_sym_With] = ACTIONS(2593),
    [sym_asserterror_keyword] = ACTIONS(2595),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_open] = ACTIONS(2595),
    [sym_preproc_close] = ACTIONS(2595),
  },
  [STATE(1022)] = {
    [sym_identifier] = ACTIONS(2597),
    [anon_sym_SEMI] = ACTIONS(2599),
    [anon_sym_DOT] = ACTIONS(2597),
    [anon_sym_EQ] = ACTIONS(2599),
    [anon_sym_DASH] = ACTIONS(2597),
    [aux_sym_boolean_token1] = ACTIONS(2597),
    [aux_sym_boolean_token2] = ACTIONS(2597),
    [sym_decimal] = ACTIONS(2597),
    [anon_sym_LPAREN] = ACTIONS(2599),
    [anon_sym_DOT_DOT] = ACTIONS(2599),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2597),
    [anon_sym_STAR] = ACTIONS(2597),
    [anon_sym_LBRACK] = ACTIONS(2599),
    [aux_sym_record_type_token1] = ACTIONS(2597),
    [aux_sym_basic_type_token21] = ACTIONS(2597),
    [aux_sym_basic_type_token22] = ACTIONS(2597),
    [aux_sym_basic_type_token48] = ACTIONS(2597),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2597),
    [anon_sym_POUNDif] = ACTIONS(2599),
    [anon_sym_POUNDIF] = ACTIONS(2599),
    [anon_sym_POUNDIf] = ACTIONS(2599),
    [anon_sym_not] = ACTIONS(2597),
    [anon_sym_NOT] = ACTIONS(2597),
    [anon_sym_Not] = ACTIONS(2597),
    [anon_sym_POUNDelif] = ACTIONS(2599),
    [anon_sym_POUNDELIF] = ACTIONS(2599),
    [anon_sym_POUNDElif] = ACTIONS(2599),
    [anon_sym_POUNDelse] = ACTIONS(2599),
    [anon_sym_POUNDELSE] = ACTIONS(2599),
    [anon_sym_POUNDElse] = ACTIONS(2599),
    [anon_sym_POUNDendif] = ACTIONS(2599),
    [anon_sym_POUNDENDIF] = ACTIONS(2599),
    [anon_sym_POUNDEndif] = ACTIONS(2599),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2599),
    [aux_sym__expression_token1] = ACTIONS(2599),
    [aux_sym__expression_token2] = ACTIONS(2597),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2597),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2597),
    [anon_sym_SLASH] = ACTIONS(2597),
    [anon_sym_div] = ACTIONS(2597),
    [anon_sym_DIV] = ACTIONS(2597),
    [anon_sym_Div] = ACTIONS(2597),
    [anon_sym_mod] = ACTIONS(2597),
    [anon_sym_MOD] = ACTIONS(2597),
    [anon_sym_Mod] = ACTIONS(2597),
    [anon_sym_PLUS] = ACTIONS(2597),
    [anon_sym_GT_EQ] = ACTIONS(2599),
    [anon_sym_LT_EQ] = ACTIONS(2599),
    [anon_sym_GT] = ACTIONS(2597),
    [anon_sym_LT] = ACTIONS(2597),
    [anon_sym_LT_GT] = ACTIONS(2599),
    [anon_sym_and] = ACTIONS(2597),
    [anon_sym_AND] = ACTIONS(2597),
    [anon_sym_And] = ACTIONS(2597),
    [anon_sym_or] = ACTIONS(2597),
    [anon_sym_OR] = ACTIONS(2597),
    [anon_sym_Or] = ACTIONS(2597),
    [anon_sym_xor] = ACTIONS(2597),
    [anon_sym_XOR] = ACTIONS(2597),
    [anon_sym_Xor] = ACTIONS(2597),
    [anon_sym_QMARK] = ACTIONS(2599),
    [sym_datetime_literal] = ACTIONS(2599),
    [sym_date_literal] = ACTIONS(2597),
    [sym_time_literal] = ACTIONS(2597),
    [sym_biginteger_literal] = ACTIONS(2599),
    [anon_sym_if] = ACTIONS(2597),
    [anon_sym_IF] = ACTIONS(2597),
    [anon_sym_If] = ACTIONS(2597),
    [anon_sym_else] = ACTIONS(2597),
    [anon_sym_ELSE] = ACTIONS(2597),
    [anon_sym_Else] = ACTIONS(2597),
    [anon_sym_case] = ACTIONS(2597),
    [anon_sym_CASE] = ACTIONS(2597),
    [anon_sym_Case] = ACTIONS(2597),
    [anon_sym_for] = ACTIONS(2597),
    [anon_sym_FOR] = ACTIONS(2597),
    [anon_sym_For] = ACTIONS(2597),
    [anon_sym_foreach] = ACTIONS(2597),
    [anon_sym_FOREACH] = ACTIONS(2597),
    [anon_sym_Foreach] = ACTIONS(2597),
    [anon_sym_while] = ACTIONS(2597),
    [anon_sym_WHILE] = ACTIONS(2597),
    [anon_sym_While] = ACTIONS(2597),
    [anon_sym_repeat] = ACTIONS(2597),
    [anon_sym_REPEAT] = ACTIONS(2597),
    [anon_sym_Repeat] = ACTIONS(2597),
    [anon_sym_exit] = ACTIONS(2597),
    [anon_sym_EXIT] = ACTIONS(2597),
    [anon_sym_Exit] = ACTIONS(2597),
    [anon_sym_continue] = ACTIONS(2597),
    [anon_sym_CONTINUE] = ACTIONS(2597),
    [anon_sym_Continue] = ACTIONS(2597),
    [anon_sym_break] = ACTIONS(2597),
    [anon_sym_BREAK] = ACTIONS(2597),
    [anon_sym_Break] = ACTIONS(2597),
    [anon_sym_with] = ACTIONS(2597),
    [anon_sym_WITH] = ACTIONS(2597),
    [anon_sym_With] = ACTIONS(2597),
    [sym_asserterror_keyword] = ACTIONS(2599),
    [anon_sym_in] = ACTIONS(2597),
    [anon_sym_IN] = ACTIONS(2597),
    [anon_sym_In] = ACTIONS(2597),
    [sym_page_keyword] = ACTIONS(2597),
    [anon_sym_codeunit] = ACTIONS(2597),
    [anon_sym_CODEUNIT] = ACTIONS(2597),
    [anon_sym_Codeunit] = ACTIONS(2597),
    [anon_sym_CodeUnit] = ACTIONS(2597),
    [anon_sym_COdeunit] = ACTIONS(2597),
    [anon_sym_codeUnit] = ACTIONS(2597),
    [sym_report_keyword] = ACTIONS(2597),
    [sym_query_keyword] = ACTIONS(2597),
    [anon_sym_xmlport] = ACTIONS(2597),
    [anon_sym_XMLPORT] = ACTIONS(2597),
    [anon_sym_Xmlport] = ACTIONS(2597),
    [anon_sym_XMLport] = ACTIONS(2597),
    [anon_sym_XMLPort] = ACTIONS(2597),
    [anon_sym_XmlPort] = ACTIONS(2597),
    [anon_sym_enum] = ACTIONS(2597),
    [anon_sym_ENUM] = ACTIONS(2597),
    [anon_sym_Enum] = ACTIONS(2597),
    [anon_sym_eNUM] = ACTIONS(2597),
    [anon_sym_eNum] = ACTIONS(2597),
    [anon_sym_ENum] = ACTIONS(2597),
    [sym_quoted_identifier] = ACTIONS(2599),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2599),
    [sym_integer] = ACTIONS(2597),
    [sym_continue_as_identifier] = ACTIONS(2599),
    [sym_preproc_open] = ACTIONS(2599),
    [sym_preproc_close] = ACTIONS(2599),
  },
  [STATE(1023)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2585),
    [anon_sym_POUNDif] = ACTIONS(2587),
    [anon_sym_POUNDIF] = ACTIONS(2587),
    [anon_sym_POUNDIf] = ACTIONS(2587),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [anon_sym_POUNDelif] = ACTIONS(2587),
    [anon_sym_POUNDELIF] = ACTIONS(2587),
    [anon_sym_POUNDElif] = ACTIONS(2587),
    [anon_sym_POUNDelse] = ACTIONS(2587),
    [anon_sym_POUNDELSE] = ACTIONS(2587),
    [anon_sym_POUNDElse] = ACTIONS(2587),
    [anon_sym_POUNDendif] = ACTIONS(2587),
    [anon_sym_POUNDENDIF] = ACTIONS(2587),
    [anon_sym_POUNDEndif] = ACTIONS(2587),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_IF] = ACTIONS(2585),
    [anon_sym_If] = ACTIONS(2585),
    [anon_sym_else] = ACTIONS(2585),
    [anon_sym_ELSE] = ACTIONS(2585),
    [anon_sym_Else] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_CASE] = ACTIONS(2585),
    [anon_sym_Case] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_FOR] = ACTIONS(2585),
    [anon_sym_For] = ACTIONS(2585),
    [anon_sym_foreach] = ACTIONS(2585),
    [anon_sym_FOREACH] = ACTIONS(2585),
    [anon_sym_Foreach] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_WHILE] = ACTIONS(2585),
    [anon_sym_While] = ACTIONS(2585),
    [anon_sym_repeat] = ACTIONS(2585),
    [anon_sym_REPEAT] = ACTIONS(2585),
    [anon_sym_Repeat] = ACTIONS(2585),
    [anon_sym_exit] = ACTIONS(2585),
    [anon_sym_EXIT] = ACTIONS(2585),
    [anon_sym_Exit] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_CONTINUE] = ACTIONS(2585),
    [anon_sym_Continue] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_BREAK] = ACTIONS(2585),
    [anon_sym_Break] = ACTIONS(2585),
    [anon_sym_with] = ACTIONS(2585),
    [anon_sym_WITH] = ACTIONS(2585),
    [anon_sym_With] = ACTIONS(2585),
    [sym_asserterror_keyword] = ACTIONS(2587),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_open] = ACTIONS(2587),
    [sym_preproc_close] = ACTIONS(2587),
  },
  [STATE(1024)] = {
    [sym_identifier] = ACTIONS(2601),
    [anon_sym_SEMI] = ACTIONS(2603),
    [anon_sym_DOT] = ACTIONS(2601),
    [anon_sym_EQ] = ACTIONS(2603),
    [anon_sym_DASH] = ACTIONS(2601),
    [aux_sym_boolean_token1] = ACTIONS(2601),
    [aux_sym_boolean_token2] = ACTIONS(2601),
    [sym_decimal] = ACTIONS(2601),
    [anon_sym_LPAREN] = ACTIONS(2603),
    [anon_sym_DOT_DOT] = ACTIONS(2603),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2601),
    [anon_sym_STAR] = ACTIONS(2601),
    [anon_sym_LBRACK] = ACTIONS(2603),
    [aux_sym_record_type_token1] = ACTIONS(2601),
    [aux_sym_basic_type_token21] = ACTIONS(2601),
    [aux_sym_basic_type_token22] = ACTIONS(2601),
    [aux_sym_basic_type_token48] = ACTIONS(2601),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2601),
    [anon_sym_POUNDif] = ACTIONS(2603),
    [anon_sym_POUNDIF] = ACTIONS(2603),
    [anon_sym_POUNDIf] = ACTIONS(2603),
    [anon_sym_not] = ACTIONS(2601),
    [anon_sym_NOT] = ACTIONS(2601),
    [anon_sym_Not] = ACTIONS(2601),
    [anon_sym_POUNDelif] = ACTIONS(2603),
    [anon_sym_POUNDELIF] = ACTIONS(2603),
    [anon_sym_POUNDElif] = ACTIONS(2603),
    [anon_sym_POUNDelse] = ACTIONS(2603),
    [anon_sym_POUNDELSE] = ACTIONS(2603),
    [anon_sym_POUNDElse] = ACTIONS(2603),
    [anon_sym_POUNDendif] = ACTIONS(2603),
    [anon_sym_POUNDENDIF] = ACTIONS(2603),
    [anon_sym_POUNDEndif] = ACTIONS(2603),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2603),
    [aux_sym__expression_token1] = ACTIONS(2603),
    [aux_sym__expression_token2] = ACTIONS(2601),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2601),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2601),
    [anon_sym_SLASH] = ACTIONS(2601),
    [anon_sym_div] = ACTIONS(2601),
    [anon_sym_DIV] = ACTIONS(2601),
    [anon_sym_Div] = ACTIONS(2601),
    [anon_sym_mod] = ACTIONS(2601),
    [anon_sym_MOD] = ACTIONS(2601),
    [anon_sym_Mod] = ACTIONS(2601),
    [anon_sym_PLUS] = ACTIONS(2601),
    [anon_sym_GT_EQ] = ACTIONS(2603),
    [anon_sym_LT_EQ] = ACTIONS(2603),
    [anon_sym_GT] = ACTIONS(2601),
    [anon_sym_LT] = ACTIONS(2601),
    [anon_sym_LT_GT] = ACTIONS(2603),
    [anon_sym_and] = ACTIONS(2601),
    [anon_sym_AND] = ACTIONS(2601),
    [anon_sym_And] = ACTIONS(2601),
    [anon_sym_or] = ACTIONS(2601),
    [anon_sym_OR] = ACTIONS(2601),
    [anon_sym_Or] = ACTIONS(2601),
    [anon_sym_xor] = ACTIONS(2601),
    [anon_sym_XOR] = ACTIONS(2601),
    [anon_sym_Xor] = ACTIONS(2601),
    [anon_sym_QMARK] = ACTIONS(2603),
    [sym_datetime_literal] = ACTIONS(2603),
    [sym_date_literal] = ACTIONS(2601),
    [sym_time_literal] = ACTIONS(2601),
    [sym_biginteger_literal] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2601),
    [anon_sym_IF] = ACTIONS(2601),
    [anon_sym_If] = ACTIONS(2601),
    [anon_sym_else] = ACTIONS(2601),
    [anon_sym_ELSE] = ACTIONS(2601),
    [anon_sym_Else] = ACTIONS(2601),
    [anon_sym_case] = ACTIONS(2601),
    [anon_sym_CASE] = ACTIONS(2601),
    [anon_sym_Case] = ACTIONS(2601),
    [anon_sym_for] = ACTIONS(2601),
    [anon_sym_FOR] = ACTIONS(2601),
    [anon_sym_For] = ACTIONS(2601),
    [anon_sym_foreach] = ACTIONS(2601),
    [anon_sym_FOREACH] = ACTIONS(2601),
    [anon_sym_Foreach] = ACTIONS(2601),
    [anon_sym_while] = ACTIONS(2601),
    [anon_sym_WHILE] = ACTIONS(2601),
    [anon_sym_While] = ACTIONS(2601),
    [anon_sym_repeat] = ACTIONS(2601),
    [anon_sym_REPEAT] = ACTIONS(2601),
    [anon_sym_Repeat] = ACTIONS(2601),
    [anon_sym_exit] = ACTIONS(2601),
    [anon_sym_EXIT] = ACTIONS(2601),
    [anon_sym_Exit] = ACTIONS(2601),
    [anon_sym_continue] = ACTIONS(2601),
    [anon_sym_CONTINUE] = ACTIONS(2601),
    [anon_sym_Continue] = ACTIONS(2601),
    [anon_sym_break] = ACTIONS(2601),
    [anon_sym_BREAK] = ACTIONS(2601),
    [anon_sym_Break] = ACTIONS(2601),
    [anon_sym_with] = ACTIONS(2601),
    [anon_sym_WITH] = ACTIONS(2601),
    [anon_sym_With] = ACTIONS(2601),
    [sym_asserterror_keyword] = ACTIONS(2603),
    [anon_sym_in] = ACTIONS(2601),
    [anon_sym_IN] = ACTIONS(2601),
    [anon_sym_In] = ACTIONS(2601),
    [sym_page_keyword] = ACTIONS(2601),
    [anon_sym_codeunit] = ACTIONS(2601),
    [anon_sym_CODEUNIT] = ACTIONS(2601),
    [anon_sym_Codeunit] = ACTIONS(2601),
    [anon_sym_CodeUnit] = ACTIONS(2601),
    [anon_sym_COdeunit] = ACTIONS(2601),
    [anon_sym_codeUnit] = ACTIONS(2601),
    [sym_report_keyword] = ACTIONS(2601),
    [sym_query_keyword] = ACTIONS(2601),
    [anon_sym_xmlport] = ACTIONS(2601),
    [anon_sym_XMLPORT] = ACTIONS(2601),
    [anon_sym_Xmlport] = ACTIONS(2601),
    [anon_sym_XMLport] = ACTIONS(2601),
    [anon_sym_XMLPort] = ACTIONS(2601),
    [anon_sym_XmlPort] = ACTIONS(2601),
    [anon_sym_enum] = ACTIONS(2601),
    [anon_sym_ENUM] = ACTIONS(2601),
    [anon_sym_Enum] = ACTIONS(2601),
    [anon_sym_eNUM] = ACTIONS(2601),
    [anon_sym_eNum] = ACTIONS(2601),
    [anon_sym_ENum] = ACTIONS(2601),
    [sym_quoted_identifier] = ACTIONS(2603),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2603),
    [sym_integer] = ACTIONS(2601),
    [sym_continue_as_identifier] = ACTIONS(2603),
    [sym_preproc_open] = ACTIONS(2603),
    [sym_preproc_close] = ACTIONS(2603),
  },
  [STATE(1025)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_SEMI] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2593),
    [anon_sym_POUNDif] = ACTIONS(2595),
    [anon_sym_POUNDIF] = ACTIONS(2595),
    [anon_sym_POUNDIf] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [anon_sym_POUNDelif] = ACTIONS(2595),
    [anon_sym_POUNDELIF] = ACTIONS(2595),
    [anon_sym_POUNDElif] = ACTIONS(2595),
    [anon_sym_POUNDelse] = ACTIONS(2595),
    [anon_sym_POUNDELSE] = ACTIONS(2595),
    [anon_sym_POUNDElse] = ACTIONS(2595),
    [anon_sym_POUNDendif] = ACTIONS(2595),
    [anon_sym_POUNDENDIF] = ACTIONS(2595),
    [anon_sym_POUNDEndif] = ACTIONS(2595),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_if] = ACTIONS(2593),
    [anon_sym_IF] = ACTIONS(2593),
    [anon_sym_If] = ACTIONS(2593),
    [anon_sym_else] = ACTIONS(2593),
    [anon_sym_ELSE] = ACTIONS(2593),
    [anon_sym_Else] = ACTIONS(2593),
    [anon_sym_case] = ACTIONS(2593),
    [anon_sym_CASE] = ACTIONS(2593),
    [anon_sym_Case] = ACTIONS(2593),
    [anon_sym_for] = ACTIONS(2593),
    [anon_sym_FOR] = ACTIONS(2593),
    [anon_sym_For] = ACTIONS(2593),
    [anon_sym_foreach] = ACTIONS(2593),
    [anon_sym_FOREACH] = ACTIONS(2593),
    [anon_sym_Foreach] = ACTIONS(2593),
    [anon_sym_while] = ACTIONS(2593),
    [anon_sym_WHILE] = ACTIONS(2593),
    [anon_sym_While] = ACTIONS(2593),
    [anon_sym_repeat] = ACTIONS(2593),
    [anon_sym_REPEAT] = ACTIONS(2593),
    [anon_sym_Repeat] = ACTIONS(2593),
    [anon_sym_exit] = ACTIONS(2593),
    [anon_sym_EXIT] = ACTIONS(2593),
    [anon_sym_Exit] = ACTIONS(2593),
    [anon_sym_continue] = ACTIONS(2593),
    [anon_sym_CONTINUE] = ACTIONS(2593),
    [anon_sym_Continue] = ACTIONS(2593),
    [anon_sym_break] = ACTIONS(2593),
    [anon_sym_BREAK] = ACTIONS(2593),
    [anon_sym_Break] = ACTIONS(2593),
    [anon_sym_with] = ACTIONS(2593),
    [anon_sym_WITH] = ACTIONS(2593),
    [anon_sym_With] = ACTIONS(2593),
    [sym_asserterror_keyword] = ACTIONS(2595),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_open] = ACTIONS(2595),
    [sym_preproc_close] = ACTIONS(2595),
  },
  [STATE(1026)] = {
    [sym_identifier] = ACTIONS(2605),
    [anon_sym_SEMI] = ACTIONS(2607),
    [anon_sym_DOT] = ACTIONS(2605),
    [anon_sym_EQ] = ACTIONS(2607),
    [anon_sym_DASH] = ACTIONS(2605),
    [aux_sym_boolean_token1] = ACTIONS(2605),
    [aux_sym_boolean_token2] = ACTIONS(2605),
    [sym_decimal] = ACTIONS(2605),
    [anon_sym_LPAREN] = ACTIONS(2607),
    [anon_sym_DOT_DOT] = ACTIONS(2607),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2605),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_LBRACK] = ACTIONS(2607),
    [aux_sym_record_type_token1] = ACTIONS(2605),
    [aux_sym_basic_type_token21] = ACTIONS(2605),
    [aux_sym_basic_type_token22] = ACTIONS(2605),
    [aux_sym_basic_type_token48] = ACTIONS(2605),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2605),
    [anon_sym_POUNDif] = ACTIONS(2607),
    [anon_sym_POUNDIF] = ACTIONS(2607),
    [anon_sym_POUNDIf] = ACTIONS(2607),
    [anon_sym_not] = ACTIONS(2605),
    [anon_sym_NOT] = ACTIONS(2605),
    [anon_sym_Not] = ACTIONS(2605),
    [anon_sym_POUNDelif] = ACTIONS(2607),
    [anon_sym_POUNDELIF] = ACTIONS(2607),
    [anon_sym_POUNDElif] = ACTIONS(2607),
    [anon_sym_POUNDelse] = ACTIONS(2607),
    [anon_sym_POUNDELSE] = ACTIONS(2607),
    [anon_sym_POUNDElse] = ACTIONS(2607),
    [anon_sym_POUNDendif] = ACTIONS(2607),
    [anon_sym_POUNDENDIF] = ACTIONS(2607),
    [anon_sym_POUNDEndif] = ACTIONS(2607),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2607),
    [aux_sym__expression_token1] = ACTIONS(2607),
    [aux_sym__expression_token2] = ACTIONS(2605),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2605),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2605),
    [anon_sym_SLASH] = ACTIONS(2605),
    [anon_sym_div] = ACTIONS(2605),
    [anon_sym_DIV] = ACTIONS(2605),
    [anon_sym_Div] = ACTIONS(2605),
    [anon_sym_mod] = ACTIONS(2605),
    [anon_sym_MOD] = ACTIONS(2605),
    [anon_sym_Mod] = ACTIONS(2605),
    [anon_sym_PLUS] = ACTIONS(2605),
    [anon_sym_GT_EQ] = ACTIONS(2607),
    [anon_sym_LT_EQ] = ACTIONS(2607),
    [anon_sym_GT] = ACTIONS(2605),
    [anon_sym_LT] = ACTIONS(2605),
    [anon_sym_LT_GT] = ACTIONS(2607),
    [anon_sym_and] = ACTIONS(2605),
    [anon_sym_AND] = ACTIONS(2605),
    [anon_sym_And] = ACTIONS(2605),
    [anon_sym_or] = ACTIONS(2605),
    [anon_sym_OR] = ACTIONS(2605),
    [anon_sym_Or] = ACTIONS(2605),
    [anon_sym_xor] = ACTIONS(2605),
    [anon_sym_XOR] = ACTIONS(2605),
    [anon_sym_Xor] = ACTIONS(2605),
    [anon_sym_QMARK] = ACTIONS(2607),
    [sym_datetime_literal] = ACTIONS(2607),
    [sym_date_literal] = ACTIONS(2605),
    [sym_time_literal] = ACTIONS(2605),
    [sym_biginteger_literal] = ACTIONS(2607),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_IF] = ACTIONS(2605),
    [anon_sym_If] = ACTIONS(2605),
    [anon_sym_else] = ACTIONS(2605),
    [anon_sym_ELSE] = ACTIONS(2605),
    [anon_sym_Else] = ACTIONS(2605),
    [anon_sym_case] = ACTIONS(2605),
    [anon_sym_CASE] = ACTIONS(2605),
    [anon_sym_Case] = ACTIONS(2605),
    [anon_sym_for] = ACTIONS(2605),
    [anon_sym_FOR] = ACTIONS(2605),
    [anon_sym_For] = ACTIONS(2605),
    [anon_sym_foreach] = ACTIONS(2605),
    [anon_sym_FOREACH] = ACTIONS(2605),
    [anon_sym_Foreach] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(2605),
    [anon_sym_WHILE] = ACTIONS(2605),
    [anon_sym_While] = ACTIONS(2605),
    [anon_sym_repeat] = ACTIONS(2605),
    [anon_sym_REPEAT] = ACTIONS(2605),
    [anon_sym_Repeat] = ACTIONS(2605),
    [anon_sym_exit] = ACTIONS(2605),
    [anon_sym_EXIT] = ACTIONS(2605),
    [anon_sym_Exit] = ACTIONS(2605),
    [anon_sym_continue] = ACTIONS(2605),
    [anon_sym_CONTINUE] = ACTIONS(2605),
    [anon_sym_Continue] = ACTIONS(2605),
    [anon_sym_break] = ACTIONS(2605),
    [anon_sym_BREAK] = ACTIONS(2605),
    [anon_sym_Break] = ACTIONS(2605),
    [anon_sym_with] = ACTIONS(2605),
    [anon_sym_WITH] = ACTIONS(2605),
    [anon_sym_With] = ACTIONS(2605),
    [sym_asserterror_keyword] = ACTIONS(2607),
    [anon_sym_in] = ACTIONS(2605),
    [anon_sym_IN] = ACTIONS(2605),
    [anon_sym_In] = ACTIONS(2605),
    [sym_page_keyword] = ACTIONS(2605),
    [anon_sym_codeunit] = ACTIONS(2605),
    [anon_sym_CODEUNIT] = ACTIONS(2605),
    [anon_sym_Codeunit] = ACTIONS(2605),
    [anon_sym_CodeUnit] = ACTIONS(2605),
    [anon_sym_COdeunit] = ACTIONS(2605),
    [anon_sym_codeUnit] = ACTIONS(2605),
    [sym_report_keyword] = ACTIONS(2605),
    [sym_query_keyword] = ACTIONS(2605),
    [anon_sym_xmlport] = ACTIONS(2605),
    [anon_sym_XMLPORT] = ACTIONS(2605),
    [anon_sym_Xmlport] = ACTIONS(2605),
    [anon_sym_XMLport] = ACTIONS(2605),
    [anon_sym_XMLPort] = ACTIONS(2605),
    [anon_sym_XmlPort] = ACTIONS(2605),
    [anon_sym_enum] = ACTIONS(2605),
    [anon_sym_ENUM] = ACTIONS(2605),
    [anon_sym_Enum] = ACTIONS(2605),
    [anon_sym_eNUM] = ACTIONS(2605),
    [anon_sym_eNum] = ACTIONS(2605),
    [anon_sym_ENum] = ACTIONS(2605),
    [sym_quoted_identifier] = ACTIONS(2607),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2607),
    [sym_integer] = ACTIONS(2605),
    [sym_continue_as_identifier] = ACTIONS(2607),
    [sym_preproc_open] = ACTIONS(2607),
    [sym_preproc_close] = ACTIONS(2607),
  },
  [STATE(1027)] = {
    [sym_identifier] = ACTIONS(2609),
    [anon_sym_SEMI] = ACTIONS(2611),
    [anon_sym_DOT] = ACTIONS(2609),
    [anon_sym_EQ] = ACTIONS(2611),
    [anon_sym_DASH] = ACTIONS(2609),
    [aux_sym_boolean_token1] = ACTIONS(2609),
    [aux_sym_boolean_token2] = ACTIONS(2609),
    [sym_decimal] = ACTIONS(2609),
    [anon_sym_LPAREN] = ACTIONS(2611),
    [anon_sym_DOT_DOT] = ACTIONS(2611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2609),
    [anon_sym_STAR] = ACTIONS(2609),
    [anon_sym_LBRACK] = ACTIONS(2611),
    [aux_sym_record_type_token1] = ACTIONS(2609),
    [aux_sym_basic_type_token21] = ACTIONS(2609),
    [aux_sym_basic_type_token22] = ACTIONS(2609),
    [aux_sym_basic_type_token48] = ACTIONS(2609),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2609),
    [anon_sym_POUNDif] = ACTIONS(2611),
    [anon_sym_POUNDIF] = ACTIONS(2611),
    [anon_sym_POUNDIf] = ACTIONS(2611),
    [anon_sym_not] = ACTIONS(2609),
    [anon_sym_NOT] = ACTIONS(2609),
    [anon_sym_Not] = ACTIONS(2609),
    [anon_sym_POUNDelif] = ACTIONS(2611),
    [anon_sym_POUNDELIF] = ACTIONS(2611),
    [anon_sym_POUNDElif] = ACTIONS(2611),
    [anon_sym_POUNDelse] = ACTIONS(2611),
    [anon_sym_POUNDELSE] = ACTIONS(2611),
    [anon_sym_POUNDElse] = ACTIONS(2611),
    [anon_sym_POUNDendif] = ACTIONS(2611),
    [anon_sym_POUNDENDIF] = ACTIONS(2611),
    [anon_sym_POUNDEndif] = ACTIONS(2611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2611),
    [aux_sym__expression_token1] = ACTIONS(2611),
    [aux_sym__expression_token2] = ACTIONS(2609),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2609),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2609),
    [anon_sym_SLASH] = ACTIONS(2609),
    [anon_sym_div] = ACTIONS(2609),
    [anon_sym_DIV] = ACTIONS(2609),
    [anon_sym_Div] = ACTIONS(2609),
    [anon_sym_mod] = ACTIONS(2609),
    [anon_sym_MOD] = ACTIONS(2609),
    [anon_sym_Mod] = ACTIONS(2609),
    [anon_sym_PLUS] = ACTIONS(2609),
    [anon_sym_GT_EQ] = ACTIONS(2611),
    [anon_sym_LT_EQ] = ACTIONS(2611),
    [anon_sym_GT] = ACTIONS(2609),
    [anon_sym_LT] = ACTIONS(2609),
    [anon_sym_LT_GT] = ACTIONS(2611),
    [anon_sym_and] = ACTIONS(2609),
    [anon_sym_AND] = ACTIONS(2609),
    [anon_sym_And] = ACTIONS(2609),
    [anon_sym_or] = ACTIONS(2609),
    [anon_sym_OR] = ACTIONS(2609),
    [anon_sym_Or] = ACTIONS(2609),
    [anon_sym_xor] = ACTIONS(2609),
    [anon_sym_XOR] = ACTIONS(2609),
    [anon_sym_Xor] = ACTIONS(2609),
    [anon_sym_QMARK] = ACTIONS(2611),
    [sym_datetime_literal] = ACTIONS(2611),
    [sym_date_literal] = ACTIONS(2609),
    [sym_time_literal] = ACTIONS(2609),
    [sym_biginteger_literal] = ACTIONS(2611),
    [anon_sym_if] = ACTIONS(2609),
    [anon_sym_IF] = ACTIONS(2609),
    [anon_sym_If] = ACTIONS(2609),
    [anon_sym_else] = ACTIONS(2609),
    [anon_sym_ELSE] = ACTIONS(2609),
    [anon_sym_Else] = ACTIONS(2609),
    [anon_sym_case] = ACTIONS(2609),
    [anon_sym_CASE] = ACTIONS(2609),
    [anon_sym_Case] = ACTIONS(2609),
    [anon_sym_for] = ACTIONS(2609),
    [anon_sym_FOR] = ACTIONS(2609),
    [anon_sym_For] = ACTIONS(2609),
    [anon_sym_foreach] = ACTIONS(2609),
    [anon_sym_FOREACH] = ACTIONS(2609),
    [anon_sym_Foreach] = ACTIONS(2609),
    [anon_sym_while] = ACTIONS(2609),
    [anon_sym_WHILE] = ACTIONS(2609),
    [anon_sym_While] = ACTIONS(2609),
    [anon_sym_repeat] = ACTIONS(2609),
    [anon_sym_REPEAT] = ACTIONS(2609),
    [anon_sym_Repeat] = ACTIONS(2609),
    [anon_sym_exit] = ACTIONS(2609),
    [anon_sym_EXIT] = ACTIONS(2609),
    [anon_sym_Exit] = ACTIONS(2609),
    [anon_sym_continue] = ACTIONS(2609),
    [anon_sym_CONTINUE] = ACTIONS(2609),
    [anon_sym_Continue] = ACTIONS(2609),
    [anon_sym_break] = ACTIONS(2609),
    [anon_sym_BREAK] = ACTIONS(2609),
    [anon_sym_Break] = ACTIONS(2609),
    [anon_sym_with] = ACTIONS(2609),
    [anon_sym_WITH] = ACTIONS(2609),
    [anon_sym_With] = ACTIONS(2609),
    [sym_asserterror_keyword] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(2609),
    [anon_sym_IN] = ACTIONS(2609),
    [anon_sym_In] = ACTIONS(2609),
    [sym_page_keyword] = ACTIONS(2609),
    [anon_sym_codeunit] = ACTIONS(2609),
    [anon_sym_CODEUNIT] = ACTIONS(2609),
    [anon_sym_Codeunit] = ACTIONS(2609),
    [anon_sym_CodeUnit] = ACTIONS(2609),
    [anon_sym_COdeunit] = ACTIONS(2609),
    [anon_sym_codeUnit] = ACTIONS(2609),
    [sym_report_keyword] = ACTIONS(2609),
    [sym_query_keyword] = ACTIONS(2609),
    [anon_sym_xmlport] = ACTIONS(2609),
    [anon_sym_XMLPORT] = ACTIONS(2609),
    [anon_sym_Xmlport] = ACTIONS(2609),
    [anon_sym_XMLport] = ACTIONS(2609),
    [anon_sym_XMLPort] = ACTIONS(2609),
    [anon_sym_XmlPort] = ACTIONS(2609),
    [anon_sym_enum] = ACTIONS(2609),
    [anon_sym_ENUM] = ACTIONS(2609),
    [anon_sym_Enum] = ACTIONS(2609),
    [anon_sym_eNUM] = ACTIONS(2609),
    [anon_sym_eNum] = ACTIONS(2609),
    [anon_sym_ENum] = ACTIONS(2609),
    [sym_quoted_identifier] = ACTIONS(2611),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2611),
    [sym_integer] = ACTIONS(2609),
    [sym_continue_as_identifier] = ACTIONS(2611),
    [sym_preproc_open] = ACTIONS(2611),
    [sym_preproc_close] = ACTIONS(2611),
  },
  [STATE(1028)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2585),
    [anon_sym_POUNDif] = ACTIONS(2587),
    [anon_sym_POUNDIF] = ACTIONS(2587),
    [anon_sym_POUNDIf] = ACTIONS(2587),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [anon_sym_POUNDelif] = ACTIONS(2587),
    [anon_sym_POUNDELIF] = ACTIONS(2587),
    [anon_sym_POUNDElif] = ACTIONS(2587),
    [anon_sym_POUNDelse] = ACTIONS(2587),
    [anon_sym_POUNDELSE] = ACTIONS(2587),
    [anon_sym_POUNDElse] = ACTIONS(2587),
    [anon_sym_POUNDendif] = ACTIONS(2587),
    [anon_sym_POUNDENDIF] = ACTIONS(2587),
    [anon_sym_POUNDEndif] = ACTIONS(2587),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_IF] = ACTIONS(2585),
    [anon_sym_If] = ACTIONS(2585),
    [anon_sym_else] = ACTIONS(2585),
    [anon_sym_ELSE] = ACTIONS(2585),
    [anon_sym_Else] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_CASE] = ACTIONS(2585),
    [anon_sym_Case] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_FOR] = ACTIONS(2585),
    [anon_sym_For] = ACTIONS(2585),
    [anon_sym_foreach] = ACTIONS(2585),
    [anon_sym_FOREACH] = ACTIONS(2585),
    [anon_sym_Foreach] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_WHILE] = ACTIONS(2585),
    [anon_sym_While] = ACTIONS(2585),
    [anon_sym_repeat] = ACTIONS(2585),
    [anon_sym_REPEAT] = ACTIONS(2585),
    [anon_sym_Repeat] = ACTIONS(2585),
    [anon_sym_exit] = ACTIONS(2585),
    [anon_sym_EXIT] = ACTIONS(2585),
    [anon_sym_Exit] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_CONTINUE] = ACTIONS(2585),
    [anon_sym_Continue] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_BREAK] = ACTIONS(2585),
    [anon_sym_Break] = ACTIONS(2585),
    [anon_sym_with] = ACTIONS(2585),
    [anon_sym_WITH] = ACTIONS(2585),
    [anon_sym_With] = ACTIONS(2585),
    [sym_asserterror_keyword] = ACTIONS(2587),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_open] = ACTIONS(2587),
    [sym_preproc_close] = ACTIONS(2587),
  },
  [STATE(1029)] = {
    [sym_identifier] = ACTIONS(2613),
    [anon_sym_SEMI] = ACTIONS(2615),
    [anon_sym_DOT] = ACTIONS(2613),
    [anon_sym_EQ] = ACTIONS(2615),
    [anon_sym_DASH] = ACTIONS(2613),
    [aux_sym_boolean_token1] = ACTIONS(2613),
    [aux_sym_boolean_token2] = ACTIONS(2613),
    [sym_decimal] = ACTIONS(2613),
    [anon_sym_LPAREN] = ACTIONS(2615),
    [anon_sym_DOT_DOT] = ACTIONS(2615),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2613),
    [anon_sym_STAR] = ACTIONS(2613),
    [anon_sym_LBRACK] = ACTIONS(2617),
    [aux_sym_record_type_token1] = ACTIONS(2613),
    [aux_sym_basic_type_token21] = ACTIONS(2613),
    [aux_sym_basic_type_token22] = ACTIONS(2613),
    [aux_sym_basic_type_token48] = ACTIONS(2613),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2613),
    [anon_sym_POUNDif] = ACTIONS(2615),
    [anon_sym_POUNDIF] = ACTIONS(2615),
    [anon_sym_POUNDIf] = ACTIONS(2615),
    [anon_sym_not] = ACTIONS(2613),
    [anon_sym_NOT] = ACTIONS(2613),
    [anon_sym_Not] = ACTIONS(2613),
    [anon_sym_POUNDelif] = ACTIONS(2615),
    [anon_sym_POUNDELIF] = ACTIONS(2615),
    [anon_sym_POUNDElif] = ACTIONS(2615),
    [anon_sym_POUNDelse] = ACTIONS(2615),
    [anon_sym_POUNDELSE] = ACTIONS(2615),
    [anon_sym_POUNDElse] = ACTIONS(2615),
    [anon_sym_POUNDendif] = ACTIONS(2615),
    [anon_sym_POUNDENDIF] = ACTIONS(2615),
    [anon_sym_POUNDEndif] = ACTIONS(2615),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2615),
    [aux_sym__expression_token1] = ACTIONS(2615),
    [aux_sym__expression_token2] = ACTIONS(2613),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2613),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2613),
    [anon_sym_SLASH] = ACTIONS(2613),
    [anon_sym_div] = ACTIONS(2613),
    [anon_sym_DIV] = ACTIONS(2613),
    [anon_sym_Div] = ACTIONS(2613),
    [anon_sym_mod] = ACTIONS(2613),
    [anon_sym_MOD] = ACTIONS(2613),
    [anon_sym_Mod] = ACTIONS(2613),
    [anon_sym_PLUS] = ACTIONS(2613),
    [anon_sym_GT_EQ] = ACTIONS(2615),
    [anon_sym_LT_EQ] = ACTIONS(2615),
    [anon_sym_GT] = ACTIONS(2613),
    [anon_sym_LT] = ACTIONS(2613),
    [anon_sym_LT_GT] = ACTIONS(2615),
    [anon_sym_and] = ACTIONS(2613),
    [anon_sym_AND] = ACTIONS(2613),
    [anon_sym_And] = ACTIONS(2613),
    [anon_sym_or] = ACTIONS(2613),
    [anon_sym_OR] = ACTIONS(2613),
    [anon_sym_Or] = ACTIONS(2613),
    [anon_sym_xor] = ACTIONS(2613),
    [anon_sym_XOR] = ACTIONS(2613),
    [anon_sym_Xor] = ACTIONS(2613),
    [anon_sym_QMARK] = ACTIONS(2615),
    [sym_datetime_literal] = ACTIONS(2615),
    [sym_date_literal] = ACTIONS(2613),
    [sym_time_literal] = ACTIONS(2613),
    [sym_biginteger_literal] = ACTIONS(2615),
    [anon_sym_if] = ACTIONS(2613),
    [anon_sym_IF] = ACTIONS(2613),
    [anon_sym_If] = ACTIONS(2613),
    [anon_sym_else] = ACTIONS(2613),
    [anon_sym_ELSE] = ACTIONS(2613),
    [anon_sym_Else] = ACTIONS(2613),
    [anon_sym_case] = ACTIONS(2613),
    [anon_sym_CASE] = ACTIONS(2613),
    [anon_sym_Case] = ACTIONS(2613),
    [anon_sym_for] = ACTIONS(2613),
    [anon_sym_FOR] = ACTIONS(2613),
    [anon_sym_For] = ACTIONS(2613),
    [anon_sym_foreach] = ACTIONS(2613),
    [anon_sym_FOREACH] = ACTIONS(2613),
    [anon_sym_Foreach] = ACTIONS(2613),
    [anon_sym_while] = ACTIONS(2613),
    [anon_sym_WHILE] = ACTIONS(2613),
    [anon_sym_While] = ACTIONS(2613),
    [anon_sym_repeat] = ACTIONS(2613),
    [anon_sym_REPEAT] = ACTIONS(2613),
    [anon_sym_Repeat] = ACTIONS(2613),
    [anon_sym_exit] = ACTIONS(2613),
    [anon_sym_EXIT] = ACTIONS(2613),
    [anon_sym_Exit] = ACTIONS(2613),
    [anon_sym_continue] = ACTIONS(2613),
    [anon_sym_CONTINUE] = ACTIONS(2613),
    [anon_sym_Continue] = ACTIONS(2613),
    [anon_sym_break] = ACTIONS(2613),
    [anon_sym_BREAK] = ACTIONS(2613),
    [anon_sym_Break] = ACTIONS(2613),
    [anon_sym_with] = ACTIONS(2613),
    [anon_sym_WITH] = ACTIONS(2613),
    [anon_sym_With] = ACTIONS(2613),
    [sym_asserterror_keyword] = ACTIONS(2615),
    [anon_sym_in] = ACTIONS(2613),
    [anon_sym_IN] = ACTIONS(2613),
    [anon_sym_In] = ACTIONS(2613),
    [sym_page_keyword] = ACTIONS(2613),
    [anon_sym_codeunit] = ACTIONS(2613),
    [anon_sym_CODEUNIT] = ACTIONS(2613),
    [anon_sym_Codeunit] = ACTIONS(2613),
    [anon_sym_CodeUnit] = ACTIONS(2613),
    [anon_sym_COdeunit] = ACTIONS(2613),
    [anon_sym_codeUnit] = ACTIONS(2613),
    [sym_report_keyword] = ACTIONS(2613),
    [sym_query_keyword] = ACTIONS(2613),
    [anon_sym_xmlport] = ACTIONS(2613),
    [anon_sym_XMLPORT] = ACTIONS(2613),
    [anon_sym_Xmlport] = ACTIONS(2613),
    [anon_sym_XMLport] = ACTIONS(2613),
    [anon_sym_XMLPort] = ACTIONS(2613),
    [anon_sym_XmlPort] = ACTIONS(2613),
    [anon_sym_enum] = ACTIONS(2613),
    [anon_sym_ENUM] = ACTIONS(2613),
    [anon_sym_Enum] = ACTIONS(2613),
    [anon_sym_eNUM] = ACTIONS(2613),
    [anon_sym_eNum] = ACTIONS(2613),
    [anon_sym_ENum] = ACTIONS(2613),
    [sym_quoted_identifier] = ACTIONS(2615),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2615),
    [sym_integer] = ACTIONS(2613),
    [sym_continue_as_identifier] = ACTIONS(2615),
    [sym_preproc_open] = ACTIONS(2615),
    [sym_preproc_close] = ACTIONS(2615),
  },
  [STATE(1030)] = {
    [sym_identifier] = ACTIONS(2619),
    [anon_sym_SEMI] = ACTIONS(2621),
    [anon_sym_DOT] = ACTIONS(2619),
    [anon_sym_EQ] = ACTIONS(2621),
    [anon_sym_DASH] = ACTIONS(2619),
    [aux_sym_boolean_token1] = ACTIONS(2619),
    [aux_sym_boolean_token2] = ACTIONS(2619),
    [sym_decimal] = ACTIONS(2619),
    [anon_sym_LPAREN] = ACTIONS(2621),
    [anon_sym_DOT_DOT] = ACTIONS(2621),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2619),
    [anon_sym_STAR] = ACTIONS(2619),
    [anon_sym_LBRACK] = ACTIONS(2623),
    [aux_sym_record_type_token1] = ACTIONS(2619),
    [aux_sym_basic_type_token21] = ACTIONS(2619),
    [aux_sym_basic_type_token22] = ACTIONS(2619),
    [aux_sym_basic_type_token48] = ACTIONS(2619),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2619),
    [anon_sym_POUNDif] = ACTIONS(2621),
    [anon_sym_POUNDIF] = ACTIONS(2621),
    [anon_sym_POUNDIf] = ACTIONS(2621),
    [anon_sym_not] = ACTIONS(2619),
    [anon_sym_NOT] = ACTIONS(2619),
    [anon_sym_Not] = ACTIONS(2619),
    [anon_sym_POUNDelif] = ACTIONS(2621),
    [anon_sym_POUNDELIF] = ACTIONS(2621),
    [anon_sym_POUNDElif] = ACTIONS(2621),
    [anon_sym_POUNDelse] = ACTIONS(2621),
    [anon_sym_POUNDELSE] = ACTIONS(2621),
    [anon_sym_POUNDElse] = ACTIONS(2621),
    [anon_sym_POUNDendif] = ACTIONS(2621),
    [anon_sym_POUNDENDIF] = ACTIONS(2621),
    [anon_sym_POUNDEndif] = ACTIONS(2621),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2621),
    [aux_sym__expression_token1] = ACTIONS(2621),
    [aux_sym__expression_token2] = ACTIONS(2619),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2619),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2619),
    [anon_sym_SLASH] = ACTIONS(2619),
    [anon_sym_div] = ACTIONS(2619),
    [anon_sym_DIV] = ACTIONS(2619),
    [anon_sym_Div] = ACTIONS(2619),
    [anon_sym_mod] = ACTIONS(2619),
    [anon_sym_MOD] = ACTIONS(2619),
    [anon_sym_Mod] = ACTIONS(2619),
    [anon_sym_PLUS] = ACTIONS(2619),
    [anon_sym_GT_EQ] = ACTIONS(2621),
    [anon_sym_LT_EQ] = ACTIONS(2621),
    [anon_sym_GT] = ACTIONS(2619),
    [anon_sym_LT] = ACTIONS(2619),
    [anon_sym_LT_GT] = ACTIONS(2621),
    [anon_sym_and] = ACTIONS(2619),
    [anon_sym_AND] = ACTIONS(2619),
    [anon_sym_And] = ACTIONS(2619),
    [anon_sym_or] = ACTIONS(2619),
    [anon_sym_OR] = ACTIONS(2619),
    [anon_sym_Or] = ACTIONS(2619),
    [anon_sym_xor] = ACTIONS(2619),
    [anon_sym_XOR] = ACTIONS(2619),
    [anon_sym_Xor] = ACTIONS(2619),
    [anon_sym_QMARK] = ACTIONS(2621),
    [sym_datetime_literal] = ACTIONS(2621),
    [sym_date_literal] = ACTIONS(2619),
    [sym_time_literal] = ACTIONS(2619),
    [sym_biginteger_literal] = ACTIONS(2621),
    [anon_sym_if] = ACTIONS(2619),
    [anon_sym_IF] = ACTIONS(2619),
    [anon_sym_If] = ACTIONS(2619),
    [anon_sym_else] = ACTIONS(2619),
    [anon_sym_ELSE] = ACTIONS(2619),
    [anon_sym_Else] = ACTIONS(2619),
    [anon_sym_case] = ACTIONS(2619),
    [anon_sym_CASE] = ACTIONS(2619),
    [anon_sym_Case] = ACTIONS(2619),
    [anon_sym_for] = ACTIONS(2619),
    [anon_sym_FOR] = ACTIONS(2619),
    [anon_sym_For] = ACTIONS(2619),
    [anon_sym_foreach] = ACTIONS(2619),
    [anon_sym_FOREACH] = ACTIONS(2619),
    [anon_sym_Foreach] = ACTIONS(2619),
    [anon_sym_while] = ACTIONS(2619),
    [anon_sym_WHILE] = ACTIONS(2619),
    [anon_sym_While] = ACTIONS(2619),
    [anon_sym_repeat] = ACTIONS(2619),
    [anon_sym_REPEAT] = ACTIONS(2619),
    [anon_sym_Repeat] = ACTIONS(2619),
    [anon_sym_exit] = ACTIONS(2619),
    [anon_sym_EXIT] = ACTIONS(2619),
    [anon_sym_Exit] = ACTIONS(2619),
    [anon_sym_continue] = ACTIONS(2619),
    [anon_sym_CONTINUE] = ACTIONS(2619),
    [anon_sym_Continue] = ACTIONS(2619),
    [anon_sym_break] = ACTIONS(2619),
    [anon_sym_BREAK] = ACTIONS(2619),
    [anon_sym_Break] = ACTIONS(2619),
    [anon_sym_with] = ACTIONS(2619),
    [anon_sym_WITH] = ACTIONS(2619),
    [anon_sym_With] = ACTIONS(2619),
    [sym_asserterror_keyword] = ACTIONS(2621),
    [anon_sym_in] = ACTIONS(2619),
    [anon_sym_IN] = ACTIONS(2619),
    [anon_sym_In] = ACTIONS(2619),
    [sym_page_keyword] = ACTIONS(2619),
    [anon_sym_codeunit] = ACTIONS(2619),
    [anon_sym_CODEUNIT] = ACTIONS(2619),
    [anon_sym_Codeunit] = ACTIONS(2619),
    [anon_sym_CodeUnit] = ACTIONS(2619),
    [anon_sym_COdeunit] = ACTIONS(2619),
    [anon_sym_codeUnit] = ACTIONS(2619),
    [sym_report_keyword] = ACTIONS(2619),
    [sym_query_keyword] = ACTIONS(2619),
    [anon_sym_xmlport] = ACTIONS(2619),
    [anon_sym_XMLPORT] = ACTIONS(2619),
    [anon_sym_Xmlport] = ACTIONS(2619),
    [anon_sym_XMLport] = ACTIONS(2619),
    [anon_sym_XMLPort] = ACTIONS(2619),
    [anon_sym_XmlPort] = ACTIONS(2619),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_ENUM] = ACTIONS(2619),
    [anon_sym_Enum] = ACTIONS(2619),
    [anon_sym_eNUM] = ACTIONS(2619),
    [anon_sym_eNum] = ACTIONS(2619),
    [anon_sym_ENum] = ACTIONS(2619),
    [sym_quoted_identifier] = ACTIONS(2621),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2621),
    [sym_integer] = ACTIONS(2619),
    [sym_continue_as_identifier] = ACTIONS(2621),
    [sym_preproc_open] = ACTIONS(2621),
    [sym_preproc_close] = ACTIONS(2621),
  },
  [STATE(1031)] = {
    [sym_identifier] = ACTIONS(2625),
    [anon_sym_SEMI] = ACTIONS(2627),
    [anon_sym_DOT] = ACTIONS(2625),
    [anon_sym_EQ] = ACTIONS(2627),
    [anon_sym_DASH] = ACTIONS(2625),
    [aux_sym_boolean_token1] = ACTIONS(2625),
    [aux_sym_boolean_token2] = ACTIONS(2625),
    [sym_decimal] = ACTIONS(2625),
    [anon_sym_LPAREN] = ACTIONS(2627),
    [anon_sym_DOT_DOT] = ACTIONS(2627),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2625),
    [anon_sym_STAR] = ACTIONS(2625),
    [anon_sym_LBRACK] = ACTIONS(2627),
    [aux_sym_record_type_token1] = ACTIONS(2625),
    [aux_sym_basic_type_token21] = ACTIONS(2625),
    [aux_sym_basic_type_token22] = ACTIONS(2625),
    [aux_sym_basic_type_token48] = ACTIONS(2625),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2625),
    [anon_sym_POUNDif] = ACTIONS(2627),
    [anon_sym_POUNDIF] = ACTIONS(2627),
    [anon_sym_POUNDIf] = ACTIONS(2627),
    [anon_sym_not] = ACTIONS(2625),
    [anon_sym_NOT] = ACTIONS(2625),
    [anon_sym_Not] = ACTIONS(2625),
    [anon_sym_POUNDelif] = ACTIONS(2627),
    [anon_sym_POUNDELIF] = ACTIONS(2627),
    [anon_sym_POUNDElif] = ACTIONS(2627),
    [anon_sym_POUNDelse] = ACTIONS(2627),
    [anon_sym_POUNDELSE] = ACTIONS(2627),
    [anon_sym_POUNDElse] = ACTIONS(2627),
    [anon_sym_POUNDendif] = ACTIONS(2627),
    [anon_sym_POUNDENDIF] = ACTIONS(2627),
    [anon_sym_POUNDEndif] = ACTIONS(2627),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2627),
    [aux_sym__expression_token1] = ACTIONS(2627),
    [aux_sym__expression_token2] = ACTIONS(2625),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2625),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2625),
    [anon_sym_SLASH] = ACTIONS(2625),
    [anon_sym_div] = ACTIONS(2625),
    [anon_sym_DIV] = ACTIONS(2625),
    [anon_sym_Div] = ACTIONS(2625),
    [anon_sym_mod] = ACTIONS(2625),
    [anon_sym_MOD] = ACTIONS(2625),
    [anon_sym_Mod] = ACTIONS(2625),
    [anon_sym_PLUS] = ACTIONS(2625),
    [anon_sym_GT_EQ] = ACTIONS(2627),
    [anon_sym_LT_EQ] = ACTIONS(2627),
    [anon_sym_GT] = ACTIONS(2625),
    [anon_sym_LT] = ACTIONS(2625),
    [anon_sym_LT_GT] = ACTIONS(2627),
    [anon_sym_and] = ACTIONS(2625),
    [anon_sym_AND] = ACTIONS(2625),
    [anon_sym_And] = ACTIONS(2625),
    [anon_sym_or] = ACTIONS(2625),
    [anon_sym_OR] = ACTIONS(2625),
    [anon_sym_Or] = ACTIONS(2625),
    [anon_sym_xor] = ACTIONS(2625),
    [anon_sym_XOR] = ACTIONS(2625),
    [anon_sym_Xor] = ACTIONS(2625),
    [anon_sym_QMARK] = ACTIONS(2627),
    [sym_datetime_literal] = ACTIONS(2627),
    [sym_date_literal] = ACTIONS(2625),
    [sym_time_literal] = ACTIONS(2625),
    [sym_biginteger_literal] = ACTIONS(2627),
    [anon_sym_if] = ACTIONS(2625),
    [anon_sym_IF] = ACTIONS(2625),
    [anon_sym_If] = ACTIONS(2625),
    [anon_sym_else] = ACTIONS(2625),
    [anon_sym_ELSE] = ACTIONS(2625),
    [anon_sym_Else] = ACTIONS(2625),
    [anon_sym_case] = ACTIONS(2625),
    [anon_sym_CASE] = ACTIONS(2625),
    [anon_sym_Case] = ACTIONS(2625),
    [anon_sym_for] = ACTIONS(2625),
    [anon_sym_FOR] = ACTIONS(2625),
    [anon_sym_For] = ACTIONS(2625),
    [anon_sym_foreach] = ACTIONS(2625),
    [anon_sym_FOREACH] = ACTIONS(2625),
    [anon_sym_Foreach] = ACTIONS(2625),
    [anon_sym_while] = ACTIONS(2625),
    [anon_sym_WHILE] = ACTIONS(2625),
    [anon_sym_While] = ACTIONS(2625),
    [anon_sym_repeat] = ACTIONS(2625),
    [anon_sym_REPEAT] = ACTIONS(2625),
    [anon_sym_Repeat] = ACTIONS(2625),
    [anon_sym_exit] = ACTIONS(2625),
    [anon_sym_EXIT] = ACTIONS(2625),
    [anon_sym_Exit] = ACTIONS(2625),
    [anon_sym_continue] = ACTIONS(2625),
    [anon_sym_CONTINUE] = ACTIONS(2625),
    [anon_sym_Continue] = ACTIONS(2625),
    [anon_sym_break] = ACTIONS(2625),
    [anon_sym_BREAK] = ACTIONS(2625),
    [anon_sym_Break] = ACTIONS(2625),
    [anon_sym_with] = ACTIONS(2625),
    [anon_sym_WITH] = ACTIONS(2625),
    [anon_sym_With] = ACTIONS(2625),
    [sym_asserterror_keyword] = ACTIONS(2627),
    [anon_sym_in] = ACTIONS(2625),
    [anon_sym_IN] = ACTIONS(2625),
    [anon_sym_In] = ACTIONS(2625),
    [sym_page_keyword] = ACTIONS(2625),
    [anon_sym_codeunit] = ACTIONS(2625),
    [anon_sym_CODEUNIT] = ACTIONS(2625),
    [anon_sym_Codeunit] = ACTIONS(2625),
    [anon_sym_CodeUnit] = ACTIONS(2625),
    [anon_sym_COdeunit] = ACTIONS(2625),
    [anon_sym_codeUnit] = ACTIONS(2625),
    [sym_report_keyword] = ACTIONS(2625),
    [sym_query_keyword] = ACTIONS(2625),
    [anon_sym_xmlport] = ACTIONS(2625),
    [anon_sym_XMLPORT] = ACTIONS(2625),
    [anon_sym_Xmlport] = ACTIONS(2625),
    [anon_sym_XMLport] = ACTIONS(2625),
    [anon_sym_XMLPort] = ACTIONS(2625),
    [anon_sym_XmlPort] = ACTIONS(2625),
    [anon_sym_enum] = ACTIONS(2625),
    [anon_sym_ENUM] = ACTIONS(2625),
    [anon_sym_Enum] = ACTIONS(2625),
    [anon_sym_eNUM] = ACTIONS(2625),
    [anon_sym_eNum] = ACTIONS(2625),
    [anon_sym_ENum] = ACTIONS(2625),
    [sym_quoted_identifier] = ACTIONS(2627),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2627),
    [sym_integer] = ACTIONS(2625),
    [sym_continue_as_identifier] = ACTIONS(2627),
    [sym_preproc_open] = ACTIONS(2627),
    [sym_preproc_close] = ACTIONS(2627),
  },
  [STATE(1032)] = {
    [sym_identifier] = ACTIONS(2629),
    [anon_sym_SEMI] = ACTIONS(2631),
    [anon_sym_DOT] = ACTIONS(2629),
    [anon_sym_EQ] = ACTIONS(2631),
    [anon_sym_DASH] = ACTIONS(2629),
    [aux_sym_boolean_token1] = ACTIONS(2629),
    [aux_sym_boolean_token2] = ACTIONS(2629),
    [sym_decimal] = ACTIONS(2629),
    [anon_sym_LPAREN] = ACTIONS(2631),
    [anon_sym_DOT_DOT] = ACTIONS(2631),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2629),
    [anon_sym_STAR] = ACTIONS(2629),
    [anon_sym_LBRACK] = ACTIONS(2631),
    [aux_sym_record_type_token1] = ACTIONS(2629),
    [aux_sym_basic_type_token21] = ACTIONS(2629),
    [aux_sym_basic_type_token22] = ACTIONS(2629),
    [aux_sym_basic_type_token48] = ACTIONS(2629),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2629),
    [anon_sym_POUNDif] = ACTIONS(2631),
    [anon_sym_POUNDIF] = ACTIONS(2631),
    [anon_sym_POUNDIf] = ACTIONS(2631),
    [anon_sym_not] = ACTIONS(2629),
    [anon_sym_NOT] = ACTIONS(2629),
    [anon_sym_Not] = ACTIONS(2629),
    [anon_sym_POUNDelif] = ACTIONS(2631),
    [anon_sym_POUNDELIF] = ACTIONS(2631),
    [anon_sym_POUNDElif] = ACTIONS(2631),
    [anon_sym_POUNDelse] = ACTIONS(2631),
    [anon_sym_POUNDELSE] = ACTIONS(2631),
    [anon_sym_POUNDElse] = ACTIONS(2631),
    [anon_sym_POUNDendif] = ACTIONS(2631),
    [anon_sym_POUNDENDIF] = ACTIONS(2631),
    [anon_sym_POUNDEndif] = ACTIONS(2631),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2631),
    [aux_sym__expression_token1] = ACTIONS(2631),
    [aux_sym__expression_token2] = ACTIONS(2629),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2629),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2629),
    [anon_sym_SLASH] = ACTIONS(2629),
    [anon_sym_div] = ACTIONS(2629),
    [anon_sym_DIV] = ACTIONS(2629),
    [anon_sym_Div] = ACTIONS(2629),
    [anon_sym_mod] = ACTIONS(2629),
    [anon_sym_MOD] = ACTIONS(2629),
    [anon_sym_Mod] = ACTIONS(2629),
    [anon_sym_PLUS] = ACTIONS(2629),
    [anon_sym_GT_EQ] = ACTIONS(2631),
    [anon_sym_LT_EQ] = ACTIONS(2631),
    [anon_sym_GT] = ACTIONS(2629),
    [anon_sym_LT] = ACTIONS(2629),
    [anon_sym_LT_GT] = ACTIONS(2631),
    [anon_sym_and] = ACTIONS(2629),
    [anon_sym_AND] = ACTIONS(2629),
    [anon_sym_And] = ACTIONS(2629),
    [anon_sym_or] = ACTIONS(2629),
    [anon_sym_OR] = ACTIONS(2629),
    [anon_sym_Or] = ACTIONS(2629),
    [anon_sym_xor] = ACTIONS(2629),
    [anon_sym_XOR] = ACTIONS(2629),
    [anon_sym_Xor] = ACTIONS(2629),
    [anon_sym_QMARK] = ACTIONS(2631),
    [sym_datetime_literal] = ACTIONS(2631),
    [sym_date_literal] = ACTIONS(2629),
    [sym_time_literal] = ACTIONS(2629),
    [sym_biginteger_literal] = ACTIONS(2631),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_IF] = ACTIONS(2629),
    [anon_sym_If] = ACTIONS(2629),
    [anon_sym_else] = ACTIONS(2629),
    [anon_sym_ELSE] = ACTIONS(2629),
    [anon_sym_Else] = ACTIONS(2629),
    [anon_sym_case] = ACTIONS(2629),
    [anon_sym_CASE] = ACTIONS(2629),
    [anon_sym_Case] = ACTIONS(2629),
    [anon_sym_for] = ACTIONS(2629),
    [anon_sym_FOR] = ACTIONS(2629),
    [anon_sym_For] = ACTIONS(2629),
    [anon_sym_foreach] = ACTIONS(2629),
    [anon_sym_FOREACH] = ACTIONS(2629),
    [anon_sym_Foreach] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(2629),
    [anon_sym_WHILE] = ACTIONS(2629),
    [anon_sym_While] = ACTIONS(2629),
    [anon_sym_repeat] = ACTIONS(2629),
    [anon_sym_REPEAT] = ACTIONS(2629),
    [anon_sym_Repeat] = ACTIONS(2629),
    [anon_sym_exit] = ACTIONS(2629),
    [anon_sym_EXIT] = ACTIONS(2629),
    [anon_sym_Exit] = ACTIONS(2629),
    [anon_sym_continue] = ACTIONS(2629),
    [anon_sym_CONTINUE] = ACTIONS(2629),
    [anon_sym_Continue] = ACTIONS(2629),
    [anon_sym_break] = ACTIONS(2629),
    [anon_sym_BREAK] = ACTIONS(2629),
    [anon_sym_Break] = ACTIONS(2629),
    [anon_sym_with] = ACTIONS(2629),
    [anon_sym_WITH] = ACTIONS(2629),
    [anon_sym_With] = ACTIONS(2629),
    [sym_asserterror_keyword] = ACTIONS(2631),
    [anon_sym_in] = ACTIONS(2629),
    [anon_sym_IN] = ACTIONS(2629),
    [anon_sym_In] = ACTIONS(2629),
    [sym_page_keyword] = ACTIONS(2629),
    [anon_sym_codeunit] = ACTIONS(2629),
    [anon_sym_CODEUNIT] = ACTIONS(2629),
    [anon_sym_Codeunit] = ACTIONS(2629),
    [anon_sym_CodeUnit] = ACTIONS(2629),
    [anon_sym_COdeunit] = ACTIONS(2629),
    [anon_sym_codeUnit] = ACTIONS(2629),
    [sym_report_keyword] = ACTIONS(2629),
    [sym_query_keyword] = ACTIONS(2629),
    [anon_sym_xmlport] = ACTIONS(2629),
    [anon_sym_XMLPORT] = ACTIONS(2629),
    [anon_sym_Xmlport] = ACTIONS(2629),
    [anon_sym_XMLport] = ACTIONS(2629),
    [anon_sym_XMLPort] = ACTIONS(2629),
    [anon_sym_XmlPort] = ACTIONS(2629),
    [anon_sym_enum] = ACTIONS(2629),
    [anon_sym_ENUM] = ACTIONS(2629),
    [anon_sym_Enum] = ACTIONS(2629),
    [anon_sym_eNUM] = ACTIONS(2629),
    [anon_sym_eNum] = ACTIONS(2629),
    [anon_sym_ENum] = ACTIONS(2629),
    [sym_quoted_identifier] = ACTIONS(2631),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2631),
    [sym_integer] = ACTIONS(2629),
    [sym_continue_as_identifier] = ACTIONS(2631),
    [sym_preproc_open] = ACTIONS(2631),
    [sym_preproc_close] = ACTIONS(2631),
  },
  [STATE(1033)] = {
    [sym_identifier] = ACTIONS(2633),
    [anon_sym_SEMI] = ACTIONS(2635),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_EQ] = ACTIONS(2635),
    [anon_sym_DASH] = ACTIONS(2633),
    [aux_sym_boolean_token1] = ACTIONS(2633),
    [aux_sym_boolean_token2] = ACTIONS(2633),
    [sym_decimal] = ACTIONS(2633),
    [anon_sym_LPAREN] = ACTIONS(2635),
    [anon_sym_DOT_DOT] = ACTIONS(2635),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2633),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [aux_sym_record_type_token1] = ACTIONS(2633),
    [aux_sym_basic_type_token21] = ACTIONS(2633),
    [aux_sym_basic_type_token22] = ACTIONS(2633),
    [aux_sym_basic_type_token48] = ACTIONS(2633),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2633),
    [anon_sym_POUNDif] = ACTIONS(2635),
    [anon_sym_POUNDIF] = ACTIONS(2635),
    [anon_sym_POUNDIf] = ACTIONS(2635),
    [anon_sym_not] = ACTIONS(2633),
    [anon_sym_NOT] = ACTIONS(2633),
    [anon_sym_Not] = ACTIONS(2633),
    [anon_sym_POUNDelif] = ACTIONS(2635),
    [anon_sym_POUNDELIF] = ACTIONS(2635),
    [anon_sym_POUNDElif] = ACTIONS(2635),
    [anon_sym_POUNDelse] = ACTIONS(2635),
    [anon_sym_POUNDELSE] = ACTIONS(2635),
    [anon_sym_POUNDElse] = ACTIONS(2635),
    [anon_sym_POUNDendif] = ACTIONS(2635),
    [anon_sym_POUNDENDIF] = ACTIONS(2635),
    [anon_sym_POUNDEndif] = ACTIONS(2635),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2635),
    [aux_sym__expression_token1] = ACTIONS(2635),
    [aux_sym__expression_token2] = ACTIONS(2633),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2633),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2633),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_div] = ACTIONS(2633),
    [anon_sym_DIV] = ACTIONS(2633),
    [anon_sym_Div] = ACTIONS(2633),
    [anon_sym_mod] = ACTIONS(2633),
    [anon_sym_MOD] = ACTIONS(2633),
    [anon_sym_Mod] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_GT] = ACTIONS(2635),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_AND] = ACTIONS(2633),
    [anon_sym_And] = ACTIONS(2633),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_OR] = ACTIONS(2633),
    [anon_sym_Or] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_XOR] = ACTIONS(2633),
    [anon_sym_Xor] = ACTIONS(2633),
    [anon_sym_QMARK] = ACTIONS(2635),
    [sym_datetime_literal] = ACTIONS(2635),
    [sym_date_literal] = ACTIONS(2633),
    [sym_time_literal] = ACTIONS(2633),
    [sym_biginteger_literal] = ACTIONS(2635),
    [anon_sym_if] = ACTIONS(2633),
    [anon_sym_IF] = ACTIONS(2633),
    [anon_sym_If] = ACTIONS(2633),
    [anon_sym_else] = ACTIONS(2633),
    [anon_sym_ELSE] = ACTIONS(2633),
    [anon_sym_Else] = ACTIONS(2633),
    [anon_sym_case] = ACTIONS(2633),
    [anon_sym_CASE] = ACTIONS(2633),
    [anon_sym_Case] = ACTIONS(2633),
    [anon_sym_for] = ACTIONS(2633),
    [anon_sym_FOR] = ACTIONS(2633),
    [anon_sym_For] = ACTIONS(2633),
    [anon_sym_foreach] = ACTIONS(2633),
    [anon_sym_FOREACH] = ACTIONS(2633),
    [anon_sym_Foreach] = ACTIONS(2633),
    [anon_sym_while] = ACTIONS(2633),
    [anon_sym_WHILE] = ACTIONS(2633),
    [anon_sym_While] = ACTIONS(2633),
    [anon_sym_repeat] = ACTIONS(2633),
    [anon_sym_REPEAT] = ACTIONS(2633),
    [anon_sym_Repeat] = ACTIONS(2633),
    [anon_sym_exit] = ACTIONS(2633),
    [anon_sym_EXIT] = ACTIONS(2633),
    [anon_sym_Exit] = ACTIONS(2633),
    [anon_sym_continue] = ACTIONS(2633),
    [anon_sym_CONTINUE] = ACTIONS(2633),
    [anon_sym_Continue] = ACTIONS(2633),
    [anon_sym_break] = ACTIONS(2633),
    [anon_sym_BREAK] = ACTIONS(2633),
    [anon_sym_Break] = ACTIONS(2633),
    [anon_sym_with] = ACTIONS(2633),
    [anon_sym_WITH] = ACTIONS(2633),
    [anon_sym_With] = ACTIONS(2633),
    [sym_asserterror_keyword] = ACTIONS(2635),
    [anon_sym_in] = ACTIONS(2633),
    [anon_sym_IN] = ACTIONS(2633),
    [anon_sym_In] = ACTIONS(2633),
    [sym_page_keyword] = ACTIONS(2633),
    [anon_sym_codeunit] = ACTIONS(2633),
    [anon_sym_CODEUNIT] = ACTIONS(2633),
    [anon_sym_Codeunit] = ACTIONS(2633),
    [anon_sym_CodeUnit] = ACTIONS(2633),
    [anon_sym_COdeunit] = ACTIONS(2633),
    [anon_sym_codeUnit] = ACTIONS(2633),
    [sym_report_keyword] = ACTIONS(2633),
    [sym_query_keyword] = ACTIONS(2633),
    [anon_sym_xmlport] = ACTIONS(2633),
    [anon_sym_XMLPORT] = ACTIONS(2633),
    [anon_sym_Xmlport] = ACTIONS(2633),
    [anon_sym_XMLport] = ACTIONS(2633),
    [anon_sym_XMLPort] = ACTIONS(2633),
    [anon_sym_XmlPort] = ACTIONS(2633),
    [anon_sym_enum] = ACTIONS(2633),
    [anon_sym_ENUM] = ACTIONS(2633),
    [anon_sym_Enum] = ACTIONS(2633),
    [anon_sym_eNUM] = ACTIONS(2633),
    [anon_sym_eNum] = ACTIONS(2633),
    [anon_sym_ENum] = ACTIONS(2633),
    [sym_quoted_identifier] = ACTIONS(2635),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2635),
    [sym_integer] = ACTIONS(2633),
    [sym_continue_as_identifier] = ACTIONS(2635),
    [sym_preproc_open] = ACTIONS(2635),
    [sym_preproc_close] = ACTIONS(2635),
  },
  [STATE(1034)] = {
    [sym_identifier] = ACTIONS(2637),
    [anon_sym_SEMI] = ACTIONS(2639),
    [anon_sym_DOT] = ACTIONS(2637),
    [anon_sym_EQ] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [aux_sym_boolean_token1] = ACTIONS(2637),
    [aux_sym_boolean_token2] = ACTIONS(2637),
    [sym_decimal] = ACTIONS(2637),
    [anon_sym_LPAREN] = ACTIONS(2639),
    [anon_sym_DOT_DOT] = ACTIONS(2639),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(2637),
    [anon_sym_LBRACK] = ACTIONS(2639),
    [aux_sym_record_type_token1] = ACTIONS(2637),
    [aux_sym_basic_type_token21] = ACTIONS(2637),
    [aux_sym_basic_type_token22] = ACTIONS(2637),
    [aux_sym_basic_type_token48] = ACTIONS(2637),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2637),
    [anon_sym_POUNDif] = ACTIONS(2639),
    [anon_sym_POUNDIF] = ACTIONS(2639),
    [anon_sym_POUNDIf] = ACTIONS(2639),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_NOT] = ACTIONS(2637),
    [anon_sym_Not] = ACTIONS(2637),
    [anon_sym_POUNDelif] = ACTIONS(2639),
    [anon_sym_POUNDELIF] = ACTIONS(2639),
    [anon_sym_POUNDElif] = ACTIONS(2639),
    [anon_sym_POUNDelse] = ACTIONS(2639),
    [anon_sym_POUNDELSE] = ACTIONS(2639),
    [anon_sym_POUNDElse] = ACTIONS(2639),
    [anon_sym_POUNDendif] = ACTIONS(2639),
    [anon_sym_POUNDENDIF] = ACTIONS(2639),
    [anon_sym_POUNDEndif] = ACTIONS(2639),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2639),
    [aux_sym__expression_token1] = ACTIONS(2639),
    [aux_sym__expression_token2] = ACTIONS(2637),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2637),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2637),
    [anon_sym_SLASH] = ACTIONS(2637),
    [anon_sym_div] = ACTIONS(2637),
    [anon_sym_DIV] = ACTIONS(2637),
    [anon_sym_Div] = ACTIONS(2637),
    [anon_sym_mod] = ACTIONS(2637),
    [anon_sym_MOD] = ACTIONS(2637),
    [anon_sym_Mod] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_GT_EQ] = ACTIONS(2639),
    [anon_sym_LT_EQ] = ACTIONS(2639),
    [anon_sym_GT] = ACTIONS(2637),
    [anon_sym_LT] = ACTIONS(2637),
    [anon_sym_LT_GT] = ACTIONS(2639),
    [anon_sym_and] = ACTIONS(2637),
    [anon_sym_AND] = ACTIONS(2637),
    [anon_sym_And] = ACTIONS(2637),
    [anon_sym_or] = ACTIONS(2637),
    [anon_sym_OR] = ACTIONS(2637),
    [anon_sym_Or] = ACTIONS(2637),
    [anon_sym_xor] = ACTIONS(2637),
    [anon_sym_XOR] = ACTIONS(2637),
    [anon_sym_Xor] = ACTIONS(2637),
    [anon_sym_QMARK] = ACTIONS(2639),
    [sym_datetime_literal] = ACTIONS(2639),
    [sym_date_literal] = ACTIONS(2637),
    [sym_time_literal] = ACTIONS(2637),
    [sym_biginteger_literal] = ACTIONS(2639),
    [anon_sym_if] = ACTIONS(2637),
    [anon_sym_IF] = ACTIONS(2637),
    [anon_sym_If] = ACTIONS(2637),
    [anon_sym_else] = ACTIONS(2637),
    [anon_sym_ELSE] = ACTIONS(2637),
    [anon_sym_Else] = ACTIONS(2637),
    [anon_sym_case] = ACTIONS(2637),
    [anon_sym_CASE] = ACTIONS(2637),
    [anon_sym_Case] = ACTIONS(2637),
    [anon_sym_for] = ACTIONS(2637),
    [anon_sym_FOR] = ACTIONS(2637),
    [anon_sym_For] = ACTIONS(2637),
    [anon_sym_foreach] = ACTIONS(2637),
    [anon_sym_FOREACH] = ACTIONS(2637),
    [anon_sym_Foreach] = ACTIONS(2637),
    [anon_sym_while] = ACTIONS(2637),
    [anon_sym_WHILE] = ACTIONS(2637),
    [anon_sym_While] = ACTIONS(2637),
    [anon_sym_repeat] = ACTIONS(2637),
    [anon_sym_REPEAT] = ACTIONS(2637),
    [anon_sym_Repeat] = ACTIONS(2637),
    [anon_sym_exit] = ACTIONS(2637),
    [anon_sym_EXIT] = ACTIONS(2637),
    [anon_sym_Exit] = ACTIONS(2637),
    [anon_sym_continue] = ACTIONS(2637),
    [anon_sym_CONTINUE] = ACTIONS(2637),
    [anon_sym_Continue] = ACTIONS(2637),
    [anon_sym_break] = ACTIONS(2637),
    [anon_sym_BREAK] = ACTIONS(2637),
    [anon_sym_Break] = ACTIONS(2637),
    [anon_sym_with] = ACTIONS(2637),
    [anon_sym_WITH] = ACTIONS(2637),
    [anon_sym_With] = ACTIONS(2637),
    [sym_asserterror_keyword] = ACTIONS(2639),
    [anon_sym_in] = ACTIONS(2637),
    [anon_sym_IN] = ACTIONS(2637),
    [anon_sym_In] = ACTIONS(2637),
    [sym_page_keyword] = ACTIONS(2637),
    [anon_sym_codeunit] = ACTIONS(2637),
    [anon_sym_CODEUNIT] = ACTIONS(2637),
    [anon_sym_Codeunit] = ACTIONS(2637),
    [anon_sym_CodeUnit] = ACTIONS(2637),
    [anon_sym_COdeunit] = ACTIONS(2637),
    [anon_sym_codeUnit] = ACTIONS(2637),
    [sym_report_keyword] = ACTIONS(2637),
    [sym_query_keyword] = ACTIONS(2637),
    [anon_sym_xmlport] = ACTIONS(2637),
    [anon_sym_XMLPORT] = ACTIONS(2637),
    [anon_sym_Xmlport] = ACTIONS(2637),
    [anon_sym_XMLport] = ACTIONS(2637),
    [anon_sym_XMLPort] = ACTIONS(2637),
    [anon_sym_XmlPort] = ACTIONS(2637),
    [anon_sym_enum] = ACTIONS(2637),
    [anon_sym_ENUM] = ACTIONS(2637),
    [anon_sym_Enum] = ACTIONS(2637),
    [anon_sym_eNUM] = ACTIONS(2637),
    [anon_sym_eNum] = ACTIONS(2637),
    [anon_sym_ENum] = ACTIONS(2637),
    [sym_quoted_identifier] = ACTIONS(2639),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2639),
    [sym_integer] = ACTIONS(2637),
    [sym_continue_as_identifier] = ACTIONS(2639),
    [sym_preproc_open] = ACTIONS(2639),
    [sym_preproc_close] = ACTIONS(2639),
  },
  [STATE(1035)] = {
    [sym_identifier] = ACTIONS(2641),
    [anon_sym_SEMI] = ACTIONS(2643),
    [anon_sym_DOT] = ACTIONS(2641),
    [anon_sym_EQ] = ACTIONS(2643),
    [anon_sym_DASH] = ACTIONS(2641),
    [aux_sym_boolean_token1] = ACTIONS(2641),
    [aux_sym_boolean_token2] = ACTIONS(2641),
    [sym_decimal] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_DOT_DOT] = ACTIONS(2643),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2641),
    [anon_sym_STAR] = ACTIONS(2641),
    [anon_sym_LBRACK] = ACTIONS(2643),
    [aux_sym_record_type_token1] = ACTIONS(2641),
    [aux_sym_basic_type_token21] = ACTIONS(2641),
    [aux_sym_basic_type_token22] = ACTIONS(2641),
    [aux_sym_basic_type_token48] = ACTIONS(2641),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2641),
    [anon_sym_POUNDif] = ACTIONS(2643),
    [anon_sym_POUNDIF] = ACTIONS(2643),
    [anon_sym_POUNDIf] = ACTIONS(2643),
    [anon_sym_not] = ACTIONS(2641),
    [anon_sym_NOT] = ACTIONS(2641),
    [anon_sym_Not] = ACTIONS(2641),
    [anon_sym_POUNDelif] = ACTIONS(2643),
    [anon_sym_POUNDELIF] = ACTIONS(2643),
    [anon_sym_POUNDElif] = ACTIONS(2643),
    [anon_sym_POUNDelse] = ACTIONS(2643),
    [anon_sym_POUNDELSE] = ACTIONS(2643),
    [anon_sym_POUNDElse] = ACTIONS(2643),
    [anon_sym_POUNDendif] = ACTIONS(2643),
    [anon_sym_POUNDENDIF] = ACTIONS(2643),
    [anon_sym_POUNDEndif] = ACTIONS(2643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2643),
    [aux_sym__expression_token1] = ACTIONS(2643),
    [aux_sym__expression_token2] = ACTIONS(2641),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2641),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2641),
    [anon_sym_SLASH] = ACTIONS(2641),
    [anon_sym_div] = ACTIONS(2641),
    [anon_sym_DIV] = ACTIONS(2641),
    [anon_sym_Div] = ACTIONS(2641),
    [anon_sym_mod] = ACTIONS(2641),
    [anon_sym_MOD] = ACTIONS(2641),
    [anon_sym_Mod] = ACTIONS(2641),
    [anon_sym_PLUS] = ACTIONS(2641),
    [anon_sym_GT_EQ] = ACTIONS(2643),
    [anon_sym_LT_EQ] = ACTIONS(2643),
    [anon_sym_GT] = ACTIONS(2641),
    [anon_sym_LT] = ACTIONS(2641),
    [anon_sym_LT_GT] = ACTIONS(2643),
    [anon_sym_and] = ACTIONS(2641),
    [anon_sym_AND] = ACTIONS(2641),
    [anon_sym_And] = ACTIONS(2641),
    [anon_sym_or] = ACTIONS(2641),
    [anon_sym_OR] = ACTIONS(2641),
    [anon_sym_Or] = ACTIONS(2641),
    [anon_sym_xor] = ACTIONS(2641),
    [anon_sym_XOR] = ACTIONS(2641),
    [anon_sym_Xor] = ACTIONS(2641),
    [anon_sym_QMARK] = ACTIONS(2643),
    [sym_datetime_literal] = ACTIONS(2643),
    [sym_date_literal] = ACTIONS(2641),
    [sym_time_literal] = ACTIONS(2641),
    [sym_biginteger_literal] = ACTIONS(2643),
    [anon_sym_if] = ACTIONS(2641),
    [anon_sym_IF] = ACTIONS(2641),
    [anon_sym_If] = ACTIONS(2641),
    [anon_sym_else] = ACTIONS(2641),
    [anon_sym_ELSE] = ACTIONS(2641),
    [anon_sym_Else] = ACTIONS(2641),
    [anon_sym_case] = ACTIONS(2641),
    [anon_sym_CASE] = ACTIONS(2641),
    [anon_sym_Case] = ACTIONS(2641),
    [anon_sym_for] = ACTIONS(2641),
    [anon_sym_FOR] = ACTIONS(2641),
    [anon_sym_For] = ACTIONS(2641),
    [anon_sym_foreach] = ACTIONS(2641),
    [anon_sym_FOREACH] = ACTIONS(2641),
    [anon_sym_Foreach] = ACTIONS(2641),
    [anon_sym_while] = ACTIONS(2641),
    [anon_sym_WHILE] = ACTIONS(2641),
    [anon_sym_While] = ACTIONS(2641),
    [anon_sym_repeat] = ACTIONS(2641),
    [anon_sym_REPEAT] = ACTIONS(2641),
    [anon_sym_Repeat] = ACTIONS(2641),
    [anon_sym_exit] = ACTIONS(2641),
    [anon_sym_EXIT] = ACTIONS(2641),
    [anon_sym_Exit] = ACTIONS(2641),
    [anon_sym_continue] = ACTIONS(2641),
    [anon_sym_CONTINUE] = ACTIONS(2641),
    [anon_sym_Continue] = ACTIONS(2641),
    [anon_sym_break] = ACTIONS(2641),
    [anon_sym_BREAK] = ACTIONS(2641),
    [anon_sym_Break] = ACTIONS(2641),
    [anon_sym_with] = ACTIONS(2641),
    [anon_sym_WITH] = ACTIONS(2641),
    [anon_sym_With] = ACTIONS(2641),
    [sym_asserterror_keyword] = ACTIONS(2643),
    [anon_sym_in] = ACTIONS(2641),
    [anon_sym_IN] = ACTIONS(2641),
    [anon_sym_In] = ACTIONS(2641),
    [sym_page_keyword] = ACTIONS(2641),
    [anon_sym_codeunit] = ACTIONS(2641),
    [anon_sym_CODEUNIT] = ACTIONS(2641),
    [anon_sym_Codeunit] = ACTIONS(2641),
    [anon_sym_CodeUnit] = ACTIONS(2641),
    [anon_sym_COdeunit] = ACTIONS(2641),
    [anon_sym_codeUnit] = ACTIONS(2641),
    [sym_report_keyword] = ACTIONS(2641),
    [sym_query_keyword] = ACTIONS(2641),
    [anon_sym_xmlport] = ACTIONS(2641),
    [anon_sym_XMLPORT] = ACTIONS(2641),
    [anon_sym_Xmlport] = ACTIONS(2641),
    [anon_sym_XMLport] = ACTIONS(2641),
    [anon_sym_XMLPort] = ACTIONS(2641),
    [anon_sym_XmlPort] = ACTIONS(2641),
    [anon_sym_enum] = ACTIONS(2641),
    [anon_sym_ENUM] = ACTIONS(2641),
    [anon_sym_Enum] = ACTIONS(2641),
    [anon_sym_eNUM] = ACTIONS(2641),
    [anon_sym_eNum] = ACTIONS(2641),
    [anon_sym_ENum] = ACTIONS(2641),
    [sym_quoted_identifier] = ACTIONS(2643),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2643),
    [sym_integer] = ACTIONS(2641),
    [sym_continue_as_identifier] = ACTIONS(2643),
    [sym_preproc_open] = ACTIONS(2643),
    [sym_preproc_close] = ACTIONS(2643),
  },
  [STATE(1036)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_SEMI] = ACTIONS(2591),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2589),
    [anon_sym_POUNDif] = ACTIONS(2591),
    [anon_sym_POUNDIF] = ACTIONS(2591),
    [anon_sym_POUNDIf] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [anon_sym_POUNDelif] = ACTIONS(2591),
    [anon_sym_POUNDELIF] = ACTIONS(2591),
    [anon_sym_POUNDElif] = ACTIONS(2591),
    [anon_sym_POUNDelse] = ACTIONS(2591),
    [anon_sym_POUNDELSE] = ACTIONS(2591),
    [anon_sym_POUNDElse] = ACTIONS(2591),
    [anon_sym_POUNDendif] = ACTIONS(2591),
    [anon_sym_POUNDENDIF] = ACTIONS(2591),
    [anon_sym_POUNDEndif] = ACTIONS(2591),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_if] = ACTIONS(2589),
    [anon_sym_IF] = ACTIONS(2589),
    [anon_sym_If] = ACTIONS(2589),
    [anon_sym_else] = ACTIONS(2589),
    [anon_sym_ELSE] = ACTIONS(2589),
    [anon_sym_Else] = ACTIONS(2589),
    [anon_sym_case] = ACTIONS(2589),
    [anon_sym_CASE] = ACTIONS(2589),
    [anon_sym_Case] = ACTIONS(2589),
    [anon_sym_for] = ACTIONS(2589),
    [anon_sym_FOR] = ACTIONS(2589),
    [anon_sym_For] = ACTIONS(2589),
    [anon_sym_foreach] = ACTIONS(2589),
    [anon_sym_FOREACH] = ACTIONS(2589),
    [anon_sym_Foreach] = ACTIONS(2589),
    [anon_sym_while] = ACTIONS(2589),
    [anon_sym_WHILE] = ACTIONS(2589),
    [anon_sym_While] = ACTIONS(2589),
    [anon_sym_repeat] = ACTIONS(2589),
    [anon_sym_REPEAT] = ACTIONS(2589),
    [anon_sym_Repeat] = ACTIONS(2589),
    [anon_sym_exit] = ACTIONS(2589),
    [anon_sym_EXIT] = ACTIONS(2589),
    [anon_sym_Exit] = ACTIONS(2589),
    [anon_sym_continue] = ACTIONS(2589),
    [anon_sym_CONTINUE] = ACTIONS(2589),
    [anon_sym_Continue] = ACTIONS(2589),
    [anon_sym_break] = ACTIONS(2589),
    [anon_sym_BREAK] = ACTIONS(2589),
    [anon_sym_Break] = ACTIONS(2589),
    [anon_sym_with] = ACTIONS(2589),
    [anon_sym_WITH] = ACTIONS(2589),
    [anon_sym_With] = ACTIONS(2589),
    [sym_asserterror_keyword] = ACTIONS(2591),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_open] = ACTIONS(2591),
    [sym_preproc_close] = ACTIONS(2591),
  },
  [STATE(1037)] = {
    [sym_identifier] = ACTIONS(2645),
    [anon_sym_SEMI] = ACTIONS(2647),
    [anon_sym_DOT] = ACTIONS(2645),
    [anon_sym_EQ] = ACTIONS(2647),
    [anon_sym_DASH] = ACTIONS(2645),
    [aux_sym_boolean_token1] = ACTIONS(2645),
    [aux_sym_boolean_token2] = ACTIONS(2645),
    [sym_decimal] = ACTIONS(2645),
    [anon_sym_LPAREN] = ACTIONS(2647),
    [anon_sym_DOT_DOT] = ACTIONS(2647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2645),
    [anon_sym_STAR] = ACTIONS(2645),
    [anon_sym_LBRACK] = ACTIONS(2647),
    [aux_sym_record_type_token1] = ACTIONS(2645),
    [aux_sym_basic_type_token21] = ACTIONS(2645),
    [aux_sym_basic_type_token22] = ACTIONS(2645),
    [aux_sym_basic_type_token48] = ACTIONS(2645),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2645),
    [anon_sym_POUNDif] = ACTIONS(2647),
    [anon_sym_POUNDIF] = ACTIONS(2647),
    [anon_sym_POUNDIf] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2645),
    [anon_sym_NOT] = ACTIONS(2645),
    [anon_sym_Not] = ACTIONS(2645),
    [anon_sym_POUNDelif] = ACTIONS(2647),
    [anon_sym_POUNDELIF] = ACTIONS(2647),
    [anon_sym_POUNDElif] = ACTIONS(2647),
    [anon_sym_POUNDelse] = ACTIONS(2647),
    [anon_sym_POUNDELSE] = ACTIONS(2647),
    [anon_sym_POUNDElse] = ACTIONS(2647),
    [anon_sym_POUNDendif] = ACTIONS(2647),
    [anon_sym_POUNDENDIF] = ACTIONS(2647),
    [anon_sym_POUNDEndif] = ACTIONS(2647),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2647),
    [aux_sym__expression_token1] = ACTIONS(2647),
    [aux_sym__expression_token2] = ACTIONS(2645),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2645),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2645),
    [anon_sym_SLASH] = ACTIONS(2645),
    [anon_sym_div] = ACTIONS(2645),
    [anon_sym_DIV] = ACTIONS(2645),
    [anon_sym_Div] = ACTIONS(2645),
    [anon_sym_mod] = ACTIONS(2645),
    [anon_sym_MOD] = ACTIONS(2645),
    [anon_sym_Mod] = ACTIONS(2645),
    [anon_sym_PLUS] = ACTIONS(2645),
    [anon_sym_GT_EQ] = ACTIONS(2647),
    [anon_sym_LT_EQ] = ACTIONS(2647),
    [anon_sym_GT] = ACTIONS(2645),
    [anon_sym_LT] = ACTIONS(2645),
    [anon_sym_LT_GT] = ACTIONS(2647),
    [anon_sym_and] = ACTIONS(2645),
    [anon_sym_AND] = ACTIONS(2645),
    [anon_sym_And] = ACTIONS(2645),
    [anon_sym_or] = ACTIONS(2645),
    [anon_sym_OR] = ACTIONS(2645),
    [anon_sym_Or] = ACTIONS(2645),
    [anon_sym_xor] = ACTIONS(2645),
    [anon_sym_XOR] = ACTIONS(2645),
    [anon_sym_Xor] = ACTIONS(2645),
    [anon_sym_QMARK] = ACTIONS(2647),
    [sym_datetime_literal] = ACTIONS(2647),
    [sym_date_literal] = ACTIONS(2645),
    [sym_time_literal] = ACTIONS(2645),
    [sym_biginteger_literal] = ACTIONS(2647),
    [anon_sym_if] = ACTIONS(2645),
    [anon_sym_IF] = ACTIONS(2645),
    [anon_sym_If] = ACTIONS(2645),
    [anon_sym_else] = ACTIONS(2645),
    [anon_sym_ELSE] = ACTIONS(2645),
    [anon_sym_Else] = ACTIONS(2645),
    [anon_sym_case] = ACTIONS(2645),
    [anon_sym_CASE] = ACTIONS(2645),
    [anon_sym_Case] = ACTIONS(2645),
    [anon_sym_for] = ACTIONS(2645),
    [anon_sym_FOR] = ACTIONS(2645),
    [anon_sym_For] = ACTIONS(2645),
    [anon_sym_foreach] = ACTIONS(2645),
    [anon_sym_FOREACH] = ACTIONS(2645),
    [anon_sym_Foreach] = ACTIONS(2645),
    [anon_sym_while] = ACTIONS(2645),
    [anon_sym_WHILE] = ACTIONS(2645),
    [anon_sym_While] = ACTIONS(2645),
    [anon_sym_repeat] = ACTIONS(2645),
    [anon_sym_REPEAT] = ACTIONS(2645),
    [anon_sym_Repeat] = ACTIONS(2645),
    [anon_sym_exit] = ACTIONS(2645),
    [anon_sym_EXIT] = ACTIONS(2645),
    [anon_sym_Exit] = ACTIONS(2645),
    [anon_sym_continue] = ACTIONS(2645),
    [anon_sym_CONTINUE] = ACTIONS(2645),
    [anon_sym_Continue] = ACTIONS(2645),
    [anon_sym_break] = ACTIONS(2645),
    [anon_sym_BREAK] = ACTIONS(2645),
    [anon_sym_Break] = ACTIONS(2645),
    [anon_sym_with] = ACTIONS(2645),
    [anon_sym_WITH] = ACTIONS(2645),
    [anon_sym_With] = ACTIONS(2645),
    [sym_asserterror_keyword] = ACTIONS(2647),
    [anon_sym_in] = ACTIONS(2645),
    [anon_sym_IN] = ACTIONS(2645),
    [anon_sym_In] = ACTIONS(2645),
    [sym_page_keyword] = ACTIONS(2645),
    [anon_sym_codeunit] = ACTIONS(2645),
    [anon_sym_CODEUNIT] = ACTIONS(2645),
    [anon_sym_Codeunit] = ACTIONS(2645),
    [anon_sym_CodeUnit] = ACTIONS(2645),
    [anon_sym_COdeunit] = ACTIONS(2645),
    [anon_sym_codeUnit] = ACTIONS(2645),
    [sym_report_keyword] = ACTIONS(2645),
    [sym_query_keyword] = ACTIONS(2645),
    [anon_sym_xmlport] = ACTIONS(2645),
    [anon_sym_XMLPORT] = ACTIONS(2645),
    [anon_sym_Xmlport] = ACTIONS(2645),
    [anon_sym_XMLport] = ACTIONS(2645),
    [anon_sym_XMLPort] = ACTIONS(2645),
    [anon_sym_XmlPort] = ACTIONS(2645),
    [anon_sym_enum] = ACTIONS(2645),
    [anon_sym_ENUM] = ACTIONS(2645),
    [anon_sym_Enum] = ACTIONS(2645),
    [anon_sym_eNUM] = ACTIONS(2645),
    [anon_sym_eNum] = ACTIONS(2645),
    [anon_sym_ENum] = ACTIONS(2645),
    [sym_quoted_identifier] = ACTIONS(2647),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2647),
    [sym_integer] = ACTIONS(2645),
    [sym_continue_as_identifier] = ACTIONS(2647),
    [sym_preproc_open] = ACTIONS(2647),
    [sym_preproc_close] = ACTIONS(2647),
  },
  [STATE(1038)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_SEMI] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2593),
    [anon_sym_POUNDif] = ACTIONS(2595),
    [anon_sym_POUNDIF] = ACTIONS(2595),
    [anon_sym_POUNDIf] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [anon_sym_POUNDelif] = ACTIONS(2595),
    [anon_sym_POUNDELIF] = ACTIONS(2595),
    [anon_sym_POUNDElif] = ACTIONS(2595),
    [anon_sym_POUNDelse] = ACTIONS(2595),
    [anon_sym_POUNDELSE] = ACTIONS(2595),
    [anon_sym_POUNDElse] = ACTIONS(2595),
    [anon_sym_POUNDendif] = ACTIONS(2595),
    [anon_sym_POUNDENDIF] = ACTIONS(2595),
    [anon_sym_POUNDEndif] = ACTIONS(2595),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_if] = ACTIONS(2593),
    [anon_sym_IF] = ACTIONS(2593),
    [anon_sym_If] = ACTIONS(2593),
    [anon_sym_else] = ACTIONS(2593),
    [anon_sym_ELSE] = ACTIONS(2593),
    [anon_sym_Else] = ACTIONS(2593),
    [anon_sym_case] = ACTIONS(2593),
    [anon_sym_CASE] = ACTIONS(2593),
    [anon_sym_Case] = ACTIONS(2593),
    [anon_sym_for] = ACTIONS(2593),
    [anon_sym_FOR] = ACTIONS(2593),
    [anon_sym_For] = ACTIONS(2593),
    [anon_sym_foreach] = ACTIONS(2593),
    [anon_sym_FOREACH] = ACTIONS(2593),
    [anon_sym_Foreach] = ACTIONS(2593),
    [anon_sym_while] = ACTIONS(2593),
    [anon_sym_WHILE] = ACTIONS(2593),
    [anon_sym_While] = ACTIONS(2593),
    [anon_sym_repeat] = ACTIONS(2593),
    [anon_sym_REPEAT] = ACTIONS(2593),
    [anon_sym_Repeat] = ACTIONS(2593),
    [anon_sym_exit] = ACTIONS(2593),
    [anon_sym_EXIT] = ACTIONS(2593),
    [anon_sym_Exit] = ACTIONS(2593),
    [anon_sym_continue] = ACTIONS(2593),
    [anon_sym_CONTINUE] = ACTIONS(2593),
    [anon_sym_Continue] = ACTIONS(2593),
    [anon_sym_break] = ACTIONS(2593),
    [anon_sym_BREAK] = ACTIONS(2593),
    [anon_sym_Break] = ACTIONS(2593),
    [anon_sym_with] = ACTIONS(2593),
    [anon_sym_WITH] = ACTIONS(2593),
    [anon_sym_With] = ACTIONS(2593),
    [sym_asserterror_keyword] = ACTIONS(2595),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_open] = ACTIONS(2595),
    [sym_preproc_close] = ACTIONS(2595),
  },
  [STATE(1039)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_SEMI] = ACTIONS(2591),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2589),
    [anon_sym_POUNDif] = ACTIONS(2591),
    [anon_sym_POUNDIF] = ACTIONS(2591),
    [anon_sym_POUNDIf] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [anon_sym_POUNDelif] = ACTIONS(2591),
    [anon_sym_POUNDELIF] = ACTIONS(2591),
    [anon_sym_POUNDElif] = ACTIONS(2591),
    [anon_sym_POUNDelse] = ACTIONS(2591),
    [anon_sym_POUNDELSE] = ACTIONS(2591),
    [anon_sym_POUNDElse] = ACTIONS(2591),
    [anon_sym_POUNDendif] = ACTIONS(2591),
    [anon_sym_POUNDENDIF] = ACTIONS(2591),
    [anon_sym_POUNDEndif] = ACTIONS(2591),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_if] = ACTIONS(2589),
    [anon_sym_IF] = ACTIONS(2589),
    [anon_sym_If] = ACTIONS(2589),
    [anon_sym_else] = ACTIONS(2589),
    [anon_sym_ELSE] = ACTIONS(2589),
    [anon_sym_Else] = ACTIONS(2589),
    [anon_sym_case] = ACTIONS(2589),
    [anon_sym_CASE] = ACTIONS(2589),
    [anon_sym_Case] = ACTIONS(2589),
    [anon_sym_for] = ACTIONS(2589),
    [anon_sym_FOR] = ACTIONS(2589),
    [anon_sym_For] = ACTIONS(2589),
    [anon_sym_foreach] = ACTIONS(2589),
    [anon_sym_FOREACH] = ACTIONS(2589),
    [anon_sym_Foreach] = ACTIONS(2589),
    [anon_sym_while] = ACTIONS(2589),
    [anon_sym_WHILE] = ACTIONS(2589),
    [anon_sym_While] = ACTIONS(2589),
    [anon_sym_repeat] = ACTIONS(2589),
    [anon_sym_REPEAT] = ACTIONS(2589),
    [anon_sym_Repeat] = ACTIONS(2589),
    [anon_sym_exit] = ACTIONS(2589),
    [anon_sym_EXIT] = ACTIONS(2589),
    [anon_sym_Exit] = ACTIONS(2589),
    [anon_sym_continue] = ACTIONS(2589),
    [anon_sym_CONTINUE] = ACTIONS(2589),
    [anon_sym_Continue] = ACTIONS(2589),
    [anon_sym_break] = ACTIONS(2589),
    [anon_sym_BREAK] = ACTIONS(2589),
    [anon_sym_Break] = ACTIONS(2589),
    [anon_sym_with] = ACTIONS(2589),
    [anon_sym_WITH] = ACTIONS(2589),
    [anon_sym_With] = ACTIONS(2589),
    [sym_asserterror_keyword] = ACTIONS(2591),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_open] = ACTIONS(2591),
    [sym_preproc_close] = ACTIONS(2591),
  },
  [STATE(1040)] = {
    [sym_identifier] = ACTIONS(2649),
    [anon_sym_SEMI] = ACTIONS(2651),
    [anon_sym_DOT] = ACTIONS(2649),
    [anon_sym_EQ] = ACTIONS(2651),
    [anon_sym_DASH] = ACTIONS(2649),
    [aux_sym_boolean_token1] = ACTIONS(2649),
    [aux_sym_boolean_token2] = ACTIONS(2649),
    [sym_decimal] = ACTIONS(2649),
    [anon_sym_LPAREN] = ACTIONS(2651),
    [anon_sym_DOT_DOT] = ACTIONS(2651),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2649),
    [anon_sym_STAR] = ACTIONS(2649),
    [anon_sym_LBRACK] = ACTIONS(2651),
    [aux_sym_record_type_token1] = ACTIONS(2649),
    [aux_sym_basic_type_token21] = ACTIONS(2649),
    [aux_sym_basic_type_token22] = ACTIONS(2649),
    [aux_sym_basic_type_token48] = ACTIONS(2649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2649),
    [anon_sym_POUNDif] = ACTIONS(2651),
    [anon_sym_POUNDIF] = ACTIONS(2651),
    [anon_sym_POUNDIf] = ACTIONS(2651),
    [anon_sym_not] = ACTIONS(2649),
    [anon_sym_NOT] = ACTIONS(2649),
    [anon_sym_Not] = ACTIONS(2649),
    [anon_sym_POUNDelif] = ACTIONS(2651),
    [anon_sym_POUNDELIF] = ACTIONS(2651),
    [anon_sym_POUNDElif] = ACTIONS(2651),
    [anon_sym_POUNDelse] = ACTIONS(2651),
    [anon_sym_POUNDELSE] = ACTIONS(2651),
    [anon_sym_POUNDElse] = ACTIONS(2651),
    [anon_sym_POUNDendif] = ACTIONS(2651),
    [anon_sym_POUNDENDIF] = ACTIONS(2651),
    [anon_sym_POUNDEndif] = ACTIONS(2651),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2651),
    [aux_sym__expression_token1] = ACTIONS(2651),
    [aux_sym__expression_token2] = ACTIONS(2649),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2649),
    [anon_sym_SLASH] = ACTIONS(2649),
    [anon_sym_div] = ACTIONS(2649),
    [anon_sym_DIV] = ACTIONS(2649),
    [anon_sym_Div] = ACTIONS(2649),
    [anon_sym_mod] = ACTIONS(2649),
    [anon_sym_MOD] = ACTIONS(2649),
    [anon_sym_Mod] = ACTIONS(2649),
    [anon_sym_PLUS] = ACTIONS(2649),
    [anon_sym_GT_EQ] = ACTIONS(2651),
    [anon_sym_LT_EQ] = ACTIONS(2651),
    [anon_sym_GT] = ACTIONS(2649),
    [anon_sym_LT] = ACTIONS(2649),
    [anon_sym_LT_GT] = ACTIONS(2651),
    [anon_sym_and] = ACTIONS(2649),
    [anon_sym_AND] = ACTIONS(2649),
    [anon_sym_And] = ACTIONS(2649),
    [anon_sym_or] = ACTIONS(2649),
    [anon_sym_OR] = ACTIONS(2649),
    [anon_sym_Or] = ACTIONS(2649),
    [anon_sym_xor] = ACTIONS(2649),
    [anon_sym_XOR] = ACTIONS(2649),
    [anon_sym_Xor] = ACTIONS(2649),
    [anon_sym_QMARK] = ACTIONS(2651),
    [sym_datetime_literal] = ACTIONS(2651),
    [sym_date_literal] = ACTIONS(2649),
    [sym_time_literal] = ACTIONS(2649),
    [sym_biginteger_literal] = ACTIONS(2651),
    [anon_sym_if] = ACTIONS(2649),
    [anon_sym_IF] = ACTIONS(2649),
    [anon_sym_If] = ACTIONS(2649),
    [anon_sym_else] = ACTIONS(2649),
    [anon_sym_ELSE] = ACTIONS(2649),
    [anon_sym_Else] = ACTIONS(2649),
    [anon_sym_case] = ACTIONS(2649),
    [anon_sym_CASE] = ACTIONS(2649),
    [anon_sym_Case] = ACTIONS(2649),
    [anon_sym_for] = ACTIONS(2649),
    [anon_sym_FOR] = ACTIONS(2649),
    [anon_sym_For] = ACTIONS(2649),
    [anon_sym_foreach] = ACTIONS(2649),
    [anon_sym_FOREACH] = ACTIONS(2649),
    [anon_sym_Foreach] = ACTIONS(2649),
    [anon_sym_while] = ACTIONS(2649),
    [anon_sym_WHILE] = ACTIONS(2649),
    [anon_sym_While] = ACTIONS(2649),
    [anon_sym_repeat] = ACTIONS(2649),
    [anon_sym_REPEAT] = ACTIONS(2649),
    [anon_sym_Repeat] = ACTIONS(2649),
    [anon_sym_exit] = ACTIONS(2649),
    [anon_sym_EXIT] = ACTIONS(2649),
    [anon_sym_Exit] = ACTIONS(2649),
    [anon_sym_continue] = ACTIONS(2649),
    [anon_sym_CONTINUE] = ACTIONS(2649),
    [anon_sym_Continue] = ACTIONS(2649),
    [anon_sym_break] = ACTIONS(2649),
    [anon_sym_BREAK] = ACTIONS(2649),
    [anon_sym_Break] = ACTIONS(2649),
    [anon_sym_with] = ACTIONS(2649),
    [anon_sym_WITH] = ACTIONS(2649),
    [anon_sym_With] = ACTIONS(2649),
    [sym_asserterror_keyword] = ACTIONS(2651),
    [anon_sym_in] = ACTIONS(2649),
    [anon_sym_IN] = ACTIONS(2649),
    [anon_sym_In] = ACTIONS(2649),
    [sym_page_keyword] = ACTIONS(2649),
    [anon_sym_codeunit] = ACTIONS(2649),
    [anon_sym_CODEUNIT] = ACTIONS(2649),
    [anon_sym_Codeunit] = ACTIONS(2649),
    [anon_sym_CodeUnit] = ACTIONS(2649),
    [anon_sym_COdeunit] = ACTIONS(2649),
    [anon_sym_codeUnit] = ACTIONS(2649),
    [sym_report_keyword] = ACTIONS(2649),
    [sym_query_keyword] = ACTIONS(2649),
    [anon_sym_xmlport] = ACTIONS(2649),
    [anon_sym_XMLPORT] = ACTIONS(2649),
    [anon_sym_Xmlport] = ACTIONS(2649),
    [anon_sym_XMLport] = ACTIONS(2649),
    [anon_sym_XMLPort] = ACTIONS(2649),
    [anon_sym_XmlPort] = ACTIONS(2649),
    [anon_sym_enum] = ACTIONS(2649),
    [anon_sym_ENUM] = ACTIONS(2649),
    [anon_sym_Enum] = ACTIONS(2649),
    [anon_sym_eNUM] = ACTIONS(2649),
    [anon_sym_eNum] = ACTIONS(2649),
    [anon_sym_ENum] = ACTIONS(2649),
    [sym_quoted_identifier] = ACTIONS(2651),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2651),
    [sym_integer] = ACTIONS(2649),
    [sym_continue_as_identifier] = ACTIONS(2651),
    [sym_preproc_open] = ACTIONS(2651),
    [sym_preproc_close] = ACTIONS(2651),
  },
  [STATE(1041)] = {
    [sym_preproc_conditional_object] = STATE(1094),
    [sym_namespace_declaration] = STATE(1120),
    [sym_using_statement] = STATE(1094),
    [sym__object] = STATE(1094),
    [sym_preproc_split_declaration] = STATE(1094),
    [sym_table_declaration] = STATE(1094),
    [sym_page_declaration] = STATE(1094),
    [sym_report_declaration] = STATE(1094),
    [sym_query_declaration] = STATE(1094),
    [sym_xmlport_declaration] = STATE(1094),
    [sym_permissionset_declaration] = STATE(1094),
    [sym_codeunit_declaration] = STATE(1094),
    [sym_enum_declaration] = STATE(1094),
    [sym_tableextension_declaration] = STATE(1094),
    [sym_pageextension_declaration] = STATE(1094),
    [sym_reportextension_declaration] = STATE(1094),
    [sym_enumextension_declaration] = STATE(1094),
    [sym_permissionsetextension_declaration] = STATE(1094),
    [sym_controladdin_declaration] = STATE(1094),
    [sym_profile_declaration] = STATE(1094),
    [sym_entitlement_declaration] = STATE(1094),
    [sym_profileextension_declaration] = STATE(1094),
    [sym_interface_declaration] = STATE(1094),
    [sym_pagecustomization_declaration] = STATE(1094),
    [sym_dotnet_declaration] = STATE(1094),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(2534),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(1094),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1567),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(1042)] = {
    [sym_identifier] = ACTIONS(2266),
    [anon_sym_SEMI] = ACTIONS(2268),
    [anon_sym_DOT] = ACTIONS(2266),
    [anon_sym_EQ] = ACTIONS(2268),
    [anon_sym_COMMA] = ACTIONS(2268),
    [anon_sym_DASH] = ACTIONS(2266),
    [aux_sym_boolean_token1] = ACTIONS(2266),
    [aux_sym_boolean_token2] = ACTIONS(2266),
    [sym_decimal] = ACTIONS(2266),
    [anon_sym_LPAREN] = ACTIONS(2268),
    [anon_sym_DOT_DOT] = ACTIONS(2268),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2266),
    [anon_sym_STAR] = ACTIONS(2266),
    [anon_sym_LBRACK] = ACTIONS(2268),
    [aux_sym_record_type_token1] = ACTIONS(2266),
    [aux_sym_basic_type_token21] = ACTIONS(2266),
    [aux_sym_basic_type_token22] = ACTIONS(2266),
    [aux_sym_basic_type_token48] = ACTIONS(2266),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2266),
    [anon_sym_COLON_COLON] = ACTIONS(2268),
    [anon_sym_POUNDif] = ACTIONS(2268),
    [anon_sym_POUNDIF] = ACTIONS(2268),
    [anon_sym_POUNDIf] = ACTIONS(2268),
    [anon_sym_not] = ACTIONS(2266),
    [anon_sym_NOT] = ACTIONS(2266),
    [anon_sym_Not] = ACTIONS(2266),
    [anon_sym_POUNDelse] = ACTIONS(2268),
    [anon_sym_POUNDELSE] = ACTIONS(2268),
    [anon_sym_POUNDElse] = ACTIONS(2268),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2268),
    [aux_sym__expression_token1] = ACTIONS(2268),
    [aux_sym__expression_token2] = ACTIONS(2266),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2266),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2266),
    [anon_sym_SLASH] = ACTIONS(2266),
    [anon_sym_div] = ACTIONS(2266),
    [anon_sym_DIV] = ACTIONS(2266),
    [anon_sym_Div] = ACTIONS(2266),
    [anon_sym_mod] = ACTIONS(2266),
    [anon_sym_MOD] = ACTIONS(2266),
    [anon_sym_Mod] = ACTIONS(2266),
    [anon_sym_PLUS] = ACTIONS(2266),
    [anon_sym_GT_EQ] = ACTIONS(2268),
    [anon_sym_LT_EQ] = ACTIONS(2268),
    [anon_sym_GT] = ACTIONS(2266),
    [anon_sym_LT] = ACTIONS(2266),
    [anon_sym_LT_GT] = ACTIONS(2268),
    [anon_sym_and] = ACTIONS(2266),
    [anon_sym_AND] = ACTIONS(2266),
    [anon_sym_And] = ACTIONS(2266),
    [anon_sym_or] = ACTIONS(2266),
    [anon_sym_OR] = ACTIONS(2266),
    [anon_sym_Or] = ACTIONS(2266),
    [anon_sym_xor] = ACTIONS(2266),
    [anon_sym_XOR] = ACTIONS(2266),
    [anon_sym_Xor] = ACTIONS(2266),
    [anon_sym_QMARK] = ACTIONS(2268),
    [sym_datetime_literal] = ACTIONS(2268),
    [sym_date_literal] = ACTIONS(2266),
    [sym_time_literal] = ACTIONS(2266),
    [sym_biginteger_literal] = ACTIONS(2268),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_IF] = ACTIONS(2266),
    [anon_sym_If] = ACTIONS(2266),
    [anon_sym_else] = ACTIONS(2266),
    [anon_sym_ELSE] = ACTIONS(2266),
    [anon_sym_Else] = ACTIONS(2266),
    [anon_sym_case] = ACTIONS(2266),
    [anon_sym_CASE] = ACTIONS(2266),
    [anon_sym_Case] = ACTIONS(2266),
    [anon_sym_for] = ACTIONS(2266),
    [anon_sym_FOR] = ACTIONS(2266),
    [anon_sym_For] = ACTIONS(2266),
    [anon_sym_foreach] = ACTIONS(2266),
    [anon_sym_FOREACH] = ACTIONS(2266),
    [anon_sym_Foreach] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2266),
    [anon_sym_WHILE] = ACTIONS(2266),
    [anon_sym_While] = ACTIONS(2266),
    [anon_sym_repeat] = ACTIONS(2266),
    [anon_sym_REPEAT] = ACTIONS(2266),
    [anon_sym_Repeat] = ACTIONS(2266),
    [anon_sym_until] = ACTIONS(2266),
    [anon_sym_UNTIL] = ACTIONS(2266),
    [anon_sym_Until] = ACTIONS(2266),
    [anon_sym_exit] = ACTIONS(2266),
    [anon_sym_EXIT] = ACTIONS(2266),
    [anon_sym_Exit] = ACTIONS(2266),
    [anon_sym_continue] = ACTIONS(2266),
    [anon_sym_CONTINUE] = ACTIONS(2266),
    [anon_sym_Continue] = ACTIONS(2266),
    [anon_sym_break] = ACTIONS(2266),
    [anon_sym_BREAK] = ACTIONS(2266),
    [anon_sym_Break] = ACTIONS(2266),
    [anon_sym_with] = ACTIONS(2266),
    [anon_sym_WITH] = ACTIONS(2266),
    [anon_sym_With] = ACTIONS(2266),
    [sym_asserterror_keyword] = ACTIONS(2268),
    [anon_sym_in] = ACTIONS(2266),
    [anon_sym_IN] = ACTIONS(2266),
    [anon_sym_In] = ACTIONS(2266),
    [sym_page_keyword] = ACTIONS(2266),
    [anon_sym_codeunit] = ACTIONS(2266),
    [anon_sym_CODEUNIT] = ACTIONS(2266),
    [anon_sym_Codeunit] = ACTIONS(2266),
    [anon_sym_CodeUnit] = ACTIONS(2266),
    [anon_sym_COdeunit] = ACTIONS(2266),
    [anon_sym_codeUnit] = ACTIONS(2266),
    [sym_report_keyword] = ACTIONS(2266),
    [sym_query_keyword] = ACTIONS(2266),
    [anon_sym_xmlport] = ACTIONS(2266),
    [anon_sym_XMLPORT] = ACTIONS(2266),
    [anon_sym_Xmlport] = ACTIONS(2266),
    [anon_sym_XMLport] = ACTIONS(2266),
    [anon_sym_XMLPort] = ACTIONS(2266),
    [anon_sym_XmlPort] = ACTIONS(2266),
    [anon_sym_enum] = ACTIONS(2266),
    [anon_sym_ENUM] = ACTIONS(2266),
    [anon_sym_Enum] = ACTIONS(2266),
    [anon_sym_eNUM] = ACTIONS(2266),
    [anon_sym_eNum] = ACTIONS(2266),
    [anon_sym_ENum] = ACTIONS(2266),
    [sym_temporary_keyword] = ACTIONS(2266),
    [sym_quoted_identifier] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2268),
    [sym_integer] = ACTIONS(2266),
    [sym_continue_as_identifier] = ACTIONS(2268),
    [sym_preproc_open] = ACTIONS(2268),
  },
  [STATE(1043)] = {
    [sym_preproc_conditional_object] = STATE(1097),
    [sym_namespace_declaration] = STATE(1110),
    [sym_using_statement] = STATE(1097),
    [sym__object] = STATE(1097),
    [sym_preproc_split_declaration] = STATE(1097),
    [sym_table_declaration] = STATE(1097),
    [sym_page_declaration] = STATE(1097),
    [sym_report_declaration] = STATE(1097),
    [sym_query_declaration] = STATE(1097),
    [sym_xmlport_declaration] = STATE(1097),
    [sym_permissionset_declaration] = STATE(1097),
    [sym_codeunit_declaration] = STATE(1097),
    [sym_enum_declaration] = STATE(1097),
    [sym_tableextension_declaration] = STATE(1097),
    [sym_pageextension_declaration] = STATE(1097),
    [sym_reportextension_declaration] = STATE(1097),
    [sym_enumextension_declaration] = STATE(1097),
    [sym_permissionsetextension_declaration] = STATE(1097),
    [sym_controladdin_declaration] = STATE(1097),
    [sym_profile_declaration] = STATE(1097),
    [sym_entitlement_declaration] = STATE(1097),
    [sym_profileextension_declaration] = STATE(1097),
    [sym_interface_declaration] = STATE(1097),
    [sym_pagecustomization_declaration] = STATE(1097),
    [sym_dotnet_declaration] = STATE(1097),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(2522),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(1097),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1567),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(1044)] = {
    [sym_preproc_conditional_object] = STATE(1115),
    [sym_namespace_declaration] = STATE(1095),
    [sym_using_statement] = STATE(1115),
    [sym__object] = STATE(1115),
    [sym_preproc_split_declaration] = STATE(1115),
    [sym_table_declaration] = STATE(1115),
    [sym_page_declaration] = STATE(1115),
    [sym_report_declaration] = STATE(1115),
    [sym_query_declaration] = STATE(1115),
    [sym_xmlport_declaration] = STATE(1115),
    [sym_permissionset_declaration] = STATE(1115),
    [sym_codeunit_declaration] = STATE(1115),
    [sym_enum_declaration] = STATE(1115),
    [sym_tableextension_declaration] = STATE(1115),
    [sym_pageextension_declaration] = STATE(1115),
    [sym_reportextension_declaration] = STATE(1115),
    [sym_enumextension_declaration] = STATE(1115),
    [sym_permissionsetextension_declaration] = STATE(1115),
    [sym_controladdin_declaration] = STATE(1115),
    [sym_profile_declaration] = STATE(1115),
    [sym_entitlement_declaration] = STATE(1115),
    [sym_profileextension_declaration] = STATE(1115),
    [sym_interface_declaration] = STATE(1115),
    [sym_pagecustomization_declaration] = STATE(1115),
    [sym_dotnet_declaration] = STATE(1115),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(1989),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(1115),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1567),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(1045)] = {
    [sym_preproc_conditional_object] = STATE(1124),
    [sym_namespace_declaration] = STATE(1123),
    [sym_using_statement] = STATE(1124),
    [sym__object] = STATE(1124),
    [sym_preproc_split_declaration] = STATE(1124),
    [sym_table_declaration] = STATE(1124),
    [sym_page_declaration] = STATE(1124),
    [sym_report_declaration] = STATE(1124),
    [sym_query_declaration] = STATE(1124),
    [sym_xmlport_declaration] = STATE(1124),
    [sym_permissionset_declaration] = STATE(1124),
    [sym_codeunit_declaration] = STATE(1124),
    [sym_enum_declaration] = STATE(1124),
    [sym_tableextension_declaration] = STATE(1124),
    [sym_pageextension_declaration] = STATE(1124),
    [sym_reportextension_declaration] = STATE(1124),
    [sym_enumextension_declaration] = STATE(1124),
    [sym_permissionsetextension_declaration] = STATE(1124),
    [sym_controladdin_declaration] = STATE(1124),
    [sym_profile_declaration] = STATE(1124),
    [sym_entitlement_declaration] = STATE(1124),
    [sym_profileextension_declaration] = STATE(1124),
    [sym_interface_declaration] = STATE(1124),
    [sym_pagecustomization_declaration] = STATE(1124),
    [sym_dotnet_declaration] = STATE(1124),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(1953),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(1124),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1567),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(1046)] = {
    [sym_preproc_conditional_object] = STATE(1108),
    [sym_namespace_declaration] = STATE(1093),
    [sym_using_statement] = STATE(1108),
    [sym__object] = STATE(1108),
    [sym_preproc_split_declaration] = STATE(1108),
    [sym_table_declaration] = STATE(1108),
    [sym_page_declaration] = STATE(1108),
    [sym_report_declaration] = STATE(1108),
    [sym_query_declaration] = STATE(1108),
    [sym_xmlport_declaration] = STATE(1108),
    [sym_permissionset_declaration] = STATE(1108),
    [sym_codeunit_declaration] = STATE(1108),
    [sym_enum_declaration] = STATE(1108),
    [sym_tableextension_declaration] = STATE(1108),
    [sym_pageextension_declaration] = STATE(1108),
    [sym_reportextension_declaration] = STATE(1108),
    [sym_enumextension_declaration] = STATE(1108),
    [sym_permissionsetextension_declaration] = STATE(1108),
    [sym_controladdin_declaration] = STATE(1108),
    [sym_profile_declaration] = STATE(1108),
    [sym_entitlement_declaration] = STATE(1108),
    [sym_profileextension_declaration] = STATE(1108),
    [sym_interface_declaration] = STATE(1108),
    [sym_pagecustomization_declaration] = STATE(1108),
    [sym_dotnet_declaration] = STATE(1108),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(1969),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(1108),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1567),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(1047)] = {
    [sym_preproc_conditional_object] = STATE(1098),
    [sym_namespace_declaration] = STATE(1117),
    [sym_using_statement] = STATE(1098),
    [sym__object] = STATE(1098),
    [sym_preproc_split_declaration] = STATE(1098),
    [sym_table_declaration] = STATE(1098),
    [sym_page_declaration] = STATE(1098),
    [sym_report_declaration] = STATE(1098),
    [sym_query_declaration] = STATE(1098),
    [sym_xmlport_declaration] = STATE(1098),
    [sym_permissionset_declaration] = STATE(1098),
    [sym_codeunit_declaration] = STATE(1098),
    [sym_enum_declaration] = STATE(1098),
    [sym_tableextension_declaration] = STATE(1098),
    [sym_pageextension_declaration] = STATE(1098),
    [sym_reportextension_declaration] = STATE(1098),
    [sym_enumextension_declaration] = STATE(1098),
    [sym_permissionsetextension_declaration] = STATE(1098),
    [sym_controladdin_declaration] = STATE(1098),
    [sym_profile_declaration] = STATE(1098),
    [sym_entitlement_declaration] = STATE(1098),
    [sym_profileextension_declaration] = STATE(1098),
    [sym_interface_declaration] = STATE(1098),
    [sym_pagecustomization_declaration] = STATE(1098),
    [sym_dotnet_declaration] = STATE(1098),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(2496),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(1098),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1567),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(1048)] = {
    [sym_preproc_conditional_object] = STATE(1103),
    [sym_namespace_declaration] = STATE(1125),
    [sym_using_statement] = STATE(1103),
    [sym__object] = STATE(1103),
    [sym_preproc_split_declaration] = STATE(1103),
    [sym_table_declaration] = STATE(1103),
    [sym_page_declaration] = STATE(1103),
    [sym_report_declaration] = STATE(1103),
    [sym_query_declaration] = STATE(1103),
    [sym_xmlport_declaration] = STATE(1103),
    [sym_permissionset_declaration] = STATE(1103),
    [sym_codeunit_declaration] = STATE(1103),
    [sym_enum_declaration] = STATE(1103),
    [sym_tableextension_declaration] = STATE(1103),
    [sym_pageextension_declaration] = STATE(1103),
    [sym_reportextension_declaration] = STATE(1103),
    [sym_enumextension_declaration] = STATE(1103),
    [sym_permissionsetextension_declaration] = STATE(1103),
    [sym_controladdin_declaration] = STATE(1103),
    [sym_profile_declaration] = STATE(1103),
    [sym_entitlement_declaration] = STATE(1103),
    [sym_profileextension_declaration] = STATE(1103),
    [sym_interface_declaration] = STATE(1103),
    [sym_pagecustomization_declaration] = STATE(1103),
    [sym_dotnet_declaration] = STATE(1103),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(1959),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(1103),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1567),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(1049)] = {
    [sym_preproc_conditional_object] = STATE(1121),
    [sym_namespace_declaration] = STATE(1122),
    [sym_using_statement] = STATE(1121),
    [sym__object] = STATE(1121),
    [sym_preproc_split_declaration] = STATE(1121),
    [sym_table_declaration] = STATE(1121),
    [sym_page_declaration] = STATE(1121),
    [sym_report_declaration] = STATE(1121),
    [sym_query_declaration] = STATE(1121),
    [sym_xmlport_declaration] = STATE(1121),
    [sym_permissionset_declaration] = STATE(1121),
    [sym_codeunit_declaration] = STATE(1121),
    [sym_enum_declaration] = STATE(1121),
    [sym_tableextension_declaration] = STATE(1121),
    [sym_pageextension_declaration] = STATE(1121),
    [sym_reportextension_declaration] = STATE(1121),
    [sym_enumextension_declaration] = STATE(1121),
    [sym_permissionsetextension_declaration] = STATE(1121),
    [sym_controladdin_declaration] = STATE(1121),
    [sym_profile_declaration] = STATE(1121),
    [sym_entitlement_declaration] = STATE(1121),
    [sym_profileextension_declaration] = STATE(1121),
    [sym_interface_declaration] = STATE(1121),
    [sym_pagecustomization_declaration] = STATE(1121),
    [sym_dotnet_declaration] = STATE(1121),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(2469),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(1121),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1567),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(1050)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_SEMI] = ACTIONS(2428),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_COMMA] = ACTIONS(2428),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2426),
    [anon_sym_COLON_COLON] = ACTIONS(2428),
    [anon_sym_POUNDif] = ACTIONS(2428),
    [anon_sym_POUNDIF] = ACTIONS(2428),
    [anon_sym_POUNDIf] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [anon_sym_POUNDelse] = ACTIONS(2428),
    [anon_sym_POUNDELSE] = ACTIONS(2428),
    [anon_sym_POUNDElse] = ACTIONS(2428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_IF] = ACTIONS(2426),
    [anon_sym_If] = ACTIONS(2426),
    [anon_sym_else] = ACTIONS(2426),
    [anon_sym_ELSE] = ACTIONS(2426),
    [anon_sym_Else] = ACTIONS(2426),
    [anon_sym_case] = ACTIONS(2426),
    [anon_sym_CASE] = ACTIONS(2426),
    [anon_sym_Case] = ACTIONS(2426),
    [anon_sym_for] = ACTIONS(2426),
    [anon_sym_FOR] = ACTIONS(2426),
    [anon_sym_For] = ACTIONS(2426),
    [anon_sym_foreach] = ACTIONS(2426),
    [anon_sym_FOREACH] = ACTIONS(2426),
    [anon_sym_Foreach] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(2426),
    [anon_sym_WHILE] = ACTIONS(2426),
    [anon_sym_While] = ACTIONS(2426),
    [anon_sym_repeat] = ACTIONS(2426),
    [anon_sym_REPEAT] = ACTIONS(2426),
    [anon_sym_Repeat] = ACTIONS(2426),
    [anon_sym_until] = ACTIONS(2426),
    [anon_sym_UNTIL] = ACTIONS(2426),
    [anon_sym_Until] = ACTIONS(2426),
    [anon_sym_exit] = ACTIONS(2426),
    [anon_sym_EXIT] = ACTIONS(2426),
    [anon_sym_Exit] = ACTIONS(2426),
    [anon_sym_continue] = ACTIONS(2426),
    [anon_sym_CONTINUE] = ACTIONS(2426),
    [anon_sym_Continue] = ACTIONS(2426),
    [anon_sym_break] = ACTIONS(2426),
    [anon_sym_BREAK] = ACTIONS(2426),
    [anon_sym_Break] = ACTIONS(2426),
    [anon_sym_with] = ACTIONS(2426),
    [anon_sym_WITH] = ACTIONS(2426),
    [anon_sym_With] = ACTIONS(2426),
    [sym_asserterror_keyword] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_open] = ACTIONS(2428),
  },
  [STATE(1051)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_until] = ACTIONS(2320),
    [anon_sym_UNTIL] = ACTIONS(2320),
    [anon_sym_Until] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
  },
  [STATE(1052)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_until] = ACTIONS(2320),
    [anon_sym_UNTIL] = ACTIONS(2320),
    [anon_sym_Until] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
  },
  [STATE(1053)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_until] = ACTIONS(2320),
    [anon_sym_UNTIL] = ACTIONS(2320),
    [anon_sym_Until] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
  },
  [STATE(1054)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_until] = ACTIONS(2320),
    [anon_sym_UNTIL] = ACTIONS(2320),
    [anon_sym_Until] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
  },
  [STATE(1055)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_until] = ACTIONS(2320),
    [anon_sym_UNTIL] = ACTIONS(2320),
    [anon_sym_Until] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
  },
  [STATE(1056)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_until] = ACTIONS(2320),
    [anon_sym_UNTIL] = ACTIONS(2320),
    [anon_sym_Until] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
  },
  [STATE(1057)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2360),
    [anon_sym_SEMI] = ACTIONS(2362),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2362),
    [anon_sym_DASH] = ACTIONS(2360),
    [aux_sym_boolean_token1] = ACTIONS(2360),
    [aux_sym_boolean_token2] = ACTIONS(2360),
    [sym_decimal] = ACTIONS(2360),
    [anon_sym_LPAREN] = ACTIONS(2362),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2360),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2360),
    [aux_sym_basic_type_token21] = ACTIONS(2360),
    [aux_sym_basic_type_token22] = ACTIONS(2360),
    [aux_sym_basic_type_token48] = ACTIONS(2360),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2360),
    [anon_sym_POUNDif] = ACTIONS(2362),
    [anon_sym_POUNDIF] = ACTIONS(2362),
    [anon_sym_POUNDIf] = ACTIONS(2362),
    [anon_sym_not] = ACTIONS(2360),
    [anon_sym_NOT] = ACTIONS(2360),
    [anon_sym_Not] = ACTIONS(2360),
    [anon_sym_POUNDelse] = ACTIONS(2362),
    [anon_sym_POUNDELSE] = ACTIONS(2362),
    [anon_sym_POUNDElse] = ACTIONS(2362),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2362),
    [aux_sym__expression_token1] = ACTIONS(2362),
    [aux_sym__expression_token2] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2360),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2360),
    [anon_sym_GT_EQ] = ACTIONS(2362),
    [anon_sym_LT_EQ] = ACTIONS(2362),
    [anon_sym_GT] = ACTIONS(2360),
    [anon_sym_LT] = ACTIONS(2360),
    [anon_sym_LT_GT] = ACTIONS(2362),
    [anon_sym_and] = ACTIONS(2360),
    [anon_sym_AND] = ACTIONS(2360),
    [anon_sym_And] = ACTIONS(2360),
    [anon_sym_or] = ACTIONS(2360),
    [anon_sym_OR] = ACTIONS(2360),
    [anon_sym_Or] = ACTIONS(2360),
    [anon_sym_xor] = ACTIONS(2360),
    [anon_sym_XOR] = ACTIONS(2360),
    [anon_sym_Xor] = ACTIONS(2360),
    [anon_sym_QMARK] = ACTIONS(2362),
    [sym_datetime_literal] = ACTIONS(2362),
    [sym_date_literal] = ACTIONS(2360),
    [sym_time_literal] = ACTIONS(2360),
    [sym_biginteger_literal] = ACTIONS(2362),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_IF] = ACTIONS(2360),
    [anon_sym_If] = ACTIONS(2360),
    [anon_sym_else] = ACTIONS(2360),
    [anon_sym_ELSE] = ACTIONS(2360),
    [anon_sym_Else] = ACTIONS(2360),
    [anon_sym_case] = ACTIONS(2360),
    [anon_sym_CASE] = ACTIONS(2360),
    [anon_sym_Case] = ACTIONS(2360),
    [anon_sym_for] = ACTIONS(2360),
    [anon_sym_FOR] = ACTIONS(2360),
    [anon_sym_For] = ACTIONS(2360),
    [anon_sym_foreach] = ACTIONS(2360),
    [anon_sym_FOREACH] = ACTIONS(2360),
    [anon_sym_Foreach] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2360),
    [anon_sym_WHILE] = ACTIONS(2360),
    [anon_sym_While] = ACTIONS(2360),
    [anon_sym_repeat] = ACTIONS(2360),
    [anon_sym_REPEAT] = ACTIONS(2360),
    [anon_sym_Repeat] = ACTIONS(2360),
    [anon_sym_until] = ACTIONS(2360),
    [anon_sym_UNTIL] = ACTIONS(2360),
    [anon_sym_Until] = ACTIONS(2360),
    [anon_sym_exit] = ACTIONS(2360),
    [anon_sym_EXIT] = ACTIONS(2360),
    [anon_sym_Exit] = ACTIONS(2360),
    [anon_sym_continue] = ACTIONS(2360),
    [anon_sym_CONTINUE] = ACTIONS(2360),
    [anon_sym_Continue] = ACTIONS(2360),
    [anon_sym_break] = ACTIONS(2360),
    [anon_sym_BREAK] = ACTIONS(2360),
    [anon_sym_Break] = ACTIONS(2360),
    [anon_sym_with] = ACTIONS(2360),
    [anon_sym_WITH] = ACTIONS(2360),
    [anon_sym_With] = ACTIONS(2360),
    [sym_asserterror_keyword] = ACTIONS(2362),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_IN] = ACTIONS(2360),
    [anon_sym_In] = ACTIONS(2360),
    [sym_page_keyword] = ACTIONS(2360),
    [anon_sym_codeunit] = ACTIONS(2360),
    [anon_sym_CODEUNIT] = ACTIONS(2360),
    [anon_sym_Codeunit] = ACTIONS(2360),
    [anon_sym_CodeUnit] = ACTIONS(2360),
    [anon_sym_COdeunit] = ACTIONS(2360),
    [anon_sym_codeUnit] = ACTIONS(2360),
    [sym_report_keyword] = ACTIONS(2360),
    [sym_query_keyword] = ACTIONS(2360),
    [anon_sym_xmlport] = ACTIONS(2360),
    [anon_sym_XMLPORT] = ACTIONS(2360),
    [anon_sym_Xmlport] = ACTIONS(2360),
    [anon_sym_XMLport] = ACTIONS(2360),
    [anon_sym_XMLPort] = ACTIONS(2360),
    [anon_sym_XmlPort] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_ENUM] = ACTIONS(2360),
    [anon_sym_Enum] = ACTIONS(2360),
    [anon_sym_eNUM] = ACTIONS(2360),
    [anon_sym_eNum] = ACTIONS(2360),
    [anon_sym_ENum] = ACTIONS(2360),
    [sym_quoted_identifier] = ACTIONS(2362),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2362),
    [sym_integer] = ACTIONS(2360),
    [sym_continue_as_identifier] = ACTIONS(2362),
    [sym_preproc_open] = ACTIONS(2362),
  },
  [STATE(1058)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2675),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_until] = ACTIONS(2270),
    [anon_sym_UNTIL] = ACTIONS(2270),
    [anon_sym_Until] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(1059)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2675),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_until] = ACTIONS(2270),
    [anon_sym_UNTIL] = ACTIONS(2270),
    [anon_sym_Until] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(1060)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2675),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_until] = ACTIONS(2270),
    [anon_sym_UNTIL] = ACTIONS(2270),
    [anon_sym_Until] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(1061)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2675),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2683),
    [anon_sym_AND] = ACTIONS(2685),
    [anon_sym_And] = ACTIONS(2687),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_until] = ACTIONS(2270),
    [anon_sym_UNTIL] = ACTIONS(2270),
    [anon_sym_Until] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(1062)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2675),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2683),
    [anon_sym_AND] = ACTIONS(2685),
    [anon_sym_And] = ACTIONS(2687),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_until] = ACTIONS(2270),
    [anon_sym_UNTIL] = ACTIONS(2270),
    [anon_sym_Until] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(1063)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2675),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2683),
    [anon_sym_AND] = ACTIONS(2685),
    [anon_sym_And] = ACTIONS(2687),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_until] = ACTIONS(2270),
    [anon_sym_UNTIL] = ACTIONS(2270),
    [anon_sym_Until] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(1064)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2675),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2683),
    [anon_sym_AND] = ACTIONS(2685),
    [anon_sym_And] = ACTIONS(2687),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_until] = ACTIONS(2270),
    [anon_sym_UNTIL] = ACTIONS(2270),
    [anon_sym_Until] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(1065)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2675),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2683),
    [anon_sym_AND] = ACTIONS(2685),
    [anon_sym_And] = ACTIONS(2687),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_until] = ACTIONS(2270),
    [anon_sym_UNTIL] = ACTIONS(2270),
    [anon_sym_Until] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(1066)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2675),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2683),
    [anon_sym_AND] = ACTIONS(2685),
    [anon_sym_And] = ACTIONS(2687),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_until] = ACTIONS(2270),
    [anon_sym_UNTIL] = ACTIONS(2270),
    [anon_sym_Until] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(1067)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2364),
    [anon_sym_SEMI] = ACTIONS(2366),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2366),
    [anon_sym_DASH] = ACTIONS(2675),
    [aux_sym_boolean_token1] = ACTIONS(2364),
    [aux_sym_boolean_token2] = ACTIONS(2364),
    [sym_decimal] = ACTIONS(2364),
    [anon_sym_LPAREN] = ACTIONS(2366),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2364),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2364),
    [aux_sym_basic_type_token21] = ACTIONS(2364),
    [aux_sym_basic_type_token22] = ACTIONS(2364),
    [aux_sym_basic_type_token48] = ACTIONS(2364),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2364),
    [anon_sym_POUNDif] = ACTIONS(2366),
    [anon_sym_POUNDIF] = ACTIONS(2366),
    [anon_sym_POUNDIf] = ACTIONS(2366),
    [anon_sym_not] = ACTIONS(2364),
    [anon_sym_NOT] = ACTIONS(2364),
    [anon_sym_Not] = ACTIONS(2364),
    [anon_sym_POUNDelse] = ACTIONS(2366),
    [anon_sym_POUNDELSE] = ACTIONS(2366),
    [anon_sym_POUNDElse] = ACTIONS(2366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2366),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2364),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2364),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_GT_EQ] = ACTIONS(2366),
    [anon_sym_LT_EQ] = ACTIONS(2366),
    [anon_sym_GT] = ACTIONS(2364),
    [anon_sym_LT] = ACTIONS(2364),
    [anon_sym_LT_GT] = ACTIONS(2366),
    [anon_sym_and] = ACTIONS(2364),
    [anon_sym_AND] = ACTIONS(2364),
    [anon_sym_And] = ACTIONS(2364),
    [anon_sym_or] = ACTIONS(2364),
    [anon_sym_OR] = ACTIONS(2364),
    [anon_sym_Or] = ACTIONS(2364),
    [anon_sym_xor] = ACTIONS(2364),
    [anon_sym_XOR] = ACTIONS(2364),
    [anon_sym_Xor] = ACTIONS(2364),
    [anon_sym_QMARK] = ACTIONS(2366),
    [sym_datetime_literal] = ACTIONS(2366),
    [sym_date_literal] = ACTIONS(2364),
    [sym_time_literal] = ACTIONS(2364),
    [sym_biginteger_literal] = ACTIONS(2366),
    [anon_sym_if] = ACTIONS(2364),
    [anon_sym_IF] = ACTIONS(2364),
    [anon_sym_If] = ACTIONS(2364),
    [anon_sym_else] = ACTIONS(2364),
    [anon_sym_ELSE] = ACTIONS(2364),
    [anon_sym_Else] = ACTIONS(2364),
    [anon_sym_case] = ACTIONS(2364),
    [anon_sym_CASE] = ACTIONS(2364),
    [anon_sym_Case] = ACTIONS(2364),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_FOR] = ACTIONS(2364),
    [anon_sym_For] = ACTIONS(2364),
    [anon_sym_foreach] = ACTIONS(2364),
    [anon_sym_FOREACH] = ACTIONS(2364),
    [anon_sym_Foreach] = ACTIONS(2364),
    [anon_sym_while] = ACTIONS(2364),
    [anon_sym_WHILE] = ACTIONS(2364),
    [anon_sym_While] = ACTIONS(2364),
    [anon_sym_repeat] = ACTIONS(2364),
    [anon_sym_REPEAT] = ACTIONS(2364),
    [anon_sym_Repeat] = ACTIONS(2364),
    [anon_sym_until] = ACTIONS(2364),
    [anon_sym_UNTIL] = ACTIONS(2364),
    [anon_sym_Until] = ACTIONS(2364),
    [anon_sym_exit] = ACTIONS(2364),
    [anon_sym_EXIT] = ACTIONS(2364),
    [anon_sym_Exit] = ACTIONS(2364),
    [anon_sym_continue] = ACTIONS(2364),
    [anon_sym_CONTINUE] = ACTIONS(2364),
    [anon_sym_Continue] = ACTIONS(2364),
    [anon_sym_break] = ACTIONS(2364),
    [anon_sym_BREAK] = ACTIONS(2364),
    [anon_sym_Break] = ACTIONS(2364),
    [anon_sym_with] = ACTIONS(2364),
    [anon_sym_WITH] = ACTIONS(2364),
    [anon_sym_With] = ACTIONS(2364),
    [sym_asserterror_keyword] = ACTIONS(2366),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2364),
    [anon_sym_codeunit] = ACTIONS(2364),
    [anon_sym_CODEUNIT] = ACTIONS(2364),
    [anon_sym_Codeunit] = ACTIONS(2364),
    [anon_sym_CodeUnit] = ACTIONS(2364),
    [anon_sym_COdeunit] = ACTIONS(2364),
    [anon_sym_codeUnit] = ACTIONS(2364),
    [sym_report_keyword] = ACTIONS(2364),
    [sym_query_keyword] = ACTIONS(2364),
    [anon_sym_xmlport] = ACTIONS(2364),
    [anon_sym_XMLPORT] = ACTIONS(2364),
    [anon_sym_Xmlport] = ACTIONS(2364),
    [anon_sym_XMLport] = ACTIONS(2364),
    [anon_sym_XMLPort] = ACTIONS(2364),
    [anon_sym_XmlPort] = ACTIONS(2364),
    [anon_sym_enum] = ACTIONS(2364),
    [anon_sym_ENUM] = ACTIONS(2364),
    [anon_sym_Enum] = ACTIONS(2364),
    [anon_sym_eNUM] = ACTIONS(2364),
    [anon_sym_eNum] = ACTIONS(2364),
    [anon_sym_ENum] = ACTIONS(2364),
    [sym_quoted_identifier] = ACTIONS(2366),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2366),
    [sym_integer] = ACTIONS(2364),
    [sym_continue_as_identifier] = ACTIONS(2366),
    [sym_preproc_open] = ACTIONS(2366),
  },
  [STATE(1068)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2368),
    [anon_sym_SEMI] = ACTIONS(2370),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2675),
    [aux_sym_boolean_token1] = ACTIONS(2368),
    [aux_sym_boolean_token2] = ACTIONS(2368),
    [sym_decimal] = ACTIONS(2368),
    [anon_sym_LPAREN] = ACTIONS(2370),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2368),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2368),
    [aux_sym_basic_type_token21] = ACTIONS(2368),
    [aux_sym_basic_type_token22] = ACTIONS(2368),
    [aux_sym_basic_type_token48] = ACTIONS(2368),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2368),
    [anon_sym_POUNDif] = ACTIONS(2370),
    [anon_sym_POUNDIF] = ACTIONS(2370),
    [anon_sym_POUNDIf] = ACTIONS(2370),
    [anon_sym_not] = ACTIONS(2368),
    [anon_sym_NOT] = ACTIONS(2368),
    [anon_sym_Not] = ACTIONS(2368),
    [anon_sym_POUNDelse] = ACTIONS(2370),
    [anon_sym_POUNDELSE] = ACTIONS(2370),
    [anon_sym_POUNDElse] = ACTIONS(2370),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2370),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2368),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2368),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2683),
    [anon_sym_AND] = ACTIONS(2685),
    [anon_sym_And] = ACTIONS(2687),
    [anon_sym_or] = ACTIONS(2689),
    [anon_sym_OR] = ACTIONS(2691),
    [anon_sym_Or] = ACTIONS(2693),
    [anon_sym_xor] = ACTIONS(2695),
    [anon_sym_XOR] = ACTIONS(2697),
    [anon_sym_Xor] = ACTIONS(2699),
    [anon_sym_QMARK] = ACTIONS(2701),
    [sym_datetime_literal] = ACTIONS(2370),
    [sym_date_literal] = ACTIONS(2368),
    [sym_time_literal] = ACTIONS(2368),
    [sym_biginteger_literal] = ACTIONS(2370),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_IF] = ACTIONS(2368),
    [anon_sym_If] = ACTIONS(2368),
    [anon_sym_else] = ACTIONS(2368),
    [anon_sym_ELSE] = ACTIONS(2368),
    [anon_sym_Else] = ACTIONS(2368),
    [anon_sym_case] = ACTIONS(2368),
    [anon_sym_CASE] = ACTIONS(2368),
    [anon_sym_Case] = ACTIONS(2368),
    [anon_sym_for] = ACTIONS(2368),
    [anon_sym_FOR] = ACTIONS(2368),
    [anon_sym_For] = ACTIONS(2368),
    [anon_sym_foreach] = ACTIONS(2368),
    [anon_sym_FOREACH] = ACTIONS(2368),
    [anon_sym_Foreach] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2368),
    [anon_sym_WHILE] = ACTIONS(2368),
    [anon_sym_While] = ACTIONS(2368),
    [anon_sym_repeat] = ACTIONS(2368),
    [anon_sym_REPEAT] = ACTIONS(2368),
    [anon_sym_Repeat] = ACTIONS(2368),
    [anon_sym_until] = ACTIONS(2368),
    [anon_sym_UNTIL] = ACTIONS(2368),
    [anon_sym_Until] = ACTIONS(2368),
    [anon_sym_exit] = ACTIONS(2368),
    [anon_sym_EXIT] = ACTIONS(2368),
    [anon_sym_Exit] = ACTIONS(2368),
    [anon_sym_continue] = ACTIONS(2368),
    [anon_sym_CONTINUE] = ACTIONS(2368),
    [anon_sym_Continue] = ACTIONS(2368),
    [anon_sym_break] = ACTIONS(2368),
    [anon_sym_BREAK] = ACTIONS(2368),
    [anon_sym_Break] = ACTIONS(2368),
    [anon_sym_with] = ACTIONS(2368),
    [anon_sym_WITH] = ACTIONS(2368),
    [anon_sym_With] = ACTIONS(2368),
    [sym_asserterror_keyword] = ACTIONS(2370),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2368),
    [anon_sym_codeunit] = ACTIONS(2368),
    [anon_sym_CODEUNIT] = ACTIONS(2368),
    [anon_sym_Codeunit] = ACTIONS(2368),
    [anon_sym_CodeUnit] = ACTIONS(2368),
    [anon_sym_COdeunit] = ACTIONS(2368),
    [anon_sym_codeUnit] = ACTIONS(2368),
    [sym_report_keyword] = ACTIONS(2368),
    [sym_query_keyword] = ACTIONS(2368),
    [anon_sym_xmlport] = ACTIONS(2368),
    [anon_sym_XMLPORT] = ACTIONS(2368),
    [anon_sym_Xmlport] = ACTIONS(2368),
    [anon_sym_XMLport] = ACTIONS(2368),
    [anon_sym_XMLPort] = ACTIONS(2368),
    [anon_sym_XmlPort] = ACTIONS(2368),
    [anon_sym_enum] = ACTIONS(2368),
    [anon_sym_ENUM] = ACTIONS(2368),
    [anon_sym_Enum] = ACTIONS(2368),
    [anon_sym_eNUM] = ACTIONS(2368),
    [anon_sym_eNum] = ACTIONS(2368),
    [anon_sym_ENum] = ACTIONS(2368),
    [sym_quoted_identifier] = ACTIONS(2370),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2370),
    [sym_integer] = ACTIONS(2368),
    [sym_continue_as_identifier] = ACTIONS(2370),
    [sym_preproc_open] = ACTIONS(2370),
  },
  [STATE(1069)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1071),
    [sym_identifier] = ACTIONS(2354),
    [anon_sym_SEMI] = ACTIONS(2356),
    [anon_sym_DOT] = ACTIONS(2354),
    [anon_sym_EQ] = ACTIONS(2356),
    [anon_sym_COMMA] = ACTIONS(2703),
    [anon_sym_DASH] = ACTIONS(2354),
    [aux_sym_boolean_token1] = ACTIONS(2354),
    [aux_sym_boolean_token2] = ACTIONS(2354),
    [sym_decimal] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(2356),
    [anon_sym_DOT_DOT] = ACTIONS(2356),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2354),
    [anon_sym_STAR] = ACTIONS(2354),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [aux_sym_record_type_token1] = ACTIONS(2354),
    [aux_sym_basic_type_token21] = ACTIONS(2354),
    [aux_sym_basic_type_token22] = ACTIONS(2354),
    [aux_sym_basic_type_token48] = ACTIONS(2354),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2354),
    [anon_sym_POUNDif] = ACTIONS(2356),
    [anon_sym_POUNDIF] = ACTIONS(2356),
    [anon_sym_POUNDIf] = ACTIONS(2356),
    [anon_sym_not] = ACTIONS(2354),
    [anon_sym_NOT] = ACTIONS(2354),
    [anon_sym_Not] = ACTIONS(2354),
    [anon_sym_POUNDelse] = ACTIONS(2356),
    [anon_sym_POUNDELSE] = ACTIONS(2356),
    [anon_sym_POUNDElse] = ACTIONS(2356),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2356),
    [aux_sym__expression_token1] = ACTIONS(2356),
    [aux_sym__expression_token2] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2354),
    [anon_sym_SLASH] = ACTIONS(2354),
    [anon_sym_div] = ACTIONS(2354),
    [anon_sym_DIV] = ACTIONS(2354),
    [anon_sym_Div] = ACTIONS(2354),
    [anon_sym_mod] = ACTIONS(2354),
    [anon_sym_MOD] = ACTIONS(2354),
    [anon_sym_Mod] = ACTIONS(2354),
    [anon_sym_PLUS] = ACTIONS(2354),
    [anon_sym_GT_EQ] = ACTIONS(2356),
    [anon_sym_LT_EQ] = ACTIONS(2356),
    [anon_sym_GT] = ACTIONS(2354),
    [anon_sym_LT] = ACTIONS(2354),
    [anon_sym_LT_GT] = ACTIONS(2356),
    [anon_sym_and] = ACTIONS(2354),
    [anon_sym_AND] = ACTIONS(2354),
    [anon_sym_And] = ACTIONS(2354),
    [anon_sym_or] = ACTIONS(2354),
    [anon_sym_OR] = ACTIONS(2354),
    [anon_sym_Or] = ACTIONS(2354),
    [anon_sym_xor] = ACTIONS(2354),
    [anon_sym_XOR] = ACTIONS(2354),
    [anon_sym_Xor] = ACTIONS(2354),
    [anon_sym_QMARK] = ACTIONS(2356),
    [sym_datetime_literal] = ACTIONS(2356),
    [sym_date_literal] = ACTIONS(2354),
    [sym_time_literal] = ACTIONS(2354),
    [sym_biginteger_literal] = ACTIONS(2356),
    [anon_sym_if] = ACTIONS(2354),
    [anon_sym_IF] = ACTIONS(2354),
    [anon_sym_If] = ACTIONS(2354),
    [anon_sym_else] = ACTIONS(2354),
    [anon_sym_ELSE] = ACTIONS(2354),
    [anon_sym_Else] = ACTIONS(2354),
    [anon_sym_case] = ACTIONS(2354),
    [anon_sym_CASE] = ACTIONS(2354),
    [anon_sym_Case] = ACTIONS(2354),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_FOR] = ACTIONS(2354),
    [anon_sym_For] = ACTIONS(2354),
    [anon_sym_foreach] = ACTIONS(2354),
    [anon_sym_FOREACH] = ACTIONS(2354),
    [anon_sym_Foreach] = ACTIONS(2354),
    [anon_sym_while] = ACTIONS(2354),
    [anon_sym_WHILE] = ACTIONS(2354),
    [anon_sym_While] = ACTIONS(2354),
    [anon_sym_repeat] = ACTIONS(2354),
    [anon_sym_REPEAT] = ACTIONS(2354),
    [anon_sym_Repeat] = ACTIONS(2354),
    [anon_sym_until] = ACTIONS(2354),
    [anon_sym_UNTIL] = ACTIONS(2354),
    [anon_sym_Until] = ACTIONS(2354),
    [anon_sym_exit] = ACTIONS(2354),
    [anon_sym_EXIT] = ACTIONS(2354),
    [anon_sym_Exit] = ACTIONS(2354),
    [anon_sym_continue] = ACTIONS(2354),
    [anon_sym_CONTINUE] = ACTIONS(2354),
    [anon_sym_Continue] = ACTIONS(2354),
    [anon_sym_break] = ACTIONS(2354),
    [anon_sym_BREAK] = ACTIONS(2354),
    [anon_sym_Break] = ACTIONS(2354),
    [anon_sym_with] = ACTIONS(2354),
    [anon_sym_WITH] = ACTIONS(2354),
    [anon_sym_With] = ACTIONS(2354),
    [sym_asserterror_keyword] = ACTIONS(2356),
    [anon_sym_in] = ACTIONS(2354),
    [anon_sym_IN] = ACTIONS(2354),
    [anon_sym_In] = ACTIONS(2354),
    [sym_page_keyword] = ACTIONS(2354),
    [anon_sym_codeunit] = ACTIONS(2354),
    [anon_sym_CODEUNIT] = ACTIONS(2354),
    [anon_sym_Codeunit] = ACTIONS(2354),
    [anon_sym_CodeUnit] = ACTIONS(2354),
    [anon_sym_COdeunit] = ACTIONS(2354),
    [anon_sym_codeUnit] = ACTIONS(2354),
    [sym_report_keyword] = ACTIONS(2354),
    [sym_query_keyword] = ACTIONS(2354),
    [anon_sym_xmlport] = ACTIONS(2354),
    [anon_sym_XMLPORT] = ACTIONS(2354),
    [anon_sym_Xmlport] = ACTIONS(2354),
    [anon_sym_XMLport] = ACTIONS(2354),
    [anon_sym_XMLPort] = ACTIONS(2354),
    [anon_sym_XmlPort] = ACTIONS(2354),
    [anon_sym_enum] = ACTIONS(2354),
    [anon_sym_ENUM] = ACTIONS(2354),
    [anon_sym_Enum] = ACTIONS(2354),
    [anon_sym_eNUM] = ACTIONS(2354),
    [anon_sym_eNum] = ACTIONS(2354),
    [anon_sym_ENum] = ACTIONS(2354),
    [sym_quoted_identifier] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2356),
    [sym_integer] = ACTIONS(2354),
    [sym_continue_as_identifier] = ACTIONS(2356),
    [sym_preproc_open] = ACTIONS(2356),
  },
  [STATE(1070)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_until] = ACTIONS(2320),
    [anon_sym_UNTIL] = ACTIONS(2320),
    [anon_sym_Until] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
  },
  [STATE(1071)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1082),
    [sym_identifier] = ACTIONS(2410),
    [anon_sym_SEMI] = ACTIONS(2412),
    [anon_sym_DOT] = ACTIONS(2410),
    [anon_sym_EQ] = ACTIONS(2412),
    [anon_sym_COMMA] = ACTIONS(2703),
    [anon_sym_DASH] = ACTIONS(2410),
    [aux_sym_boolean_token1] = ACTIONS(2410),
    [aux_sym_boolean_token2] = ACTIONS(2410),
    [sym_decimal] = ACTIONS(2410),
    [anon_sym_LPAREN] = ACTIONS(2412),
    [anon_sym_DOT_DOT] = ACTIONS(2412),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2410),
    [anon_sym_STAR] = ACTIONS(2410),
    [anon_sym_LBRACK] = ACTIONS(2412),
    [aux_sym_record_type_token1] = ACTIONS(2410),
    [aux_sym_basic_type_token21] = ACTIONS(2410),
    [aux_sym_basic_type_token22] = ACTIONS(2410),
    [aux_sym_basic_type_token48] = ACTIONS(2410),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2410),
    [anon_sym_POUNDif] = ACTIONS(2412),
    [anon_sym_POUNDIF] = ACTIONS(2412),
    [anon_sym_POUNDIf] = ACTIONS(2412),
    [anon_sym_not] = ACTIONS(2410),
    [anon_sym_NOT] = ACTIONS(2410),
    [anon_sym_Not] = ACTIONS(2410),
    [anon_sym_POUNDelse] = ACTIONS(2412),
    [anon_sym_POUNDELSE] = ACTIONS(2412),
    [anon_sym_POUNDElse] = ACTIONS(2412),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2412),
    [aux_sym__expression_token1] = ACTIONS(2412),
    [aux_sym__expression_token2] = ACTIONS(2410),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2410),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2410),
    [anon_sym_SLASH] = ACTIONS(2410),
    [anon_sym_div] = ACTIONS(2410),
    [anon_sym_DIV] = ACTIONS(2410),
    [anon_sym_Div] = ACTIONS(2410),
    [anon_sym_mod] = ACTIONS(2410),
    [anon_sym_MOD] = ACTIONS(2410),
    [anon_sym_Mod] = ACTIONS(2410),
    [anon_sym_PLUS] = ACTIONS(2410),
    [anon_sym_GT_EQ] = ACTIONS(2412),
    [anon_sym_LT_EQ] = ACTIONS(2412),
    [anon_sym_GT] = ACTIONS(2410),
    [anon_sym_LT] = ACTIONS(2410),
    [anon_sym_LT_GT] = ACTIONS(2412),
    [anon_sym_and] = ACTIONS(2410),
    [anon_sym_AND] = ACTIONS(2410),
    [anon_sym_And] = ACTIONS(2410),
    [anon_sym_or] = ACTIONS(2410),
    [anon_sym_OR] = ACTIONS(2410),
    [anon_sym_Or] = ACTIONS(2410),
    [anon_sym_xor] = ACTIONS(2410),
    [anon_sym_XOR] = ACTIONS(2410),
    [anon_sym_Xor] = ACTIONS(2410),
    [anon_sym_QMARK] = ACTIONS(2412),
    [sym_datetime_literal] = ACTIONS(2412),
    [sym_date_literal] = ACTIONS(2410),
    [sym_time_literal] = ACTIONS(2410),
    [sym_biginteger_literal] = ACTIONS(2412),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_IF] = ACTIONS(2410),
    [anon_sym_If] = ACTIONS(2410),
    [anon_sym_else] = ACTIONS(2410),
    [anon_sym_ELSE] = ACTIONS(2410),
    [anon_sym_Else] = ACTIONS(2410),
    [anon_sym_case] = ACTIONS(2410),
    [anon_sym_CASE] = ACTIONS(2410),
    [anon_sym_Case] = ACTIONS(2410),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_FOR] = ACTIONS(2410),
    [anon_sym_For] = ACTIONS(2410),
    [anon_sym_foreach] = ACTIONS(2410),
    [anon_sym_FOREACH] = ACTIONS(2410),
    [anon_sym_Foreach] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2410),
    [anon_sym_WHILE] = ACTIONS(2410),
    [anon_sym_While] = ACTIONS(2410),
    [anon_sym_repeat] = ACTIONS(2410),
    [anon_sym_REPEAT] = ACTIONS(2410),
    [anon_sym_Repeat] = ACTIONS(2410),
    [anon_sym_until] = ACTIONS(2410),
    [anon_sym_UNTIL] = ACTIONS(2410),
    [anon_sym_Until] = ACTIONS(2410),
    [anon_sym_exit] = ACTIONS(2410),
    [anon_sym_EXIT] = ACTIONS(2410),
    [anon_sym_Exit] = ACTIONS(2410),
    [anon_sym_continue] = ACTIONS(2410),
    [anon_sym_CONTINUE] = ACTIONS(2410),
    [anon_sym_Continue] = ACTIONS(2410),
    [anon_sym_break] = ACTIONS(2410),
    [anon_sym_BREAK] = ACTIONS(2410),
    [anon_sym_Break] = ACTIONS(2410),
    [anon_sym_with] = ACTIONS(2410),
    [anon_sym_WITH] = ACTIONS(2410),
    [anon_sym_With] = ACTIONS(2410),
    [sym_asserterror_keyword] = ACTIONS(2412),
    [anon_sym_in] = ACTIONS(2410),
    [anon_sym_IN] = ACTIONS(2410),
    [anon_sym_In] = ACTIONS(2410),
    [sym_page_keyword] = ACTIONS(2410),
    [anon_sym_codeunit] = ACTIONS(2410),
    [anon_sym_CODEUNIT] = ACTIONS(2410),
    [anon_sym_Codeunit] = ACTIONS(2410),
    [anon_sym_CodeUnit] = ACTIONS(2410),
    [anon_sym_COdeunit] = ACTIONS(2410),
    [anon_sym_codeUnit] = ACTIONS(2410),
    [sym_report_keyword] = ACTIONS(2410),
    [sym_query_keyword] = ACTIONS(2410),
    [anon_sym_xmlport] = ACTIONS(2410),
    [anon_sym_XMLPORT] = ACTIONS(2410),
    [anon_sym_Xmlport] = ACTIONS(2410),
    [anon_sym_XMLport] = ACTIONS(2410),
    [anon_sym_XMLPort] = ACTIONS(2410),
    [anon_sym_XmlPort] = ACTIONS(2410),
    [anon_sym_enum] = ACTIONS(2410),
    [anon_sym_ENUM] = ACTIONS(2410),
    [anon_sym_Enum] = ACTIONS(2410),
    [anon_sym_eNUM] = ACTIONS(2410),
    [anon_sym_eNum] = ACTIONS(2410),
    [anon_sym_ENum] = ACTIONS(2410),
    [sym_quoted_identifier] = ACTIONS(2412),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2412),
    [sym_integer] = ACTIONS(2410),
    [sym_continue_as_identifier] = ACTIONS(2412),
    [sym_preproc_open] = ACTIONS(2412),
  },
  [STATE(1072)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1082),
    [sym_identifier] = ACTIONS(2354),
    [anon_sym_SEMI] = ACTIONS(2356),
    [anon_sym_DOT] = ACTIONS(2354),
    [anon_sym_EQ] = ACTIONS(2356),
    [anon_sym_COMMA] = ACTIONS(2703),
    [anon_sym_DASH] = ACTIONS(2354),
    [aux_sym_boolean_token1] = ACTIONS(2354),
    [aux_sym_boolean_token2] = ACTIONS(2354),
    [sym_decimal] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(2356),
    [anon_sym_DOT_DOT] = ACTIONS(2356),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2354),
    [anon_sym_STAR] = ACTIONS(2354),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [aux_sym_record_type_token1] = ACTIONS(2354),
    [aux_sym_basic_type_token21] = ACTIONS(2354),
    [aux_sym_basic_type_token22] = ACTIONS(2354),
    [aux_sym_basic_type_token48] = ACTIONS(2354),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2354),
    [anon_sym_POUNDif] = ACTIONS(2356),
    [anon_sym_POUNDIF] = ACTIONS(2356),
    [anon_sym_POUNDIf] = ACTIONS(2356),
    [anon_sym_not] = ACTIONS(2354),
    [anon_sym_NOT] = ACTIONS(2354),
    [anon_sym_Not] = ACTIONS(2354),
    [anon_sym_POUNDelse] = ACTIONS(2356),
    [anon_sym_POUNDELSE] = ACTIONS(2356),
    [anon_sym_POUNDElse] = ACTIONS(2356),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2356),
    [aux_sym__expression_token1] = ACTIONS(2356),
    [aux_sym__expression_token2] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2354),
    [anon_sym_SLASH] = ACTIONS(2354),
    [anon_sym_div] = ACTIONS(2354),
    [anon_sym_DIV] = ACTIONS(2354),
    [anon_sym_Div] = ACTIONS(2354),
    [anon_sym_mod] = ACTIONS(2354),
    [anon_sym_MOD] = ACTIONS(2354),
    [anon_sym_Mod] = ACTIONS(2354),
    [anon_sym_PLUS] = ACTIONS(2354),
    [anon_sym_GT_EQ] = ACTIONS(2356),
    [anon_sym_LT_EQ] = ACTIONS(2356),
    [anon_sym_GT] = ACTIONS(2354),
    [anon_sym_LT] = ACTIONS(2354),
    [anon_sym_LT_GT] = ACTIONS(2356),
    [anon_sym_and] = ACTIONS(2354),
    [anon_sym_AND] = ACTIONS(2354),
    [anon_sym_And] = ACTIONS(2354),
    [anon_sym_or] = ACTIONS(2354),
    [anon_sym_OR] = ACTIONS(2354),
    [anon_sym_Or] = ACTIONS(2354),
    [anon_sym_xor] = ACTIONS(2354),
    [anon_sym_XOR] = ACTIONS(2354),
    [anon_sym_Xor] = ACTIONS(2354),
    [anon_sym_QMARK] = ACTIONS(2356),
    [sym_datetime_literal] = ACTIONS(2356),
    [sym_date_literal] = ACTIONS(2354),
    [sym_time_literal] = ACTIONS(2354),
    [sym_biginteger_literal] = ACTIONS(2356),
    [anon_sym_if] = ACTIONS(2354),
    [anon_sym_IF] = ACTIONS(2354),
    [anon_sym_If] = ACTIONS(2354),
    [anon_sym_else] = ACTIONS(2354),
    [anon_sym_ELSE] = ACTIONS(2354),
    [anon_sym_Else] = ACTIONS(2354),
    [anon_sym_case] = ACTIONS(2354),
    [anon_sym_CASE] = ACTIONS(2354),
    [anon_sym_Case] = ACTIONS(2354),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_FOR] = ACTIONS(2354),
    [anon_sym_For] = ACTIONS(2354),
    [anon_sym_foreach] = ACTIONS(2354),
    [anon_sym_FOREACH] = ACTIONS(2354),
    [anon_sym_Foreach] = ACTIONS(2354),
    [anon_sym_while] = ACTIONS(2354),
    [anon_sym_WHILE] = ACTIONS(2354),
    [anon_sym_While] = ACTIONS(2354),
    [anon_sym_repeat] = ACTIONS(2354),
    [anon_sym_REPEAT] = ACTIONS(2354),
    [anon_sym_Repeat] = ACTIONS(2354),
    [anon_sym_until] = ACTIONS(2354),
    [anon_sym_UNTIL] = ACTIONS(2354),
    [anon_sym_Until] = ACTIONS(2354),
    [anon_sym_exit] = ACTIONS(2354),
    [anon_sym_EXIT] = ACTIONS(2354),
    [anon_sym_Exit] = ACTIONS(2354),
    [anon_sym_continue] = ACTIONS(2354),
    [anon_sym_CONTINUE] = ACTIONS(2354),
    [anon_sym_Continue] = ACTIONS(2354),
    [anon_sym_break] = ACTIONS(2354),
    [anon_sym_BREAK] = ACTIONS(2354),
    [anon_sym_Break] = ACTIONS(2354),
    [anon_sym_with] = ACTIONS(2354),
    [anon_sym_WITH] = ACTIONS(2354),
    [anon_sym_With] = ACTIONS(2354),
    [sym_asserterror_keyword] = ACTIONS(2356),
    [anon_sym_in] = ACTIONS(2354),
    [anon_sym_IN] = ACTIONS(2354),
    [anon_sym_In] = ACTIONS(2354),
    [sym_page_keyword] = ACTIONS(2354),
    [anon_sym_codeunit] = ACTIONS(2354),
    [anon_sym_CODEUNIT] = ACTIONS(2354),
    [anon_sym_Codeunit] = ACTIONS(2354),
    [anon_sym_CodeUnit] = ACTIONS(2354),
    [anon_sym_COdeunit] = ACTIONS(2354),
    [anon_sym_codeUnit] = ACTIONS(2354),
    [sym_report_keyword] = ACTIONS(2354),
    [sym_query_keyword] = ACTIONS(2354),
    [anon_sym_xmlport] = ACTIONS(2354),
    [anon_sym_XMLPORT] = ACTIONS(2354),
    [anon_sym_Xmlport] = ACTIONS(2354),
    [anon_sym_XMLport] = ACTIONS(2354),
    [anon_sym_XMLPort] = ACTIONS(2354),
    [anon_sym_XmlPort] = ACTIONS(2354),
    [anon_sym_enum] = ACTIONS(2354),
    [anon_sym_ENUM] = ACTIONS(2354),
    [anon_sym_Enum] = ACTIONS(2354),
    [anon_sym_eNUM] = ACTIONS(2354),
    [anon_sym_eNum] = ACTIONS(2354),
    [anon_sym_ENum] = ACTIONS(2354),
    [sym_quoted_identifier] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2356),
    [sym_integer] = ACTIONS(2354),
    [sym_continue_as_identifier] = ACTIONS(2356),
    [sym_preproc_open] = ACTIONS(2356),
  },
  [STATE(1073)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2382),
    [anon_sym_SEMI] = ACTIONS(2385),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2675),
    [aux_sym_boolean_token1] = ACTIONS(2382),
    [aux_sym_boolean_token2] = ACTIONS(2382),
    [sym_decimal] = ACTIONS(2382),
    [anon_sym_LPAREN] = ACTIONS(2385),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2382),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2382),
    [aux_sym_basic_type_token21] = ACTIONS(2382),
    [aux_sym_basic_type_token22] = ACTIONS(2382),
    [aux_sym_basic_type_token48] = ACTIONS(2382),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2382),
    [anon_sym_POUNDif] = ACTIONS(2385),
    [anon_sym_POUNDIF] = ACTIONS(2385),
    [anon_sym_POUNDIf] = ACTIONS(2385),
    [anon_sym_not] = ACTIONS(2382),
    [anon_sym_NOT] = ACTIONS(2382),
    [anon_sym_Not] = ACTIONS(2382),
    [anon_sym_POUNDelse] = ACTIONS(2385),
    [anon_sym_POUNDELSE] = ACTIONS(2385),
    [anon_sym_POUNDElse] = ACTIONS(2385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2705),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2382),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2683),
    [anon_sym_AND] = ACTIONS(2685),
    [anon_sym_And] = ACTIONS(2687),
    [anon_sym_or] = ACTIONS(2689),
    [anon_sym_OR] = ACTIONS(2691),
    [anon_sym_Or] = ACTIONS(2693),
    [anon_sym_xor] = ACTIONS(2695),
    [anon_sym_XOR] = ACTIONS(2697),
    [anon_sym_Xor] = ACTIONS(2699),
    [anon_sym_QMARK] = ACTIONS(2701),
    [sym_datetime_literal] = ACTIONS(2385),
    [sym_date_literal] = ACTIONS(2382),
    [sym_time_literal] = ACTIONS(2382),
    [sym_biginteger_literal] = ACTIONS(2385),
    [anon_sym_if] = ACTIONS(2382),
    [anon_sym_IF] = ACTIONS(2382),
    [anon_sym_If] = ACTIONS(2382),
    [anon_sym_else] = ACTIONS(2382),
    [anon_sym_ELSE] = ACTIONS(2382),
    [anon_sym_Else] = ACTIONS(2382),
    [anon_sym_case] = ACTIONS(2382),
    [anon_sym_CASE] = ACTIONS(2382),
    [anon_sym_Case] = ACTIONS(2382),
    [anon_sym_for] = ACTIONS(2382),
    [anon_sym_FOR] = ACTIONS(2382),
    [anon_sym_For] = ACTIONS(2382),
    [anon_sym_foreach] = ACTIONS(2382),
    [anon_sym_FOREACH] = ACTIONS(2382),
    [anon_sym_Foreach] = ACTIONS(2382),
    [anon_sym_while] = ACTIONS(2382),
    [anon_sym_WHILE] = ACTIONS(2382),
    [anon_sym_While] = ACTIONS(2382),
    [anon_sym_repeat] = ACTIONS(2382),
    [anon_sym_REPEAT] = ACTIONS(2382),
    [anon_sym_Repeat] = ACTIONS(2382),
    [anon_sym_until] = ACTIONS(2382),
    [anon_sym_UNTIL] = ACTIONS(2382),
    [anon_sym_Until] = ACTIONS(2382),
    [anon_sym_exit] = ACTIONS(2382),
    [anon_sym_EXIT] = ACTIONS(2382),
    [anon_sym_Exit] = ACTIONS(2382),
    [anon_sym_continue] = ACTIONS(2382),
    [anon_sym_CONTINUE] = ACTIONS(2382),
    [anon_sym_Continue] = ACTIONS(2382),
    [anon_sym_break] = ACTIONS(2382),
    [anon_sym_BREAK] = ACTIONS(2382),
    [anon_sym_Break] = ACTIONS(2382),
    [anon_sym_with] = ACTIONS(2382),
    [anon_sym_WITH] = ACTIONS(2382),
    [anon_sym_With] = ACTIONS(2382),
    [sym_asserterror_keyword] = ACTIONS(2385),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2382),
    [anon_sym_codeunit] = ACTIONS(2382),
    [anon_sym_CODEUNIT] = ACTIONS(2382),
    [anon_sym_Codeunit] = ACTIONS(2382),
    [anon_sym_CodeUnit] = ACTIONS(2382),
    [anon_sym_COdeunit] = ACTIONS(2382),
    [anon_sym_codeUnit] = ACTIONS(2382),
    [sym_report_keyword] = ACTIONS(2382),
    [sym_query_keyword] = ACTIONS(2382),
    [anon_sym_xmlport] = ACTIONS(2382),
    [anon_sym_XMLPORT] = ACTIONS(2382),
    [anon_sym_Xmlport] = ACTIONS(2382),
    [anon_sym_XMLport] = ACTIONS(2382),
    [anon_sym_XMLPort] = ACTIONS(2382),
    [anon_sym_XmlPort] = ACTIONS(2382),
    [anon_sym_enum] = ACTIONS(2382),
    [anon_sym_ENUM] = ACTIONS(2382),
    [anon_sym_Enum] = ACTIONS(2382),
    [anon_sym_eNUM] = ACTIONS(2382),
    [anon_sym_eNum] = ACTIONS(2382),
    [anon_sym_ENum] = ACTIONS(2382),
    [sym_quoted_identifier] = ACTIONS(2385),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2385),
    [sym_integer] = ACTIONS(2382),
    [sym_continue_as_identifier] = ACTIONS(2385),
    [sym_preproc_open] = ACTIONS(2385),
  },
  [STATE(1074)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2388),
    [anon_sym_SEMI] = ACTIONS(2390),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2675),
    [aux_sym_boolean_token1] = ACTIONS(2388),
    [aux_sym_boolean_token2] = ACTIONS(2388),
    [sym_decimal] = ACTIONS(2388),
    [anon_sym_LPAREN] = ACTIONS(2390),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2388),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2388),
    [aux_sym_basic_type_token21] = ACTIONS(2388),
    [aux_sym_basic_type_token22] = ACTIONS(2388),
    [aux_sym_basic_type_token48] = ACTIONS(2388),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2388),
    [anon_sym_POUNDif] = ACTIONS(2390),
    [anon_sym_POUNDIF] = ACTIONS(2390),
    [anon_sym_POUNDIf] = ACTIONS(2390),
    [anon_sym_not] = ACTIONS(2388),
    [anon_sym_NOT] = ACTIONS(2388),
    [anon_sym_Not] = ACTIONS(2388),
    [anon_sym_POUNDelse] = ACTIONS(2390),
    [anon_sym_POUNDELSE] = ACTIONS(2390),
    [anon_sym_POUNDElse] = ACTIONS(2390),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2705),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2388),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2388),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2683),
    [anon_sym_AND] = ACTIONS(2685),
    [anon_sym_And] = ACTIONS(2687),
    [anon_sym_or] = ACTIONS(2689),
    [anon_sym_OR] = ACTIONS(2691),
    [anon_sym_Or] = ACTIONS(2693),
    [anon_sym_xor] = ACTIONS(2695),
    [anon_sym_XOR] = ACTIONS(2697),
    [anon_sym_Xor] = ACTIONS(2699),
    [anon_sym_QMARK] = ACTIONS(2701),
    [sym_datetime_literal] = ACTIONS(2390),
    [sym_date_literal] = ACTIONS(2388),
    [sym_time_literal] = ACTIONS(2388),
    [sym_biginteger_literal] = ACTIONS(2390),
    [anon_sym_if] = ACTIONS(2388),
    [anon_sym_IF] = ACTIONS(2388),
    [anon_sym_If] = ACTIONS(2388),
    [anon_sym_else] = ACTIONS(2388),
    [anon_sym_ELSE] = ACTIONS(2388),
    [anon_sym_Else] = ACTIONS(2388),
    [anon_sym_case] = ACTIONS(2388),
    [anon_sym_CASE] = ACTIONS(2388),
    [anon_sym_Case] = ACTIONS(2388),
    [anon_sym_for] = ACTIONS(2388),
    [anon_sym_FOR] = ACTIONS(2388),
    [anon_sym_For] = ACTIONS(2388),
    [anon_sym_foreach] = ACTIONS(2388),
    [anon_sym_FOREACH] = ACTIONS(2388),
    [anon_sym_Foreach] = ACTIONS(2388),
    [anon_sym_while] = ACTIONS(2388),
    [anon_sym_WHILE] = ACTIONS(2388),
    [anon_sym_While] = ACTIONS(2388),
    [anon_sym_repeat] = ACTIONS(2388),
    [anon_sym_REPEAT] = ACTIONS(2388),
    [anon_sym_Repeat] = ACTIONS(2388),
    [anon_sym_until] = ACTIONS(2388),
    [anon_sym_UNTIL] = ACTIONS(2388),
    [anon_sym_Until] = ACTIONS(2388),
    [anon_sym_exit] = ACTIONS(2388),
    [anon_sym_EXIT] = ACTIONS(2388),
    [anon_sym_Exit] = ACTIONS(2388),
    [anon_sym_continue] = ACTIONS(2388),
    [anon_sym_CONTINUE] = ACTIONS(2388),
    [anon_sym_Continue] = ACTIONS(2388),
    [anon_sym_break] = ACTIONS(2388),
    [anon_sym_BREAK] = ACTIONS(2388),
    [anon_sym_Break] = ACTIONS(2388),
    [anon_sym_with] = ACTIONS(2388),
    [anon_sym_WITH] = ACTIONS(2388),
    [anon_sym_With] = ACTIONS(2388),
    [sym_asserterror_keyword] = ACTIONS(2390),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2388),
    [anon_sym_codeunit] = ACTIONS(2388),
    [anon_sym_CODEUNIT] = ACTIONS(2388),
    [anon_sym_Codeunit] = ACTIONS(2388),
    [anon_sym_CodeUnit] = ACTIONS(2388),
    [anon_sym_COdeunit] = ACTIONS(2388),
    [anon_sym_codeUnit] = ACTIONS(2388),
    [sym_report_keyword] = ACTIONS(2388),
    [sym_query_keyword] = ACTIONS(2388),
    [anon_sym_xmlport] = ACTIONS(2388),
    [anon_sym_XMLPORT] = ACTIONS(2388),
    [anon_sym_Xmlport] = ACTIONS(2388),
    [anon_sym_XMLport] = ACTIONS(2388),
    [anon_sym_XMLPort] = ACTIONS(2388),
    [anon_sym_XmlPort] = ACTIONS(2388),
    [anon_sym_enum] = ACTIONS(2388),
    [anon_sym_ENUM] = ACTIONS(2388),
    [anon_sym_Enum] = ACTIONS(2388),
    [anon_sym_eNUM] = ACTIONS(2388),
    [anon_sym_eNum] = ACTIONS(2388),
    [anon_sym_ENum] = ACTIONS(2388),
    [sym_quoted_identifier] = ACTIONS(2390),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2390),
    [sym_integer] = ACTIONS(2388),
    [sym_continue_as_identifier] = ACTIONS(2390),
    [sym_preproc_open] = ACTIONS(2390),
  },
  [STATE(1075)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2392),
    [anon_sym_SEMI] = ACTIONS(2394),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2675),
    [aux_sym_boolean_token1] = ACTIONS(2392),
    [aux_sym_boolean_token2] = ACTIONS(2392),
    [sym_decimal] = ACTIONS(2392),
    [anon_sym_LPAREN] = ACTIONS(2394),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2392),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2392),
    [aux_sym_basic_type_token21] = ACTIONS(2392),
    [aux_sym_basic_type_token22] = ACTIONS(2392),
    [aux_sym_basic_type_token48] = ACTIONS(2392),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2392),
    [anon_sym_POUNDif] = ACTIONS(2394),
    [anon_sym_POUNDIF] = ACTIONS(2394),
    [anon_sym_POUNDIf] = ACTIONS(2394),
    [anon_sym_not] = ACTIONS(2392),
    [anon_sym_NOT] = ACTIONS(2392),
    [anon_sym_Not] = ACTIONS(2392),
    [anon_sym_POUNDelse] = ACTIONS(2394),
    [anon_sym_POUNDELSE] = ACTIONS(2394),
    [anon_sym_POUNDElse] = ACTIONS(2394),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2705),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2392),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2392),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2683),
    [anon_sym_AND] = ACTIONS(2685),
    [anon_sym_And] = ACTIONS(2687),
    [anon_sym_or] = ACTIONS(2689),
    [anon_sym_OR] = ACTIONS(2691),
    [anon_sym_Or] = ACTIONS(2693),
    [anon_sym_xor] = ACTIONS(2695),
    [anon_sym_XOR] = ACTIONS(2697),
    [anon_sym_Xor] = ACTIONS(2699),
    [anon_sym_QMARK] = ACTIONS(2701),
    [sym_datetime_literal] = ACTIONS(2394),
    [sym_date_literal] = ACTIONS(2392),
    [sym_time_literal] = ACTIONS(2392),
    [sym_biginteger_literal] = ACTIONS(2394),
    [anon_sym_if] = ACTIONS(2392),
    [anon_sym_IF] = ACTIONS(2392),
    [anon_sym_If] = ACTIONS(2392),
    [anon_sym_else] = ACTIONS(2392),
    [anon_sym_ELSE] = ACTIONS(2392),
    [anon_sym_Else] = ACTIONS(2392),
    [anon_sym_case] = ACTIONS(2392),
    [anon_sym_CASE] = ACTIONS(2392),
    [anon_sym_Case] = ACTIONS(2392),
    [anon_sym_for] = ACTIONS(2392),
    [anon_sym_FOR] = ACTIONS(2392),
    [anon_sym_For] = ACTIONS(2392),
    [anon_sym_foreach] = ACTIONS(2392),
    [anon_sym_FOREACH] = ACTIONS(2392),
    [anon_sym_Foreach] = ACTIONS(2392),
    [anon_sym_while] = ACTIONS(2392),
    [anon_sym_WHILE] = ACTIONS(2392),
    [anon_sym_While] = ACTIONS(2392),
    [anon_sym_repeat] = ACTIONS(2392),
    [anon_sym_REPEAT] = ACTIONS(2392),
    [anon_sym_Repeat] = ACTIONS(2392),
    [anon_sym_until] = ACTIONS(2392),
    [anon_sym_UNTIL] = ACTIONS(2392),
    [anon_sym_Until] = ACTIONS(2392),
    [anon_sym_exit] = ACTIONS(2392),
    [anon_sym_EXIT] = ACTIONS(2392),
    [anon_sym_Exit] = ACTIONS(2392),
    [anon_sym_continue] = ACTIONS(2392),
    [anon_sym_CONTINUE] = ACTIONS(2392),
    [anon_sym_Continue] = ACTIONS(2392),
    [anon_sym_break] = ACTIONS(2392),
    [anon_sym_BREAK] = ACTIONS(2392),
    [anon_sym_Break] = ACTIONS(2392),
    [anon_sym_with] = ACTIONS(2392),
    [anon_sym_WITH] = ACTIONS(2392),
    [anon_sym_With] = ACTIONS(2392),
    [sym_asserterror_keyword] = ACTIONS(2394),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2392),
    [anon_sym_codeunit] = ACTIONS(2392),
    [anon_sym_CODEUNIT] = ACTIONS(2392),
    [anon_sym_Codeunit] = ACTIONS(2392),
    [anon_sym_CodeUnit] = ACTIONS(2392),
    [anon_sym_COdeunit] = ACTIONS(2392),
    [anon_sym_codeUnit] = ACTIONS(2392),
    [sym_report_keyword] = ACTIONS(2392),
    [sym_query_keyword] = ACTIONS(2392),
    [anon_sym_xmlport] = ACTIONS(2392),
    [anon_sym_XMLPORT] = ACTIONS(2392),
    [anon_sym_Xmlport] = ACTIONS(2392),
    [anon_sym_XMLport] = ACTIONS(2392),
    [anon_sym_XMLPort] = ACTIONS(2392),
    [anon_sym_XmlPort] = ACTIONS(2392),
    [anon_sym_enum] = ACTIONS(2392),
    [anon_sym_ENUM] = ACTIONS(2392),
    [anon_sym_Enum] = ACTIONS(2392),
    [anon_sym_eNUM] = ACTIONS(2392),
    [anon_sym_eNum] = ACTIONS(2392),
    [anon_sym_ENum] = ACTIONS(2392),
    [sym_quoted_identifier] = ACTIONS(2394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2394),
    [sym_integer] = ACTIONS(2392),
    [sym_continue_as_identifier] = ACTIONS(2394),
    [sym_preproc_open] = ACTIONS(2394),
  },
  [STATE(1076)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1077),
    [sym_identifier] = ACTIONS(2442),
    [anon_sym_SEMI] = ACTIONS(2444),
    [anon_sym_DOT] = ACTIONS(2707),
    [anon_sym_EQ] = ACTIONS(2444),
    [anon_sym_DASH] = ACTIONS(2442),
    [aux_sym_boolean_token1] = ACTIONS(2442),
    [aux_sym_boolean_token2] = ACTIONS(2442),
    [sym_decimal] = ACTIONS(2442),
    [anon_sym_LPAREN] = ACTIONS(2444),
    [anon_sym_DOT_DOT] = ACTIONS(2444),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2442),
    [anon_sym_STAR] = ACTIONS(2442),
    [anon_sym_LBRACK] = ACTIONS(2444),
    [aux_sym_record_type_token1] = ACTIONS(2442),
    [aux_sym_basic_type_token21] = ACTIONS(2442),
    [aux_sym_basic_type_token22] = ACTIONS(2442),
    [aux_sym_basic_type_token48] = ACTIONS(2442),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2442),
    [anon_sym_POUNDif] = ACTIONS(2444),
    [anon_sym_POUNDIF] = ACTIONS(2444),
    [anon_sym_POUNDIf] = ACTIONS(2444),
    [anon_sym_not] = ACTIONS(2442),
    [anon_sym_NOT] = ACTIONS(2442),
    [anon_sym_Not] = ACTIONS(2442),
    [anon_sym_POUNDelse] = ACTIONS(2444),
    [anon_sym_POUNDELSE] = ACTIONS(2444),
    [anon_sym_POUNDElse] = ACTIONS(2444),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2444),
    [aux_sym__expression_token1] = ACTIONS(2444),
    [aux_sym__expression_token2] = ACTIONS(2442),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2442),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2442),
    [anon_sym_SLASH] = ACTIONS(2442),
    [anon_sym_div] = ACTIONS(2442),
    [anon_sym_DIV] = ACTIONS(2442),
    [anon_sym_Div] = ACTIONS(2442),
    [anon_sym_mod] = ACTIONS(2442),
    [anon_sym_MOD] = ACTIONS(2442),
    [anon_sym_Mod] = ACTIONS(2442),
    [anon_sym_PLUS] = ACTIONS(2442),
    [anon_sym_GT_EQ] = ACTIONS(2444),
    [anon_sym_LT_EQ] = ACTIONS(2444),
    [anon_sym_GT] = ACTIONS(2442),
    [anon_sym_LT] = ACTIONS(2442),
    [anon_sym_LT_GT] = ACTIONS(2444),
    [anon_sym_and] = ACTIONS(2442),
    [anon_sym_AND] = ACTIONS(2442),
    [anon_sym_And] = ACTIONS(2442),
    [anon_sym_or] = ACTIONS(2442),
    [anon_sym_OR] = ACTIONS(2442),
    [anon_sym_Or] = ACTIONS(2442),
    [anon_sym_xor] = ACTIONS(2442),
    [anon_sym_XOR] = ACTIONS(2442),
    [anon_sym_Xor] = ACTIONS(2442),
    [anon_sym_QMARK] = ACTIONS(2444),
    [sym_datetime_literal] = ACTIONS(2444),
    [sym_date_literal] = ACTIONS(2442),
    [sym_time_literal] = ACTIONS(2442),
    [sym_biginteger_literal] = ACTIONS(2444),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_IF] = ACTIONS(2442),
    [anon_sym_If] = ACTIONS(2442),
    [anon_sym_else] = ACTIONS(2442),
    [anon_sym_ELSE] = ACTIONS(2442),
    [anon_sym_Else] = ACTIONS(2442),
    [anon_sym_case] = ACTIONS(2442),
    [anon_sym_CASE] = ACTIONS(2442),
    [anon_sym_Case] = ACTIONS(2442),
    [anon_sym_for] = ACTIONS(2442),
    [anon_sym_FOR] = ACTIONS(2442),
    [anon_sym_For] = ACTIONS(2442),
    [anon_sym_foreach] = ACTIONS(2442),
    [anon_sym_FOREACH] = ACTIONS(2442),
    [anon_sym_Foreach] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2442),
    [anon_sym_WHILE] = ACTIONS(2442),
    [anon_sym_While] = ACTIONS(2442),
    [anon_sym_repeat] = ACTIONS(2442),
    [anon_sym_REPEAT] = ACTIONS(2442),
    [anon_sym_Repeat] = ACTIONS(2442),
    [anon_sym_until] = ACTIONS(2442),
    [anon_sym_UNTIL] = ACTIONS(2442),
    [anon_sym_Until] = ACTIONS(2442),
    [anon_sym_exit] = ACTIONS(2442),
    [anon_sym_EXIT] = ACTIONS(2442),
    [anon_sym_Exit] = ACTIONS(2442),
    [anon_sym_continue] = ACTIONS(2442),
    [anon_sym_CONTINUE] = ACTIONS(2442),
    [anon_sym_Continue] = ACTIONS(2442),
    [anon_sym_break] = ACTIONS(2442),
    [anon_sym_BREAK] = ACTIONS(2442),
    [anon_sym_Break] = ACTIONS(2442),
    [anon_sym_with] = ACTIONS(2442),
    [anon_sym_WITH] = ACTIONS(2442),
    [anon_sym_With] = ACTIONS(2442),
    [sym_asserterror_keyword] = ACTIONS(2444),
    [anon_sym_in] = ACTIONS(2442),
    [anon_sym_IN] = ACTIONS(2442),
    [anon_sym_In] = ACTIONS(2442),
    [sym_page_keyword] = ACTIONS(2442),
    [anon_sym_codeunit] = ACTIONS(2442),
    [anon_sym_CODEUNIT] = ACTIONS(2442),
    [anon_sym_Codeunit] = ACTIONS(2442),
    [anon_sym_CodeUnit] = ACTIONS(2442),
    [anon_sym_COdeunit] = ACTIONS(2442),
    [anon_sym_codeUnit] = ACTIONS(2442),
    [sym_report_keyword] = ACTIONS(2442),
    [sym_query_keyword] = ACTIONS(2442),
    [anon_sym_xmlport] = ACTIONS(2442),
    [anon_sym_XMLPORT] = ACTIONS(2442),
    [anon_sym_Xmlport] = ACTIONS(2442),
    [anon_sym_XMLport] = ACTIONS(2442),
    [anon_sym_XMLPort] = ACTIONS(2442),
    [anon_sym_XmlPort] = ACTIONS(2442),
    [anon_sym_enum] = ACTIONS(2442),
    [anon_sym_ENUM] = ACTIONS(2442),
    [anon_sym_Enum] = ACTIONS(2442),
    [anon_sym_eNUM] = ACTIONS(2442),
    [anon_sym_eNum] = ACTIONS(2442),
    [anon_sym_ENum] = ACTIONS(2442),
    [sym_temporary_keyword] = ACTIONS(2442),
    [sym_quoted_identifier] = ACTIONS(2444),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2444),
    [sym_integer] = ACTIONS(2442),
    [sym_continue_as_identifier] = ACTIONS(2444),
    [sym_preproc_open] = ACTIONS(2444),
  },
  [STATE(1077)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1077),
    [sym_identifier] = ACTIONS(2396),
    [anon_sym_SEMI] = ACTIONS(2398),
    [anon_sym_DOT] = ACTIONS(2709),
    [anon_sym_EQ] = ACTIONS(2398),
    [anon_sym_DASH] = ACTIONS(2396),
    [aux_sym_boolean_token1] = ACTIONS(2396),
    [aux_sym_boolean_token2] = ACTIONS(2396),
    [sym_decimal] = ACTIONS(2396),
    [anon_sym_LPAREN] = ACTIONS(2398),
    [anon_sym_DOT_DOT] = ACTIONS(2398),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2396),
    [anon_sym_STAR] = ACTIONS(2396),
    [anon_sym_LBRACK] = ACTIONS(2398),
    [aux_sym_record_type_token1] = ACTIONS(2396),
    [aux_sym_basic_type_token21] = ACTIONS(2396),
    [aux_sym_basic_type_token22] = ACTIONS(2396),
    [aux_sym_basic_type_token48] = ACTIONS(2396),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2396),
    [anon_sym_POUNDif] = ACTIONS(2398),
    [anon_sym_POUNDIF] = ACTIONS(2398),
    [anon_sym_POUNDIf] = ACTIONS(2398),
    [anon_sym_not] = ACTIONS(2396),
    [anon_sym_NOT] = ACTIONS(2396),
    [anon_sym_Not] = ACTIONS(2396),
    [anon_sym_POUNDelse] = ACTIONS(2398),
    [anon_sym_POUNDELSE] = ACTIONS(2398),
    [anon_sym_POUNDElse] = ACTIONS(2398),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2398),
    [aux_sym__expression_token1] = ACTIONS(2398),
    [aux_sym__expression_token2] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2396),
    [anon_sym_SLASH] = ACTIONS(2396),
    [anon_sym_div] = ACTIONS(2396),
    [anon_sym_DIV] = ACTIONS(2396),
    [anon_sym_Div] = ACTIONS(2396),
    [anon_sym_mod] = ACTIONS(2396),
    [anon_sym_MOD] = ACTIONS(2396),
    [anon_sym_Mod] = ACTIONS(2396),
    [anon_sym_PLUS] = ACTIONS(2396),
    [anon_sym_GT_EQ] = ACTIONS(2398),
    [anon_sym_LT_EQ] = ACTIONS(2398),
    [anon_sym_GT] = ACTIONS(2396),
    [anon_sym_LT] = ACTIONS(2396),
    [anon_sym_LT_GT] = ACTIONS(2398),
    [anon_sym_and] = ACTIONS(2396),
    [anon_sym_AND] = ACTIONS(2396),
    [anon_sym_And] = ACTIONS(2396),
    [anon_sym_or] = ACTIONS(2396),
    [anon_sym_OR] = ACTIONS(2396),
    [anon_sym_Or] = ACTIONS(2396),
    [anon_sym_xor] = ACTIONS(2396),
    [anon_sym_XOR] = ACTIONS(2396),
    [anon_sym_Xor] = ACTIONS(2396),
    [anon_sym_QMARK] = ACTIONS(2398),
    [sym_datetime_literal] = ACTIONS(2398),
    [sym_date_literal] = ACTIONS(2396),
    [sym_time_literal] = ACTIONS(2396),
    [sym_biginteger_literal] = ACTIONS(2398),
    [anon_sym_if] = ACTIONS(2396),
    [anon_sym_IF] = ACTIONS(2396),
    [anon_sym_If] = ACTIONS(2396),
    [anon_sym_else] = ACTIONS(2396),
    [anon_sym_ELSE] = ACTIONS(2396),
    [anon_sym_Else] = ACTIONS(2396),
    [anon_sym_case] = ACTIONS(2396),
    [anon_sym_CASE] = ACTIONS(2396),
    [anon_sym_Case] = ACTIONS(2396),
    [anon_sym_for] = ACTIONS(2396),
    [anon_sym_FOR] = ACTIONS(2396),
    [anon_sym_For] = ACTIONS(2396),
    [anon_sym_foreach] = ACTIONS(2396),
    [anon_sym_FOREACH] = ACTIONS(2396),
    [anon_sym_Foreach] = ACTIONS(2396),
    [anon_sym_while] = ACTIONS(2396),
    [anon_sym_WHILE] = ACTIONS(2396),
    [anon_sym_While] = ACTIONS(2396),
    [anon_sym_repeat] = ACTIONS(2396),
    [anon_sym_REPEAT] = ACTIONS(2396),
    [anon_sym_Repeat] = ACTIONS(2396),
    [anon_sym_until] = ACTIONS(2396),
    [anon_sym_UNTIL] = ACTIONS(2396),
    [anon_sym_Until] = ACTIONS(2396),
    [anon_sym_exit] = ACTIONS(2396),
    [anon_sym_EXIT] = ACTIONS(2396),
    [anon_sym_Exit] = ACTIONS(2396),
    [anon_sym_continue] = ACTIONS(2396),
    [anon_sym_CONTINUE] = ACTIONS(2396),
    [anon_sym_Continue] = ACTIONS(2396),
    [anon_sym_break] = ACTIONS(2396),
    [anon_sym_BREAK] = ACTIONS(2396),
    [anon_sym_Break] = ACTIONS(2396),
    [anon_sym_with] = ACTIONS(2396),
    [anon_sym_WITH] = ACTIONS(2396),
    [anon_sym_With] = ACTIONS(2396),
    [sym_asserterror_keyword] = ACTIONS(2398),
    [anon_sym_in] = ACTIONS(2396),
    [anon_sym_IN] = ACTIONS(2396),
    [anon_sym_In] = ACTIONS(2396),
    [sym_page_keyword] = ACTIONS(2396),
    [anon_sym_codeunit] = ACTIONS(2396),
    [anon_sym_CODEUNIT] = ACTIONS(2396),
    [anon_sym_Codeunit] = ACTIONS(2396),
    [anon_sym_CodeUnit] = ACTIONS(2396),
    [anon_sym_COdeunit] = ACTIONS(2396),
    [anon_sym_codeUnit] = ACTIONS(2396),
    [sym_report_keyword] = ACTIONS(2396),
    [sym_query_keyword] = ACTIONS(2396),
    [anon_sym_xmlport] = ACTIONS(2396),
    [anon_sym_XMLPORT] = ACTIONS(2396),
    [anon_sym_Xmlport] = ACTIONS(2396),
    [anon_sym_XMLport] = ACTIONS(2396),
    [anon_sym_XMLPort] = ACTIONS(2396),
    [anon_sym_XmlPort] = ACTIONS(2396),
    [anon_sym_enum] = ACTIONS(2396),
    [anon_sym_ENUM] = ACTIONS(2396),
    [anon_sym_Enum] = ACTIONS(2396),
    [anon_sym_eNUM] = ACTIONS(2396),
    [anon_sym_eNum] = ACTIONS(2396),
    [anon_sym_ENum] = ACTIONS(2396),
    [sym_temporary_keyword] = ACTIONS(2396),
    [sym_quoted_identifier] = ACTIONS(2398),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2398),
    [sym_integer] = ACTIONS(2396),
    [sym_continue_as_identifier] = ACTIONS(2398),
    [sym_preproc_open] = ACTIONS(2398),
  },
  [STATE(1078)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2372),
    [anon_sym_SEMI] = ACTIONS(2374),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2675),
    [aux_sym_boolean_token1] = ACTIONS(2372),
    [aux_sym_boolean_token2] = ACTIONS(2372),
    [sym_decimal] = ACTIONS(2372),
    [anon_sym_LPAREN] = ACTIONS(2374),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2372),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2372),
    [aux_sym_basic_type_token21] = ACTIONS(2372),
    [aux_sym_basic_type_token22] = ACTIONS(2372),
    [aux_sym_basic_type_token48] = ACTIONS(2372),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2372),
    [anon_sym_POUNDif] = ACTIONS(2374),
    [anon_sym_POUNDIF] = ACTIONS(2374),
    [anon_sym_POUNDIf] = ACTIONS(2374),
    [anon_sym_not] = ACTIONS(2372),
    [anon_sym_NOT] = ACTIONS(2372),
    [anon_sym_Not] = ACTIONS(2372),
    [anon_sym_POUNDelse] = ACTIONS(2374),
    [anon_sym_POUNDELSE] = ACTIONS(2374),
    [anon_sym_POUNDElse] = ACTIONS(2374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2712),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2372),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2372),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2683),
    [anon_sym_AND] = ACTIONS(2685),
    [anon_sym_And] = ACTIONS(2687),
    [anon_sym_or] = ACTIONS(2689),
    [anon_sym_OR] = ACTIONS(2691),
    [anon_sym_Or] = ACTIONS(2693),
    [anon_sym_xor] = ACTIONS(2695),
    [anon_sym_XOR] = ACTIONS(2697),
    [anon_sym_Xor] = ACTIONS(2699),
    [anon_sym_QMARK] = ACTIONS(2701),
    [sym_datetime_literal] = ACTIONS(2374),
    [sym_date_literal] = ACTIONS(2372),
    [sym_time_literal] = ACTIONS(2372),
    [sym_biginteger_literal] = ACTIONS(2374),
    [anon_sym_if] = ACTIONS(2372),
    [anon_sym_IF] = ACTIONS(2372),
    [anon_sym_If] = ACTIONS(2372),
    [anon_sym_else] = ACTIONS(2372),
    [anon_sym_ELSE] = ACTIONS(2372),
    [anon_sym_Else] = ACTIONS(2372),
    [anon_sym_case] = ACTIONS(2372),
    [anon_sym_CASE] = ACTIONS(2372),
    [anon_sym_Case] = ACTIONS(2372),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_FOR] = ACTIONS(2372),
    [anon_sym_For] = ACTIONS(2372),
    [anon_sym_foreach] = ACTIONS(2372),
    [anon_sym_FOREACH] = ACTIONS(2372),
    [anon_sym_Foreach] = ACTIONS(2372),
    [anon_sym_while] = ACTIONS(2372),
    [anon_sym_WHILE] = ACTIONS(2372),
    [anon_sym_While] = ACTIONS(2372),
    [anon_sym_repeat] = ACTIONS(2372),
    [anon_sym_REPEAT] = ACTIONS(2372),
    [anon_sym_Repeat] = ACTIONS(2372),
    [anon_sym_until] = ACTIONS(2372),
    [anon_sym_UNTIL] = ACTIONS(2372),
    [anon_sym_Until] = ACTIONS(2372),
    [anon_sym_exit] = ACTIONS(2372),
    [anon_sym_EXIT] = ACTIONS(2372),
    [anon_sym_Exit] = ACTIONS(2372),
    [anon_sym_continue] = ACTIONS(2372),
    [anon_sym_CONTINUE] = ACTIONS(2372),
    [anon_sym_Continue] = ACTIONS(2372),
    [anon_sym_break] = ACTIONS(2372),
    [anon_sym_BREAK] = ACTIONS(2372),
    [anon_sym_Break] = ACTIONS(2372),
    [anon_sym_with] = ACTIONS(2372),
    [anon_sym_WITH] = ACTIONS(2372),
    [anon_sym_With] = ACTIONS(2372),
    [sym_asserterror_keyword] = ACTIONS(2374),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2372),
    [anon_sym_codeunit] = ACTIONS(2372),
    [anon_sym_CODEUNIT] = ACTIONS(2372),
    [anon_sym_Codeunit] = ACTIONS(2372),
    [anon_sym_CodeUnit] = ACTIONS(2372),
    [anon_sym_COdeunit] = ACTIONS(2372),
    [anon_sym_codeUnit] = ACTIONS(2372),
    [sym_report_keyword] = ACTIONS(2372),
    [sym_query_keyword] = ACTIONS(2372),
    [anon_sym_xmlport] = ACTIONS(2372),
    [anon_sym_XMLPORT] = ACTIONS(2372),
    [anon_sym_Xmlport] = ACTIONS(2372),
    [anon_sym_XMLport] = ACTIONS(2372),
    [anon_sym_XMLPort] = ACTIONS(2372),
    [anon_sym_XmlPort] = ACTIONS(2372),
    [anon_sym_enum] = ACTIONS(2372),
    [anon_sym_ENUM] = ACTIONS(2372),
    [anon_sym_Enum] = ACTIONS(2372),
    [anon_sym_eNUM] = ACTIONS(2372),
    [anon_sym_eNum] = ACTIONS(2372),
    [anon_sym_ENum] = ACTIONS(2372),
    [sym_quoted_identifier] = ACTIONS(2374),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2374),
    [sym_integer] = ACTIONS(2372),
    [sym_continue_as_identifier] = ACTIONS(2374),
    [sym_preproc_open] = ACTIONS(2374),
  },
  [STATE(1079)] = {
    [sym_identifier] = ACTIONS(2414),
    [anon_sym_SEMI] = ACTIONS(2416),
    [anon_sym_DOT] = ACTIONS(2414),
    [anon_sym_EQ] = ACTIONS(2416),
    [anon_sym_COMMA] = ACTIONS(2416),
    [anon_sym_DASH] = ACTIONS(2414),
    [aux_sym_boolean_token1] = ACTIONS(2414),
    [aux_sym_boolean_token2] = ACTIONS(2414),
    [sym_decimal] = ACTIONS(2414),
    [anon_sym_LPAREN] = ACTIONS(2416),
    [anon_sym_DOT_DOT] = ACTIONS(2416),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2414),
    [anon_sym_STAR] = ACTIONS(2414),
    [anon_sym_LBRACK] = ACTIONS(2416),
    [aux_sym_record_type_token1] = ACTIONS(2414),
    [aux_sym_basic_type_token21] = ACTIONS(2414),
    [aux_sym_basic_type_token22] = ACTIONS(2414),
    [aux_sym_basic_type_token48] = ACTIONS(2414),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2414),
    [anon_sym_COLON_COLON] = ACTIONS(2416),
    [anon_sym_POUNDif] = ACTIONS(2416),
    [anon_sym_POUNDIF] = ACTIONS(2416),
    [anon_sym_POUNDIf] = ACTIONS(2416),
    [anon_sym_not] = ACTIONS(2414),
    [anon_sym_NOT] = ACTIONS(2414),
    [anon_sym_Not] = ACTIONS(2414),
    [anon_sym_POUNDelse] = ACTIONS(2416),
    [anon_sym_POUNDELSE] = ACTIONS(2416),
    [anon_sym_POUNDElse] = ACTIONS(2416),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2416),
    [aux_sym__expression_token1] = ACTIONS(2416),
    [aux_sym__expression_token2] = ACTIONS(2414),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2414),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2414),
    [anon_sym_SLASH] = ACTIONS(2414),
    [anon_sym_div] = ACTIONS(2414),
    [anon_sym_DIV] = ACTIONS(2414),
    [anon_sym_Div] = ACTIONS(2414),
    [anon_sym_mod] = ACTIONS(2414),
    [anon_sym_MOD] = ACTIONS(2414),
    [anon_sym_Mod] = ACTIONS(2414),
    [anon_sym_PLUS] = ACTIONS(2414),
    [anon_sym_GT_EQ] = ACTIONS(2416),
    [anon_sym_LT_EQ] = ACTIONS(2416),
    [anon_sym_GT] = ACTIONS(2414),
    [anon_sym_LT] = ACTIONS(2414),
    [anon_sym_LT_GT] = ACTIONS(2416),
    [anon_sym_and] = ACTIONS(2414),
    [anon_sym_AND] = ACTIONS(2414),
    [anon_sym_And] = ACTIONS(2414),
    [anon_sym_or] = ACTIONS(2414),
    [anon_sym_OR] = ACTIONS(2414),
    [anon_sym_Or] = ACTIONS(2414),
    [anon_sym_xor] = ACTIONS(2414),
    [anon_sym_XOR] = ACTIONS(2414),
    [anon_sym_Xor] = ACTIONS(2414),
    [anon_sym_QMARK] = ACTIONS(2416),
    [sym_datetime_literal] = ACTIONS(2416),
    [sym_date_literal] = ACTIONS(2414),
    [sym_time_literal] = ACTIONS(2414),
    [sym_biginteger_literal] = ACTIONS(2416),
    [anon_sym_if] = ACTIONS(2414),
    [anon_sym_IF] = ACTIONS(2414),
    [anon_sym_If] = ACTIONS(2414),
    [anon_sym_else] = ACTIONS(2414),
    [anon_sym_ELSE] = ACTIONS(2414),
    [anon_sym_Else] = ACTIONS(2414),
    [anon_sym_case] = ACTIONS(2414),
    [anon_sym_CASE] = ACTIONS(2414),
    [anon_sym_Case] = ACTIONS(2414),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_FOR] = ACTIONS(2414),
    [anon_sym_For] = ACTIONS(2414),
    [anon_sym_foreach] = ACTIONS(2414),
    [anon_sym_FOREACH] = ACTIONS(2414),
    [anon_sym_Foreach] = ACTIONS(2414),
    [anon_sym_while] = ACTIONS(2414),
    [anon_sym_WHILE] = ACTIONS(2414),
    [anon_sym_While] = ACTIONS(2414),
    [anon_sym_repeat] = ACTIONS(2414),
    [anon_sym_REPEAT] = ACTIONS(2414),
    [anon_sym_Repeat] = ACTIONS(2414),
    [anon_sym_until] = ACTIONS(2414),
    [anon_sym_UNTIL] = ACTIONS(2414),
    [anon_sym_Until] = ACTIONS(2414),
    [anon_sym_exit] = ACTIONS(2414),
    [anon_sym_EXIT] = ACTIONS(2414),
    [anon_sym_Exit] = ACTIONS(2414),
    [anon_sym_continue] = ACTIONS(2414),
    [anon_sym_CONTINUE] = ACTIONS(2414),
    [anon_sym_Continue] = ACTIONS(2414),
    [anon_sym_break] = ACTIONS(2414),
    [anon_sym_BREAK] = ACTIONS(2414),
    [anon_sym_Break] = ACTIONS(2414),
    [anon_sym_with] = ACTIONS(2414),
    [anon_sym_WITH] = ACTIONS(2414),
    [anon_sym_With] = ACTIONS(2414),
    [sym_asserterror_keyword] = ACTIONS(2416),
    [anon_sym_in] = ACTIONS(2414),
    [anon_sym_IN] = ACTIONS(2414),
    [anon_sym_In] = ACTIONS(2414),
    [sym_page_keyword] = ACTIONS(2414),
    [anon_sym_codeunit] = ACTIONS(2414),
    [anon_sym_CODEUNIT] = ACTIONS(2414),
    [anon_sym_Codeunit] = ACTIONS(2414),
    [anon_sym_CodeUnit] = ACTIONS(2414),
    [anon_sym_COdeunit] = ACTIONS(2414),
    [anon_sym_codeUnit] = ACTIONS(2414),
    [sym_report_keyword] = ACTIONS(2414),
    [sym_query_keyword] = ACTIONS(2414),
    [anon_sym_xmlport] = ACTIONS(2414),
    [anon_sym_XMLPORT] = ACTIONS(2414),
    [anon_sym_Xmlport] = ACTIONS(2414),
    [anon_sym_XMLport] = ACTIONS(2414),
    [anon_sym_XMLPort] = ACTIONS(2414),
    [anon_sym_XmlPort] = ACTIONS(2414),
    [anon_sym_enum] = ACTIONS(2414),
    [anon_sym_ENUM] = ACTIONS(2414),
    [anon_sym_Enum] = ACTIONS(2414),
    [anon_sym_eNUM] = ACTIONS(2414),
    [anon_sym_eNum] = ACTIONS(2414),
    [anon_sym_ENum] = ACTIONS(2414),
    [sym_quoted_identifier] = ACTIONS(2416),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2416),
    [sym_integer] = ACTIONS(2414),
    [sym_continue_as_identifier] = ACTIONS(2416),
    [sym_preproc_open] = ACTIONS(2416),
  },
  [STATE(1080)] = {
    [sym_identifier] = ACTIONS(2418),
    [anon_sym_SEMI] = ACTIONS(2420),
    [anon_sym_DOT] = ACTIONS(2418),
    [anon_sym_EQ] = ACTIONS(2420),
    [anon_sym_COMMA] = ACTIONS(2420),
    [anon_sym_DASH] = ACTIONS(2418),
    [aux_sym_boolean_token1] = ACTIONS(2418),
    [aux_sym_boolean_token2] = ACTIONS(2418),
    [sym_decimal] = ACTIONS(2418),
    [anon_sym_LPAREN] = ACTIONS(2420),
    [anon_sym_DOT_DOT] = ACTIONS(2420),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2418),
    [anon_sym_STAR] = ACTIONS(2418),
    [anon_sym_LBRACK] = ACTIONS(2420),
    [aux_sym_record_type_token1] = ACTIONS(2418),
    [aux_sym_basic_type_token21] = ACTIONS(2418),
    [aux_sym_basic_type_token22] = ACTIONS(2418),
    [aux_sym_basic_type_token48] = ACTIONS(2418),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2418),
    [anon_sym_COLON_COLON] = ACTIONS(2420),
    [anon_sym_POUNDif] = ACTIONS(2420),
    [anon_sym_POUNDIF] = ACTIONS(2420),
    [anon_sym_POUNDIf] = ACTIONS(2420),
    [anon_sym_not] = ACTIONS(2418),
    [anon_sym_NOT] = ACTIONS(2418),
    [anon_sym_Not] = ACTIONS(2418),
    [anon_sym_POUNDelse] = ACTIONS(2420),
    [anon_sym_POUNDELSE] = ACTIONS(2420),
    [anon_sym_POUNDElse] = ACTIONS(2420),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2420),
    [aux_sym__expression_token1] = ACTIONS(2420),
    [aux_sym__expression_token2] = ACTIONS(2418),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2418),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2418),
    [anon_sym_SLASH] = ACTIONS(2418),
    [anon_sym_div] = ACTIONS(2418),
    [anon_sym_DIV] = ACTIONS(2418),
    [anon_sym_Div] = ACTIONS(2418),
    [anon_sym_mod] = ACTIONS(2418),
    [anon_sym_MOD] = ACTIONS(2418),
    [anon_sym_Mod] = ACTIONS(2418),
    [anon_sym_PLUS] = ACTIONS(2418),
    [anon_sym_GT_EQ] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(2420),
    [anon_sym_GT] = ACTIONS(2418),
    [anon_sym_LT] = ACTIONS(2418),
    [anon_sym_LT_GT] = ACTIONS(2420),
    [anon_sym_and] = ACTIONS(2418),
    [anon_sym_AND] = ACTIONS(2418),
    [anon_sym_And] = ACTIONS(2418),
    [anon_sym_or] = ACTIONS(2418),
    [anon_sym_OR] = ACTIONS(2418),
    [anon_sym_Or] = ACTIONS(2418),
    [anon_sym_xor] = ACTIONS(2418),
    [anon_sym_XOR] = ACTIONS(2418),
    [anon_sym_Xor] = ACTIONS(2418),
    [anon_sym_QMARK] = ACTIONS(2420),
    [sym_datetime_literal] = ACTIONS(2420),
    [sym_date_literal] = ACTIONS(2418),
    [sym_time_literal] = ACTIONS(2418),
    [sym_biginteger_literal] = ACTIONS(2420),
    [anon_sym_if] = ACTIONS(2418),
    [anon_sym_IF] = ACTIONS(2418),
    [anon_sym_If] = ACTIONS(2418),
    [anon_sym_else] = ACTIONS(2418),
    [anon_sym_ELSE] = ACTIONS(2418),
    [anon_sym_Else] = ACTIONS(2418),
    [anon_sym_case] = ACTIONS(2418),
    [anon_sym_CASE] = ACTIONS(2418),
    [anon_sym_Case] = ACTIONS(2418),
    [anon_sym_for] = ACTIONS(2418),
    [anon_sym_FOR] = ACTIONS(2418),
    [anon_sym_For] = ACTIONS(2418),
    [anon_sym_foreach] = ACTIONS(2418),
    [anon_sym_FOREACH] = ACTIONS(2418),
    [anon_sym_Foreach] = ACTIONS(2418),
    [anon_sym_while] = ACTIONS(2418),
    [anon_sym_WHILE] = ACTIONS(2418),
    [anon_sym_While] = ACTIONS(2418),
    [anon_sym_repeat] = ACTIONS(2418),
    [anon_sym_REPEAT] = ACTIONS(2418),
    [anon_sym_Repeat] = ACTIONS(2418),
    [anon_sym_until] = ACTIONS(2418),
    [anon_sym_UNTIL] = ACTIONS(2418),
    [anon_sym_Until] = ACTIONS(2418),
    [anon_sym_exit] = ACTIONS(2418),
    [anon_sym_EXIT] = ACTIONS(2418),
    [anon_sym_Exit] = ACTIONS(2418),
    [anon_sym_continue] = ACTIONS(2418),
    [anon_sym_CONTINUE] = ACTIONS(2418),
    [anon_sym_Continue] = ACTIONS(2418),
    [anon_sym_break] = ACTIONS(2418),
    [anon_sym_BREAK] = ACTIONS(2418),
    [anon_sym_Break] = ACTIONS(2418),
    [anon_sym_with] = ACTIONS(2418),
    [anon_sym_WITH] = ACTIONS(2418),
    [anon_sym_With] = ACTIONS(2418),
    [sym_asserterror_keyword] = ACTIONS(2420),
    [anon_sym_in] = ACTIONS(2418),
    [anon_sym_IN] = ACTIONS(2418),
    [anon_sym_In] = ACTIONS(2418),
    [sym_page_keyword] = ACTIONS(2418),
    [anon_sym_codeunit] = ACTIONS(2418),
    [anon_sym_CODEUNIT] = ACTIONS(2418),
    [anon_sym_Codeunit] = ACTIONS(2418),
    [anon_sym_CodeUnit] = ACTIONS(2418),
    [anon_sym_COdeunit] = ACTIONS(2418),
    [anon_sym_codeUnit] = ACTIONS(2418),
    [sym_report_keyword] = ACTIONS(2418),
    [sym_query_keyword] = ACTIONS(2418),
    [anon_sym_xmlport] = ACTIONS(2418),
    [anon_sym_XMLPORT] = ACTIONS(2418),
    [anon_sym_Xmlport] = ACTIONS(2418),
    [anon_sym_XMLport] = ACTIONS(2418),
    [anon_sym_XMLPort] = ACTIONS(2418),
    [anon_sym_XmlPort] = ACTIONS(2418),
    [anon_sym_enum] = ACTIONS(2418),
    [anon_sym_ENUM] = ACTIONS(2418),
    [anon_sym_Enum] = ACTIONS(2418),
    [anon_sym_eNUM] = ACTIONS(2418),
    [anon_sym_eNum] = ACTIONS(2418),
    [anon_sym_ENum] = ACTIONS(2418),
    [sym_quoted_identifier] = ACTIONS(2420),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2420),
    [sym_integer] = ACTIONS(2418),
    [sym_continue_as_identifier] = ACTIONS(2420),
    [sym_preproc_open] = ACTIONS(2420),
  },
  [STATE(1081)] = {
    [sym_identifier] = ACTIONS(2422),
    [anon_sym_SEMI] = ACTIONS(2424),
    [anon_sym_DOT] = ACTIONS(2422),
    [anon_sym_EQ] = ACTIONS(2424),
    [anon_sym_COMMA] = ACTIONS(2424),
    [anon_sym_DASH] = ACTIONS(2422),
    [aux_sym_boolean_token1] = ACTIONS(2422),
    [aux_sym_boolean_token2] = ACTIONS(2422),
    [sym_decimal] = ACTIONS(2422),
    [anon_sym_LPAREN] = ACTIONS(2424),
    [anon_sym_DOT_DOT] = ACTIONS(2424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2422),
    [anon_sym_STAR] = ACTIONS(2422),
    [anon_sym_LBRACK] = ACTIONS(2424),
    [aux_sym_record_type_token1] = ACTIONS(2422),
    [aux_sym_basic_type_token21] = ACTIONS(2422),
    [aux_sym_basic_type_token22] = ACTIONS(2422),
    [aux_sym_basic_type_token48] = ACTIONS(2422),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2422),
    [anon_sym_COLON_COLON] = ACTIONS(2424),
    [anon_sym_POUNDif] = ACTIONS(2424),
    [anon_sym_POUNDIF] = ACTIONS(2424),
    [anon_sym_POUNDIf] = ACTIONS(2424),
    [anon_sym_not] = ACTIONS(2422),
    [anon_sym_NOT] = ACTIONS(2422),
    [anon_sym_Not] = ACTIONS(2422),
    [anon_sym_POUNDelse] = ACTIONS(2424),
    [anon_sym_POUNDELSE] = ACTIONS(2424),
    [anon_sym_POUNDElse] = ACTIONS(2424),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2424),
    [aux_sym__expression_token1] = ACTIONS(2424),
    [aux_sym__expression_token2] = ACTIONS(2422),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2422),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2422),
    [anon_sym_SLASH] = ACTIONS(2422),
    [anon_sym_div] = ACTIONS(2422),
    [anon_sym_DIV] = ACTIONS(2422),
    [anon_sym_Div] = ACTIONS(2422),
    [anon_sym_mod] = ACTIONS(2422),
    [anon_sym_MOD] = ACTIONS(2422),
    [anon_sym_Mod] = ACTIONS(2422),
    [anon_sym_PLUS] = ACTIONS(2422),
    [anon_sym_GT_EQ] = ACTIONS(2424),
    [anon_sym_LT_EQ] = ACTIONS(2424),
    [anon_sym_GT] = ACTIONS(2422),
    [anon_sym_LT] = ACTIONS(2422),
    [anon_sym_LT_GT] = ACTIONS(2424),
    [anon_sym_and] = ACTIONS(2422),
    [anon_sym_AND] = ACTIONS(2422),
    [anon_sym_And] = ACTIONS(2422),
    [anon_sym_or] = ACTIONS(2422),
    [anon_sym_OR] = ACTIONS(2422),
    [anon_sym_Or] = ACTIONS(2422),
    [anon_sym_xor] = ACTIONS(2422),
    [anon_sym_XOR] = ACTIONS(2422),
    [anon_sym_Xor] = ACTIONS(2422),
    [anon_sym_QMARK] = ACTIONS(2424),
    [sym_datetime_literal] = ACTIONS(2424),
    [sym_date_literal] = ACTIONS(2422),
    [sym_time_literal] = ACTIONS(2422),
    [sym_biginteger_literal] = ACTIONS(2424),
    [anon_sym_if] = ACTIONS(2422),
    [anon_sym_IF] = ACTIONS(2422),
    [anon_sym_If] = ACTIONS(2422),
    [anon_sym_else] = ACTIONS(2422),
    [anon_sym_ELSE] = ACTIONS(2422),
    [anon_sym_Else] = ACTIONS(2422),
    [anon_sym_case] = ACTIONS(2422),
    [anon_sym_CASE] = ACTIONS(2422),
    [anon_sym_Case] = ACTIONS(2422),
    [anon_sym_for] = ACTIONS(2422),
    [anon_sym_FOR] = ACTIONS(2422),
    [anon_sym_For] = ACTIONS(2422),
    [anon_sym_foreach] = ACTIONS(2422),
    [anon_sym_FOREACH] = ACTIONS(2422),
    [anon_sym_Foreach] = ACTIONS(2422),
    [anon_sym_while] = ACTIONS(2422),
    [anon_sym_WHILE] = ACTIONS(2422),
    [anon_sym_While] = ACTIONS(2422),
    [anon_sym_repeat] = ACTIONS(2422),
    [anon_sym_REPEAT] = ACTIONS(2422),
    [anon_sym_Repeat] = ACTIONS(2422),
    [anon_sym_until] = ACTIONS(2422),
    [anon_sym_UNTIL] = ACTIONS(2422),
    [anon_sym_Until] = ACTIONS(2422),
    [anon_sym_exit] = ACTIONS(2422),
    [anon_sym_EXIT] = ACTIONS(2422),
    [anon_sym_Exit] = ACTIONS(2422),
    [anon_sym_continue] = ACTIONS(2422),
    [anon_sym_CONTINUE] = ACTIONS(2422),
    [anon_sym_Continue] = ACTIONS(2422),
    [anon_sym_break] = ACTIONS(2422),
    [anon_sym_BREAK] = ACTIONS(2422),
    [anon_sym_Break] = ACTIONS(2422),
    [anon_sym_with] = ACTIONS(2422),
    [anon_sym_WITH] = ACTIONS(2422),
    [anon_sym_With] = ACTIONS(2422),
    [sym_asserterror_keyword] = ACTIONS(2424),
    [anon_sym_in] = ACTIONS(2422),
    [anon_sym_IN] = ACTIONS(2422),
    [anon_sym_In] = ACTIONS(2422),
    [sym_page_keyword] = ACTIONS(2422),
    [anon_sym_codeunit] = ACTIONS(2422),
    [anon_sym_CODEUNIT] = ACTIONS(2422),
    [anon_sym_Codeunit] = ACTIONS(2422),
    [anon_sym_CodeUnit] = ACTIONS(2422),
    [anon_sym_COdeunit] = ACTIONS(2422),
    [anon_sym_codeUnit] = ACTIONS(2422),
    [sym_report_keyword] = ACTIONS(2422),
    [sym_query_keyword] = ACTIONS(2422),
    [anon_sym_xmlport] = ACTIONS(2422),
    [anon_sym_XMLPORT] = ACTIONS(2422),
    [anon_sym_Xmlport] = ACTIONS(2422),
    [anon_sym_XMLport] = ACTIONS(2422),
    [anon_sym_XMLPort] = ACTIONS(2422),
    [anon_sym_XmlPort] = ACTIONS(2422),
    [anon_sym_enum] = ACTIONS(2422),
    [anon_sym_ENUM] = ACTIONS(2422),
    [anon_sym_Enum] = ACTIONS(2422),
    [anon_sym_eNUM] = ACTIONS(2422),
    [anon_sym_eNum] = ACTIONS(2422),
    [anon_sym_ENum] = ACTIONS(2422),
    [sym_quoted_identifier] = ACTIONS(2424),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2424),
    [sym_integer] = ACTIONS(2422),
    [sym_continue_as_identifier] = ACTIONS(2424),
    [sym_preproc_open] = ACTIONS(2424),
  },
  [STATE(1082)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1082),
    [sym_identifier] = ACTIONS(2403),
    [anon_sym_SEMI] = ACTIONS(2405),
    [anon_sym_DOT] = ACTIONS(2403),
    [anon_sym_EQ] = ACTIONS(2405),
    [anon_sym_COMMA] = ACTIONS(2714),
    [anon_sym_DASH] = ACTIONS(2403),
    [aux_sym_boolean_token1] = ACTIONS(2403),
    [aux_sym_boolean_token2] = ACTIONS(2403),
    [sym_decimal] = ACTIONS(2403),
    [anon_sym_LPAREN] = ACTIONS(2405),
    [anon_sym_DOT_DOT] = ACTIONS(2405),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2403),
    [anon_sym_STAR] = ACTIONS(2403),
    [anon_sym_LBRACK] = ACTIONS(2405),
    [aux_sym_record_type_token1] = ACTIONS(2403),
    [aux_sym_basic_type_token21] = ACTIONS(2403),
    [aux_sym_basic_type_token22] = ACTIONS(2403),
    [aux_sym_basic_type_token48] = ACTIONS(2403),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2403),
    [anon_sym_POUNDif] = ACTIONS(2405),
    [anon_sym_POUNDIF] = ACTIONS(2405),
    [anon_sym_POUNDIf] = ACTIONS(2405),
    [anon_sym_not] = ACTIONS(2403),
    [anon_sym_NOT] = ACTIONS(2403),
    [anon_sym_Not] = ACTIONS(2403),
    [anon_sym_POUNDelse] = ACTIONS(2405),
    [anon_sym_POUNDELSE] = ACTIONS(2405),
    [anon_sym_POUNDElse] = ACTIONS(2405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2405),
    [aux_sym__expression_token1] = ACTIONS(2405),
    [aux_sym__expression_token2] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2403),
    [anon_sym_SLASH] = ACTIONS(2403),
    [anon_sym_div] = ACTIONS(2403),
    [anon_sym_DIV] = ACTIONS(2403),
    [anon_sym_Div] = ACTIONS(2403),
    [anon_sym_mod] = ACTIONS(2403),
    [anon_sym_MOD] = ACTIONS(2403),
    [anon_sym_Mod] = ACTIONS(2403),
    [anon_sym_PLUS] = ACTIONS(2403),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_LT_GT] = ACTIONS(2405),
    [anon_sym_and] = ACTIONS(2403),
    [anon_sym_AND] = ACTIONS(2403),
    [anon_sym_And] = ACTIONS(2403),
    [anon_sym_or] = ACTIONS(2403),
    [anon_sym_OR] = ACTIONS(2403),
    [anon_sym_Or] = ACTIONS(2403),
    [anon_sym_xor] = ACTIONS(2403),
    [anon_sym_XOR] = ACTIONS(2403),
    [anon_sym_Xor] = ACTIONS(2403),
    [anon_sym_QMARK] = ACTIONS(2405),
    [sym_datetime_literal] = ACTIONS(2405),
    [sym_date_literal] = ACTIONS(2403),
    [sym_time_literal] = ACTIONS(2403),
    [sym_biginteger_literal] = ACTIONS(2405),
    [anon_sym_if] = ACTIONS(2403),
    [anon_sym_IF] = ACTIONS(2403),
    [anon_sym_If] = ACTIONS(2403),
    [anon_sym_else] = ACTIONS(2403),
    [anon_sym_ELSE] = ACTIONS(2403),
    [anon_sym_Else] = ACTIONS(2403),
    [anon_sym_case] = ACTIONS(2403),
    [anon_sym_CASE] = ACTIONS(2403),
    [anon_sym_Case] = ACTIONS(2403),
    [anon_sym_for] = ACTIONS(2403),
    [anon_sym_FOR] = ACTIONS(2403),
    [anon_sym_For] = ACTIONS(2403),
    [anon_sym_foreach] = ACTIONS(2403),
    [anon_sym_FOREACH] = ACTIONS(2403),
    [anon_sym_Foreach] = ACTIONS(2403),
    [anon_sym_while] = ACTIONS(2403),
    [anon_sym_WHILE] = ACTIONS(2403),
    [anon_sym_While] = ACTIONS(2403),
    [anon_sym_repeat] = ACTIONS(2403),
    [anon_sym_REPEAT] = ACTIONS(2403),
    [anon_sym_Repeat] = ACTIONS(2403),
    [anon_sym_until] = ACTIONS(2403),
    [anon_sym_UNTIL] = ACTIONS(2403),
    [anon_sym_Until] = ACTIONS(2403),
    [anon_sym_exit] = ACTIONS(2403),
    [anon_sym_EXIT] = ACTIONS(2403),
    [anon_sym_Exit] = ACTIONS(2403),
    [anon_sym_continue] = ACTIONS(2403),
    [anon_sym_CONTINUE] = ACTIONS(2403),
    [anon_sym_Continue] = ACTIONS(2403),
    [anon_sym_break] = ACTIONS(2403),
    [anon_sym_BREAK] = ACTIONS(2403),
    [anon_sym_Break] = ACTIONS(2403),
    [anon_sym_with] = ACTIONS(2403),
    [anon_sym_WITH] = ACTIONS(2403),
    [anon_sym_With] = ACTIONS(2403),
    [sym_asserterror_keyword] = ACTIONS(2405),
    [anon_sym_in] = ACTIONS(2403),
    [anon_sym_IN] = ACTIONS(2403),
    [anon_sym_In] = ACTIONS(2403),
    [sym_page_keyword] = ACTIONS(2403),
    [anon_sym_codeunit] = ACTIONS(2403),
    [anon_sym_CODEUNIT] = ACTIONS(2403),
    [anon_sym_Codeunit] = ACTIONS(2403),
    [anon_sym_CodeUnit] = ACTIONS(2403),
    [anon_sym_COdeunit] = ACTIONS(2403),
    [anon_sym_codeUnit] = ACTIONS(2403),
    [sym_report_keyword] = ACTIONS(2403),
    [sym_query_keyword] = ACTIONS(2403),
    [anon_sym_xmlport] = ACTIONS(2403),
    [anon_sym_XMLPORT] = ACTIONS(2403),
    [anon_sym_Xmlport] = ACTIONS(2403),
    [anon_sym_XMLport] = ACTIONS(2403),
    [anon_sym_XMLPort] = ACTIONS(2403),
    [anon_sym_XmlPort] = ACTIONS(2403),
    [anon_sym_enum] = ACTIONS(2403),
    [anon_sym_ENUM] = ACTIONS(2403),
    [anon_sym_Enum] = ACTIONS(2403),
    [anon_sym_eNUM] = ACTIONS(2403),
    [anon_sym_eNum] = ACTIONS(2403),
    [anon_sym_ENum] = ACTIONS(2403),
    [sym_quoted_identifier] = ACTIONS(2405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2405),
    [sym_integer] = ACTIONS(2403),
    [sym_continue_as_identifier] = ACTIONS(2405),
    [sym_preproc_open] = ACTIONS(2405),
  },
  [STATE(1083)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1076),
    [sym_identifier] = ACTIONS(2346),
    [anon_sym_SEMI] = ACTIONS(2348),
    [anon_sym_DOT] = ACTIONS(2707),
    [anon_sym_EQ] = ACTIONS(2348),
    [anon_sym_DASH] = ACTIONS(2346),
    [aux_sym_boolean_token1] = ACTIONS(2346),
    [aux_sym_boolean_token2] = ACTIONS(2346),
    [sym_decimal] = ACTIONS(2346),
    [anon_sym_LPAREN] = ACTIONS(2348),
    [anon_sym_DOT_DOT] = ACTIONS(2348),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2346),
    [anon_sym_STAR] = ACTIONS(2346),
    [anon_sym_LBRACK] = ACTIONS(2348),
    [aux_sym_record_type_token1] = ACTIONS(2346),
    [aux_sym_basic_type_token21] = ACTIONS(2346),
    [aux_sym_basic_type_token22] = ACTIONS(2346),
    [aux_sym_basic_type_token48] = ACTIONS(2346),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2346),
    [anon_sym_POUNDif] = ACTIONS(2348),
    [anon_sym_POUNDIF] = ACTIONS(2348),
    [anon_sym_POUNDIf] = ACTIONS(2348),
    [anon_sym_not] = ACTIONS(2346),
    [anon_sym_NOT] = ACTIONS(2346),
    [anon_sym_Not] = ACTIONS(2346),
    [anon_sym_POUNDelse] = ACTIONS(2348),
    [anon_sym_POUNDELSE] = ACTIONS(2348),
    [anon_sym_POUNDElse] = ACTIONS(2348),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2348),
    [aux_sym__expression_token1] = ACTIONS(2348),
    [aux_sym__expression_token2] = ACTIONS(2346),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2346),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2346),
    [anon_sym_SLASH] = ACTIONS(2346),
    [anon_sym_div] = ACTIONS(2346),
    [anon_sym_DIV] = ACTIONS(2346),
    [anon_sym_Div] = ACTIONS(2346),
    [anon_sym_mod] = ACTIONS(2346),
    [anon_sym_MOD] = ACTIONS(2346),
    [anon_sym_Mod] = ACTIONS(2346),
    [anon_sym_PLUS] = ACTIONS(2346),
    [anon_sym_GT_EQ] = ACTIONS(2348),
    [anon_sym_LT_EQ] = ACTIONS(2348),
    [anon_sym_GT] = ACTIONS(2346),
    [anon_sym_LT] = ACTIONS(2346),
    [anon_sym_LT_GT] = ACTIONS(2348),
    [anon_sym_and] = ACTIONS(2346),
    [anon_sym_AND] = ACTIONS(2346),
    [anon_sym_And] = ACTIONS(2346),
    [anon_sym_or] = ACTIONS(2346),
    [anon_sym_OR] = ACTIONS(2346),
    [anon_sym_Or] = ACTIONS(2346),
    [anon_sym_xor] = ACTIONS(2346),
    [anon_sym_XOR] = ACTIONS(2346),
    [anon_sym_Xor] = ACTIONS(2346),
    [anon_sym_QMARK] = ACTIONS(2348),
    [sym_datetime_literal] = ACTIONS(2348),
    [sym_date_literal] = ACTIONS(2346),
    [sym_time_literal] = ACTIONS(2346),
    [sym_biginteger_literal] = ACTIONS(2348),
    [anon_sym_if] = ACTIONS(2346),
    [anon_sym_IF] = ACTIONS(2346),
    [anon_sym_If] = ACTIONS(2346),
    [anon_sym_else] = ACTIONS(2346),
    [anon_sym_ELSE] = ACTIONS(2346),
    [anon_sym_Else] = ACTIONS(2346),
    [anon_sym_case] = ACTIONS(2346),
    [anon_sym_CASE] = ACTIONS(2346),
    [anon_sym_Case] = ACTIONS(2346),
    [anon_sym_for] = ACTIONS(2346),
    [anon_sym_FOR] = ACTIONS(2346),
    [anon_sym_For] = ACTIONS(2346),
    [anon_sym_foreach] = ACTIONS(2346),
    [anon_sym_FOREACH] = ACTIONS(2346),
    [anon_sym_Foreach] = ACTIONS(2346),
    [anon_sym_while] = ACTIONS(2346),
    [anon_sym_WHILE] = ACTIONS(2346),
    [anon_sym_While] = ACTIONS(2346),
    [anon_sym_repeat] = ACTIONS(2346),
    [anon_sym_REPEAT] = ACTIONS(2346),
    [anon_sym_Repeat] = ACTIONS(2346),
    [anon_sym_until] = ACTIONS(2346),
    [anon_sym_UNTIL] = ACTIONS(2346),
    [anon_sym_Until] = ACTIONS(2346),
    [anon_sym_exit] = ACTIONS(2346),
    [anon_sym_EXIT] = ACTIONS(2346),
    [anon_sym_Exit] = ACTIONS(2346),
    [anon_sym_continue] = ACTIONS(2346),
    [anon_sym_CONTINUE] = ACTIONS(2346),
    [anon_sym_Continue] = ACTIONS(2346),
    [anon_sym_break] = ACTIONS(2346),
    [anon_sym_BREAK] = ACTIONS(2346),
    [anon_sym_Break] = ACTIONS(2346),
    [anon_sym_with] = ACTIONS(2346),
    [anon_sym_WITH] = ACTIONS(2346),
    [anon_sym_With] = ACTIONS(2346),
    [sym_asserterror_keyword] = ACTIONS(2348),
    [anon_sym_in] = ACTIONS(2346),
    [anon_sym_IN] = ACTIONS(2346),
    [anon_sym_In] = ACTIONS(2346),
    [sym_page_keyword] = ACTIONS(2346),
    [anon_sym_codeunit] = ACTIONS(2346),
    [anon_sym_CODEUNIT] = ACTIONS(2346),
    [anon_sym_Codeunit] = ACTIONS(2346),
    [anon_sym_CodeUnit] = ACTIONS(2346),
    [anon_sym_COdeunit] = ACTIONS(2346),
    [anon_sym_codeUnit] = ACTIONS(2346),
    [sym_report_keyword] = ACTIONS(2346),
    [sym_query_keyword] = ACTIONS(2346),
    [anon_sym_xmlport] = ACTIONS(2346),
    [anon_sym_XMLPORT] = ACTIONS(2346),
    [anon_sym_Xmlport] = ACTIONS(2346),
    [anon_sym_XMLport] = ACTIONS(2346),
    [anon_sym_XMLPort] = ACTIONS(2346),
    [anon_sym_XmlPort] = ACTIONS(2346),
    [anon_sym_enum] = ACTIONS(2346),
    [anon_sym_ENUM] = ACTIONS(2346),
    [anon_sym_Enum] = ACTIONS(2346),
    [anon_sym_eNUM] = ACTIONS(2346),
    [anon_sym_eNum] = ACTIONS(2346),
    [anon_sym_ENum] = ACTIONS(2346),
    [sym_temporary_keyword] = ACTIONS(2346),
    [sym_quoted_identifier] = ACTIONS(2348),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2348),
    [sym_integer] = ACTIONS(2346),
    [sym_continue_as_identifier] = ACTIONS(2348),
    [sym_preproc_open] = ACTIONS(2348),
  },
  [STATE(1084)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2430),
    [anon_sym_SEMI] = ACTIONS(2432),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2432),
    [anon_sym_DASH] = ACTIONS(2430),
    [aux_sym_boolean_token1] = ACTIONS(2430),
    [aux_sym_boolean_token2] = ACTIONS(2430),
    [sym_decimal] = ACTIONS(2430),
    [anon_sym_LPAREN] = ACTIONS(2432),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2430),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2430),
    [aux_sym_basic_type_token21] = ACTIONS(2430),
    [aux_sym_basic_type_token22] = ACTIONS(2430),
    [aux_sym_basic_type_token48] = ACTIONS(2430),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2430),
    [anon_sym_POUNDif] = ACTIONS(2432),
    [anon_sym_POUNDIF] = ACTIONS(2432),
    [anon_sym_POUNDIf] = ACTIONS(2432),
    [anon_sym_not] = ACTIONS(2430),
    [anon_sym_NOT] = ACTIONS(2430),
    [anon_sym_Not] = ACTIONS(2430),
    [anon_sym_POUNDelse] = ACTIONS(2432),
    [anon_sym_POUNDELSE] = ACTIONS(2432),
    [anon_sym_POUNDElse] = ACTIONS(2432),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2432),
    [aux_sym__expression_token1] = ACTIONS(2432),
    [aux_sym__expression_token2] = ACTIONS(2430),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2430),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2430),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2430),
    [anon_sym_GT_EQ] = ACTIONS(2432),
    [anon_sym_LT_EQ] = ACTIONS(2432),
    [anon_sym_GT] = ACTIONS(2430),
    [anon_sym_LT] = ACTIONS(2430),
    [anon_sym_LT_GT] = ACTIONS(2432),
    [anon_sym_and] = ACTIONS(2430),
    [anon_sym_AND] = ACTIONS(2430),
    [anon_sym_And] = ACTIONS(2430),
    [anon_sym_or] = ACTIONS(2430),
    [anon_sym_OR] = ACTIONS(2430),
    [anon_sym_Or] = ACTIONS(2430),
    [anon_sym_xor] = ACTIONS(2430),
    [anon_sym_XOR] = ACTIONS(2430),
    [anon_sym_Xor] = ACTIONS(2430),
    [anon_sym_QMARK] = ACTIONS(2432),
    [sym_datetime_literal] = ACTIONS(2432),
    [sym_date_literal] = ACTIONS(2430),
    [sym_time_literal] = ACTIONS(2430),
    [sym_biginteger_literal] = ACTIONS(2432),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_IF] = ACTIONS(2430),
    [anon_sym_If] = ACTIONS(2430),
    [anon_sym_else] = ACTIONS(2430),
    [anon_sym_ELSE] = ACTIONS(2430),
    [anon_sym_Else] = ACTIONS(2430),
    [anon_sym_case] = ACTIONS(2430),
    [anon_sym_CASE] = ACTIONS(2430),
    [anon_sym_Case] = ACTIONS(2430),
    [anon_sym_for] = ACTIONS(2430),
    [anon_sym_FOR] = ACTIONS(2430),
    [anon_sym_For] = ACTIONS(2430),
    [anon_sym_foreach] = ACTIONS(2430),
    [anon_sym_FOREACH] = ACTIONS(2430),
    [anon_sym_Foreach] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2430),
    [anon_sym_WHILE] = ACTIONS(2430),
    [anon_sym_While] = ACTIONS(2430),
    [anon_sym_repeat] = ACTIONS(2430),
    [anon_sym_REPEAT] = ACTIONS(2430),
    [anon_sym_Repeat] = ACTIONS(2430),
    [anon_sym_until] = ACTIONS(2430),
    [anon_sym_UNTIL] = ACTIONS(2430),
    [anon_sym_Until] = ACTIONS(2430),
    [anon_sym_exit] = ACTIONS(2430),
    [anon_sym_EXIT] = ACTIONS(2430),
    [anon_sym_Exit] = ACTIONS(2430),
    [anon_sym_continue] = ACTIONS(2430),
    [anon_sym_CONTINUE] = ACTIONS(2430),
    [anon_sym_Continue] = ACTIONS(2430),
    [anon_sym_break] = ACTIONS(2430),
    [anon_sym_BREAK] = ACTIONS(2430),
    [anon_sym_Break] = ACTIONS(2430),
    [anon_sym_with] = ACTIONS(2430),
    [anon_sym_WITH] = ACTIONS(2430),
    [anon_sym_With] = ACTIONS(2430),
    [sym_asserterror_keyword] = ACTIONS(2432),
    [anon_sym_in] = ACTIONS(2430),
    [anon_sym_IN] = ACTIONS(2430),
    [anon_sym_In] = ACTIONS(2430),
    [sym_page_keyword] = ACTIONS(2430),
    [anon_sym_codeunit] = ACTIONS(2430),
    [anon_sym_CODEUNIT] = ACTIONS(2430),
    [anon_sym_Codeunit] = ACTIONS(2430),
    [anon_sym_CodeUnit] = ACTIONS(2430),
    [anon_sym_COdeunit] = ACTIONS(2430),
    [anon_sym_codeUnit] = ACTIONS(2430),
    [sym_report_keyword] = ACTIONS(2430),
    [sym_query_keyword] = ACTIONS(2430),
    [anon_sym_xmlport] = ACTIONS(2430),
    [anon_sym_XMLPORT] = ACTIONS(2430),
    [anon_sym_Xmlport] = ACTIONS(2430),
    [anon_sym_XMLport] = ACTIONS(2430),
    [anon_sym_XMLPort] = ACTIONS(2430),
    [anon_sym_XmlPort] = ACTIONS(2430),
    [anon_sym_enum] = ACTIONS(2430),
    [anon_sym_ENUM] = ACTIONS(2430),
    [anon_sym_Enum] = ACTIONS(2430),
    [anon_sym_eNUM] = ACTIONS(2430),
    [anon_sym_eNum] = ACTIONS(2430),
    [anon_sym_ENum] = ACTIONS(2430),
    [sym_quoted_identifier] = ACTIONS(2432),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2432),
    [sym_integer] = ACTIONS(2430),
    [sym_continue_as_identifier] = ACTIONS(2432),
    [sym_preproc_open] = ACTIONS(2432),
  },
  [STATE(1085)] = {
    [sym_argument_list] = STATE(1111),
    [sym_identifier] = ACTIONS(2434),
    [anon_sym_SEMI] = ACTIONS(2436),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_DASH] = ACTIONS(2434),
    [aux_sym_boolean_token1] = ACTIONS(2434),
    [aux_sym_boolean_token2] = ACTIONS(2434),
    [sym_decimal] = ACTIONS(2434),
    [anon_sym_LPAREN] = ACTIONS(2717),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2434),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [aux_sym_record_type_token1] = ACTIONS(2434),
    [aux_sym_basic_type_token21] = ACTIONS(2434),
    [aux_sym_basic_type_token22] = ACTIONS(2434),
    [aux_sym_basic_type_token48] = ACTIONS(2434),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2434),
    [anon_sym_COLON_COLON] = ACTIONS(2719),
    [anon_sym_POUNDif] = ACTIONS(2436),
    [anon_sym_POUNDIF] = ACTIONS(2436),
    [anon_sym_POUNDIf] = ACTIONS(2436),
    [anon_sym_not] = ACTIONS(2434),
    [anon_sym_NOT] = ACTIONS(2434),
    [anon_sym_Not] = ACTIONS(2434),
    [anon_sym_POUNDelse] = ACTIONS(2436),
    [anon_sym_POUNDELSE] = ACTIONS(2436),
    [anon_sym_POUNDElse] = ACTIONS(2436),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2434),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(2434),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(2436),
    [sym_date_literal] = ACTIONS(2434),
    [sym_time_literal] = ACTIONS(2434),
    [sym_biginteger_literal] = ACTIONS(2436),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_IF] = ACTIONS(2434),
    [anon_sym_If] = ACTIONS(2434),
    [anon_sym_else] = ACTIONS(2434),
    [anon_sym_ELSE] = ACTIONS(2434),
    [anon_sym_Else] = ACTIONS(2434),
    [anon_sym_case] = ACTIONS(2434),
    [anon_sym_CASE] = ACTIONS(2434),
    [anon_sym_Case] = ACTIONS(2434),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_FOR] = ACTIONS(2434),
    [anon_sym_For] = ACTIONS(2434),
    [anon_sym_foreach] = ACTIONS(2434),
    [anon_sym_FOREACH] = ACTIONS(2434),
    [anon_sym_Foreach] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(2434),
    [anon_sym_WHILE] = ACTIONS(2434),
    [anon_sym_While] = ACTIONS(2434),
    [anon_sym_repeat] = ACTIONS(2434),
    [anon_sym_REPEAT] = ACTIONS(2434),
    [anon_sym_Repeat] = ACTIONS(2434),
    [anon_sym_until] = ACTIONS(2434),
    [anon_sym_UNTIL] = ACTIONS(2434),
    [anon_sym_Until] = ACTIONS(2434),
    [anon_sym_exit] = ACTIONS(2434),
    [anon_sym_EXIT] = ACTIONS(2434),
    [anon_sym_Exit] = ACTIONS(2434),
    [anon_sym_continue] = ACTIONS(2434),
    [anon_sym_CONTINUE] = ACTIONS(2434),
    [anon_sym_Continue] = ACTIONS(2434),
    [anon_sym_break] = ACTIONS(2434),
    [anon_sym_BREAK] = ACTIONS(2434),
    [anon_sym_Break] = ACTIONS(2434),
    [anon_sym_with] = ACTIONS(2434),
    [anon_sym_WITH] = ACTIONS(2434),
    [anon_sym_With] = ACTIONS(2434),
    [sym_asserterror_keyword] = ACTIONS(2436),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(2434),
    [anon_sym_codeunit] = ACTIONS(2434),
    [anon_sym_CODEUNIT] = ACTIONS(2434),
    [anon_sym_Codeunit] = ACTIONS(2434),
    [anon_sym_CodeUnit] = ACTIONS(2434),
    [anon_sym_COdeunit] = ACTIONS(2434),
    [anon_sym_codeUnit] = ACTIONS(2434),
    [sym_report_keyword] = ACTIONS(2434),
    [sym_query_keyword] = ACTIONS(2434),
    [anon_sym_xmlport] = ACTIONS(2434),
    [anon_sym_XMLPORT] = ACTIONS(2434),
    [anon_sym_Xmlport] = ACTIONS(2434),
    [anon_sym_XMLport] = ACTIONS(2434),
    [anon_sym_XMLPort] = ACTIONS(2434),
    [anon_sym_XmlPort] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2434),
    [anon_sym_ENUM] = ACTIONS(2434),
    [anon_sym_Enum] = ACTIONS(2434),
    [anon_sym_eNUM] = ACTIONS(2434),
    [anon_sym_eNum] = ACTIONS(2434),
    [anon_sym_ENum] = ACTIONS(2434),
    [sym_quoted_identifier] = ACTIONS(2436),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2436),
    [sym_integer] = ACTIONS(2434),
    [sym_continue_as_identifier] = ACTIONS(2436),
    [sym_preproc_open] = ACTIONS(2436),
  },
  [STATE(1086)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1072),
    [sym_identifier] = ACTIONS(376),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(2703),
    [anon_sym_DASH] = ACTIONS(376),
    [aux_sym_boolean_token1] = ACTIONS(376),
    [aux_sym_boolean_token2] = ACTIONS(376),
    [sym_decimal] = ACTIONS(376),
    [anon_sym_LPAREN] = ACTIONS(374),
    [anon_sym_DOT_DOT] = ACTIONS(374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(376),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(376),
    [aux_sym_basic_type_token21] = ACTIONS(376),
    [aux_sym_basic_type_token22] = ACTIONS(376),
    [aux_sym_basic_type_token48] = ACTIONS(376),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(376),
    [anon_sym_POUNDif] = ACTIONS(374),
    [anon_sym_POUNDIF] = ACTIONS(374),
    [anon_sym_POUNDIf] = ACTIONS(374),
    [anon_sym_not] = ACTIONS(376),
    [anon_sym_NOT] = ACTIONS(376),
    [anon_sym_Not] = ACTIONS(376),
    [anon_sym_POUNDelse] = ACTIONS(374),
    [anon_sym_POUNDELSE] = ACTIONS(374),
    [anon_sym_POUNDElse] = ACTIONS(374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(374),
    [aux_sym__expression_token1] = ACTIONS(374),
    [aux_sym__expression_token2] = ACTIONS(376),
    [aux_sym_keyword_identifier_token1] = ACTIONS(376),
    [aux_sym_keyword_identifier_token2] = ACTIONS(376),
    [anon_sym_SLASH] = ACTIONS(376),
    [anon_sym_div] = ACTIONS(376),
    [anon_sym_DIV] = ACTIONS(376),
    [anon_sym_Div] = ACTIONS(376),
    [anon_sym_mod] = ACTIONS(376),
    [anon_sym_MOD] = ACTIONS(376),
    [anon_sym_Mod] = ACTIONS(376),
    [anon_sym_PLUS] = ACTIONS(376),
    [anon_sym_GT_EQ] = ACTIONS(374),
    [anon_sym_LT_EQ] = ACTIONS(374),
    [anon_sym_GT] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(376),
    [anon_sym_LT_GT] = ACTIONS(374),
    [anon_sym_and] = ACTIONS(376),
    [anon_sym_AND] = ACTIONS(376),
    [anon_sym_And] = ACTIONS(376),
    [anon_sym_or] = ACTIONS(376),
    [anon_sym_OR] = ACTIONS(376),
    [anon_sym_Or] = ACTIONS(376),
    [anon_sym_xor] = ACTIONS(376),
    [anon_sym_XOR] = ACTIONS(376),
    [anon_sym_Xor] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(374),
    [sym_datetime_literal] = ACTIONS(374),
    [sym_date_literal] = ACTIONS(376),
    [sym_time_literal] = ACTIONS(376),
    [sym_biginteger_literal] = ACTIONS(374),
    [anon_sym_if] = ACTIONS(376),
    [anon_sym_IF] = ACTIONS(376),
    [anon_sym_If] = ACTIONS(376),
    [anon_sym_else] = ACTIONS(376),
    [anon_sym_ELSE] = ACTIONS(376),
    [anon_sym_Else] = ACTIONS(376),
    [anon_sym_case] = ACTIONS(376),
    [anon_sym_CASE] = ACTIONS(376),
    [anon_sym_Case] = ACTIONS(376),
    [anon_sym_for] = ACTIONS(376),
    [anon_sym_FOR] = ACTIONS(376),
    [anon_sym_For] = ACTIONS(376),
    [anon_sym_foreach] = ACTIONS(376),
    [anon_sym_FOREACH] = ACTIONS(376),
    [anon_sym_Foreach] = ACTIONS(376),
    [anon_sym_while] = ACTIONS(376),
    [anon_sym_WHILE] = ACTIONS(376),
    [anon_sym_While] = ACTIONS(376),
    [anon_sym_repeat] = ACTIONS(376),
    [anon_sym_REPEAT] = ACTIONS(376),
    [anon_sym_Repeat] = ACTIONS(376),
    [anon_sym_until] = ACTIONS(376),
    [anon_sym_UNTIL] = ACTIONS(376),
    [anon_sym_Until] = ACTIONS(376),
    [anon_sym_exit] = ACTIONS(376),
    [anon_sym_EXIT] = ACTIONS(376),
    [anon_sym_Exit] = ACTIONS(376),
    [anon_sym_continue] = ACTIONS(376),
    [anon_sym_CONTINUE] = ACTIONS(376),
    [anon_sym_Continue] = ACTIONS(376),
    [anon_sym_break] = ACTIONS(376),
    [anon_sym_BREAK] = ACTIONS(376),
    [anon_sym_Break] = ACTIONS(376),
    [anon_sym_with] = ACTIONS(376),
    [anon_sym_WITH] = ACTIONS(376),
    [anon_sym_With] = ACTIONS(376),
    [sym_asserterror_keyword] = ACTIONS(374),
    [anon_sym_in] = ACTIONS(376),
    [anon_sym_IN] = ACTIONS(376),
    [anon_sym_In] = ACTIONS(376),
    [sym_page_keyword] = ACTIONS(376),
    [anon_sym_codeunit] = ACTIONS(376),
    [anon_sym_CODEUNIT] = ACTIONS(376),
    [anon_sym_Codeunit] = ACTIONS(376),
    [anon_sym_CodeUnit] = ACTIONS(376),
    [anon_sym_COdeunit] = ACTIONS(376),
    [anon_sym_codeUnit] = ACTIONS(376),
    [sym_report_keyword] = ACTIONS(376),
    [sym_query_keyword] = ACTIONS(376),
    [anon_sym_xmlport] = ACTIONS(376),
    [anon_sym_XMLPORT] = ACTIONS(376),
    [anon_sym_Xmlport] = ACTIONS(376),
    [anon_sym_XMLport] = ACTIONS(376),
    [anon_sym_XMLPort] = ACTIONS(376),
    [anon_sym_XmlPort] = ACTIONS(376),
    [anon_sym_enum] = ACTIONS(376),
    [anon_sym_ENUM] = ACTIONS(376),
    [anon_sym_Enum] = ACTIONS(376),
    [anon_sym_eNUM] = ACTIONS(376),
    [anon_sym_eNum] = ACTIONS(376),
    [anon_sym_ENum] = ACTIONS(376),
    [sym_quoted_identifier] = ACTIONS(374),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(374),
    [sym_integer] = ACTIONS(376),
    [sym_continue_as_identifier] = ACTIONS(374),
    [sym_preproc_open] = ACTIONS(374),
  },
  [STATE(1087)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2360),
    [anon_sym_SEMI] = ACTIONS(2362),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2362),
    [anon_sym_DASH] = ACTIONS(2360),
    [aux_sym_boolean_token1] = ACTIONS(2360),
    [aux_sym_boolean_token2] = ACTIONS(2360),
    [sym_decimal] = ACTIONS(2360),
    [anon_sym_LPAREN] = ACTIONS(2362),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2360),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2360),
    [aux_sym_basic_type_token21] = ACTIONS(2360),
    [aux_sym_basic_type_token22] = ACTIONS(2360),
    [aux_sym_basic_type_token48] = ACTIONS(2360),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2360),
    [anon_sym_POUNDif] = ACTIONS(2362),
    [anon_sym_POUNDIF] = ACTIONS(2362),
    [anon_sym_POUNDIf] = ACTIONS(2362),
    [anon_sym_not] = ACTIONS(2360),
    [anon_sym_NOT] = ACTIONS(2360),
    [anon_sym_Not] = ACTIONS(2360),
    [anon_sym_POUNDelse] = ACTIONS(2362),
    [anon_sym_POUNDELSE] = ACTIONS(2362),
    [anon_sym_POUNDElse] = ACTIONS(2362),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2362),
    [aux_sym__expression_token1] = ACTIONS(2362),
    [aux_sym__expression_token2] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2360),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2360),
    [anon_sym_GT_EQ] = ACTIONS(2362),
    [anon_sym_LT_EQ] = ACTIONS(2362),
    [anon_sym_GT] = ACTIONS(2360),
    [anon_sym_LT] = ACTIONS(2360),
    [anon_sym_LT_GT] = ACTIONS(2362),
    [anon_sym_and] = ACTIONS(2360),
    [anon_sym_AND] = ACTIONS(2360),
    [anon_sym_And] = ACTIONS(2360),
    [anon_sym_or] = ACTIONS(2360),
    [anon_sym_OR] = ACTIONS(2360),
    [anon_sym_Or] = ACTIONS(2360),
    [anon_sym_xor] = ACTIONS(2360),
    [anon_sym_XOR] = ACTIONS(2360),
    [anon_sym_Xor] = ACTIONS(2360),
    [anon_sym_QMARK] = ACTIONS(2362),
    [sym_datetime_literal] = ACTIONS(2362),
    [sym_date_literal] = ACTIONS(2360),
    [sym_time_literal] = ACTIONS(2360),
    [sym_biginteger_literal] = ACTIONS(2362),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_IF] = ACTIONS(2360),
    [anon_sym_If] = ACTIONS(2360),
    [anon_sym_else] = ACTIONS(2360),
    [anon_sym_ELSE] = ACTIONS(2360),
    [anon_sym_Else] = ACTIONS(2360),
    [anon_sym_case] = ACTIONS(2360),
    [anon_sym_CASE] = ACTIONS(2360),
    [anon_sym_Case] = ACTIONS(2360),
    [anon_sym_for] = ACTIONS(2360),
    [anon_sym_FOR] = ACTIONS(2360),
    [anon_sym_For] = ACTIONS(2360),
    [anon_sym_foreach] = ACTIONS(2360),
    [anon_sym_FOREACH] = ACTIONS(2360),
    [anon_sym_Foreach] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2360),
    [anon_sym_WHILE] = ACTIONS(2360),
    [anon_sym_While] = ACTIONS(2360),
    [anon_sym_repeat] = ACTIONS(2360),
    [anon_sym_REPEAT] = ACTIONS(2360),
    [anon_sym_Repeat] = ACTIONS(2360),
    [anon_sym_until] = ACTIONS(2360),
    [anon_sym_UNTIL] = ACTIONS(2360),
    [anon_sym_Until] = ACTIONS(2360),
    [anon_sym_exit] = ACTIONS(2360),
    [anon_sym_EXIT] = ACTIONS(2360),
    [anon_sym_Exit] = ACTIONS(2360),
    [anon_sym_continue] = ACTIONS(2360),
    [anon_sym_CONTINUE] = ACTIONS(2360),
    [anon_sym_Continue] = ACTIONS(2360),
    [anon_sym_break] = ACTIONS(2360),
    [anon_sym_BREAK] = ACTIONS(2360),
    [anon_sym_Break] = ACTIONS(2360),
    [anon_sym_with] = ACTIONS(2360),
    [anon_sym_WITH] = ACTIONS(2360),
    [anon_sym_With] = ACTIONS(2360),
    [sym_asserterror_keyword] = ACTIONS(2362),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_IN] = ACTIONS(2360),
    [anon_sym_In] = ACTIONS(2360),
    [sym_page_keyword] = ACTIONS(2360),
    [anon_sym_codeunit] = ACTIONS(2360),
    [anon_sym_CODEUNIT] = ACTIONS(2360),
    [anon_sym_Codeunit] = ACTIONS(2360),
    [anon_sym_CodeUnit] = ACTIONS(2360),
    [anon_sym_COdeunit] = ACTIONS(2360),
    [anon_sym_codeUnit] = ACTIONS(2360),
    [sym_report_keyword] = ACTIONS(2360),
    [sym_query_keyword] = ACTIONS(2360),
    [anon_sym_xmlport] = ACTIONS(2360),
    [anon_sym_XMLPORT] = ACTIONS(2360),
    [anon_sym_Xmlport] = ACTIONS(2360),
    [anon_sym_XMLport] = ACTIONS(2360),
    [anon_sym_XMLPort] = ACTIONS(2360),
    [anon_sym_XmlPort] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_ENUM] = ACTIONS(2360),
    [anon_sym_Enum] = ACTIONS(2360),
    [anon_sym_eNUM] = ACTIONS(2360),
    [anon_sym_eNum] = ACTIONS(2360),
    [anon_sym_ENum] = ACTIONS(2360),
    [sym_quoted_identifier] = ACTIONS(2362),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2362),
    [sym_integer] = ACTIONS(2360),
    [sym_continue_as_identifier] = ACTIONS(2362),
    [sym_preproc_open] = ACTIONS(2362),
  },
  [STATE(1088)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2316),
    [anon_sym_SEMI] = ACTIONS(2318),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2318),
    [anon_sym_DASH] = ACTIONS(2316),
    [aux_sym_boolean_token1] = ACTIONS(2316),
    [aux_sym_boolean_token2] = ACTIONS(2316),
    [sym_decimal] = ACTIONS(2316),
    [anon_sym_LPAREN] = ACTIONS(2318),
    [anon_sym_DOT_DOT] = ACTIONS(2318),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2316),
    [anon_sym_STAR] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2316),
    [aux_sym_basic_type_token21] = ACTIONS(2316),
    [aux_sym_basic_type_token22] = ACTIONS(2316),
    [aux_sym_basic_type_token48] = ACTIONS(2316),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2316),
    [anon_sym_POUNDif] = ACTIONS(2318),
    [anon_sym_POUNDIF] = ACTIONS(2318),
    [anon_sym_POUNDIf] = ACTIONS(2318),
    [anon_sym_not] = ACTIONS(2316),
    [anon_sym_NOT] = ACTIONS(2316),
    [anon_sym_Not] = ACTIONS(2316),
    [anon_sym_POUNDelse] = ACTIONS(2318),
    [anon_sym_POUNDELSE] = ACTIONS(2318),
    [anon_sym_POUNDElse] = ACTIONS(2318),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2318),
    [aux_sym__expression_token1] = ACTIONS(2318),
    [aux_sym__expression_token2] = ACTIONS(2316),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2316),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2316),
    [anon_sym_SLASH] = ACTIONS(2316),
    [anon_sym_div] = ACTIONS(2316),
    [anon_sym_DIV] = ACTIONS(2316),
    [anon_sym_Div] = ACTIONS(2316),
    [anon_sym_mod] = ACTIONS(2316),
    [anon_sym_MOD] = ACTIONS(2316),
    [anon_sym_Mod] = ACTIONS(2316),
    [anon_sym_PLUS] = ACTIONS(2316),
    [anon_sym_GT_EQ] = ACTIONS(2318),
    [anon_sym_LT_EQ] = ACTIONS(2318),
    [anon_sym_GT] = ACTIONS(2316),
    [anon_sym_LT] = ACTIONS(2316),
    [anon_sym_LT_GT] = ACTIONS(2318),
    [anon_sym_and] = ACTIONS(2316),
    [anon_sym_AND] = ACTIONS(2316),
    [anon_sym_And] = ACTIONS(2316),
    [anon_sym_or] = ACTIONS(2316),
    [anon_sym_OR] = ACTIONS(2316),
    [anon_sym_Or] = ACTIONS(2316),
    [anon_sym_xor] = ACTIONS(2316),
    [anon_sym_XOR] = ACTIONS(2316),
    [anon_sym_Xor] = ACTIONS(2316),
    [anon_sym_QMARK] = ACTIONS(2318),
    [sym_datetime_literal] = ACTIONS(2318),
    [sym_date_literal] = ACTIONS(2316),
    [sym_time_literal] = ACTIONS(2316),
    [sym_biginteger_literal] = ACTIONS(2318),
    [anon_sym_if] = ACTIONS(2316),
    [anon_sym_IF] = ACTIONS(2316),
    [anon_sym_If] = ACTIONS(2316),
    [anon_sym_else] = ACTIONS(2316),
    [anon_sym_ELSE] = ACTIONS(2316),
    [anon_sym_Else] = ACTIONS(2316),
    [anon_sym_case] = ACTIONS(2316),
    [anon_sym_CASE] = ACTIONS(2316),
    [anon_sym_Case] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2316),
    [anon_sym_FOR] = ACTIONS(2316),
    [anon_sym_For] = ACTIONS(2316),
    [anon_sym_foreach] = ACTIONS(2316),
    [anon_sym_FOREACH] = ACTIONS(2316),
    [anon_sym_Foreach] = ACTIONS(2316),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_WHILE] = ACTIONS(2316),
    [anon_sym_While] = ACTIONS(2316),
    [anon_sym_repeat] = ACTIONS(2316),
    [anon_sym_REPEAT] = ACTIONS(2316),
    [anon_sym_Repeat] = ACTIONS(2316),
    [anon_sym_until] = ACTIONS(2316),
    [anon_sym_UNTIL] = ACTIONS(2316),
    [anon_sym_Until] = ACTIONS(2316),
    [anon_sym_exit] = ACTIONS(2316),
    [anon_sym_EXIT] = ACTIONS(2316),
    [anon_sym_Exit] = ACTIONS(2316),
    [anon_sym_continue] = ACTIONS(2316),
    [anon_sym_CONTINUE] = ACTIONS(2316),
    [anon_sym_Continue] = ACTIONS(2316),
    [anon_sym_break] = ACTIONS(2316),
    [anon_sym_BREAK] = ACTIONS(2316),
    [anon_sym_Break] = ACTIONS(2316),
    [anon_sym_with] = ACTIONS(2316),
    [anon_sym_WITH] = ACTIONS(2316),
    [anon_sym_With] = ACTIONS(2316),
    [sym_asserterror_keyword] = ACTIONS(2318),
    [anon_sym_in] = ACTIONS(2316),
    [anon_sym_IN] = ACTIONS(2316),
    [anon_sym_In] = ACTIONS(2316),
    [sym_page_keyword] = ACTIONS(2316),
    [anon_sym_codeunit] = ACTIONS(2316),
    [anon_sym_CODEUNIT] = ACTIONS(2316),
    [anon_sym_Codeunit] = ACTIONS(2316),
    [anon_sym_CodeUnit] = ACTIONS(2316),
    [anon_sym_COdeunit] = ACTIONS(2316),
    [anon_sym_codeUnit] = ACTIONS(2316),
    [sym_report_keyword] = ACTIONS(2316),
    [sym_query_keyword] = ACTIONS(2316),
    [anon_sym_xmlport] = ACTIONS(2316),
    [anon_sym_XMLPORT] = ACTIONS(2316),
    [anon_sym_Xmlport] = ACTIONS(2316),
    [anon_sym_XMLport] = ACTIONS(2316),
    [anon_sym_XMLPort] = ACTIONS(2316),
    [anon_sym_XmlPort] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_ENUM] = ACTIONS(2316),
    [anon_sym_Enum] = ACTIONS(2316),
    [anon_sym_eNUM] = ACTIONS(2316),
    [anon_sym_eNum] = ACTIONS(2316),
    [anon_sym_ENum] = ACTIONS(2316),
    [sym_quoted_identifier] = ACTIONS(2318),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2318),
    [sym_integer] = ACTIONS(2316),
    [sym_continue_as_identifier] = ACTIONS(2318),
    [sym_preproc_open] = ACTIONS(2318),
  },
  [STATE(1089)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_until] = ACTIONS(2320),
    [anon_sym_UNTIL] = ACTIONS(2320),
    [anon_sym_Until] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
  },
  [STATE(1090)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2326),
    [anon_sym_SEMI] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2675),
    [aux_sym_boolean_token1] = ACTIONS(2326),
    [aux_sym_boolean_token2] = ACTIONS(2326),
    [sym_decimal] = ACTIONS(2326),
    [anon_sym_LPAREN] = ACTIONS(2328),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [aux_sym_record_type_token1] = ACTIONS(2326),
    [aux_sym_basic_type_token21] = ACTIONS(2326),
    [aux_sym_basic_type_token22] = ACTIONS(2326),
    [aux_sym_basic_type_token48] = ACTIONS(2326),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2326),
    [anon_sym_POUNDif] = ACTIONS(2328),
    [anon_sym_POUNDIF] = ACTIONS(2328),
    [anon_sym_POUNDIf] = ACTIONS(2328),
    [anon_sym_not] = ACTIONS(2326),
    [anon_sym_NOT] = ACTIONS(2326),
    [anon_sym_Not] = ACTIONS(2326),
    [anon_sym_POUNDelse] = ACTIONS(2328),
    [anon_sym_POUNDELSE] = ACTIONS(2328),
    [anon_sym_POUNDElse] = ACTIONS(2328),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2705),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2326),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2326),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2683),
    [anon_sym_AND] = ACTIONS(2685),
    [anon_sym_And] = ACTIONS(2687),
    [anon_sym_or] = ACTIONS(2689),
    [anon_sym_OR] = ACTIONS(2691),
    [anon_sym_Or] = ACTIONS(2693),
    [anon_sym_xor] = ACTIONS(2695),
    [anon_sym_XOR] = ACTIONS(2697),
    [anon_sym_Xor] = ACTIONS(2699),
    [anon_sym_QMARK] = ACTIONS(2701),
    [sym_datetime_literal] = ACTIONS(2328),
    [sym_date_literal] = ACTIONS(2326),
    [sym_time_literal] = ACTIONS(2326),
    [sym_biginteger_literal] = ACTIONS(2328),
    [anon_sym_if] = ACTIONS(2326),
    [anon_sym_IF] = ACTIONS(2326),
    [anon_sym_If] = ACTIONS(2326),
    [anon_sym_else] = ACTIONS(2326),
    [anon_sym_ELSE] = ACTIONS(2326),
    [anon_sym_Else] = ACTIONS(2326),
    [anon_sym_case] = ACTIONS(2326),
    [anon_sym_CASE] = ACTIONS(2326),
    [anon_sym_Case] = ACTIONS(2326),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_FOR] = ACTIONS(2326),
    [anon_sym_For] = ACTIONS(2326),
    [anon_sym_foreach] = ACTIONS(2326),
    [anon_sym_FOREACH] = ACTIONS(2326),
    [anon_sym_Foreach] = ACTIONS(2326),
    [anon_sym_while] = ACTIONS(2326),
    [anon_sym_WHILE] = ACTIONS(2326),
    [anon_sym_While] = ACTIONS(2326),
    [anon_sym_repeat] = ACTIONS(2326),
    [anon_sym_REPEAT] = ACTIONS(2326),
    [anon_sym_Repeat] = ACTIONS(2326),
    [anon_sym_until] = ACTIONS(2326),
    [anon_sym_UNTIL] = ACTIONS(2326),
    [anon_sym_Until] = ACTIONS(2326),
    [anon_sym_exit] = ACTIONS(2326),
    [anon_sym_EXIT] = ACTIONS(2326),
    [anon_sym_Exit] = ACTIONS(2326),
    [anon_sym_continue] = ACTIONS(2326),
    [anon_sym_CONTINUE] = ACTIONS(2326),
    [anon_sym_Continue] = ACTIONS(2326),
    [anon_sym_break] = ACTIONS(2326),
    [anon_sym_BREAK] = ACTIONS(2326),
    [anon_sym_Break] = ACTIONS(2326),
    [anon_sym_with] = ACTIONS(2326),
    [anon_sym_WITH] = ACTIONS(2326),
    [anon_sym_With] = ACTIONS(2326),
    [sym_asserterror_keyword] = ACTIONS(2328),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2326),
    [anon_sym_codeunit] = ACTIONS(2326),
    [anon_sym_CODEUNIT] = ACTIONS(2326),
    [anon_sym_Codeunit] = ACTIONS(2326),
    [anon_sym_CodeUnit] = ACTIONS(2326),
    [anon_sym_COdeunit] = ACTIONS(2326),
    [anon_sym_codeUnit] = ACTIONS(2326),
    [sym_report_keyword] = ACTIONS(2326),
    [sym_query_keyword] = ACTIONS(2326),
    [anon_sym_xmlport] = ACTIONS(2326),
    [anon_sym_XMLPORT] = ACTIONS(2326),
    [anon_sym_Xmlport] = ACTIONS(2326),
    [anon_sym_XMLport] = ACTIONS(2326),
    [anon_sym_XMLPort] = ACTIONS(2326),
    [anon_sym_XmlPort] = ACTIONS(2326),
    [anon_sym_enum] = ACTIONS(2326),
    [anon_sym_ENUM] = ACTIONS(2326),
    [anon_sym_Enum] = ACTIONS(2326),
    [anon_sym_eNUM] = ACTIONS(2326),
    [anon_sym_eNum] = ACTIONS(2326),
    [anon_sym_ENum] = ACTIONS(2326),
    [sym_quoted_identifier] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2328),
    [sym_integer] = ACTIONS(2326),
    [sym_continue_as_identifier] = ACTIONS(2328),
    [sym_preproc_open] = ACTIONS(2328),
  },
  [STATE(1091)] = {
    [sym_comparison_operator] = STATE(3146),
    [sym_in_keyword] = STATE(11196),
    [sym_identifier] = ACTIONS(2378),
    [anon_sym_SEMI] = ACTIONS(2380),
    [anon_sym_DOT] = ACTIONS(2653),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2378),
    [aux_sym_boolean_token1] = ACTIONS(2378),
    [aux_sym_boolean_token2] = ACTIONS(2378),
    [sym_decimal] = ACTIONS(2378),
    [anon_sym_LPAREN] = ACTIONS(2380),
    [anon_sym_DOT_DOT] = ACTIONS(2655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2378),
    [anon_sym_STAR] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2380),
    [aux_sym_record_type_token1] = ACTIONS(2378),
    [aux_sym_basic_type_token21] = ACTIONS(2378),
    [aux_sym_basic_type_token22] = ACTIONS(2378),
    [aux_sym_basic_type_token48] = ACTIONS(2378),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2378),
    [anon_sym_POUNDif] = ACTIONS(2380),
    [anon_sym_POUNDIF] = ACTIONS(2380),
    [anon_sym_POUNDIf] = ACTIONS(2380),
    [anon_sym_not] = ACTIONS(2378),
    [anon_sym_NOT] = ACTIONS(2378),
    [anon_sym_Not] = ACTIONS(2378),
    [anon_sym_POUNDelse] = ACTIONS(2380),
    [anon_sym_POUNDELSE] = ACTIONS(2380),
    [anon_sym_POUNDElse] = ACTIONS(2380),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2705),
    [aux_sym__expression_token1] = ACTIONS(2677),
    [aux_sym__expression_token2] = ACTIONS(2679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2378),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2378),
    [anon_sym_SLASH] = ACTIONS(2661),
    [anon_sym_div] = ACTIONS(2663),
    [anon_sym_DIV] = ACTIONS(2665),
    [anon_sym_Div] = ACTIONS(2667),
    [anon_sym_mod] = ACTIONS(2669),
    [anon_sym_MOD] = ACTIONS(2671),
    [anon_sym_Mod] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2378),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2683),
    [anon_sym_AND] = ACTIONS(2685),
    [anon_sym_And] = ACTIONS(2687),
    [anon_sym_or] = ACTIONS(2689),
    [anon_sym_OR] = ACTIONS(2691),
    [anon_sym_Or] = ACTIONS(2693),
    [anon_sym_xor] = ACTIONS(2695),
    [anon_sym_XOR] = ACTIONS(2697),
    [anon_sym_Xor] = ACTIONS(2699),
    [anon_sym_QMARK] = ACTIONS(2701),
    [sym_datetime_literal] = ACTIONS(2380),
    [sym_date_literal] = ACTIONS(2378),
    [sym_time_literal] = ACTIONS(2378),
    [sym_biginteger_literal] = ACTIONS(2380),
    [anon_sym_if] = ACTIONS(2378),
    [anon_sym_IF] = ACTIONS(2378),
    [anon_sym_If] = ACTIONS(2378),
    [anon_sym_else] = ACTIONS(2378),
    [anon_sym_ELSE] = ACTIONS(2378),
    [anon_sym_Else] = ACTIONS(2378),
    [anon_sym_case] = ACTIONS(2378),
    [anon_sym_CASE] = ACTIONS(2378),
    [anon_sym_Case] = ACTIONS(2378),
    [anon_sym_for] = ACTIONS(2378),
    [anon_sym_FOR] = ACTIONS(2378),
    [anon_sym_For] = ACTIONS(2378),
    [anon_sym_foreach] = ACTIONS(2378),
    [anon_sym_FOREACH] = ACTIONS(2378),
    [anon_sym_Foreach] = ACTIONS(2378),
    [anon_sym_while] = ACTIONS(2378),
    [anon_sym_WHILE] = ACTIONS(2378),
    [anon_sym_While] = ACTIONS(2378),
    [anon_sym_repeat] = ACTIONS(2378),
    [anon_sym_REPEAT] = ACTIONS(2378),
    [anon_sym_Repeat] = ACTIONS(2378),
    [anon_sym_until] = ACTIONS(2378),
    [anon_sym_UNTIL] = ACTIONS(2378),
    [anon_sym_Until] = ACTIONS(2378),
    [anon_sym_exit] = ACTIONS(2378),
    [anon_sym_EXIT] = ACTIONS(2378),
    [anon_sym_Exit] = ACTIONS(2378),
    [anon_sym_continue] = ACTIONS(2378),
    [anon_sym_CONTINUE] = ACTIONS(2378),
    [anon_sym_Continue] = ACTIONS(2378),
    [anon_sym_break] = ACTIONS(2378),
    [anon_sym_BREAK] = ACTIONS(2378),
    [anon_sym_Break] = ACTIONS(2378),
    [anon_sym_with] = ACTIONS(2378),
    [anon_sym_WITH] = ACTIONS(2378),
    [anon_sym_With] = ACTIONS(2378),
    [sym_asserterror_keyword] = ACTIONS(2380),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2378),
    [anon_sym_codeunit] = ACTIONS(2378),
    [anon_sym_CODEUNIT] = ACTIONS(2378),
    [anon_sym_Codeunit] = ACTIONS(2378),
    [anon_sym_CodeUnit] = ACTIONS(2378),
    [anon_sym_COdeunit] = ACTIONS(2378),
    [anon_sym_codeUnit] = ACTIONS(2378),
    [sym_report_keyword] = ACTIONS(2378),
    [sym_query_keyword] = ACTIONS(2378),
    [anon_sym_xmlport] = ACTIONS(2378),
    [anon_sym_XMLPORT] = ACTIONS(2378),
    [anon_sym_Xmlport] = ACTIONS(2378),
    [anon_sym_XMLport] = ACTIONS(2378),
    [anon_sym_XMLPort] = ACTIONS(2378),
    [anon_sym_XmlPort] = ACTIONS(2378),
    [anon_sym_enum] = ACTIONS(2378),
    [anon_sym_ENUM] = ACTIONS(2378),
    [anon_sym_Enum] = ACTIONS(2378),
    [anon_sym_eNUM] = ACTIONS(2378),
    [anon_sym_eNum] = ACTIONS(2378),
    [anon_sym_ENum] = ACTIONS(2378),
    [sym_quoted_identifier] = ACTIONS(2380),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2380),
    [sym_integer] = ACTIONS(2378),
    [sym_continue_as_identifier] = ACTIONS(2380),
    [sym_preproc_open] = ACTIONS(2380),
  },
  [STATE(1092)] = {
    [sym_identifier] = ACTIONS(2539),
    [anon_sym_SEMI] = ACTIONS(2541),
    [anon_sym_DOT] = ACTIONS(2539),
    [anon_sym_EQ] = ACTIONS(2541),
    [anon_sym_COMMA] = ACTIONS(2541),
    [anon_sym_DASH] = ACTIONS(2539),
    [aux_sym_boolean_token1] = ACTIONS(2539),
    [aux_sym_boolean_token2] = ACTIONS(2539),
    [sym_decimal] = ACTIONS(2539),
    [anon_sym_LPAREN] = ACTIONS(2541),
    [anon_sym_DOT_DOT] = ACTIONS(2541),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2539),
    [anon_sym_STAR] = ACTIONS(2539),
    [anon_sym_LBRACK] = ACTIONS(2541),
    [aux_sym_record_type_token1] = ACTIONS(2539),
    [aux_sym_basic_type_token21] = ACTIONS(2539),
    [aux_sym_basic_type_token22] = ACTIONS(2539),
    [aux_sym_basic_type_token48] = ACTIONS(2539),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2539),
    [anon_sym_POUNDif] = ACTIONS(2541),
    [anon_sym_POUNDIF] = ACTIONS(2541),
    [anon_sym_POUNDIf] = ACTIONS(2541),
    [anon_sym_not] = ACTIONS(2539),
    [anon_sym_NOT] = ACTIONS(2539),
    [anon_sym_Not] = ACTIONS(2539),
    [anon_sym_POUNDelse] = ACTIONS(2541),
    [anon_sym_POUNDELSE] = ACTIONS(2541),
    [anon_sym_POUNDElse] = ACTIONS(2541),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2541),
    [aux_sym__expression_token1] = ACTIONS(2541),
    [aux_sym__expression_token2] = ACTIONS(2539),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2539),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2539),
    [anon_sym_SLASH] = ACTIONS(2539),
    [anon_sym_div] = ACTIONS(2539),
    [anon_sym_DIV] = ACTIONS(2539),
    [anon_sym_Div] = ACTIONS(2539),
    [anon_sym_mod] = ACTIONS(2539),
    [anon_sym_MOD] = ACTIONS(2539),
    [anon_sym_Mod] = ACTIONS(2539),
    [anon_sym_PLUS] = ACTIONS(2539),
    [anon_sym_GT_EQ] = ACTIONS(2541),
    [anon_sym_LT_EQ] = ACTIONS(2541),
    [anon_sym_GT] = ACTIONS(2539),
    [anon_sym_LT] = ACTIONS(2539),
    [anon_sym_LT_GT] = ACTIONS(2541),
    [anon_sym_and] = ACTIONS(2539),
    [anon_sym_AND] = ACTIONS(2539),
    [anon_sym_And] = ACTIONS(2539),
    [anon_sym_or] = ACTIONS(2539),
    [anon_sym_OR] = ACTIONS(2539),
    [anon_sym_Or] = ACTIONS(2539),
    [anon_sym_xor] = ACTIONS(2539),
    [anon_sym_XOR] = ACTIONS(2539),
    [anon_sym_Xor] = ACTIONS(2539),
    [anon_sym_QMARK] = ACTIONS(2541),
    [sym_datetime_literal] = ACTIONS(2541),
    [sym_date_literal] = ACTIONS(2539),
    [sym_time_literal] = ACTIONS(2539),
    [sym_biginteger_literal] = ACTIONS(2541),
    [anon_sym_if] = ACTIONS(2539),
    [anon_sym_IF] = ACTIONS(2539),
    [anon_sym_If] = ACTIONS(2539),
    [anon_sym_else] = ACTIONS(2539),
    [anon_sym_ELSE] = ACTIONS(2539),
    [anon_sym_Else] = ACTIONS(2539),
    [anon_sym_case] = ACTIONS(2539),
    [anon_sym_CASE] = ACTIONS(2539),
    [anon_sym_Case] = ACTIONS(2539),
    [anon_sym_for] = ACTIONS(2539),
    [anon_sym_FOR] = ACTIONS(2539),
    [anon_sym_For] = ACTIONS(2539),
    [anon_sym_foreach] = ACTIONS(2539),
    [anon_sym_FOREACH] = ACTIONS(2539),
    [anon_sym_Foreach] = ACTIONS(2539),
    [anon_sym_while] = ACTIONS(2539),
    [anon_sym_WHILE] = ACTIONS(2539),
    [anon_sym_While] = ACTIONS(2539),
    [anon_sym_repeat] = ACTIONS(2539),
    [anon_sym_REPEAT] = ACTIONS(2539),
    [anon_sym_Repeat] = ACTIONS(2539),
    [anon_sym_until] = ACTIONS(2539),
    [anon_sym_UNTIL] = ACTIONS(2539),
    [anon_sym_Until] = ACTIONS(2539),
    [anon_sym_exit] = ACTIONS(2539),
    [anon_sym_EXIT] = ACTIONS(2539),
    [anon_sym_Exit] = ACTIONS(2539),
    [anon_sym_continue] = ACTIONS(2539),
    [anon_sym_CONTINUE] = ACTIONS(2539),
    [anon_sym_Continue] = ACTIONS(2539),
    [anon_sym_break] = ACTIONS(2539),
    [anon_sym_BREAK] = ACTIONS(2539),
    [anon_sym_Break] = ACTIONS(2539),
    [anon_sym_with] = ACTIONS(2539),
    [anon_sym_WITH] = ACTIONS(2539),
    [anon_sym_With] = ACTIONS(2539),
    [sym_asserterror_keyword] = ACTIONS(2541),
    [anon_sym_in] = ACTIONS(2539),
    [anon_sym_IN] = ACTIONS(2539),
    [anon_sym_In] = ACTIONS(2539),
    [sym_page_keyword] = ACTIONS(2539),
    [anon_sym_codeunit] = ACTIONS(2539),
    [anon_sym_CODEUNIT] = ACTIONS(2539),
    [anon_sym_Codeunit] = ACTIONS(2539),
    [anon_sym_CodeUnit] = ACTIONS(2539),
    [anon_sym_COdeunit] = ACTIONS(2539),
    [anon_sym_codeUnit] = ACTIONS(2539),
    [sym_report_keyword] = ACTIONS(2539),
    [sym_query_keyword] = ACTIONS(2539),
    [anon_sym_xmlport] = ACTIONS(2539),
    [anon_sym_XMLPORT] = ACTIONS(2539),
    [anon_sym_Xmlport] = ACTIONS(2539),
    [anon_sym_XMLport] = ACTIONS(2539),
    [anon_sym_XMLPort] = ACTIONS(2539),
    [anon_sym_XmlPort] = ACTIONS(2539),
    [anon_sym_enum] = ACTIONS(2539),
    [anon_sym_ENUM] = ACTIONS(2539),
    [anon_sym_Enum] = ACTIONS(2539),
    [anon_sym_eNUM] = ACTIONS(2539),
    [anon_sym_eNum] = ACTIONS(2539),
    [anon_sym_ENum] = ACTIONS(2539),
    [sym_quoted_identifier] = ACTIONS(2541),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2541),
    [sym_integer] = ACTIONS(2539),
    [sym_continue_as_identifier] = ACTIONS(2541),
    [sym_preproc_open] = ACTIONS(2541),
  },
  [STATE(1093)] = {
    [sym_preproc_conditional_object] = STATE(1115),
    [sym_using_statement] = STATE(1115),
    [sym__object] = STATE(1115),
    [sym_preproc_split_declaration] = STATE(1115),
    [sym_table_declaration] = STATE(1115),
    [sym_page_declaration] = STATE(1115),
    [sym_report_declaration] = STATE(1115),
    [sym_query_declaration] = STATE(1115),
    [sym_xmlport_declaration] = STATE(1115),
    [sym_permissionset_declaration] = STATE(1115),
    [sym_codeunit_declaration] = STATE(1115),
    [sym_enum_declaration] = STATE(1115),
    [sym_tableextension_declaration] = STATE(1115),
    [sym_pageextension_declaration] = STATE(1115),
    [sym_reportextension_declaration] = STATE(1115),
    [sym_enumextension_declaration] = STATE(1115),
    [sym_permissionsetextension_declaration] = STATE(1115),
    [sym_controladdin_declaration] = STATE(1115),
    [sym_profile_declaration] = STATE(1115),
    [sym_entitlement_declaration] = STATE(1115),
    [sym_profileextension_declaration] = STATE(1115),
    [sym_interface_declaration] = STATE(1115),
    [sym_pagecustomization_declaration] = STATE(1115),
    [sym_dotnet_declaration] = STATE(1115),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(1989),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(1115),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(1094)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(2469),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(1095)] = {
    [sym_preproc_conditional_object] = STATE(1105),
    [sym_using_statement] = STATE(1105),
    [sym__object] = STATE(1105),
    [sym_preproc_split_declaration] = STATE(1105),
    [sym_table_declaration] = STATE(1105),
    [sym_page_declaration] = STATE(1105),
    [sym_report_declaration] = STATE(1105),
    [sym_query_declaration] = STATE(1105),
    [sym_xmlport_declaration] = STATE(1105),
    [sym_permissionset_declaration] = STATE(1105),
    [sym_codeunit_declaration] = STATE(1105),
    [sym_enum_declaration] = STATE(1105),
    [sym_tableextension_declaration] = STATE(1105),
    [sym_pageextension_declaration] = STATE(1105),
    [sym_reportextension_declaration] = STATE(1105),
    [sym_enumextension_declaration] = STATE(1105),
    [sym_permissionsetextension_declaration] = STATE(1105),
    [sym_controladdin_declaration] = STATE(1105),
    [sym_profile_declaration] = STATE(1105),
    [sym_entitlement_declaration] = STATE(1105),
    [sym_profileextension_declaration] = STATE(1105),
    [sym_interface_declaration] = STATE(1105),
    [sym_pagecustomization_declaration] = STATE(1105),
    [sym_dotnet_declaration] = STATE(1105),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(2002),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(1105),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(1096)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(2541),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(1097)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(2496),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(1098)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(2534),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(1099)] = {
    [sym_identifier] = ACTIONS(2403),
    [anon_sym_SEMI] = ACTIONS(2405),
    [anon_sym_DOT] = ACTIONS(2403),
    [anon_sym_EQ] = ACTIONS(2405),
    [anon_sym_COMMA] = ACTIONS(2405),
    [anon_sym_DASH] = ACTIONS(2403),
    [aux_sym_boolean_token1] = ACTIONS(2403),
    [aux_sym_boolean_token2] = ACTIONS(2403),
    [sym_decimal] = ACTIONS(2403),
    [anon_sym_LPAREN] = ACTIONS(2405),
    [anon_sym_DOT_DOT] = ACTIONS(2405),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2403),
    [anon_sym_STAR] = ACTIONS(2403),
    [anon_sym_LBRACK] = ACTIONS(2405),
    [aux_sym_record_type_token1] = ACTIONS(2403),
    [aux_sym_basic_type_token21] = ACTIONS(2403),
    [aux_sym_basic_type_token22] = ACTIONS(2403),
    [aux_sym_basic_type_token48] = ACTIONS(2403),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2403),
    [anon_sym_POUNDif] = ACTIONS(2405),
    [anon_sym_POUNDIF] = ACTIONS(2405),
    [anon_sym_POUNDIf] = ACTIONS(2405),
    [anon_sym_not] = ACTIONS(2403),
    [anon_sym_NOT] = ACTIONS(2403),
    [anon_sym_Not] = ACTIONS(2403),
    [anon_sym_POUNDelse] = ACTIONS(2405),
    [anon_sym_POUNDELSE] = ACTIONS(2405),
    [anon_sym_POUNDElse] = ACTIONS(2405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2405),
    [aux_sym__expression_token1] = ACTIONS(2405),
    [aux_sym__expression_token2] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2403),
    [anon_sym_SLASH] = ACTIONS(2403),
    [anon_sym_div] = ACTIONS(2403),
    [anon_sym_DIV] = ACTIONS(2403),
    [anon_sym_Div] = ACTIONS(2403),
    [anon_sym_mod] = ACTIONS(2403),
    [anon_sym_MOD] = ACTIONS(2403),
    [anon_sym_Mod] = ACTIONS(2403),
    [anon_sym_PLUS] = ACTIONS(2403),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_LT_GT] = ACTIONS(2405),
    [anon_sym_and] = ACTIONS(2403),
    [anon_sym_AND] = ACTIONS(2403),
    [anon_sym_And] = ACTIONS(2403),
    [anon_sym_or] = ACTIONS(2403),
    [anon_sym_OR] = ACTIONS(2403),
    [anon_sym_Or] = ACTIONS(2403),
    [anon_sym_xor] = ACTIONS(2403),
    [anon_sym_XOR] = ACTIONS(2403),
    [anon_sym_Xor] = ACTIONS(2403),
    [anon_sym_QMARK] = ACTIONS(2405),
    [sym_datetime_literal] = ACTIONS(2405),
    [sym_date_literal] = ACTIONS(2403),
    [sym_time_literal] = ACTIONS(2403),
    [sym_biginteger_literal] = ACTIONS(2405),
    [anon_sym_if] = ACTIONS(2403),
    [anon_sym_IF] = ACTIONS(2403),
    [anon_sym_If] = ACTIONS(2403),
    [anon_sym_else] = ACTIONS(2403),
    [anon_sym_ELSE] = ACTIONS(2403),
    [anon_sym_Else] = ACTIONS(2403),
    [anon_sym_case] = ACTIONS(2403),
    [anon_sym_CASE] = ACTIONS(2403),
    [anon_sym_Case] = ACTIONS(2403),
    [anon_sym_for] = ACTIONS(2403),
    [anon_sym_FOR] = ACTIONS(2403),
    [anon_sym_For] = ACTIONS(2403),
    [anon_sym_foreach] = ACTIONS(2403),
    [anon_sym_FOREACH] = ACTIONS(2403),
    [anon_sym_Foreach] = ACTIONS(2403),
    [anon_sym_while] = ACTIONS(2403),
    [anon_sym_WHILE] = ACTIONS(2403),
    [anon_sym_While] = ACTIONS(2403),
    [anon_sym_repeat] = ACTIONS(2403),
    [anon_sym_REPEAT] = ACTIONS(2403),
    [anon_sym_Repeat] = ACTIONS(2403),
    [anon_sym_until] = ACTIONS(2403),
    [anon_sym_UNTIL] = ACTIONS(2403),
    [anon_sym_Until] = ACTIONS(2403),
    [anon_sym_exit] = ACTIONS(2403),
    [anon_sym_EXIT] = ACTIONS(2403),
    [anon_sym_Exit] = ACTIONS(2403),
    [anon_sym_continue] = ACTIONS(2403),
    [anon_sym_CONTINUE] = ACTIONS(2403),
    [anon_sym_Continue] = ACTIONS(2403),
    [anon_sym_break] = ACTIONS(2403),
    [anon_sym_BREAK] = ACTIONS(2403),
    [anon_sym_Break] = ACTIONS(2403),
    [anon_sym_with] = ACTIONS(2403),
    [anon_sym_WITH] = ACTIONS(2403),
    [anon_sym_With] = ACTIONS(2403),
    [sym_asserterror_keyword] = ACTIONS(2405),
    [anon_sym_in] = ACTIONS(2403),
    [anon_sym_IN] = ACTIONS(2403),
    [anon_sym_In] = ACTIONS(2403),
    [sym_page_keyword] = ACTIONS(2403),
    [anon_sym_codeunit] = ACTIONS(2403),
    [anon_sym_CODEUNIT] = ACTIONS(2403),
    [anon_sym_Codeunit] = ACTIONS(2403),
    [anon_sym_CodeUnit] = ACTIONS(2403),
    [anon_sym_COdeunit] = ACTIONS(2403),
    [anon_sym_codeUnit] = ACTIONS(2403),
    [sym_report_keyword] = ACTIONS(2403),
    [sym_query_keyword] = ACTIONS(2403),
    [anon_sym_xmlport] = ACTIONS(2403),
    [anon_sym_XMLPORT] = ACTIONS(2403),
    [anon_sym_Xmlport] = ACTIONS(2403),
    [anon_sym_XMLport] = ACTIONS(2403),
    [anon_sym_XMLPort] = ACTIONS(2403),
    [anon_sym_XmlPort] = ACTIONS(2403),
    [anon_sym_enum] = ACTIONS(2403),
    [anon_sym_ENUM] = ACTIONS(2403),
    [anon_sym_Enum] = ACTIONS(2403),
    [anon_sym_eNUM] = ACTIONS(2403),
    [anon_sym_eNum] = ACTIONS(2403),
    [anon_sym_ENum] = ACTIONS(2403),
    [sym_quoted_identifier] = ACTIONS(2405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2405),
    [sym_integer] = ACTIONS(2403),
    [sym_continue_as_identifier] = ACTIONS(2405),
    [sym_preproc_open] = ACTIONS(2405),
  },
  [STATE(1100)] = {
    [sym_identifier] = ACTIONS(2543),
    [anon_sym_SEMI] = ACTIONS(2545),
    [anon_sym_DOT] = ACTIONS(2543),
    [anon_sym_EQ] = ACTIONS(2545),
    [anon_sym_DASH] = ACTIONS(2543),
    [aux_sym_boolean_token1] = ACTIONS(2543),
    [aux_sym_boolean_token2] = ACTIONS(2543),
    [sym_decimal] = ACTIONS(2543),
    [anon_sym_LPAREN] = ACTIONS(2545),
    [anon_sym_DOT_DOT] = ACTIONS(2545),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2543),
    [anon_sym_STAR] = ACTIONS(2543),
    [anon_sym_LBRACK] = ACTIONS(2545),
    [aux_sym_record_type_token1] = ACTIONS(2543),
    [aux_sym_basic_type_token21] = ACTIONS(2543),
    [aux_sym_basic_type_token22] = ACTIONS(2543),
    [aux_sym_basic_type_token48] = ACTIONS(2543),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2543),
    [anon_sym_COLON_COLON] = ACTIONS(2545),
    [anon_sym_POUNDif] = ACTIONS(2545),
    [anon_sym_POUNDIF] = ACTIONS(2545),
    [anon_sym_POUNDIf] = ACTIONS(2545),
    [anon_sym_not] = ACTIONS(2543),
    [anon_sym_NOT] = ACTIONS(2543),
    [anon_sym_Not] = ACTIONS(2543),
    [anon_sym_POUNDelse] = ACTIONS(2545),
    [anon_sym_POUNDELSE] = ACTIONS(2545),
    [anon_sym_POUNDElse] = ACTIONS(2545),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2545),
    [aux_sym__expression_token1] = ACTIONS(2545),
    [aux_sym__expression_token2] = ACTIONS(2543),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2543),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2543),
    [anon_sym_SLASH] = ACTIONS(2543),
    [anon_sym_div] = ACTIONS(2543),
    [anon_sym_DIV] = ACTIONS(2543),
    [anon_sym_Div] = ACTIONS(2543),
    [anon_sym_mod] = ACTIONS(2543),
    [anon_sym_MOD] = ACTIONS(2543),
    [anon_sym_Mod] = ACTIONS(2543),
    [anon_sym_PLUS] = ACTIONS(2543),
    [anon_sym_GT_EQ] = ACTIONS(2545),
    [anon_sym_LT_EQ] = ACTIONS(2545),
    [anon_sym_GT] = ACTIONS(2543),
    [anon_sym_LT] = ACTIONS(2543),
    [anon_sym_LT_GT] = ACTIONS(2545),
    [anon_sym_and] = ACTIONS(2543),
    [anon_sym_AND] = ACTIONS(2543),
    [anon_sym_And] = ACTIONS(2543),
    [anon_sym_or] = ACTIONS(2543),
    [anon_sym_OR] = ACTIONS(2543),
    [anon_sym_Or] = ACTIONS(2543),
    [anon_sym_xor] = ACTIONS(2543),
    [anon_sym_XOR] = ACTIONS(2543),
    [anon_sym_Xor] = ACTIONS(2543),
    [anon_sym_QMARK] = ACTIONS(2545),
    [sym_datetime_literal] = ACTIONS(2545),
    [sym_date_literal] = ACTIONS(2543),
    [sym_time_literal] = ACTIONS(2543),
    [sym_biginteger_literal] = ACTIONS(2545),
    [anon_sym_if] = ACTIONS(2543),
    [anon_sym_IF] = ACTIONS(2543),
    [anon_sym_If] = ACTIONS(2543),
    [anon_sym_else] = ACTIONS(2543),
    [anon_sym_ELSE] = ACTIONS(2543),
    [anon_sym_Else] = ACTIONS(2543),
    [anon_sym_case] = ACTIONS(2543),
    [anon_sym_CASE] = ACTIONS(2543),
    [anon_sym_Case] = ACTIONS(2543),
    [anon_sym_for] = ACTIONS(2543),
    [anon_sym_FOR] = ACTIONS(2543),
    [anon_sym_For] = ACTIONS(2543),
    [anon_sym_foreach] = ACTIONS(2543),
    [anon_sym_FOREACH] = ACTIONS(2543),
    [anon_sym_Foreach] = ACTIONS(2543),
    [anon_sym_while] = ACTIONS(2543),
    [anon_sym_WHILE] = ACTIONS(2543),
    [anon_sym_While] = ACTIONS(2543),
    [anon_sym_repeat] = ACTIONS(2543),
    [anon_sym_REPEAT] = ACTIONS(2543),
    [anon_sym_Repeat] = ACTIONS(2543),
    [anon_sym_until] = ACTIONS(2543),
    [anon_sym_UNTIL] = ACTIONS(2543),
    [anon_sym_Until] = ACTIONS(2543),
    [anon_sym_exit] = ACTIONS(2543),
    [anon_sym_EXIT] = ACTIONS(2543),
    [anon_sym_Exit] = ACTIONS(2543),
    [anon_sym_continue] = ACTIONS(2543),
    [anon_sym_CONTINUE] = ACTIONS(2543),
    [anon_sym_Continue] = ACTIONS(2543),
    [anon_sym_break] = ACTIONS(2543),
    [anon_sym_BREAK] = ACTIONS(2543),
    [anon_sym_Break] = ACTIONS(2543),
    [anon_sym_with] = ACTIONS(2543),
    [anon_sym_WITH] = ACTIONS(2543),
    [anon_sym_With] = ACTIONS(2543),
    [sym_asserterror_keyword] = ACTIONS(2545),
    [anon_sym_in] = ACTIONS(2543),
    [anon_sym_IN] = ACTIONS(2543),
    [anon_sym_In] = ACTIONS(2543),
    [sym_page_keyword] = ACTIONS(2543),
    [anon_sym_codeunit] = ACTIONS(2543),
    [anon_sym_CODEUNIT] = ACTIONS(2543),
    [anon_sym_Codeunit] = ACTIONS(2543),
    [anon_sym_CodeUnit] = ACTIONS(2543),
    [anon_sym_COdeunit] = ACTIONS(2543),
    [anon_sym_codeUnit] = ACTIONS(2543),
    [sym_report_keyword] = ACTIONS(2543),
    [sym_query_keyword] = ACTIONS(2543),
    [anon_sym_xmlport] = ACTIONS(2543),
    [anon_sym_XMLPORT] = ACTIONS(2543),
    [anon_sym_Xmlport] = ACTIONS(2543),
    [anon_sym_XMLport] = ACTIONS(2543),
    [anon_sym_XMLPort] = ACTIONS(2543),
    [anon_sym_XmlPort] = ACTIONS(2543),
    [anon_sym_enum] = ACTIONS(2543),
    [anon_sym_ENUM] = ACTIONS(2543),
    [anon_sym_Enum] = ACTIONS(2543),
    [anon_sym_eNUM] = ACTIONS(2543),
    [anon_sym_eNum] = ACTIONS(2543),
    [anon_sym_ENum] = ACTIONS(2543),
    [sym_quoted_identifier] = ACTIONS(2545),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2545),
    [sym_integer] = ACTIONS(2543),
    [sym_continue_as_identifier] = ACTIONS(2545),
    [sym_preproc_open] = ACTIONS(2545),
  },
  [STATE(1101)] = {
    [sym_identifier] = ACTIONS(2551),
    [anon_sym_SEMI] = ACTIONS(2553),
    [anon_sym_DOT] = ACTIONS(2551),
    [anon_sym_EQ] = ACTIONS(2553),
    [anon_sym_COMMA] = ACTIONS(2553),
    [anon_sym_DASH] = ACTIONS(2551),
    [aux_sym_boolean_token1] = ACTIONS(2551),
    [aux_sym_boolean_token2] = ACTIONS(2551),
    [sym_decimal] = ACTIONS(2551),
    [anon_sym_LPAREN] = ACTIONS(2553),
    [anon_sym_DOT_DOT] = ACTIONS(2553),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2551),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_LBRACK] = ACTIONS(2553),
    [aux_sym_record_type_token1] = ACTIONS(2551),
    [aux_sym_basic_type_token21] = ACTIONS(2551),
    [aux_sym_basic_type_token22] = ACTIONS(2551),
    [aux_sym_basic_type_token48] = ACTIONS(2551),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2551),
    [anon_sym_POUNDif] = ACTIONS(2553),
    [anon_sym_POUNDIF] = ACTIONS(2553),
    [anon_sym_POUNDIf] = ACTIONS(2553),
    [anon_sym_not] = ACTIONS(2551),
    [anon_sym_NOT] = ACTIONS(2551),
    [anon_sym_Not] = ACTIONS(2551),
    [anon_sym_POUNDelse] = ACTIONS(2553),
    [anon_sym_POUNDELSE] = ACTIONS(2553),
    [anon_sym_POUNDElse] = ACTIONS(2553),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2553),
    [aux_sym__expression_token1] = ACTIONS(2553),
    [aux_sym__expression_token2] = ACTIONS(2551),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2551),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2551),
    [anon_sym_SLASH] = ACTIONS(2551),
    [anon_sym_div] = ACTIONS(2551),
    [anon_sym_DIV] = ACTIONS(2551),
    [anon_sym_Div] = ACTIONS(2551),
    [anon_sym_mod] = ACTIONS(2551),
    [anon_sym_MOD] = ACTIONS(2551),
    [anon_sym_Mod] = ACTIONS(2551),
    [anon_sym_PLUS] = ACTIONS(2551),
    [anon_sym_GT_EQ] = ACTIONS(2553),
    [anon_sym_LT_EQ] = ACTIONS(2553),
    [anon_sym_GT] = ACTIONS(2551),
    [anon_sym_LT] = ACTIONS(2551),
    [anon_sym_LT_GT] = ACTIONS(2553),
    [anon_sym_and] = ACTIONS(2551),
    [anon_sym_AND] = ACTIONS(2551),
    [anon_sym_And] = ACTIONS(2551),
    [anon_sym_or] = ACTIONS(2551),
    [anon_sym_OR] = ACTIONS(2551),
    [anon_sym_Or] = ACTIONS(2551),
    [anon_sym_xor] = ACTIONS(2551),
    [anon_sym_XOR] = ACTIONS(2551),
    [anon_sym_Xor] = ACTIONS(2551),
    [anon_sym_QMARK] = ACTIONS(2553),
    [sym_datetime_literal] = ACTIONS(2553),
    [sym_date_literal] = ACTIONS(2551),
    [sym_time_literal] = ACTIONS(2551),
    [sym_biginteger_literal] = ACTIONS(2553),
    [anon_sym_if] = ACTIONS(2551),
    [anon_sym_IF] = ACTIONS(2551),
    [anon_sym_If] = ACTIONS(2551),
    [anon_sym_else] = ACTIONS(2551),
    [anon_sym_ELSE] = ACTIONS(2551),
    [anon_sym_Else] = ACTIONS(2551),
    [anon_sym_case] = ACTIONS(2551),
    [anon_sym_CASE] = ACTIONS(2551),
    [anon_sym_Case] = ACTIONS(2551),
    [anon_sym_for] = ACTIONS(2551),
    [anon_sym_FOR] = ACTIONS(2551),
    [anon_sym_For] = ACTIONS(2551),
    [anon_sym_foreach] = ACTIONS(2551),
    [anon_sym_FOREACH] = ACTIONS(2551),
    [anon_sym_Foreach] = ACTIONS(2551),
    [anon_sym_while] = ACTIONS(2551),
    [anon_sym_WHILE] = ACTIONS(2551),
    [anon_sym_While] = ACTIONS(2551),
    [anon_sym_repeat] = ACTIONS(2551),
    [anon_sym_REPEAT] = ACTIONS(2551),
    [anon_sym_Repeat] = ACTIONS(2551),
    [anon_sym_until] = ACTIONS(2551),
    [anon_sym_UNTIL] = ACTIONS(2551),
    [anon_sym_Until] = ACTIONS(2551),
    [anon_sym_exit] = ACTIONS(2551),
    [anon_sym_EXIT] = ACTIONS(2551),
    [anon_sym_Exit] = ACTIONS(2551),
    [anon_sym_continue] = ACTIONS(2551),
    [anon_sym_CONTINUE] = ACTIONS(2551),
    [anon_sym_Continue] = ACTIONS(2551),
    [anon_sym_break] = ACTIONS(2551),
    [anon_sym_BREAK] = ACTIONS(2551),
    [anon_sym_Break] = ACTIONS(2551),
    [anon_sym_with] = ACTIONS(2551),
    [anon_sym_WITH] = ACTIONS(2551),
    [anon_sym_With] = ACTIONS(2551),
    [sym_asserterror_keyword] = ACTIONS(2553),
    [anon_sym_in] = ACTIONS(2551),
    [anon_sym_IN] = ACTIONS(2551),
    [anon_sym_In] = ACTIONS(2551),
    [sym_page_keyword] = ACTIONS(2551),
    [anon_sym_codeunit] = ACTIONS(2551),
    [anon_sym_CODEUNIT] = ACTIONS(2551),
    [anon_sym_Codeunit] = ACTIONS(2551),
    [anon_sym_CodeUnit] = ACTIONS(2551),
    [anon_sym_COdeunit] = ACTIONS(2551),
    [anon_sym_codeUnit] = ACTIONS(2551),
    [sym_report_keyword] = ACTIONS(2551),
    [sym_query_keyword] = ACTIONS(2551),
    [anon_sym_xmlport] = ACTIONS(2551),
    [anon_sym_XMLPORT] = ACTIONS(2551),
    [anon_sym_Xmlport] = ACTIONS(2551),
    [anon_sym_XMLport] = ACTIONS(2551),
    [anon_sym_XMLPort] = ACTIONS(2551),
    [anon_sym_XmlPort] = ACTIONS(2551),
    [anon_sym_enum] = ACTIONS(2551),
    [anon_sym_ENUM] = ACTIONS(2551),
    [anon_sym_Enum] = ACTIONS(2551),
    [anon_sym_eNUM] = ACTIONS(2551),
    [anon_sym_eNum] = ACTIONS(2551),
    [anon_sym_ENum] = ACTIONS(2551),
    [sym_quoted_identifier] = ACTIONS(2553),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2553),
    [sym_integer] = ACTIONS(2551),
    [sym_continue_as_identifier] = ACTIONS(2553),
    [sym_preproc_open] = ACTIONS(2553),
  },
  [STATE(1102)] = {
    [sym_identifier] = ACTIONS(2529),
    [anon_sym_SEMI] = ACTIONS(2531),
    [anon_sym_DOT] = ACTIONS(2529),
    [anon_sym_EQ] = ACTIONS(2531),
    [anon_sym_COMMA] = ACTIONS(2531),
    [anon_sym_DASH] = ACTIONS(2529),
    [aux_sym_boolean_token1] = ACTIONS(2529),
    [aux_sym_boolean_token2] = ACTIONS(2529),
    [sym_decimal] = ACTIONS(2529),
    [anon_sym_LPAREN] = ACTIONS(2531),
    [anon_sym_DOT_DOT] = ACTIONS(2531),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2529),
    [anon_sym_STAR] = ACTIONS(2529),
    [anon_sym_LBRACK] = ACTIONS(2531),
    [aux_sym_record_type_token1] = ACTIONS(2529),
    [aux_sym_basic_type_token21] = ACTIONS(2529),
    [aux_sym_basic_type_token22] = ACTIONS(2529),
    [aux_sym_basic_type_token48] = ACTIONS(2529),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2529),
    [anon_sym_POUNDif] = ACTIONS(2531),
    [anon_sym_POUNDIF] = ACTIONS(2531),
    [anon_sym_POUNDIf] = ACTIONS(2531),
    [anon_sym_not] = ACTIONS(2529),
    [anon_sym_NOT] = ACTIONS(2529),
    [anon_sym_Not] = ACTIONS(2529),
    [anon_sym_POUNDelse] = ACTIONS(2531),
    [anon_sym_POUNDELSE] = ACTIONS(2531),
    [anon_sym_POUNDElse] = ACTIONS(2531),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2531),
    [aux_sym__expression_token1] = ACTIONS(2531),
    [aux_sym__expression_token2] = ACTIONS(2529),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2529),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2529),
    [anon_sym_SLASH] = ACTIONS(2529),
    [anon_sym_div] = ACTIONS(2529),
    [anon_sym_DIV] = ACTIONS(2529),
    [anon_sym_Div] = ACTIONS(2529),
    [anon_sym_mod] = ACTIONS(2529),
    [anon_sym_MOD] = ACTIONS(2529),
    [anon_sym_Mod] = ACTIONS(2529),
    [anon_sym_PLUS] = ACTIONS(2529),
    [anon_sym_GT_EQ] = ACTIONS(2531),
    [anon_sym_LT_EQ] = ACTIONS(2531),
    [anon_sym_GT] = ACTIONS(2529),
    [anon_sym_LT] = ACTIONS(2529),
    [anon_sym_LT_GT] = ACTIONS(2531),
    [anon_sym_and] = ACTIONS(2529),
    [anon_sym_AND] = ACTIONS(2529),
    [anon_sym_And] = ACTIONS(2529),
    [anon_sym_or] = ACTIONS(2529),
    [anon_sym_OR] = ACTIONS(2529),
    [anon_sym_Or] = ACTIONS(2529),
    [anon_sym_xor] = ACTIONS(2529),
    [anon_sym_XOR] = ACTIONS(2529),
    [anon_sym_Xor] = ACTIONS(2529),
    [anon_sym_QMARK] = ACTIONS(2531),
    [sym_datetime_literal] = ACTIONS(2531),
    [sym_date_literal] = ACTIONS(2529),
    [sym_time_literal] = ACTIONS(2529),
    [sym_biginteger_literal] = ACTIONS(2531),
    [anon_sym_if] = ACTIONS(2529),
    [anon_sym_IF] = ACTIONS(2529),
    [anon_sym_If] = ACTIONS(2529),
    [anon_sym_else] = ACTIONS(2529),
    [anon_sym_ELSE] = ACTIONS(2529),
    [anon_sym_Else] = ACTIONS(2529),
    [anon_sym_case] = ACTIONS(2529),
    [anon_sym_CASE] = ACTIONS(2529),
    [anon_sym_Case] = ACTIONS(2529),
    [anon_sym_for] = ACTIONS(2529),
    [anon_sym_FOR] = ACTIONS(2529),
    [anon_sym_For] = ACTIONS(2529),
    [anon_sym_foreach] = ACTIONS(2529),
    [anon_sym_FOREACH] = ACTIONS(2529),
    [anon_sym_Foreach] = ACTIONS(2529),
    [anon_sym_while] = ACTIONS(2529),
    [anon_sym_WHILE] = ACTIONS(2529),
    [anon_sym_While] = ACTIONS(2529),
    [anon_sym_repeat] = ACTIONS(2529),
    [anon_sym_REPEAT] = ACTIONS(2529),
    [anon_sym_Repeat] = ACTIONS(2529),
    [anon_sym_until] = ACTIONS(2529),
    [anon_sym_UNTIL] = ACTIONS(2529),
    [anon_sym_Until] = ACTIONS(2529),
    [anon_sym_exit] = ACTIONS(2529),
    [anon_sym_EXIT] = ACTIONS(2529),
    [anon_sym_Exit] = ACTIONS(2529),
    [anon_sym_continue] = ACTIONS(2529),
    [anon_sym_CONTINUE] = ACTIONS(2529),
    [anon_sym_Continue] = ACTIONS(2529),
    [anon_sym_break] = ACTIONS(2529),
    [anon_sym_BREAK] = ACTIONS(2529),
    [anon_sym_Break] = ACTIONS(2529),
    [anon_sym_with] = ACTIONS(2529),
    [anon_sym_WITH] = ACTIONS(2529),
    [anon_sym_With] = ACTIONS(2529),
    [sym_asserterror_keyword] = ACTIONS(2531),
    [anon_sym_in] = ACTIONS(2529),
    [anon_sym_IN] = ACTIONS(2529),
    [anon_sym_In] = ACTIONS(2529),
    [sym_page_keyword] = ACTIONS(2529),
    [anon_sym_codeunit] = ACTIONS(2529),
    [anon_sym_CODEUNIT] = ACTIONS(2529),
    [anon_sym_Codeunit] = ACTIONS(2529),
    [anon_sym_CodeUnit] = ACTIONS(2529),
    [anon_sym_COdeunit] = ACTIONS(2529),
    [anon_sym_codeUnit] = ACTIONS(2529),
    [sym_report_keyword] = ACTIONS(2529),
    [sym_query_keyword] = ACTIONS(2529),
    [anon_sym_xmlport] = ACTIONS(2529),
    [anon_sym_XMLPORT] = ACTIONS(2529),
    [anon_sym_Xmlport] = ACTIONS(2529),
    [anon_sym_XMLport] = ACTIONS(2529),
    [anon_sym_XMLPort] = ACTIONS(2529),
    [anon_sym_XmlPort] = ACTIONS(2529),
    [anon_sym_enum] = ACTIONS(2529),
    [anon_sym_ENUM] = ACTIONS(2529),
    [anon_sym_Enum] = ACTIONS(2529),
    [anon_sym_eNUM] = ACTIONS(2529),
    [anon_sym_eNum] = ACTIONS(2529),
    [anon_sym_ENum] = ACTIONS(2529),
    [sym_quoted_identifier] = ACTIONS(2531),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2531),
    [sym_integer] = ACTIONS(2529),
    [sym_continue_as_identifier] = ACTIONS(2531),
    [sym_preproc_open] = ACTIONS(2531),
  },
  [STATE(1103)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(1969),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(1104)] = {
    [sym_identifier] = ACTIONS(2533),
    [anon_sym_SEMI] = ACTIONS(2535),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym_EQ] = ACTIONS(2535),
    [anon_sym_DASH] = ACTIONS(2533),
    [aux_sym_boolean_token1] = ACTIONS(2533),
    [aux_sym_boolean_token2] = ACTIONS(2533),
    [sym_decimal] = ACTIONS(2533),
    [anon_sym_LPAREN] = ACTIONS(2535),
    [anon_sym_DOT_DOT] = ACTIONS(2535),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2533),
    [anon_sym_STAR] = ACTIONS(2533),
    [anon_sym_LBRACK] = ACTIONS(2535),
    [aux_sym_record_type_token1] = ACTIONS(2533),
    [aux_sym_basic_type_token21] = ACTIONS(2533),
    [aux_sym_basic_type_token22] = ACTIONS(2533),
    [aux_sym_basic_type_token48] = ACTIONS(2533),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2533),
    [anon_sym_POUNDif] = ACTIONS(2535),
    [anon_sym_POUNDIF] = ACTIONS(2535),
    [anon_sym_POUNDIf] = ACTIONS(2535),
    [anon_sym_not] = ACTIONS(2533),
    [anon_sym_NOT] = ACTIONS(2533),
    [anon_sym_Not] = ACTIONS(2533),
    [anon_sym_POUNDelse] = ACTIONS(2535),
    [anon_sym_POUNDELSE] = ACTIONS(2535),
    [anon_sym_POUNDElse] = ACTIONS(2535),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2535),
    [aux_sym__expression_token1] = ACTIONS(2535),
    [aux_sym__expression_token2] = ACTIONS(2533),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2533),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2533),
    [anon_sym_SLASH] = ACTIONS(2533),
    [anon_sym_div] = ACTIONS(2533),
    [anon_sym_DIV] = ACTIONS(2533),
    [anon_sym_Div] = ACTIONS(2533),
    [anon_sym_mod] = ACTIONS(2533),
    [anon_sym_MOD] = ACTIONS(2533),
    [anon_sym_Mod] = ACTIONS(2533),
    [anon_sym_PLUS] = ACTIONS(2533),
    [anon_sym_GT_EQ] = ACTIONS(2535),
    [anon_sym_LT_EQ] = ACTIONS(2535),
    [anon_sym_GT] = ACTIONS(2533),
    [anon_sym_LT] = ACTIONS(2533),
    [anon_sym_LT_GT] = ACTIONS(2535),
    [anon_sym_and] = ACTIONS(2533),
    [anon_sym_AND] = ACTIONS(2533),
    [anon_sym_And] = ACTIONS(2533),
    [anon_sym_or] = ACTIONS(2533),
    [anon_sym_OR] = ACTIONS(2533),
    [anon_sym_Or] = ACTIONS(2533),
    [anon_sym_xor] = ACTIONS(2533),
    [anon_sym_XOR] = ACTIONS(2533),
    [anon_sym_Xor] = ACTIONS(2533),
    [anon_sym_QMARK] = ACTIONS(2535),
    [sym_datetime_literal] = ACTIONS(2535),
    [sym_date_literal] = ACTIONS(2533),
    [sym_time_literal] = ACTIONS(2533),
    [sym_biginteger_literal] = ACTIONS(2535),
    [anon_sym_if] = ACTIONS(2533),
    [anon_sym_IF] = ACTIONS(2533),
    [anon_sym_If] = ACTIONS(2533),
    [anon_sym_else] = ACTIONS(2533),
    [anon_sym_ELSE] = ACTIONS(2533),
    [anon_sym_Else] = ACTIONS(2533),
    [anon_sym_case] = ACTIONS(2533),
    [anon_sym_CASE] = ACTIONS(2533),
    [anon_sym_Case] = ACTIONS(2533),
    [anon_sym_for] = ACTIONS(2533),
    [anon_sym_FOR] = ACTIONS(2533),
    [anon_sym_For] = ACTIONS(2533),
    [anon_sym_foreach] = ACTIONS(2533),
    [anon_sym_FOREACH] = ACTIONS(2533),
    [anon_sym_Foreach] = ACTIONS(2533),
    [anon_sym_while] = ACTIONS(2533),
    [anon_sym_WHILE] = ACTIONS(2533),
    [anon_sym_While] = ACTIONS(2533),
    [anon_sym_repeat] = ACTIONS(2533),
    [anon_sym_REPEAT] = ACTIONS(2533),
    [anon_sym_Repeat] = ACTIONS(2533),
    [anon_sym_until] = ACTIONS(2533),
    [anon_sym_UNTIL] = ACTIONS(2533),
    [anon_sym_Until] = ACTIONS(2533),
    [anon_sym_exit] = ACTIONS(2533),
    [anon_sym_EXIT] = ACTIONS(2533),
    [anon_sym_Exit] = ACTIONS(2533),
    [anon_sym_continue] = ACTIONS(2533),
    [anon_sym_CONTINUE] = ACTIONS(2533),
    [anon_sym_Continue] = ACTIONS(2533),
    [anon_sym_break] = ACTIONS(2533),
    [anon_sym_BREAK] = ACTIONS(2533),
    [anon_sym_Break] = ACTIONS(2533),
    [anon_sym_with] = ACTIONS(2533),
    [anon_sym_WITH] = ACTIONS(2533),
    [anon_sym_With] = ACTIONS(2533),
    [sym_asserterror_keyword] = ACTIONS(2535),
    [anon_sym_in] = ACTIONS(2533),
    [anon_sym_IN] = ACTIONS(2533),
    [anon_sym_In] = ACTIONS(2533),
    [sym_page_keyword] = ACTIONS(2533),
    [anon_sym_codeunit] = ACTIONS(2533),
    [anon_sym_CODEUNIT] = ACTIONS(2533),
    [anon_sym_Codeunit] = ACTIONS(2533),
    [anon_sym_CodeUnit] = ACTIONS(2533),
    [anon_sym_COdeunit] = ACTIONS(2533),
    [anon_sym_codeUnit] = ACTIONS(2533),
    [sym_report_keyword] = ACTIONS(2533),
    [sym_query_keyword] = ACTIONS(2533),
    [anon_sym_xmlport] = ACTIONS(2533),
    [anon_sym_XMLPORT] = ACTIONS(2533),
    [anon_sym_Xmlport] = ACTIONS(2533),
    [anon_sym_XMLport] = ACTIONS(2533),
    [anon_sym_XMLPort] = ACTIONS(2533),
    [anon_sym_XmlPort] = ACTIONS(2533),
    [anon_sym_enum] = ACTIONS(2533),
    [anon_sym_ENUM] = ACTIONS(2533),
    [anon_sym_Enum] = ACTIONS(2533),
    [anon_sym_eNUM] = ACTIONS(2533),
    [anon_sym_eNum] = ACTIONS(2533),
    [anon_sym_ENum] = ACTIONS(2533),
    [sym_temporary_keyword] = ACTIONS(2721),
    [sym_quoted_identifier] = ACTIONS(2535),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2535),
    [sym_integer] = ACTIONS(2533),
    [sym_continue_as_identifier] = ACTIONS(2535),
    [sym_preproc_open] = ACTIONS(2535),
  },
  [STATE(1105)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(2021),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(1106)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_SEMI] = ACTIONS(2428),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2426),
    [anon_sym_COLON_COLON] = ACTIONS(2723),
    [anon_sym_POUNDif] = ACTIONS(2428),
    [anon_sym_POUNDIF] = ACTIONS(2428),
    [anon_sym_POUNDIf] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [anon_sym_POUNDelse] = ACTIONS(2428),
    [anon_sym_POUNDELSE] = ACTIONS(2428),
    [anon_sym_POUNDElse] = ACTIONS(2428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_IF] = ACTIONS(2426),
    [anon_sym_If] = ACTIONS(2426),
    [anon_sym_else] = ACTIONS(2426),
    [anon_sym_ELSE] = ACTIONS(2426),
    [anon_sym_Else] = ACTIONS(2426),
    [anon_sym_case] = ACTIONS(2426),
    [anon_sym_CASE] = ACTIONS(2426),
    [anon_sym_Case] = ACTIONS(2426),
    [anon_sym_for] = ACTIONS(2426),
    [anon_sym_FOR] = ACTIONS(2426),
    [anon_sym_For] = ACTIONS(2426),
    [anon_sym_foreach] = ACTIONS(2426),
    [anon_sym_FOREACH] = ACTIONS(2426),
    [anon_sym_Foreach] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(2426),
    [anon_sym_WHILE] = ACTIONS(2426),
    [anon_sym_While] = ACTIONS(2426),
    [anon_sym_repeat] = ACTIONS(2426),
    [anon_sym_REPEAT] = ACTIONS(2426),
    [anon_sym_Repeat] = ACTIONS(2426),
    [anon_sym_until] = ACTIONS(2426),
    [anon_sym_UNTIL] = ACTIONS(2426),
    [anon_sym_Until] = ACTIONS(2426),
    [anon_sym_exit] = ACTIONS(2426),
    [anon_sym_EXIT] = ACTIONS(2426),
    [anon_sym_Exit] = ACTIONS(2426),
    [anon_sym_continue] = ACTIONS(2426),
    [anon_sym_CONTINUE] = ACTIONS(2426),
    [anon_sym_Continue] = ACTIONS(2426),
    [anon_sym_break] = ACTIONS(2426),
    [anon_sym_BREAK] = ACTIONS(2426),
    [anon_sym_Break] = ACTIONS(2426),
    [anon_sym_with] = ACTIONS(2426),
    [anon_sym_WITH] = ACTIONS(2426),
    [anon_sym_With] = ACTIONS(2426),
    [sym_asserterror_keyword] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_open] = ACTIONS(2428),
  },
  [STATE(1107)] = {
    [sym_identifier] = ACTIONS(2547),
    [anon_sym_SEMI] = ACTIONS(2549),
    [anon_sym_DOT] = ACTIONS(2547),
    [anon_sym_EQ] = ACTIONS(2549),
    [anon_sym_DASH] = ACTIONS(2547),
    [aux_sym_boolean_token1] = ACTIONS(2547),
    [aux_sym_boolean_token2] = ACTIONS(2547),
    [sym_decimal] = ACTIONS(2547),
    [anon_sym_LPAREN] = ACTIONS(2549),
    [anon_sym_DOT_DOT] = ACTIONS(2549),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2547),
    [anon_sym_STAR] = ACTIONS(2547),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [aux_sym_record_type_token1] = ACTIONS(2547),
    [aux_sym_basic_type_token21] = ACTIONS(2547),
    [aux_sym_basic_type_token22] = ACTIONS(2547),
    [aux_sym_basic_type_token48] = ACTIONS(2547),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2547),
    [anon_sym_COLON_COLON] = ACTIONS(2549),
    [anon_sym_POUNDif] = ACTIONS(2549),
    [anon_sym_POUNDIF] = ACTIONS(2549),
    [anon_sym_POUNDIf] = ACTIONS(2549),
    [anon_sym_not] = ACTIONS(2547),
    [anon_sym_NOT] = ACTIONS(2547),
    [anon_sym_Not] = ACTIONS(2547),
    [anon_sym_POUNDelse] = ACTIONS(2549),
    [anon_sym_POUNDELSE] = ACTIONS(2549),
    [anon_sym_POUNDElse] = ACTIONS(2549),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2549),
    [aux_sym__expression_token1] = ACTIONS(2549),
    [aux_sym__expression_token2] = ACTIONS(2547),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2547),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2547),
    [anon_sym_SLASH] = ACTIONS(2547),
    [anon_sym_div] = ACTIONS(2547),
    [anon_sym_DIV] = ACTIONS(2547),
    [anon_sym_Div] = ACTIONS(2547),
    [anon_sym_mod] = ACTIONS(2547),
    [anon_sym_MOD] = ACTIONS(2547),
    [anon_sym_Mod] = ACTIONS(2547),
    [anon_sym_PLUS] = ACTIONS(2547),
    [anon_sym_GT_EQ] = ACTIONS(2549),
    [anon_sym_LT_EQ] = ACTIONS(2549),
    [anon_sym_GT] = ACTIONS(2547),
    [anon_sym_LT] = ACTIONS(2547),
    [anon_sym_LT_GT] = ACTIONS(2549),
    [anon_sym_and] = ACTIONS(2547),
    [anon_sym_AND] = ACTIONS(2547),
    [anon_sym_And] = ACTIONS(2547),
    [anon_sym_or] = ACTIONS(2547),
    [anon_sym_OR] = ACTIONS(2547),
    [anon_sym_Or] = ACTIONS(2547),
    [anon_sym_xor] = ACTIONS(2547),
    [anon_sym_XOR] = ACTIONS(2547),
    [anon_sym_Xor] = ACTIONS(2547),
    [anon_sym_QMARK] = ACTIONS(2549),
    [sym_datetime_literal] = ACTIONS(2549),
    [sym_date_literal] = ACTIONS(2547),
    [sym_time_literal] = ACTIONS(2547),
    [sym_biginteger_literal] = ACTIONS(2549),
    [anon_sym_if] = ACTIONS(2547),
    [anon_sym_IF] = ACTIONS(2547),
    [anon_sym_If] = ACTIONS(2547),
    [anon_sym_else] = ACTIONS(2547),
    [anon_sym_ELSE] = ACTIONS(2547),
    [anon_sym_Else] = ACTIONS(2547),
    [anon_sym_case] = ACTIONS(2547),
    [anon_sym_CASE] = ACTIONS(2547),
    [anon_sym_Case] = ACTIONS(2547),
    [anon_sym_for] = ACTIONS(2547),
    [anon_sym_FOR] = ACTIONS(2547),
    [anon_sym_For] = ACTIONS(2547),
    [anon_sym_foreach] = ACTIONS(2547),
    [anon_sym_FOREACH] = ACTIONS(2547),
    [anon_sym_Foreach] = ACTIONS(2547),
    [anon_sym_while] = ACTIONS(2547),
    [anon_sym_WHILE] = ACTIONS(2547),
    [anon_sym_While] = ACTIONS(2547),
    [anon_sym_repeat] = ACTIONS(2547),
    [anon_sym_REPEAT] = ACTIONS(2547),
    [anon_sym_Repeat] = ACTIONS(2547),
    [anon_sym_until] = ACTIONS(2547),
    [anon_sym_UNTIL] = ACTIONS(2547),
    [anon_sym_Until] = ACTIONS(2547),
    [anon_sym_exit] = ACTIONS(2547),
    [anon_sym_EXIT] = ACTIONS(2547),
    [anon_sym_Exit] = ACTIONS(2547),
    [anon_sym_continue] = ACTIONS(2547),
    [anon_sym_CONTINUE] = ACTIONS(2547),
    [anon_sym_Continue] = ACTIONS(2547),
    [anon_sym_break] = ACTIONS(2547),
    [anon_sym_BREAK] = ACTIONS(2547),
    [anon_sym_Break] = ACTIONS(2547),
    [anon_sym_with] = ACTIONS(2547),
    [anon_sym_WITH] = ACTIONS(2547),
    [anon_sym_With] = ACTIONS(2547),
    [sym_asserterror_keyword] = ACTIONS(2549),
    [anon_sym_in] = ACTIONS(2547),
    [anon_sym_IN] = ACTIONS(2547),
    [anon_sym_In] = ACTIONS(2547),
    [sym_page_keyword] = ACTIONS(2547),
    [anon_sym_codeunit] = ACTIONS(2547),
    [anon_sym_CODEUNIT] = ACTIONS(2547),
    [anon_sym_Codeunit] = ACTIONS(2547),
    [anon_sym_CodeUnit] = ACTIONS(2547),
    [anon_sym_COdeunit] = ACTIONS(2547),
    [anon_sym_codeUnit] = ACTIONS(2547),
    [sym_report_keyword] = ACTIONS(2547),
    [sym_query_keyword] = ACTIONS(2547),
    [anon_sym_xmlport] = ACTIONS(2547),
    [anon_sym_XMLPORT] = ACTIONS(2547),
    [anon_sym_Xmlport] = ACTIONS(2547),
    [anon_sym_XMLport] = ACTIONS(2547),
    [anon_sym_XMLPort] = ACTIONS(2547),
    [anon_sym_XmlPort] = ACTIONS(2547),
    [anon_sym_enum] = ACTIONS(2547),
    [anon_sym_ENUM] = ACTIONS(2547),
    [anon_sym_Enum] = ACTIONS(2547),
    [anon_sym_eNUM] = ACTIONS(2547),
    [anon_sym_eNum] = ACTIONS(2547),
    [anon_sym_ENum] = ACTIONS(2547),
    [sym_quoted_identifier] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2549),
    [sym_integer] = ACTIONS(2547),
    [sym_continue_as_identifier] = ACTIONS(2549),
    [sym_preproc_open] = ACTIONS(2549),
  },
  [STATE(1108)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(1989),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(1109)] = {
    [sym_identifier] = ACTIONS(2555),
    [anon_sym_SEMI] = ACTIONS(2557),
    [anon_sym_DOT] = ACTIONS(2555),
    [anon_sym_EQ] = ACTIONS(2557),
    [anon_sym_DASH] = ACTIONS(2555),
    [aux_sym_boolean_token1] = ACTIONS(2555),
    [aux_sym_boolean_token2] = ACTIONS(2555),
    [sym_decimal] = ACTIONS(2555),
    [anon_sym_LPAREN] = ACTIONS(2557),
    [anon_sym_DOT_DOT] = ACTIONS(2557),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2555),
    [anon_sym_STAR] = ACTIONS(2555),
    [anon_sym_LBRACK] = ACTIONS(2557),
    [aux_sym_record_type_token1] = ACTIONS(2555),
    [aux_sym_basic_type_token21] = ACTIONS(2555),
    [aux_sym_basic_type_token22] = ACTIONS(2555),
    [aux_sym_basic_type_token48] = ACTIONS(2555),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2555),
    [anon_sym_COLON_COLON] = ACTIONS(2557),
    [anon_sym_POUNDif] = ACTIONS(2557),
    [anon_sym_POUNDIF] = ACTIONS(2557),
    [anon_sym_POUNDIf] = ACTIONS(2557),
    [anon_sym_not] = ACTIONS(2555),
    [anon_sym_NOT] = ACTIONS(2555),
    [anon_sym_Not] = ACTIONS(2555),
    [anon_sym_POUNDelse] = ACTIONS(2557),
    [anon_sym_POUNDELSE] = ACTIONS(2557),
    [anon_sym_POUNDElse] = ACTIONS(2557),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2557),
    [aux_sym__expression_token1] = ACTIONS(2557),
    [aux_sym__expression_token2] = ACTIONS(2555),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2555),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2555),
    [anon_sym_SLASH] = ACTIONS(2555),
    [anon_sym_div] = ACTIONS(2555),
    [anon_sym_DIV] = ACTIONS(2555),
    [anon_sym_Div] = ACTIONS(2555),
    [anon_sym_mod] = ACTIONS(2555),
    [anon_sym_MOD] = ACTIONS(2555),
    [anon_sym_Mod] = ACTIONS(2555),
    [anon_sym_PLUS] = ACTIONS(2555),
    [anon_sym_GT_EQ] = ACTIONS(2557),
    [anon_sym_LT_EQ] = ACTIONS(2557),
    [anon_sym_GT] = ACTIONS(2555),
    [anon_sym_LT] = ACTIONS(2555),
    [anon_sym_LT_GT] = ACTIONS(2557),
    [anon_sym_and] = ACTIONS(2555),
    [anon_sym_AND] = ACTIONS(2555),
    [anon_sym_And] = ACTIONS(2555),
    [anon_sym_or] = ACTIONS(2555),
    [anon_sym_OR] = ACTIONS(2555),
    [anon_sym_Or] = ACTIONS(2555),
    [anon_sym_xor] = ACTIONS(2555),
    [anon_sym_XOR] = ACTIONS(2555),
    [anon_sym_Xor] = ACTIONS(2555),
    [anon_sym_QMARK] = ACTIONS(2557),
    [sym_datetime_literal] = ACTIONS(2557),
    [sym_date_literal] = ACTIONS(2555),
    [sym_time_literal] = ACTIONS(2555),
    [sym_biginteger_literal] = ACTIONS(2557),
    [anon_sym_if] = ACTIONS(2555),
    [anon_sym_IF] = ACTIONS(2555),
    [anon_sym_If] = ACTIONS(2555),
    [anon_sym_else] = ACTIONS(2555),
    [anon_sym_ELSE] = ACTIONS(2555),
    [anon_sym_Else] = ACTIONS(2555),
    [anon_sym_case] = ACTIONS(2555),
    [anon_sym_CASE] = ACTIONS(2555),
    [anon_sym_Case] = ACTIONS(2555),
    [anon_sym_for] = ACTIONS(2555),
    [anon_sym_FOR] = ACTIONS(2555),
    [anon_sym_For] = ACTIONS(2555),
    [anon_sym_foreach] = ACTIONS(2555),
    [anon_sym_FOREACH] = ACTIONS(2555),
    [anon_sym_Foreach] = ACTIONS(2555),
    [anon_sym_while] = ACTIONS(2555),
    [anon_sym_WHILE] = ACTIONS(2555),
    [anon_sym_While] = ACTIONS(2555),
    [anon_sym_repeat] = ACTIONS(2555),
    [anon_sym_REPEAT] = ACTIONS(2555),
    [anon_sym_Repeat] = ACTIONS(2555),
    [anon_sym_until] = ACTIONS(2555),
    [anon_sym_UNTIL] = ACTIONS(2555),
    [anon_sym_Until] = ACTIONS(2555),
    [anon_sym_exit] = ACTIONS(2555),
    [anon_sym_EXIT] = ACTIONS(2555),
    [anon_sym_Exit] = ACTIONS(2555),
    [anon_sym_continue] = ACTIONS(2555),
    [anon_sym_CONTINUE] = ACTIONS(2555),
    [anon_sym_Continue] = ACTIONS(2555),
    [anon_sym_break] = ACTIONS(2555),
    [anon_sym_BREAK] = ACTIONS(2555),
    [anon_sym_Break] = ACTIONS(2555),
    [anon_sym_with] = ACTIONS(2555),
    [anon_sym_WITH] = ACTIONS(2555),
    [anon_sym_With] = ACTIONS(2555),
    [sym_asserterror_keyword] = ACTIONS(2557),
    [anon_sym_in] = ACTIONS(2555),
    [anon_sym_IN] = ACTIONS(2555),
    [anon_sym_In] = ACTIONS(2555),
    [sym_page_keyword] = ACTIONS(2555),
    [anon_sym_codeunit] = ACTIONS(2555),
    [anon_sym_CODEUNIT] = ACTIONS(2555),
    [anon_sym_Codeunit] = ACTIONS(2555),
    [anon_sym_CodeUnit] = ACTIONS(2555),
    [anon_sym_COdeunit] = ACTIONS(2555),
    [anon_sym_codeUnit] = ACTIONS(2555),
    [sym_report_keyword] = ACTIONS(2555),
    [sym_query_keyword] = ACTIONS(2555),
    [anon_sym_xmlport] = ACTIONS(2555),
    [anon_sym_XMLPORT] = ACTIONS(2555),
    [anon_sym_Xmlport] = ACTIONS(2555),
    [anon_sym_XMLport] = ACTIONS(2555),
    [anon_sym_XMLPort] = ACTIONS(2555),
    [anon_sym_XmlPort] = ACTIONS(2555),
    [anon_sym_enum] = ACTIONS(2555),
    [anon_sym_ENUM] = ACTIONS(2555),
    [anon_sym_Enum] = ACTIONS(2555),
    [anon_sym_eNUM] = ACTIONS(2555),
    [anon_sym_eNum] = ACTIONS(2555),
    [anon_sym_ENum] = ACTIONS(2555),
    [sym_quoted_identifier] = ACTIONS(2557),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2557),
    [sym_integer] = ACTIONS(2555),
    [sym_continue_as_identifier] = ACTIONS(2557),
    [sym_preproc_open] = ACTIONS(2557),
  },
  [STATE(1110)] = {
    [sym_preproc_conditional_object] = STATE(1098),
    [sym_using_statement] = STATE(1098),
    [sym__object] = STATE(1098),
    [sym_preproc_split_declaration] = STATE(1098),
    [sym_table_declaration] = STATE(1098),
    [sym_page_declaration] = STATE(1098),
    [sym_report_declaration] = STATE(1098),
    [sym_query_declaration] = STATE(1098),
    [sym_xmlport_declaration] = STATE(1098),
    [sym_permissionset_declaration] = STATE(1098),
    [sym_codeunit_declaration] = STATE(1098),
    [sym_enum_declaration] = STATE(1098),
    [sym_tableextension_declaration] = STATE(1098),
    [sym_pageextension_declaration] = STATE(1098),
    [sym_reportextension_declaration] = STATE(1098),
    [sym_enumextension_declaration] = STATE(1098),
    [sym_permissionsetextension_declaration] = STATE(1098),
    [sym_controladdin_declaration] = STATE(1098),
    [sym_profile_declaration] = STATE(1098),
    [sym_entitlement_declaration] = STATE(1098),
    [sym_profileextension_declaration] = STATE(1098),
    [sym_interface_declaration] = STATE(1098),
    [sym_pagecustomization_declaration] = STATE(1098),
    [sym_dotnet_declaration] = STATE(1098),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(2496),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(1098),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(1111)] = {
    [sym_identifier] = ACTIONS(2565),
    [anon_sym_SEMI] = ACTIONS(2567),
    [anon_sym_DOT] = ACTIONS(2565),
    [anon_sym_EQ] = ACTIONS(2567),
    [anon_sym_DASH] = ACTIONS(2565),
    [aux_sym_boolean_token1] = ACTIONS(2565),
    [aux_sym_boolean_token2] = ACTIONS(2565),
    [sym_decimal] = ACTIONS(2565),
    [anon_sym_LPAREN] = ACTIONS(2567),
    [anon_sym_DOT_DOT] = ACTIONS(2567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2565),
    [anon_sym_STAR] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2567),
    [aux_sym_record_type_token1] = ACTIONS(2565),
    [aux_sym_basic_type_token21] = ACTIONS(2565),
    [aux_sym_basic_type_token22] = ACTIONS(2565),
    [aux_sym_basic_type_token48] = ACTIONS(2565),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_POUNDif] = ACTIONS(2567),
    [anon_sym_POUNDIF] = ACTIONS(2567),
    [anon_sym_POUNDIf] = ACTIONS(2567),
    [anon_sym_not] = ACTIONS(2565),
    [anon_sym_NOT] = ACTIONS(2565),
    [anon_sym_Not] = ACTIONS(2565),
    [anon_sym_POUNDelse] = ACTIONS(2567),
    [anon_sym_POUNDELSE] = ACTIONS(2567),
    [anon_sym_POUNDElse] = ACTIONS(2567),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2567),
    [aux_sym__expression_token1] = ACTIONS(2567),
    [aux_sym__expression_token2] = ACTIONS(2565),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2565),
    [anon_sym_SLASH] = ACTIONS(2565),
    [anon_sym_div] = ACTIONS(2565),
    [anon_sym_DIV] = ACTIONS(2565),
    [anon_sym_Div] = ACTIONS(2565),
    [anon_sym_mod] = ACTIONS(2565),
    [anon_sym_MOD] = ACTIONS(2565),
    [anon_sym_Mod] = ACTIONS(2565),
    [anon_sym_PLUS] = ACTIONS(2565),
    [anon_sym_GT_EQ] = ACTIONS(2567),
    [anon_sym_LT_EQ] = ACTIONS(2567),
    [anon_sym_GT] = ACTIONS(2565),
    [anon_sym_LT] = ACTIONS(2565),
    [anon_sym_LT_GT] = ACTIONS(2567),
    [anon_sym_and] = ACTIONS(2565),
    [anon_sym_AND] = ACTIONS(2565),
    [anon_sym_And] = ACTIONS(2565),
    [anon_sym_or] = ACTIONS(2565),
    [anon_sym_OR] = ACTIONS(2565),
    [anon_sym_Or] = ACTIONS(2565),
    [anon_sym_xor] = ACTIONS(2565),
    [anon_sym_XOR] = ACTIONS(2565),
    [anon_sym_Xor] = ACTIONS(2565),
    [anon_sym_QMARK] = ACTIONS(2567),
    [sym_datetime_literal] = ACTIONS(2567),
    [sym_date_literal] = ACTIONS(2565),
    [sym_time_literal] = ACTIONS(2565),
    [sym_biginteger_literal] = ACTIONS(2567),
    [anon_sym_if] = ACTIONS(2565),
    [anon_sym_IF] = ACTIONS(2565),
    [anon_sym_If] = ACTIONS(2565),
    [anon_sym_else] = ACTIONS(2565),
    [anon_sym_ELSE] = ACTIONS(2565),
    [anon_sym_Else] = ACTIONS(2565),
    [anon_sym_case] = ACTIONS(2565),
    [anon_sym_CASE] = ACTIONS(2565),
    [anon_sym_Case] = ACTIONS(2565),
    [anon_sym_for] = ACTIONS(2565),
    [anon_sym_FOR] = ACTIONS(2565),
    [anon_sym_For] = ACTIONS(2565),
    [anon_sym_foreach] = ACTIONS(2565),
    [anon_sym_FOREACH] = ACTIONS(2565),
    [anon_sym_Foreach] = ACTIONS(2565),
    [anon_sym_while] = ACTIONS(2565),
    [anon_sym_WHILE] = ACTIONS(2565),
    [anon_sym_While] = ACTIONS(2565),
    [anon_sym_repeat] = ACTIONS(2565),
    [anon_sym_REPEAT] = ACTIONS(2565),
    [anon_sym_Repeat] = ACTIONS(2565),
    [anon_sym_until] = ACTIONS(2565),
    [anon_sym_UNTIL] = ACTIONS(2565),
    [anon_sym_Until] = ACTIONS(2565),
    [anon_sym_exit] = ACTIONS(2565),
    [anon_sym_EXIT] = ACTIONS(2565),
    [anon_sym_Exit] = ACTIONS(2565),
    [anon_sym_continue] = ACTIONS(2565),
    [anon_sym_CONTINUE] = ACTIONS(2565),
    [anon_sym_Continue] = ACTIONS(2565),
    [anon_sym_break] = ACTIONS(2565),
    [anon_sym_BREAK] = ACTIONS(2565),
    [anon_sym_Break] = ACTIONS(2565),
    [anon_sym_with] = ACTIONS(2565),
    [anon_sym_WITH] = ACTIONS(2565),
    [anon_sym_With] = ACTIONS(2565),
    [sym_asserterror_keyword] = ACTIONS(2567),
    [anon_sym_in] = ACTIONS(2565),
    [anon_sym_IN] = ACTIONS(2565),
    [anon_sym_In] = ACTIONS(2565),
    [sym_page_keyword] = ACTIONS(2565),
    [anon_sym_codeunit] = ACTIONS(2565),
    [anon_sym_CODEUNIT] = ACTIONS(2565),
    [anon_sym_Codeunit] = ACTIONS(2565),
    [anon_sym_CodeUnit] = ACTIONS(2565),
    [anon_sym_COdeunit] = ACTIONS(2565),
    [anon_sym_codeUnit] = ACTIONS(2565),
    [sym_report_keyword] = ACTIONS(2565),
    [sym_query_keyword] = ACTIONS(2565),
    [anon_sym_xmlport] = ACTIONS(2565),
    [anon_sym_XMLPORT] = ACTIONS(2565),
    [anon_sym_Xmlport] = ACTIONS(2565),
    [anon_sym_XMLport] = ACTIONS(2565),
    [anon_sym_XMLPort] = ACTIONS(2565),
    [anon_sym_XmlPort] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_ENUM] = ACTIONS(2565),
    [anon_sym_Enum] = ACTIONS(2565),
    [anon_sym_eNUM] = ACTIONS(2565),
    [anon_sym_eNum] = ACTIONS(2565),
    [anon_sym_ENum] = ACTIONS(2565),
    [sym_quoted_identifier] = ACTIONS(2567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2567),
    [sym_integer] = ACTIONS(2565),
    [sym_continue_as_identifier] = ACTIONS(2567),
    [sym_preproc_open] = ACTIONS(2567),
  },
  [STATE(1112)] = {
    [sym_identifier] = ACTIONS(2517),
    [anon_sym_SEMI] = ACTIONS(2519),
    [anon_sym_DOT] = ACTIONS(2517),
    [anon_sym_EQ] = ACTIONS(2519),
    [anon_sym_DASH] = ACTIONS(2517),
    [aux_sym_boolean_token1] = ACTIONS(2517),
    [aux_sym_boolean_token2] = ACTIONS(2517),
    [sym_decimal] = ACTIONS(2517),
    [anon_sym_LPAREN] = ACTIONS(2519),
    [anon_sym_DOT_DOT] = ACTIONS(2519),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2517),
    [anon_sym_STAR] = ACTIONS(2517),
    [anon_sym_LBRACK] = ACTIONS(2519),
    [aux_sym_record_type_token1] = ACTIONS(2517),
    [aux_sym_basic_type_token21] = ACTIONS(2517),
    [aux_sym_basic_type_token22] = ACTIONS(2517),
    [aux_sym_basic_type_token48] = ACTIONS(2517),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2517),
    [anon_sym_COLON_COLON] = ACTIONS(2519),
    [anon_sym_POUNDif] = ACTIONS(2519),
    [anon_sym_POUNDIF] = ACTIONS(2519),
    [anon_sym_POUNDIf] = ACTIONS(2519),
    [anon_sym_not] = ACTIONS(2517),
    [anon_sym_NOT] = ACTIONS(2517),
    [anon_sym_Not] = ACTIONS(2517),
    [anon_sym_POUNDelse] = ACTIONS(2519),
    [anon_sym_POUNDELSE] = ACTIONS(2519),
    [anon_sym_POUNDElse] = ACTIONS(2519),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2519),
    [aux_sym__expression_token1] = ACTIONS(2519),
    [aux_sym__expression_token2] = ACTIONS(2517),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2517),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2517),
    [anon_sym_SLASH] = ACTIONS(2517),
    [anon_sym_div] = ACTIONS(2517),
    [anon_sym_DIV] = ACTIONS(2517),
    [anon_sym_Div] = ACTIONS(2517),
    [anon_sym_mod] = ACTIONS(2517),
    [anon_sym_MOD] = ACTIONS(2517),
    [anon_sym_Mod] = ACTIONS(2517),
    [anon_sym_PLUS] = ACTIONS(2517),
    [anon_sym_GT_EQ] = ACTIONS(2519),
    [anon_sym_LT_EQ] = ACTIONS(2519),
    [anon_sym_GT] = ACTIONS(2517),
    [anon_sym_LT] = ACTIONS(2517),
    [anon_sym_LT_GT] = ACTIONS(2519),
    [anon_sym_and] = ACTIONS(2517),
    [anon_sym_AND] = ACTIONS(2517),
    [anon_sym_And] = ACTIONS(2517),
    [anon_sym_or] = ACTIONS(2517),
    [anon_sym_OR] = ACTIONS(2517),
    [anon_sym_Or] = ACTIONS(2517),
    [anon_sym_xor] = ACTIONS(2517),
    [anon_sym_XOR] = ACTIONS(2517),
    [anon_sym_Xor] = ACTIONS(2517),
    [anon_sym_QMARK] = ACTIONS(2519),
    [sym_datetime_literal] = ACTIONS(2519),
    [sym_date_literal] = ACTIONS(2517),
    [sym_time_literal] = ACTIONS(2517),
    [sym_biginteger_literal] = ACTIONS(2519),
    [anon_sym_if] = ACTIONS(2517),
    [anon_sym_IF] = ACTIONS(2517),
    [anon_sym_If] = ACTIONS(2517),
    [anon_sym_else] = ACTIONS(2517),
    [anon_sym_ELSE] = ACTIONS(2517),
    [anon_sym_Else] = ACTIONS(2517),
    [anon_sym_case] = ACTIONS(2517),
    [anon_sym_CASE] = ACTIONS(2517),
    [anon_sym_Case] = ACTIONS(2517),
    [anon_sym_for] = ACTIONS(2517),
    [anon_sym_FOR] = ACTIONS(2517),
    [anon_sym_For] = ACTIONS(2517),
    [anon_sym_foreach] = ACTIONS(2517),
    [anon_sym_FOREACH] = ACTIONS(2517),
    [anon_sym_Foreach] = ACTIONS(2517),
    [anon_sym_while] = ACTIONS(2517),
    [anon_sym_WHILE] = ACTIONS(2517),
    [anon_sym_While] = ACTIONS(2517),
    [anon_sym_repeat] = ACTIONS(2517),
    [anon_sym_REPEAT] = ACTIONS(2517),
    [anon_sym_Repeat] = ACTIONS(2517),
    [anon_sym_until] = ACTIONS(2517),
    [anon_sym_UNTIL] = ACTIONS(2517),
    [anon_sym_Until] = ACTIONS(2517),
    [anon_sym_exit] = ACTIONS(2517),
    [anon_sym_EXIT] = ACTIONS(2517),
    [anon_sym_Exit] = ACTIONS(2517),
    [anon_sym_continue] = ACTIONS(2517),
    [anon_sym_CONTINUE] = ACTIONS(2517),
    [anon_sym_Continue] = ACTIONS(2517),
    [anon_sym_break] = ACTIONS(2517),
    [anon_sym_BREAK] = ACTIONS(2517),
    [anon_sym_Break] = ACTIONS(2517),
    [anon_sym_with] = ACTIONS(2517),
    [anon_sym_WITH] = ACTIONS(2517),
    [anon_sym_With] = ACTIONS(2517),
    [sym_asserterror_keyword] = ACTIONS(2519),
    [anon_sym_in] = ACTIONS(2517),
    [anon_sym_IN] = ACTIONS(2517),
    [anon_sym_In] = ACTIONS(2517),
    [sym_page_keyword] = ACTIONS(2517),
    [anon_sym_codeunit] = ACTIONS(2517),
    [anon_sym_CODEUNIT] = ACTIONS(2517),
    [anon_sym_Codeunit] = ACTIONS(2517),
    [anon_sym_CodeUnit] = ACTIONS(2517),
    [anon_sym_COdeunit] = ACTIONS(2517),
    [anon_sym_codeUnit] = ACTIONS(2517),
    [sym_report_keyword] = ACTIONS(2517),
    [sym_query_keyword] = ACTIONS(2517),
    [anon_sym_xmlport] = ACTIONS(2517),
    [anon_sym_XMLPORT] = ACTIONS(2517),
    [anon_sym_Xmlport] = ACTIONS(2517),
    [anon_sym_XMLport] = ACTIONS(2517),
    [anon_sym_XMLPort] = ACTIONS(2517),
    [anon_sym_XmlPort] = ACTIONS(2517),
    [anon_sym_enum] = ACTIONS(2517),
    [anon_sym_ENUM] = ACTIONS(2517),
    [anon_sym_Enum] = ACTIONS(2517),
    [anon_sym_eNUM] = ACTIONS(2517),
    [anon_sym_eNum] = ACTIONS(2517),
    [anon_sym_ENum] = ACTIONS(2517),
    [sym_quoted_identifier] = ACTIONS(2519),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2519),
    [sym_integer] = ACTIONS(2517),
    [sym_continue_as_identifier] = ACTIONS(2519),
    [sym_preproc_open] = ACTIONS(2519),
  },
  [STATE(1113)] = {
    [sym_identifier] = ACTIONS(2521),
    [anon_sym_SEMI] = ACTIONS(2523),
    [anon_sym_DOT] = ACTIONS(2521),
    [anon_sym_EQ] = ACTIONS(2523),
    [anon_sym_DASH] = ACTIONS(2521),
    [aux_sym_boolean_token1] = ACTIONS(2521),
    [aux_sym_boolean_token2] = ACTIONS(2521),
    [sym_decimal] = ACTIONS(2521),
    [anon_sym_LPAREN] = ACTIONS(2523),
    [anon_sym_DOT_DOT] = ACTIONS(2523),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2521),
    [anon_sym_STAR] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [aux_sym_record_type_token1] = ACTIONS(2521),
    [aux_sym_basic_type_token21] = ACTIONS(2521),
    [aux_sym_basic_type_token22] = ACTIONS(2521),
    [aux_sym_basic_type_token48] = ACTIONS(2521),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2521),
    [anon_sym_COLON_COLON] = ACTIONS(2523),
    [anon_sym_POUNDif] = ACTIONS(2523),
    [anon_sym_POUNDIF] = ACTIONS(2523),
    [anon_sym_POUNDIf] = ACTIONS(2523),
    [anon_sym_not] = ACTIONS(2521),
    [anon_sym_NOT] = ACTIONS(2521),
    [anon_sym_Not] = ACTIONS(2521),
    [anon_sym_POUNDelse] = ACTIONS(2523),
    [anon_sym_POUNDELSE] = ACTIONS(2523),
    [anon_sym_POUNDElse] = ACTIONS(2523),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2523),
    [aux_sym__expression_token1] = ACTIONS(2523),
    [aux_sym__expression_token2] = ACTIONS(2521),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2521),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2521),
    [anon_sym_SLASH] = ACTIONS(2521),
    [anon_sym_div] = ACTIONS(2521),
    [anon_sym_DIV] = ACTIONS(2521),
    [anon_sym_Div] = ACTIONS(2521),
    [anon_sym_mod] = ACTIONS(2521),
    [anon_sym_MOD] = ACTIONS(2521),
    [anon_sym_Mod] = ACTIONS(2521),
    [anon_sym_PLUS] = ACTIONS(2521),
    [anon_sym_GT_EQ] = ACTIONS(2523),
    [anon_sym_LT_EQ] = ACTIONS(2523),
    [anon_sym_GT] = ACTIONS(2521),
    [anon_sym_LT] = ACTIONS(2521),
    [anon_sym_LT_GT] = ACTIONS(2523),
    [anon_sym_and] = ACTIONS(2521),
    [anon_sym_AND] = ACTIONS(2521),
    [anon_sym_And] = ACTIONS(2521),
    [anon_sym_or] = ACTIONS(2521),
    [anon_sym_OR] = ACTIONS(2521),
    [anon_sym_Or] = ACTIONS(2521),
    [anon_sym_xor] = ACTIONS(2521),
    [anon_sym_XOR] = ACTIONS(2521),
    [anon_sym_Xor] = ACTIONS(2521),
    [anon_sym_QMARK] = ACTIONS(2523),
    [sym_datetime_literal] = ACTIONS(2523),
    [sym_date_literal] = ACTIONS(2521),
    [sym_time_literal] = ACTIONS(2521),
    [sym_biginteger_literal] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2521),
    [anon_sym_IF] = ACTIONS(2521),
    [anon_sym_If] = ACTIONS(2521),
    [anon_sym_else] = ACTIONS(2521),
    [anon_sym_ELSE] = ACTIONS(2521),
    [anon_sym_Else] = ACTIONS(2521),
    [anon_sym_case] = ACTIONS(2521),
    [anon_sym_CASE] = ACTIONS(2521),
    [anon_sym_Case] = ACTIONS(2521),
    [anon_sym_for] = ACTIONS(2521),
    [anon_sym_FOR] = ACTIONS(2521),
    [anon_sym_For] = ACTIONS(2521),
    [anon_sym_foreach] = ACTIONS(2521),
    [anon_sym_FOREACH] = ACTIONS(2521),
    [anon_sym_Foreach] = ACTIONS(2521),
    [anon_sym_while] = ACTIONS(2521),
    [anon_sym_WHILE] = ACTIONS(2521),
    [anon_sym_While] = ACTIONS(2521),
    [anon_sym_repeat] = ACTIONS(2521),
    [anon_sym_REPEAT] = ACTIONS(2521),
    [anon_sym_Repeat] = ACTIONS(2521),
    [anon_sym_until] = ACTIONS(2521),
    [anon_sym_UNTIL] = ACTIONS(2521),
    [anon_sym_Until] = ACTIONS(2521),
    [anon_sym_exit] = ACTIONS(2521),
    [anon_sym_EXIT] = ACTIONS(2521),
    [anon_sym_Exit] = ACTIONS(2521),
    [anon_sym_continue] = ACTIONS(2521),
    [anon_sym_CONTINUE] = ACTIONS(2521),
    [anon_sym_Continue] = ACTIONS(2521),
    [anon_sym_break] = ACTIONS(2521),
    [anon_sym_BREAK] = ACTIONS(2521),
    [anon_sym_Break] = ACTIONS(2521),
    [anon_sym_with] = ACTIONS(2521),
    [anon_sym_WITH] = ACTIONS(2521),
    [anon_sym_With] = ACTIONS(2521),
    [sym_asserterror_keyword] = ACTIONS(2523),
    [anon_sym_in] = ACTIONS(2521),
    [anon_sym_IN] = ACTIONS(2521),
    [anon_sym_In] = ACTIONS(2521),
    [sym_page_keyword] = ACTIONS(2521),
    [anon_sym_codeunit] = ACTIONS(2521),
    [anon_sym_CODEUNIT] = ACTIONS(2521),
    [anon_sym_Codeunit] = ACTIONS(2521),
    [anon_sym_CodeUnit] = ACTIONS(2521),
    [anon_sym_COdeunit] = ACTIONS(2521),
    [anon_sym_codeUnit] = ACTIONS(2521),
    [sym_report_keyword] = ACTIONS(2521),
    [sym_query_keyword] = ACTIONS(2521),
    [anon_sym_xmlport] = ACTIONS(2521),
    [anon_sym_XMLPORT] = ACTIONS(2521),
    [anon_sym_Xmlport] = ACTIONS(2521),
    [anon_sym_XMLport] = ACTIONS(2521),
    [anon_sym_XMLPort] = ACTIONS(2521),
    [anon_sym_XmlPort] = ACTIONS(2521),
    [anon_sym_enum] = ACTIONS(2521),
    [anon_sym_ENUM] = ACTIONS(2521),
    [anon_sym_Enum] = ACTIONS(2521),
    [anon_sym_eNUM] = ACTIONS(2521),
    [anon_sym_eNum] = ACTIONS(2521),
    [anon_sym_ENum] = ACTIONS(2521),
    [sym_quoted_identifier] = ACTIONS(2523),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2523),
    [sym_integer] = ACTIONS(2521),
    [sym_continue_as_identifier] = ACTIONS(2523),
    [sym_preproc_open] = ACTIONS(2523),
  },
  [STATE(1114)] = {
    [sym_identifier] = ACTIONS(2396),
    [anon_sym_SEMI] = ACTIONS(2398),
    [anon_sym_DOT] = ACTIONS(2396),
    [anon_sym_EQ] = ACTIONS(2398),
    [anon_sym_DASH] = ACTIONS(2396),
    [aux_sym_boolean_token1] = ACTIONS(2396),
    [aux_sym_boolean_token2] = ACTIONS(2396),
    [sym_decimal] = ACTIONS(2396),
    [anon_sym_LPAREN] = ACTIONS(2398),
    [anon_sym_DOT_DOT] = ACTIONS(2398),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2396),
    [anon_sym_STAR] = ACTIONS(2396),
    [anon_sym_LBRACK] = ACTIONS(2398),
    [aux_sym_record_type_token1] = ACTIONS(2396),
    [aux_sym_basic_type_token21] = ACTIONS(2396),
    [aux_sym_basic_type_token22] = ACTIONS(2396),
    [aux_sym_basic_type_token48] = ACTIONS(2396),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2396),
    [anon_sym_POUNDif] = ACTIONS(2398),
    [anon_sym_POUNDIF] = ACTIONS(2398),
    [anon_sym_POUNDIf] = ACTIONS(2398),
    [anon_sym_not] = ACTIONS(2396),
    [anon_sym_NOT] = ACTIONS(2396),
    [anon_sym_Not] = ACTIONS(2396),
    [anon_sym_POUNDelse] = ACTIONS(2398),
    [anon_sym_POUNDELSE] = ACTIONS(2398),
    [anon_sym_POUNDElse] = ACTIONS(2398),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2398),
    [aux_sym__expression_token1] = ACTIONS(2398),
    [aux_sym__expression_token2] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2396),
    [anon_sym_SLASH] = ACTIONS(2396),
    [anon_sym_div] = ACTIONS(2396),
    [anon_sym_DIV] = ACTIONS(2396),
    [anon_sym_Div] = ACTIONS(2396),
    [anon_sym_mod] = ACTIONS(2396),
    [anon_sym_MOD] = ACTIONS(2396),
    [anon_sym_Mod] = ACTIONS(2396),
    [anon_sym_PLUS] = ACTIONS(2396),
    [anon_sym_GT_EQ] = ACTIONS(2398),
    [anon_sym_LT_EQ] = ACTIONS(2398),
    [anon_sym_GT] = ACTIONS(2396),
    [anon_sym_LT] = ACTIONS(2396),
    [anon_sym_LT_GT] = ACTIONS(2398),
    [anon_sym_and] = ACTIONS(2396),
    [anon_sym_AND] = ACTIONS(2396),
    [anon_sym_And] = ACTIONS(2396),
    [anon_sym_or] = ACTIONS(2396),
    [anon_sym_OR] = ACTIONS(2396),
    [anon_sym_Or] = ACTIONS(2396),
    [anon_sym_xor] = ACTIONS(2396),
    [anon_sym_XOR] = ACTIONS(2396),
    [anon_sym_Xor] = ACTIONS(2396),
    [anon_sym_QMARK] = ACTIONS(2398),
    [sym_datetime_literal] = ACTIONS(2398),
    [sym_date_literal] = ACTIONS(2396),
    [sym_time_literal] = ACTIONS(2396),
    [sym_biginteger_literal] = ACTIONS(2398),
    [anon_sym_if] = ACTIONS(2396),
    [anon_sym_IF] = ACTIONS(2396),
    [anon_sym_If] = ACTIONS(2396),
    [anon_sym_else] = ACTIONS(2396),
    [anon_sym_ELSE] = ACTIONS(2396),
    [anon_sym_Else] = ACTIONS(2396),
    [anon_sym_case] = ACTIONS(2396),
    [anon_sym_CASE] = ACTIONS(2396),
    [anon_sym_Case] = ACTIONS(2396),
    [anon_sym_for] = ACTIONS(2396),
    [anon_sym_FOR] = ACTIONS(2396),
    [anon_sym_For] = ACTIONS(2396),
    [anon_sym_foreach] = ACTIONS(2396),
    [anon_sym_FOREACH] = ACTIONS(2396),
    [anon_sym_Foreach] = ACTIONS(2396),
    [anon_sym_while] = ACTIONS(2396),
    [anon_sym_WHILE] = ACTIONS(2396),
    [anon_sym_While] = ACTIONS(2396),
    [anon_sym_repeat] = ACTIONS(2396),
    [anon_sym_REPEAT] = ACTIONS(2396),
    [anon_sym_Repeat] = ACTIONS(2396),
    [anon_sym_until] = ACTIONS(2396),
    [anon_sym_UNTIL] = ACTIONS(2396),
    [anon_sym_Until] = ACTIONS(2396),
    [anon_sym_exit] = ACTIONS(2396),
    [anon_sym_EXIT] = ACTIONS(2396),
    [anon_sym_Exit] = ACTIONS(2396),
    [anon_sym_continue] = ACTIONS(2396),
    [anon_sym_CONTINUE] = ACTIONS(2396),
    [anon_sym_Continue] = ACTIONS(2396),
    [anon_sym_break] = ACTIONS(2396),
    [anon_sym_BREAK] = ACTIONS(2396),
    [anon_sym_Break] = ACTIONS(2396),
    [anon_sym_with] = ACTIONS(2396),
    [anon_sym_WITH] = ACTIONS(2396),
    [anon_sym_With] = ACTIONS(2396),
    [sym_asserterror_keyword] = ACTIONS(2398),
    [anon_sym_in] = ACTIONS(2396),
    [anon_sym_IN] = ACTIONS(2396),
    [anon_sym_In] = ACTIONS(2396),
    [sym_page_keyword] = ACTIONS(2396),
    [anon_sym_codeunit] = ACTIONS(2396),
    [anon_sym_CODEUNIT] = ACTIONS(2396),
    [anon_sym_Codeunit] = ACTIONS(2396),
    [anon_sym_CodeUnit] = ACTIONS(2396),
    [anon_sym_COdeunit] = ACTIONS(2396),
    [anon_sym_codeUnit] = ACTIONS(2396),
    [sym_report_keyword] = ACTIONS(2396),
    [sym_query_keyword] = ACTIONS(2396),
    [anon_sym_xmlport] = ACTIONS(2396),
    [anon_sym_XMLPORT] = ACTIONS(2396),
    [anon_sym_Xmlport] = ACTIONS(2396),
    [anon_sym_XMLport] = ACTIONS(2396),
    [anon_sym_XMLPort] = ACTIONS(2396),
    [anon_sym_XmlPort] = ACTIONS(2396),
    [anon_sym_enum] = ACTIONS(2396),
    [anon_sym_ENUM] = ACTIONS(2396),
    [anon_sym_Enum] = ACTIONS(2396),
    [anon_sym_eNUM] = ACTIONS(2396),
    [anon_sym_eNum] = ACTIONS(2396),
    [anon_sym_ENum] = ACTIONS(2396),
    [sym_temporary_keyword] = ACTIONS(2396),
    [sym_quoted_identifier] = ACTIONS(2398),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2398),
    [sym_integer] = ACTIONS(2396),
    [sym_continue_as_identifier] = ACTIONS(2398),
    [sym_preproc_open] = ACTIONS(2398),
  },
  [STATE(1115)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(2002),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(1116)] = {
    [sym_identifier] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2563),
    [anon_sym_DOT] = ACTIONS(2561),
    [anon_sym_EQ] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2561),
    [aux_sym_boolean_token1] = ACTIONS(2561),
    [aux_sym_boolean_token2] = ACTIONS(2561),
    [sym_decimal] = ACTIONS(2561),
    [anon_sym_LPAREN] = ACTIONS(2563),
    [anon_sym_DOT_DOT] = ACTIONS(2563),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2561),
    [anon_sym_STAR] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2563),
    [aux_sym_record_type_token1] = ACTIONS(2561),
    [aux_sym_basic_type_token21] = ACTIONS(2561),
    [aux_sym_basic_type_token22] = ACTIONS(2561),
    [aux_sym_basic_type_token48] = ACTIONS(2561),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_POUNDif] = ACTIONS(2563),
    [anon_sym_POUNDIF] = ACTIONS(2563),
    [anon_sym_POUNDIf] = ACTIONS(2563),
    [anon_sym_not] = ACTIONS(2561),
    [anon_sym_NOT] = ACTIONS(2561),
    [anon_sym_Not] = ACTIONS(2561),
    [anon_sym_POUNDelse] = ACTIONS(2563),
    [anon_sym_POUNDELSE] = ACTIONS(2563),
    [anon_sym_POUNDElse] = ACTIONS(2563),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2563),
    [aux_sym__expression_token1] = ACTIONS(2563),
    [aux_sym__expression_token2] = ACTIONS(2561),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2561),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2561),
    [anon_sym_SLASH] = ACTIONS(2561),
    [anon_sym_div] = ACTIONS(2561),
    [anon_sym_DIV] = ACTIONS(2561),
    [anon_sym_Div] = ACTIONS(2561),
    [anon_sym_mod] = ACTIONS(2561),
    [anon_sym_MOD] = ACTIONS(2561),
    [anon_sym_Mod] = ACTIONS(2561),
    [anon_sym_PLUS] = ACTIONS(2561),
    [anon_sym_GT_EQ] = ACTIONS(2563),
    [anon_sym_LT_EQ] = ACTIONS(2563),
    [anon_sym_GT] = ACTIONS(2561),
    [anon_sym_LT] = ACTIONS(2561),
    [anon_sym_LT_GT] = ACTIONS(2563),
    [anon_sym_and] = ACTIONS(2561),
    [anon_sym_AND] = ACTIONS(2561),
    [anon_sym_And] = ACTIONS(2561),
    [anon_sym_or] = ACTIONS(2561),
    [anon_sym_OR] = ACTIONS(2561),
    [anon_sym_Or] = ACTIONS(2561),
    [anon_sym_xor] = ACTIONS(2561),
    [anon_sym_XOR] = ACTIONS(2561),
    [anon_sym_Xor] = ACTIONS(2561),
    [anon_sym_QMARK] = ACTIONS(2563),
    [sym_datetime_literal] = ACTIONS(2563),
    [sym_date_literal] = ACTIONS(2561),
    [sym_time_literal] = ACTIONS(2561),
    [sym_biginteger_literal] = ACTIONS(2563),
    [anon_sym_if] = ACTIONS(2561),
    [anon_sym_IF] = ACTIONS(2561),
    [anon_sym_If] = ACTIONS(2561),
    [anon_sym_else] = ACTIONS(2561),
    [anon_sym_ELSE] = ACTIONS(2561),
    [anon_sym_Else] = ACTIONS(2561),
    [anon_sym_case] = ACTIONS(2561),
    [anon_sym_CASE] = ACTIONS(2561),
    [anon_sym_Case] = ACTIONS(2561),
    [anon_sym_for] = ACTIONS(2561),
    [anon_sym_FOR] = ACTIONS(2561),
    [anon_sym_For] = ACTIONS(2561),
    [anon_sym_foreach] = ACTIONS(2561),
    [anon_sym_FOREACH] = ACTIONS(2561),
    [anon_sym_Foreach] = ACTIONS(2561),
    [anon_sym_while] = ACTIONS(2561),
    [anon_sym_WHILE] = ACTIONS(2561),
    [anon_sym_While] = ACTIONS(2561),
    [anon_sym_repeat] = ACTIONS(2561),
    [anon_sym_REPEAT] = ACTIONS(2561),
    [anon_sym_Repeat] = ACTIONS(2561),
    [anon_sym_until] = ACTIONS(2561),
    [anon_sym_UNTIL] = ACTIONS(2561),
    [anon_sym_Until] = ACTIONS(2561),
    [anon_sym_exit] = ACTIONS(2561),
    [anon_sym_EXIT] = ACTIONS(2561),
    [anon_sym_Exit] = ACTIONS(2561),
    [anon_sym_continue] = ACTIONS(2561),
    [anon_sym_CONTINUE] = ACTIONS(2561),
    [anon_sym_Continue] = ACTIONS(2561),
    [anon_sym_break] = ACTIONS(2561),
    [anon_sym_BREAK] = ACTIONS(2561),
    [anon_sym_Break] = ACTIONS(2561),
    [anon_sym_with] = ACTIONS(2561),
    [anon_sym_WITH] = ACTIONS(2561),
    [anon_sym_With] = ACTIONS(2561),
    [sym_asserterror_keyword] = ACTIONS(2563),
    [anon_sym_in] = ACTIONS(2561),
    [anon_sym_IN] = ACTIONS(2561),
    [anon_sym_In] = ACTIONS(2561),
    [sym_page_keyword] = ACTIONS(2561),
    [anon_sym_codeunit] = ACTIONS(2561),
    [anon_sym_CODEUNIT] = ACTIONS(2561),
    [anon_sym_Codeunit] = ACTIONS(2561),
    [anon_sym_CodeUnit] = ACTIONS(2561),
    [anon_sym_COdeunit] = ACTIONS(2561),
    [anon_sym_codeUnit] = ACTIONS(2561),
    [sym_report_keyword] = ACTIONS(2561),
    [sym_query_keyword] = ACTIONS(2561),
    [anon_sym_xmlport] = ACTIONS(2561),
    [anon_sym_XMLPORT] = ACTIONS(2561),
    [anon_sym_Xmlport] = ACTIONS(2561),
    [anon_sym_XMLport] = ACTIONS(2561),
    [anon_sym_XMLPort] = ACTIONS(2561),
    [anon_sym_XmlPort] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_ENUM] = ACTIONS(2561),
    [anon_sym_Enum] = ACTIONS(2561),
    [anon_sym_eNUM] = ACTIONS(2561),
    [anon_sym_eNum] = ACTIONS(2561),
    [anon_sym_ENum] = ACTIONS(2561),
    [sym_quoted_identifier] = ACTIONS(2563),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2563),
    [sym_integer] = ACTIONS(2561),
    [sym_continue_as_identifier] = ACTIONS(2563),
    [sym_preproc_open] = ACTIONS(2563),
  },
  [STATE(1117)] = {
    [sym_preproc_conditional_object] = STATE(1094),
    [sym_using_statement] = STATE(1094),
    [sym__object] = STATE(1094),
    [sym_preproc_split_declaration] = STATE(1094),
    [sym_table_declaration] = STATE(1094),
    [sym_page_declaration] = STATE(1094),
    [sym_report_declaration] = STATE(1094),
    [sym_query_declaration] = STATE(1094),
    [sym_xmlport_declaration] = STATE(1094),
    [sym_permissionset_declaration] = STATE(1094),
    [sym_codeunit_declaration] = STATE(1094),
    [sym_enum_declaration] = STATE(1094),
    [sym_tableextension_declaration] = STATE(1094),
    [sym_pageextension_declaration] = STATE(1094),
    [sym_reportextension_declaration] = STATE(1094),
    [sym_enumextension_declaration] = STATE(1094),
    [sym_permissionsetextension_declaration] = STATE(1094),
    [sym_controladdin_declaration] = STATE(1094),
    [sym_profile_declaration] = STATE(1094),
    [sym_entitlement_declaration] = STATE(1094),
    [sym_profileextension_declaration] = STATE(1094),
    [sym_interface_declaration] = STATE(1094),
    [sym_pagecustomization_declaration] = STATE(1094),
    [sym_dotnet_declaration] = STATE(1094),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(2534),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(1094),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(1118)] = {
    [sym_identifier] = ACTIONS(2525),
    [anon_sym_SEMI] = ACTIONS(2527),
    [anon_sym_DOT] = ACTIONS(2525),
    [anon_sym_EQ] = ACTIONS(2527),
    [anon_sym_DASH] = ACTIONS(2525),
    [aux_sym_boolean_token1] = ACTIONS(2525),
    [aux_sym_boolean_token2] = ACTIONS(2525),
    [sym_decimal] = ACTIONS(2525),
    [anon_sym_LPAREN] = ACTIONS(2527),
    [anon_sym_DOT_DOT] = ACTIONS(2527),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2525),
    [anon_sym_STAR] = ACTIONS(2525),
    [anon_sym_LBRACK] = ACTIONS(2527),
    [aux_sym_record_type_token1] = ACTIONS(2525),
    [aux_sym_basic_type_token21] = ACTIONS(2525),
    [aux_sym_basic_type_token22] = ACTIONS(2525),
    [aux_sym_basic_type_token48] = ACTIONS(2525),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2525),
    [anon_sym_COLON_COLON] = ACTIONS(2527),
    [anon_sym_POUNDif] = ACTIONS(2527),
    [anon_sym_POUNDIF] = ACTIONS(2527),
    [anon_sym_POUNDIf] = ACTIONS(2527),
    [anon_sym_not] = ACTIONS(2525),
    [anon_sym_NOT] = ACTIONS(2525),
    [anon_sym_Not] = ACTIONS(2525),
    [anon_sym_POUNDelse] = ACTIONS(2527),
    [anon_sym_POUNDELSE] = ACTIONS(2527),
    [anon_sym_POUNDElse] = ACTIONS(2527),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2527),
    [aux_sym__expression_token1] = ACTIONS(2527),
    [aux_sym__expression_token2] = ACTIONS(2525),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2525),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2525),
    [anon_sym_SLASH] = ACTIONS(2525),
    [anon_sym_div] = ACTIONS(2525),
    [anon_sym_DIV] = ACTIONS(2525),
    [anon_sym_Div] = ACTIONS(2525),
    [anon_sym_mod] = ACTIONS(2525),
    [anon_sym_MOD] = ACTIONS(2525),
    [anon_sym_Mod] = ACTIONS(2525),
    [anon_sym_PLUS] = ACTIONS(2525),
    [anon_sym_GT_EQ] = ACTIONS(2527),
    [anon_sym_LT_EQ] = ACTIONS(2527),
    [anon_sym_GT] = ACTIONS(2525),
    [anon_sym_LT] = ACTIONS(2525),
    [anon_sym_LT_GT] = ACTIONS(2527),
    [anon_sym_and] = ACTIONS(2525),
    [anon_sym_AND] = ACTIONS(2525),
    [anon_sym_And] = ACTIONS(2525),
    [anon_sym_or] = ACTIONS(2525),
    [anon_sym_OR] = ACTIONS(2525),
    [anon_sym_Or] = ACTIONS(2525),
    [anon_sym_xor] = ACTIONS(2525),
    [anon_sym_XOR] = ACTIONS(2525),
    [anon_sym_Xor] = ACTIONS(2525),
    [anon_sym_QMARK] = ACTIONS(2527),
    [sym_datetime_literal] = ACTIONS(2527),
    [sym_date_literal] = ACTIONS(2525),
    [sym_time_literal] = ACTIONS(2525),
    [sym_biginteger_literal] = ACTIONS(2527),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_IF] = ACTIONS(2525),
    [anon_sym_If] = ACTIONS(2525),
    [anon_sym_else] = ACTIONS(2525),
    [anon_sym_ELSE] = ACTIONS(2525),
    [anon_sym_Else] = ACTIONS(2525),
    [anon_sym_case] = ACTIONS(2525),
    [anon_sym_CASE] = ACTIONS(2525),
    [anon_sym_Case] = ACTIONS(2525),
    [anon_sym_for] = ACTIONS(2525),
    [anon_sym_FOR] = ACTIONS(2525),
    [anon_sym_For] = ACTIONS(2525),
    [anon_sym_foreach] = ACTIONS(2525),
    [anon_sym_FOREACH] = ACTIONS(2525),
    [anon_sym_Foreach] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(2525),
    [anon_sym_WHILE] = ACTIONS(2525),
    [anon_sym_While] = ACTIONS(2525),
    [anon_sym_repeat] = ACTIONS(2525),
    [anon_sym_REPEAT] = ACTIONS(2525),
    [anon_sym_Repeat] = ACTIONS(2525),
    [anon_sym_until] = ACTIONS(2525),
    [anon_sym_UNTIL] = ACTIONS(2525),
    [anon_sym_Until] = ACTIONS(2525),
    [anon_sym_exit] = ACTIONS(2525),
    [anon_sym_EXIT] = ACTIONS(2525),
    [anon_sym_Exit] = ACTIONS(2525),
    [anon_sym_continue] = ACTIONS(2525),
    [anon_sym_CONTINUE] = ACTIONS(2525),
    [anon_sym_Continue] = ACTIONS(2525),
    [anon_sym_break] = ACTIONS(2525),
    [anon_sym_BREAK] = ACTIONS(2525),
    [anon_sym_Break] = ACTIONS(2525),
    [anon_sym_with] = ACTIONS(2525),
    [anon_sym_WITH] = ACTIONS(2525),
    [anon_sym_With] = ACTIONS(2525),
    [sym_asserterror_keyword] = ACTIONS(2527),
    [anon_sym_in] = ACTIONS(2525),
    [anon_sym_IN] = ACTIONS(2525),
    [anon_sym_In] = ACTIONS(2525),
    [sym_page_keyword] = ACTIONS(2525),
    [anon_sym_codeunit] = ACTIONS(2525),
    [anon_sym_CODEUNIT] = ACTIONS(2525),
    [anon_sym_Codeunit] = ACTIONS(2525),
    [anon_sym_CodeUnit] = ACTIONS(2525),
    [anon_sym_COdeunit] = ACTIONS(2525),
    [anon_sym_codeUnit] = ACTIONS(2525),
    [sym_report_keyword] = ACTIONS(2525),
    [sym_query_keyword] = ACTIONS(2525),
    [anon_sym_xmlport] = ACTIONS(2525),
    [anon_sym_XMLPORT] = ACTIONS(2525),
    [anon_sym_Xmlport] = ACTIONS(2525),
    [anon_sym_XMLport] = ACTIONS(2525),
    [anon_sym_XMLPort] = ACTIONS(2525),
    [anon_sym_XmlPort] = ACTIONS(2525),
    [anon_sym_enum] = ACTIONS(2525),
    [anon_sym_ENUM] = ACTIONS(2525),
    [anon_sym_Enum] = ACTIONS(2525),
    [anon_sym_eNUM] = ACTIONS(2525),
    [anon_sym_eNum] = ACTIONS(2525),
    [anon_sym_ENum] = ACTIONS(2525),
    [sym_quoted_identifier] = ACTIONS(2527),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2527),
    [sym_integer] = ACTIONS(2525),
    [sym_continue_as_identifier] = ACTIONS(2527),
    [sym_preproc_open] = ACTIONS(2527),
  },
  [STATE(1119)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_SEMI] = ACTIONS(2428),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_COMMA] = ACTIONS(2428),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2426),
    [anon_sym_POUNDif] = ACTIONS(2428),
    [anon_sym_POUNDIF] = ACTIONS(2428),
    [anon_sym_POUNDIf] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [anon_sym_POUNDelse] = ACTIONS(2428),
    [anon_sym_POUNDELSE] = ACTIONS(2428),
    [anon_sym_POUNDElse] = ACTIONS(2428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_IF] = ACTIONS(2426),
    [anon_sym_If] = ACTIONS(2426),
    [anon_sym_else] = ACTIONS(2426),
    [anon_sym_ELSE] = ACTIONS(2426),
    [anon_sym_Else] = ACTIONS(2426),
    [anon_sym_case] = ACTIONS(2426),
    [anon_sym_CASE] = ACTIONS(2426),
    [anon_sym_Case] = ACTIONS(2426),
    [anon_sym_for] = ACTIONS(2426),
    [anon_sym_FOR] = ACTIONS(2426),
    [anon_sym_For] = ACTIONS(2426),
    [anon_sym_foreach] = ACTIONS(2426),
    [anon_sym_FOREACH] = ACTIONS(2426),
    [anon_sym_Foreach] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(2426),
    [anon_sym_WHILE] = ACTIONS(2426),
    [anon_sym_While] = ACTIONS(2426),
    [anon_sym_repeat] = ACTIONS(2426),
    [anon_sym_REPEAT] = ACTIONS(2426),
    [anon_sym_Repeat] = ACTIONS(2426),
    [anon_sym_until] = ACTIONS(2426),
    [anon_sym_UNTIL] = ACTIONS(2426),
    [anon_sym_Until] = ACTIONS(2426),
    [anon_sym_exit] = ACTIONS(2426),
    [anon_sym_EXIT] = ACTIONS(2426),
    [anon_sym_Exit] = ACTIONS(2426),
    [anon_sym_continue] = ACTIONS(2426),
    [anon_sym_CONTINUE] = ACTIONS(2426),
    [anon_sym_Continue] = ACTIONS(2426),
    [anon_sym_break] = ACTIONS(2426),
    [anon_sym_BREAK] = ACTIONS(2426),
    [anon_sym_Break] = ACTIONS(2426),
    [anon_sym_with] = ACTIONS(2426),
    [anon_sym_WITH] = ACTIONS(2426),
    [anon_sym_With] = ACTIONS(2426),
    [sym_asserterror_keyword] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_open] = ACTIONS(2428),
  },
  [STATE(1120)] = {
    [sym_preproc_conditional_object] = STATE(1121),
    [sym_using_statement] = STATE(1121),
    [sym__object] = STATE(1121),
    [sym_preproc_split_declaration] = STATE(1121),
    [sym_table_declaration] = STATE(1121),
    [sym_page_declaration] = STATE(1121),
    [sym_report_declaration] = STATE(1121),
    [sym_query_declaration] = STATE(1121),
    [sym_xmlport_declaration] = STATE(1121),
    [sym_permissionset_declaration] = STATE(1121),
    [sym_codeunit_declaration] = STATE(1121),
    [sym_enum_declaration] = STATE(1121),
    [sym_tableextension_declaration] = STATE(1121),
    [sym_pageextension_declaration] = STATE(1121),
    [sym_reportextension_declaration] = STATE(1121),
    [sym_enumextension_declaration] = STATE(1121),
    [sym_permissionsetextension_declaration] = STATE(1121),
    [sym_controladdin_declaration] = STATE(1121),
    [sym_profile_declaration] = STATE(1121),
    [sym_entitlement_declaration] = STATE(1121),
    [sym_profileextension_declaration] = STATE(1121),
    [sym_interface_declaration] = STATE(1121),
    [sym_pagecustomization_declaration] = STATE(1121),
    [sym_dotnet_declaration] = STATE(1121),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(2469),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(1121),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(1121)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(2461),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(1122)] = {
    [sym_preproc_conditional_object] = STATE(1096),
    [sym_using_statement] = STATE(1096),
    [sym__object] = STATE(1096),
    [sym_preproc_split_declaration] = STATE(1096),
    [sym_table_declaration] = STATE(1096),
    [sym_page_declaration] = STATE(1096),
    [sym_report_declaration] = STATE(1096),
    [sym_query_declaration] = STATE(1096),
    [sym_xmlport_declaration] = STATE(1096),
    [sym_permissionset_declaration] = STATE(1096),
    [sym_codeunit_declaration] = STATE(1096),
    [sym_enum_declaration] = STATE(1096),
    [sym_tableextension_declaration] = STATE(1096),
    [sym_pageextension_declaration] = STATE(1096),
    [sym_reportextension_declaration] = STATE(1096),
    [sym_enumextension_declaration] = STATE(1096),
    [sym_permissionsetextension_declaration] = STATE(1096),
    [sym_controladdin_declaration] = STATE(1096),
    [sym_profile_declaration] = STATE(1096),
    [sym_entitlement_declaration] = STATE(1096),
    [sym_profileextension_declaration] = STATE(1096),
    [sym_interface_declaration] = STATE(1096),
    [sym_pagecustomization_declaration] = STATE(1096),
    [sym_dotnet_declaration] = STATE(1096),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(2461),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(1096),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(1123)] = {
    [sym_preproc_conditional_object] = STATE(1103),
    [sym_using_statement] = STATE(1103),
    [sym__object] = STATE(1103),
    [sym_preproc_split_declaration] = STATE(1103),
    [sym_table_declaration] = STATE(1103),
    [sym_page_declaration] = STATE(1103),
    [sym_report_declaration] = STATE(1103),
    [sym_query_declaration] = STATE(1103),
    [sym_xmlport_declaration] = STATE(1103),
    [sym_permissionset_declaration] = STATE(1103),
    [sym_codeunit_declaration] = STATE(1103),
    [sym_enum_declaration] = STATE(1103),
    [sym_tableextension_declaration] = STATE(1103),
    [sym_pageextension_declaration] = STATE(1103),
    [sym_reportextension_declaration] = STATE(1103),
    [sym_enumextension_declaration] = STATE(1103),
    [sym_permissionsetextension_declaration] = STATE(1103),
    [sym_controladdin_declaration] = STATE(1103),
    [sym_profile_declaration] = STATE(1103),
    [sym_entitlement_declaration] = STATE(1103),
    [sym_profileextension_declaration] = STATE(1103),
    [sym_interface_declaration] = STATE(1103),
    [sym_pagecustomization_declaration] = STATE(1103),
    [sym_dotnet_declaration] = STATE(1103),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(1959),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(1103),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(1124)] = {
    [sym_preproc_conditional_object] = STATE(996),
    [sym_using_statement] = STATE(996),
    [sym__object] = STATE(996),
    [sym_preproc_split_declaration] = STATE(996),
    [sym_table_declaration] = STATE(996),
    [sym_page_declaration] = STATE(996),
    [sym_report_declaration] = STATE(996),
    [sym_query_declaration] = STATE(996),
    [sym_xmlport_declaration] = STATE(996),
    [sym_permissionset_declaration] = STATE(996),
    [sym_codeunit_declaration] = STATE(996),
    [sym_enum_declaration] = STATE(996),
    [sym_tableextension_declaration] = STATE(996),
    [sym_pageextension_declaration] = STATE(996),
    [sym_reportextension_declaration] = STATE(996),
    [sym_enumextension_declaration] = STATE(996),
    [sym_permissionsetextension_declaration] = STATE(996),
    [sym_controladdin_declaration] = STATE(996),
    [sym_profile_declaration] = STATE(996),
    [sym_entitlement_declaration] = STATE(996),
    [sym_profileextension_declaration] = STATE(996),
    [sym_interface_declaration] = STATE(996),
    [sym_pagecustomization_declaration] = STATE(996),
    [sym_dotnet_declaration] = STATE(996),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(1959),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(996),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(1125)] = {
    [sym_preproc_conditional_object] = STATE(1108),
    [sym_using_statement] = STATE(1108),
    [sym__object] = STATE(1108),
    [sym_preproc_split_declaration] = STATE(1108),
    [sym_table_declaration] = STATE(1108),
    [sym_page_declaration] = STATE(1108),
    [sym_report_declaration] = STATE(1108),
    [sym_query_declaration] = STATE(1108),
    [sym_xmlport_declaration] = STATE(1108),
    [sym_permissionset_declaration] = STATE(1108),
    [sym_codeunit_declaration] = STATE(1108),
    [sym_enum_declaration] = STATE(1108),
    [sym_tableextension_declaration] = STATE(1108),
    [sym_pageextension_declaration] = STATE(1108),
    [sym_reportextension_declaration] = STATE(1108),
    [sym_enumextension_declaration] = STATE(1108),
    [sym_permissionsetextension_declaration] = STATE(1108),
    [sym_controladdin_declaration] = STATE(1108),
    [sym_profile_declaration] = STATE(1108),
    [sym_entitlement_declaration] = STATE(1108),
    [sym_profileextension_declaration] = STATE(1108),
    [sym_interface_declaration] = STATE(1108),
    [sym_pagecustomization_declaration] = STATE(1108),
    [sym_dotnet_declaration] = STATE(1108),
    [sym_preproc_if] = STATE(616),
    [sym_preproc_endif] = STATE(1969),
    [sym_tableextension_keyword] = STATE(12523),
    [sym_pageextension_keyword] = STATE(12524),
    [sym_codeunit_keyword] = STATE(11894),
    [sym_reportextension_keyword] = STATE(12525),
    [sym_xmlport_keyword] = STATE(11895),
    [sym_enum_keyword] = STATE(11896),
    [sym_enumextension_keyword] = STATE(12526),
    [sym_controladdin_keyword] = STATE(8548),
    [sym_dotnet_keyword] = STATE(12555),
    [sym_profileextension_keyword] = STATE(8704),
    [sym_permissionset_keyword] = STATE(11897),
    [sym_permissionsetextension_keyword] = STATE(12527),
    [sym_pagecustomization_keyword] = STATE(8705),
    [aux_sym_source_file_repeat1] = STATE(1108),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1551),
    [anon_sym_POUNDENDIF] = ACTIONS(1551),
    [anon_sym_POUNDEndif] = ACTIONS(1551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2185),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(2187),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(2189),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(2191),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(2193),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1563),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1565),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1569),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1551),
  },
  [STATE(1126)] = {
    [sym_identifier] = ACTIONS(2434),
    [anon_sym_SEMI] = ACTIONS(2436),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_DASH] = ACTIONS(2434),
    [aux_sym_boolean_token1] = ACTIONS(2434),
    [aux_sym_boolean_token2] = ACTIONS(2434),
    [sym_decimal] = ACTIONS(2434),
    [anon_sym_LPAREN] = ACTIONS(2436),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2434),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [aux_sym_record_type_token1] = ACTIONS(2434),
    [aux_sym_basic_type_token21] = ACTIONS(2434),
    [aux_sym_basic_type_token22] = ACTIONS(2434),
    [aux_sym_basic_type_token48] = ACTIONS(2434),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2434),
    [anon_sym_COLON_COLON] = ACTIONS(2719),
    [anon_sym_POUNDif] = ACTIONS(2436),
    [anon_sym_POUNDIF] = ACTIONS(2436),
    [anon_sym_POUNDIf] = ACTIONS(2436),
    [anon_sym_not] = ACTIONS(2434),
    [anon_sym_NOT] = ACTIONS(2434),
    [anon_sym_Not] = ACTIONS(2434),
    [anon_sym_POUNDelse] = ACTIONS(2436),
    [anon_sym_POUNDELSE] = ACTIONS(2436),
    [anon_sym_POUNDElse] = ACTIONS(2436),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2434),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(2434),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(2436),
    [sym_date_literal] = ACTIONS(2434),
    [sym_time_literal] = ACTIONS(2434),
    [sym_biginteger_literal] = ACTIONS(2436),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_IF] = ACTIONS(2434),
    [anon_sym_If] = ACTIONS(2434),
    [anon_sym_else] = ACTIONS(2434),
    [anon_sym_ELSE] = ACTIONS(2434),
    [anon_sym_Else] = ACTIONS(2434),
    [anon_sym_case] = ACTIONS(2434),
    [anon_sym_CASE] = ACTIONS(2434),
    [anon_sym_Case] = ACTIONS(2434),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_FOR] = ACTIONS(2434),
    [anon_sym_For] = ACTIONS(2434),
    [anon_sym_foreach] = ACTIONS(2434),
    [anon_sym_FOREACH] = ACTIONS(2434),
    [anon_sym_Foreach] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(2434),
    [anon_sym_WHILE] = ACTIONS(2434),
    [anon_sym_While] = ACTIONS(2434),
    [anon_sym_repeat] = ACTIONS(2434),
    [anon_sym_REPEAT] = ACTIONS(2434),
    [anon_sym_Repeat] = ACTIONS(2434),
    [anon_sym_until] = ACTIONS(2434),
    [anon_sym_UNTIL] = ACTIONS(2434),
    [anon_sym_Until] = ACTIONS(2434),
    [anon_sym_exit] = ACTIONS(2434),
    [anon_sym_EXIT] = ACTIONS(2434),
    [anon_sym_Exit] = ACTIONS(2434),
    [anon_sym_continue] = ACTIONS(2434),
    [anon_sym_CONTINUE] = ACTIONS(2434),
    [anon_sym_Continue] = ACTIONS(2434),
    [anon_sym_break] = ACTIONS(2434),
    [anon_sym_BREAK] = ACTIONS(2434),
    [anon_sym_Break] = ACTIONS(2434),
    [anon_sym_with] = ACTIONS(2434),
    [anon_sym_WITH] = ACTIONS(2434),
    [anon_sym_With] = ACTIONS(2434),
    [sym_asserterror_keyword] = ACTIONS(2436),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(2434),
    [anon_sym_codeunit] = ACTIONS(2434),
    [anon_sym_CODEUNIT] = ACTIONS(2434),
    [anon_sym_Codeunit] = ACTIONS(2434),
    [anon_sym_CodeUnit] = ACTIONS(2434),
    [anon_sym_COdeunit] = ACTIONS(2434),
    [anon_sym_codeUnit] = ACTIONS(2434),
    [sym_report_keyword] = ACTIONS(2434),
    [sym_query_keyword] = ACTIONS(2434),
    [anon_sym_xmlport] = ACTIONS(2434),
    [anon_sym_XMLPORT] = ACTIONS(2434),
    [anon_sym_Xmlport] = ACTIONS(2434),
    [anon_sym_XMLport] = ACTIONS(2434),
    [anon_sym_XMLPort] = ACTIONS(2434),
    [anon_sym_XmlPort] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2434),
    [anon_sym_ENUM] = ACTIONS(2434),
    [anon_sym_Enum] = ACTIONS(2434),
    [anon_sym_eNUM] = ACTIONS(2434),
    [anon_sym_eNum] = ACTIONS(2434),
    [anon_sym_ENum] = ACTIONS(2434),
    [sym_quoted_identifier] = ACTIONS(2436),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2436),
    [sym_integer] = ACTIONS(2434),
    [sym_continue_as_identifier] = ACTIONS(2436),
    [sym_preproc_open] = ACTIONS(2436),
  },
  [STATE(1127)] = {
    [sym_identifier] = ACTIONS(2569),
    [anon_sym_SEMI] = ACTIONS(2571),
    [anon_sym_DOT] = ACTIONS(2569),
    [anon_sym_EQ] = ACTIONS(2571),
    [anon_sym_DASH] = ACTIONS(2569),
    [aux_sym_boolean_token1] = ACTIONS(2569),
    [aux_sym_boolean_token2] = ACTIONS(2569),
    [sym_decimal] = ACTIONS(2569),
    [anon_sym_LPAREN] = ACTIONS(2571),
    [anon_sym_DOT_DOT] = ACTIONS(2571),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2569),
    [anon_sym_STAR] = ACTIONS(2569),
    [anon_sym_LBRACK] = ACTIONS(2571),
    [aux_sym_record_type_token1] = ACTIONS(2569),
    [aux_sym_basic_type_token21] = ACTIONS(2569),
    [aux_sym_basic_type_token22] = ACTIONS(2569),
    [aux_sym_basic_type_token48] = ACTIONS(2569),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2569),
    [anon_sym_POUNDif] = ACTIONS(2571),
    [anon_sym_POUNDIF] = ACTIONS(2571),
    [anon_sym_POUNDIf] = ACTIONS(2571),
    [anon_sym_not] = ACTIONS(2569),
    [anon_sym_NOT] = ACTIONS(2569),
    [anon_sym_Not] = ACTIONS(2569),
    [anon_sym_POUNDelse] = ACTIONS(2571),
    [anon_sym_POUNDELSE] = ACTIONS(2571),
    [anon_sym_POUNDElse] = ACTIONS(2571),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2571),
    [aux_sym__expression_token1] = ACTIONS(2571),
    [aux_sym__expression_token2] = ACTIONS(2569),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2569),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2569),
    [anon_sym_SLASH] = ACTIONS(2569),
    [anon_sym_div] = ACTIONS(2569),
    [anon_sym_DIV] = ACTIONS(2569),
    [anon_sym_Div] = ACTIONS(2569),
    [anon_sym_mod] = ACTIONS(2569),
    [anon_sym_MOD] = ACTIONS(2569),
    [anon_sym_Mod] = ACTIONS(2569),
    [anon_sym_PLUS] = ACTIONS(2569),
    [anon_sym_GT_EQ] = ACTIONS(2571),
    [anon_sym_LT_EQ] = ACTIONS(2571),
    [anon_sym_GT] = ACTIONS(2569),
    [anon_sym_LT] = ACTIONS(2569),
    [anon_sym_LT_GT] = ACTIONS(2571),
    [anon_sym_and] = ACTIONS(2569),
    [anon_sym_AND] = ACTIONS(2569),
    [anon_sym_And] = ACTIONS(2569),
    [anon_sym_or] = ACTIONS(2569),
    [anon_sym_OR] = ACTIONS(2569),
    [anon_sym_Or] = ACTIONS(2569),
    [anon_sym_xor] = ACTIONS(2569),
    [anon_sym_XOR] = ACTIONS(2569),
    [anon_sym_Xor] = ACTIONS(2569),
    [anon_sym_QMARK] = ACTIONS(2571),
    [sym_datetime_literal] = ACTIONS(2571),
    [sym_date_literal] = ACTIONS(2569),
    [sym_time_literal] = ACTIONS(2569),
    [sym_biginteger_literal] = ACTIONS(2571),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_IF] = ACTIONS(2569),
    [anon_sym_If] = ACTIONS(2569),
    [anon_sym_else] = ACTIONS(2569),
    [anon_sym_ELSE] = ACTIONS(2569),
    [anon_sym_Else] = ACTIONS(2569),
    [anon_sym_case] = ACTIONS(2569),
    [anon_sym_CASE] = ACTIONS(2569),
    [anon_sym_Case] = ACTIONS(2569),
    [anon_sym_for] = ACTIONS(2569),
    [anon_sym_FOR] = ACTIONS(2569),
    [anon_sym_For] = ACTIONS(2569),
    [anon_sym_foreach] = ACTIONS(2569),
    [anon_sym_FOREACH] = ACTIONS(2569),
    [anon_sym_Foreach] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2569),
    [anon_sym_WHILE] = ACTIONS(2569),
    [anon_sym_While] = ACTIONS(2569),
    [anon_sym_repeat] = ACTIONS(2569),
    [anon_sym_REPEAT] = ACTIONS(2569),
    [anon_sym_Repeat] = ACTIONS(2569),
    [anon_sym_until] = ACTIONS(2569),
    [anon_sym_UNTIL] = ACTIONS(2569),
    [anon_sym_Until] = ACTIONS(2569),
    [anon_sym_exit] = ACTIONS(2569),
    [anon_sym_EXIT] = ACTIONS(2569),
    [anon_sym_Exit] = ACTIONS(2569),
    [anon_sym_continue] = ACTIONS(2569),
    [anon_sym_CONTINUE] = ACTIONS(2569),
    [anon_sym_Continue] = ACTIONS(2569),
    [anon_sym_break] = ACTIONS(2569),
    [anon_sym_BREAK] = ACTIONS(2569),
    [anon_sym_Break] = ACTIONS(2569),
    [anon_sym_with] = ACTIONS(2569),
    [anon_sym_WITH] = ACTIONS(2569),
    [anon_sym_With] = ACTIONS(2569),
    [sym_asserterror_keyword] = ACTIONS(2571),
    [anon_sym_in] = ACTIONS(2569),
    [anon_sym_IN] = ACTIONS(2569),
    [anon_sym_In] = ACTIONS(2569),
    [sym_page_keyword] = ACTIONS(2569),
    [anon_sym_codeunit] = ACTIONS(2569),
    [anon_sym_CODEUNIT] = ACTIONS(2569),
    [anon_sym_Codeunit] = ACTIONS(2569),
    [anon_sym_CodeUnit] = ACTIONS(2569),
    [anon_sym_COdeunit] = ACTIONS(2569),
    [anon_sym_codeUnit] = ACTIONS(2569),
    [sym_report_keyword] = ACTIONS(2569),
    [sym_query_keyword] = ACTIONS(2569),
    [anon_sym_xmlport] = ACTIONS(2569),
    [anon_sym_XMLPORT] = ACTIONS(2569),
    [anon_sym_Xmlport] = ACTIONS(2569),
    [anon_sym_XMLport] = ACTIONS(2569),
    [anon_sym_XMLPort] = ACTIONS(2569),
    [anon_sym_XmlPort] = ACTIONS(2569),
    [anon_sym_enum] = ACTIONS(2569),
    [anon_sym_ENUM] = ACTIONS(2569),
    [anon_sym_Enum] = ACTIONS(2569),
    [anon_sym_eNUM] = ACTIONS(2569),
    [anon_sym_eNum] = ACTIONS(2569),
    [anon_sym_ENum] = ACTIONS(2569),
    [sym_quoted_identifier] = ACTIONS(2571),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2571),
    [sym_integer] = ACTIONS(2569),
    [sym_continue_as_identifier] = ACTIONS(2571),
    [sym_preproc_open] = ACTIONS(2571),
  },
  [STATE(1128)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2585),
    [anon_sym_POUNDif] = ACTIONS(2587),
    [anon_sym_POUNDIF] = ACTIONS(2587),
    [anon_sym_POUNDIf] = ACTIONS(2587),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [anon_sym_POUNDelse] = ACTIONS(2587),
    [anon_sym_POUNDELSE] = ACTIONS(2587),
    [anon_sym_POUNDElse] = ACTIONS(2587),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_IF] = ACTIONS(2585),
    [anon_sym_If] = ACTIONS(2585),
    [anon_sym_else] = ACTIONS(2585),
    [anon_sym_ELSE] = ACTIONS(2585),
    [anon_sym_Else] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_CASE] = ACTIONS(2585),
    [anon_sym_Case] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_FOR] = ACTIONS(2585),
    [anon_sym_For] = ACTIONS(2585),
    [anon_sym_foreach] = ACTIONS(2585),
    [anon_sym_FOREACH] = ACTIONS(2585),
    [anon_sym_Foreach] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_WHILE] = ACTIONS(2585),
    [anon_sym_While] = ACTIONS(2585),
    [anon_sym_repeat] = ACTIONS(2585),
    [anon_sym_REPEAT] = ACTIONS(2585),
    [anon_sym_Repeat] = ACTIONS(2585),
    [anon_sym_until] = ACTIONS(2585),
    [anon_sym_UNTIL] = ACTIONS(2585),
    [anon_sym_Until] = ACTIONS(2585),
    [anon_sym_exit] = ACTIONS(2585),
    [anon_sym_EXIT] = ACTIONS(2585),
    [anon_sym_Exit] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_CONTINUE] = ACTIONS(2585),
    [anon_sym_Continue] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_BREAK] = ACTIONS(2585),
    [anon_sym_Break] = ACTIONS(2585),
    [anon_sym_with] = ACTIONS(2585),
    [anon_sym_WITH] = ACTIONS(2585),
    [anon_sym_With] = ACTIONS(2585),
    [sym_asserterror_keyword] = ACTIONS(2587),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_open] = ACTIONS(2587),
  },
  [STATE(1129)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_SEMI] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2593),
    [anon_sym_POUNDif] = ACTIONS(2595),
    [anon_sym_POUNDIF] = ACTIONS(2595),
    [anon_sym_POUNDIf] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [anon_sym_POUNDelse] = ACTIONS(2595),
    [anon_sym_POUNDELSE] = ACTIONS(2595),
    [anon_sym_POUNDElse] = ACTIONS(2595),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_if] = ACTIONS(2593),
    [anon_sym_IF] = ACTIONS(2593),
    [anon_sym_If] = ACTIONS(2593),
    [anon_sym_else] = ACTIONS(2593),
    [anon_sym_ELSE] = ACTIONS(2593),
    [anon_sym_Else] = ACTIONS(2593),
    [anon_sym_case] = ACTIONS(2593),
    [anon_sym_CASE] = ACTIONS(2593),
    [anon_sym_Case] = ACTIONS(2593),
    [anon_sym_for] = ACTIONS(2593),
    [anon_sym_FOR] = ACTIONS(2593),
    [anon_sym_For] = ACTIONS(2593),
    [anon_sym_foreach] = ACTIONS(2593),
    [anon_sym_FOREACH] = ACTIONS(2593),
    [anon_sym_Foreach] = ACTIONS(2593),
    [anon_sym_while] = ACTIONS(2593),
    [anon_sym_WHILE] = ACTIONS(2593),
    [anon_sym_While] = ACTIONS(2593),
    [anon_sym_repeat] = ACTIONS(2593),
    [anon_sym_REPEAT] = ACTIONS(2593),
    [anon_sym_Repeat] = ACTIONS(2593),
    [anon_sym_until] = ACTIONS(2593),
    [anon_sym_UNTIL] = ACTIONS(2593),
    [anon_sym_Until] = ACTIONS(2593),
    [anon_sym_exit] = ACTIONS(2593),
    [anon_sym_EXIT] = ACTIONS(2593),
    [anon_sym_Exit] = ACTIONS(2593),
    [anon_sym_continue] = ACTIONS(2593),
    [anon_sym_CONTINUE] = ACTIONS(2593),
    [anon_sym_Continue] = ACTIONS(2593),
    [anon_sym_break] = ACTIONS(2593),
    [anon_sym_BREAK] = ACTIONS(2593),
    [anon_sym_Break] = ACTIONS(2593),
    [anon_sym_with] = ACTIONS(2593),
    [anon_sym_WITH] = ACTIONS(2593),
    [anon_sym_With] = ACTIONS(2593),
    [sym_asserterror_keyword] = ACTIONS(2595),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_open] = ACTIONS(2595),
  },
  [STATE(1130)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_SEMI] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2593),
    [anon_sym_POUNDif] = ACTIONS(2595),
    [anon_sym_POUNDIF] = ACTIONS(2595),
    [anon_sym_POUNDIf] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [anon_sym_POUNDelse] = ACTIONS(2595),
    [anon_sym_POUNDELSE] = ACTIONS(2595),
    [anon_sym_POUNDElse] = ACTIONS(2595),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_if] = ACTIONS(2593),
    [anon_sym_IF] = ACTIONS(2593),
    [anon_sym_If] = ACTIONS(2593),
    [anon_sym_else] = ACTIONS(2593),
    [anon_sym_ELSE] = ACTIONS(2593),
    [anon_sym_Else] = ACTIONS(2593),
    [anon_sym_case] = ACTIONS(2593),
    [anon_sym_CASE] = ACTIONS(2593),
    [anon_sym_Case] = ACTIONS(2593),
    [anon_sym_for] = ACTIONS(2593),
    [anon_sym_FOR] = ACTIONS(2593),
    [anon_sym_For] = ACTIONS(2593),
    [anon_sym_foreach] = ACTIONS(2593),
    [anon_sym_FOREACH] = ACTIONS(2593),
    [anon_sym_Foreach] = ACTIONS(2593),
    [anon_sym_while] = ACTIONS(2593),
    [anon_sym_WHILE] = ACTIONS(2593),
    [anon_sym_While] = ACTIONS(2593),
    [anon_sym_repeat] = ACTIONS(2593),
    [anon_sym_REPEAT] = ACTIONS(2593),
    [anon_sym_Repeat] = ACTIONS(2593),
    [anon_sym_until] = ACTIONS(2593),
    [anon_sym_UNTIL] = ACTIONS(2593),
    [anon_sym_Until] = ACTIONS(2593),
    [anon_sym_exit] = ACTIONS(2593),
    [anon_sym_EXIT] = ACTIONS(2593),
    [anon_sym_Exit] = ACTIONS(2593),
    [anon_sym_continue] = ACTIONS(2593),
    [anon_sym_CONTINUE] = ACTIONS(2593),
    [anon_sym_Continue] = ACTIONS(2593),
    [anon_sym_break] = ACTIONS(2593),
    [anon_sym_BREAK] = ACTIONS(2593),
    [anon_sym_Break] = ACTIONS(2593),
    [anon_sym_with] = ACTIONS(2593),
    [anon_sym_WITH] = ACTIONS(2593),
    [anon_sym_With] = ACTIONS(2593),
    [sym_asserterror_keyword] = ACTIONS(2595),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_open] = ACTIONS(2595),
  },
  [STATE(1131)] = {
    [sym_identifier] = ACTIONS(2613),
    [anon_sym_SEMI] = ACTIONS(2615),
    [anon_sym_DOT] = ACTIONS(2613),
    [anon_sym_EQ] = ACTIONS(2615),
    [anon_sym_DASH] = ACTIONS(2613),
    [aux_sym_boolean_token1] = ACTIONS(2613),
    [aux_sym_boolean_token2] = ACTIONS(2613),
    [sym_decimal] = ACTIONS(2613),
    [anon_sym_LPAREN] = ACTIONS(2615),
    [anon_sym_DOT_DOT] = ACTIONS(2615),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2613),
    [anon_sym_STAR] = ACTIONS(2613),
    [anon_sym_LBRACK] = ACTIONS(2725),
    [aux_sym_record_type_token1] = ACTIONS(2613),
    [aux_sym_basic_type_token21] = ACTIONS(2613),
    [aux_sym_basic_type_token22] = ACTIONS(2613),
    [aux_sym_basic_type_token48] = ACTIONS(2613),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2613),
    [anon_sym_POUNDif] = ACTIONS(2615),
    [anon_sym_POUNDIF] = ACTIONS(2615),
    [anon_sym_POUNDIf] = ACTIONS(2615),
    [anon_sym_not] = ACTIONS(2613),
    [anon_sym_NOT] = ACTIONS(2613),
    [anon_sym_Not] = ACTIONS(2613),
    [anon_sym_POUNDelse] = ACTIONS(2615),
    [anon_sym_POUNDELSE] = ACTIONS(2615),
    [anon_sym_POUNDElse] = ACTIONS(2615),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2615),
    [aux_sym__expression_token1] = ACTIONS(2615),
    [aux_sym__expression_token2] = ACTIONS(2613),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2613),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2613),
    [anon_sym_SLASH] = ACTIONS(2613),
    [anon_sym_div] = ACTIONS(2613),
    [anon_sym_DIV] = ACTIONS(2613),
    [anon_sym_Div] = ACTIONS(2613),
    [anon_sym_mod] = ACTIONS(2613),
    [anon_sym_MOD] = ACTIONS(2613),
    [anon_sym_Mod] = ACTIONS(2613),
    [anon_sym_PLUS] = ACTIONS(2613),
    [anon_sym_GT_EQ] = ACTIONS(2615),
    [anon_sym_LT_EQ] = ACTIONS(2615),
    [anon_sym_GT] = ACTIONS(2613),
    [anon_sym_LT] = ACTIONS(2613),
    [anon_sym_LT_GT] = ACTIONS(2615),
    [anon_sym_and] = ACTIONS(2613),
    [anon_sym_AND] = ACTIONS(2613),
    [anon_sym_And] = ACTIONS(2613),
    [anon_sym_or] = ACTIONS(2613),
    [anon_sym_OR] = ACTIONS(2613),
    [anon_sym_Or] = ACTIONS(2613),
    [anon_sym_xor] = ACTIONS(2613),
    [anon_sym_XOR] = ACTIONS(2613),
    [anon_sym_Xor] = ACTIONS(2613),
    [anon_sym_QMARK] = ACTIONS(2615),
    [sym_datetime_literal] = ACTIONS(2615),
    [sym_date_literal] = ACTIONS(2613),
    [sym_time_literal] = ACTIONS(2613),
    [sym_biginteger_literal] = ACTIONS(2615),
    [anon_sym_if] = ACTIONS(2613),
    [anon_sym_IF] = ACTIONS(2613),
    [anon_sym_If] = ACTIONS(2613),
    [anon_sym_else] = ACTIONS(2613),
    [anon_sym_ELSE] = ACTIONS(2613),
    [anon_sym_Else] = ACTIONS(2613),
    [anon_sym_case] = ACTIONS(2613),
    [anon_sym_CASE] = ACTIONS(2613),
    [anon_sym_Case] = ACTIONS(2613),
    [anon_sym_for] = ACTIONS(2613),
    [anon_sym_FOR] = ACTIONS(2613),
    [anon_sym_For] = ACTIONS(2613),
    [anon_sym_foreach] = ACTIONS(2613),
    [anon_sym_FOREACH] = ACTIONS(2613),
    [anon_sym_Foreach] = ACTIONS(2613),
    [anon_sym_while] = ACTIONS(2613),
    [anon_sym_WHILE] = ACTIONS(2613),
    [anon_sym_While] = ACTIONS(2613),
    [anon_sym_repeat] = ACTIONS(2613),
    [anon_sym_REPEAT] = ACTIONS(2613),
    [anon_sym_Repeat] = ACTIONS(2613),
    [anon_sym_until] = ACTIONS(2613),
    [anon_sym_UNTIL] = ACTIONS(2613),
    [anon_sym_Until] = ACTIONS(2613),
    [anon_sym_exit] = ACTIONS(2613),
    [anon_sym_EXIT] = ACTIONS(2613),
    [anon_sym_Exit] = ACTIONS(2613),
    [anon_sym_continue] = ACTIONS(2613),
    [anon_sym_CONTINUE] = ACTIONS(2613),
    [anon_sym_Continue] = ACTIONS(2613),
    [anon_sym_break] = ACTIONS(2613),
    [anon_sym_BREAK] = ACTIONS(2613),
    [anon_sym_Break] = ACTIONS(2613),
    [anon_sym_with] = ACTIONS(2613),
    [anon_sym_WITH] = ACTIONS(2613),
    [anon_sym_With] = ACTIONS(2613),
    [sym_asserterror_keyword] = ACTIONS(2615),
    [anon_sym_in] = ACTIONS(2613),
    [anon_sym_IN] = ACTIONS(2613),
    [anon_sym_In] = ACTIONS(2613),
    [sym_page_keyword] = ACTIONS(2613),
    [anon_sym_codeunit] = ACTIONS(2613),
    [anon_sym_CODEUNIT] = ACTIONS(2613),
    [anon_sym_Codeunit] = ACTIONS(2613),
    [anon_sym_CodeUnit] = ACTIONS(2613),
    [anon_sym_COdeunit] = ACTIONS(2613),
    [anon_sym_codeUnit] = ACTIONS(2613),
    [sym_report_keyword] = ACTIONS(2613),
    [sym_query_keyword] = ACTIONS(2613),
    [anon_sym_xmlport] = ACTIONS(2613),
    [anon_sym_XMLPORT] = ACTIONS(2613),
    [anon_sym_Xmlport] = ACTIONS(2613),
    [anon_sym_XMLport] = ACTIONS(2613),
    [anon_sym_XMLPort] = ACTIONS(2613),
    [anon_sym_XmlPort] = ACTIONS(2613),
    [anon_sym_enum] = ACTIONS(2613),
    [anon_sym_ENUM] = ACTIONS(2613),
    [anon_sym_Enum] = ACTIONS(2613),
    [anon_sym_eNUM] = ACTIONS(2613),
    [anon_sym_eNum] = ACTIONS(2613),
    [anon_sym_ENum] = ACTIONS(2613),
    [sym_quoted_identifier] = ACTIONS(2615),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2615),
    [sym_integer] = ACTIONS(2613),
    [sym_continue_as_identifier] = ACTIONS(2615),
    [sym_preproc_open] = ACTIONS(2615),
  },
  [STATE(1132)] = {
    [sym_identifier] = ACTIONS(2637),
    [anon_sym_SEMI] = ACTIONS(2639),
    [anon_sym_DOT] = ACTIONS(2637),
    [anon_sym_EQ] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [aux_sym_boolean_token1] = ACTIONS(2637),
    [aux_sym_boolean_token2] = ACTIONS(2637),
    [sym_decimal] = ACTIONS(2637),
    [anon_sym_LPAREN] = ACTIONS(2639),
    [anon_sym_DOT_DOT] = ACTIONS(2639),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(2637),
    [anon_sym_LBRACK] = ACTIONS(2639),
    [aux_sym_record_type_token1] = ACTIONS(2637),
    [aux_sym_basic_type_token21] = ACTIONS(2637),
    [aux_sym_basic_type_token22] = ACTIONS(2637),
    [aux_sym_basic_type_token48] = ACTIONS(2637),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2637),
    [anon_sym_POUNDif] = ACTIONS(2639),
    [anon_sym_POUNDIF] = ACTIONS(2639),
    [anon_sym_POUNDIf] = ACTIONS(2639),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_NOT] = ACTIONS(2637),
    [anon_sym_Not] = ACTIONS(2637),
    [anon_sym_POUNDelse] = ACTIONS(2639),
    [anon_sym_POUNDELSE] = ACTIONS(2639),
    [anon_sym_POUNDElse] = ACTIONS(2639),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2639),
    [aux_sym__expression_token1] = ACTIONS(2639),
    [aux_sym__expression_token2] = ACTIONS(2637),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2637),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2637),
    [anon_sym_SLASH] = ACTIONS(2637),
    [anon_sym_div] = ACTIONS(2637),
    [anon_sym_DIV] = ACTIONS(2637),
    [anon_sym_Div] = ACTIONS(2637),
    [anon_sym_mod] = ACTIONS(2637),
    [anon_sym_MOD] = ACTIONS(2637),
    [anon_sym_Mod] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_GT_EQ] = ACTIONS(2639),
    [anon_sym_LT_EQ] = ACTIONS(2639),
    [anon_sym_GT] = ACTIONS(2637),
    [anon_sym_LT] = ACTIONS(2637),
    [anon_sym_LT_GT] = ACTIONS(2639),
    [anon_sym_and] = ACTIONS(2637),
    [anon_sym_AND] = ACTIONS(2637),
    [anon_sym_And] = ACTIONS(2637),
    [anon_sym_or] = ACTIONS(2637),
    [anon_sym_OR] = ACTIONS(2637),
    [anon_sym_Or] = ACTIONS(2637),
    [anon_sym_xor] = ACTIONS(2637),
    [anon_sym_XOR] = ACTIONS(2637),
    [anon_sym_Xor] = ACTIONS(2637),
    [anon_sym_QMARK] = ACTIONS(2639),
    [sym_datetime_literal] = ACTIONS(2639),
    [sym_date_literal] = ACTIONS(2637),
    [sym_time_literal] = ACTIONS(2637),
    [sym_biginteger_literal] = ACTIONS(2639),
    [anon_sym_if] = ACTIONS(2637),
    [anon_sym_IF] = ACTIONS(2637),
    [anon_sym_If] = ACTIONS(2637),
    [anon_sym_else] = ACTIONS(2637),
    [anon_sym_ELSE] = ACTIONS(2637),
    [anon_sym_Else] = ACTIONS(2637),
    [anon_sym_case] = ACTIONS(2637),
    [anon_sym_CASE] = ACTIONS(2637),
    [anon_sym_Case] = ACTIONS(2637),
    [anon_sym_for] = ACTIONS(2637),
    [anon_sym_FOR] = ACTIONS(2637),
    [anon_sym_For] = ACTIONS(2637),
    [anon_sym_foreach] = ACTIONS(2637),
    [anon_sym_FOREACH] = ACTIONS(2637),
    [anon_sym_Foreach] = ACTIONS(2637),
    [anon_sym_while] = ACTIONS(2637),
    [anon_sym_WHILE] = ACTIONS(2637),
    [anon_sym_While] = ACTIONS(2637),
    [anon_sym_repeat] = ACTIONS(2637),
    [anon_sym_REPEAT] = ACTIONS(2637),
    [anon_sym_Repeat] = ACTIONS(2637),
    [anon_sym_until] = ACTIONS(2637),
    [anon_sym_UNTIL] = ACTIONS(2637),
    [anon_sym_Until] = ACTIONS(2637),
    [anon_sym_exit] = ACTIONS(2637),
    [anon_sym_EXIT] = ACTIONS(2637),
    [anon_sym_Exit] = ACTIONS(2637),
    [anon_sym_continue] = ACTIONS(2637),
    [anon_sym_CONTINUE] = ACTIONS(2637),
    [anon_sym_Continue] = ACTIONS(2637),
    [anon_sym_break] = ACTIONS(2637),
    [anon_sym_BREAK] = ACTIONS(2637),
    [anon_sym_Break] = ACTIONS(2637),
    [anon_sym_with] = ACTIONS(2637),
    [anon_sym_WITH] = ACTIONS(2637),
    [anon_sym_With] = ACTIONS(2637),
    [sym_asserterror_keyword] = ACTIONS(2639),
    [anon_sym_in] = ACTIONS(2637),
    [anon_sym_IN] = ACTIONS(2637),
    [anon_sym_In] = ACTIONS(2637),
    [sym_page_keyword] = ACTIONS(2637),
    [anon_sym_codeunit] = ACTIONS(2637),
    [anon_sym_CODEUNIT] = ACTIONS(2637),
    [anon_sym_Codeunit] = ACTIONS(2637),
    [anon_sym_CodeUnit] = ACTIONS(2637),
    [anon_sym_COdeunit] = ACTIONS(2637),
    [anon_sym_codeUnit] = ACTIONS(2637),
    [sym_report_keyword] = ACTIONS(2637),
    [sym_query_keyword] = ACTIONS(2637),
    [anon_sym_xmlport] = ACTIONS(2637),
    [anon_sym_XMLPORT] = ACTIONS(2637),
    [anon_sym_Xmlport] = ACTIONS(2637),
    [anon_sym_XMLport] = ACTIONS(2637),
    [anon_sym_XMLPort] = ACTIONS(2637),
    [anon_sym_XmlPort] = ACTIONS(2637),
    [anon_sym_enum] = ACTIONS(2637),
    [anon_sym_ENUM] = ACTIONS(2637),
    [anon_sym_Enum] = ACTIONS(2637),
    [anon_sym_eNUM] = ACTIONS(2637),
    [anon_sym_eNum] = ACTIONS(2637),
    [anon_sym_ENum] = ACTIONS(2637),
    [sym_quoted_identifier] = ACTIONS(2639),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2639),
    [sym_integer] = ACTIONS(2637),
    [sym_continue_as_identifier] = ACTIONS(2639),
    [sym_preproc_open] = ACTIONS(2639),
  },
  [STATE(1133)] = {
    [sym_identifier] = ACTIONS(2605),
    [anon_sym_SEMI] = ACTIONS(2607),
    [anon_sym_DOT] = ACTIONS(2605),
    [anon_sym_EQ] = ACTIONS(2607),
    [anon_sym_DASH] = ACTIONS(2605),
    [aux_sym_boolean_token1] = ACTIONS(2605),
    [aux_sym_boolean_token2] = ACTIONS(2605),
    [sym_decimal] = ACTIONS(2605),
    [anon_sym_LPAREN] = ACTIONS(2607),
    [anon_sym_DOT_DOT] = ACTIONS(2607),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2605),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_LBRACK] = ACTIONS(2607),
    [aux_sym_record_type_token1] = ACTIONS(2605),
    [aux_sym_basic_type_token21] = ACTIONS(2605),
    [aux_sym_basic_type_token22] = ACTIONS(2605),
    [aux_sym_basic_type_token48] = ACTIONS(2605),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2605),
    [anon_sym_POUNDif] = ACTIONS(2607),
    [anon_sym_POUNDIF] = ACTIONS(2607),
    [anon_sym_POUNDIf] = ACTIONS(2607),
    [anon_sym_not] = ACTIONS(2605),
    [anon_sym_NOT] = ACTIONS(2605),
    [anon_sym_Not] = ACTIONS(2605),
    [anon_sym_POUNDelse] = ACTIONS(2607),
    [anon_sym_POUNDELSE] = ACTIONS(2607),
    [anon_sym_POUNDElse] = ACTIONS(2607),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2607),
    [aux_sym__expression_token1] = ACTIONS(2607),
    [aux_sym__expression_token2] = ACTIONS(2605),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2605),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2605),
    [anon_sym_SLASH] = ACTIONS(2605),
    [anon_sym_div] = ACTIONS(2605),
    [anon_sym_DIV] = ACTIONS(2605),
    [anon_sym_Div] = ACTIONS(2605),
    [anon_sym_mod] = ACTIONS(2605),
    [anon_sym_MOD] = ACTIONS(2605),
    [anon_sym_Mod] = ACTIONS(2605),
    [anon_sym_PLUS] = ACTIONS(2605),
    [anon_sym_GT_EQ] = ACTIONS(2607),
    [anon_sym_LT_EQ] = ACTIONS(2607),
    [anon_sym_GT] = ACTIONS(2605),
    [anon_sym_LT] = ACTIONS(2605),
    [anon_sym_LT_GT] = ACTIONS(2607),
    [anon_sym_and] = ACTIONS(2605),
    [anon_sym_AND] = ACTIONS(2605),
    [anon_sym_And] = ACTIONS(2605),
    [anon_sym_or] = ACTIONS(2605),
    [anon_sym_OR] = ACTIONS(2605),
    [anon_sym_Or] = ACTIONS(2605),
    [anon_sym_xor] = ACTIONS(2605),
    [anon_sym_XOR] = ACTIONS(2605),
    [anon_sym_Xor] = ACTIONS(2605),
    [anon_sym_QMARK] = ACTIONS(2607),
    [sym_datetime_literal] = ACTIONS(2607),
    [sym_date_literal] = ACTIONS(2605),
    [sym_time_literal] = ACTIONS(2605),
    [sym_biginteger_literal] = ACTIONS(2607),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_IF] = ACTIONS(2605),
    [anon_sym_If] = ACTIONS(2605),
    [anon_sym_else] = ACTIONS(2605),
    [anon_sym_ELSE] = ACTIONS(2605),
    [anon_sym_Else] = ACTIONS(2605),
    [anon_sym_case] = ACTIONS(2605),
    [anon_sym_CASE] = ACTIONS(2605),
    [anon_sym_Case] = ACTIONS(2605),
    [anon_sym_for] = ACTIONS(2605),
    [anon_sym_FOR] = ACTIONS(2605),
    [anon_sym_For] = ACTIONS(2605),
    [anon_sym_foreach] = ACTIONS(2605),
    [anon_sym_FOREACH] = ACTIONS(2605),
    [anon_sym_Foreach] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(2605),
    [anon_sym_WHILE] = ACTIONS(2605),
    [anon_sym_While] = ACTIONS(2605),
    [anon_sym_repeat] = ACTIONS(2605),
    [anon_sym_REPEAT] = ACTIONS(2605),
    [anon_sym_Repeat] = ACTIONS(2605),
    [anon_sym_until] = ACTIONS(2605),
    [anon_sym_UNTIL] = ACTIONS(2605),
    [anon_sym_Until] = ACTIONS(2605),
    [anon_sym_exit] = ACTIONS(2605),
    [anon_sym_EXIT] = ACTIONS(2605),
    [anon_sym_Exit] = ACTIONS(2605),
    [anon_sym_continue] = ACTIONS(2605),
    [anon_sym_CONTINUE] = ACTIONS(2605),
    [anon_sym_Continue] = ACTIONS(2605),
    [anon_sym_break] = ACTIONS(2605),
    [anon_sym_BREAK] = ACTIONS(2605),
    [anon_sym_Break] = ACTIONS(2605),
    [anon_sym_with] = ACTIONS(2605),
    [anon_sym_WITH] = ACTIONS(2605),
    [anon_sym_With] = ACTIONS(2605),
    [sym_asserterror_keyword] = ACTIONS(2607),
    [anon_sym_in] = ACTIONS(2605),
    [anon_sym_IN] = ACTIONS(2605),
    [anon_sym_In] = ACTIONS(2605),
    [sym_page_keyword] = ACTIONS(2605),
    [anon_sym_codeunit] = ACTIONS(2605),
    [anon_sym_CODEUNIT] = ACTIONS(2605),
    [anon_sym_Codeunit] = ACTIONS(2605),
    [anon_sym_CodeUnit] = ACTIONS(2605),
    [anon_sym_COdeunit] = ACTIONS(2605),
    [anon_sym_codeUnit] = ACTIONS(2605),
    [sym_report_keyword] = ACTIONS(2605),
    [sym_query_keyword] = ACTIONS(2605),
    [anon_sym_xmlport] = ACTIONS(2605),
    [anon_sym_XMLPORT] = ACTIONS(2605),
    [anon_sym_Xmlport] = ACTIONS(2605),
    [anon_sym_XMLport] = ACTIONS(2605),
    [anon_sym_XMLPort] = ACTIONS(2605),
    [anon_sym_XmlPort] = ACTIONS(2605),
    [anon_sym_enum] = ACTIONS(2605),
    [anon_sym_ENUM] = ACTIONS(2605),
    [anon_sym_Enum] = ACTIONS(2605),
    [anon_sym_eNUM] = ACTIONS(2605),
    [anon_sym_eNum] = ACTIONS(2605),
    [anon_sym_ENum] = ACTIONS(2605),
    [sym_quoted_identifier] = ACTIONS(2607),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2607),
    [sym_integer] = ACTIONS(2605),
    [sym_continue_as_identifier] = ACTIONS(2607),
    [sym_preproc_open] = ACTIONS(2607),
  },
  [STATE(1134)] = {
    [sym_identifier] = ACTIONS(2597),
    [anon_sym_SEMI] = ACTIONS(2599),
    [anon_sym_DOT] = ACTIONS(2597),
    [anon_sym_EQ] = ACTIONS(2599),
    [anon_sym_DASH] = ACTIONS(2597),
    [aux_sym_boolean_token1] = ACTIONS(2597),
    [aux_sym_boolean_token2] = ACTIONS(2597),
    [sym_decimal] = ACTIONS(2597),
    [anon_sym_LPAREN] = ACTIONS(2599),
    [anon_sym_DOT_DOT] = ACTIONS(2599),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2597),
    [anon_sym_STAR] = ACTIONS(2597),
    [anon_sym_LBRACK] = ACTIONS(2599),
    [aux_sym_record_type_token1] = ACTIONS(2597),
    [aux_sym_basic_type_token21] = ACTIONS(2597),
    [aux_sym_basic_type_token22] = ACTIONS(2597),
    [aux_sym_basic_type_token48] = ACTIONS(2597),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2597),
    [anon_sym_POUNDif] = ACTIONS(2599),
    [anon_sym_POUNDIF] = ACTIONS(2599),
    [anon_sym_POUNDIf] = ACTIONS(2599),
    [anon_sym_not] = ACTIONS(2597),
    [anon_sym_NOT] = ACTIONS(2597),
    [anon_sym_Not] = ACTIONS(2597),
    [anon_sym_POUNDelse] = ACTIONS(2599),
    [anon_sym_POUNDELSE] = ACTIONS(2599),
    [anon_sym_POUNDElse] = ACTIONS(2599),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2599),
    [aux_sym__expression_token1] = ACTIONS(2599),
    [aux_sym__expression_token2] = ACTIONS(2597),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2597),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2597),
    [anon_sym_SLASH] = ACTIONS(2597),
    [anon_sym_div] = ACTIONS(2597),
    [anon_sym_DIV] = ACTIONS(2597),
    [anon_sym_Div] = ACTIONS(2597),
    [anon_sym_mod] = ACTIONS(2597),
    [anon_sym_MOD] = ACTIONS(2597),
    [anon_sym_Mod] = ACTIONS(2597),
    [anon_sym_PLUS] = ACTIONS(2597),
    [anon_sym_GT_EQ] = ACTIONS(2599),
    [anon_sym_LT_EQ] = ACTIONS(2599),
    [anon_sym_GT] = ACTIONS(2597),
    [anon_sym_LT] = ACTIONS(2597),
    [anon_sym_LT_GT] = ACTIONS(2599),
    [anon_sym_and] = ACTIONS(2597),
    [anon_sym_AND] = ACTIONS(2597),
    [anon_sym_And] = ACTIONS(2597),
    [anon_sym_or] = ACTIONS(2597),
    [anon_sym_OR] = ACTIONS(2597),
    [anon_sym_Or] = ACTIONS(2597),
    [anon_sym_xor] = ACTIONS(2597),
    [anon_sym_XOR] = ACTIONS(2597),
    [anon_sym_Xor] = ACTIONS(2597),
    [anon_sym_QMARK] = ACTIONS(2599),
    [sym_datetime_literal] = ACTIONS(2599),
    [sym_date_literal] = ACTIONS(2597),
    [sym_time_literal] = ACTIONS(2597),
    [sym_biginteger_literal] = ACTIONS(2599),
    [anon_sym_if] = ACTIONS(2597),
    [anon_sym_IF] = ACTIONS(2597),
    [anon_sym_If] = ACTIONS(2597),
    [anon_sym_else] = ACTIONS(2597),
    [anon_sym_ELSE] = ACTIONS(2597),
    [anon_sym_Else] = ACTIONS(2597),
    [anon_sym_case] = ACTIONS(2597),
    [anon_sym_CASE] = ACTIONS(2597),
    [anon_sym_Case] = ACTIONS(2597),
    [anon_sym_for] = ACTIONS(2597),
    [anon_sym_FOR] = ACTIONS(2597),
    [anon_sym_For] = ACTIONS(2597),
    [anon_sym_foreach] = ACTIONS(2597),
    [anon_sym_FOREACH] = ACTIONS(2597),
    [anon_sym_Foreach] = ACTIONS(2597),
    [anon_sym_while] = ACTIONS(2597),
    [anon_sym_WHILE] = ACTIONS(2597),
    [anon_sym_While] = ACTIONS(2597),
    [anon_sym_repeat] = ACTIONS(2597),
    [anon_sym_REPEAT] = ACTIONS(2597),
    [anon_sym_Repeat] = ACTIONS(2597),
    [anon_sym_until] = ACTIONS(2597),
    [anon_sym_UNTIL] = ACTIONS(2597),
    [anon_sym_Until] = ACTIONS(2597),
    [anon_sym_exit] = ACTIONS(2597),
    [anon_sym_EXIT] = ACTIONS(2597),
    [anon_sym_Exit] = ACTIONS(2597),
    [anon_sym_continue] = ACTIONS(2597),
    [anon_sym_CONTINUE] = ACTIONS(2597),
    [anon_sym_Continue] = ACTIONS(2597),
    [anon_sym_break] = ACTIONS(2597),
    [anon_sym_BREAK] = ACTIONS(2597),
    [anon_sym_Break] = ACTIONS(2597),
    [anon_sym_with] = ACTIONS(2597),
    [anon_sym_WITH] = ACTIONS(2597),
    [anon_sym_With] = ACTIONS(2597),
    [sym_asserterror_keyword] = ACTIONS(2599),
    [anon_sym_in] = ACTIONS(2597),
    [anon_sym_IN] = ACTIONS(2597),
    [anon_sym_In] = ACTIONS(2597),
    [sym_page_keyword] = ACTIONS(2597),
    [anon_sym_codeunit] = ACTIONS(2597),
    [anon_sym_CODEUNIT] = ACTIONS(2597),
    [anon_sym_Codeunit] = ACTIONS(2597),
    [anon_sym_CodeUnit] = ACTIONS(2597),
    [anon_sym_COdeunit] = ACTIONS(2597),
    [anon_sym_codeUnit] = ACTIONS(2597),
    [sym_report_keyword] = ACTIONS(2597),
    [sym_query_keyword] = ACTIONS(2597),
    [anon_sym_xmlport] = ACTIONS(2597),
    [anon_sym_XMLPORT] = ACTIONS(2597),
    [anon_sym_Xmlport] = ACTIONS(2597),
    [anon_sym_XMLport] = ACTIONS(2597),
    [anon_sym_XMLPort] = ACTIONS(2597),
    [anon_sym_XmlPort] = ACTIONS(2597),
    [anon_sym_enum] = ACTIONS(2597),
    [anon_sym_ENUM] = ACTIONS(2597),
    [anon_sym_Enum] = ACTIONS(2597),
    [anon_sym_eNUM] = ACTIONS(2597),
    [anon_sym_eNum] = ACTIONS(2597),
    [anon_sym_ENum] = ACTIONS(2597),
    [sym_quoted_identifier] = ACTIONS(2599),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2599),
    [sym_integer] = ACTIONS(2597),
    [sym_continue_as_identifier] = ACTIONS(2599),
    [sym_preproc_open] = ACTIONS(2599),
  },
  [STATE(1135)] = {
    [sym_identifier] = ACTIONS(2601),
    [anon_sym_SEMI] = ACTIONS(2603),
    [anon_sym_DOT] = ACTIONS(2601),
    [anon_sym_EQ] = ACTIONS(2603),
    [anon_sym_DASH] = ACTIONS(2601),
    [aux_sym_boolean_token1] = ACTIONS(2601),
    [aux_sym_boolean_token2] = ACTIONS(2601),
    [sym_decimal] = ACTIONS(2601),
    [anon_sym_LPAREN] = ACTIONS(2603),
    [anon_sym_DOT_DOT] = ACTIONS(2603),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2601),
    [anon_sym_STAR] = ACTIONS(2601),
    [anon_sym_LBRACK] = ACTIONS(2603),
    [aux_sym_record_type_token1] = ACTIONS(2601),
    [aux_sym_basic_type_token21] = ACTIONS(2601),
    [aux_sym_basic_type_token22] = ACTIONS(2601),
    [aux_sym_basic_type_token48] = ACTIONS(2601),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2601),
    [anon_sym_POUNDif] = ACTIONS(2603),
    [anon_sym_POUNDIF] = ACTIONS(2603),
    [anon_sym_POUNDIf] = ACTIONS(2603),
    [anon_sym_not] = ACTIONS(2601),
    [anon_sym_NOT] = ACTIONS(2601),
    [anon_sym_Not] = ACTIONS(2601),
    [anon_sym_POUNDelse] = ACTIONS(2603),
    [anon_sym_POUNDELSE] = ACTIONS(2603),
    [anon_sym_POUNDElse] = ACTIONS(2603),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2603),
    [aux_sym__expression_token1] = ACTIONS(2603),
    [aux_sym__expression_token2] = ACTIONS(2601),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2601),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2601),
    [anon_sym_SLASH] = ACTIONS(2601),
    [anon_sym_div] = ACTIONS(2601),
    [anon_sym_DIV] = ACTIONS(2601),
    [anon_sym_Div] = ACTIONS(2601),
    [anon_sym_mod] = ACTIONS(2601),
    [anon_sym_MOD] = ACTIONS(2601),
    [anon_sym_Mod] = ACTIONS(2601),
    [anon_sym_PLUS] = ACTIONS(2601),
    [anon_sym_GT_EQ] = ACTIONS(2603),
    [anon_sym_LT_EQ] = ACTIONS(2603),
    [anon_sym_GT] = ACTIONS(2601),
    [anon_sym_LT] = ACTIONS(2601),
    [anon_sym_LT_GT] = ACTIONS(2603),
    [anon_sym_and] = ACTIONS(2601),
    [anon_sym_AND] = ACTIONS(2601),
    [anon_sym_And] = ACTIONS(2601),
    [anon_sym_or] = ACTIONS(2601),
    [anon_sym_OR] = ACTIONS(2601),
    [anon_sym_Or] = ACTIONS(2601),
    [anon_sym_xor] = ACTIONS(2601),
    [anon_sym_XOR] = ACTIONS(2601),
    [anon_sym_Xor] = ACTIONS(2601),
    [anon_sym_QMARK] = ACTIONS(2603),
    [sym_datetime_literal] = ACTIONS(2603),
    [sym_date_literal] = ACTIONS(2601),
    [sym_time_literal] = ACTIONS(2601),
    [sym_biginteger_literal] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2601),
    [anon_sym_IF] = ACTIONS(2601),
    [anon_sym_If] = ACTIONS(2601),
    [anon_sym_else] = ACTIONS(2601),
    [anon_sym_ELSE] = ACTIONS(2601),
    [anon_sym_Else] = ACTIONS(2601),
    [anon_sym_case] = ACTIONS(2601),
    [anon_sym_CASE] = ACTIONS(2601),
    [anon_sym_Case] = ACTIONS(2601),
    [anon_sym_for] = ACTIONS(2601),
    [anon_sym_FOR] = ACTIONS(2601),
    [anon_sym_For] = ACTIONS(2601),
    [anon_sym_foreach] = ACTIONS(2601),
    [anon_sym_FOREACH] = ACTIONS(2601),
    [anon_sym_Foreach] = ACTIONS(2601),
    [anon_sym_while] = ACTIONS(2601),
    [anon_sym_WHILE] = ACTIONS(2601),
    [anon_sym_While] = ACTIONS(2601),
    [anon_sym_repeat] = ACTIONS(2601),
    [anon_sym_REPEAT] = ACTIONS(2601),
    [anon_sym_Repeat] = ACTIONS(2601),
    [anon_sym_until] = ACTIONS(2601),
    [anon_sym_UNTIL] = ACTIONS(2601),
    [anon_sym_Until] = ACTIONS(2601),
    [anon_sym_exit] = ACTIONS(2601),
    [anon_sym_EXIT] = ACTIONS(2601),
    [anon_sym_Exit] = ACTIONS(2601),
    [anon_sym_continue] = ACTIONS(2601),
    [anon_sym_CONTINUE] = ACTIONS(2601),
    [anon_sym_Continue] = ACTIONS(2601),
    [anon_sym_break] = ACTIONS(2601),
    [anon_sym_BREAK] = ACTIONS(2601),
    [anon_sym_Break] = ACTIONS(2601),
    [anon_sym_with] = ACTIONS(2601),
    [anon_sym_WITH] = ACTIONS(2601),
    [anon_sym_With] = ACTIONS(2601),
    [sym_asserterror_keyword] = ACTIONS(2603),
    [anon_sym_in] = ACTIONS(2601),
    [anon_sym_IN] = ACTIONS(2601),
    [anon_sym_In] = ACTIONS(2601),
    [sym_page_keyword] = ACTIONS(2601),
    [anon_sym_codeunit] = ACTIONS(2601),
    [anon_sym_CODEUNIT] = ACTIONS(2601),
    [anon_sym_Codeunit] = ACTIONS(2601),
    [anon_sym_CodeUnit] = ACTIONS(2601),
    [anon_sym_COdeunit] = ACTIONS(2601),
    [anon_sym_codeUnit] = ACTIONS(2601),
    [sym_report_keyword] = ACTIONS(2601),
    [sym_query_keyword] = ACTIONS(2601),
    [anon_sym_xmlport] = ACTIONS(2601),
    [anon_sym_XMLPORT] = ACTIONS(2601),
    [anon_sym_Xmlport] = ACTIONS(2601),
    [anon_sym_XMLport] = ACTIONS(2601),
    [anon_sym_XMLPort] = ACTIONS(2601),
    [anon_sym_XmlPort] = ACTIONS(2601),
    [anon_sym_enum] = ACTIONS(2601),
    [anon_sym_ENUM] = ACTIONS(2601),
    [anon_sym_Enum] = ACTIONS(2601),
    [anon_sym_eNUM] = ACTIONS(2601),
    [anon_sym_eNum] = ACTIONS(2601),
    [anon_sym_ENum] = ACTIONS(2601),
    [sym_quoted_identifier] = ACTIONS(2603),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2603),
    [sym_integer] = ACTIONS(2601),
    [sym_continue_as_identifier] = ACTIONS(2603),
    [sym_preproc_open] = ACTIONS(2603),
  },
  [STATE(1136)] = {
    [sym_identifier] = ACTIONS(2609),
    [anon_sym_SEMI] = ACTIONS(2611),
    [anon_sym_DOT] = ACTIONS(2609),
    [anon_sym_EQ] = ACTIONS(2611),
    [anon_sym_DASH] = ACTIONS(2609),
    [aux_sym_boolean_token1] = ACTIONS(2609),
    [aux_sym_boolean_token2] = ACTIONS(2609),
    [sym_decimal] = ACTIONS(2609),
    [anon_sym_LPAREN] = ACTIONS(2611),
    [anon_sym_DOT_DOT] = ACTIONS(2611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2609),
    [anon_sym_STAR] = ACTIONS(2609),
    [anon_sym_LBRACK] = ACTIONS(2611),
    [aux_sym_record_type_token1] = ACTIONS(2609),
    [aux_sym_basic_type_token21] = ACTIONS(2609),
    [aux_sym_basic_type_token22] = ACTIONS(2609),
    [aux_sym_basic_type_token48] = ACTIONS(2609),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2609),
    [anon_sym_POUNDif] = ACTIONS(2611),
    [anon_sym_POUNDIF] = ACTIONS(2611),
    [anon_sym_POUNDIf] = ACTIONS(2611),
    [anon_sym_not] = ACTIONS(2609),
    [anon_sym_NOT] = ACTIONS(2609),
    [anon_sym_Not] = ACTIONS(2609),
    [anon_sym_POUNDelse] = ACTIONS(2611),
    [anon_sym_POUNDELSE] = ACTIONS(2611),
    [anon_sym_POUNDElse] = ACTIONS(2611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2611),
    [aux_sym__expression_token1] = ACTIONS(2611),
    [aux_sym__expression_token2] = ACTIONS(2609),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2609),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2609),
    [anon_sym_SLASH] = ACTIONS(2609),
    [anon_sym_div] = ACTIONS(2609),
    [anon_sym_DIV] = ACTIONS(2609),
    [anon_sym_Div] = ACTIONS(2609),
    [anon_sym_mod] = ACTIONS(2609),
    [anon_sym_MOD] = ACTIONS(2609),
    [anon_sym_Mod] = ACTIONS(2609),
    [anon_sym_PLUS] = ACTIONS(2609),
    [anon_sym_GT_EQ] = ACTIONS(2611),
    [anon_sym_LT_EQ] = ACTIONS(2611),
    [anon_sym_GT] = ACTIONS(2609),
    [anon_sym_LT] = ACTIONS(2609),
    [anon_sym_LT_GT] = ACTIONS(2611),
    [anon_sym_and] = ACTIONS(2609),
    [anon_sym_AND] = ACTIONS(2609),
    [anon_sym_And] = ACTIONS(2609),
    [anon_sym_or] = ACTIONS(2609),
    [anon_sym_OR] = ACTIONS(2609),
    [anon_sym_Or] = ACTIONS(2609),
    [anon_sym_xor] = ACTIONS(2609),
    [anon_sym_XOR] = ACTIONS(2609),
    [anon_sym_Xor] = ACTIONS(2609),
    [anon_sym_QMARK] = ACTIONS(2611),
    [sym_datetime_literal] = ACTIONS(2611),
    [sym_date_literal] = ACTIONS(2609),
    [sym_time_literal] = ACTIONS(2609),
    [sym_biginteger_literal] = ACTIONS(2611),
    [anon_sym_if] = ACTIONS(2609),
    [anon_sym_IF] = ACTIONS(2609),
    [anon_sym_If] = ACTIONS(2609),
    [anon_sym_else] = ACTIONS(2609),
    [anon_sym_ELSE] = ACTIONS(2609),
    [anon_sym_Else] = ACTIONS(2609),
    [anon_sym_case] = ACTIONS(2609),
    [anon_sym_CASE] = ACTIONS(2609),
    [anon_sym_Case] = ACTIONS(2609),
    [anon_sym_for] = ACTIONS(2609),
    [anon_sym_FOR] = ACTIONS(2609),
    [anon_sym_For] = ACTIONS(2609),
    [anon_sym_foreach] = ACTIONS(2609),
    [anon_sym_FOREACH] = ACTIONS(2609),
    [anon_sym_Foreach] = ACTIONS(2609),
    [anon_sym_while] = ACTIONS(2609),
    [anon_sym_WHILE] = ACTIONS(2609),
    [anon_sym_While] = ACTIONS(2609),
    [anon_sym_repeat] = ACTIONS(2609),
    [anon_sym_REPEAT] = ACTIONS(2609),
    [anon_sym_Repeat] = ACTIONS(2609),
    [anon_sym_until] = ACTIONS(2609),
    [anon_sym_UNTIL] = ACTIONS(2609),
    [anon_sym_Until] = ACTIONS(2609),
    [anon_sym_exit] = ACTIONS(2609),
    [anon_sym_EXIT] = ACTIONS(2609),
    [anon_sym_Exit] = ACTIONS(2609),
    [anon_sym_continue] = ACTIONS(2609),
    [anon_sym_CONTINUE] = ACTIONS(2609),
    [anon_sym_Continue] = ACTIONS(2609),
    [anon_sym_break] = ACTIONS(2609),
    [anon_sym_BREAK] = ACTIONS(2609),
    [anon_sym_Break] = ACTIONS(2609),
    [anon_sym_with] = ACTIONS(2609),
    [anon_sym_WITH] = ACTIONS(2609),
    [anon_sym_With] = ACTIONS(2609),
    [sym_asserterror_keyword] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(2609),
    [anon_sym_IN] = ACTIONS(2609),
    [anon_sym_In] = ACTIONS(2609),
    [sym_page_keyword] = ACTIONS(2609),
    [anon_sym_codeunit] = ACTIONS(2609),
    [anon_sym_CODEUNIT] = ACTIONS(2609),
    [anon_sym_Codeunit] = ACTIONS(2609),
    [anon_sym_CodeUnit] = ACTIONS(2609),
    [anon_sym_COdeunit] = ACTIONS(2609),
    [anon_sym_codeUnit] = ACTIONS(2609),
    [sym_report_keyword] = ACTIONS(2609),
    [sym_query_keyword] = ACTIONS(2609),
    [anon_sym_xmlport] = ACTIONS(2609),
    [anon_sym_XMLPORT] = ACTIONS(2609),
    [anon_sym_Xmlport] = ACTIONS(2609),
    [anon_sym_XMLport] = ACTIONS(2609),
    [anon_sym_XMLPort] = ACTIONS(2609),
    [anon_sym_XmlPort] = ACTIONS(2609),
    [anon_sym_enum] = ACTIONS(2609),
    [anon_sym_ENUM] = ACTIONS(2609),
    [anon_sym_Enum] = ACTIONS(2609),
    [anon_sym_eNUM] = ACTIONS(2609),
    [anon_sym_eNum] = ACTIONS(2609),
    [anon_sym_ENum] = ACTIONS(2609),
    [sym_quoted_identifier] = ACTIONS(2611),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2611),
    [sym_integer] = ACTIONS(2609),
    [sym_continue_as_identifier] = ACTIONS(2611),
    [sym_preproc_open] = ACTIONS(2611),
  },
  [STATE(1137)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2585),
    [anon_sym_POUNDif] = ACTIONS(2587),
    [anon_sym_POUNDIF] = ACTIONS(2587),
    [anon_sym_POUNDIf] = ACTIONS(2587),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [anon_sym_POUNDelse] = ACTIONS(2587),
    [anon_sym_POUNDELSE] = ACTIONS(2587),
    [anon_sym_POUNDElse] = ACTIONS(2587),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_IF] = ACTIONS(2585),
    [anon_sym_If] = ACTIONS(2585),
    [anon_sym_else] = ACTIONS(2585),
    [anon_sym_ELSE] = ACTIONS(2585),
    [anon_sym_Else] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_CASE] = ACTIONS(2585),
    [anon_sym_Case] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_FOR] = ACTIONS(2585),
    [anon_sym_For] = ACTIONS(2585),
    [anon_sym_foreach] = ACTIONS(2585),
    [anon_sym_FOREACH] = ACTIONS(2585),
    [anon_sym_Foreach] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_WHILE] = ACTIONS(2585),
    [anon_sym_While] = ACTIONS(2585),
    [anon_sym_repeat] = ACTIONS(2585),
    [anon_sym_REPEAT] = ACTIONS(2585),
    [anon_sym_Repeat] = ACTIONS(2585),
    [anon_sym_until] = ACTIONS(2585),
    [anon_sym_UNTIL] = ACTIONS(2585),
    [anon_sym_Until] = ACTIONS(2585),
    [anon_sym_exit] = ACTIONS(2585),
    [anon_sym_EXIT] = ACTIONS(2585),
    [anon_sym_Exit] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_CONTINUE] = ACTIONS(2585),
    [anon_sym_Continue] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_BREAK] = ACTIONS(2585),
    [anon_sym_Break] = ACTIONS(2585),
    [anon_sym_with] = ACTIONS(2585),
    [anon_sym_WITH] = ACTIONS(2585),
    [anon_sym_With] = ACTIONS(2585),
    [sym_asserterror_keyword] = ACTIONS(2587),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_open] = ACTIONS(2587),
  },
  [STATE(1138)] = {
    [sym_identifier] = ACTIONS(2649),
    [anon_sym_SEMI] = ACTIONS(2651),
    [anon_sym_DOT] = ACTIONS(2649),
    [anon_sym_EQ] = ACTIONS(2651),
    [anon_sym_DASH] = ACTIONS(2649),
    [aux_sym_boolean_token1] = ACTIONS(2649),
    [aux_sym_boolean_token2] = ACTIONS(2649),
    [sym_decimal] = ACTIONS(2649),
    [anon_sym_LPAREN] = ACTIONS(2651),
    [anon_sym_DOT_DOT] = ACTIONS(2651),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2649),
    [anon_sym_STAR] = ACTIONS(2649),
    [anon_sym_LBRACK] = ACTIONS(2651),
    [aux_sym_record_type_token1] = ACTIONS(2649),
    [aux_sym_basic_type_token21] = ACTIONS(2649),
    [aux_sym_basic_type_token22] = ACTIONS(2649),
    [aux_sym_basic_type_token48] = ACTIONS(2649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2649),
    [anon_sym_POUNDif] = ACTIONS(2651),
    [anon_sym_POUNDIF] = ACTIONS(2651),
    [anon_sym_POUNDIf] = ACTIONS(2651),
    [anon_sym_not] = ACTIONS(2649),
    [anon_sym_NOT] = ACTIONS(2649),
    [anon_sym_Not] = ACTIONS(2649),
    [anon_sym_POUNDelse] = ACTIONS(2651),
    [anon_sym_POUNDELSE] = ACTIONS(2651),
    [anon_sym_POUNDElse] = ACTIONS(2651),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2651),
    [aux_sym__expression_token1] = ACTIONS(2651),
    [aux_sym__expression_token2] = ACTIONS(2649),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2649),
    [anon_sym_SLASH] = ACTIONS(2649),
    [anon_sym_div] = ACTIONS(2649),
    [anon_sym_DIV] = ACTIONS(2649),
    [anon_sym_Div] = ACTIONS(2649),
    [anon_sym_mod] = ACTIONS(2649),
    [anon_sym_MOD] = ACTIONS(2649),
    [anon_sym_Mod] = ACTIONS(2649),
    [anon_sym_PLUS] = ACTIONS(2649),
    [anon_sym_GT_EQ] = ACTIONS(2651),
    [anon_sym_LT_EQ] = ACTIONS(2651),
    [anon_sym_GT] = ACTIONS(2649),
    [anon_sym_LT] = ACTIONS(2649),
    [anon_sym_LT_GT] = ACTIONS(2651),
    [anon_sym_and] = ACTIONS(2649),
    [anon_sym_AND] = ACTIONS(2649),
    [anon_sym_And] = ACTIONS(2649),
    [anon_sym_or] = ACTIONS(2649),
    [anon_sym_OR] = ACTIONS(2649),
    [anon_sym_Or] = ACTIONS(2649),
    [anon_sym_xor] = ACTIONS(2649),
    [anon_sym_XOR] = ACTIONS(2649),
    [anon_sym_Xor] = ACTIONS(2649),
    [anon_sym_QMARK] = ACTIONS(2651),
    [sym_datetime_literal] = ACTIONS(2651),
    [sym_date_literal] = ACTIONS(2649),
    [sym_time_literal] = ACTIONS(2649),
    [sym_biginteger_literal] = ACTIONS(2651),
    [anon_sym_if] = ACTIONS(2649),
    [anon_sym_IF] = ACTIONS(2649),
    [anon_sym_If] = ACTIONS(2649),
    [anon_sym_else] = ACTIONS(2649),
    [anon_sym_ELSE] = ACTIONS(2649),
    [anon_sym_Else] = ACTIONS(2649),
    [anon_sym_case] = ACTIONS(2649),
    [anon_sym_CASE] = ACTIONS(2649),
    [anon_sym_Case] = ACTIONS(2649),
    [anon_sym_for] = ACTIONS(2649),
    [anon_sym_FOR] = ACTIONS(2649),
    [anon_sym_For] = ACTIONS(2649),
    [anon_sym_foreach] = ACTIONS(2649),
    [anon_sym_FOREACH] = ACTIONS(2649),
    [anon_sym_Foreach] = ACTIONS(2649),
    [anon_sym_while] = ACTIONS(2649),
    [anon_sym_WHILE] = ACTIONS(2649),
    [anon_sym_While] = ACTIONS(2649),
    [anon_sym_repeat] = ACTIONS(2649),
    [anon_sym_REPEAT] = ACTIONS(2649),
    [anon_sym_Repeat] = ACTIONS(2649),
    [anon_sym_until] = ACTIONS(2649),
    [anon_sym_UNTIL] = ACTIONS(2649),
    [anon_sym_Until] = ACTIONS(2649),
    [anon_sym_exit] = ACTIONS(2649),
    [anon_sym_EXIT] = ACTIONS(2649),
    [anon_sym_Exit] = ACTIONS(2649),
    [anon_sym_continue] = ACTIONS(2649),
    [anon_sym_CONTINUE] = ACTIONS(2649),
    [anon_sym_Continue] = ACTIONS(2649),
    [anon_sym_break] = ACTIONS(2649),
    [anon_sym_BREAK] = ACTIONS(2649),
    [anon_sym_Break] = ACTIONS(2649),
    [anon_sym_with] = ACTIONS(2649),
    [anon_sym_WITH] = ACTIONS(2649),
    [anon_sym_With] = ACTIONS(2649),
    [sym_asserterror_keyword] = ACTIONS(2651),
    [anon_sym_in] = ACTIONS(2649),
    [anon_sym_IN] = ACTIONS(2649),
    [anon_sym_In] = ACTIONS(2649),
    [sym_page_keyword] = ACTIONS(2649),
    [anon_sym_codeunit] = ACTIONS(2649),
    [anon_sym_CODEUNIT] = ACTIONS(2649),
    [anon_sym_Codeunit] = ACTIONS(2649),
    [anon_sym_CodeUnit] = ACTIONS(2649),
    [anon_sym_COdeunit] = ACTIONS(2649),
    [anon_sym_codeUnit] = ACTIONS(2649),
    [sym_report_keyword] = ACTIONS(2649),
    [sym_query_keyword] = ACTIONS(2649),
    [anon_sym_xmlport] = ACTIONS(2649),
    [anon_sym_XMLPORT] = ACTIONS(2649),
    [anon_sym_Xmlport] = ACTIONS(2649),
    [anon_sym_XMLport] = ACTIONS(2649),
    [anon_sym_XMLPort] = ACTIONS(2649),
    [anon_sym_XmlPort] = ACTIONS(2649),
    [anon_sym_enum] = ACTIONS(2649),
    [anon_sym_ENUM] = ACTIONS(2649),
    [anon_sym_Enum] = ACTIONS(2649),
    [anon_sym_eNUM] = ACTIONS(2649),
    [anon_sym_eNum] = ACTIONS(2649),
    [anon_sym_ENum] = ACTIONS(2649),
    [sym_quoted_identifier] = ACTIONS(2651),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2651),
    [sym_integer] = ACTIONS(2649),
    [sym_continue_as_identifier] = ACTIONS(2651),
    [sym_preproc_open] = ACTIONS(2651),
  },
  [STATE(1139)] = {
    [sym_identifier] = ACTIONS(2619),
    [anon_sym_SEMI] = ACTIONS(2621),
    [anon_sym_DOT] = ACTIONS(2619),
    [anon_sym_EQ] = ACTIONS(2621),
    [anon_sym_DASH] = ACTIONS(2619),
    [aux_sym_boolean_token1] = ACTIONS(2619),
    [aux_sym_boolean_token2] = ACTIONS(2619),
    [sym_decimal] = ACTIONS(2619),
    [anon_sym_LPAREN] = ACTIONS(2621),
    [anon_sym_DOT_DOT] = ACTIONS(2621),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2619),
    [anon_sym_STAR] = ACTIONS(2619),
    [anon_sym_LBRACK] = ACTIONS(2727),
    [aux_sym_record_type_token1] = ACTIONS(2619),
    [aux_sym_basic_type_token21] = ACTIONS(2619),
    [aux_sym_basic_type_token22] = ACTIONS(2619),
    [aux_sym_basic_type_token48] = ACTIONS(2619),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2619),
    [anon_sym_POUNDif] = ACTIONS(2621),
    [anon_sym_POUNDIF] = ACTIONS(2621),
    [anon_sym_POUNDIf] = ACTIONS(2621),
    [anon_sym_not] = ACTIONS(2619),
    [anon_sym_NOT] = ACTIONS(2619),
    [anon_sym_Not] = ACTIONS(2619),
    [anon_sym_POUNDelse] = ACTIONS(2621),
    [anon_sym_POUNDELSE] = ACTIONS(2621),
    [anon_sym_POUNDElse] = ACTIONS(2621),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2621),
    [aux_sym__expression_token1] = ACTIONS(2621),
    [aux_sym__expression_token2] = ACTIONS(2619),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2619),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2619),
    [anon_sym_SLASH] = ACTIONS(2619),
    [anon_sym_div] = ACTIONS(2619),
    [anon_sym_DIV] = ACTIONS(2619),
    [anon_sym_Div] = ACTIONS(2619),
    [anon_sym_mod] = ACTIONS(2619),
    [anon_sym_MOD] = ACTIONS(2619),
    [anon_sym_Mod] = ACTIONS(2619),
    [anon_sym_PLUS] = ACTIONS(2619),
    [anon_sym_GT_EQ] = ACTIONS(2621),
    [anon_sym_LT_EQ] = ACTIONS(2621),
    [anon_sym_GT] = ACTIONS(2619),
    [anon_sym_LT] = ACTIONS(2619),
    [anon_sym_LT_GT] = ACTIONS(2621),
    [anon_sym_and] = ACTIONS(2619),
    [anon_sym_AND] = ACTIONS(2619),
    [anon_sym_And] = ACTIONS(2619),
    [anon_sym_or] = ACTIONS(2619),
    [anon_sym_OR] = ACTIONS(2619),
    [anon_sym_Or] = ACTIONS(2619),
    [anon_sym_xor] = ACTIONS(2619),
    [anon_sym_XOR] = ACTIONS(2619),
    [anon_sym_Xor] = ACTIONS(2619),
    [anon_sym_QMARK] = ACTIONS(2621),
    [sym_datetime_literal] = ACTIONS(2621),
    [sym_date_literal] = ACTIONS(2619),
    [sym_time_literal] = ACTIONS(2619),
    [sym_biginteger_literal] = ACTIONS(2621),
    [anon_sym_if] = ACTIONS(2619),
    [anon_sym_IF] = ACTIONS(2619),
    [anon_sym_If] = ACTIONS(2619),
    [anon_sym_else] = ACTIONS(2619),
    [anon_sym_ELSE] = ACTIONS(2619),
    [anon_sym_Else] = ACTIONS(2619),
    [anon_sym_case] = ACTIONS(2619),
    [anon_sym_CASE] = ACTIONS(2619),
    [anon_sym_Case] = ACTIONS(2619),
    [anon_sym_for] = ACTIONS(2619),
    [anon_sym_FOR] = ACTIONS(2619),
    [anon_sym_For] = ACTIONS(2619),
    [anon_sym_foreach] = ACTIONS(2619),
    [anon_sym_FOREACH] = ACTIONS(2619),
    [anon_sym_Foreach] = ACTIONS(2619),
    [anon_sym_while] = ACTIONS(2619),
    [anon_sym_WHILE] = ACTIONS(2619),
    [anon_sym_While] = ACTIONS(2619),
    [anon_sym_repeat] = ACTIONS(2619),
    [anon_sym_REPEAT] = ACTIONS(2619),
    [anon_sym_Repeat] = ACTIONS(2619),
    [anon_sym_until] = ACTIONS(2619),
    [anon_sym_UNTIL] = ACTIONS(2619),
    [anon_sym_Until] = ACTIONS(2619),
    [anon_sym_exit] = ACTIONS(2619),
    [anon_sym_EXIT] = ACTIONS(2619),
    [anon_sym_Exit] = ACTIONS(2619),
    [anon_sym_continue] = ACTIONS(2619),
    [anon_sym_CONTINUE] = ACTIONS(2619),
    [anon_sym_Continue] = ACTIONS(2619),
    [anon_sym_break] = ACTIONS(2619),
    [anon_sym_BREAK] = ACTIONS(2619),
    [anon_sym_Break] = ACTIONS(2619),
    [anon_sym_with] = ACTIONS(2619),
    [anon_sym_WITH] = ACTIONS(2619),
    [anon_sym_With] = ACTIONS(2619),
    [sym_asserterror_keyword] = ACTIONS(2621),
    [anon_sym_in] = ACTIONS(2619),
    [anon_sym_IN] = ACTIONS(2619),
    [anon_sym_In] = ACTIONS(2619),
    [sym_page_keyword] = ACTIONS(2619),
    [anon_sym_codeunit] = ACTIONS(2619),
    [anon_sym_CODEUNIT] = ACTIONS(2619),
    [anon_sym_Codeunit] = ACTIONS(2619),
    [anon_sym_CodeUnit] = ACTIONS(2619),
    [anon_sym_COdeunit] = ACTIONS(2619),
    [anon_sym_codeUnit] = ACTIONS(2619),
    [sym_report_keyword] = ACTIONS(2619),
    [sym_query_keyword] = ACTIONS(2619),
    [anon_sym_xmlport] = ACTIONS(2619),
    [anon_sym_XMLPORT] = ACTIONS(2619),
    [anon_sym_Xmlport] = ACTIONS(2619),
    [anon_sym_XMLport] = ACTIONS(2619),
    [anon_sym_XMLPort] = ACTIONS(2619),
    [anon_sym_XmlPort] = ACTIONS(2619),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_ENUM] = ACTIONS(2619),
    [anon_sym_Enum] = ACTIONS(2619),
    [anon_sym_eNUM] = ACTIONS(2619),
    [anon_sym_eNum] = ACTIONS(2619),
    [anon_sym_ENum] = ACTIONS(2619),
    [sym_quoted_identifier] = ACTIONS(2621),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2621),
    [sym_integer] = ACTIONS(2619),
    [sym_continue_as_identifier] = ACTIONS(2621),
    [sym_preproc_open] = ACTIONS(2621),
  },
  [STATE(1140)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2585),
    [anon_sym_POUNDif] = ACTIONS(2587),
    [anon_sym_POUNDIF] = ACTIONS(2587),
    [anon_sym_POUNDIf] = ACTIONS(2587),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [anon_sym_POUNDelse] = ACTIONS(2587),
    [anon_sym_POUNDELSE] = ACTIONS(2587),
    [anon_sym_POUNDElse] = ACTIONS(2587),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_IF] = ACTIONS(2585),
    [anon_sym_If] = ACTIONS(2585),
    [anon_sym_else] = ACTIONS(2585),
    [anon_sym_ELSE] = ACTIONS(2585),
    [anon_sym_Else] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_CASE] = ACTIONS(2585),
    [anon_sym_Case] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_FOR] = ACTIONS(2585),
    [anon_sym_For] = ACTIONS(2585),
    [anon_sym_foreach] = ACTIONS(2585),
    [anon_sym_FOREACH] = ACTIONS(2585),
    [anon_sym_Foreach] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_WHILE] = ACTIONS(2585),
    [anon_sym_While] = ACTIONS(2585),
    [anon_sym_repeat] = ACTIONS(2585),
    [anon_sym_REPEAT] = ACTIONS(2585),
    [anon_sym_Repeat] = ACTIONS(2585),
    [anon_sym_until] = ACTIONS(2585),
    [anon_sym_UNTIL] = ACTIONS(2585),
    [anon_sym_Until] = ACTIONS(2585),
    [anon_sym_exit] = ACTIONS(2585),
    [anon_sym_EXIT] = ACTIONS(2585),
    [anon_sym_Exit] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_CONTINUE] = ACTIONS(2585),
    [anon_sym_Continue] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_BREAK] = ACTIONS(2585),
    [anon_sym_Break] = ACTIONS(2585),
    [anon_sym_with] = ACTIONS(2585),
    [anon_sym_WITH] = ACTIONS(2585),
    [anon_sym_With] = ACTIONS(2585),
    [sym_asserterror_keyword] = ACTIONS(2587),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_open] = ACTIONS(2587),
  },
  [STATE(1141)] = {
    [sym_identifier] = ACTIONS(2625),
    [anon_sym_SEMI] = ACTIONS(2627),
    [anon_sym_DOT] = ACTIONS(2625),
    [anon_sym_EQ] = ACTIONS(2627),
    [anon_sym_DASH] = ACTIONS(2625),
    [aux_sym_boolean_token1] = ACTIONS(2625),
    [aux_sym_boolean_token2] = ACTIONS(2625),
    [sym_decimal] = ACTIONS(2625),
    [anon_sym_LPAREN] = ACTIONS(2627),
    [anon_sym_DOT_DOT] = ACTIONS(2627),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2625),
    [anon_sym_STAR] = ACTIONS(2625),
    [anon_sym_LBRACK] = ACTIONS(2627),
    [aux_sym_record_type_token1] = ACTIONS(2625),
    [aux_sym_basic_type_token21] = ACTIONS(2625),
    [aux_sym_basic_type_token22] = ACTIONS(2625),
    [aux_sym_basic_type_token48] = ACTIONS(2625),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2625),
    [anon_sym_POUNDif] = ACTIONS(2627),
    [anon_sym_POUNDIF] = ACTIONS(2627),
    [anon_sym_POUNDIf] = ACTIONS(2627),
    [anon_sym_not] = ACTIONS(2625),
    [anon_sym_NOT] = ACTIONS(2625),
    [anon_sym_Not] = ACTIONS(2625),
    [anon_sym_POUNDelse] = ACTIONS(2627),
    [anon_sym_POUNDELSE] = ACTIONS(2627),
    [anon_sym_POUNDElse] = ACTIONS(2627),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2627),
    [aux_sym__expression_token1] = ACTIONS(2627),
    [aux_sym__expression_token2] = ACTIONS(2625),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2625),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2625),
    [anon_sym_SLASH] = ACTIONS(2625),
    [anon_sym_div] = ACTIONS(2625),
    [anon_sym_DIV] = ACTIONS(2625),
    [anon_sym_Div] = ACTIONS(2625),
    [anon_sym_mod] = ACTIONS(2625),
    [anon_sym_MOD] = ACTIONS(2625),
    [anon_sym_Mod] = ACTIONS(2625),
    [anon_sym_PLUS] = ACTIONS(2625),
    [anon_sym_GT_EQ] = ACTIONS(2627),
    [anon_sym_LT_EQ] = ACTIONS(2627),
    [anon_sym_GT] = ACTIONS(2625),
    [anon_sym_LT] = ACTIONS(2625),
    [anon_sym_LT_GT] = ACTIONS(2627),
    [anon_sym_and] = ACTIONS(2625),
    [anon_sym_AND] = ACTIONS(2625),
    [anon_sym_And] = ACTIONS(2625),
    [anon_sym_or] = ACTIONS(2625),
    [anon_sym_OR] = ACTIONS(2625),
    [anon_sym_Or] = ACTIONS(2625),
    [anon_sym_xor] = ACTIONS(2625),
    [anon_sym_XOR] = ACTIONS(2625),
    [anon_sym_Xor] = ACTIONS(2625),
    [anon_sym_QMARK] = ACTIONS(2627),
    [sym_datetime_literal] = ACTIONS(2627),
    [sym_date_literal] = ACTIONS(2625),
    [sym_time_literal] = ACTIONS(2625),
    [sym_biginteger_literal] = ACTIONS(2627),
    [anon_sym_if] = ACTIONS(2625),
    [anon_sym_IF] = ACTIONS(2625),
    [anon_sym_If] = ACTIONS(2625),
    [anon_sym_else] = ACTIONS(2625),
    [anon_sym_ELSE] = ACTIONS(2625),
    [anon_sym_Else] = ACTIONS(2625),
    [anon_sym_case] = ACTIONS(2625),
    [anon_sym_CASE] = ACTIONS(2625),
    [anon_sym_Case] = ACTIONS(2625),
    [anon_sym_for] = ACTIONS(2625),
    [anon_sym_FOR] = ACTIONS(2625),
    [anon_sym_For] = ACTIONS(2625),
    [anon_sym_foreach] = ACTIONS(2625),
    [anon_sym_FOREACH] = ACTIONS(2625),
    [anon_sym_Foreach] = ACTIONS(2625),
    [anon_sym_while] = ACTIONS(2625),
    [anon_sym_WHILE] = ACTIONS(2625),
    [anon_sym_While] = ACTIONS(2625),
    [anon_sym_repeat] = ACTIONS(2625),
    [anon_sym_REPEAT] = ACTIONS(2625),
    [anon_sym_Repeat] = ACTIONS(2625),
    [anon_sym_until] = ACTIONS(2625),
    [anon_sym_UNTIL] = ACTIONS(2625),
    [anon_sym_Until] = ACTIONS(2625),
    [anon_sym_exit] = ACTIONS(2625),
    [anon_sym_EXIT] = ACTIONS(2625),
    [anon_sym_Exit] = ACTIONS(2625),
    [anon_sym_continue] = ACTIONS(2625),
    [anon_sym_CONTINUE] = ACTIONS(2625),
    [anon_sym_Continue] = ACTIONS(2625),
    [anon_sym_break] = ACTIONS(2625),
    [anon_sym_BREAK] = ACTIONS(2625),
    [anon_sym_Break] = ACTIONS(2625),
    [anon_sym_with] = ACTIONS(2625),
    [anon_sym_WITH] = ACTIONS(2625),
    [anon_sym_With] = ACTIONS(2625),
    [sym_asserterror_keyword] = ACTIONS(2627),
    [anon_sym_in] = ACTIONS(2625),
    [anon_sym_IN] = ACTIONS(2625),
    [anon_sym_In] = ACTIONS(2625),
    [sym_page_keyword] = ACTIONS(2625),
    [anon_sym_codeunit] = ACTIONS(2625),
    [anon_sym_CODEUNIT] = ACTIONS(2625),
    [anon_sym_Codeunit] = ACTIONS(2625),
    [anon_sym_CodeUnit] = ACTIONS(2625),
    [anon_sym_COdeunit] = ACTIONS(2625),
    [anon_sym_codeUnit] = ACTIONS(2625),
    [sym_report_keyword] = ACTIONS(2625),
    [sym_query_keyword] = ACTIONS(2625),
    [anon_sym_xmlport] = ACTIONS(2625),
    [anon_sym_XMLPORT] = ACTIONS(2625),
    [anon_sym_Xmlport] = ACTIONS(2625),
    [anon_sym_XMLport] = ACTIONS(2625),
    [anon_sym_XMLPort] = ACTIONS(2625),
    [anon_sym_XmlPort] = ACTIONS(2625),
    [anon_sym_enum] = ACTIONS(2625),
    [anon_sym_ENUM] = ACTIONS(2625),
    [anon_sym_Enum] = ACTIONS(2625),
    [anon_sym_eNUM] = ACTIONS(2625),
    [anon_sym_eNum] = ACTIONS(2625),
    [anon_sym_ENum] = ACTIONS(2625),
    [sym_quoted_identifier] = ACTIONS(2627),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2627),
    [sym_integer] = ACTIONS(2625),
    [sym_continue_as_identifier] = ACTIONS(2627),
    [sym_preproc_open] = ACTIONS(2627),
  },
  [STATE(1142)] = {
    [sym_identifier] = ACTIONS(2629),
    [anon_sym_SEMI] = ACTIONS(2631),
    [anon_sym_DOT] = ACTIONS(2629),
    [anon_sym_EQ] = ACTIONS(2631),
    [anon_sym_DASH] = ACTIONS(2629),
    [aux_sym_boolean_token1] = ACTIONS(2629),
    [aux_sym_boolean_token2] = ACTIONS(2629),
    [sym_decimal] = ACTIONS(2629),
    [anon_sym_LPAREN] = ACTIONS(2631),
    [anon_sym_DOT_DOT] = ACTIONS(2631),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2629),
    [anon_sym_STAR] = ACTIONS(2629),
    [anon_sym_LBRACK] = ACTIONS(2631),
    [aux_sym_record_type_token1] = ACTIONS(2629),
    [aux_sym_basic_type_token21] = ACTIONS(2629),
    [aux_sym_basic_type_token22] = ACTIONS(2629),
    [aux_sym_basic_type_token48] = ACTIONS(2629),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2629),
    [anon_sym_POUNDif] = ACTIONS(2631),
    [anon_sym_POUNDIF] = ACTIONS(2631),
    [anon_sym_POUNDIf] = ACTIONS(2631),
    [anon_sym_not] = ACTIONS(2629),
    [anon_sym_NOT] = ACTIONS(2629),
    [anon_sym_Not] = ACTIONS(2629),
    [anon_sym_POUNDelse] = ACTIONS(2631),
    [anon_sym_POUNDELSE] = ACTIONS(2631),
    [anon_sym_POUNDElse] = ACTIONS(2631),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2631),
    [aux_sym__expression_token1] = ACTIONS(2631),
    [aux_sym__expression_token2] = ACTIONS(2629),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2629),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2629),
    [anon_sym_SLASH] = ACTIONS(2629),
    [anon_sym_div] = ACTIONS(2629),
    [anon_sym_DIV] = ACTIONS(2629),
    [anon_sym_Div] = ACTIONS(2629),
    [anon_sym_mod] = ACTIONS(2629),
    [anon_sym_MOD] = ACTIONS(2629),
    [anon_sym_Mod] = ACTIONS(2629),
    [anon_sym_PLUS] = ACTIONS(2629),
    [anon_sym_GT_EQ] = ACTIONS(2631),
    [anon_sym_LT_EQ] = ACTIONS(2631),
    [anon_sym_GT] = ACTIONS(2629),
    [anon_sym_LT] = ACTIONS(2629),
    [anon_sym_LT_GT] = ACTIONS(2631),
    [anon_sym_and] = ACTIONS(2629),
    [anon_sym_AND] = ACTIONS(2629),
    [anon_sym_And] = ACTIONS(2629),
    [anon_sym_or] = ACTIONS(2629),
    [anon_sym_OR] = ACTIONS(2629),
    [anon_sym_Or] = ACTIONS(2629),
    [anon_sym_xor] = ACTIONS(2629),
    [anon_sym_XOR] = ACTIONS(2629),
    [anon_sym_Xor] = ACTIONS(2629),
    [anon_sym_QMARK] = ACTIONS(2631),
    [sym_datetime_literal] = ACTIONS(2631),
    [sym_date_literal] = ACTIONS(2629),
    [sym_time_literal] = ACTIONS(2629),
    [sym_biginteger_literal] = ACTIONS(2631),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_IF] = ACTIONS(2629),
    [anon_sym_If] = ACTIONS(2629),
    [anon_sym_else] = ACTIONS(2629),
    [anon_sym_ELSE] = ACTIONS(2629),
    [anon_sym_Else] = ACTIONS(2629),
    [anon_sym_case] = ACTIONS(2629),
    [anon_sym_CASE] = ACTIONS(2629),
    [anon_sym_Case] = ACTIONS(2629),
    [anon_sym_for] = ACTIONS(2629),
    [anon_sym_FOR] = ACTIONS(2629),
    [anon_sym_For] = ACTIONS(2629),
    [anon_sym_foreach] = ACTIONS(2629),
    [anon_sym_FOREACH] = ACTIONS(2629),
    [anon_sym_Foreach] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(2629),
    [anon_sym_WHILE] = ACTIONS(2629),
    [anon_sym_While] = ACTIONS(2629),
    [anon_sym_repeat] = ACTIONS(2629),
    [anon_sym_REPEAT] = ACTIONS(2629),
    [anon_sym_Repeat] = ACTIONS(2629),
    [anon_sym_until] = ACTIONS(2629),
    [anon_sym_UNTIL] = ACTIONS(2629),
    [anon_sym_Until] = ACTIONS(2629),
    [anon_sym_exit] = ACTIONS(2629),
    [anon_sym_EXIT] = ACTIONS(2629),
    [anon_sym_Exit] = ACTIONS(2629),
    [anon_sym_continue] = ACTIONS(2629),
    [anon_sym_CONTINUE] = ACTIONS(2629),
    [anon_sym_Continue] = ACTIONS(2629),
    [anon_sym_break] = ACTIONS(2629),
    [anon_sym_BREAK] = ACTIONS(2629),
    [anon_sym_Break] = ACTIONS(2629),
    [anon_sym_with] = ACTIONS(2629),
    [anon_sym_WITH] = ACTIONS(2629),
    [anon_sym_With] = ACTIONS(2629),
    [sym_asserterror_keyword] = ACTIONS(2631),
    [anon_sym_in] = ACTIONS(2629),
    [anon_sym_IN] = ACTIONS(2629),
    [anon_sym_In] = ACTIONS(2629),
    [sym_page_keyword] = ACTIONS(2629),
    [anon_sym_codeunit] = ACTIONS(2629),
    [anon_sym_CODEUNIT] = ACTIONS(2629),
    [anon_sym_Codeunit] = ACTIONS(2629),
    [anon_sym_CodeUnit] = ACTIONS(2629),
    [anon_sym_COdeunit] = ACTIONS(2629),
    [anon_sym_codeUnit] = ACTIONS(2629),
    [sym_report_keyword] = ACTIONS(2629),
    [sym_query_keyword] = ACTIONS(2629),
    [anon_sym_xmlport] = ACTIONS(2629),
    [anon_sym_XMLPORT] = ACTIONS(2629),
    [anon_sym_Xmlport] = ACTIONS(2629),
    [anon_sym_XMLport] = ACTIONS(2629),
    [anon_sym_XMLPort] = ACTIONS(2629),
    [anon_sym_XmlPort] = ACTIONS(2629),
    [anon_sym_enum] = ACTIONS(2629),
    [anon_sym_ENUM] = ACTIONS(2629),
    [anon_sym_Enum] = ACTIONS(2629),
    [anon_sym_eNUM] = ACTIONS(2629),
    [anon_sym_eNum] = ACTIONS(2629),
    [anon_sym_ENum] = ACTIONS(2629),
    [sym_quoted_identifier] = ACTIONS(2631),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2631),
    [sym_integer] = ACTIONS(2629),
    [sym_continue_as_identifier] = ACTIONS(2631),
    [sym_preproc_open] = ACTIONS(2631),
  },
  [STATE(1143)] = {
    [sym_identifier] = ACTIONS(2633),
    [anon_sym_SEMI] = ACTIONS(2635),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_EQ] = ACTIONS(2635),
    [anon_sym_DASH] = ACTIONS(2633),
    [aux_sym_boolean_token1] = ACTIONS(2633),
    [aux_sym_boolean_token2] = ACTIONS(2633),
    [sym_decimal] = ACTIONS(2633),
    [anon_sym_LPAREN] = ACTIONS(2635),
    [anon_sym_DOT_DOT] = ACTIONS(2635),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2633),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [aux_sym_record_type_token1] = ACTIONS(2633),
    [aux_sym_basic_type_token21] = ACTIONS(2633),
    [aux_sym_basic_type_token22] = ACTIONS(2633),
    [aux_sym_basic_type_token48] = ACTIONS(2633),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2633),
    [anon_sym_POUNDif] = ACTIONS(2635),
    [anon_sym_POUNDIF] = ACTIONS(2635),
    [anon_sym_POUNDIf] = ACTIONS(2635),
    [anon_sym_not] = ACTIONS(2633),
    [anon_sym_NOT] = ACTIONS(2633),
    [anon_sym_Not] = ACTIONS(2633),
    [anon_sym_POUNDelse] = ACTIONS(2635),
    [anon_sym_POUNDELSE] = ACTIONS(2635),
    [anon_sym_POUNDElse] = ACTIONS(2635),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2635),
    [aux_sym__expression_token1] = ACTIONS(2635),
    [aux_sym__expression_token2] = ACTIONS(2633),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2633),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2633),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_div] = ACTIONS(2633),
    [anon_sym_DIV] = ACTIONS(2633),
    [anon_sym_Div] = ACTIONS(2633),
    [anon_sym_mod] = ACTIONS(2633),
    [anon_sym_MOD] = ACTIONS(2633),
    [anon_sym_Mod] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_GT] = ACTIONS(2635),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_AND] = ACTIONS(2633),
    [anon_sym_And] = ACTIONS(2633),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_OR] = ACTIONS(2633),
    [anon_sym_Or] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_XOR] = ACTIONS(2633),
    [anon_sym_Xor] = ACTIONS(2633),
    [anon_sym_QMARK] = ACTIONS(2635),
    [sym_datetime_literal] = ACTIONS(2635),
    [sym_date_literal] = ACTIONS(2633),
    [sym_time_literal] = ACTIONS(2633),
    [sym_biginteger_literal] = ACTIONS(2635),
    [anon_sym_if] = ACTIONS(2633),
    [anon_sym_IF] = ACTIONS(2633),
    [anon_sym_If] = ACTIONS(2633),
    [anon_sym_else] = ACTIONS(2633),
    [anon_sym_ELSE] = ACTIONS(2633),
    [anon_sym_Else] = ACTIONS(2633),
    [anon_sym_case] = ACTIONS(2633),
    [anon_sym_CASE] = ACTIONS(2633),
    [anon_sym_Case] = ACTIONS(2633),
    [anon_sym_for] = ACTIONS(2633),
    [anon_sym_FOR] = ACTIONS(2633),
    [anon_sym_For] = ACTIONS(2633),
    [anon_sym_foreach] = ACTIONS(2633),
    [anon_sym_FOREACH] = ACTIONS(2633),
    [anon_sym_Foreach] = ACTIONS(2633),
    [anon_sym_while] = ACTIONS(2633),
    [anon_sym_WHILE] = ACTIONS(2633),
    [anon_sym_While] = ACTIONS(2633),
    [anon_sym_repeat] = ACTIONS(2633),
    [anon_sym_REPEAT] = ACTIONS(2633),
    [anon_sym_Repeat] = ACTIONS(2633),
    [anon_sym_until] = ACTIONS(2633),
    [anon_sym_UNTIL] = ACTIONS(2633),
    [anon_sym_Until] = ACTIONS(2633),
    [anon_sym_exit] = ACTIONS(2633),
    [anon_sym_EXIT] = ACTIONS(2633),
    [anon_sym_Exit] = ACTIONS(2633),
    [anon_sym_continue] = ACTIONS(2633),
    [anon_sym_CONTINUE] = ACTIONS(2633),
    [anon_sym_Continue] = ACTIONS(2633),
    [anon_sym_break] = ACTIONS(2633),
    [anon_sym_BREAK] = ACTIONS(2633),
    [anon_sym_Break] = ACTIONS(2633),
    [anon_sym_with] = ACTIONS(2633),
    [anon_sym_WITH] = ACTIONS(2633),
    [anon_sym_With] = ACTIONS(2633),
    [sym_asserterror_keyword] = ACTIONS(2635),
    [anon_sym_in] = ACTIONS(2633),
    [anon_sym_IN] = ACTIONS(2633),
    [anon_sym_In] = ACTIONS(2633),
    [sym_page_keyword] = ACTIONS(2633),
    [anon_sym_codeunit] = ACTIONS(2633),
    [anon_sym_CODEUNIT] = ACTIONS(2633),
    [anon_sym_Codeunit] = ACTIONS(2633),
    [anon_sym_CodeUnit] = ACTIONS(2633),
    [anon_sym_COdeunit] = ACTIONS(2633),
    [anon_sym_codeUnit] = ACTIONS(2633),
    [sym_report_keyword] = ACTIONS(2633),
    [sym_query_keyword] = ACTIONS(2633),
    [anon_sym_xmlport] = ACTIONS(2633),
    [anon_sym_XMLPORT] = ACTIONS(2633),
    [anon_sym_Xmlport] = ACTIONS(2633),
    [anon_sym_XMLport] = ACTIONS(2633),
    [anon_sym_XMLPort] = ACTIONS(2633),
    [anon_sym_XmlPort] = ACTIONS(2633),
    [anon_sym_enum] = ACTIONS(2633),
    [anon_sym_ENUM] = ACTIONS(2633),
    [anon_sym_Enum] = ACTIONS(2633),
    [anon_sym_eNUM] = ACTIONS(2633),
    [anon_sym_eNum] = ACTIONS(2633),
    [anon_sym_ENum] = ACTIONS(2633),
    [sym_quoted_identifier] = ACTIONS(2635),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2635),
    [sym_integer] = ACTIONS(2633),
    [sym_continue_as_identifier] = ACTIONS(2635),
    [sym_preproc_open] = ACTIONS(2635),
  },
  [STATE(1144)] = {
    [sym_identifier] = ACTIONS(2641),
    [anon_sym_SEMI] = ACTIONS(2643),
    [anon_sym_DOT] = ACTIONS(2641),
    [anon_sym_EQ] = ACTIONS(2643),
    [anon_sym_DASH] = ACTIONS(2641),
    [aux_sym_boolean_token1] = ACTIONS(2641),
    [aux_sym_boolean_token2] = ACTIONS(2641),
    [sym_decimal] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_DOT_DOT] = ACTIONS(2643),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2641),
    [anon_sym_STAR] = ACTIONS(2641),
    [anon_sym_LBRACK] = ACTIONS(2643),
    [aux_sym_record_type_token1] = ACTIONS(2641),
    [aux_sym_basic_type_token21] = ACTIONS(2641),
    [aux_sym_basic_type_token22] = ACTIONS(2641),
    [aux_sym_basic_type_token48] = ACTIONS(2641),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2641),
    [anon_sym_POUNDif] = ACTIONS(2643),
    [anon_sym_POUNDIF] = ACTIONS(2643),
    [anon_sym_POUNDIf] = ACTIONS(2643),
    [anon_sym_not] = ACTIONS(2641),
    [anon_sym_NOT] = ACTIONS(2641),
    [anon_sym_Not] = ACTIONS(2641),
    [anon_sym_POUNDelse] = ACTIONS(2643),
    [anon_sym_POUNDELSE] = ACTIONS(2643),
    [anon_sym_POUNDElse] = ACTIONS(2643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2643),
    [aux_sym__expression_token1] = ACTIONS(2643),
    [aux_sym__expression_token2] = ACTIONS(2641),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2641),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2641),
    [anon_sym_SLASH] = ACTIONS(2641),
    [anon_sym_div] = ACTIONS(2641),
    [anon_sym_DIV] = ACTIONS(2641),
    [anon_sym_Div] = ACTIONS(2641),
    [anon_sym_mod] = ACTIONS(2641),
    [anon_sym_MOD] = ACTIONS(2641),
    [anon_sym_Mod] = ACTIONS(2641),
    [anon_sym_PLUS] = ACTIONS(2641),
    [anon_sym_GT_EQ] = ACTIONS(2643),
    [anon_sym_LT_EQ] = ACTIONS(2643),
    [anon_sym_GT] = ACTIONS(2641),
    [anon_sym_LT] = ACTIONS(2641),
    [anon_sym_LT_GT] = ACTIONS(2643),
    [anon_sym_and] = ACTIONS(2641),
    [anon_sym_AND] = ACTIONS(2641),
    [anon_sym_And] = ACTIONS(2641),
    [anon_sym_or] = ACTIONS(2641),
    [anon_sym_OR] = ACTIONS(2641),
    [anon_sym_Or] = ACTIONS(2641),
    [anon_sym_xor] = ACTIONS(2641),
    [anon_sym_XOR] = ACTIONS(2641),
    [anon_sym_Xor] = ACTIONS(2641),
    [anon_sym_QMARK] = ACTIONS(2643),
    [sym_datetime_literal] = ACTIONS(2643),
    [sym_date_literal] = ACTIONS(2641),
    [sym_time_literal] = ACTIONS(2641),
    [sym_biginteger_literal] = ACTIONS(2643),
    [anon_sym_if] = ACTIONS(2641),
    [anon_sym_IF] = ACTIONS(2641),
    [anon_sym_If] = ACTIONS(2641),
    [anon_sym_else] = ACTIONS(2641),
    [anon_sym_ELSE] = ACTIONS(2641),
    [anon_sym_Else] = ACTIONS(2641),
    [anon_sym_case] = ACTIONS(2641),
    [anon_sym_CASE] = ACTIONS(2641),
    [anon_sym_Case] = ACTIONS(2641),
    [anon_sym_for] = ACTIONS(2641),
    [anon_sym_FOR] = ACTIONS(2641),
    [anon_sym_For] = ACTIONS(2641),
    [anon_sym_foreach] = ACTIONS(2641),
    [anon_sym_FOREACH] = ACTIONS(2641),
    [anon_sym_Foreach] = ACTIONS(2641),
    [anon_sym_while] = ACTIONS(2641),
    [anon_sym_WHILE] = ACTIONS(2641),
    [anon_sym_While] = ACTIONS(2641),
    [anon_sym_repeat] = ACTIONS(2641),
    [anon_sym_REPEAT] = ACTIONS(2641),
    [anon_sym_Repeat] = ACTIONS(2641),
    [anon_sym_until] = ACTIONS(2641),
    [anon_sym_UNTIL] = ACTIONS(2641),
    [anon_sym_Until] = ACTIONS(2641),
    [anon_sym_exit] = ACTIONS(2641),
    [anon_sym_EXIT] = ACTIONS(2641),
    [anon_sym_Exit] = ACTIONS(2641),
    [anon_sym_continue] = ACTIONS(2641),
    [anon_sym_CONTINUE] = ACTIONS(2641),
    [anon_sym_Continue] = ACTIONS(2641),
    [anon_sym_break] = ACTIONS(2641),
    [anon_sym_BREAK] = ACTIONS(2641),
    [anon_sym_Break] = ACTIONS(2641),
    [anon_sym_with] = ACTIONS(2641),
    [anon_sym_WITH] = ACTIONS(2641),
    [anon_sym_With] = ACTIONS(2641),
    [sym_asserterror_keyword] = ACTIONS(2643),
    [anon_sym_in] = ACTIONS(2641),
    [anon_sym_IN] = ACTIONS(2641),
    [anon_sym_In] = ACTIONS(2641),
    [sym_page_keyword] = ACTIONS(2641),
    [anon_sym_codeunit] = ACTIONS(2641),
    [anon_sym_CODEUNIT] = ACTIONS(2641),
    [anon_sym_Codeunit] = ACTIONS(2641),
    [anon_sym_CodeUnit] = ACTIONS(2641),
    [anon_sym_COdeunit] = ACTIONS(2641),
    [anon_sym_codeUnit] = ACTIONS(2641),
    [sym_report_keyword] = ACTIONS(2641),
    [sym_query_keyword] = ACTIONS(2641),
    [anon_sym_xmlport] = ACTIONS(2641),
    [anon_sym_XMLPORT] = ACTIONS(2641),
    [anon_sym_Xmlport] = ACTIONS(2641),
    [anon_sym_XMLport] = ACTIONS(2641),
    [anon_sym_XMLPort] = ACTIONS(2641),
    [anon_sym_XmlPort] = ACTIONS(2641),
    [anon_sym_enum] = ACTIONS(2641),
    [anon_sym_ENUM] = ACTIONS(2641),
    [anon_sym_Enum] = ACTIONS(2641),
    [anon_sym_eNUM] = ACTIONS(2641),
    [anon_sym_eNum] = ACTIONS(2641),
    [anon_sym_ENum] = ACTIONS(2641),
    [sym_quoted_identifier] = ACTIONS(2643),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2643),
    [sym_integer] = ACTIONS(2641),
    [sym_continue_as_identifier] = ACTIONS(2643),
    [sym_preproc_open] = ACTIONS(2643),
  },
  [STATE(1145)] = {
    [sym_identifier] = ACTIONS(2645),
    [anon_sym_SEMI] = ACTIONS(2647),
    [anon_sym_DOT] = ACTIONS(2645),
    [anon_sym_EQ] = ACTIONS(2647),
    [anon_sym_DASH] = ACTIONS(2645),
    [aux_sym_boolean_token1] = ACTIONS(2645),
    [aux_sym_boolean_token2] = ACTIONS(2645),
    [sym_decimal] = ACTIONS(2645),
    [anon_sym_LPAREN] = ACTIONS(2647),
    [anon_sym_DOT_DOT] = ACTIONS(2647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2645),
    [anon_sym_STAR] = ACTIONS(2645),
    [anon_sym_LBRACK] = ACTIONS(2647),
    [aux_sym_record_type_token1] = ACTIONS(2645),
    [aux_sym_basic_type_token21] = ACTIONS(2645),
    [aux_sym_basic_type_token22] = ACTIONS(2645),
    [aux_sym_basic_type_token48] = ACTIONS(2645),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2645),
    [anon_sym_POUNDif] = ACTIONS(2647),
    [anon_sym_POUNDIF] = ACTIONS(2647),
    [anon_sym_POUNDIf] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2645),
    [anon_sym_NOT] = ACTIONS(2645),
    [anon_sym_Not] = ACTIONS(2645),
    [anon_sym_POUNDelse] = ACTIONS(2647),
    [anon_sym_POUNDELSE] = ACTIONS(2647),
    [anon_sym_POUNDElse] = ACTIONS(2647),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2647),
    [aux_sym__expression_token1] = ACTIONS(2647),
    [aux_sym__expression_token2] = ACTIONS(2645),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2645),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2645),
    [anon_sym_SLASH] = ACTIONS(2645),
    [anon_sym_div] = ACTIONS(2645),
    [anon_sym_DIV] = ACTIONS(2645),
    [anon_sym_Div] = ACTIONS(2645),
    [anon_sym_mod] = ACTIONS(2645),
    [anon_sym_MOD] = ACTIONS(2645),
    [anon_sym_Mod] = ACTIONS(2645),
    [anon_sym_PLUS] = ACTIONS(2645),
    [anon_sym_GT_EQ] = ACTIONS(2647),
    [anon_sym_LT_EQ] = ACTIONS(2647),
    [anon_sym_GT] = ACTIONS(2645),
    [anon_sym_LT] = ACTIONS(2645),
    [anon_sym_LT_GT] = ACTIONS(2647),
    [anon_sym_and] = ACTIONS(2645),
    [anon_sym_AND] = ACTIONS(2645),
    [anon_sym_And] = ACTIONS(2645),
    [anon_sym_or] = ACTIONS(2645),
    [anon_sym_OR] = ACTIONS(2645),
    [anon_sym_Or] = ACTIONS(2645),
    [anon_sym_xor] = ACTIONS(2645),
    [anon_sym_XOR] = ACTIONS(2645),
    [anon_sym_Xor] = ACTIONS(2645),
    [anon_sym_QMARK] = ACTIONS(2647),
    [sym_datetime_literal] = ACTIONS(2647),
    [sym_date_literal] = ACTIONS(2645),
    [sym_time_literal] = ACTIONS(2645),
    [sym_biginteger_literal] = ACTIONS(2647),
    [anon_sym_if] = ACTIONS(2645),
    [anon_sym_IF] = ACTIONS(2645),
    [anon_sym_If] = ACTIONS(2645),
    [anon_sym_else] = ACTIONS(2645),
    [anon_sym_ELSE] = ACTIONS(2645),
    [anon_sym_Else] = ACTIONS(2645),
    [anon_sym_case] = ACTIONS(2645),
    [anon_sym_CASE] = ACTIONS(2645),
    [anon_sym_Case] = ACTIONS(2645),
    [anon_sym_for] = ACTIONS(2645),
    [anon_sym_FOR] = ACTIONS(2645),
    [anon_sym_For] = ACTIONS(2645),
    [anon_sym_foreach] = ACTIONS(2645),
    [anon_sym_FOREACH] = ACTIONS(2645),
    [anon_sym_Foreach] = ACTIONS(2645),
    [anon_sym_while] = ACTIONS(2645),
    [anon_sym_WHILE] = ACTIONS(2645),
    [anon_sym_While] = ACTIONS(2645),
    [anon_sym_repeat] = ACTIONS(2645),
    [anon_sym_REPEAT] = ACTIONS(2645),
    [anon_sym_Repeat] = ACTIONS(2645),
    [anon_sym_until] = ACTIONS(2645),
    [anon_sym_UNTIL] = ACTIONS(2645),
    [anon_sym_Until] = ACTIONS(2645),
    [anon_sym_exit] = ACTIONS(2645),
    [anon_sym_EXIT] = ACTIONS(2645),
    [anon_sym_Exit] = ACTIONS(2645),
    [anon_sym_continue] = ACTIONS(2645),
    [anon_sym_CONTINUE] = ACTIONS(2645),
    [anon_sym_Continue] = ACTIONS(2645),
    [anon_sym_break] = ACTIONS(2645),
    [anon_sym_BREAK] = ACTIONS(2645),
    [anon_sym_Break] = ACTIONS(2645),
    [anon_sym_with] = ACTIONS(2645),
    [anon_sym_WITH] = ACTIONS(2645),
    [anon_sym_With] = ACTIONS(2645),
    [sym_asserterror_keyword] = ACTIONS(2647),
    [anon_sym_in] = ACTIONS(2645),
    [anon_sym_IN] = ACTIONS(2645),
    [anon_sym_In] = ACTIONS(2645),
    [sym_page_keyword] = ACTIONS(2645),
    [anon_sym_codeunit] = ACTIONS(2645),
    [anon_sym_CODEUNIT] = ACTIONS(2645),
    [anon_sym_Codeunit] = ACTIONS(2645),
    [anon_sym_CodeUnit] = ACTIONS(2645),
    [anon_sym_COdeunit] = ACTIONS(2645),
    [anon_sym_codeUnit] = ACTIONS(2645),
    [sym_report_keyword] = ACTIONS(2645),
    [sym_query_keyword] = ACTIONS(2645),
    [anon_sym_xmlport] = ACTIONS(2645),
    [anon_sym_XMLPORT] = ACTIONS(2645),
    [anon_sym_Xmlport] = ACTIONS(2645),
    [anon_sym_XMLport] = ACTIONS(2645),
    [anon_sym_XMLPort] = ACTIONS(2645),
    [anon_sym_XmlPort] = ACTIONS(2645),
    [anon_sym_enum] = ACTIONS(2645),
    [anon_sym_ENUM] = ACTIONS(2645),
    [anon_sym_Enum] = ACTIONS(2645),
    [anon_sym_eNUM] = ACTIONS(2645),
    [anon_sym_eNum] = ACTIONS(2645),
    [anon_sym_ENum] = ACTIONS(2645),
    [sym_quoted_identifier] = ACTIONS(2647),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2647),
    [sym_integer] = ACTIONS(2645),
    [sym_continue_as_identifier] = ACTIONS(2647),
    [sym_preproc_open] = ACTIONS(2647),
  },
  [STATE(1146)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_SEMI] = ACTIONS(2591),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2589),
    [anon_sym_POUNDif] = ACTIONS(2591),
    [anon_sym_POUNDIF] = ACTIONS(2591),
    [anon_sym_POUNDIf] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [anon_sym_POUNDelse] = ACTIONS(2591),
    [anon_sym_POUNDELSE] = ACTIONS(2591),
    [anon_sym_POUNDElse] = ACTIONS(2591),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_if] = ACTIONS(2589),
    [anon_sym_IF] = ACTIONS(2589),
    [anon_sym_If] = ACTIONS(2589),
    [anon_sym_else] = ACTIONS(2589),
    [anon_sym_ELSE] = ACTIONS(2589),
    [anon_sym_Else] = ACTIONS(2589),
    [anon_sym_case] = ACTIONS(2589),
    [anon_sym_CASE] = ACTIONS(2589),
    [anon_sym_Case] = ACTIONS(2589),
    [anon_sym_for] = ACTIONS(2589),
    [anon_sym_FOR] = ACTIONS(2589),
    [anon_sym_For] = ACTIONS(2589),
    [anon_sym_foreach] = ACTIONS(2589),
    [anon_sym_FOREACH] = ACTIONS(2589),
    [anon_sym_Foreach] = ACTIONS(2589),
    [anon_sym_while] = ACTIONS(2589),
    [anon_sym_WHILE] = ACTIONS(2589),
    [anon_sym_While] = ACTIONS(2589),
    [anon_sym_repeat] = ACTIONS(2589),
    [anon_sym_REPEAT] = ACTIONS(2589),
    [anon_sym_Repeat] = ACTIONS(2589),
    [anon_sym_until] = ACTIONS(2589),
    [anon_sym_UNTIL] = ACTIONS(2589),
    [anon_sym_Until] = ACTIONS(2589),
    [anon_sym_exit] = ACTIONS(2589),
    [anon_sym_EXIT] = ACTIONS(2589),
    [anon_sym_Exit] = ACTIONS(2589),
    [anon_sym_continue] = ACTIONS(2589),
    [anon_sym_CONTINUE] = ACTIONS(2589),
    [anon_sym_Continue] = ACTIONS(2589),
    [anon_sym_break] = ACTIONS(2589),
    [anon_sym_BREAK] = ACTIONS(2589),
    [anon_sym_Break] = ACTIONS(2589),
    [anon_sym_with] = ACTIONS(2589),
    [anon_sym_WITH] = ACTIONS(2589),
    [anon_sym_With] = ACTIONS(2589),
    [sym_asserterror_keyword] = ACTIONS(2591),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_open] = ACTIONS(2591),
  },
  [STATE(1147)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_SEMI] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2593),
    [anon_sym_POUNDif] = ACTIONS(2595),
    [anon_sym_POUNDIF] = ACTIONS(2595),
    [anon_sym_POUNDIf] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [anon_sym_POUNDelse] = ACTIONS(2595),
    [anon_sym_POUNDELSE] = ACTIONS(2595),
    [anon_sym_POUNDElse] = ACTIONS(2595),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_if] = ACTIONS(2593),
    [anon_sym_IF] = ACTIONS(2593),
    [anon_sym_If] = ACTIONS(2593),
    [anon_sym_else] = ACTIONS(2593),
    [anon_sym_ELSE] = ACTIONS(2593),
    [anon_sym_Else] = ACTIONS(2593),
    [anon_sym_case] = ACTIONS(2593),
    [anon_sym_CASE] = ACTIONS(2593),
    [anon_sym_Case] = ACTIONS(2593),
    [anon_sym_for] = ACTIONS(2593),
    [anon_sym_FOR] = ACTIONS(2593),
    [anon_sym_For] = ACTIONS(2593),
    [anon_sym_foreach] = ACTIONS(2593),
    [anon_sym_FOREACH] = ACTIONS(2593),
    [anon_sym_Foreach] = ACTIONS(2593),
    [anon_sym_while] = ACTIONS(2593),
    [anon_sym_WHILE] = ACTIONS(2593),
    [anon_sym_While] = ACTIONS(2593),
    [anon_sym_repeat] = ACTIONS(2593),
    [anon_sym_REPEAT] = ACTIONS(2593),
    [anon_sym_Repeat] = ACTIONS(2593),
    [anon_sym_until] = ACTIONS(2593),
    [anon_sym_UNTIL] = ACTIONS(2593),
    [anon_sym_Until] = ACTIONS(2593),
    [anon_sym_exit] = ACTIONS(2593),
    [anon_sym_EXIT] = ACTIONS(2593),
    [anon_sym_Exit] = ACTIONS(2593),
    [anon_sym_continue] = ACTIONS(2593),
    [anon_sym_CONTINUE] = ACTIONS(2593),
    [anon_sym_Continue] = ACTIONS(2593),
    [anon_sym_break] = ACTIONS(2593),
    [anon_sym_BREAK] = ACTIONS(2593),
    [anon_sym_Break] = ACTIONS(2593),
    [anon_sym_with] = ACTIONS(2593),
    [anon_sym_WITH] = ACTIONS(2593),
    [anon_sym_With] = ACTIONS(2593),
    [sym_asserterror_keyword] = ACTIONS(2595),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_open] = ACTIONS(2595),
  },
  [STATE(1148)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_SEMI] = ACTIONS(2591),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2589),
    [anon_sym_POUNDif] = ACTIONS(2591),
    [anon_sym_POUNDIF] = ACTIONS(2591),
    [anon_sym_POUNDIf] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [anon_sym_POUNDelse] = ACTIONS(2591),
    [anon_sym_POUNDELSE] = ACTIONS(2591),
    [anon_sym_POUNDElse] = ACTIONS(2591),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_if] = ACTIONS(2589),
    [anon_sym_IF] = ACTIONS(2589),
    [anon_sym_If] = ACTIONS(2589),
    [anon_sym_else] = ACTIONS(2589),
    [anon_sym_ELSE] = ACTIONS(2589),
    [anon_sym_Else] = ACTIONS(2589),
    [anon_sym_case] = ACTIONS(2589),
    [anon_sym_CASE] = ACTIONS(2589),
    [anon_sym_Case] = ACTIONS(2589),
    [anon_sym_for] = ACTIONS(2589),
    [anon_sym_FOR] = ACTIONS(2589),
    [anon_sym_For] = ACTIONS(2589),
    [anon_sym_foreach] = ACTIONS(2589),
    [anon_sym_FOREACH] = ACTIONS(2589),
    [anon_sym_Foreach] = ACTIONS(2589),
    [anon_sym_while] = ACTIONS(2589),
    [anon_sym_WHILE] = ACTIONS(2589),
    [anon_sym_While] = ACTIONS(2589),
    [anon_sym_repeat] = ACTIONS(2589),
    [anon_sym_REPEAT] = ACTIONS(2589),
    [anon_sym_Repeat] = ACTIONS(2589),
    [anon_sym_until] = ACTIONS(2589),
    [anon_sym_UNTIL] = ACTIONS(2589),
    [anon_sym_Until] = ACTIONS(2589),
    [anon_sym_exit] = ACTIONS(2589),
    [anon_sym_EXIT] = ACTIONS(2589),
    [anon_sym_Exit] = ACTIONS(2589),
    [anon_sym_continue] = ACTIONS(2589),
    [anon_sym_CONTINUE] = ACTIONS(2589),
    [anon_sym_Continue] = ACTIONS(2589),
    [anon_sym_break] = ACTIONS(2589),
    [anon_sym_BREAK] = ACTIONS(2589),
    [anon_sym_Break] = ACTIONS(2589),
    [anon_sym_with] = ACTIONS(2589),
    [anon_sym_WITH] = ACTIONS(2589),
    [anon_sym_With] = ACTIONS(2589),
    [sym_asserterror_keyword] = ACTIONS(2591),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_open] = ACTIONS(2591),
  },
  [STATE(1149)] = {
    [sym_identifier] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym_DOT] = ACTIONS(2573),
    [anon_sym_EQ] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2573),
    [aux_sym_boolean_token1] = ACTIONS(2573),
    [aux_sym_boolean_token2] = ACTIONS(2573),
    [sym_decimal] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2575),
    [anon_sym_DOT_DOT] = ACTIONS(2575),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2575),
    [aux_sym_record_type_token1] = ACTIONS(2573),
    [aux_sym_basic_type_token21] = ACTIONS(2573),
    [aux_sym_basic_type_token22] = ACTIONS(2573),
    [aux_sym_basic_type_token48] = ACTIONS(2573),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2573),
    [anon_sym_POUNDif] = ACTIONS(2575),
    [anon_sym_POUNDIF] = ACTIONS(2575),
    [anon_sym_POUNDIf] = ACTIONS(2575),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_NOT] = ACTIONS(2573),
    [anon_sym_Not] = ACTIONS(2573),
    [anon_sym_POUNDelse] = ACTIONS(2575),
    [anon_sym_POUNDELSE] = ACTIONS(2575),
    [anon_sym_POUNDElse] = ACTIONS(2575),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2575),
    [aux_sym__expression_token1] = ACTIONS(2575),
    [aux_sym__expression_token2] = ACTIONS(2573),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2573),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2573),
    [anon_sym_SLASH] = ACTIONS(2573),
    [anon_sym_div] = ACTIONS(2573),
    [anon_sym_DIV] = ACTIONS(2573),
    [anon_sym_Div] = ACTIONS(2573),
    [anon_sym_mod] = ACTIONS(2573),
    [anon_sym_MOD] = ACTIONS(2573),
    [anon_sym_Mod] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_GT_EQ] = ACTIONS(2575),
    [anon_sym_LT_EQ] = ACTIONS(2575),
    [anon_sym_GT] = ACTIONS(2573),
    [anon_sym_LT] = ACTIONS(2573),
    [anon_sym_LT_GT] = ACTIONS(2575),
    [anon_sym_and] = ACTIONS(2573),
    [anon_sym_AND] = ACTIONS(2573),
    [anon_sym_And] = ACTIONS(2573),
    [anon_sym_or] = ACTIONS(2573),
    [anon_sym_OR] = ACTIONS(2573),
    [anon_sym_Or] = ACTIONS(2573),
    [anon_sym_xor] = ACTIONS(2573),
    [anon_sym_XOR] = ACTIONS(2573),
    [anon_sym_Xor] = ACTIONS(2573),
    [anon_sym_QMARK] = ACTIONS(2575),
    [sym_datetime_literal] = ACTIONS(2575),
    [sym_date_literal] = ACTIONS(2573),
    [sym_time_literal] = ACTIONS(2573),
    [sym_biginteger_literal] = ACTIONS(2575),
    [anon_sym_if] = ACTIONS(2573),
    [anon_sym_IF] = ACTIONS(2573),
    [anon_sym_If] = ACTIONS(2573),
    [anon_sym_else] = ACTIONS(2573),
    [anon_sym_ELSE] = ACTIONS(2573),
    [anon_sym_Else] = ACTIONS(2573),
    [anon_sym_case] = ACTIONS(2573),
    [anon_sym_CASE] = ACTIONS(2573),
    [anon_sym_Case] = ACTIONS(2573),
    [anon_sym_for] = ACTIONS(2573),
    [anon_sym_FOR] = ACTIONS(2573),
    [anon_sym_For] = ACTIONS(2573),
    [anon_sym_foreach] = ACTIONS(2573),
    [anon_sym_FOREACH] = ACTIONS(2573),
    [anon_sym_Foreach] = ACTIONS(2573),
    [anon_sym_while] = ACTIONS(2573),
    [anon_sym_WHILE] = ACTIONS(2573),
    [anon_sym_While] = ACTIONS(2573),
    [anon_sym_repeat] = ACTIONS(2573),
    [anon_sym_REPEAT] = ACTIONS(2573),
    [anon_sym_Repeat] = ACTIONS(2573),
    [anon_sym_until] = ACTIONS(2573),
    [anon_sym_UNTIL] = ACTIONS(2573),
    [anon_sym_Until] = ACTIONS(2573),
    [anon_sym_exit] = ACTIONS(2573),
    [anon_sym_EXIT] = ACTIONS(2573),
    [anon_sym_Exit] = ACTIONS(2573),
    [anon_sym_continue] = ACTIONS(2573),
    [anon_sym_CONTINUE] = ACTIONS(2573),
    [anon_sym_Continue] = ACTIONS(2573),
    [anon_sym_break] = ACTIONS(2573),
    [anon_sym_BREAK] = ACTIONS(2573),
    [anon_sym_Break] = ACTIONS(2573),
    [anon_sym_with] = ACTIONS(2573),
    [anon_sym_WITH] = ACTIONS(2573),
    [anon_sym_With] = ACTIONS(2573),
    [sym_asserterror_keyword] = ACTIONS(2575),
    [anon_sym_in] = ACTIONS(2573),
    [anon_sym_IN] = ACTIONS(2573),
    [anon_sym_In] = ACTIONS(2573),
    [sym_page_keyword] = ACTIONS(2573),
    [anon_sym_codeunit] = ACTIONS(2573),
    [anon_sym_CODEUNIT] = ACTIONS(2573),
    [anon_sym_Codeunit] = ACTIONS(2573),
    [anon_sym_CodeUnit] = ACTIONS(2573),
    [anon_sym_COdeunit] = ACTIONS(2573),
    [anon_sym_codeUnit] = ACTIONS(2573),
    [sym_report_keyword] = ACTIONS(2573),
    [sym_query_keyword] = ACTIONS(2573),
    [anon_sym_xmlport] = ACTIONS(2573),
    [anon_sym_XMLPORT] = ACTIONS(2573),
    [anon_sym_Xmlport] = ACTIONS(2573),
    [anon_sym_XMLport] = ACTIONS(2573),
    [anon_sym_XMLPort] = ACTIONS(2573),
    [anon_sym_XmlPort] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_ENUM] = ACTIONS(2573),
    [anon_sym_Enum] = ACTIONS(2573),
    [anon_sym_eNUM] = ACTIONS(2573),
    [anon_sym_eNum] = ACTIONS(2573),
    [anon_sym_ENum] = ACTIONS(2573),
    [sym_quoted_identifier] = ACTIONS(2575),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2575),
    [sym_integer] = ACTIONS(2573),
    [sym_continue_as_identifier] = ACTIONS(2575),
    [sym_preproc_open] = ACTIONS(2575),
  },
  [STATE(1150)] = {
    [sym_identifier] = ACTIONS(2577),
    [anon_sym_SEMI] = ACTIONS(2579),
    [anon_sym_DOT] = ACTIONS(2577),
    [anon_sym_EQ] = ACTIONS(2579),
    [anon_sym_DASH] = ACTIONS(2577),
    [aux_sym_boolean_token1] = ACTIONS(2577),
    [aux_sym_boolean_token2] = ACTIONS(2577),
    [sym_decimal] = ACTIONS(2577),
    [anon_sym_LPAREN] = ACTIONS(2579),
    [anon_sym_DOT_DOT] = ACTIONS(2579),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2577),
    [anon_sym_STAR] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [aux_sym_record_type_token1] = ACTIONS(2577),
    [aux_sym_basic_type_token21] = ACTIONS(2577),
    [aux_sym_basic_type_token22] = ACTIONS(2577),
    [aux_sym_basic_type_token48] = ACTIONS(2577),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2577),
    [anon_sym_POUNDif] = ACTIONS(2579),
    [anon_sym_POUNDIF] = ACTIONS(2579),
    [anon_sym_POUNDIf] = ACTIONS(2579),
    [anon_sym_not] = ACTIONS(2577),
    [anon_sym_NOT] = ACTIONS(2577),
    [anon_sym_Not] = ACTIONS(2577),
    [anon_sym_POUNDelse] = ACTIONS(2579),
    [anon_sym_POUNDELSE] = ACTIONS(2579),
    [anon_sym_POUNDElse] = ACTIONS(2579),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2579),
    [aux_sym__expression_token1] = ACTIONS(2579),
    [aux_sym__expression_token2] = ACTIONS(2577),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2577),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2577),
    [anon_sym_SLASH] = ACTIONS(2577),
    [anon_sym_div] = ACTIONS(2577),
    [anon_sym_DIV] = ACTIONS(2577),
    [anon_sym_Div] = ACTIONS(2577),
    [anon_sym_mod] = ACTIONS(2577),
    [anon_sym_MOD] = ACTIONS(2577),
    [anon_sym_Mod] = ACTIONS(2577),
    [anon_sym_PLUS] = ACTIONS(2577),
    [anon_sym_GT_EQ] = ACTIONS(2579),
    [anon_sym_LT_EQ] = ACTIONS(2579),
    [anon_sym_GT] = ACTIONS(2577),
    [anon_sym_LT] = ACTIONS(2577),
    [anon_sym_LT_GT] = ACTIONS(2579),
    [anon_sym_and] = ACTIONS(2577),
    [anon_sym_AND] = ACTIONS(2577),
    [anon_sym_And] = ACTIONS(2577),
    [anon_sym_or] = ACTIONS(2577),
    [anon_sym_OR] = ACTIONS(2577),
    [anon_sym_Or] = ACTIONS(2577),
    [anon_sym_xor] = ACTIONS(2577),
    [anon_sym_XOR] = ACTIONS(2577),
    [anon_sym_Xor] = ACTIONS(2577),
    [anon_sym_QMARK] = ACTIONS(2579),
    [sym_datetime_literal] = ACTIONS(2579),
    [sym_date_literal] = ACTIONS(2577),
    [sym_time_literal] = ACTIONS(2577),
    [sym_biginteger_literal] = ACTIONS(2579),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_IF] = ACTIONS(2577),
    [anon_sym_If] = ACTIONS(2577),
    [anon_sym_else] = ACTIONS(2577),
    [anon_sym_ELSE] = ACTIONS(2577),
    [anon_sym_Else] = ACTIONS(2577),
    [anon_sym_case] = ACTIONS(2577),
    [anon_sym_CASE] = ACTIONS(2577),
    [anon_sym_Case] = ACTIONS(2577),
    [anon_sym_for] = ACTIONS(2577),
    [anon_sym_FOR] = ACTIONS(2577),
    [anon_sym_For] = ACTIONS(2577),
    [anon_sym_foreach] = ACTIONS(2577),
    [anon_sym_FOREACH] = ACTIONS(2577),
    [anon_sym_Foreach] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(2577),
    [anon_sym_WHILE] = ACTIONS(2577),
    [anon_sym_While] = ACTIONS(2577),
    [anon_sym_repeat] = ACTIONS(2577),
    [anon_sym_REPEAT] = ACTIONS(2577),
    [anon_sym_Repeat] = ACTIONS(2577),
    [anon_sym_until] = ACTIONS(2577),
    [anon_sym_UNTIL] = ACTIONS(2577),
    [anon_sym_Until] = ACTIONS(2577),
    [anon_sym_exit] = ACTIONS(2577),
    [anon_sym_EXIT] = ACTIONS(2577),
    [anon_sym_Exit] = ACTIONS(2577),
    [anon_sym_continue] = ACTIONS(2577),
    [anon_sym_CONTINUE] = ACTIONS(2577),
    [anon_sym_Continue] = ACTIONS(2577),
    [anon_sym_break] = ACTIONS(2577),
    [anon_sym_BREAK] = ACTIONS(2577),
    [anon_sym_Break] = ACTIONS(2577),
    [anon_sym_with] = ACTIONS(2577),
    [anon_sym_WITH] = ACTIONS(2577),
    [anon_sym_With] = ACTIONS(2577),
    [sym_asserterror_keyword] = ACTIONS(2579),
    [anon_sym_in] = ACTIONS(2577),
    [anon_sym_IN] = ACTIONS(2577),
    [anon_sym_In] = ACTIONS(2577),
    [sym_page_keyword] = ACTIONS(2577),
    [anon_sym_codeunit] = ACTIONS(2577),
    [anon_sym_CODEUNIT] = ACTIONS(2577),
    [anon_sym_Codeunit] = ACTIONS(2577),
    [anon_sym_CodeUnit] = ACTIONS(2577),
    [anon_sym_COdeunit] = ACTIONS(2577),
    [anon_sym_codeUnit] = ACTIONS(2577),
    [sym_report_keyword] = ACTIONS(2577),
    [sym_query_keyword] = ACTIONS(2577),
    [anon_sym_xmlport] = ACTIONS(2577),
    [anon_sym_XMLPORT] = ACTIONS(2577),
    [anon_sym_Xmlport] = ACTIONS(2577),
    [anon_sym_XMLport] = ACTIONS(2577),
    [anon_sym_XMLPort] = ACTIONS(2577),
    [anon_sym_XmlPort] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_ENUM] = ACTIONS(2577),
    [anon_sym_Enum] = ACTIONS(2577),
    [anon_sym_eNUM] = ACTIONS(2577),
    [anon_sym_eNum] = ACTIONS(2577),
    [anon_sym_ENum] = ACTIONS(2577),
    [sym_quoted_identifier] = ACTIONS(2579),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2579),
    [sym_integer] = ACTIONS(2577),
    [sym_continue_as_identifier] = ACTIONS(2579),
    [sym_preproc_open] = ACTIONS(2579),
  },
  [STATE(1151)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_SEMI] = ACTIONS(2591),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2589),
    [anon_sym_POUNDif] = ACTIONS(2591),
    [anon_sym_POUNDIF] = ACTIONS(2591),
    [anon_sym_POUNDIf] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [anon_sym_POUNDelse] = ACTIONS(2591),
    [anon_sym_POUNDELSE] = ACTIONS(2591),
    [anon_sym_POUNDElse] = ACTIONS(2591),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_if] = ACTIONS(2589),
    [anon_sym_IF] = ACTIONS(2589),
    [anon_sym_If] = ACTIONS(2589),
    [anon_sym_else] = ACTIONS(2589),
    [anon_sym_ELSE] = ACTIONS(2589),
    [anon_sym_Else] = ACTIONS(2589),
    [anon_sym_case] = ACTIONS(2589),
    [anon_sym_CASE] = ACTIONS(2589),
    [anon_sym_Case] = ACTIONS(2589),
    [anon_sym_for] = ACTIONS(2589),
    [anon_sym_FOR] = ACTIONS(2589),
    [anon_sym_For] = ACTIONS(2589),
    [anon_sym_foreach] = ACTIONS(2589),
    [anon_sym_FOREACH] = ACTIONS(2589),
    [anon_sym_Foreach] = ACTIONS(2589),
    [anon_sym_while] = ACTIONS(2589),
    [anon_sym_WHILE] = ACTIONS(2589),
    [anon_sym_While] = ACTIONS(2589),
    [anon_sym_repeat] = ACTIONS(2589),
    [anon_sym_REPEAT] = ACTIONS(2589),
    [anon_sym_Repeat] = ACTIONS(2589),
    [anon_sym_until] = ACTIONS(2589),
    [anon_sym_UNTIL] = ACTIONS(2589),
    [anon_sym_Until] = ACTIONS(2589),
    [anon_sym_exit] = ACTIONS(2589),
    [anon_sym_EXIT] = ACTIONS(2589),
    [anon_sym_Exit] = ACTIONS(2589),
    [anon_sym_continue] = ACTIONS(2589),
    [anon_sym_CONTINUE] = ACTIONS(2589),
    [anon_sym_Continue] = ACTIONS(2589),
    [anon_sym_break] = ACTIONS(2589),
    [anon_sym_BREAK] = ACTIONS(2589),
    [anon_sym_Break] = ACTIONS(2589),
    [anon_sym_with] = ACTIONS(2589),
    [anon_sym_WITH] = ACTIONS(2589),
    [anon_sym_With] = ACTIONS(2589),
    [sym_asserterror_keyword] = ACTIONS(2591),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_open] = ACTIONS(2591),
  },
  [STATE(1152)] = {
    [sym_identifier] = ACTIONS(2581),
    [anon_sym_SEMI] = ACTIONS(2583),
    [anon_sym_DOT] = ACTIONS(2581),
    [anon_sym_EQ] = ACTIONS(2583),
    [anon_sym_DASH] = ACTIONS(2581),
    [aux_sym_boolean_token1] = ACTIONS(2581),
    [aux_sym_boolean_token2] = ACTIONS(2581),
    [sym_decimal] = ACTIONS(2581),
    [anon_sym_LPAREN] = ACTIONS(2583),
    [anon_sym_DOT_DOT] = ACTIONS(2583),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2581),
    [anon_sym_STAR] = ACTIONS(2581),
    [anon_sym_LBRACK] = ACTIONS(2583),
    [aux_sym_record_type_token1] = ACTIONS(2581),
    [aux_sym_basic_type_token21] = ACTIONS(2581),
    [aux_sym_basic_type_token22] = ACTIONS(2581),
    [aux_sym_basic_type_token48] = ACTIONS(2581),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2581),
    [anon_sym_POUNDif] = ACTIONS(2583),
    [anon_sym_POUNDIF] = ACTIONS(2583),
    [anon_sym_POUNDIf] = ACTIONS(2583),
    [anon_sym_not] = ACTIONS(2581),
    [anon_sym_NOT] = ACTIONS(2581),
    [anon_sym_Not] = ACTIONS(2581),
    [anon_sym_POUNDelse] = ACTIONS(2583),
    [anon_sym_POUNDELSE] = ACTIONS(2583),
    [anon_sym_POUNDElse] = ACTIONS(2583),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2583),
    [aux_sym__expression_token1] = ACTIONS(2583),
    [aux_sym__expression_token2] = ACTIONS(2581),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2581),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2581),
    [anon_sym_SLASH] = ACTIONS(2581),
    [anon_sym_div] = ACTIONS(2581),
    [anon_sym_DIV] = ACTIONS(2581),
    [anon_sym_Div] = ACTIONS(2581),
    [anon_sym_mod] = ACTIONS(2581),
    [anon_sym_MOD] = ACTIONS(2581),
    [anon_sym_Mod] = ACTIONS(2581),
    [anon_sym_PLUS] = ACTIONS(2581),
    [anon_sym_GT_EQ] = ACTIONS(2583),
    [anon_sym_LT_EQ] = ACTIONS(2583),
    [anon_sym_GT] = ACTIONS(2581),
    [anon_sym_LT] = ACTIONS(2581),
    [anon_sym_LT_GT] = ACTIONS(2583),
    [anon_sym_and] = ACTIONS(2581),
    [anon_sym_AND] = ACTIONS(2581),
    [anon_sym_And] = ACTIONS(2581),
    [anon_sym_or] = ACTIONS(2581),
    [anon_sym_OR] = ACTIONS(2581),
    [anon_sym_Or] = ACTIONS(2581),
    [anon_sym_xor] = ACTIONS(2581),
    [anon_sym_XOR] = ACTIONS(2581),
    [anon_sym_Xor] = ACTIONS(2581),
    [anon_sym_QMARK] = ACTIONS(2583),
    [sym_datetime_literal] = ACTIONS(2583),
    [sym_date_literal] = ACTIONS(2581),
    [sym_time_literal] = ACTIONS(2581),
    [sym_biginteger_literal] = ACTIONS(2583),
    [anon_sym_if] = ACTIONS(2581),
    [anon_sym_IF] = ACTIONS(2581),
    [anon_sym_If] = ACTIONS(2581),
    [anon_sym_else] = ACTIONS(2581),
    [anon_sym_ELSE] = ACTIONS(2581),
    [anon_sym_Else] = ACTIONS(2581),
    [anon_sym_case] = ACTIONS(2581),
    [anon_sym_CASE] = ACTIONS(2581),
    [anon_sym_Case] = ACTIONS(2581),
    [anon_sym_for] = ACTIONS(2581),
    [anon_sym_FOR] = ACTIONS(2581),
    [anon_sym_For] = ACTIONS(2581),
    [anon_sym_foreach] = ACTIONS(2581),
    [anon_sym_FOREACH] = ACTIONS(2581),
    [anon_sym_Foreach] = ACTIONS(2581),
    [anon_sym_while] = ACTIONS(2581),
    [anon_sym_WHILE] = ACTIONS(2581),
    [anon_sym_While] = ACTIONS(2581),
    [anon_sym_repeat] = ACTIONS(2581),
    [anon_sym_REPEAT] = ACTIONS(2581),
    [anon_sym_Repeat] = ACTIONS(2581),
    [anon_sym_until] = ACTIONS(2581),
    [anon_sym_UNTIL] = ACTIONS(2581),
    [anon_sym_Until] = ACTIONS(2581),
    [anon_sym_exit] = ACTIONS(2581),
    [anon_sym_EXIT] = ACTIONS(2581),
    [anon_sym_Exit] = ACTIONS(2581),
    [anon_sym_continue] = ACTIONS(2581),
    [anon_sym_CONTINUE] = ACTIONS(2581),
    [anon_sym_Continue] = ACTIONS(2581),
    [anon_sym_break] = ACTIONS(2581),
    [anon_sym_BREAK] = ACTIONS(2581),
    [anon_sym_Break] = ACTIONS(2581),
    [anon_sym_with] = ACTIONS(2581),
    [anon_sym_WITH] = ACTIONS(2581),
    [anon_sym_With] = ACTIONS(2581),
    [sym_asserterror_keyword] = ACTIONS(2583),
    [anon_sym_in] = ACTIONS(2581),
    [anon_sym_IN] = ACTIONS(2581),
    [anon_sym_In] = ACTIONS(2581),
    [sym_page_keyword] = ACTIONS(2581),
    [anon_sym_codeunit] = ACTIONS(2581),
    [anon_sym_CODEUNIT] = ACTIONS(2581),
    [anon_sym_Codeunit] = ACTIONS(2581),
    [anon_sym_CodeUnit] = ACTIONS(2581),
    [anon_sym_COdeunit] = ACTIONS(2581),
    [anon_sym_codeUnit] = ACTIONS(2581),
    [sym_report_keyword] = ACTIONS(2581),
    [sym_query_keyword] = ACTIONS(2581),
    [anon_sym_xmlport] = ACTIONS(2581),
    [anon_sym_XMLPORT] = ACTIONS(2581),
    [anon_sym_Xmlport] = ACTIONS(2581),
    [anon_sym_XMLport] = ACTIONS(2581),
    [anon_sym_XMLPort] = ACTIONS(2581),
    [anon_sym_XmlPort] = ACTIONS(2581),
    [anon_sym_enum] = ACTIONS(2581),
    [anon_sym_ENUM] = ACTIONS(2581),
    [anon_sym_Enum] = ACTIONS(2581),
    [anon_sym_eNUM] = ACTIONS(2581),
    [anon_sym_eNum] = ACTIONS(2581),
    [anon_sym_ENum] = ACTIONS(2581),
    [sym_quoted_identifier] = ACTIONS(2583),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2583),
    [sym_integer] = ACTIONS(2581),
    [sym_continue_as_identifier] = ACTIONS(2583),
    [sym_preproc_open] = ACTIONS(2583),
  },
  [STATE(1153)] = {
    [sym_identifier] = ACTIONS(2266),
    [anon_sym_SEMI] = ACTIONS(2268),
    [anon_sym_DOT] = ACTIONS(2266),
    [anon_sym_EQ] = ACTIONS(2268),
    [anon_sym_COMMA] = ACTIONS(2268),
    [anon_sym_DASH] = ACTIONS(2266),
    [aux_sym_boolean_token1] = ACTIONS(2266),
    [aux_sym_boolean_token2] = ACTIONS(2266),
    [sym_decimal] = ACTIONS(2266),
    [anon_sym_LPAREN] = ACTIONS(2268),
    [anon_sym_DOT_DOT] = ACTIONS(2268),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2266),
    [anon_sym_STAR] = ACTIONS(2266),
    [anon_sym_LBRACK] = ACTIONS(2268),
    [aux_sym_record_type_token1] = ACTIONS(2266),
    [aux_sym_basic_type_token21] = ACTIONS(2266),
    [aux_sym_basic_type_token22] = ACTIONS(2266),
    [aux_sym_basic_type_token48] = ACTIONS(2266),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2266),
    [anon_sym_COLON_COLON] = ACTIONS(2268),
    [anon_sym_POUNDif] = ACTIONS(2268),
    [anon_sym_POUNDIF] = ACTIONS(2268),
    [anon_sym_POUNDIf] = ACTIONS(2268),
    [anon_sym_not] = ACTIONS(2266),
    [anon_sym_NOT] = ACTIONS(2266),
    [anon_sym_Not] = ACTIONS(2266),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2268),
    [aux_sym__expression_token1] = ACTIONS(2268),
    [aux_sym__expression_token2] = ACTIONS(2266),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2266),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2266),
    [anon_sym_SLASH] = ACTIONS(2266),
    [anon_sym_div] = ACTIONS(2266),
    [anon_sym_DIV] = ACTIONS(2266),
    [anon_sym_Div] = ACTIONS(2266),
    [anon_sym_mod] = ACTIONS(2266),
    [anon_sym_MOD] = ACTIONS(2266),
    [anon_sym_Mod] = ACTIONS(2266),
    [anon_sym_PLUS] = ACTIONS(2266),
    [anon_sym_GT_EQ] = ACTIONS(2268),
    [anon_sym_LT_EQ] = ACTIONS(2268),
    [anon_sym_GT] = ACTIONS(2266),
    [anon_sym_LT] = ACTIONS(2266),
    [anon_sym_LT_GT] = ACTIONS(2268),
    [anon_sym_and] = ACTIONS(2266),
    [anon_sym_AND] = ACTIONS(2266),
    [anon_sym_And] = ACTIONS(2266),
    [anon_sym_or] = ACTIONS(2266),
    [anon_sym_OR] = ACTIONS(2266),
    [anon_sym_Or] = ACTIONS(2266),
    [anon_sym_xor] = ACTIONS(2266),
    [anon_sym_XOR] = ACTIONS(2266),
    [anon_sym_Xor] = ACTIONS(2266),
    [anon_sym_QMARK] = ACTIONS(2268),
    [sym_datetime_literal] = ACTIONS(2268),
    [sym_date_literal] = ACTIONS(2266),
    [sym_time_literal] = ACTIONS(2266),
    [sym_biginteger_literal] = ACTIONS(2268),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_IF] = ACTIONS(2266),
    [anon_sym_If] = ACTIONS(2266),
    [anon_sym_else] = ACTIONS(2266),
    [anon_sym_ELSE] = ACTIONS(2266),
    [anon_sym_Else] = ACTIONS(2266),
    [anon_sym_case] = ACTIONS(2266),
    [anon_sym_CASE] = ACTIONS(2266),
    [anon_sym_Case] = ACTIONS(2266),
    [anon_sym_for] = ACTIONS(2266),
    [anon_sym_FOR] = ACTIONS(2266),
    [anon_sym_For] = ACTIONS(2266),
    [anon_sym_foreach] = ACTIONS(2266),
    [anon_sym_FOREACH] = ACTIONS(2266),
    [anon_sym_Foreach] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2266),
    [anon_sym_WHILE] = ACTIONS(2266),
    [anon_sym_While] = ACTIONS(2266),
    [anon_sym_repeat] = ACTIONS(2266),
    [anon_sym_REPEAT] = ACTIONS(2266),
    [anon_sym_Repeat] = ACTIONS(2266),
    [anon_sym_exit] = ACTIONS(2266),
    [anon_sym_EXIT] = ACTIONS(2266),
    [anon_sym_Exit] = ACTIONS(2266),
    [anon_sym_continue] = ACTIONS(2266),
    [anon_sym_CONTINUE] = ACTIONS(2266),
    [anon_sym_Continue] = ACTIONS(2266),
    [anon_sym_break] = ACTIONS(2266),
    [anon_sym_BREAK] = ACTIONS(2266),
    [anon_sym_Break] = ACTIONS(2266),
    [anon_sym_with] = ACTIONS(2266),
    [anon_sym_WITH] = ACTIONS(2266),
    [anon_sym_With] = ACTIONS(2266),
    [sym_asserterror_keyword] = ACTIONS(2268),
    [anon_sym_in] = ACTIONS(2266),
    [anon_sym_IN] = ACTIONS(2266),
    [anon_sym_In] = ACTIONS(2266),
    [sym_page_keyword] = ACTIONS(2266),
    [anon_sym_codeunit] = ACTIONS(2266),
    [anon_sym_CODEUNIT] = ACTIONS(2266),
    [anon_sym_Codeunit] = ACTIONS(2266),
    [anon_sym_CodeUnit] = ACTIONS(2266),
    [anon_sym_COdeunit] = ACTIONS(2266),
    [anon_sym_codeUnit] = ACTIONS(2266),
    [sym_report_keyword] = ACTIONS(2266),
    [sym_query_keyword] = ACTIONS(2266),
    [anon_sym_xmlport] = ACTIONS(2266),
    [anon_sym_XMLPORT] = ACTIONS(2266),
    [anon_sym_Xmlport] = ACTIONS(2266),
    [anon_sym_XMLport] = ACTIONS(2266),
    [anon_sym_XMLPort] = ACTIONS(2266),
    [anon_sym_XmlPort] = ACTIONS(2266),
    [anon_sym_enum] = ACTIONS(2266),
    [anon_sym_ENUM] = ACTIONS(2266),
    [anon_sym_Enum] = ACTIONS(2266),
    [anon_sym_eNUM] = ACTIONS(2266),
    [anon_sym_eNum] = ACTIONS(2266),
    [anon_sym_ENum] = ACTIONS(2266),
    [sym_temporary_keyword] = ACTIONS(2266),
    [sym_quoted_identifier] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2268),
    [sym_integer] = ACTIONS(2266),
    [sym_continue_as_identifier] = ACTIONS(2268),
    [sym_preproc_open] = ACTIONS(2268),
    [sym_end_keyword] = ACTIONS(2268),
  },
  [STATE(1154)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_end_keyword] = ACTIONS(2322),
  },
  [STATE(1155)] = {
    [sym_boolean] = STATE(980),
    [sym_code_block] = STATE(1664),
    [sym_assignment_expression] = STATE(980),
    [sym__expression] = STATE(980),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(980),
    [sym_multiplicative_expression] = STATE(980),
    [sym_additive_expression] = STATE(980),
    [sym_comparison_expression] = STATE(980),
    [sym_logical_expression] = STATE(980),
    [sym_ternary_expression] = STATE(980),
    [sym_unary_expression] = STATE(980),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(980),
    [sym_list_literal] = STATE(980),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(980),
    [sym__literal_value] = STATE(980),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(2735),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(2737),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2739),
    [anon_sym_POUNDif] = ACTIONS(2735),
    [anon_sym_POUNDIF] = ACTIONS(2735),
    [anon_sym_POUNDIf] = ACTIONS(2735),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(2735),
    [anon_sym_POUNDELIF] = ACTIONS(2735),
    [anon_sym_POUNDElif] = ACTIONS(2735),
    [anon_sym_POUNDelse] = ACTIONS(2735),
    [anon_sym_POUNDELSE] = ACTIONS(2735),
    [anon_sym_POUNDElse] = ACTIONS(2735),
    [anon_sym_POUNDendif] = ACTIONS(2735),
    [anon_sym_POUNDENDIF] = ACTIONS(2735),
    [anon_sym_POUNDEndif] = ACTIONS(2735),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(2741),
    [sym_date_literal] = ACTIONS(2737),
    [sym_time_literal] = ACTIONS(2737),
    [sym_biginteger_literal] = ACTIONS(2741),
    [anon_sym_if] = ACTIONS(2739),
    [anon_sym_IF] = ACTIONS(2739),
    [anon_sym_If] = ACTIONS(2739),
    [anon_sym_else] = ACTIONS(2739),
    [anon_sym_ELSE] = ACTIONS(2739),
    [anon_sym_Else] = ACTIONS(2739),
    [anon_sym_case] = ACTIONS(2739),
    [anon_sym_CASE] = ACTIONS(2739),
    [anon_sym_Case] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2739),
    [anon_sym_FOR] = ACTIONS(2739),
    [anon_sym_For] = ACTIONS(2739),
    [anon_sym_foreach] = ACTIONS(2739),
    [anon_sym_FOREACH] = ACTIONS(2739),
    [anon_sym_Foreach] = ACTIONS(2739),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_WHILE] = ACTIONS(2739),
    [anon_sym_While] = ACTIONS(2739),
    [anon_sym_repeat] = ACTIONS(2739),
    [anon_sym_REPEAT] = ACTIONS(2739),
    [anon_sym_Repeat] = ACTIONS(2739),
    [anon_sym_exit] = ACTIONS(2739),
    [anon_sym_EXIT] = ACTIONS(2739),
    [anon_sym_Exit] = ACTIONS(2739),
    [anon_sym_continue] = ACTIONS(2739),
    [anon_sym_CONTINUE] = ACTIONS(2739),
    [anon_sym_Continue] = ACTIONS(2739),
    [anon_sym_break] = ACTIONS(2739),
    [anon_sym_BREAK] = ACTIONS(2739),
    [anon_sym_Break] = ACTIONS(2739),
    [anon_sym_with] = ACTIONS(2739),
    [anon_sym_WITH] = ACTIONS(2739),
    [anon_sym_With] = ACTIONS(2739),
    [sym_asserterror_keyword] = ACTIONS(2735),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2741),
    [sym_integer] = ACTIONS(2737),
    [sym_continue_as_identifier] = ACTIONS(2741),
    [sym_preproc_open] = ACTIONS(2735),
    [sym_preproc_close] = ACTIONS(2735),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(1156)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2368),
    [anon_sym_SEMI] = ACTIONS(2370),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2743),
    [aux_sym_boolean_token1] = ACTIONS(2368),
    [aux_sym_boolean_token2] = ACTIONS(2368),
    [sym_decimal] = ACTIONS(2368),
    [anon_sym_LPAREN] = ACTIONS(2370),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2368),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2368),
    [aux_sym_basic_type_token21] = ACTIONS(2368),
    [aux_sym_basic_type_token22] = ACTIONS(2368),
    [aux_sym_basic_type_token48] = ACTIONS(2368),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2368),
    [anon_sym_POUNDif] = ACTIONS(2370),
    [anon_sym_POUNDIF] = ACTIONS(2370),
    [anon_sym_POUNDIf] = ACTIONS(2370),
    [anon_sym_not] = ACTIONS(2368),
    [anon_sym_NOT] = ACTIONS(2368),
    [anon_sym_Not] = ACTIONS(2368),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2370),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2368),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2368),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2767),
    [anon_sym_AND] = ACTIONS(2769),
    [anon_sym_And] = ACTIONS(2771),
    [anon_sym_or] = ACTIONS(2773),
    [anon_sym_OR] = ACTIONS(2775),
    [anon_sym_Or] = ACTIONS(2777),
    [anon_sym_xor] = ACTIONS(2779),
    [anon_sym_XOR] = ACTIONS(2781),
    [anon_sym_Xor] = ACTIONS(2783),
    [anon_sym_QMARK] = ACTIONS(2785),
    [sym_datetime_literal] = ACTIONS(2370),
    [sym_date_literal] = ACTIONS(2368),
    [sym_time_literal] = ACTIONS(2368),
    [sym_biginteger_literal] = ACTIONS(2370),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_IF] = ACTIONS(2368),
    [anon_sym_If] = ACTIONS(2368),
    [anon_sym_else] = ACTIONS(2368),
    [anon_sym_ELSE] = ACTIONS(2368),
    [anon_sym_Else] = ACTIONS(2368),
    [anon_sym_case] = ACTIONS(2368),
    [anon_sym_CASE] = ACTIONS(2368),
    [anon_sym_Case] = ACTIONS(2368),
    [anon_sym_for] = ACTIONS(2368),
    [anon_sym_FOR] = ACTIONS(2368),
    [anon_sym_For] = ACTIONS(2368),
    [anon_sym_foreach] = ACTIONS(2368),
    [anon_sym_FOREACH] = ACTIONS(2368),
    [anon_sym_Foreach] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2368),
    [anon_sym_WHILE] = ACTIONS(2368),
    [anon_sym_While] = ACTIONS(2368),
    [anon_sym_repeat] = ACTIONS(2368),
    [anon_sym_REPEAT] = ACTIONS(2368),
    [anon_sym_Repeat] = ACTIONS(2368),
    [anon_sym_exit] = ACTIONS(2368),
    [anon_sym_EXIT] = ACTIONS(2368),
    [anon_sym_Exit] = ACTIONS(2368),
    [anon_sym_continue] = ACTIONS(2368),
    [anon_sym_CONTINUE] = ACTIONS(2368),
    [anon_sym_Continue] = ACTIONS(2368),
    [anon_sym_break] = ACTIONS(2368),
    [anon_sym_BREAK] = ACTIONS(2368),
    [anon_sym_Break] = ACTIONS(2368),
    [anon_sym_with] = ACTIONS(2368),
    [anon_sym_WITH] = ACTIONS(2368),
    [anon_sym_With] = ACTIONS(2368),
    [sym_asserterror_keyword] = ACTIONS(2370),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2368),
    [anon_sym_codeunit] = ACTIONS(2368),
    [anon_sym_CODEUNIT] = ACTIONS(2368),
    [anon_sym_Codeunit] = ACTIONS(2368),
    [anon_sym_CodeUnit] = ACTIONS(2368),
    [anon_sym_COdeunit] = ACTIONS(2368),
    [anon_sym_codeUnit] = ACTIONS(2368),
    [sym_report_keyword] = ACTIONS(2368),
    [sym_query_keyword] = ACTIONS(2368),
    [anon_sym_xmlport] = ACTIONS(2368),
    [anon_sym_XMLPORT] = ACTIONS(2368),
    [anon_sym_Xmlport] = ACTIONS(2368),
    [anon_sym_XMLport] = ACTIONS(2368),
    [anon_sym_XMLPort] = ACTIONS(2368),
    [anon_sym_XmlPort] = ACTIONS(2368),
    [anon_sym_enum] = ACTIONS(2368),
    [anon_sym_ENUM] = ACTIONS(2368),
    [anon_sym_Enum] = ACTIONS(2368),
    [anon_sym_eNUM] = ACTIONS(2368),
    [anon_sym_eNum] = ACTIONS(2368),
    [anon_sym_ENum] = ACTIONS(2368),
    [sym_quoted_identifier] = ACTIONS(2370),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2370),
    [sym_integer] = ACTIONS(2368),
    [sym_continue_as_identifier] = ACTIONS(2370),
    [sym_preproc_open] = ACTIONS(2370),
    [sym_end_keyword] = ACTIONS(2370),
  },
  [STATE(1157)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_SEMI] = ACTIONS(2428),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_COMMA] = ACTIONS(2428),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2426),
    [anon_sym_COLON_COLON] = ACTIONS(2428),
    [anon_sym_POUNDif] = ACTIONS(2428),
    [anon_sym_POUNDIF] = ACTIONS(2428),
    [anon_sym_POUNDIf] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_IF] = ACTIONS(2426),
    [anon_sym_If] = ACTIONS(2426),
    [anon_sym_else] = ACTIONS(2426),
    [anon_sym_ELSE] = ACTIONS(2426),
    [anon_sym_Else] = ACTIONS(2426),
    [anon_sym_case] = ACTIONS(2426),
    [anon_sym_CASE] = ACTIONS(2426),
    [anon_sym_Case] = ACTIONS(2426),
    [anon_sym_for] = ACTIONS(2426),
    [anon_sym_FOR] = ACTIONS(2426),
    [anon_sym_For] = ACTIONS(2426),
    [anon_sym_foreach] = ACTIONS(2426),
    [anon_sym_FOREACH] = ACTIONS(2426),
    [anon_sym_Foreach] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(2426),
    [anon_sym_WHILE] = ACTIONS(2426),
    [anon_sym_While] = ACTIONS(2426),
    [anon_sym_repeat] = ACTIONS(2426),
    [anon_sym_REPEAT] = ACTIONS(2426),
    [anon_sym_Repeat] = ACTIONS(2426),
    [anon_sym_exit] = ACTIONS(2426),
    [anon_sym_EXIT] = ACTIONS(2426),
    [anon_sym_Exit] = ACTIONS(2426),
    [anon_sym_continue] = ACTIONS(2426),
    [anon_sym_CONTINUE] = ACTIONS(2426),
    [anon_sym_Continue] = ACTIONS(2426),
    [anon_sym_break] = ACTIONS(2426),
    [anon_sym_BREAK] = ACTIONS(2426),
    [anon_sym_Break] = ACTIONS(2426),
    [anon_sym_with] = ACTIONS(2426),
    [anon_sym_WITH] = ACTIONS(2426),
    [anon_sym_With] = ACTIONS(2426),
    [sym_asserterror_keyword] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_open] = ACTIONS(2428),
    [sym_end_keyword] = ACTIONS(2428),
  },
  [STATE(1158)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2388),
    [anon_sym_SEMI] = ACTIONS(2390),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2743),
    [aux_sym_boolean_token1] = ACTIONS(2388),
    [aux_sym_boolean_token2] = ACTIONS(2388),
    [sym_decimal] = ACTIONS(2388),
    [anon_sym_LPAREN] = ACTIONS(2390),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2388),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2388),
    [aux_sym_basic_type_token21] = ACTIONS(2388),
    [aux_sym_basic_type_token22] = ACTIONS(2388),
    [aux_sym_basic_type_token48] = ACTIONS(2388),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2388),
    [anon_sym_POUNDif] = ACTIONS(2390),
    [anon_sym_POUNDIF] = ACTIONS(2390),
    [anon_sym_POUNDIf] = ACTIONS(2390),
    [anon_sym_not] = ACTIONS(2388),
    [anon_sym_NOT] = ACTIONS(2388),
    [anon_sym_Not] = ACTIONS(2388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2787),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2388),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2388),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2767),
    [anon_sym_AND] = ACTIONS(2769),
    [anon_sym_And] = ACTIONS(2771),
    [anon_sym_or] = ACTIONS(2773),
    [anon_sym_OR] = ACTIONS(2775),
    [anon_sym_Or] = ACTIONS(2777),
    [anon_sym_xor] = ACTIONS(2779),
    [anon_sym_XOR] = ACTIONS(2781),
    [anon_sym_Xor] = ACTIONS(2783),
    [anon_sym_QMARK] = ACTIONS(2785),
    [sym_datetime_literal] = ACTIONS(2390),
    [sym_date_literal] = ACTIONS(2388),
    [sym_time_literal] = ACTIONS(2388),
    [sym_biginteger_literal] = ACTIONS(2390),
    [anon_sym_if] = ACTIONS(2388),
    [anon_sym_IF] = ACTIONS(2388),
    [anon_sym_If] = ACTIONS(2388),
    [anon_sym_else] = ACTIONS(2388),
    [anon_sym_ELSE] = ACTIONS(2388),
    [anon_sym_Else] = ACTIONS(2388),
    [anon_sym_case] = ACTIONS(2388),
    [anon_sym_CASE] = ACTIONS(2388),
    [anon_sym_Case] = ACTIONS(2388),
    [anon_sym_for] = ACTIONS(2388),
    [anon_sym_FOR] = ACTIONS(2388),
    [anon_sym_For] = ACTIONS(2388),
    [anon_sym_foreach] = ACTIONS(2388),
    [anon_sym_FOREACH] = ACTIONS(2388),
    [anon_sym_Foreach] = ACTIONS(2388),
    [anon_sym_while] = ACTIONS(2388),
    [anon_sym_WHILE] = ACTIONS(2388),
    [anon_sym_While] = ACTIONS(2388),
    [anon_sym_repeat] = ACTIONS(2388),
    [anon_sym_REPEAT] = ACTIONS(2388),
    [anon_sym_Repeat] = ACTIONS(2388),
    [anon_sym_exit] = ACTIONS(2388),
    [anon_sym_EXIT] = ACTIONS(2388),
    [anon_sym_Exit] = ACTIONS(2388),
    [anon_sym_continue] = ACTIONS(2388),
    [anon_sym_CONTINUE] = ACTIONS(2388),
    [anon_sym_Continue] = ACTIONS(2388),
    [anon_sym_break] = ACTIONS(2388),
    [anon_sym_BREAK] = ACTIONS(2388),
    [anon_sym_Break] = ACTIONS(2388),
    [anon_sym_with] = ACTIONS(2388),
    [anon_sym_WITH] = ACTIONS(2388),
    [anon_sym_With] = ACTIONS(2388),
    [sym_asserterror_keyword] = ACTIONS(2390),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2388),
    [anon_sym_codeunit] = ACTIONS(2388),
    [anon_sym_CODEUNIT] = ACTIONS(2388),
    [anon_sym_Codeunit] = ACTIONS(2388),
    [anon_sym_CodeUnit] = ACTIONS(2388),
    [anon_sym_COdeunit] = ACTIONS(2388),
    [anon_sym_codeUnit] = ACTIONS(2388),
    [sym_report_keyword] = ACTIONS(2388),
    [sym_query_keyword] = ACTIONS(2388),
    [anon_sym_xmlport] = ACTIONS(2388),
    [anon_sym_XMLPORT] = ACTIONS(2388),
    [anon_sym_Xmlport] = ACTIONS(2388),
    [anon_sym_XMLport] = ACTIONS(2388),
    [anon_sym_XMLPort] = ACTIONS(2388),
    [anon_sym_XmlPort] = ACTIONS(2388),
    [anon_sym_enum] = ACTIONS(2388),
    [anon_sym_ENUM] = ACTIONS(2388),
    [anon_sym_Enum] = ACTIONS(2388),
    [anon_sym_eNUM] = ACTIONS(2388),
    [anon_sym_eNum] = ACTIONS(2388),
    [anon_sym_ENum] = ACTIONS(2388),
    [sym_quoted_identifier] = ACTIONS(2390),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2390),
    [sym_integer] = ACTIONS(2388),
    [sym_continue_as_identifier] = ACTIONS(2390),
    [sym_preproc_open] = ACTIONS(2390),
    [sym_end_keyword] = ACTIONS(2390),
  },
  [STATE(1159)] = {
    [sym_preproc_conditional_object] = STATE(1170),
    [sym_using_statement] = STATE(1170),
    [sym__object] = STATE(1170),
    [sym_preproc_split_declaration] = STATE(1170),
    [sym_table_declaration] = STATE(1170),
    [sym_page_declaration] = STATE(1170),
    [sym_report_declaration] = STATE(1170),
    [sym_query_declaration] = STATE(1170),
    [sym_xmlport_declaration] = STATE(1170),
    [sym_permissionset_declaration] = STATE(1170),
    [sym_codeunit_declaration] = STATE(1170),
    [sym_enum_declaration] = STATE(1170),
    [sym_tableextension_declaration] = STATE(1170),
    [sym_pageextension_declaration] = STATE(1170),
    [sym_reportextension_declaration] = STATE(1170),
    [sym_enumextension_declaration] = STATE(1170),
    [sym_permissionsetextension_declaration] = STATE(1170),
    [sym_controladdin_declaration] = STATE(1170),
    [sym_profile_declaration] = STATE(1170),
    [sym_entitlement_declaration] = STATE(1170),
    [sym_profileextension_declaration] = STATE(1170),
    [sym_interface_declaration] = STATE(1170),
    [sym_pagecustomization_declaration] = STATE(1170),
    [sym_dotnet_declaration] = STATE(1170),
    [sym_preproc_if] = STATE(620),
    [sym_tableextension_keyword] = STATE(12387),
    [sym_pageextension_keyword] = STATE(12389),
    [sym_codeunit_keyword] = STATE(12423),
    [sym_reportextension_keyword] = STATE(12428),
    [sym_xmlport_keyword] = STATE(12505),
    [sym_enum_keyword] = STATE(12506),
    [sym_enumextension_keyword] = STATE(12516),
    [sym_controladdin_keyword] = STATE(8740),
    [sym_dotnet_keyword] = STATE(11413),
    [sym_profileextension_keyword] = STATE(8726),
    [sym_permissionset_keyword] = STATE(12440),
    [sym_permissionsetextension_keyword] = STATE(12495),
    [sym_pagecustomization_keyword] = STATE(8356),
    [aux_sym_source_file_repeat1] = STATE(1170),
    [ts_builtin_sym_end] = ACTIONS(2789),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(13),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(19),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(23),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(33),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(39),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(47),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(53),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
  },
  [STATE(1160)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1163),
    [sym_identifier] = ACTIONS(2410),
    [anon_sym_SEMI] = ACTIONS(2412),
    [anon_sym_DOT] = ACTIONS(2410),
    [anon_sym_EQ] = ACTIONS(2412),
    [anon_sym_COMMA] = ACTIONS(2791),
    [anon_sym_DASH] = ACTIONS(2410),
    [aux_sym_boolean_token1] = ACTIONS(2410),
    [aux_sym_boolean_token2] = ACTIONS(2410),
    [sym_decimal] = ACTIONS(2410),
    [anon_sym_LPAREN] = ACTIONS(2412),
    [anon_sym_DOT_DOT] = ACTIONS(2412),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2410),
    [anon_sym_STAR] = ACTIONS(2410),
    [anon_sym_LBRACK] = ACTIONS(2412),
    [aux_sym_record_type_token1] = ACTIONS(2410),
    [aux_sym_basic_type_token21] = ACTIONS(2410),
    [aux_sym_basic_type_token22] = ACTIONS(2410),
    [aux_sym_basic_type_token48] = ACTIONS(2410),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2410),
    [anon_sym_POUNDif] = ACTIONS(2412),
    [anon_sym_POUNDIF] = ACTIONS(2412),
    [anon_sym_POUNDIf] = ACTIONS(2412),
    [anon_sym_not] = ACTIONS(2410),
    [anon_sym_NOT] = ACTIONS(2410),
    [anon_sym_Not] = ACTIONS(2410),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2412),
    [aux_sym__expression_token1] = ACTIONS(2412),
    [aux_sym__expression_token2] = ACTIONS(2410),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2410),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2410),
    [anon_sym_SLASH] = ACTIONS(2410),
    [anon_sym_div] = ACTIONS(2410),
    [anon_sym_DIV] = ACTIONS(2410),
    [anon_sym_Div] = ACTIONS(2410),
    [anon_sym_mod] = ACTIONS(2410),
    [anon_sym_MOD] = ACTIONS(2410),
    [anon_sym_Mod] = ACTIONS(2410),
    [anon_sym_PLUS] = ACTIONS(2410),
    [anon_sym_GT_EQ] = ACTIONS(2412),
    [anon_sym_LT_EQ] = ACTIONS(2412),
    [anon_sym_GT] = ACTIONS(2410),
    [anon_sym_LT] = ACTIONS(2410),
    [anon_sym_LT_GT] = ACTIONS(2412),
    [anon_sym_and] = ACTIONS(2410),
    [anon_sym_AND] = ACTIONS(2410),
    [anon_sym_And] = ACTIONS(2410),
    [anon_sym_or] = ACTIONS(2410),
    [anon_sym_OR] = ACTIONS(2410),
    [anon_sym_Or] = ACTIONS(2410),
    [anon_sym_xor] = ACTIONS(2410),
    [anon_sym_XOR] = ACTIONS(2410),
    [anon_sym_Xor] = ACTIONS(2410),
    [anon_sym_QMARK] = ACTIONS(2412),
    [sym_datetime_literal] = ACTIONS(2412),
    [sym_date_literal] = ACTIONS(2410),
    [sym_time_literal] = ACTIONS(2410),
    [sym_biginteger_literal] = ACTIONS(2412),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_IF] = ACTIONS(2410),
    [anon_sym_If] = ACTIONS(2410),
    [anon_sym_else] = ACTIONS(2410),
    [anon_sym_ELSE] = ACTIONS(2410),
    [anon_sym_Else] = ACTIONS(2410),
    [anon_sym_case] = ACTIONS(2410),
    [anon_sym_CASE] = ACTIONS(2410),
    [anon_sym_Case] = ACTIONS(2410),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_FOR] = ACTIONS(2410),
    [anon_sym_For] = ACTIONS(2410),
    [anon_sym_foreach] = ACTIONS(2410),
    [anon_sym_FOREACH] = ACTIONS(2410),
    [anon_sym_Foreach] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2410),
    [anon_sym_WHILE] = ACTIONS(2410),
    [anon_sym_While] = ACTIONS(2410),
    [anon_sym_repeat] = ACTIONS(2410),
    [anon_sym_REPEAT] = ACTIONS(2410),
    [anon_sym_Repeat] = ACTIONS(2410),
    [anon_sym_exit] = ACTIONS(2410),
    [anon_sym_EXIT] = ACTIONS(2410),
    [anon_sym_Exit] = ACTIONS(2410),
    [anon_sym_continue] = ACTIONS(2410),
    [anon_sym_CONTINUE] = ACTIONS(2410),
    [anon_sym_Continue] = ACTIONS(2410),
    [anon_sym_break] = ACTIONS(2410),
    [anon_sym_BREAK] = ACTIONS(2410),
    [anon_sym_Break] = ACTIONS(2410),
    [anon_sym_with] = ACTIONS(2410),
    [anon_sym_WITH] = ACTIONS(2410),
    [anon_sym_With] = ACTIONS(2410),
    [sym_asserterror_keyword] = ACTIONS(2412),
    [anon_sym_in] = ACTIONS(2410),
    [anon_sym_IN] = ACTIONS(2410),
    [anon_sym_In] = ACTIONS(2410),
    [sym_page_keyword] = ACTIONS(2410),
    [anon_sym_codeunit] = ACTIONS(2410),
    [anon_sym_CODEUNIT] = ACTIONS(2410),
    [anon_sym_Codeunit] = ACTIONS(2410),
    [anon_sym_CodeUnit] = ACTIONS(2410),
    [anon_sym_COdeunit] = ACTIONS(2410),
    [anon_sym_codeUnit] = ACTIONS(2410),
    [sym_report_keyword] = ACTIONS(2410),
    [sym_query_keyword] = ACTIONS(2410),
    [anon_sym_xmlport] = ACTIONS(2410),
    [anon_sym_XMLPORT] = ACTIONS(2410),
    [anon_sym_Xmlport] = ACTIONS(2410),
    [anon_sym_XMLport] = ACTIONS(2410),
    [anon_sym_XMLPort] = ACTIONS(2410),
    [anon_sym_XmlPort] = ACTIONS(2410),
    [anon_sym_enum] = ACTIONS(2410),
    [anon_sym_ENUM] = ACTIONS(2410),
    [anon_sym_Enum] = ACTIONS(2410),
    [anon_sym_eNUM] = ACTIONS(2410),
    [anon_sym_eNum] = ACTIONS(2410),
    [anon_sym_ENum] = ACTIONS(2410),
    [sym_quoted_identifier] = ACTIONS(2412),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2412),
    [sym_integer] = ACTIONS(2410),
    [sym_continue_as_identifier] = ACTIONS(2412),
    [sym_preproc_open] = ACTIONS(2412),
    [sym_end_keyword] = ACTIONS(2412),
  },
  [STATE(1161)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2372),
    [anon_sym_SEMI] = ACTIONS(2374),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2743),
    [aux_sym_boolean_token1] = ACTIONS(2372),
    [aux_sym_boolean_token2] = ACTIONS(2372),
    [sym_decimal] = ACTIONS(2372),
    [anon_sym_LPAREN] = ACTIONS(2374),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2372),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2372),
    [aux_sym_basic_type_token21] = ACTIONS(2372),
    [aux_sym_basic_type_token22] = ACTIONS(2372),
    [aux_sym_basic_type_token48] = ACTIONS(2372),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2372),
    [anon_sym_POUNDif] = ACTIONS(2374),
    [anon_sym_POUNDIF] = ACTIONS(2374),
    [anon_sym_POUNDIf] = ACTIONS(2374),
    [anon_sym_not] = ACTIONS(2372),
    [anon_sym_NOT] = ACTIONS(2372),
    [anon_sym_Not] = ACTIONS(2372),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2793),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2372),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2372),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2767),
    [anon_sym_AND] = ACTIONS(2769),
    [anon_sym_And] = ACTIONS(2771),
    [anon_sym_or] = ACTIONS(2773),
    [anon_sym_OR] = ACTIONS(2775),
    [anon_sym_Or] = ACTIONS(2777),
    [anon_sym_xor] = ACTIONS(2779),
    [anon_sym_XOR] = ACTIONS(2781),
    [anon_sym_Xor] = ACTIONS(2783),
    [anon_sym_QMARK] = ACTIONS(2785),
    [sym_datetime_literal] = ACTIONS(2374),
    [sym_date_literal] = ACTIONS(2372),
    [sym_time_literal] = ACTIONS(2372),
    [sym_biginteger_literal] = ACTIONS(2374),
    [anon_sym_if] = ACTIONS(2372),
    [anon_sym_IF] = ACTIONS(2372),
    [anon_sym_If] = ACTIONS(2372),
    [anon_sym_else] = ACTIONS(2372),
    [anon_sym_ELSE] = ACTIONS(2372),
    [anon_sym_Else] = ACTIONS(2372),
    [anon_sym_case] = ACTIONS(2372),
    [anon_sym_CASE] = ACTIONS(2372),
    [anon_sym_Case] = ACTIONS(2372),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_FOR] = ACTIONS(2372),
    [anon_sym_For] = ACTIONS(2372),
    [anon_sym_foreach] = ACTIONS(2372),
    [anon_sym_FOREACH] = ACTIONS(2372),
    [anon_sym_Foreach] = ACTIONS(2372),
    [anon_sym_while] = ACTIONS(2372),
    [anon_sym_WHILE] = ACTIONS(2372),
    [anon_sym_While] = ACTIONS(2372),
    [anon_sym_repeat] = ACTIONS(2372),
    [anon_sym_REPEAT] = ACTIONS(2372),
    [anon_sym_Repeat] = ACTIONS(2372),
    [anon_sym_exit] = ACTIONS(2372),
    [anon_sym_EXIT] = ACTIONS(2372),
    [anon_sym_Exit] = ACTIONS(2372),
    [anon_sym_continue] = ACTIONS(2372),
    [anon_sym_CONTINUE] = ACTIONS(2372),
    [anon_sym_Continue] = ACTIONS(2372),
    [anon_sym_break] = ACTIONS(2372),
    [anon_sym_BREAK] = ACTIONS(2372),
    [anon_sym_Break] = ACTIONS(2372),
    [anon_sym_with] = ACTIONS(2372),
    [anon_sym_WITH] = ACTIONS(2372),
    [anon_sym_With] = ACTIONS(2372),
    [sym_asserterror_keyword] = ACTIONS(2374),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2372),
    [anon_sym_codeunit] = ACTIONS(2372),
    [anon_sym_CODEUNIT] = ACTIONS(2372),
    [anon_sym_Codeunit] = ACTIONS(2372),
    [anon_sym_CodeUnit] = ACTIONS(2372),
    [anon_sym_COdeunit] = ACTIONS(2372),
    [anon_sym_codeUnit] = ACTIONS(2372),
    [sym_report_keyword] = ACTIONS(2372),
    [sym_query_keyword] = ACTIONS(2372),
    [anon_sym_xmlport] = ACTIONS(2372),
    [anon_sym_XMLPORT] = ACTIONS(2372),
    [anon_sym_Xmlport] = ACTIONS(2372),
    [anon_sym_XMLport] = ACTIONS(2372),
    [anon_sym_XMLPort] = ACTIONS(2372),
    [anon_sym_XmlPort] = ACTIONS(2372),
    [anon_sym_enum] = ACTIONS(2372),
    [anon_sym_ENUM] = ACTIONS(2372),
    [anon_sym_Enum] = ACTIONS(2372),
    [anon_sym_eNUM] = ACTIONS(2372),
    [anon_sym_eNum] = ACTIONS(2372),
    [anon_sym_ENum] = ACTIONS(2372),
    [sym_quoted_identifier] = ACTIONS(2374),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2374),
    [sym_integer] = ACTIONS(2372),
    [sym_continue_as_identifier] = ACTIONS(2374),
    [sym_preproc_open] = ACTIONS(2374),
    [sym_end_keyword] = ACTIONS(2374),
  },
  [STATE(1162)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1168),
    [sym_identifier] = ACTIONS(2442),
    [anon_sym_SEMI] = ACTIONS(2444),
    [anon_sym_DOT] = ACTIONS(2795),
    [anon_sym_EQ] = ACTIONS(2444),
    [anon_sym_DASH] = ACTIONS(2442),
    [aux_sym_boolean_token1] = ACTIONS(2442),
    [aux_sym_boolean_token2] = ACTIONS(2442),
    [sym_decimal] = ACTIONS(2442),
    [anon_sym_LPAREN] = ACTIONS(2444),
    [anon_sym_DOT_DOT] = ACTIONS(2444),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2442),
    [anon_sym_STAR] = ACTIONS(2442),
    [anon_sym_LBRACK] = ACTIONS(2444),
    [aux_sym_record_type_token1] = ACTIONS(2442),
    [aux_sym_basic_type_token21] = ACTIONS(2442),
    [aux_sym_basic_type_token22] = ACTIONS(2442),
    [aux_sym_basic_type_token48] = ACTIONS(2442),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2442),
    [anon_sym_POUNDif] = ACTIONS(2444),
    [anon_sym_POUNDIF] = ACTIONS(2444),
    [anon_sym_POUNDIf] = ACTIONS(2444),
    [anon_sym_not] = ACTIONS(2442),
    [anon_sym_NOT] = ACTIONS(2442),
    [anon_sym_Not] = ACTIONS(2442),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2444),
    [aux_sym__expression_token1] = ACTIONS(2444),
    [aux_sym__expression_token2] = ACTIONS(2442),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2442),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2442),
    [anon_sym_SLASH] = ACTIONS(2442),
    [anon_sym_div] = ACTIONS(2442),
    [anon_sym_DIV] = ACTIONS(2442),
    [anon_sym_Div] = ACTIONS(2442),
    [anon_sym_mod] = ACTIONS(2442),
    [anon_sym_MOD] = ACTIONS(2442),
    [anon_sym_Mod] = ACTIONS(2442),
    [anon_sym_PLUS] = ACTIONS(2442),
    [anon_sym_GT_EQ] = ACTIONS(2444),
    [anon_sym_LT_EQ] = ACTIONS(2444),
    [anon_sym_GT] = ACTIONS(2442),
    [anon_sym_LT] = ACTIONS(2442),
    [anon_sym_LT_GT] = ACTIONS(2444),
    [anon_sym_and] = ACTIONS(2442),
    [anon_sym_AND] = ACTIONS(2442),
    [anon_sym_And] = ACTIONS(2442),
    [anon_sym_or] = ACTIONS(2442),
    [anon_sym_OR] = ACTIONS(2442),
    [anon_sym_Or] = ACTIONS(2442),
    [anon_sym_xor] = ACTIONS(2442),
    [anon_sym_XOR] = ACTIONS(2442),
    [anon_sym_Xor] = ACTIONS(2442),
    [anon_sym_QMARK] = ACTIONS(2444),
    [sym_datetime_literal] = ACTIONS(2444),
    [sym_date_literal] = ACTIONS(2442),
    [sym_time_literal] = ACTIONS(2442),
    [sym_biginteger_literal] = ACTIONS(2444),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_IF] = ACTIONS(2442),
    [anon_sym_If] = ACTIONS(2442),
    [anon_sym_else] = ACTIONS(2442),
    [anon_sym_ELSE] = ACTIONS(2442),
    [anon_sym_Else] = ACTIONS(2442),
    [anon_sym_case] = ACTIONS(2442),
    [anon_sym_CASE] = ACTIONS(2442),
    [anon_sym_Case] = ACTIONS(2442),
    [anon_sym_for] = ACTIONS(2442),
    [anon_sym_FOR] = ACTIONS(2442),
    [anon_sym_For] = ACTIONS(2442),
    [anon_sym_foreach] = ACTIONS(2442),
    [anon_sym_FOREACH] = ACTIONS(2442),
    [anon_sym_Foreach] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2442),
    [anon_sym_WHILE] = ACTIONS(2442),
    [anon_sym_While] = ACTIONS(2442),
    [anon_sym_repeat] = ACTIONS(2442),
    [anon_sym_REPEAT] = ACTIONS(2442),
    [anon_sym_Repeat] = ACTIONS(2442),
    [anon_sym_exit] = ACTIONS(2442),
    [anon_sym_EXIT] = ACTIONS(2442),
    [anon_sym_Exit] = ACTIONS(2442),
    [anon_sym_continue] = ACTIONS(2442),
    [anon_sym_CONTINUE] = ACTIONS(2442),
    [anon_sym_Continue] = ACTIONS(2442),
    [anon_sym_break] = ACTIONS(2442),
    [anon_sym_BREAK] = ACTIONS(2442),
    [anon_sym_Break] = ACTIONS(2442),
    [anon_sym_with] = ACTIONS(2442),
    [anon_sym_WITH] = ACTIONS(2442),
    [anon_sym_With] = ACTIONS(2442),
    [sym_asserterror_keyword] = ACTIONS(2444),
    [anon_sym_in] = ACTIONS(2442),
    [anon_sym_IN] = ACTIONS(2442),
    [anon_sym_In] = ACTIONS(2442),
    [sym_page_keyword] = ACTIONS(2442),
    [anon_sym_codeunit] = ACTIONS(2442),
    [anon_sym_CODEUNIT] = ACTIONS(2442),
    [anon_sym_Codeunit] = ACTIONS(2442),
    [anon_sym_CodeUnit] = ACTIONS(2442),
    [anon_sym_COdeunit] = ACTIONS(2442),
    [anon_sym_codeUnit] = ACTIONS(2442),
    [sym_report_keyword] = ACTIONS(2442),
    [sym_query_keyword] = ACTIONS(2442),
    [anon_sym_xmlport] = ACTIONS(2442),
    [anon_sym_XMLPORT] = ACTIONS(2442),
    [anon_sym_Xmlport] = ACTIONS(2442),
    [anon_sym_XMLport] = ACTIONS(2442),
    [anon_sym_XMLPort] = ACTIONS(2442),
    [anon_sym_XmlPort] = ACTIONS(2442),
    [anon_sym_enum] = ACTIONS(2442),
    [anon_sym_ENUM] = ACTIONS(2442),
    [anon_sym_Enum] = ACTIONS(2442),
    [anon_sym_eNUM] = ACTIONS(2442),
    [anon_sym_eNum] = ACTIONS(2442),
    [anon_sym_ENum] = ACTIONS(2442),
    [sym_temporary_keyword] = ACTIONS(2442),
    [sym_quoted_identifier] = ACTIONS(2444),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2444),
    [sym_integer] = ACTIONS(2442),
    [sym_continue_as_identifier] = ACTIONS(2444),
    [sym_preproc_open] = ACTIONS(2444),
    [sym_end_keyword] = ACTIONS(2444),
  },
  [STATE(1163)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1163),
    [sym_identifier] = ACTIONS(2403),
    [anon_sym_SEMI] = ACTIONS(2405),
    [anon_sym_DOT] = ACTIONS(2403),
    [anon_sym_EQ] = ACTIONS(2405),
    [anon_sym_COMMA] = ACTIONS(2797),
    [anon_sym_DASH] = ACTIONS(2403),
    [aux_sym_boolean_token1] = ACTIONS(2403),
    [aux_sym_boolean_token2] = ACTIONS(2403),
    [sym_decimal] = ACTIONS(2403),
    [anon_sym_LPAREN] = ACTIONS(2405),
    [anon_sym_DOT_DOT] = ACTIONS(2405),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2403),
    [anon_sym_STAR] = ACTIONS(2403),
    [anon_sym_LBRACK] = ACTIONS(2405),
    [aux_sym_record_type_token1] = ACTIONS(2403),
    [aux_sym_basic_type_token21] = ACTIONS(2403),
    [aux_sym_basic_type_token22] = ACTIONS(2403),
    [aux_sym_basic_type_token48] = ACTIONS(2403),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2403),
    [anon_sym_POUNDif] = ACTIONS(2405),
    [anon_sym_POUNDIF] = ACTIONS(2405),
    [anon_sym_POUNDIf] = ACTIONS(2405),
    [anon_sym_not] = ACTIONS(2403),
    [anon_sym_NOT] = ACTIONS(2403),
    [anon_sym_Not] = ACTIONS(2403),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2405),
    [aux_sym__expression_token1] = ACTIONS(2405),
    [aux_sym__expression_token2] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2403),
    [anon_sym_SLASH] = ACTIONS(2403),
    [anon_sym_div] = ACTIONS(2403),
    [anon_sym_DIV] = ACTIONS(2403),
    [anon_sym_Div] = ACTIONS(2403),
    [anon_sym_mod] = ACTIONS(2403),
    [anon_sym_MOD] = ACTIONS(2403),
    [anon_sym_Mod] = ACTIONS(2403),
    [anon_sym_PLUS] = ACTIONS(2403),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_LT_GT] = ACTIONS(2405),
    [anon_sym_and] = ACTIONS(2403),
    [anon_sym_AND] = ACTIONS(2403),
    [anon_sym_And] = ACTIONS(2403),
    [anon_sym_or] = ACTIONS(2403),
    [anon_sym_OR] = ACTIONS(2403),
    [anon_sym_Or] = ACTIONS(2403),
    [anon_sym_xor] = ACTIONS(2403),
    [anon_sym_XOR] = ACTIONS(2403),
    [anon_sym_Xor] = ACTIONS(2403),
    [anon_sym_QMARK] = ACTIONS(2405),
    [sym_datetime_literal] = ACTIONS(2405),
    [sym_date_literal] = ACTIONS(2403),
    [sym_time_literal] = ACTIONS(2403),
    [sym_biginteger_literal] = ACTIONS(2405),
    [anon_sym_if] = ACTIONS(2403),
    [anon_sym_IF] = ACTIONS(2403),
    [anon_sym_If] = ACTIONS(2403),
    [anon_sym_else] = ACTIONS(2403),
    [anon_sym_ELSE] = ACTIONS(2403),
    [anon_sym_Else] = ACTIONS(2403),
    [anon_sym_case] = ACTIONS(2403),
    [anon_sym_CASE] = ACTIONS(2403),
    [anon_sym_Case] = ACTIONS(2403),
    [anon_sym_for] = ACTIONS(2403),
    [anon_sym_FOR] = ACTIONS(2403),
    [anon_sym_For] = ACTIONS(2403),
    [anon_sym_foreach] = ACTIONS(2403),
    [anon_sym_FOREACH] = ACTIONS(2403),
    [anon_sym_Foreach] = ACTIONS(2403),
    [anon_sym_while] = ACTIONS(2403),
    [anon_sym_WHILE] = ACTIONS(2403),
    [anon_sym_While] = ACTIONS(2403),
    [anon_sym_repeat] = ACTIONS(2403),
    [anon_sym_REPEAT] = ACTIONS(2403),
    [anon_sym_Repeat] = ACTIONS(2403),
    [anon_sym_exit] = ACTIONS(2403),
    [anon_sym_EXIT] = ACTIONS(2403),
    [anon_sym_Exit] = ACTIONS(2403),
    [anon_sym_continue] = ACTIONS(2403),
    [anon_sym_CONTINUE] = ACTIONS(2403),
    [anon_sym_Continue] = ACTIONS(2403),
    [anon_sym_break] = ACTIONS(2403),
    [anon_sym_BREAK] = ACTIONS(2403),
    [anon_sym_Break] = ACTIONS(2403),
    [anon_sym_with] = ACTIONS(2403),
    [anon_sym_WITH] = ACTIONS(2403),
    [anon_sym_With] = ACTIONS(2403),
    [sym_asserterror_keyword] = ACTIONS(2405),
    [anon_sym_in] = ACTIONS(2403),
    [anon_sym_IN] = ACTIONS(2403),
    [anon_sym_In] = ACTIONS(2403),
    [sym_page_keyword] = ACTIONS(2403),
    [anon_sym_codeunit] = ACTIONS(2403),
    [anon_sym_CODEUNIT] = ACTIONS(2403),
    [anon_sym_Codeunit] = ACTIONS(2403),
    [anon_sym_CodeUnit] = ACTIONS(2403),
    [anon_sym_COdeunit] = ACTIONS(2403),
    [anon_sym_codeUnit] = ACTIONS(2403),
    [sym_report_keyword] = ACTIONS(2403),
    [sym_query_keyword] = ACTIONS(2403),
    [anon_sym_xmlport] = ACTIONS(2403),
    [anon_sym_XMLPORT] = ACTIONS(2403),
    [anon_sym_Xmlport] = ACTIONS(2403),
    [anon_sym_XMLport] = ACTIONS(2403),
    [anon_sym_XMLPort] = ACTIONS(2403),
    [anon_sym_XmlPort] = ACTIONS(2403),
    [anon_sym_enum] = ACTIONS(2403),
    [anon_sym_ENUM] = ACTIONS(2403),
    [anon_sym_Enum] = ACTIONS(2403),
    [anon_sym_eNUM] = ACTIONS(2403),
    [anon_sym_eNum] = ACTIONS(2403),
    [anon_sym_ENum] = ACTIONS(2403),
    [sym_quoted_identifier] = ACTIONS(2405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2405),
    [sym_integer] = ACTIONS(2403),
    [sym_continue_as_identifier] = ACTIONS(2405),
    [sym_preproc_open] = ACTIONS(2405),
    [sym_end_keyword] = ACTIONS(2405),
  },
  [STATE(1164)] = {
    [sym_preproc_conditional_object] = STATE(1170),
    [sym_using_statement] = STATE(1170),
    [sym__object] = STATE(1170),
    [sym_preproc_split_declaration] = STATE(1170),
    [sym_table_declaration] = STATE(1170),
    [sym_page_declaration] = STATE(1170),
    [sym_report_declaration] = STATE(1170),
    [sym_query_declaration] = STATE(1170),
    [sym_xmlport_declaration] = STATE(1170),
    [sym_permissionset_declaration] = STATE(1170),
    [sym_codeunit_declaration] = STATE(1170),
    [sym_enum_declaration] = STATE(1170),
    [sym_tableextension_declaration] = STATE(1170),
    [sym_pageextension_declaration] = STATE(1170),
    [sym_reportextension_declaration] = STATE(1170),
    [sym_enumextension_declaration] = STATE(1170),
    [sym_permissionsetextension_declaration] = STATE(1170),
    [sym_controladdin_declaration] = STATE(1170),
    [sym_profile_declaration] = STATE(1170),
    [sym_entitlement_declaration] = STATE(1170),
    [sym_profileextension_declaration] = STATE(1170),
    [sym_interface_declaration] = STATE(1170),
    [sym_pagecustomization_declaration] = STATE(1170),
    [sym_dotnet_declaration] = STATE(1170),
    [sym_preproc_if] = STATE(620),
    [sym_tableextension_keyword] = STATE(12387),
    [sym_pageextension_keyword] = STATE(12389),
    [sym_codeunit_keyword] = STATE(12423),
    [sym_reportextension_keyword] = STATE(12428),
    [sym_xmlport_keyword] = STATE(12505),
    [sym_enum_keyword] = STATE(12506),
    [sym_enumextension_keyword] = STATE(12516),
    [sym_controladdin_keyword] = STATE(8740),
    [sym_dotnet_keyword] = STATE(11413),
    [sym_profileextension_keyword] = STATE(8726),
    [sym_permissionset_keyword] = STATE(12440),
    [sym_permissionsetextension_keyword] = STATE(12495),
    [sym_pagecustomization_keyword] = STATE(8356),
    [aux_sym_source_file_repeat1] = STATE(1170),
    [ts_builtin_sym_end] = ACTIONS(2800),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(13),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(19),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(23),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(33),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(39),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(47),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(53),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
  },
  [STATE(1165)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2378),
    [anon_sym_SEMI] = ACTIONS(2380),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2378),
    [aux_sym_boolean_token1] = ACTIONS(2378),
    [aux_sym_boolean_token2] = ACTIONS(2378),
    [sym_decimal] = ACTIONS(2378),
    [anon_sym_LPAREN] = ACTIONS(2380),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2378),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2380),
    [aux_sym_record_type_token1] = ACTIONS(2378),
    [aux_sym_basic_type_token21] = ACTIONS(2378),
    [aux_sym_basic_type_token22] = ACTIONS(2378),
    [aux_sym_basic_type_token48] = ACTIONS(2378),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2378),
    [anon_sym_POUNDif] = ACTIONS(2380),
    [anon_sym_POUNDIF] = ACTIONS(2380),
    [anon_sym_POUNDIf] = ACTIONS(2380),
    [anon_sym_not] = ACTIONS(2378),
    [anon_sym_NOT] = ACTIONS(2378),
    [anon_sym_Not] = ACTIONS(2378),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2787),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2378),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2378),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2378),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2767),
    [anon_sym_AND] = ACTIONS(2769),
    [anon_sym_And] = ACTIONS(2771),
    [anon_sym_or] = ACTIONS(2773),
    [anon_sym_OR] = ACTIONS(2775),
    [anon_sym_Or] = ACTIONS(2777),
    [anon_sym_xor] = ACTIONS(2779),
    [anon_sym_XOR] = ACTIONS(2781),
    [anon_sym_Xor] = ACTIONS(2783),
    [anon_sym_QMARK] = ACTIONS(2785),
    [sym_datetime_literal] = ACTIONS(2380),
    [sym_date_literal] = ACTIONS(2378),
    [sym_time_literal] = ACTIONS(2378),
    [sym_biginteger_literal] = ACTIONS(2380),
    [anon_sym_if] = ACTIONS(2378),
    [anon_sym_IF] = ACTIONS(2378),
    [anon_sym_If] = ACTIONS(2378),
    [anon_sym_else] = ACTIONS(2378),
    [anon_sym_ELSE] = ACTIONS(2378),
    [anon_sym_Else] = ACTIONS(2378),
    [anon_sym_case] = ACTIONS(2378),
    [anon_sym_CASE] = ACTIONS(2378),
    [anon_sym_Case] = ACTIONS(2378),
    [anon_sym_for] = ACTIONS(2378),
    [anon_sym_FOR] = ACTIONS(2378),
    [anon_sym_For] = ACTIONS(2378),
    [anon_sym_foreach] = ACTIONS(2378),
    [anon_sym_FOREACH] = ACTIONS(2378),
    [anon_sym_Foreach] = ACTIONS(2378),
    [anon_sym_while] = ACTIONS(2378),
    [anon_sym_WHILE] = ACTIONS(2378),
    [anon_sym_While] = ACTIONS(2378),
    [anon_sym_repeat] = ACTIONS(2378),
    [anon_sym_REPEAT] = ACTIONS(2378),
    [anon_sym_Repeat] = ACTIONS(2378),
    [anon_sym_exit] = ACTIONS(2378),
    [anon_sym_EXIT] = ACTIONS(2378),
    [anon_sym_Exit] = ACTIONS(2378),
    [anon_sym_continue] = ACTIONS(2378),
    [anon_sym_CONTINUE] = ACTIONS(2378),
    [anon_sym_Continue] = ACTIONS(2378),
    [anon_sym_break] = ACTIONS(2378),
    [anon_sym_BREAK] = ACTIONS(2378),
    [anon_sym_Break] = ACTIONS(2378),
    [anon_sym_with] = ACTIONS(2378),
    [anon_sym_WITH] = ACTIONS(2378),
    [anon_sym_With] = ACTIONS(2378),
    [sym_asserterror_keyword] = ACTIONS(2380),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2378),
    [anon_sym_codeunit] = ACTIONS(2378),
    [anon_sym_CODEUNIT] = ACTIONS(2378),
    [anon_sym_Codeunit] = ACTIONS(2378),
    [anon_sym_CodeUnit] = ACTIONS(2378),
    [anon_sym_COdeunit] = ACTIONS(2378),
    [anon_sym_codeUnit] = ACTIONS(2378),
    [sym_report_keyword] = ACTIONS(2378),
    [sym_query_keyword] = ACTIONS(2378),
    [anon_sym_xmlport] = ACTIONS(2378),
    [anon_sym_XMLPORT] = ACTIONS(2378),
    [anon_sym_Xmlport] = ACTIONS(2378),
    [anon_sym_XMLport] = ACTIONS(2378),
    [anon_sym_XMLPort] = ACTIONS(2378),
    [anon_sym_XmlPort] = ACTIONS(2378),
    [anon_sym_enum] = ACTIONS(2378),
    [anon_sym_ENUM] = ACTIONS(2378),
    [anon_sym_Enum] = ACTIONS(2378),
    [anon_sym_eNUM] = ACTIONS(2378),
    [anon_sym_eNum] = ACTIONS(2378),
    [anon_sym_ENum] = ACTIONS(2378),
    [sym_quoted_identifier] = ACTIONS(2380),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2380),
    [sym_integer] = ACTIONS(2378),
    [sym_continue_as_identifier] = ACTIONS(2380),
    [sym_preproc_open] = ACTIONS(2380),
    [sym_end_keyword] = ACTIONS(2380),
  },
  [STATE(1166)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2392),
    [anon_sym_SEMI] = ACTIONS(2394),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2743),
    [aux_sym_boolean_token1] = ACTIONS(2392),
    [aux_sym_boolean_token2] = ACTIONS(2392),
    [sym_decimal] = ACTIONS(2392),
    [anon_sym_LPAREN] = ACTIONS(2394),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2392),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2392),
    [aux_sym_basic_type_token21] = ACTIONS(2392),
    [aux_sym_basic_type_token22] = ACTIONS(2392),
    [aux_sym_basic_type_token48] = ACTIONS(2392),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2392),
    [anon_sym_POUNDif] = ACTIONS(2394),
    [anon_sym_POUNDIF] = ACTIONS(2394),
    [anon_sym_POUNDIf] = ACTIONS(2394),
    [anon_sym_not] = ACTIONS(2392),
    [anon_sym_NOT] = ACTIONS(2392),
    [anon_sym_Not] = ACTIONS(2392),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2787),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2392),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2392),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2767),
    [anon_sym_AND] = ACTIONS(2769),
    [anon_sym_And] = ACTIONS(2771),
    [anon_sym_or] = ACTIONS(2773),
    [anon_sym_OR] = ACTIONS(2775),
    [anon_sym_Or] = ACTIONS(2777),
    [anon_sym_xor] = ACTIONS(2779),
    [anon_sym_XOR] = ACTIONS(2781),
    [anon_sym_Xor] = ACTIONS(2783),
    [anon_sym_QMARK] = ACTIONS(2785),
    [sym_datetime_literal] = ACTIONS(2394),
    [sym_date_literal] = ACTIONS(2392),
    [sym_time_literal] = ACTIONS(2392),
    [sym_biginteger_literal] = ACTIONS(2394),
    [anon_sym_if] = ACTIONS(2392),
    [anon_sym_IF] = ACTIONS(2392),
    [anon_sym_If] = ACTIONS(2392),
    [anon_sym_else] = ACTIONS(2392),
    [anon_sym_ELSE] = ACTIONS(2392),
    [anon_sym_Else] = ACTIONS(2392),
    [anon_sym_case] = ACTIONS(2392),
    [anon_sym_CASE] = ACTIONS(2392),
    [anon_sym_Case] = ACTIONS(2392),
    [anon_sym_for] = ACTIONS(2392),
    [anon_sym_FOR] = ACTIONS(2392),
    [anon_sym_For] = ACTIONS(2392),
    [anon_sym_foreach] = ACTIONS(2392),
    [anon_sym_FOREACH] = ACTIONS(2392),
    [anon_sym_Foreach] = ACTIONS(2392),
    [anon_sym_while] = ACTIONS(2392),
    [anon_sym_WHILE] = ACTIONS(2392),
    [anon_sym_While] = ACTIONS(2392),
    [anon_sym_repeat] = ACTIONS(2392),
    [anon_sym_REPEAT] = ACTIONS(2392),
    [anon_sym_Repeat] = ACTIONS(2392),
    [anon_sym_exit] = ACTIONS(2392),
    [anon_sym_EXIT] = ACTIONS(2392),
    [anon_sym_Exit] = ACTIONS(2392),
    [anon_sym_continue] = ACTIONS(2392),
    [anon_sym_CONTINUE] = ACTIONS(2392),
    [anon_sym_Continue] = ACTIONS(2392),
    [anon_sym_break] = ACTIONS(2392),
    [anon_sym_BREAK] = ACTIONS(2392),
    [anon_sym_Break] = ACTIONS(2392),
    [anon_sym_with] = ACTIONS(2392),
    [anon_sym_WITH] = ACTIONS(2392),
    [anon_sym_With] = ACTIONS(2392),
    [sym_asserterror_keyword] = ACTIONS(2394),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2392),
    [anon_sym_codeunit] = ACTIONS(2392),
    [anon_sym_CODEUNIT] = ACTIONS(2392),
    [anon_sym_Codeunit] = ACTIONS(2392),
    [anon_sym_CodeUnit] = ACTIONS(2392),
    [anon_sym_COdeunit] = ACTIONS(2392),
    [anon_sym_codeUnit] = ACTIONS(2392),
    [sym_report_keyword] = ACTIONS(2392),
    [sym_query_keyword] = ACTIONS(2392),
    [anon_sym_xmlport] = ACTIONS(2392),
    [anon_sym_XMLPORT] = ACTIONS(2392),
    [anon_sym_Xmlport] = ACTIONS(2392),
    [anon_sym_XMLport] = ACTIONS(2392),
    [anon_sym_XMLPort] = ACTIONS(2392),
    [anon_sym_XmlPort] = ACTIONS(2392),
    [anon_sym_enum] = ACTIONS(2392),
    [anon_sym_ENUM] = ACTIONS(2392),
    [anon_sym_Enum] = ACTIONS(2392),
    [anon_sym_eNUM] = ACTIONS(2392),
    [anon_sym_eNum] = ACTIONS(2392),
    [anon_sym_ENum] = ACTIONS(2392),
    [sym_quoted_identifier] = ACTIONS(2394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2394),
    [sym_integer] = ACTIONS(2392),
    [sym_continue_as_identifier] = ACTIONS(2394),
    [sym_preproc_open] = ACTIONS(2394),
    [sym_end_keyword] = ACTIONS(2394),
  },
  [STATE(1167)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2430),
    [anon_sym_SEMI] = ACTIONS(2432),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2432),
    [anon_sym_DASH] = ACTIONS(2430),
    [aux_sym_boolean_token1] = ACTIONS(2430),
    [aux_sym_boolean_token2] = ACTIONS(2430),
    [sym_decimal] = ACTIONS(2430),
    [anon_sym_LPAREN] = ACTIONS(2432),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2430),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2430),
    [aux_sym_basic_type_token21] = ACTIONS(2430),
    [aux_sym_basic_type_token22] = ACTIONS(2430),
    [aux_sym_basic_type_token48] = ACTIONS(2430),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2430),
    [anon_sym_POUNDif] = ACTIONS(2432),
    [anon_sym_POUNDIF] = ACTIONS(2432),
    [anon_sym_POUNDIf] = ACTIONS(2432),
    [anon_sym_not] = ACTIONS(2430),
    [anon_sym_NOT] = ACTIONS(2430),
    [anon_sym_Not] = ACTIONS(2430),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2432),
    [aux_sym__expression_token1] = ACTIONS(2432),
    [aux_sym__expression_token2] = ACTIONS(2430),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2430),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2430),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2430),
    [anon_sym_GT_EQ] = ACTIONS(2432),
    [anon_sym_LT_EQ] = ACTIONS(2432),
    [anon_sym_GT] = ACTIONS(2430),
    [anon_sym_LT] = ACTIONS(2430),
    [anon_sym_LT_GT] = ACTIONS(2432),
    [anon_sym_and] = ACTIONS(2430),
    [anon_sym_AND] = ACTIONS(2430),
    [anon_sym_And] = ACTIONS(2430),
    [anon_sym_or] = ACTIONS(2430),
    [anon_sym_OR] = ACTIONS(2430),
    [anon_sym_Or] = ACTIONS(2430),
    [anon_sym_xor] = ACTIONS(2430),
    [anon_sym_XOR] = ACTIONS(2430),
    [anon_sym_Xor] = ACTIONS(2430),
    [anon_sym_QMARK] = ACTIONS(2432),
    [sym_datetime_literal] = ACTIONS(2432),
    [sym_date_literal] = ACTIONS(2430),
    [sym_time_literal] = ACTIONS(2430),
    [sym_biginteger_literal] = ACTIONS(2432),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_IF] = ACTIONS(2430),
    [anon_sym_If] = ACTIONS(2430),
    [anon_sym_else] = ACTIONS(2430),
    [anon_sym_ELSE] = ACTIONS(2430),
    [anon_sym_Else] = ACTIONS(2430),
    [anon_sym_case] = ACTIONS(2430),
    [anon_sym_CASE] = ACTIONS(2430),
    [anon_sym_Case] = ACTIONS(2430),
    [anon_sym_for] = ACTIONS(2430),
    [anon_sym_FOR] = ACTIONS(2430),
    [anon_sym_For] = ACTIONS(2430),
    [anon_sym_foreach] = ACTIONS(2430),
    [anon_sym_FOREACH] = ACTIONS(2430),
    [anon_sym_Foreach] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2430),
    [anon_sym_WHILE] = ACTIONS(2430),
    [anon_sym_While] = ACTIONS(2430),
    [anon_sym_repeat] = ACTIONS(2430),
    [anon_sym_REPEAT] = ACTIONS(2430),
    [anon_sym_Repeat] = ACTIONS(2430),
    [anon_sym_exit] = ACTIONS(2430),
    [anon_sym_EXIT] = ACTIONS(2430),
    [anon_sym_Exit] = ACTIONS(2430),
    [anon_sym_continue] = ACTIONS(2430),
    [anon_sym_CONTINUE] = ACTIONS(2430),
    [anon_sym_Continue] = ACTIONS(2430),
    [anon_sym_break] = ACTIONS(2430),
    [anon_sym_BREAK] = ACTIONS(2430),
    [anon_sym_Break] = ACTIONS(2430),
    [anon_sym_with] = ACTIONS(2430),
    [anon_sym_WITH] = ACTIONS(2430),
    [anon_sym_With] = ACTIONS(2430),
    [sym_asserterror_keyword] = ACTIONS(2432),
    [anon_sym_in] = ACTIONS(2430),
    [anon_sym_IN] = ACTIONS(2430),
    [anon_sym_In] = ACTIONS(2430),
    [sym_page_keyword] = ACTIONS(2430),
    [anon_sym_codeunit] = ACTIONS(2430),
    [anon_sym_CODEUNIT] = ACTIONS(2430),
    [anon_sym_Codeunit] = ACTIONS(2430),
    [anon_sym_CodeUnit] = ACTIONS(2430),
    [anon_sym_COdeunit] = ACTIONS(2430),
    [anon_sym_codeUnit] = ACTIONS(2430),
    [sym_report_keyword] = ACTIONS(2430),
    [sym_query_keyword] = ACTIONS(2430),
    [anon_sym_xmlport] = ACTIONS(2430),
    [anon_sym_XMLPORT] = ACTIONS(2430),
    [anon_sym_Xmlport] = ACTIONS(2430),
    [anon_sym_XMLport] = ACTIONS(2430),
    [anon_sym_XMLPort] = ACTIONS(2430),
    [anon_sym_XmlPort] = ACTIONS(2430),
    [anon_sym_enum] = ACTIONS(2430),
    [anon_sym_ENUM] = ACTIONS(2430),
    [anon_sym_Enum] = ACTIONS(2430),
    [anon_sym_eNUM] = ACTIONS(2430),
    [anon_sym_eNum] = ACTIONS(2430),
    [anon_sym_ENum] = ACTIONS(2430),
    [sym_quoted_identifier] = ACTIONS(2432),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2432),
    [sym_integer] = ACTIONS(2430),
    [sym_continue_as_identifier] = ACTIONS(2432),
    [sym_preproc_open] = ACTIONS(2432),
    [sym_end_keyword] = ACTIONS(2432),
  },
  [STATE(1168)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1168),
    [sym_identifier] = ACTIONS(2396),
    [anon_sym_SEMI] = ACTIONS(2398),
    [anon_sym_DOT] = ACTIONS(2802),
    [anon_sym_EQ] = ACTIONS(2398),
    [anon_sym_DASH] = ACTIONS(2396),
    [aux_sym_boolean_token1] = ACTIONS(2396),
    [aux_sym_boolean_token2] = ACTIONS(2396),
    [sym_decimal] = ACTIONS(2396),
    [anon_sym_LPAREN] = ACTIONS(2398),
    [anon_sym_DOT_DOT] = ACTIONS(2398),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2396),
    [anon_sym_STAR] = ACTIONS(2396),
    [anon_sym_LBRACK] = ACTIONS(2398),
    [aux_sym_record_type_token1] = ACTIONS(2396),
    [aux_sym_basic_type_token21] = ACTIONS(2396),
    [aux_sym_basic_type_token22] = ACTIONS(2396),
    [aux_sym_basic_type_token48] = ACTIONS(2396),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2396),
    [anon_sym_POUNDif] = ACTIONS(2398),
    [anon_sym_POUNDIF] = ACTIONS(2398),
    [anon_sym_POUNDIf] = ACTIONS(2398),
    [anon_sym_not] = ACTIONS(2396),
    [anon_sym_NOT] = ACTIONS(2396),
    [anon_sym_Not] = ACTIONS(2396),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2398),
    [aux_sym__expression_token1] = ACTIONS(2398),
    [aux_sym__expression_token2] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2396),
    [anon_sym_SLASH] = ACTIONS(2396),
    [anon_sym_div] = ACTIONS(2396),
    [anon_sym_DIV] = ACTIONS(2396),
    [anon_sym_Div] = ACTIONS(2396),
    [anon_sym_mod] = ACTIONS(2396),
    [anon_sym_MOD] = ACTIONS(2396),
    [anon_sym_Mod] = ACTIONS(2396),
    [anon_sym_PLUS] = ACTIONS(2396),
    [anon_sym_GT_EQ] = ACTIONS(2398),
    [anon_sym_LT_EQ] = ACTIONS(2398),
    [anon_sym_GT] = ACTIONS(2396),
    [anon_sym_LT] = ACTIONS(2396),
    [anon_sym_LT_GT] = ACTIONS(2398),
    [anon_sym_and] = ACTIONS(2396),
    [anon_sym_AND] = ACTIONS(2396),
    [anon_sym_And] = ACTIONS(2396),
    [anon_sym_or] = ACTIONS(2396),
    [anon_sym_OR] = ACTIONS(2396),
    [anon_sym_Or] = ACTIONS(2396),
    [anon_sym_xor] = ACTIONS(2396),
    [anon_sym_XOR] = ACTIONS(2396),
    [anon_sym_Xor] = ACTIONS(2396),
    [anon_sym_QMARK] = ACTIONS(2398),
    [sym_datetime_literal] = ACTIONS(2398),
    [sym_date_literal] = ACTIONS(2396),
    [sym_time_literal] = ACTIONS(2396),
    [sym_biginteger_literal] = ACTIONS(2398),
    [anon_sym_if] = ACTIONS(2396),
    [anon_sym_IF] = ACTIONS(2396),
    [anon_sym_If] = ACTIONS(2396),
    [anon_sym_else] = ACTIONS(2396),
    [anon_sym_ELSE] = ACTIONS(2396),
    [anon_sym_Else] = ACTIONS(2396),
    [anon_sym_case] = ACTIONS(2396),
    [anon_sym_CASE] = ACTIONS(2396),
    [anon_sym_Case] = ACTIONS(2396),
    [anon_sym_for] = ACTIONS(2396),
    [anon_sym_FOR] = ACTIONS(2396),
    [anon_sym_For] = ACTIONS(2396),
    [anon_sym_foreach] = ACTIONS(2396),
    [anon_sym_FOREACH] = ACTIONS(2396),
    [anon_sym_Foreach] = ACTIONS(2396),
    [anon_sym_while] = ACTIONS(2396),
    [anon_sym_WHILE] = ACTIONS(2396),
    [anon_sym_While] = ACTIONS(2396),
    [anon_sym_repeat] = ACTIONS(2396),
    [anon_sym_REPEAT] = ACTIONS(2396),
    [anon_sym_Repeat] = ACTIONS(2396),
    [anon_sym_exit] = ACTIONS(2396),
    [anon_sym_EXIT] = ACTIONS(2396),
    [anon_sym_Exit] = ACTIONS(2396),
    [anon_sym_continue] = ACTIONS(2396),
    [anon_sym_CONTINUE] = ACTIONS(2396),
    [anon_sym_Continue] = ACTIONS(2396),
    [anon_sym_break] = ACTIONS(2396),
    [anon_sym_BREAK] = ACTIONS(2396),
    [anon_sym_Break] = ACTIONS(2396),
    [anon_sym_with] = ACTIONS(2396),
    [anon_sym_WITH] = ACTIONS(2396),
    [anon_sym_With] = ACTIONS(2396),
    [sym_asserterror_keyword] = ACTIONS(2398),
    [anon_sym_in] = ACTIONS(2396),
    [anon_sym_IN] = ACTIONS(2396),
    [anon_sym_In] = ACTIONS(2396),
    [sym_page_keyword] = ACTIONS(2396),
    [anon_sym_codeunit] = ACTIONS(2396),
    [anon_sym_CODEUNIT] = ACTIONS(2396),
    [anon_sym_Codeunit] = ACTIONS(2396),
    [anon_sym_CodeUnit] = ACTIONS(2396),
    [anon_sym_COdeunit] = ACTIONS(2396),
    [anon_sym_codeUnit] = ACTIONS(2396),
    [sym_report_keyword] = ACTIONS(2396),
    [sym_query_keyword] = ACTIONS(2396),
    [anon_sym_xmlport] = ACTIONS(2396),
    [anon_sym_XMLPORT] = ACTIONS(2396),
    [anon_sym_Xmlport] = ACTIONS(2396),
    [anon_sym_XMLport] = ACTIONS(2396),
    [anon_sym_XMLPort] = ACTIONS(2396),
    [anon_sym_XmlPort] = ACTIONS(2396),
    [anon_sym_enum] = ACTIONS(2396),
    [anon_sym_ENUM] = ACTIONS(2396),
    [anon_sym_Enum] = ACTIONS(2396),
    [anon_sym_eNUM] = ACTIONS(2396),
    [anon_sym_eNum] = ACTIONS(2396),
    [anon_sym_ENum] = ACTIONS(2396),
    [sym_temporary_keyword] = ACTIONS(2396),
    [sym_quoted_identifier] = ACTIONS(2398),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2398),
    [sym_integer] = ACTIONS(2396),
    [sym_continue_as_identifier] = ACTIONS(2398),
    [sym_preproc_open] = ACTIONS(2398),
    [sym_end_keyword] = ACTIONS(2398),
  },
  [STATE(1169)] = {
    [sym_argument_list] = STATE(1213),
    [sym_identifier] = ACTIONS(2434),
    [anon_sym_SEMI] = ACTIONS(2436),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_DASH] = ACTIONS(2434),
    [aux_sym_boolean_token1] = ACTIONS(2434),
    [aux_sym_boolean_token2] = ACTIONS(2434),
    [sym_decimal] = ACTIONS(2434),
    [anon_sym_LPAREN] = ACTIONS(2805),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2434),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [aux_sym_record_type_token1] = ACTIONS(2434),
    [aux_sym_basic_type_token21] = ACTIONS(2434),
    [aux_sym_basic_type_token22] = ACTIONS(2434),
    [aux_sym_basic_type_token48] = ACTIONS(2434),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2434),
    [anon_sym_COLON_COLON] = ACTIONS(2807),
    [anon_sym_POUNDif] = ACTIONS(2436),
    [anon_sym_POUNDIF] = ACTIONS(2436),
    [anon_sym_POUNDIf] = ACTIONS(2436),
    [anon_sym_not] = ACTIONS(2434),
    [anon_sym_NOT] = ACTIONS(2434),
    [anon_sym_Not] = ACTIONS(2434),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2434),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(2434),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(2436),
    [sym_date_literal] = ACTIONS(2434),
    [sym_time_literal] = ACTIONS(2434),
    [sym_biginteger_literal] = ACTIONS(2436),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_IF] = ACTIONS(2434),
    [anon_sym_If] = ACTIONS(2434),
    [anon_sym_else] = ACTIONS(2434),
    [anon_sym_ELSE] = ACTIONS(2434),
    [anon_sym_Else] = ACTIONS(2434),
    [anon_sym_case] = ACTIONS(2434),
    [anon_sym_CASE] = ACTIONS(2434),
    [anon_sym_Case] = ACTIONS(2434),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_FOR] = ACTIONS(2434),
    [anon_sym_For] = ACTIONS(2434),
    [anon_sym_foreach] = ACTIONS(2434),
    [anon_sym_FOREACH] = ACTIONS(2434),
    [anon_sym_Foreach] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(2434),
    [anon_sym_WHILE] = ACTIONS(2434),
    [anon_sym_While] = ACTIONS(2434),
    [anon_sym_repeat] = ACTIONS(2434),
    [anon_sym_REPEAT] = ACTIONS(2434),
    [anon_sym_Repeat] = ACTIONS(2434),
    [anon_sym_exit] = ACTIONS(2434),
    [anon_sym_EXIT] = ACTIONS(2434),
    [anon_sym_Exit] = ACTIONS(2434),
    [anon_sym_continue] = ACTIONS(2434),
    [anon_sym_CONTINUE] = ACTIONS(2434),
    [anon_sym_Continue] = ACTIONS(2434),
    [anon_sym_break] = ACTIONS(2434),
    [anon_sym_BREAK] = ACTIONS(2434),
    [anon_sym_Break] = ACTIONS(2434),
    [anon_sym_with] = ACTIONS(2434),
    [anon_sym_WITH] = ACTIONS(2434),
    [anon_sym_With] = ACTIONS(2434),
    [sym_asserterror_keyword] = ACTIONS(2436),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(2434),
    [anon_sym_codeunit] = ACTIONS(2434),
    [anon_sym_CODEUNIT] = ACTIONS(2434),
    [anon_sym_Codeunit] = ACTIONS(2434),
    [anon_sym_CodeUnit] = ACTIONS(2434),
    [anon_sym_COdeunit] = ACTIONS(2434),
    [anon_sym_codeUnit] = ACTIONS(2434),
    [sym_report_keyword] = ACTIONS(2434),
    [sym_query_keyword] = ACTIONS(2434),
    [anon_sym_xmlport] = ACTIONS(2434),
    [anon_sym_XMLPORT] = ACTIONS(2434),
    [anon_sym_Xmlport] = ACTIONS(2434),
    [anon_sym_XMLport] = ACTIONS(2434),
    [anon_sym_XMLPort] = ACTIONS(2434),
    [anon_sym_XmlPort] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2434),
    [anon_sym_ENUM] = ACTIONS(2434),
    [anon_sym_Enum] = ACTIONS(2434),
    [anon_sym_eNUM] = ACTIONS(2434),
    [anon_sym_eNum] = ACTIONS(2434),
    [anon_sym_ENum] = ACTIONS(2434),
    [sym_quoted_identifier] = ACTIONS(2436),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2436),
    [sym_integer] = ACTIONS(2434),
    [sym_continue_as_identifier] = ACTIONS(2436),
    [sym_preproc_open] = ACTIONS(2436),
    [sym_end_keyword] = ACTIONS(2436),
  },
  [STATE(1170)] = {
    [sym_preproc_conditional_object] = STATE(1170),
    [sym_using_statement] = STATE(1170),
    [sym__object] = STATE(1170),
    [sym_preproc_split_declaration] = STATE(1170),
    [sym_table_declaration] = STATE(1170),
    [sym_page_declaration] = STATE(1170),
    [sym_report_declaration] = STATE(1170),
    [sym_query_declaration] = STATE(1170),
    [sym_xmlport_declaration] = STATE(1170),
    [sym_permissionset_declaration] = STATE(1170),
    [sym_codeunit_declaration] = STATE(1170),
    [sym_enum_declaration] = STATE(1170),
    [sym_tableextension_declaration] = STATE(1170),
    [sym_pageextension_declaration] = STATE(1170),
    [sym_reportextension_declaration] = STATE(1170),
    [sym_enumextension_declaration] = STATE(1170),
    [sym_permissionsetextension_declaration] = STATE(1170),
    [sym_controladdin_declaration] = STATE(1170),
    [sym_profile_declaration] = STATE(1170),
    [sym_entitlement_declaration] = STATE(1170),
    [sym_profileextension_declaration] = STATE(1170),
    [sym_interface_declaration] = STATE(1170),
    [sym_pagecustomization_declaration] = STATE(1170),
    [sym_dotnet_declaration] = STATE(1170),
    [sym_preproc_if] = STATE(620),
    [sym_tableextension_keyword] = STATE(12387),
    [sym_pageextension_keyword] = STATE(12389),
    [sym_codeunit_keyword] = STATE(12423),
    [sym_reportextension_keyword] = STATE(12428),
    [sym_xmlport_keyword] = STATE(12505),
    [sym_enum_keyword] = STATE(12506),
    [sym_enumextension_keyword] = STATE(12516),
    [sym_controladdin_keyword] = STATE(8740),
    [sym_dotnet_keyword] = STATE(11413),
    [sym_profileextension_keyword] = STATE(8726),
    [sym_permissionset_keyword] = STATE(12440),
    [sym_permissionsetextension_keyword] = STATE(12495),
    [sym_pagecustomization_keyword] = STATE(8356),
    [aux_sym_source_file_repeat1] = STATE(1170),
    [ts_builtin_sym_end] = ACTIONS(2449),
    [anon_sym_POUNDif] = ACTIONS(2446),
    [anon_sym_POUNDIF] = ACTIONS(2446),
    [anon_sym_POUNDIf] = ACTIONS(2446),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2809),
    [anon_sym_tableextension] = ACTIONS(2454),
    [anon_sym_TABLEEXTENSION] = ACTIONS(2454),
    [anon_sym_Tableextension] = ACTIONS(2454),
    [anon_sym_TableExtension] = ACTIONS(2454),
    [anon_sym_tableExtension] = ACTIONS(2454),
    [sym_page_keyword] = ACTIONS(2812),
    [anon_sym_pageextension] = ACTIONS(2460),
    [anon_sym_PAGEEXTENSION] = ACTIONS(2460),
    [anon_sym_Pageextension] = ACTIONS(2460),
    [anon_sym_PageExtension] = ACTIONS(2460),
    [anon_sym_pageExtension] = ACTIONS(2460),
    [anon_sym_codeunit] = ACTIONS(2463),
    [anon_sym_CODEUNIT] = ACTIONS(2463),
    [anon_sym_Codeunit] = ACTIONS(2463),
    [anon_sym_CodeUnit] = ACTIONS(2463),
    [anon_sym_COdeunit] = ACTIONS(2463),
    [anon_sym_codeUnit] = ACTIONS(2463),
    [sym_report_keyword] = ACTIONS(2815),
    [anon_sym_reportextension] = ACTIONS(2469),
    [anon_sym_REPORTEXTENSION] = ACTIONS(2469),
    [anon_sym_Reportextension] = ACTIONS(2469),
    [anon_sym_ReportExtension] = ACTIONS(2469),
    [anon_sym_reportExtension] = ACTIONS(2469),
    [sym_query_keyword] = ACTIONS(2818),
    [anon_sym_xmlport] = ACTIONS(2475),
    [anon_sym_XMLPORT] = ACTIONS(2475),
    [anon_sym_Xmlport] = ACTIONS(2475),
    [anon_sym_XMLport] = ACTIONS(2475),
    [anon_sym_XMLPort] = ACTIONS(2475),
    [anon_sym_XmlPort] = ACTIONS(2475),
    [anon_sym_enum] = ACTIONS(2478),
    [anon_sym_ENUM] = ACTIONS(2478),
    [anon_sym_Enum] = ACTIONS(2478),
    [anon_sym_eNUM] = ACTIONS(2481),
    [anon_sym_eNum] = ACTIONS(2481),
    [anon_sym_ENum] = ACTIONS(2481),
    [anon_sym_enumextension] = ACTIONS(2484),
    [anon_sym_ENUMEXTENSION] = ACTIONS(2484),
    [anon_sym_Enumextension] = ACTIONS(2484),
    [anon_sym_EnumExtension] = ACTIONS(2484),
    [anon_sym_enumExtension] = ACTIONS(2484),
    [sym_interface_keyword] = ACTIONS(2821),
    [anon_sym_controladdin] = ACTIONS(2490),
    [anon_sym_CONTROLADDIN] = ACTIONS(2490),
    [anon_sym_Controladdin] = ACTIONS(2490),
    [anon_sym_ControlAddIn] = ACTIONS(2490),
    [anon_sym_ControlAddin] = ACTIONS(2490),
    [anon_sym_controlAddIn] = ACTIONS(2490),
    [anon_sym_controlAddin] = ACTIONS(2490),
    [anon_sym_dotnet] = ACTIONS(2493),
    [anon_sym_DOTNET] = ACTIONS(2493),
    [anon_sym_Dotnet] = ACTIONS(2493),
    [anon_sym_DotNet] = ACTIONS(2493),
    [anon_sym_dotNet] = ACTIONS(2493),
    [sym_profile_keyword] = ACTIONS(2824),
    [anon_sym_profileextension] = ACTIONS(2499),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(2499),
    [anon_sym_Profileextension] = ACTIONS(2499),
    [anon_sym_ProfileExtension] = ACTIONS(2499),
    [anon_sym_profileExtension] = ACTIONS(2499),
    [anon_sym_permissionset] = ACTIONS(2502),
    [anon_sym_PERMISSIONSET] = ACTIONS(2502),
    [anon_sym_Permissionset] = ACTIONS(2502),
    [anon_sym_PermissionSet] = ACTIONS(2502),
    [anon_sym_permissionSet] = ACTIONS(2502),
    [anon_sym_permissionsetextension] = ACTIONS(2505),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(2505),
    [anon_sym_Permissionsetextension] = ACTIONS(2505),
    [anon_sym_PermissionSetExtension] = ACTIONS(2505),
    [anon_sym_permissionSetExtension] = ACTIONS(2505),
    [sym_entitlement_keyword] = ACTIONS(2827),
    [anon_sym_pagecustomization] = ACTIONS(2511),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(2511),
    [anon_sym_Pagecustomization] = ACTIONS(2511),
    [anon_sym_PageCustomization] = ACTIONS(2511),
    [anon_sym_pageCustomization] = ACTIONS(2511),
    [sym_using_keyword] = ACTIONS(2830),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(2446),
  },
  [STATE(1171)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2743),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_end_keyword] = ACTIONS(2272),
  },
  [STATE(1172)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2743),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_end_keyword] = ACTIONS(2272),
  },
  [STATE(1173)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2316),
    [anon_sym_SEMI] = ACTIONS(2318),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2318),
    [anon_sym_DASH] = ACTIONS(2316),
    [aux_sym_boolean_token1] = ACTIONS(2316),
    [aux_sym_boolean_token2] = ACTIONS(2316),
    [sym_decimal] = ACTIONS(2316),
    [anon_sym_LPAREN] = ACTIONS(2318),
    [anon_sym_DOT_DOT] = ACTIONS(2318),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2316),
    [anon_sym_STAR] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2316),
    [aux_sym_basic_type_token21] = ACTIONS(2316),
    [aux_sym_basic_type_token22] = ACTIONS(2316),
    [aux_sym_basic_type_token48] = ACTIONS(2316),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2316),
    [anon_sym_POUNDif] = ACTIONS(2318),
    [anon_sym_POUNDIF] = ACTIONS(2318),
    [anon_sym_POUNDIf] = ACTIONS(2318),
    [anon_sym_not] = ACTIONS(2316),
    [anon_sym_NOT] = ACTIONS(2316),
    [anon_sym_Not] = ACTIONS(2316),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2318),
    [aux_sym__expression_token1] = ACTIONS(2318),
    [aux_sym__expression_token2] = ACTIONS(2316),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2316),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2316),
    [anon_sym_SLASH] = ACTIONS(2316),
    [anon_sym_div] = ACTIONS(2316),
    [anon_sym_DIV] = ACTIONS(2316),
    [anon_sym_Div] = ACTIONS(2316),
    [anon_sym_mod] = ACTIONS(2316),
    [anon_sym_MOD] = ACTIONS(2316),
    [anon_sym_Mod] = ACTIONS(2316),
    [anon_sym_PLUS] = ACTIONS(2316),
    [anon_sym_GT_EQ] = ACTIONS(2318),
    [anon_sym_LT_EQ] = ACTIONS(2318),
    [anon_sym_GT] = ACTIONS(2316),
    [anon_sym_LT] = ACTIONS(2316),
    [anon_sym_LT_GT] = ACTIONS(2318),
    [anon_sym_and] = ACTIONS(2316),
    [anon_sym_AND] = ACTIONS(2316),
    [anon_sym_And] = ACTIONS(2316),
    [anon_sym_or] = ACTIONS(2316),
    [anon_sym_OR] = ACTIONS(2316),
    [anon_sym_Or] = ACTIONS(2316),
    [anon_sym_xor] = ACTIONS(2316),
    [anon_sym_XOR] = ACTIONS(2316),
    [anon_sym_Xor] = ACTIONS(2316),
    [anon_sym_QMARK] = ACTIONS(2318),
    [sym_datetime_literal] = ACTIONS(2318),
    [sym_date_literal] = ACTIONS(2316),
    [sym_time_literal] = ACTIONS(2316),
    [sym_biginteger_literal] = ACTIONS(2318),
    [anon_sym_if] = ACTIONS(2316),
    [anon_sym_IF] = ACTIONS(2316),
    [anon_sym_If] = ACTIONS(2316),
    [anon_sym_else] = ACTIONS(2316),
    [anon_sym_ELSE] = ACTIONS(2316),
    [anon_sym_Else] = ACTIONS(2316),
    [anon_sym_case] = ACTIONS(2316),
    [anon_sym_CASE] = ACTIONS(2316),
    [anon_sym_Case] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2316),
    [anon_sym_FOR] = ACTIONS(2316),
    [anon_sym_For] = ACTIONS(2316),
    [anon_sym_foreach] = ACTIONS(2316),
    [anon_sym_FOREACH] = ACTIONS(2316),
    [anon_sym_Foreach] = ACTIONS(2316),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_WHILE] = ACTIONS(2316),
    [anon_sym_While] = ACTIONS(2316),
    [anon_sym_repeat] = ACTIONS(2316),
    [anon_sym_REPEAT] = ACTIONS(2316),
    [anon_sym_Repeat] = ACTIONS(2316),
    [anon_sym_exit] = ACTIONS(2316),
    [anon_sym_EXIT] = ACTIONS(2316),
    [anon_sym_Exit] = ACTIONS(2316),
    [anon_sym_continue] = ACTIONS(2316),
    [anon_sym_CONTINUE] = ACTIONS(2316),
    [anon_sym_Continue] = ACTIONS(2316),
    [anon_sym_break] = ACTIONS(2316),
    [anon_sym_BREAK] = ACTIONS(2316),
    [anon_sym_Break] = ACTIONS(2316),
    [anon_sym_with] = ACTIONS(2316),
    [anon_sym_WITH] = ACTIONS(2316),
    [anon_sym_With] = ACTIONS(2316),
    [sym_asserterror_keyword] = ACTIONS(2318),
    [anon_sym_in] = ACTIONS(2316),
    [anon_sym_IN] = ACTIONS(2316),
    [anon_sym_In] = ACTIONS(2316),
    [sym_page_keyword] = ACTIONS(2316),
    [anon_sym_codeunit] = ACTIONS(2316),
    [anon_sym_CODEUNIT] = ACTIONS(2316),
    [anon_sym_Codeunit] = ACTIONS(2316),
    [anon_sym_CodeUnit] = ACTIONS(2316),
    [anon_sym_COdeunit] = ACTIONS(2316),
    [anon_sym_codeUnit] = ACTIONS(2316),
    [sym_report_keyword] = ACTIONS(2316),
    [sym_query_keyword] = ACTIONS(2316),
    [anon_sym_xmlport] = ACTIONS(2316),
    [anon_sym_XMLPORT] = ACTIONS(2316),
    [anon_sym_Xmlport] = ACTIONS(2316),
    [anon_sym_XMLport] = ACTIONS(2316),
    [anon_sym_XMLPort] = ACTIONS(2316),
    [anon_sym_XmlPort] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_ENUM] = ACTIONS(2316),
    [anon_sym_Enum] = ACTIONS(2316),
    [anon_sym_eNUM] = ACTIONS(2316),
    [anon_sym_eNum] = ACTIONS(2316),
    [anon_sym_ENum] = ACTIONS(2316),
    [sym_quoted_identifier] = ACTIONS(2318),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2318),
    [sym_integer] = ACTIONS(2316),
    [sym_continue_as_identifier] = ACTIONS(2318),
    [sym_preproc_open] = ACTIONS(2318),
    [sym_end_keyword] = ACTIONS(2318),
  },
  [STATE(1174)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_end_keyword] = ACTIONS(2322),
  },
  [STATE(1175)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2326),
    [anon_sym_SEMI] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2743),
    [aux_sym_boolean_token1] = ACTIONS(2326),
    [aux_sym_boolean_token2] = ACTIONS(2326),
    [sym_decimal] = ACTIONS(2326),
    [anon_sym_LPAREN] = ACTIONS(2328),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2326),
    [aux_sym_basic_type_token21] = ACTIONS(2326),
    [aux_sym_basic_type_token22] = ACTIONS(2326),
    [aux_sym_basic_type_token48] = ACTIONS(2326),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2326),
    [anon_sym_POUNDif] = ACTIONS(2328),
    [anon_sym_POUNDIF] = ACTIONS(2328),
    [anon_sym_POUNDIf] = ACTIONS(2328),
    [anon_sym_not] = ACTIONS(2326),
    [anon_sym_NOT] = ACTIONS(2326),
    [anon_sym_Not] = ACTIONS(2326),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2787),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2326),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2326),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2767),
    [anon_sym_AND] = ACTIONS(2769),
    [anon_sym_And] = ACTIONS(2771),
    [anon_sym_or] = ACTIONS(2773),
    [anon_sym_OR] = ACTIONS(2775),
    [anon_sym_Or] = ACTIONS(2777),
    [anon_sym_xor] = ACTIONS(2779),
    [anon_sym_XOR] = ACTIONS(2781),
    [anon_sym_Xor] = ACTIONS(2783),
    [anon_sym_QMARK] = ACTIONS(2785),
    [sym_datetime_literal] = ACTIONS(2328),
    [sym_date_literal] = ACTIONS(2326),
    [sym_time_literal] = ACTIONS(2326),
    [sym_biginteger_literal] = ACTIONS(2328),
    [anon_sym_if] = ACTIONS(2326),
    [anon_sym_IF] = ACTIONS(2326),
    [anon_sym_If] = ACTIONS(2326),
    [anon_sym_else] = ACTIONS(2326),
    [anon_sym_ELSE] = ACTIONS(2326),
    [anon_sym_Else] = ACTIONS(2326),
    [anon_sym_case] = ACTIONS(2326),
    [anon_sym_CASE] = ACTIONS(2326),
    [anon_sym_Case] = ACTIONS(2326),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_FOR] = ACTIONS(2326),
    [anon_sym_For] = ACTIONS(2326),
    [anon_sym_foreach] = ACTIONS(2326),
    [anon_sym_FOREACH] = ACTIONS(2326),
    [anon_sym_Foreach] = ACTIONS(2326),
    [anon_sym_while] = ACTIONS(2326),
    [anon_sym_WHILE] = ACTIONS(2326),
    [anon_sym_While] = ACTIONS(2326),
    [anon_sym_repeat] = ACTIONS(2326),
    [anon_sym_REPEAT] = ACTIONS(2326),
    [anon_sym_Repeat] = ACTIONS(2326),
    [anon_sym_exit] = ACTIONS(2326),
    [anon_sym_EXIT] = ACTIONS(2326),
    [anon_sym_Exit] = ACTIONS(2326),
    [anon_sym_continue] = ACTIONS(2326),
    [anon_sym_CONTINUE] = ACTIONS(2326),
    [anon_sym_Continue] = ACTIONS(2326),
    [anon_sym_break] = ACTIONS(2326),
    [anon_sym_BREAK] = ACTIONS(2326),
    [anon_sym_Break] = ACTIONS(2326),
    [anon_sym_with] = ACTIONS(2326),
    [anon_sym_WITH] = ACTIONS(2326),
    [anon_sym_With] = ACTIONS(2326),
    [sym_asserterror_keyword] = ACTIONS(2328),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2326),
    [anon_sym_codeunit] = ACTIONS(2326),
    [anon_sym_CODEUNIT] = ACTIONS(2326),
    [anon_sym_Codeunit] = ACTIONS(2326),
    [anon_sym_CodeUnit] = ACTIONS(2326),
    [anon_sym_COdeunit] = ACTIONS(2326),
    [anon_sym_codeUnit] = ACTIONS(2326),
    [sym_report_keyword] = ACTIONS(2326),
    [sym_query_keyword] = ACTIONS(2326),
    [anon_sym_xmlport] = ACTIONS(2326),
    [anon_sym_XMLPORT] = ACTIONS(2326),
    [anon_sym_Xmlport] = ACTIONS(2326),
    [anon_sym_XMLport] = ACTIONS(2326),
    [anon_sym_XMLPort] = ACTIONS(2326),
    [anon_sym_XmlPort] = ACTIONS(2326),
    [anon_sym_enum] = ACTIONS(2326),
    [anon_sym_ENUM] = ACTIONS(2326),
    [anon_sym_Enum] = ACTIONS(2326),
    [anon_sym_eNUM] = ACTIONS(2326),
    [anon_sym_eNum] = ACTIONS(2326),
    [anon_sym_ENum] = ACTIONS(2326),
    [sym_quoted_identifier] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2328),
    [sym_integer] = ACTIONS(2326),
    [sym_continue_as_identifier] = ACTIONS(2328),
    [sym_preproc_open] = ACTIONS(2328),
    [sym_end_keyword] = ACTIONS(2328),
  },
  [STATE(1176)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_end_keyword] = ACTIONS(2322),
  },
  [STATE(1177)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2743),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_end_keyword] = ACTIONS(2272),
  },
  [STATE(1178)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_end_keyword] = ACTIONS(2322),
  },
  [STATE(1179)] = {
    [sym_preproc_conditional_object] = STATE(1159),
    [sym_using_statement] = STATE(1159),
    [sym__object] = STATE(1159),
    [sym_preproc_split_declaration] = STATE(1159),
    [sym_table_declaration] = STATE(1159),
    [sym_page_declaration] = STATE(1159),
    [sym_report_declaration] = STATE(1159),
    [sym_query_declaration] = STATE(1159),
    [sym_xmlport_declaration] = STATE(1159),
    [sym_permissionset_declaration] = STATE(1159),
    [sym_codeunit_declaration] = STATE(1159),
    [sym_enum_declaration] = STATE(1159),
    [sym_tableextension_declaration] = STATE(1159),
    [sym_pageextension_declaration] = STATE(1159),
    [sym_reportextension_declaration] = STATE(1159),
    [sym_enumextension_declaration] = STATE(1159),
    [sym_permissionsetextension_declaration] = STATE(1159),
    [sym_controladdin_declaration] = STATE(1159),
    [sym_profile_declaration] = STATE(1159),
    [sym_entitlement_declaration] = STATE(1159),
    [sym_profileextension_declaration] = STATE(1159),
    [sym_interface_declaration] = STATE(1159),
    [sym_pagecustomization_declaration] = STATE(1159),
    [sym_dotnet_declaration] = STATE(1159),
    [sym_preproc_if] = STATE(620),
    [sym_tableextension_keyword] = STATE(12387),
    [sym_pageextension_keyword] = STATE(12389),
    [sym_codeunit_keyword] = STATE(12423),
    [sym_reportextension_keyword] = STATE(12428),
    [sym_xmlport_keyword] = STATE(12505),
    [sym_enum_keyword] = STATE(12506),
    [sym_enumextension_keyword] = STATE(12516),
    [sym_controladdin_keyword] = STATE(8740),
    [sym_dotnet_keyword] = STATE(11413),
    [sym_profileextension_keyword] = STATE(8726),
    [sym_permissionset_keyword] = STATE(12440),
    [sym_permissionsetextension_keyword] = STATE(12495),
    [sym_pagecustomization_keyword] = STATE(8356),
    [aux_sym_source_file_repeat1] = STATE(1159),
    [ts_builtin_sym_end] = ACTIONS(2800),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(13),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(19),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(23),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(33),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(39),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(47),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(53),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
  },
  [STATE(1180)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_end_keyword] = ACTIONS(2322),
  },
  [STATE(1181)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_end_keyword] = ACTIONS(2322),
  },
  [STATE(1182)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_end_keyword] = ACTIONS(2322),
  },
  [STATE(1183)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_IF] = ACTIONS(2320),
    [anon_sym_If] = ACTIONS(2320),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_CASE] = ACTIONS(2320),
    [anon_sym_Case] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_FOR] = ACTIONS(2320),
    [anon_sym_For] = ACTIONS(2320),
    [anon_sym_foreach] = ACTIONS(2320),
    [anon_sym_FOREACH] = ACTIONS(2320),
    [anon_sym_Foreach] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_WHILE] = ACTIONS(2320),
    [anon_sym_While] = ACTIONS(2320),
    [anon_sym_repeat] = ACTIONS(2320),
    [anon_sym_REPEAT] = ACTIONS(2320),
    [anon_sym_Repeat] = ACTIONS(2320),
    [anon_sym_exit] = ACTIONS(2320),
    [anon_sym_EXIT] = ACTIONS(2320),
    [anon_sym_Exit] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_CONTINUE] = ACTIONS(2320),
    [anon_sym_Continue] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_BREAK] = ACTIONS(2320),
    [anon_sym_Break] = ACTIONS(2320),
    [anon_sym_with] = ACTIONS(2320),
    [anon_sym_WITH] = ACTIONS(2320),
    [anon_sym_With] = ACTIONS(2320),
    [sym_asserterror_keyword] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_end_keyword] = ACTIONS(2322),
  },
  [STATE(1184)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2360),
    [anon_sym_SEMI] = ACTIONS(2362),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2362),
    [anon_sym_DASH] = ACTIONS(2360),
    [aux_sym_boolean_token1] = ACTIONS(2360),
    [aux_sym_boolean_token2] = ACTIONS(2360),
    [sym_decimal] = ACTIONS(2360),
    [anon_sym_LPAREN] = ACTIONS(2362),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2360),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2360),
    [aux_sym_basic_type_token21] = ACTIONS(2360),
    [aux_sym_basic_type_token22] = ACTIONS(2360),
    [aux_sym_basic_type_token48] = ACTIONS(2360),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2360),
    [anon_sym_POUNDif] = ACTIONS(2362),
    [anon_sym_POUNDIF] = ACTIONS(2362),
    [anon_sym_POUNDIf] = ACTIONS(2362),
    [anon_sym_not] = ACTIONS(2360),
    [anon_sym_NOT] = ACTIONS(2360),
    [anon_sym_Not] = ACTIONS(2360),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2362),
    [aux_sym__expression_token1] = ACTIONS(2362),
    [aux_sym__expression_token2] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2360),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2360),
    [anon_sym_GT_EQ] = ACTIONS(2362),
    [anon_sym_LT_EQ] = ACTIONS(2362),
    [anon_sym_GT] = ACTIONS(2360),
    [anon_sym_LT] = ACTIONS(2360),
    [anon_sym_LT_GT] = ACTIONS(2362),
    [anon_sym_and] = ACTIONS(2360),
    [anon_sym_AND] = ACTIONS(2360),
    [anon_sym_And] = ACTIONS(2360),
    [anon_sym_or] = ACTIONS(2360),
    [anon_sym_OR] = ACTIONS(2360),
    [anon_sym_Or] = ACTIONS(2360),
    [anon_sym_xor] = ACTIONS(2360),
    [anon_sym_XOR] = ACTIONS(2360),
    [anon_sym_Xor] = ACTIONS(2360),
    [anon_sym_QMARK] = ACTIONS(2362),
    [sym_datetime_literal] = ACTIONS(2362),
    [sym_date_literal] = ACTIONS(2360),
    [sym_time_literal] = ACTIONS(2360),
    [sym_biginteger_literal] = ACTIONS(2362),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_IF] = ACTIONS(2360),
    [anon_sym_If] = ACTIONS(2360),
    [anon_sym_else] = ACTIONS(2360),
    [anon_sym_ELSE] = ACTIONS(2360),
    [anon_sym_Else] = ACTIONS(2360),
    [anon_sym_case] = ACTIONS(2360),
    [anon_sym_CASE] = ACTIONS(2360),
    [anon_sym_Case] = ACTIONS(2360),
    [anon_sym_for] = ACTIONS(2360),
    [anon_sym_FOR] = ACTIONS(2360),
    [anon_sym_For] = ACTIONS(2360),
    [anon_sym_foreach] = ACTIONS(2360),
    [anon_sym_FOREACH] = ACTIONS(2360),
    [anon_sym_Foreach] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2360),
    [anon_sym_WHILE] = ACTIONS(2360),
    [anon_sym_While] = ACTIONS(2360),
    [anon_sym_repeat] = ACTIONS(2360),
    [anon_sym_REPEAT] = ACTIONS(2360),
    [anon_sym_Repeat] = ACTIONS(2360),
    [anon_sym_exit] = ACTIONS(2360),
    [anon_sym_EXIT] = ACTIONS(2360),
    [anon_sym_Exit] = ACTIONS(2360),
    [anon_sym_continue] = ACTIONS(2360),
    [anon_sym_CONTINUE] = ACTIONS(2360),
    [anon_sym_Continue] = ACTIONS(2360),
    [anon_sym_break] = ACTIONS(2360),
    [anon_sym_BREAK] = ACTIONS(2360),
    [anon_sym_Break] = ACTIONS(2360),
    [anon_sym_with] = ACTIONS(2360),
    [anon_sym_WITH] = ACTIONS(2360),
    [anon_sym_With] = ACTIONS(2360),
    [sym_asserterror_keyword] = ACTIONS(2362),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_IN] = ACTIONS(2360),
    [anon_sym_In] = ACTIONS(2360),
    [sym_page_keyword] = ACTIONS(2360),
    [anon_sym_codeunit] = ACTIONS(2360),
    [anon_sym_CODEUNIT] = ACTIONS(2360),
    [anon_sym_Codeunit] = ACTIONS(2360),
    [anon_sym_CodeUnit] = ACTIONS(2360),
    [anon_sym_COdeunit] = ACTIONS(2360),
    [anon_sym_codeUnit] = ACTIONS(2360),
    [sym_report_keyword] = ACTIONS(2360),
    [sym_query_keyword] = ACTIONS(2360),
    [anon_sym_xmlport] = ACTIONS(2360),
    [anon_sym_XMLPORT] = ACTIONS(2360),
    [anon_sym_Xmlport] = ACTIONS(2360),
    [anon_sym_XMLport] = ACTIONS(2360),
    [anon_sym_XMLPort] = ACTIONS(2360),
    [anon_sym_XmlPort] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_ENUM] = ACTIONS(2360),
    [anon_sym_Enum] = ACTIONS(2360),
    [anon_sym_eNUM] = ACTIONS(2360),
    [anon_sym_eNum] = ACTIONS(2360),
    [anon_sym_ENum] = ACTIONS(2360),
    [sym_quoted_identifier] = ACTIONS(2362),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2362),
    [sym_integer] = ACTIONS(2360),
    [sym_continue_as_identifier] = ACTIONS(2362),
    [sym_preproc_open] = ACTIONS(2362),
    [sym_end_keyword] = ACTIONS(2362),
  },
  [STATE(1185)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2743),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2767),
    [anon_sym_AND] = ACTIONS(2769),
    [anon_sym_And] = ACTIONS(2771),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_end_keyword] = ACTIONS(2272),
  },
  [STATE(1186)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2743),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2767),
    [anon_sym_AND] = ACTIONS(2769),
    [anon_sym_And] = ACTIONS(2771),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_end_keyword] = ACTIONS(2272),
  },
  [STATE(1187)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1196),
    [sym_identifier] = ACTIONS(376),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(2791),
    [anon_sym_DASH] = ACTIONS(376),
    [aux_sym_boolean_token1] = ACTIONS(376),
    [aux_sym_boolean_token2] = ACTIONS(376),
    [sym_decimal] = ACTIONS(376),
    [anon_sym_LPAREN] = ACTIONS(374),
    [anon_sym_DOT_DOT] = ACTIONS(374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(376),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(376),
    [aux_sym_basic_type_token21] = ACTIONS(376),
    [aux_sym_basic_type_token22] = ACTIONS(376),
    [aux_sym_basic_type_token48] = ACTIONS(376),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(376),
    [anon_sym_POUNDif] = ACTIONS(374),
    [anon_sym_POUNDIF] = ACTIONS(374),
    [anon_sym_POUNDIf] = ACTIONS(374),
    [anon_sym_not] = ACTIONS(376),
    [anon_sym_NOT] = ACTIONS(376),
    [anon_sym_Not] = ACTIONS(376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(374),
    [aux_sym__expression_token1] = ACTIONS(374),
    [aux_sym__expression_token2] = ACTIONS(376),
    [aux_sym_keyword_identifier_token1] = ACTIONS(376),
    [aux_sym_keyword_identifier_token2] = ACTIONS(376),
    [anon_sym_SLASH] = ACTIONS(376),
    [anon_sym_div] = ACTIONS(376),
    [anon_sym_DIV] = ACTIONS(376),
    [anon_sym_Div] = ACTIONS(376),
    [anon_sym_mod] = ACTIONS(376),
    [anon_sym_MOD] = ACTIONS(376),
    [anon_sym_Mod] = ACTIONS(376),
    [anon_sym_PLUS] = ACTIONS(376),
    [anon_sym_GT_EQ] = ACTIONS(374),
    [anon_sym_LT_EQ] = ACTIONS(374),
    [anon_sym_GT] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(376),
    [anon_sym_LT_GT] = ACTIONS(374),
    [anon_sym_and] = ACTIONS(376),
    [anon_sym_AND] = ACTIONS(376),
    [anon_sym_And] = ACTIONS(376),
    [anon_sym_or] = ACTIONS(376),
    [anon_sym_OR] = ACTIONS(376),
    [anon_sym_Or] = ACTIONS(376),
    [anon_sym_xor] = ACTIONS(376),
    [anon_sym_XOR] = ACTIONS(376),
    [anon_sym_Xor] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(374),
    [sym_datetime_literal] = ACTIONS(374),
    [sym_date_literal] = ACTIONS(376),
    [sym_time_literal] = ACTIONS(376),
    [sym_biginteger_literal] = ACTIONS(374),
    [anon_sym_if] = ACTIONS(376),
    [anon_sym_IF] = ACTIONS(376),
    [anon_sym_If] = ACTIONS(376),
    [anon_sym_else] = ACTIONS(376),
    [anon_sym_ELSE] = ACTIONS(376),
    [anon_sym_Else] = ACTIONS(376),
    [anon_sym_case] = ACTIONS(376),
    [anon_sym_CASE] = ACTIONS(376),
    [anon_sym_Case] = ACTIONS(376),
    [anon_sym_for] = ACTIONS(376),
    [anon_sym_FOR] = ACTIONS(376),
    [anon_sym_For] = ACTIONS(376),
    [anon_sym_foreach] = ACTIONS(376),
    [anon_sym_FOREACH] = ACTIONS(376),
    [anon_sym_Foreach] = ACTIONS(376),
    [anon_sym_while] = ACTIONS(376),
    [anon_sym_WHILE] = ACTIONS(376),
    [anon_sym_While] = ACTIONS(376),
    [anon_sym_repeat] = ACTIONS(376),
    [anon_sym_REPEAT] = ACTIONS(376),
    [anon_sym_Repeat] = ACTIONS(376),
    [anon_sym_exit] = ACTIONS(376),
    [anon_sym_EXIT] = ACTIONS(376),
    [anon_sym_Exit] = ACTIONS(376),
    [anon_sym_continue] = ACTIONS(376),
    [anon_sym_CONTINUE] = ACTIONS(376),
    [anon_sym_Continue] = ACTIONS(376),
    [anon_sym_break] = ACTIONS(376),
    [anon_sym_BREAK] = ACTIONS(376),
    [anon_sym_Break] = ACTIONS(376),
    [anon_sym_with] = ACTIONS(376),
    [anon_sym_WITH] = ACTIONS(376),
    [anon_sym_With] = ACTIONS(376),
    [sym_asserterror_keyword] = ACTIONS(374),
    [anon_sym_in] = ACTIONS(376),
    [anon_sym_IN] = ACTIONS(376),
    [anon_sym_In] = ACTIONS(376),
    [sym_page_keyword] = ACTIONS(376),
    [anon_sym_codeunit] = ACTIONS(376),
    [anon_sym_CODEUNIT] = ACTIONS(376),
    [anon_sym_Codeunit] = ACTIONS(376),
    [anon_sym_CodeUnit] = ACTIONS(376),
    [anon_sym_COdeunit] = ACTIONS(376),
    [anon_sym_codeUnit] = ACTIONS(376),
    [sym_report_keyword] = ACTIONS(376),
    [sym_query_keyword] = ACTIONS(376),
    [anon_sym_xmlport] = ACTIONS(376),
    [anon_sym_XMLPORT] = ACTIONS(376),
    [anon_sym_Xmlport] = ACTIONS(376),
    [anon_sym_XMLport] = ACTIONS(376),
    [anon_sym_XMLPort] = ACTIONS(376),
    [anon_sym_XmlPort] = ACTIONS(376),
    [anon_sym_enum] = ACTIONS(376),
    [anon_sym_ENUM] = ACTIONS(376),
    [anon_sym_Enum] = ACTIONS(376),
    [anon_sym_eNUM] = ACTIONS(376),
    [anon_sym_eNum] = ACTIONS(376),
    [anon_sym_ENum] = ACTIONS(376),
    [sym_quoted_identifier] = ACTIONS(374),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(374),
    [sym_integer] = ACTIONS(376),
    [sym_continue_as_identifier] = ACTIONS(374),
    [sym_preproc_open] = ACTIONS(374),
    [sym_end_keyword] = ACTIONS(374),
  },
  [STATE(1188)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1160),
    [sym_identifier] = ACTIONS(2354),
    [anon_sym_SEMI] = ACTIONS(2356),
    [anon_sym_DOT] = ACTIONS(2354),
    [anon_sym_EQ] = ACTIONS(2356),
    [anon_sym_COMMA] = ACTIONS(2791),
    [anon_sym_DASH] = ACTIONS(2354),
    [aux_sym_boolean_token1] = ACTIONS(2354),
    [aux_sym_boolean_token2] = ACTIONS(2354),
    [sym_decimal] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(2356),
    [anon_sym_DOT_DOT] = ACTIONS(2356),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2354),
    [anon_sym_STAR] = ACTIONS(2354),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [aux_sym_record_type_token1] = ACTIONS(2354),
    [aux_sym_basic_type_token21] = ACTIONS(2354),
    [aux_sym_basic_type_token22] = ACTIONS(2354),
    [aux_sym_basic_type_token48] = ACTIONS(2354),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2354),
    [anon_sym_POUNDif] = ACTIONS(2356),
    [anon_sym_POUNDIF] = ACTIONS(2356),
    [anon_sym_POUNDIf] = ACTIONS(2356),
    [anon_sym_not] = ACTIONS(2354),
    [anon_sym_NOT] = ACTIONS(2354),
    [anon_sym_Not] = ACTIONS(2354),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2356),
    [aux_sym__expression_token1] = ACTIONS(2356),
    [aux_sym__expression_token2] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2354),
    [anon_sym_SLASH] = ACTIONS(2354),
    [anon_sym_div] = ACTIONS(2354),
    [anon_sym_DIV] = ACTIONS(2354),
    [anon_sym_Div] = ACTIONS(2354),
    [anon_sym_mod] = ACTIONS(2354),
    [anon_sym_MOD] = ACTIONS(2354),
    [anon_sym_Mod] = ACTIONS(2354),
    [anon_sym_PLUS] = ACTIONS(2354),
    [anon_sym_GT_EQ] = ACTIONS(2356),
    [anon_sym_LT_EQ] = ACTIONS(2356),
    [anon_sym_GT] = ACTIONS(2354),
    [anon_sym_LT] = ACTIONS(2354),
    [anon_sym_LT_GT] = ACTIONS(2356),
    [anon_sym_and] = ACTIONS(2354),
    [anon_sym_AND] = ACTIONS(2354),
    [anon_sym_And] = ACTIONS(2354),
    [anon_sym_or] = ACTIONS(2354),
    [anon_sym_OR] = ACTIONS(2354),
    [anon_sym_Or] = ACTIONS(2354),
    [anon_sym_xor] = ACTIONS(2354),
    [anon_sym_XOR] = ACTIONS(2354),
    [anon_sym_Xor] = ACTIONS(2354),
    [anon_sym_QMARK] = ACTIONS(2356),
    [sym_datetime_literal] = ACTIONS(2356),
    [sym_date_literal] = ACTIONS(2354),
    [sym_time_literal] = ACTIONS(2354),
    [sym_biginteger_literal] = ACTIONS(2356),
    [anon_sym_if] = ACTIONS(2354),
    [anon_sym_IF] = ACTIONS(2354),
    [anon_sym_If] = ACTIONS(2354),
    [anon_sym_else] = ACTIONS(2354),
    [anon_sym_ELSE] = ACTIONS(2354),
    [anon_sym_Else] = ACTIONS(2354),
    [anon_sym_case] = ACTIONS(2354),
    [anon_sym_CASE] = ACTIONS(2354),
    [anon_sym_Case] = ACTIONS(2354),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_FOR] = ACTIONS(2354),
    [anon_sym_For] = ACTIONS(2354),
    [anon_sym_foreach] = ACTIONS(2354),
    [anon_sym_FOREACH] = ACTIONS(2354),
    [anon_sym_Foreach] = ACTIONS(2354),
    [anon_sym_while] = ACTIONS(2354),
    [anon_sym_WHILE] = ACTIONS(2354),
    [anon_sym_While] = ACTIONS(2354),
    [anon_sym_repeat] = ACTIONS(2354),
    [anon_sym_REPEAT] = ACTIONS(2354),
    [anon_sym_Repeat] = ACTIONS(2354),
    [anon_sym_exit] = ACTIONS(2354),
    [anon_sym_EXIT] = ACTIONS(2354),
    [anon_sym_Exit] = ACTIONS(2354),
    [anon_sym_continue] = ACTIONS(2354),
    [anon_sym_CONTINUE] = ACTIONS(2354),
    [anon_sym_Continue] = ACTIONS(2354),
    [anon_sym_break] = ACTIONS(2354),
    [anon_sym_BREAK] = ACTIONS(2354),
    [anon_sym_Break] = ACTIONS(2354),
    [anon_sym_with] = ACTIONS(2354),
    [anon_sym_WITH] = ACTIONS(2354),
    [anon_sym_With] = ACTIONS(2354),
    [sym_asserterror_keyword] = ACTIONS(2356),
    [anon_sym_in] = ACTIONS(2354),
    [anon_sym_IN] = ACTIONS(2354),
    [anon_sym_In] = ACTIONS(2354),
    [sym_page_keyword] = ACTIONS(2354),
    [anon_sym_codeunit] = ACTIONS(2354),
    [anon_sym_CODEUNIT] = ACTIONS(2354),
    [anon_sym_Codeunit] = ACTIONS(2354),
    [anon_sym_CodeUnit] = ACTIONS(2354),
    [anon_sym_COdeunit] = ACTIONS(2354),
    [anon_sym_codeUnit] = ACTIONS(2354),
    [sym_report_keyword] = ACTIONS(2354),
    [sym_query_keyword] = ACTIONS(2354),
    [anon_sym_xmlport] = ACTIONS(2354),
    [anon_sym_XMLPORT] = ACTIONS(2354),
    [anon_sym_Xmlport] = ACTIONS(2354),
    [anon_sym_XMLport] = ACTIONS(2354),
    [anon_sym_XMLPort] = ACTIONS(2354),
    [anon_sym_XmlPort] = ACTIONS(2354),
    [anon_sym_enum] = ACTIONS(2354),
    [anon_sym_ENUM] = ACTIONS(2354),
    [anon_sym_Enum] = ACTIONS(2354),
    [anon_sym_eNUM] = ACTIONS(2354),
    [anon_sym_eNum] = ACTIONS(2354),
    [anon_sym_ENum] = ACTIONS(2354),
    [sym_quoted_identifier] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2356),
    [sym_integer] = ACTIONS(2354),
    [sym_continue_as_identifier] = ACTIONS(2356),
    [sym_preproc_open] = ACTIONS(2356),
    [sym_end_keyword] = ACTIONS(2356),
  },
  [STATE(1189)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2743),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2767),
    [anon_sym_AND] = ACTIONS(2769),
    [anon_sym_And] = ACTIONS(2771),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_end_keyword] = ACTIONS(2272),
  },
  [STATE(1190)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2382),
    [anon_sym_SEMI] = ACTIONS(2385),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2743),
    [aux_sym_boolean_token1] = ACTIONS(2382),
    [aux_sym_boolean_token2] = ACTIONS(2382),
    [sym_decimal] = ACTIONS(2382),
    [anon_sym_LPAREN] = ACTIONS(2385),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2382),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2382),
    [aux_sym_basic_type_token21] = ACTIONS(2382),
    [aux_sym_basic_type_token22] = ACTIONS(2382),
    [aux_sym_basic_type_token48] = ACTIONS(2382),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2382),
    [anon_sym_POUNDif] = ACTIONS(2385),
    [anon_sym_POUNDIF] = ACTIONS(2385),
    [anon_sym_POUNDIf] = ACTIONS(2385),
    [anon_sym_not] = ACTIONS(2382),
    [anon_sym_NOT] = ACTIONS(2382),
    [anon_sym_Not] = ACTIONS(2382),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2787),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2382),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2767),
    [anon_sym_AND] = ACTIONS(2769),
    [anon_sym_And] = ACTIONS(2771),
    [anon_sym_or] = ACTIONS(2773),
    [anon_sym_OR] = ACTIONS(2775),
    [anon_sym_Or] = ACTIONS(2777),
    [anon_sym_xor] = ACTIONS(2779),
    [anon_sym_XOR] = ACTIONS(2781),
    [anon_sym_Xor] = ACTIONS(2783),
    [anon_sym_QMARK] = ACTIONS(2785),
    [sym_datetime_literal] = ACTIONS(2385),
    [sym_date_literal] = ACTIONS(2382),
    [sym_time_literal] = ACTIONS(2382),
    [sym_biginteger_literal] = ACTIONS(2385),
    [anon_sym_if] = ACTIONS(2382),
    [anon_sym_IF] = ACTIONS(2382),
    [anon_sym_If] = ACTIONS(2382),
    [anon_sym_else] = ACTIONS(2382),
    [anon_sym_ELSE] = ACTIONS(2382),
    [anon_sym_Else] = ACTIONS(2382),
    [anon_sym_case] = ACTIONS(2382),
    [anon_sym_CASE] = ACTIONS(2382),
    [anon_sym_Case] = ACTIONS(2382),
    [anon_sym_for] = ACTIONS(2382),
    [anon_sym_FOR] = ACTIONS(2382),
    [anon_sym_For] = ACTIONS(2382),
    [anon_sym_foreach] = ACTIONS(2382),
    [anon_sym_FOREACH] = ACTIONS(2382),
    [anon_sym_Foreach] = ACTIONS(2382),
    [anon_sym_while] = ACTIONS(2382),
    [anon_sym_WHILE] = ACTIONS(2382),
    [anon_sym_While] = ACTIONS(2382),
    [anon_sym_repeat] = ACTIONS(2382),
    [anon_sym_REPEAT] = ACTIONS(2382),
    [anon_sym_Repeat] = ACTIONS(2382),
    [anon_sym_exit] = ACTIONS(2382),
    [anon_sym_EXIT] = ACTIONS(2382),
    [anon_sym_Exit] = ACTIONS(2382),
    [anon_sym_continue] = ACTIONS(2382),
    [anon_sym_CONTINUE] = ACTIONS(2382),
    [anon_sym_Continue] = ACTIONS(2382),
    [anon_sym_break] = ACTIONS(2382),
    [anon_sym_BREAK] = ACTIONS(2382),
    [anon_sym_Break] = ACTIONS(2382),
    [anon_sym_with] = ACTIONS(2382),
    [anon_sym_WITH] = ACTIONS(2382),
    [anon_sym_With] = ACTIONS(2382),
    [sym_asserterror_keyword] = ACTIONS(2385),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2382),
    [anon_sym_codeunit] = ACTIONS(2382),
    [anon_sym_CODEUNIT] = ACTIONS(2382),
    [anon_sym_Codeunit] = ACTIONS(2382),
    [anon_sym_CodeUnit] = ACTIONS(2382),
    [anon_sym_COdeunit] = ACTIONS(2382),
    [anon_sym_codeUnit] = ACTIONS(2382),
    [sym_report_keyword] = ACTIONS(2382),
    [sym_query_keyword] = ACTIONS(2382),
    [anon_sym_xmlport] = ACTIONS(2382),
    [anon_sym_XMLPORT] = ACTIONS(2382),
    [anon_sym_Xmlport] = ACTIONS(2382),
    [anon_sym_XMLport] = ACTIONS(2382),
    [anon_sym_XMLPort] = ACTIONS(2382),
    [anon_sym_XmlPort] = ACTIONS(2382),
    [anon_sym_enum] = ACTIONS(2382),
    [anon_sym_ENUM] = ACTIONS(2382),
    [anon_sym_Enum] = ACTIONS(2382),
    [anon_sym_eNUM] = ACTIONS(2382),
    [anon_sym_eNum] = ACTIONS(2382),
    [anon_sym_ENum] = ACTIONS(2382),
    [sym_quoted_identifier] = ACTIONS(2385),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2385),
    [sym_integer] = ACTIONS(2382),
    [sym_continue_as_identifier] = ACTIONS(2385),
    [sym_preproc_open] = ACTIONS(2385),
    [sym_end_keyword] = ACTIONS(2385),
  },
  [STATE(1191)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2743),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2767),
    [anon_sym_AND] = ACTIONS(2769),
    [anon_sym_And] = ACTIONS(2771),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_end_keyword] = ACTIONS(2272),
  },
  [STATE(1192)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2743),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2767),
    [anon_sym_AND] = ACTIONS(2769),
    [anon_sym_And] = ACTIONS(2771),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_end_keyword] = ACTIONS(2272),
  },
  [STATE(1193)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1162),
    [sym_identifier] = ACTIONS(2346),
    [anon_sym_SEMI] = ACTIONS(2348),
    [anon_sym_DOT] = ACTIONS(2795),
    [anon_sym_EQ] = ACTIONS(2348),
    [anon_sym_DASH] = ACTIONS(2346),
    [aux_sym_boolean_token1] = ACTIONS(2346),
    [aux_sym_boolean_token2] = ACTIONS(2346),
    [sym_decimal] = ACTIONS(2346),
    [anon_sym_LPAREN] = ACTIONS(2348),
    [anon_sym_DOT_DOT] = ACTIONS(2348),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2346),
    [anon_sym_STAR] = ACTIONS(2346),
    [anon_sym_LBRACK] = ACTIONS(2348),
    [aux_sym_record_type_token1] = ACTIONS(2346),
    [aux_sym_basic_type_token21] = ACTIONS(2346),
    [aux_sym_basic_type_token22] = ACTIONS(2346),
    [aux_sym_basic_type_token48] = ACTIONS(2346),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2346),
    [anon_sym_POUNDif] = ACTIONS(2348),
    [anon_sym_POUNDIF] = ACTIONS(2348),
    [anon_sym_POUNDIf] = ACTIONS(2348),
    [anon_sym_not] = ACTIONS(2346),
    [anon_sym_NOT] = ACTIONS(2346),
    [anon_sym_Not] = ACTIONS(2346),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2348),
    [aux_sym__expression_token1] = ACTIONS(2348),
    [aux_sym__expression_token2] = ACTIONS(2346),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2346),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2346),
    [anon_sym_SLASH] = ACTIONS(2346),
    [anon_sym_div] = ACTIONS(2346),
    [anon_sym_DIV] = ACTIONS(2346),
    [anon_sym_Div] = ACTIONS(2346),
    [anon_sym_mod] = ACTIONS(2346),
    [anon_sym_MOD] = ACTIONS(2346),
    [anon_sym_Mod] = ACTIONS(2346),
    [anon_sym_PLUS] = ACTIONS(2346),
    [anon_sym_GT_EQ] = ACTIONS(2348),
    [anon_sym_LT_EQ] = ACTIONS(2348),
    [anon_sym_GT] = ACTIONS(2346),
    [anon_sym_LT] = ACTIONS(2346),
    [anon_sym_LT_GT] = ACTIONS(2348),
    [anon_sym_and] = ACTIONS(2346),
    [anon_sym_AND] = ACTIONS(2346),
    [anon_sym_And] = ACTIONS(2346),
    [anon_sym_or] = ACTIONS(2346),
    [anon_sym_OR] = ACTIONS(2346),
    [anon_sym_Or] = ACTIONS(2346),
    [anon_sym_xor] = ACTIONS(2346),
    [anon_sym_XOR] = ACTIONS(2346),
    [anon_sym_Xor] = ACTIONS(2346),
    [anon_sym_QMARK] = ACTIONS(2348),
    [sym_datetime_literal] = ACTIONS(2348),
    [sym_date_literal] = ACTIONS(2346),
    [sym_time_literal] = ACTIONS(2346),
    [sym_biginteger_literal] = ACTIONS(2348),
    [anon_sym_if] = ACTIONS(2346),
    [anon_sym_IF] = ACTIONS(2346),
    [anon_sym_If] = ACTIONS(2346),
    [anon_sym_else] = ACTIONS(2346),
    [anon_sym_ELSE] = ACTIONS(2346),
    [anon_sym_Else] = ACTIONS(2346),
    [anon_sym_case] = ACTIONS(2346),
    [anon_sym_CASE] = ACTIONS(2346),
    [anon_sym_Case] = ACTIONS(2346),
    [anon_sym_for] = ACTIONS(2346),
    [anon_sym_FOR] = ACTIONS(2346),
    [anon_sym_For] = ACTIONS(2346),
    [anon_sym_foreach] = ACTIONS(2346),
    [anon_sym_FOREACH] = ACTIONS(2346),
    [anon_sym_Foreach] = ACTIONS(2346),
    [anon_sym_while] = ACTIONS(2346),
    [anon_sym_WHILE] = ACTIONS(2346),
    [anon_sym_While] = ACTIONS(2346),
    [anon_sym_repeat] = ACTIONS(2346),
    [anon_sym_REPEAT] = ACTIONS(2346),
    [anon_sym_Repeat] = ACTIONS(2346),
    [anon_sym_exit] = ACTIONS(2346),
    [anon_sym_EXIT] = ACTIONS(2346),
    [anon_sym_Exit] = ACTIONS(2346),
    [anon_sym_continue] = ACTIONS(2346),
    [anon_sym_CONTINUE] = ACTIONS(2346),
    [anon_sym_Continue] = ACTIONS(2346),
    [anon_sym_break] = ACTIONS(2346),
    [anon_sym_BREAK] = ACTIONS(2346),
    [anon_sym_Break] = ACTIONS(2346),
    [anon_sym_with] = ACTIONS(2346),
    [anon_sym_WITH] = ACTIONS(2346),
    [anon_sym_With] = ACTIONS(2346),
    [sym_asserterror_keyword] = ACTIONS(2348),
    [anon_sym_in] = ACTIONS(2346),
    [anon_sym_IN] = ACTIONS(2346),
    [anon_sym_In] = ACTIONS(2346),
    [sym_page_keyword] = ACTIONS(2346),
    [anon_sym_codeunit] = ACTIONS(2346),
    [anon_sym_CODEUNIT] = ACTIONS(2346),
    [anon_sym_Codeunit] = ACTIONS(2346),
    [anon_sym_CodeUnit] = ACTIONS(2346),
    [anon_sym_COdeunit] = ACTIONS(2346),
    [anon_sym_codeUnit] = ACTIONS(2346),
    [sym_report_keyword] = ACTIONS(2346),
    [sym_query_keyword] = ACTIONS(2346),
    [anon_sym_xmlport] = ACTIONS(2346),
    [anon_sym_XMLPORT] = ACTIONS(2346),
    [anon_sym_Xmlport] = ACTIONS(2346),
    [anon_sym_XMLport] = ACTIONS(2346),
    [anon_sym_XMLPort] = ACTIONS(2346),
    [anon_sym_XmlPort] = ACTIONS(2346),
    [anon_sym_enum] = ACTIONS(2346),
    [anon_sym_ENUM] = ACTIONS(2346),
    [anon_sym_Enum] = ACTIONS(2346),
    [anon_sym_eNUM] = ACTIONS(2346),
    [anon_sym_eNum] = ACTIONS(2346),
    [anon_sym_ENum] = ACTIONS(2346),
    [sym_temporary_keyword] = ACTIONS(2346),
    [sym_quoted_identifier] = ACTIONS(2348),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2348),
    [sym_integer] = ACTIONS(2346),
    [sym_continue_as_identifier] = ACTIONS(2348),
    [sym_preproc_open] = ACTIONS(2348),
    [sym_end_keyword] = ACTIONS(2348),
  },
  [STATE(1194)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2743),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2767),
    [anon_sym_AND] = ACTIONS(2769),
    [anon_sym_And] = ACTIONS(2771),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2270),
    [anon_sym_IF] = ACTIONS(2270),
    [anon_sym_If] = ACTIONS(2270),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_case] = ACTIONS(2270),
    [anon_sym_CASE] = ACTIONS(2270),
    [anon_sym_Case] = ACTIONS(2270),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_FOR] = ACTIONS(2270),
    [anon_sym_For] = ACTIONS(2270),
    [anon_sym_foreach] = ACTIONS(2270),
    [anon_sym_FOREACH] = ACTIONS(2270),
    [anon_sym_Foreach] = ACTIONS(2270),
    [anon_sym_while] = ACTIONS(2270),
    [anon_sym_WHILE] = ACTIONS(2270),
    [anon_sym_While] = ACTIONS(2270),
    [anon_sym_repeat] = ACTIONS(2270),
    [anon_sym_REPEAT] = ACTIONS(2270),
    [anon_sym_Repeat] = ACTIONS(2270),
    [anon_sym_exit] = ACTIONS(2270),
    [anon_sym_EXIT] = ACTIONS(2270),
    [anon_sym_Exit] = ACTIONS(2270),
    [anon_sym_continue] = ACTIONS(2270),
    [anon_sym_CONTINUE] = ACTIONS(2270),
    [anon_sym_Continue] = ACTIONS(2270),
    [anon_sym_break] = ACTIONS(2270),
    [anon_sym_BREAK] = ACTIONS(2270),
    [anon_sym_Break] = ACTIONS(2270),
    [anon_sym_with] = ACTIONS(2270),
    [anon_sym_WITH] = ACTIONS(2270),
    [anon_sym_With] = ACTIONS(2270),
    [sym_asserterror_keyword] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_end_keyword] = ACTIONS(2272),
  },
  [STATE(1195)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2364),
    [anon_sym_SEMI] = ACTIONS(2366),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2366),
    [anon_sym_DASH] = ACTIONS(2743),
    [aux_sym_boolean_token1] = ACTIONS(2364),
    [aux_sym_boolean_token2] = ACTIONS(2364),
    [sym_decimal] = ACTIONS(2364),
    [anon_sym_LPAREN] = ACTIONS(2366),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2364),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2364),
    [aux_sym_basic_type_token21] = ACTIONS(2364),
    [aux_sym_basic_type_token22] = ACTIONS(2364),
    [aux_sym_basic_type_token48] = ACTIONS(2364),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2364),
    [anon_sym_POUNDif] = ACTIONS(2366),
    [anon_sym_POUNDIF] = ACTIONS(2366),
    [anon_sym_POUNDIf] = ACTIONS(2366),
    [anon_sym_not] = ACTIONS(2364),
    [anon_sym_NOT] = ACTIONS(2364),
    [anon_sym_Not] = ACTIONS(2364),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2366),
    [aux_sym__expression_token1] = ACTIONS(2747),
    [aux_sym__expression_token2] = ACTIONS(2749),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2364),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2364),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_GT_EQ] = ACTIONS(2366),
    [anon_sym_LT_EQ] = ACTIONS(2366),
    [anon_sym_GT] = ACTIONS(2364),
    [anon_sym_LT] = ACTIONS(2364),
    [anon_sym_LT_GT] = ACTIONS(2366),
    [anon_sym_and] = ACTIONS(2364),
    [anon_sym_AND] = ACTIONS(2364),
    [anon_sym_And] = ACTIONS(2364),
    [anon_sym_or] = ACTIONS(2364),
    [anon_sym_OR] = ACTIONS(2364),
    [anon_sym_Or] = ACTIONS(2364),
    [anon_sym_xor] = ACTIONS(2364),
    [anon_sym_XOR] = ACTIONS(2364),
    [anon_sym_Xor] = ACTIONS(2364),
    [anon_sym_QMARK] = ACTIONS(2366),
    [sym_datetime_literal] = ACTIONS(2366),
    [sym_date_literal] = ACTIONS(2364),
    [sym_time_literal] = ACTIONS(2364),
    [sym_biginteger_literal] = ACTIONS(2366),
    [anon_sym_if] = ACTIONS(2364),
    [anon_sym_IF] = ACTIONS(2364),
    [anon_sym_If] = ACTIONS(2364),
    [anon_sym_else] = ACTIONS(2364),
    [anon_sym_ELSE] = ACTIONS(2364),
    [anon_sym_Else] = ACTIONS(2364),
    [anon_sym_case] = ACTIONS(2364),
    [anon_sym_CASE] = ACTIONS(2364),
    [anon_sym_Case] = ACTIONS(2364),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_FOR] = ACTIONS(2364),
    [anon_sym_For] = ACTIONS(2364),
    [anon_sym_foreach] = ACTIONS(2364),
    [anon_sym_FOREACH] = ACTIONS(2364),
    [anon_sym_Foreach] = ACTIONS(2364),
    [anon_sym_while] = ACTIONS(2364),
    [anon_sym_WHILE] = ACTIONS(2364),
    [anon_sym_While] = ACTIONS(2364),
    [anon_sym_repeat] = ACTIONS(2364),
    [anon_sym_REPEAT] = ACTIONS(2364),
    [anon_sym_Repeat] = ACTIONS(2364),
    [anon_sym_exit] = ACTIONS(2364),
    [anon_sym_EXIT] = ACTIONS(2364),
    [anon_sym_Exit] = ACTIONS(2364),
    [anon_sym_continue] = ACTIONS(2364),
    [anon_sym_CONTINUE] = ACTIONS(2364),
    [anon_sym_Continue] = ACTIONS(2364),
    [anon_sym_break] = ACTIONS(2364),
    [anon_sym_BREAK] = ACTIONS(2364),
    [anon_sym_Break] = ACTIONS(2364),
    [anon_sym_with] = ACTIONS(2364),
    [anon_sym_WITH] = ACTIONS(2364),
    [anon_sym_With] = ACTIONS(2364),
    [sym_asserterror_keyword] = ACTIONS(2366),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2364),
    [anon_sym_codeunit] = ACTIONS(2364),
    [anon_sym_CODEUNIT] = ACTIONS(2364),
    [anon_sym_Codeunit] = ACTIONS(2364),
    [anon_sym_CodeUnit] = ACTIONS(2364),
    [anon_sym_COdeunit] = ACTIONS(2364),
    [anon_sym_codeUnit] = ACTIONS(2364),
    [sym_report_keyword] = ACTIONS(2364),
    [sym_query_keyword] = ACTIONS(2364),
    [anon_sym_xmlport] = ACTIONS(2364),
    [anon_sym_XMLPORT] = ACTIONS(2364),
    [anon_sym_Xmlport] = ACTIONS(2364),
    [anon_sym_XMLport] = ACTIONS(2364),
    [anon_sym_XMLPort] = ACTIONS(2364),
    [anon_sym_XmlPort] = ACTIONS(2364),
    [anon_sym_enum] = ACTIONS(2364),
    [anon_sym_ENUM] = ACTIONS(2364),
    [anon_sym_Enum] = ACTIONS(2364),
    [anon_sym_eNUM] = ACTIONS(2364),
    [anon_sym_eNum] = ACTIONS(2364),
    [anon_sym_ENum] = ACTIONS(2364),
    [sym_quoted_identifier] = ACTIONS(2366),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2366),
    [sym_integer] = ACTIONS(2364),
    [sym_continue_as_identifier] = ACTIONS(2366),
    [sym_preproc_open] = ACTIONS(2366),
    [sym_end_keyword] = ACTIONS(2366),
  },
  [STATE(1196)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1163),
    [sym_identifier] = ACTIONS(2354),
    [anon_sym_SEMI] = ACTIONS(2356),
    [anon_sym_DOT] = ACTIONS(2354),
    [anon_sym_EQ] = ACTIONS(2356),
    [anon_sym_COMMA] = ACTIONS(2791),
    [anon_sym_DASH] = ACTIONS(2354),
    [aux_sym_boolean_token1] = ACTIONS(2354),
    [aux_sym_boolean_token2] = ACTIONS(2354),
    [sym_decimal] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(2356),
    [anon_sym_DOT_DOT] = ACTIONS(2356),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2354),
    [anon_sym_STAR] = ACTIONS(2354),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [aux_sym_record_type_token1] = ACTIONS(2354),
    [aux_sym_basic_type_token21] = ACTIONS(2354),
    [aux_sym_basic_type_token22] = ACTIONS(2354),
    [aux_sym_basic_type_token48] = ACTIONS(2354),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2354),
    [anon_sym_POUNDif] = ACTIONS(2356),
    [anon_sym_POUNDIF] = ACTIONS(2356),
    [anon_sym_POUNDIf] = ACTIONS(2356),
    [anon_sym_not] = ACTIONS(2354),
    [anon_sym_NOT] = ACTIONS(2354),
    [anon_sym_Not] = ACTIONS(2354),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2356),
    [aux_sym__expression_token1] = ACTIONS(2356),
    [aux_sym__expression_token2] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2354),
    [anon_sym_SLASH] = ACTIONS(2354),
    [anon_sym_div] = ACTIONS(2354),
    [anon_sym_DIV] = ACTIONS(2354),
    [anon_sym_Div] = ACTIONS(2354),
    [anon_sym_mod] = ACTIONS(2354),
    [anon_sym_MOD] = ACTIONS(2354),
    [anon_sym_Mod] = ACTIONS(2354),
    [anon_sym_PLUS] = ACTIONS(2354),
    [anon_sym_GT_EQ] = ACTIONS(2356),
    [anon_sym_LT_EQ] = ACTIONS(2356),
    [anon_sym_GT] = ACTIONS(2354),
    [anon_sym_LT] = ACTIONS(2354),
    [anon_sym_LT_GT] = ACTIONS(2356),
    [anon_sym_and] = ACTIONS(2354),
    [anon_sym_AND] = ACTIONS(2354),
    [anon_sym_And] = ACTIONS(2354),
    [anon_sym_or] = ACTIONS(2354),
    [anon_sym_OR] = ACTIONS(2354),
    [anon_sym_Or] = ACTIONS(2354),
    [anon_sym_xor] = ACTIONS(2354),
    [anon_sym_XOR] = ACTIONS(2354),
    [anon_sym_Xor] = ACTIONS(2354),
    [anon_sym_QMARK] = ACTIONS(2356),
    [sym_datetime_literal] = ACTIONS(2356),
    [sym_date_literal] = ACTIONS(2354),
    [sym_time_literal] = ACTIONS(2354),
    [sym_biginteger_literal] = ACTIONS(2356),
    [anon_sym_if] = ACTIONS(2354),
    [anon_sym_IF] = ACTIONS(2354),
    [anon_sym_If] = ACTIONS(2354),
    [anon_sym_else] = ACTIONS(2354),
    [anon_sym_ELSE] = ACTIONS(2354),
    [anon_sym_Else] = ACTIONS(2354),
    [anon_sym_case] = ACTIONS(2354),
    [anon_sym_CASE] = ACTIONS(2354),
    [anon_sym_Case] = ACTIONS(2354),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_FOR] = ACTIONS(2354),
    [anon_sym_For] = ACTIONS(2354),
    [anon_sym_foreach] = ACTIONS(2354),
    [anon_sym_FOREACH] = ACTIONS(2354),
    [anon_sym_Foreach] = ACTIONS(2354),
    [anon_sym_while] = ACTIONS(2354),
    [anon_sym_WHILE] = ACTIONS(2354),
    [anon_sym_While] = ACTIONS(2354),
    [anon_sym_repeat] = ACTIONS(2354),
    [anon_sym_REPEAT] = ACTIONS(2354),
    [anon_sym_Repeat] = ACTIONS(2354),
    [anon_sym_exit] = ACTIONS(2354),
    [anon_sym_EXIT] = ACTIONS(2354),
    [anon_sym_Exit] = ACTIONS(2354),
    [anon_sym_continue] = ACTIONS(2354),
    [anon_sym_CONTINUE] = ACTIONS(2354),
    [anon_sym_Continue] = ACTIONS(2354),
    [anon_sym_break] = ACTIONS(2354),
    [anon_sym_BREAK] = ACTIONS(2354),
    [anon_sym_Break] = ACTIONS(2354),
    [anon_sym_with] = ACTIONS(2354),
    [anon_sym_WITH] = ACTIONS(2354),
    [anon_sym_With] = ACTIONS(2354),
    [sym_asserterror_keyword] = ACTIONS(2356),
    [anon_sym_in] = ACTIONS(2354),
    [anon_sym_IN] = ACTIONS(2354),
    [anon_sym_In] = ACTIONS(2354),
    [sym_page_keyword] = ACTIONS(2354),
    [anon_sym_codeunit] = ACTIONS(2354),
    [anon_sym_CODEUNIT] = ACTIONS(2354),
    [anon_sym_Codeunit] = ACTIONS(2354),
    [anon_sym_CodeUnit] = ACTIONS(2354),
    [anon_sym_COdeunit] = ACTIONS(2354),
    [anon_sym_codeUnit] = ACTIONS(2354),
    [sym_report_keyword] = ACTIONS(2354),
    [sym_query_keyword] = ACTIONS(2354),
    [anon_sym_xmlport] = ACTIONS(2354),
    [anon_sym_XMLPORT] = ACTIONS(2354),
    [anon_sym_Xmlport] = ACTIONS(2354),
    [anon_sym_XMLport] = ACTIONS(2354),
    [anon_sym_XMLPort] = ACTIONS(2354),
    [anon_sym_XmlPort] = ACTIONS(2354),
    [anon_sym_enum] = ACTIONS(2354),
    [anon_sym_ENUM] = ACTIONS(2354),
    [anon_sym_Enum] = ACTIONS(2354),
    [anon_sym_eNUM] = ACTIONS(2354),
    [anon_sym_eNum] = ACTIONS(2354),
    [anon_sym_ENum] = ACTIONS(2354),
    [sym_quoted_identifier] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2356),
    [sym_integer] = ACTIONS(2354),
    [sym_continue_as_identifier] = ACTIONS(2356),
    [sym_preproc_open] = ACTIONS(2356),
    [sym_end_keyword] = ACTIONS(2356),
  },
  [STATE(1197)] = {
    [sym_identifier] = ACTIONS(2414),
    [anon_sym_SEMI] = ACTIONS(2416),
    [anon_sym_DOT] = ACTIONS(2414),
    [anon_sym_EQ] = ACTIONS(2416),
    [anon_sym_COMMA] = ACTIONS(2416),
    [anon_sym_DASH] = ACTIONS(2414),
    [aux_sym_boolean_token1] = ACTIONS(2414),
    [aux_sym_boolean_token2] = ACTIONS(2414),
    [sym_decimal] = ACTIONS(2414),
    [anon_sym_LPAREN] = ACTIONS(2416),
    [anon_sym_DOT_DOT] = ACTIONS(2416),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2414),
    [anon_sym_STAR] = ACTIONS(2414),
    [anon_sym_LBRACK] = ACTIONS(2416),
    [aux_sym_record_type_token1] = ACTIONS(2414),
    [aux_sym_basic_type_token21] = ACTIONS(2414),
    [aux_sym_basic_type_token22] = ACTIONS(2414),
    [aux_sym_basic_type_token48] = ACTIONS(2414),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2414),
    [anon_sym_COLON_COLON] = ACTIONS(2416),
    [anon_sym_POUNDif] = ACTIONS(2416),
    [anon_sym_POUNDIF] = ACTIONS(2416),
    [anon_sym_POUNDIf] = ACTIONS(2416),
    [anon_sym_not] = ACTIONS(2414),
    [anon_sym_NOT] = ACTIONS(2414),
    [anon_sym_Not] = ACTIONS(2414),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2416),
    [aux_sym__expression_token1] = ACTIONS(2416),
    [aux_sym__expression_token2] = ACTIONS(2414),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2414),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2414),
    [anon_sym_SLASH] = ACTIONS(2414),
    [anon_sym_div] = ACTIONS(2414),
    [anon_sym_DIV] = ACTIONS(2414),
    [anon_sym_Div] = ACTIONS(2414),
    [anon_sym_mod] = ACTIONS(2414),
    [anon_sym_MOD] = ACTIONS(2414),
    [anon_sym_Mod] = ACTIONS(2414),
    [anon_sym_PLUS] = ACTIONS(2414),
    [anon_sym_GT_EQ] = ACTIONS(2416),
    [anon_sym_LT_EQ] = ACTIONS(2416),
    [anon_sym_GT] = ACTIONS(2414),
    [anon_sym_LT] = ACTIONS(2414),
    [anon_sym_LT_GT] = ACTIONS(2416),
    [anon_sym_and] = ACTIONS(2414),
    [anon_sym_AND] = ACTIONS(2414),
    [anon_sym_And] = ACTIONS(2414),
    [anon_sym_or] = ACTIONS(2414),
    [anon_sym_OR] = ACTIONS(2414),
    [anon_sym_Or] = ACTIONS(2414),
    [anon_sym_xor] = ACTIONS(2414),
    [anon_sym_XOR] = ACTIONS(2414),
    [anon_sym_Xor] = ACTIONS(2414),
    [anon_sym_QMARK] = ACTIONS(2416),
    [sym_datetime_literal] = ACTIONS(2416),
    [sym_date_literal] = ACTIONS(2414),
    [sym_time_literal] = ACTIONS(2414),
    [sym_biginteger_literal] = ACTIONS(2416),
    [anon_sym_if] = ACTIONS(2414),
    [anon_sym_IF] = ACTIONS(2414),
    [anon_sym_If] = ACTIONS(2414),
    [anon_sym_else] = ACTIONS(2414),
    [anon_sym_ELSE] = ACTIONS(2414),
    [anon_sym_Else] = ACTIONS(2414),
    [anon_sym_case] = ACTIONS(2414),
    [anon_sym_CASE] = ACTIONS(2414),
    [anon_sym_Case] = ACTIONS(2414),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_FOR] = ACTIONS(2414),
    [anon_sym_For] = ACTIONS(2414),
    [anon_sym_foreach] = ACTIONS(2414),
    [anon_sym_FOREACH] = ACTIONS(2414),
    [anon_sym_Foreach] = ACTIONS(2414),
    [anon_sym_while] = ACTIONS(2414),
    [anon_sym_WHILE] = ACTIONS(2414),
    [anon_sym_While] = ACTIONS(2414),
    [anon_sym_repeat] = ACTIONS(2414),
    [anon_sym_REPEAT] = ACTIONS(2414),
    [anon_sym_Repeat] = ACTIONS(2414),
    [anon_sym_exit] = ACTIONS(2414),
    [anon_sym_EXIT] = ACTIONS(2414),
    [anon_sym_Exit] = ACTIONS(2414),
    [anon_sym_continue] = ACTIONS(2414),
    [anon_sym_CONTINUE] = ACTIONS(2414),
    [anon_sym_Continue] = ACTIONS(2414),
    [anon_sym_break] = ACTIONS(2414),
    [anon_sym_BREAK] = ACTIONS(2414),
    [anon_sym_Break] = ACTIONS(2414),
    [anon_sym_with] = ACTIONS(2414),
    [anon_sym_WITH] = ACTIONS(2414),
    [anon_sym_With] = ACTIONS(2414),
    [sym_asserterror_keyword] = ACTIONS(2416),
    [anon_sym_in] = ACTIONS(2414),
    [anon_sym_IN] = ACTIONS(2414),
    [anon_sym_In] = ACTIONS(2414),
    [sym_page_keyword] = ACTIONS(2414),
    [anon_sym_codeunit] = ACTIONS(2414),
    [anon_sym_CODEUNIT] = ACTIONS(2414),
    [anon_sym_Codeunit] = ACTIONS(2414),
    [anon_sym_CodeUnit] = ACTIONS(2414),
    [anon_sym_COdeunit] = ACTIONS(2414),
    [anon_sym_codeUnit] = ACTIONS(2414),
    [sym_report_keyword] = ACTIONS(2414),
    [sym_query_keyword] = ACTIONS(2414),
    [anon_sym_xmlport] = ACTIONS(2414),
    [anon_sym_XMLPORT] = ACTIONS(2414),
    [anon_sym_Xmlport] = ACTIONS(2414),
    [anon_sym_XMLport] = ACTIONS(2414),
    [anon_sym_XMLPort] = ACTIONS(2414),
    [anon_sym_XmlPort] = ACTIONS(2414),
    [anon_sym_enum] = ACTIONS(2414),
    [anon_sym_ENUM] = ACTIONS(2414),
    [anon_sym_Enum] = ACTIONS(2414),
    [anon_sym_eNUM] = ACTIONS(2414),
    [anon_sym_eNum] = ACTIONS(2414),
    [anon_sym_ENum] = ACTIONS(2414),
    [sym_quoted_identifier] = ACTIONS(2416),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2416),
    [sym_integer] = ACTIONS(2414),
    [sym_continue_as_identifier] = ACTIONS(2416),
    [sym_preproc_open] = ACTIONS(2416),
    [sym_end_keyword] = ACTIONS(2416),
  },
  [STATE(1198)] = {
    [sym_identifier] = ACTIONS(2418),
    [anon_sym_SEMI] = ACTIONS(2420),
    [anon_sym_DOT] = ACTIONS(2418),
    [anon_sym_EQ] = ACTIONS(2420),
    [anon_sym_COMMA] = ACTIONS(2420),
    [anon_sym_DASH] = ACTIONS(2418),
    [aux_sym_boolean_token1] = ACTIONS(2418),
    [aux_sym_boolean_token2] = ACTIONS(2418),
    [sym_decimal] = ACTIONS(2418),
    [anon_sym_LPAREN] = ACTIONS(2420),
    [anon_sym_DOT_DOT] = ACTIONS(2420),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2418),
    [anon_sym_STAR] = ACTIONS(2418),
    [anon_sym_LBRACK] = ACTIONS(2420),
    [aux_sym_record_type_token1] = ACTIONS(2418),
    [aux_sym_basic_type_token21] = ACTIONS(2418),
    [aux_sym_basic_type_token22] = ACTIONS(2418),
    [aux_sym_basic_type_token48] = ACTIONS(2418),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2418),
    [anon_sym_COLON_COLON] = ACTIONS(2420),
    [anon_sym_POUNDif] = ACTIONS(2420),
    [anon_sym_POUNDIF] = ACTIONS(2420),
    [anon_sym_POUNDIf] = ACTIONS(2420),
    [anon_sym_not] = ACTIONS(2418),
    [anon_sym_NOT] = ACTIONS(2418),
    [anon_sym_Not] = ACTIONS(2418),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2420),
    [aux_sym__expression_token1] = ACTIONS(2420),
    [aux_sym__expression_token2] = ACTIONS(2418),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2418),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2418),
    [anon_sym_SLASH] = ACTIONS(2418),
    [anon_sym_div] = ACTIONS(2418),
    [anon_sym_DIV] = ACTIONS(2418),
    [anon_sym_Div] = ACTIONS(2418),
    [anon_sym_mod] = ACTIONS(2418),
    [anon_sym_MOD] = ACTIONS(2418),
    [anon_sym_Mod] = ACTIONS(2418),
    [anon_sym_PLUS] = ACTIONS(2418),
    [anon_sym_GT_EQ] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(2420),
    [anon_sym_GT] = ACTIONS(2418),
    [anon_sym_LT] = ACTIONS(2418),
    [anon_sym_LT_GT] = ACTIONS(2420),
    [anon_sym_and] = ACTIONS(2418),
    [anon_sym_AND] = ACTIONS(2418),
    [anon_sym_And] = ACTIONS(2418),
    [anon_sym_or] = ACTIONS(2418),
    [anon_sym_OR] = ACTIONS(2418),
    [anon_sym_Or] = ACTIONS(2418),
    [anon_sym_xor] = ACTIONS(2418),
    [anon_sym_XOR] = ACTIONS(2418),
    [anon_sym_Xor] = ACTIONS(2418),
    [anon_sym_QMARK] = ACTIONS(2420),
    [sym_datetime_literal] = ACTIONS(2420),
    [sym_date_literal] = ACTIONS(2418),
    [sym_time_literal] = ACTIONS(2418),
    [sym_biginteger_literal] = ACTIONS(2420),
    [anon_sym_if] = ACTIONS(2418),
    [anon_sym_IF] = ACTIONS(2418),
    [anon_sym_If] = ACTIONS(2418),
    [anon_sym_else] = ACTIONS(2418),
    [anon_sym_ELSE] = ACTIONS(2418),
    [anon_sym_Else] = ACTIONS(2418),
    [anon_sym_case] = ACTIONS(2418),
    [anon_sym_CASE] = ACTIONS(2418),
    [anon_sym_Case] = ACTIONS(2418),
    [anon_sym_for] = ACTIONS(2418),
    [anon_sym_FOR] = ACTIONS(2418),
    [anon_sym_For] = ACTIONS(2418),
    [anon_sym_foreach] = ACTIONS(2418),
    [anon_sym_FOREACH] = ACTIONS(2418),
    [anon_sym_Foreach] = ACTIONS(2418),
    [anon_sym_while] = ACTIONS(2418),
    [anon_sym_WHILE] = ACTIONS(2418),
    [anon_sym_While] = ACTIONS(2418),
    [anon_sym_repeat] = ACTIONS(2418),
    [anon_sym_REPEAT] = ACTIONS(2418),
    [anon_sym_Repeat] = ACTIONS(2418),
    [anon_sym_exit] = ACTIONS(2418),
    [anon_sym_EXIT] = ACTIONS(2418),
    [anon_sym_Exit] = ACTIONS(2418),
    [anon_sym_continue] = ACTIONS(2418),
    [anon_sym_CONTINUE] = ACTIONS(2418),
    [anon_sym_Continue] = ACTIONS(2418),
    [anon_sym_break] = ACTIONS(2418),
    [anon_sym_BREAK] = ACTIONS(2418),
    [anon_sym_Break] = ACTIONS(2418),
    [anon_sym_with] = ACTIONS(2418),
    [anon_sym_WITH] = ACTIONS(2418),
    [anon_sym_With] = ACTIONS(2418),
    [sym_asserterror_keyword] = ACTIONS(2420),
    [anon_sym_in] = ACTIONS(2418),
    [anon_sym_IN] = ACTIONS(2418),
    [anon_sym_In] = ACTIONS(2418),
    [sym_page_keyword] = ACTIONS(2418),
    [anon_sym_codeunit] = ACTIONS(2418),
    [anon_sym_CODEUNIT] = ACTIONS(2418),
    [anon_sym_Codeunit] = ACTIONS(2418),
    [anon_sym_CodeUnit] = ACTIONS(2418),
    [anon_sym_COdeunit] = ACTIONS(2418),
    [anon_sym_codeUnit] = ACTIONS(2418),
    [sym_report_keyword] = ACTIONS(2418),
    [sym_query_keyword] = ACTIONS(2418),
    [anon_sym_xmlport] = ACTIONS(2418),
    [anon_sym_XMLPORT] = ACTIONS(2418),
    [anon_sym_Xmlport] = ACTIONS(2418),
    [anon_sym_XMLport] = ACTIONS(2418),
    [anon_sym_XMLPort] = ACTIONS(2418),
    [anon_sym_XmlPort] = ACTIONS(2418),
    [anon_sym_enum] = ACTIONS(2418),
    [anon_sym_ENUM] = ACTIONS(2418),
    [anon_sym_Enum] = ACTIONS(2418),
    [anon_sym_eNUM] = ACTIONS(2418),
    [anon_sym_eNum] = ACTIONS(2418),
    [anon_sym_ENum] = ACTIONS(2418),
    [sym_quoted_identifier] = ACTIONS(2420),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2420),
    [sym_integer] = ACTIONS(2418),
    [sym_continue_as_identifier] = ACTIONS(2420),
    [sym_preproc_open] = ACTIONS(2420),
    [sym_end_keyword] = ACTIONS(2420),
  },
  [STATE(1199)] = {
    [sym_identifier] = ACTIONS(2422),
    [anon_sym_SEMI] = ACTIONS(2424),
    [anon_sym_DOT] = ACTIONS(2422),
    [anon_sym_EQ] = ACTIONS(2424),
    [anon_sym_COMMA] = ACTIONS(2424),
    [anon_sym_DASH] = ACTIONS(2422),
    [aux_sym_boolean_token1] = ACTIONS(2422),
    [aux_sym_boolean_token2] = ACTIONS(2422),
    [sym_decimal] = ACTIONS(2422),
    [anon_sym_LPAREN] = ACTIONS(2424),
    [anon_sym_DOT_DOT] = ACTIONS(2424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2422),
    [anon_sym_STAR] = ACTIONS(2422),
    [anon_sym_LBRACK] = ACTIONS(2424),
    [aux_sym_record_type_token1] = ACTIONS(2422),
    [aux_sym_basic_type_token21] = ACTIONS(2422),
    [aux_sym_basic_type_token22] = ACTIONS(2422),
    [aux_sym_basic_type_token48] = ACTIONS(2422),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2422),
    [anon_sym_COLON_COLON] = ACTIONS(2424),
    [anon_sym_POUNDif] = ACTIONS(2424),
    [anon_sym_POUNDIF] = ACTIONS(2424),
    [anon_sym_POUNDIf] = ACTIONS(2424),
    [anon_sym_not] = ACTIONS(2422),
    [anon_sym_NOT] = ACTIONS(2422),
    [anon_sym_Not] = ACTIONS(2422),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2424),
    [aux_sym__expression_token1] = ACTIONS(2424),
    [aux_sym__expression_token2] = ACTIONS(2422),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2422),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2422),
    [anon_sym_SLASH] = ACTIONS(2422),
    [anon_sym_div] = ACTIONS(2422),
    [anon_sym_DIV] = ACTIONS(2422),
    [anon_sym_Div] = ACTIONS(2422),
    [anon_sym_mod] = ACTIONS(2422),
    [anon_sym_MOD] = ACTIONS(2422),
    [anon_sym_Mod] = ACTIONS(2422),
    [anon_sym_PLUS] = ACTIONS(2422),
    [anon_sym_GT_EQ] = ACTIONS(2424),
    [anon_sym_LT_EQ] = ACTIONS(2424),
    [anon_sym_GT] = ACTIONS(2422),
    [anon_sym_LT] = ACTIONS(2422),
    [anon_sym_LT_GT] = ACTIONS(2424),
    [anon_sym_and] = ACTIONS(2422),
    [anon_sym_AND] = ACTIONS(2422),
    [anon_sym_And] = ACTIONS(2422),
    [anon_sym_or] = ACTIONS(2422),
    [anon_sym_OR] = ACTIONS(2422),
    [anon_sym_Or] = ACTIONS(2422),
    [anon_sym_xor] = ACTIONS(2422),
    [anon_sym_XOR] = ACTIONS(2422),
    [anon_sym_Xor] = ACTIONS(2422),
    [anon_sym_QMARK] = ACTIONS(2424),
    [sym_datetime_literal] = ACTIONS(2424),
    [sym_date_literal] = ACTIONS(2422),
    [sym_time_literal] = ACTIONS(2422),
    [sym_biginteger_literal] = ACTIONS(2424),
    [anon_sym_if] = ACTIONS(2422),
    [anon_sym_IF] = ACTIONS(2422),
    [anon_sym_If] = ACTIONS(2422),
    [anon_sym_else] = ACTIONS(2422),
    [anon_sym_ELSE] = ACTIONS(2422),
    [anon_sym_Else] = ACTIONS(2422),
    [anon_sym_case] = ACTIONS(2422),
    [anon_sym_CASE] = ACTIONS(2422),
    [anon_sym_Case] = ACTIONS(2422),
    [anon_sym_for] = ACTIONS(2422),
    [anon_sym_FOR] = ACTIONS(2422),
    [anon_sym_For] = ACTIONS(2422),
    [anon_sym_foreach] = ACTIONS(2422),
    [anon_sym_FOREACH] = ACTIONS(2422),
    [anon_sym_Foreach] = ACTIONS(2422),
    [anon_sym_while] = ACTIONS(2422),
    [anon_sym_WHILE] = ACTIONS(2422),
    [anon_sym_While] = ACTIONS(2422),
    [anon_sym_repeat] = ACTIONS(2422),
    [anon_sym_REPEAT] = ACTIONS(2422),
    [anon_sym_Repeat] = ACTIONS(2422),
    [anon_sym_exit] = ACTIONS(2422),
    [anon_sym_EXIT] = ACTIONS(2422),
    [anon_sym_Exit] = ACTIONS(2422),
    [anon_sym_continue] = ACTIONS(2422),
    [anon_sym_CONTINUE] = ACTIONS(2422),
    [anon_sym_Continue] = ACTIONS(2422),
    [anon_sym_break] = ACTIONS(2422),
    [anon_sym_BREAK] = ACTIONS(2422),
    [anon_sym_Break] = ACTIONS(2422),
    [anon_sym_with] = ACTIONS(2422),
    [anon_sym_WITH] = ACTIONS(2422),
    [anon_sym_With] = ACTIONS(2422),
    [sym_asserterror_keyword] = ACTIONS(2424),
    [anon_sym_in] = ACTIONS(2422),
    [anon_sym_IN] = ACTIONS(2422),
    [anon_sym_In] = ACTIONS(2422),
    [sym_page_keyword] = ACTIONS(2422),
    [anon_sym_codeunit] = ACTIONS(2422),
    [anon_sym_CODEUNIT] = ACTIONS(2422),
    [anon_sym_Codeunit] = ACTIONS(2422),
    [anon_sym_CodeUnit] = ACTIONS(2422),
    [anon_sym_COdeunit] = ACTIONS(2422),
    [anon_sym_codeUnit] = ACTIONS(2422),
    [sym_report_keyword] = ACTIONS(2422),
    [sym_query_keyword] = ACTIONS(2422),
    [anon_sym_xmlport] = ACTIONS(2422),
    [anon_sym_XMLPORT] = ACTIONS(2422),
    [anon_sym_Xmlport] = ACTIONS(2422),
    [anon_sym_XMLport] = ACTIONS(2422),
    [anon_sym_XMLPort] = ACTIONS(2422),
    [anon_sym_XmlPort] = ACTIONS(2422),
    [anon_sym_enum] = ACTIONS(2422),
    [anon_sym_ENUM] = ACTIONS(2422),
    [anon_sym_Enum] = ACTIONS(2422),
    [anon_sym_eNUM] = ACTIONS(2422),
    [anon_sym_eNum] = ACTIONS(2422),
    [anon_sym_ENum] = ACTIONS(2422),
    [sym_quoted_identifier] = ACTIONS(2424),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2424),
    [sym_integer] = ACTIONS(2422),
    [sym_continue_as_identifier] = ACTIONS(2424),
    [sym_preproc_open] = ACTIONS(2424),
    [sym_end_keyword] = ACTIONS(2424),
  },
  [STATE(1200)] = {
    [sym_comparison_operator] = STATE(2956),
    [sym_in_keyword] = STATE(11251),
    [sym_identifier] = ACTIONS(2360),
    [anon_sym_SEMI] = ACTIONS(2362),
    [anon_sym_DOT] = ACTIONS(2729),
    [anon_sym_EQ] = ACTIONS(2362),
    [anon_sym_DASH] = ACTIONS(2360),
    [aux_sym_boolean_token1] = ACTIONS(2360),
    [aux_sym_boolean_token2] = ACTIONS(2360),
    [sym_decimal] = ACTIONS(2360),
    [anon_sym_LPAREN] = ACTIONS(2362),
    [anon_sym_DOT_DOT] = ACTIONS(2731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2360),
    [anon_sym_STAR] = ACTIONS(2745),
    [anon_sym_LBRACK] = ACTIONS(2733),
    [aux_sym_record_type_token1] = ACTIONS(2360),
    [aux_sym_basic_type_token21] = ACTIONS(2360),
    [aux_sym_basic_type_token22] = ACTIONS(2360),
    [aux_sym_basic_type_token48] = ACTIONS(2360),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2360),
    [anon_sym_POUNDif] = ACTIONS(2362),
    [anon_sym_POUNDIF] = ACTIONS(2362),
    [anon_sym_POUNDIf] = ACTIONS(2362),
    [anon_sym_not] = ACTIONS(2360),
    [anon_sym_NOT] = ACTIONS(2360),
    [anon_sym_Not] = ACTIONS(2360),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2362),
    [aux_sym__expression_token1] = ACTIONS(2362),
    [aux_sym__expression_token2] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2360),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_div] = ACTIONS(2753),
    [anon_sym_DIV] = ACTIONS(2755),
    [anon_sym_Div] = ACTIONS(2757),
    [anon_sym_mod] = ACTIONS(2759),
    [anon_sym_MOD] = ACTIONS(2761),
    [anon_sym_Mod] = ACTIONS(2763),
    [anon_sym_PLUS] = ACTIONS(2360),
    [anon_sym_GT_EQ] = ACTIONS(2362),
    [anon_sym_LT_EQ] = ACTIONS(2362),
    [anon_sym_GT] = ACTIONS(2360),
    [anon_sym_LT] = ACTIONS(2360),
    [anon_sym_LT_GT] = ACTIONS(2362),
    [anon_sym_and] = ACTIONS(2360),
    [anon_sym_AND] = ACTIONS(2360),
    [anon_sym_And] = ACTIONS(2360),
    [anon_sym_or] = ACTIONS(2360),
    [anon_sym_OR] = ACTIONS(2360),
    [anon_sym_Or] = ACTIONS(2360),
    [anon_sym_xor] = ACTIONS(2360),
    [anon_sym_XOR] = ACTIONS(2360),
    [anon_sym_Xor] = ACTIONS(2360),
    [anon_sym_QMARK] = ACTIONS(2362),
    [sym_datetime_literal] = ACTIONS(2362),
    [sym_date_literal] = ACTIONS(2360),
    [sym_time_literal] = ACTIONS(2360),
    [sym_biginteger_literal] = ACTIONS(2362),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_IF] = ACTIONS(2360),
    [anon_sym_If] = ACTIONS(2360),
    [anon_sym_else] = ACTIONS(2360),
    [anon_sym_ELSE] = ACTIONS(2360),
    [anon_sym_Else] = ACTIONS(2360),
    [anon_sym_case] = ACTIONS(2360),
    [anon_sym_CASE] = ACTIONS(2360),
    [anon_sym_Case] = ACTIONS(2360),
    [anon_sym_for] = ACTIONS(2360),
    [anon_sym_FOR] = ACTIONS(2360),
    [anon_sym_For] = ACTIONS(2360),
    [anon_sym_foreach] = ACTIONS(2360),
    [anon_sym_FOREACH] = ACTIONS(2360),
    [anon_sym_Foreach] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2360),
    [anon_sym_WHILE] = ACTIONS(2360),
    [anon_sym_While] = ACTIONS(2360),
    [anon_sym_repeat] = ACTIONS(2360),
    [anon_sym_REPEAT] = ACTIONS(2360),
    [anon_sym_Repeat] = ACTIONS(2360),
    [anon_sym_exit] = ACTIONS(2360),
    [anon_sym_EXIT] = ACTIONS(2360),
    [anon_sym_Exit] = ACTIONS(2360),
    [anon_sym_continue] = ACTIONS(2360),
    [anon_sym_CONTINUE] = ACTIONS(2360),
    [anon_sym_Continue] = ACTIONS(2360),
    [anon_sym_break] = ACTIONS(2360),
    [anon_sym_BREAK] = ACTIONS(2360),
    [anon_sym_Break] = ACTIONS(2360),
    [anon_sym_with] = ACTIONS(2360),
    [anon_sym_WITH] = ACTIONS(2360),
    [anon_sym_With] = ACTIONS(2360),
    [sym_asserterror_keyword] = ACTIONS(2362),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_IN] = ACTIONS(2360),
    [anon_sym_In] = ACTIONS(2360),
    [sym_page_keyword] = ACTIONS(2360),
    [anon_sym_codeunit] = ACTIONS(2360),
    [anon_sym_CODEUNIT] = ACTIONS(2360),
    [anon_sym_Codeunit] = ACTIONS(2360),
    [anon_sym_CodeUnit] = ACTIONS(2360),
    [anon_sym_COdeunit] = ACTIONS(2360),
    [anon_sym_codeUnit] = ACTIONS(2360),
    [sym_report_keyword] = ACTIONS(2360),
    [sym_query_keyword] = ACTIONS(2360),
    [anon_sym_xmlport] = ACTIONS(2360),
    [anon_sym_XMLPORT] = ACTIONS(2360),
    [anon_sym_Xmlport] = ACTIONS(2360),
    [anon_sym_XMLport] = ACTIONS(2360),
    [anon_sym_XMLPort] = ACTIONS(2360),
    [anon_sym_XmlPort] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_ENUM] = ACTIONS(2360),
    [anon_sym_Enum] = ACTIONS(2360),
    [anon_sym_eNUM] = ACTIONS(2360),
    [anon_sym_eNum] = ACTIONS(2360),
    [anon_sym_ENum] = ACTIONS(2360),
    [sym_quoted_identifier] = ACTIONS(2362),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2362),
    [sym_integer] = ACTIONS(2360),
    [sym_continue_as_identifier] = ACTIONS(2362),
    [sym_preproc_open] = ACTIONS(2362),
    [sym_end_keyword] = ACTIONS(2362),
  },
  [STATE(1201)] = {
    [sym_identifier] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2563),
    [anon_sym_DOT] = ACTIONS(2561),
    [anon_sym_EQ] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2561),
    [aux_sym_boolean_token1] = ACTIONS(2561),
    [aux_sym_boolean_token2] = ACTIONS(2561),
    [sym_decimal] = ACTIONS(2561),
    [anon_sym_LPAREN] = ACTIONS(2563),
    [anon_sym_DOT_DOT] = ACTIONS(2563),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2561),
    [anon_sym_STAR] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2563),
    [aux_sym_record_type_token1] = ACTIONS(2561),
    [aux_sym_basic_type_token21] = ACTIONS(2561),
    [aux_sym_basic_type_token22] = ACTIONS(2561),
    [aux_sym_basic_type_token48] = ACTIONS(2561),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_POUNDif] = ACTIONS(2563),
    [anon_sym_POUNDIF] = ACTIONS(2563),
    [anon_sym_POUNDIf] = ACTIONS(2563),
    [anon_sym_not] = ACTIONS(2561),
    [anon_sym_NOT] = ACTIONS(2561),
    [anon_sym_Not] = ACTIONS(2561),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2563),
    [aux_sym__expression_token1] = ACTIONS(2563),
    [aux_sym__expression_token2] = ACTIONS(2561),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2561),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2561),
    [anon_sym_SLASH] = ACTIONS(2561),
    [anon_sym_div] = ACTIONS(2561),
    [anon_sym_DIV] = ACTIONS(2561),
    [anon_sym_Div] = ACTIONS(2561),
    [anon_sym_mod] = ACTIONS(2561),
    [anon_sym_MOD] = ACTIONS(2561),
    [anon_sym_Mod] = ACTIONS(2561),
    [anon_sym_PLUS] = ACTIONS(2561),
    [anon_sym_GT_EQ] = ACTIONS(2563),
    [anon_sym_LT_EQ] = ACTIONS(2563),
    [anon_sym_GT] = ACTIONS(2561),
    [anon_sym_LT] = ACTIONS(2561),
    [anon_sym_LT_GT] = ACTIONS(2563),
    [anon_sym_and] = ACTIONS(2561),
    [anon_sym_AND] = ACTIONS(2561),
    [anon_sym_And] = ACTIONS(2561),
    [anon_sym_or] = ACTIONS(2561),
    [anon_sym_OR] = ACTIONS(2561),
    [anon_sym_Or] = ACTIONS(2561),
    [anon_sym_xor] = ACTIONS(2561),
    [anon_sym_XOR] = ACTIONS(2561),
    [anon_sym_Xor] = ACTIONS(2561),
    [anon_sym_QMARK] = ACTIONS(2563),
    [sym_datetime_literal] = ACTIONS(2563),
    [sym_date_literal] = ACTIONS(2561),
    [sym_time_literal] = ACTIONS(2561),
    [sym_biginteger_literal] = ACTIONS(2563),
    [anon_sym_if] = ACTIONS(2561),
    [anon_sym_IF] = ACTIONS(2561),
    [anon_sym_If] = ACTIONS(2561),
    [anon_sym_else] = ACTIONS(2561),
    [anon_sym_ELSE] = ACTIONS(2561),
    [anon_sym_Else] = ACTIONS(2561),
    [anon_sym_case] = ACTIONS(2561),
    [anon_sym_CASE] = ACTIONS(2561),
    [anon_sym_Case] = ACTIONS(2561),
    [anon_sym_for] = ACTIONS(2561),
    [anon_sym_FOR] = ACTIONS(2561),
    [anon_sym_For] = ACTIONS(2561),
    [anon_sym_foreach] = ACTIONS(2561),
    [anon_sym_FOREACH] = ACTIONS(2561),
    [anon_sym_Foreach] = ACTIONS(2561),
    [anon_sym_while] = ACTIONS(2561),
    [anon_sym_WHILE] = ACTIONS(2561),
    [anon_sym_While] = ACTIONS(2561),
    [anon_sym_repeat] = ACTIONS(2561),
    [anon_sym_REPEAT] = ACTIONS(2561),
    [anon_sym_Repeat] = ACTIONS(2561),
    [anon_sym_exit] = ACTIONS(2561),
    [anon_sym_EXIT] = ACTIONS(2561),
    [anon_sym_Exit] = ACTIONS(2561),
    [anon_sym_continue] = ACTIONS(2561),
    [anon_sym_CONTINUE] = ACTIONS(2561),
    [anon_sym_Continue] = ACTIONS(2561),
    [anon_sym_break] = ACTIONS(2561),
    [anon_sym_BREAK] = ACTIONS(2561),
    [anon_sym_Break] = ACTIONS(2561),
    [anon_sym_with] = ACTIONS(2561),
    [anon_sym_WITH] = ACTIONS(2561),
    [anon_sym_With] = ACTIONS(2561),
    [sym_asserterror_keyword] = ACTIONS(2563),
    [anon_sym_in] = ACTIONS(2561),
    [anon_sym_IN] = ACTIONS(2561),
    [anon_sym_In] = ACTIONS(2561),
    [sym_page_keyword] = ACTIONS(2561),
    [anon_sym_codeunit] = ACTIONS(2561),
    [anon_sym_CODEUNIT] = ACTIONS(2561),
    [anon_sym_Codeunit] = ACTIONS(2561),
    [anon_sym_CodeUnit] = ACTIONS(2561),
    [anon_sym_COdeunit] = ACTIONS(2561),
    [anon_sym_codeUnit] = ACTIONS(2561),
    [sym_report_keyword] = ACTIONS(2561),
    [sym_query_keyword] = ACTIONS(2561),
    [anon_sym_xmlport] = ACTIONS(2561),
    [anon_sym_XMLPORT] = ACTIONS(2561),
    [anon_sym_Xmlport] = ACTIONS(2561),
    [anon_sym_XMLport] = ACTIONS(2561),
    [anon_sym_XMLPort] = ACTIONS(2561),
    [anon_sym_XmlPort] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_ENUM] = ACTIONS(2561),
    [anon_sym_Enum] = ACTIONS(2561),
    [anon_sym_eNUM] = ACTIONS(2561),
    [anon_sym_eNum] = ACTIONS(2561),
    [anon_sym_ENum] = ACTIONS(2561),
    [sym_quoted_identifier] = ACTIONS(2563),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2563),
    [sym_integer] = ACTIONS(2561),
    [sym_continue_as_identifier] = ACTIONS(2563),
    [sym_preproc_open] = ACTIONS(2563),
    [sym_end_keyword] = ACTIONS(2563),
  },
  [STATE(1202)] = {
    [sym_identifier] = ACTIONS(2533),
    [anon_sym_SEMI] = ACTIONS(2535),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym_EQ] = ACTIONS(2535),
    [anon_sym_DASH] = ACTIONS(2533),
    [aux_sym_boolean_token1] = ACTIONS(2533),
    [aux_sym_boolean_token2] = ACTIONS(2533),
    [sym_decimal] = ACTIONS(2533),
    [anon_sym_LPAREN] = ACTIONS(2535),
    [anon_sym_DOT_DOT] = ACTIONS(2535),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2533),
    [anon_sym_STAR] = ACTIONS(2533),
    [anon_sym_LBRACK] = ACTIONS(2535),
    [aux_sym_record_type_token1] = ACTIONS(2533),
    [aux_sym_basic_type_token21] = ACTIONS(2533),
    [aux_sym_basic_type_token22] = ACTIONS(2533),
    [aux_sym_basic_type_token48] = ACTIONS(2533),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2533),
    [anon_sym_POUNDif] = ACTIONS(2535),
    [anon_sym_POUNDIF] = ACTIONS(2535),
    [anon_sym_POUNDIf] = ACTIONS(2535),
    [anon_sym_not] = ACTIONS(2533),
    [anon_sym_NOT] = ACTIONS(2533),
    [anon_sym_Not] = ACTIONS(2533),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2535),
    [aux_sym__expression_token1] = ACTIONS(2535),
    [aux_sym__expression_token2] = ACTIONS(2533),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2533),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2533),
    [anon_sym_SLASH] = ACTIONS(2533),
    [anon_sym_div] = ACTIONS(2533),
    [anon_sym_DIV] = ACTIONS(2533),
    [anon_sym_Div] = ACTIONS(2533),
    [anon_sym_mod] = ACTIONS(2533),
    [anon_sym_MOD] = ACTIONS(2533),
    [anon_sym_Mod] = ACTIONS(2533),
    [anon_sym_PLUS] = ACTIONS(2533),
    [anon_sym_GT_EQ] = ACTIONS(2535),
    [anon_sym_LT_EQ] = ACTIONS(2535),
    [anon_sym_GT] = ACTIONS(2533),
    [anon_sym_LT] = ACTIONS(2533),
    [anon_sym_LT_GT] = ACTIONS(2535),
    [anon_sym_and] = ACTIONS(2533),
    [anon_sym_AND] = ACTIONS(2533),
    [anon_sym_And] = ACTIONS(2533),
    [anon_sym_or] = ACTIONS(2533),
    [anon_sym_OR] = ACTIONS(2533),
    [anon_sym_Or] = ACTIONS(2533),
    [anon_sym_xor] = ACTIONS(2533),
    [anon_sym_XOR] = ACTIONS(2533),
    [anon_sym_Xor] = ACTIONS(2533),
    [anon_sym_QMARK] = ACTIONS(2535),
    [sym_datetime_literal] = ACTIONS(2535),
    [sym_date_literal] = ACTIONS(2533),
    [sym_time_literal] = ACTIONS(2533),
    [sym_biginteger_literal] = ACTIONS(2535),
    [anon_sym_if] = ACTIONS(2533),
    [anon_sym_IF] = ACTIONS(2533),
    [anon_sym_If] = ACTIONS(2533),
    [anon_sym_else] = ACTIONS(2533),
    [anon_sym_ELSE] = ACTIONS(2533),
    [anon_sym_Else] = ACTIONS(2533),
    [anon_sym_case] = ACTIONS(2533),
    [anon_sym_CASE] = ACTIONS(2533),
    [anon_sym_Case] = ACTIONS(2533),
    [anon_sym_for] = ACTIONS(2533),
    [anon_sym_FOR] = ACTIONS(2533),
    [anon_sym_For] = ACTIONS(2533),
    [anon_sym_foreach] = ACTIONS(2533),
    [anon_sym_FOREACH] = ACTIONS(2533),
    [anon_sym_Foreach] = ACTIONS(2533),
    [anon_sym_while] = ACTIONS(2533),
    [anon_sym_WHILE] = ACTIONS(2533),
    [anon_sym_While] = ACTIONS(2533),
    [anon_sym_repeat] = ACTIONS(2533),
    [anon_sym_REPEAT] = ACTIONS(2533),
    [anon_sym_Repeat] = ACTIONS(2533),
    [anon_sym_exit] = ACTIONS(2533),
    [anon_sym_EXIT] = ACTIONS(2533),
    [anon_sym_Exit] = ACTIONS(2533),
    [anon_sym_continue] = ACTIONS(2533),
    [anon_sym_CONTINUE] = ACTIONS(2533),
    [anon_sym_Continue] = ACTIONS(2533),
    [anon_sym_break] = ACTIONS(2533),
    [anon_sym_BREAK] = ACTIONS(2533),
    [anon_sym_Break] = ACTIONS(2533),
    [anon_sym_with] = ACTIONS(2533),
    [anon_sym_WITH] = ACTIONS(2533),
    [anon_sym_With] = ACTIONS(2533),
    [sym_asserterror_keyword] = ACTIONS(2535),
    [anon_sym_in] = ACTIONS(2533),
    [anon_sym_IN] = ACTIONS(2533),
    [anon_sym_In] = ACTIONS(2533),
    [sym_page_keyword] = ACTIONS(2533),
    [anon_sym_codeunit] = ACTIONS(2533),
    [anon_sym_CODEUNIT] = ACTIONS(2533),
    [anon_sym_Codeunit] = ACTIONS(2533),
    [anon_sym_CodeUnit] = ACTIONS(2533),
    [anon_sym_COdeunit] = ACTIONS(2533),
    [anon_sym_codeUnit] = ACTIONS(2533),
    [sym_report_keyword] = ACTIONS(2533),
    [sym_query_keyword] = ACTIONS(2533),
    [anon_sym_xmlport] = ACTIONS(2533),
    [anon_sym_XMLPORT] = ACTIONS(2533),
    [anon_sym_Xmlport] = ACTIONS(2533),
    [anon_sym_XMLport] = ACTIONS(2533),
    [anon_sym_XMLPort] = ACTIONS(2533),
    [anon_sym_XmlPort] = ACTIONS(2533),
    [anon_sym_enum] = ACTIONS(2533),
    [anon_sym_ENUM] = ACTIONS(2533),
    [anon_sym_Enum] = ACTIONS(2533),
    [anon_sym_eNUM] = ACTIONS(2533),
    [anon_sym_eNum] = ACTIONS(2533),
    [anon_sym_ENum] = ACTIONS(2533),
    [sym_temporary_keyword] = ACTIONS(2833),
    [sym_quoted_identifier] = ACTIONS(2535),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2535),
    [sym_integer] = ACTIONS(2533),
    [sym_continue_as_identifier] = ACTIONS(2535),
    [sym_preproc_open] = ACTIONS(2535),
    [sym_end_keyword] = ACTIONS(2535),
  },
  [STATE(1203)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_SEMI] = ACTIONS(2428),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_COMMA] = ACTIONS(2428),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2426),
    [anon_sym_POUNDif] = ACTIONS(2428),
    [anon_sym_POUNDIF] = ACTIONS(2428),
    [anon_sym_POUNDIf] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_IF] = ACTIONS(2426),
    [anon_sym_If] = ACTIONS(2426),
    [anon_sym_else] = ACTIONS(2426),
    [anon_sym_ELSE] = ACTIONS(2426),
    [anon_sym_Else] = ACTIONS(2426),
    [anon_sym_case] = ACTIONS(2426),
    [anon_sym_CASE] = ACTIONS(2426),
    [anon_sym_Case] = ACTIONS(2426),
    [anon_sym_for] = ACTIONS(2426),
    [anon_sym_FOR] = ACTIONS(2426),
    [anon_sym_For] = ACTIONS(2426),
    [anon_sym_foreach] = ACTIONS(2426),
    [anon_sym_FOREACH] = ACTIONS(2426),
    [anon_sym_Foreach] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(2426),
    [anon_sym_WHILE] = ACTIONS(2426),
    [anon_sym_While] = ACTIONS(2426),
    [anon_sym_repeat] = ACTIONS(2426),
    [anon_sym_REPEAT] = ACTIONS(2426),
    [anon_sym_Repeat] = ACTIONS(2426),
    [anon_sym_exit] = ACTIONS(2426),
    [anon_sym_EXIT] = ACTIONS(2426),
    [anon_sym_Exit] = ACTIONS(2426),
    [anon_sym_continue] = ACTIONS(2426),
    [anon_sym_CONTINUE] = ACTIONS(2426),
    [anon_sym_Continue] = ACTIONS(2426),
    [anon_sym_break] = ACTIONS(2426),
    [anon_sym_BREAK] = ACTIONS(2426),
    [anon_sym_Break] = ACTIONS(2426),
    [anon_sym_with] = ACTIONS(2426),
    [anon_sym_WITH] = ACTIONS(2426),
    [anon_sym_With] = ACTIONS(2426),
    [sym_asserterror_keyword] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_open] = ACTIONS(2428),
    [sym_end_keyword] = ACTIONS(2428),
  },
  [STATE(1204)] = {
    [sym_identifier] = ACTIONS(2517),
    [anon_sym_SEMI] = ACTIONS(2519),
    [anon_sym_DOT] = ACTIONS(2517),
    [anon_sym_EQ] = ACTIONS(2519),
    [anon_sym_DASH] = ACTIONS(2517),
    [aux_sym_boolean_token1] = ACTIONS(2517),
    [aux_sym_boolean_token2] = ACTIONS(2517),
    [sym_decimal] = ACTIONS(2517),
    [anon_sym_LPAREN] = ACTIONS(2519),
    [anon_sym_DOT_DOT] = ACTIONS(2519),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2517),
    [anon_sym_STAR] = ACTIONS(2517),
    [anon_sym_LBRACK] = ACTIONS(2519),
    [aux_sym_record_type_token1] = ACTIONS(2517),
    [aux_sym_basic_type_token21] = ACTIONS(2517),
    [aux_sym_basic_type_token22] = ACTIONS(2517),
    [aux_sym_basic_type_token48] = ACTIONS(2517),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2517),
    [anon_sym_COLON_COLON] = ACTIONS(2519),
    [anon_sym_POUNDif] = ACTIONS(2519),
    [anon_sym_POUNDIF] = ACTIONS(2519),
    [anon_sym_POUNDIf] = ACTIONS(2519),
    [anon_sym_not] = ACTIONS(2517),
    [anon_sym_NOT] = ACTIONS(2517),
    [anon_sym_Not] = ACTIONS(2517),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2519),
    [aux_sym__expression_token1] = ACTIONS(2519),
    [aux_sym__expression_token2] = ACTIONS(2517),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2517),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2517),
    [anon_sym_SLASH] = ACTIONS(2517),
    [anon_sym_div] = ACTIONS(2517),
    [anon_sym_DIV] = ACTIONS(2517),
    [anon_sym_Div] = ACTIONS(2517),
    [anon_sym_mod] = ACTIONS(2517),
    [anon_sym_MOD] = ACTIONS(2517),
    [anon_sym_Mod] = ACTIONS(2517),
    [anon_sym_PLUS] = ACTIONS(2517),
    [anon_sym_GT_EQ] = ACTIONS(2519),
    [anon_sym_LT_EQ] = ACTIONS(2519),
    [anon_sym_GT] = ACTIONS(2517),
    [anon_sym_LT] = ACTIONS(2517),
    [anon_sym_LT_GT] = ACTIONS(2519),
    [anon_sym_and] = ACTIONS(2517),
    [anon_sym_AND] = ACTIONS(2517),
    [anon_sym_And] = ACTIONS(2517),
    [anon_sym_or] = ACTIONS(2517),
    [anon_sym_OR] = ACTIONS(2517),
    [anon_sym_Or] = ACTIONS(2517),
    [anon_sym_xor] = ACTIONS(2517),
    [anon_sym_XOR] = ACTIONS(2517),
    [anon_sym_Xor] = ACTIONS(2517),
    [anon_sym_QMARK] = ACTIONS(2519),
    [sym_datetime_literal] = ACTIONS(2519),
    [sym_date_literal] = ACTIONS(2517),
    [sym_time_literal] = ACTIONS(2517),
    [sym_biginteger_literal] = ACTIONS(2519),
    [anon_sym_if] = ACTIONS(2517),
    [anon_sym_IF] = ACTIONS(2517),
    [anon_sym_If] = ACTIONS(2517),
    [anon_sym_else] = ACTIONS(2517),
    [anon_sym_ELSE] = ACTIONS(2517),
    [anon_sym_Else] = ACTIONS(2517),
    [anon_sym_case] = ACTIONS(2517),
    [anon_sym_CASE] = ACTIONS(2517),
    [anon_sym_Case] = ACTIONS(2517),
    [anon_sym_for] = ACTIONS(2517),
    [anon_sym_FOR] = ACTIONS(2517),
    [anon_sym_For] = ACTIONS(2517),
    [anon_sym_foreach] = ACTIONS(2517),
    [anon_sym_FOREACH] = ACTIONS(2517),
    [anon_sym_Foreach] = ACTIONS(2517),
    [anon_sym_while] = ACTIONS(2517),
    [anon_sym_WHILE] = ACTIONS(2517),
    [anon_sym_While] = ACTIONS(2517),
    [anon_sym_repeat] = ACTIONS(2517),
    [anon_sym_REPEAT] = ACTIONS(2517),
    [anon_sym_Repeat] = ACTIONS(2517),
    [anon_sym_exit] = ACTIONS(2517),
    [anon_sym_EXIT] = ACTIONS(2517),
    [anon_sym_Exit] = ACTIONS(2517),
    [anon_sym_continue] = ACTIONS(2517),
    [anon_sym_CONTINUE] = ACTIONS(2517),
    [anon_sym_Continue] = ACTIONS(2517),
    [anon_sym_break] = ACTIONS(2517),
    [anon_sym_BREAK] = ACTIONS(2517),
    [anon_sym_Break] = ACTIONS(2517),
    [anon_sym_with] = ACTIONS(2517),
    [anon_sym_WITH] = ACTIONS(2517),
    [anon_sym_With] = ACTIONS(2517),
    [sym_asserterror_keyword] = ACTIONS(2519),
    [anon_sym_in] = ACTIONS(2517),
    [anon_sym_IN] = ACTIONS(2517),
    [anon_sym_In] = ACTIONS(2517),
    [sym_page_keyword] = ACTIONS(2517),
    [anon_sym_codeunit] = ACTIONS(2517),
    [anon_sym_CODEUNIT] = ACTIONS(2517),
    [anon_sym_Codeunit] = ACTIONS(2517),
    [anon_sym_CodeUnit] = ACTIONS(2517),
    [anon_sym_COdeunit] = ACTIONS(2517),
    [anon_sym_codeUnit] = ACTIONS(2517),
    [sym_report_keyword] = ACTIONS(2517),
    [sym_query_keyword] = ACTIONS(2517),
    [anon_sym_xmlport] = ACTIONS(2517),
    [anon_sym_XMLPORT] = ACTIONS(2517),
    [anon_sym_Xmlport] = ACTIONS(2517),
    [anon_sym_XMLport] = ACTIONS(2517),
    [anon_sym_XMLPort] = ACTIONS(2517),
    [anon_sym_XmlPort] = ACTIONS(2517),
    [anon_sym_enum] = ACTIONS(2517),
    [anon_sym_ENUM] = ACTIONS(2517),
    [anon_sym_Enum] = ACTIONS(2517),
    [anon_sym_eNUM] = ACTIONS(2517),
    [anon_sym_eNum] = ACTIONS(2517),
    [anon_sym_ENum] = ACTIONS(2517),
    [sym_quoted_identifier] = ACTIONS(2519),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2519),
    [sym_integer] = ACTIONS(2517),
    [sym_continue_as_identifier] = ACTIONS(2519),
    [sym_preproc_open] = ACTIONS(2519),
    [sym_end_keyword] = ACTIONS(2519),
  },
  [STATE(1205)] = {
    [sym_identifier] = ACTIONS(2434),
    [anon_sym_SEMI] = ACTIONS(2436),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_DASH] = ACTIONS(2434),
    [aux_sym_boolean_token1] = ACTIONS(2434),
    [aux_sym_boolean_token2] = ACTIONS(2434),
    [sym_decimal] = ACTIONS(2434),
    [anon_sym_LPAREN] = ACTIONS(2436),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2434),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [aux_sym_record_type_token1] = ACTIONS(2434),
    [aux_sym_basic_type_token21] = ACTIONS(2434),
    [aux_sym_basic_type_token22] = ACTIONS(2434),
    [aux_sym_basic_type_token48] = ACTIONS(2434),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2434),
    [anon_sym_COLON_COLON] = ACTIONS(2807),
    [anon_sym_POUNDif] = ACTIONS(2436),
    [anon_sym_POUNDIF] = ACTIONS(2436),
    [anon_sym_POUNDIf] = ACTIONS(2436),
    [anon_sym_not] = ACTIONS(2434),
    [anon_sym_NOT] = ACTIONS(2434),
    [anon_sym_Not] = ACTIONS(2434),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2434),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(2434),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(2436),
    [sym_date_literal] = ACTIONS(2434),
    [sym_time_literal] = ACTIONS(2434),
    [sym_biginteger_literal] = ACTIONS(2436),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_IF] = ACTIONS(2434),
    [anon_sym_If] = ACTIONS(2434),
    [anon_sym_else] = ACTIONS(2434),
    [anon_sym_ELSE] = ACTIONS(2434),
    [anon_sym_Else] = ACTIONS(2434),
    [anon_sym_case] = ACTIONS(2434),
    [anon_sym_CASE] = ACTIONS(2434),
    [anon_sym_Case] = ACTIONS(2434),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_FOR] = ACTIONS(2434),
    [anon_sym_For] = ACTIONS(2434),
    [anon_sym_foreach] = ACTIONS(2434),
    [anon_sym_FOREACH] = ACTIONS(2434),
    [anon_sym_Foreach] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(2434),
    [anon_sym_WHILE] = ACTIONS(2434),
    [anon_sym_While] = ACTIONS(2434),
    [anon_sym_repeat] = ACTIONS(2434),
    [anon_sym_REPEAT] = ACTIONS(2434),
    [anon_sym_Repeat] = ACTIONS(2434),
    [anon_sym_exit] = ACTIONS(2434),
    [anon_sym_EXIT] = ACTIONS(2434),
    [anon_sym_Exit] = ACTIONS(2434),
    [anon_sym_continue] = ACTIONS(2434),
    [anon_sym_CONTINUE] = ACTIONS(2434),
    [anon_sym_Continue] = ACTIONS(2434),
    [anon_sym_break] = ACTIONS(2434),
    [anon_sym_BREAK] = ACTIONS(2434),
    [anon_sym_Break] = ACTIONS(2434),
    [anon_sym_with] = ACTIONS(2434),
    [anon_sym_WITH] = ACTIONS(2434),
    [anon_sym_With] = ACTIONS(2434),
    [sym_asserterror_keyword] = ACTIONS(2436),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(2434),
    [anon_sym_codeunit] = ACTIONS(2434),
    [anon_sym_CODEUNIT] = ACTIONS(2434),
    [anon_sym_Codeunit] = ACTIONS(2434),
    [anon_sym_CodeUnit] = ACTIONS(2434),
    [anon_sym_COdeunit] = ACTIONS(2434),
    [anon_sym_codeUnit] = ACTIONS(2434),
    [sym_report_keyword] = ACTIONS(2434),
    [sym_query_keyword] = ACTIONS(2434),
    [anon_sym_xmlport] = ACTIONS(2434),
    [anon_sym_XMLPORT] = ACTIONS(2434),
    [anon_sym_Xmlport] = ACTIONS(2434),
    [anon_sym_XMLport] = ACTIONS(2434),
    [anon_sym_XMLPort] = ACTIONS(2434),
    [anon_sym_XmlPort] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2434),
    [anon_sym_ENUM] = ACTIONS(2434),
    [anon_sym_Enum] = ACTIONS(2434),
    [anon_sym_eNUM] = ACTIONS(2434),
    [anon_sym_eNum] = ACTIONS(2434),
    [anon_sym_ENum] = ACTIONS(2434),
    [sym_quoted_identifier] = ACTIONS(2436),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2436),
    [sym_integer] = ACTIONS(2434),
    [sym_continue_as_identifier] = ACTIONS(2436),
    [sym_preproc_open] = ACTIONS(2436),
    [sym_end_keyword] = ACTIONS(2436),
  },
  [STATE(1206)] = {
    [sym_identifier] = ACTIONS(2521),
    [anon_sym_SEMI] = ACTIONS(2523),
    [anon_sym_DOT] = ACTIONS(2521),
    [anon_sym_EQ] = ACTIONS(2523),
    [anon_sym_DASH] = ACTIONS(2521),
    [aux_sym_boolean_token1] = ACTIONS(2521),
    [aux_sym_boolean_token2] = ACTIONS(2521),
    [sym_decimal] = ACTIONS(2521),
    [anon_sym_LPAREN] = ACTIONS(2523),
    [anon_sym_DOT_DOT] = ACTIONS(2523),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2521),
    [anon_sym_STAR] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [aux_sym_record_type_token1] = ACTIONS(2521),
    [aux_sym_basic_type_token21] = ACTIONS(2521),
    [aux_sym_basic_type_token22] = ACTIONS(2521),
    [aux_sym_basic_type_token48] = ACTIONS(2521),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2521),
    [anon_sym_COLON_COLON] = ACTIONS(2523),
    [anon_sym_POUNDif] = ACTIONS(2523),
    [anon_sym_POUNDIF] = ACTIONS(2523),
    [anon_sym_POUNDIf] = ACTIONS(2523),
    [anon_sym_not] = ACTIONS(2521),
    [anon_sym_NOT] = ACTIONS(2521),
    [anon_sym_Not] = ACTIONS(2521),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2523),
    [aux_sym__expression_token1] = ACTIONS(2523),
    [aux_sym__expression_token2] = ACTIONS(2521),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2521),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2521),
    [anon_sym_SLASH] = ACTIONS(2521),
    [anon_sym_div] = ACTIONS(2521),
    [anon_sym_DIV] = ACTIONS(2521),
    [anon_sym_Div] = ACTIONS(2521),
    [anon_sym_mod] = ACTIONS(2521),
    [anon_sym_MOD] = ACTIONS(2521),
    [anon_sym_Mod] = ACTIONS(2521),
    [anon_sym_PLUS] = ACTIONS(2521),
    [anon_sym_GT_EQ] = ACTIONS(2523),
    [anon_sym_LT_EQ] = ACTIONS(2523),
    [anon_sym_GT] = ACTIONS(2521),
    [anon_sym_LT] = ACTIONS(2521),
    [anon_sym_LT_GT] = ACTIONS(2523),
    [anon_sym_and] = ACTIONS(2521),
    [anon_sym_AND] = ACTIONS(2521),
    [anon_sym_And] = ACTIONS(2521),
    [anon_sym_or] = ACTIONS(2521),
    [anon_sym_OR] = ACTIONS(2521),
    [anon_sym_Or] = ACTIONS(2521),
    [anon_sym_xor] = ACTIONS(2521),
    [anon_sym_XOR] = ACTIONS(2521),
    [anon_sym_Xor] = ACTIONS(2521),
    [anon_sym_QMARK] = ACTIONS(2523),
    [sym_datetime_literal] = ACTIONS(2523),
    [sym_date_literal] = ACTIONS(2521),
    [sym_time_literal] = ACTIONS(2521),
    [sym_biginteger_literal] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2521),
    [anon_sym_IF] = ACTIONS(2521),
    [anon_sym_If] = ACTIONS(2521),
    [anon_sym_else] = ACTIONS(2521),
    [anon_sym_ELSE] = ACTIONS(2521),
    [anon_sym_Else] = ACTIONS(2521),
    [anon_sym_case] = ACTIONS(2521),
    [anon_sym_CASE] = ACTIONS(2521),
    [anon_sym_Case] = ACTIONS(2521),
    [anon_sym_for] = ACTIONS(2521),
    [anon_sym_FOR] = ACTIONS(2521),
    [anon_sym_For] = ACTIONS(2521),
    [anon_sym_foreach] = ACTIONS(2521),
    [anon_sym_FOREACH] = ACTIONS(2521),
    [anon_sym_Foreach] = ACTIONS(2521),
    [anon_sym_while] = ACTIONS(2521),
    [anon_sym_WHILE] = ACTIONS(2521),
    [anon_sym_While] = ACTIONS(2521),
    [anon_sym_repeat] = ACTIONS(2521),
    [anon_sym_REPEAT] = ACTIONS(2521),
    [anon_sym_Repeat] = ACTIONS(2521),
    [anon_sym_exit] = ACTIONS(2521),
    [anon_sym_EXIT] = ACTIONS(2521),
    [anon_sym_Exit] = ACTIONS(2521),
    [anon_sym_continue] = ACTIONS(2521),
    [anon_sym_CONTINUE] = ACTIONS(2521),
    [anon_sym_Continue] = ACTIONS(2521),
    [anon_sym_break] = ACTIONS(2521),
    [anon_sym_BREAK] = ACTIONS(2521),
    [anon_sym_Break] = ACTIONS(2521),
    [anon_sym_with] = ACTIONS(2521),
    [anon_sym_WITH] = ACTIONS(2521),
    [anon_sym_With] = ACTIONS(2521),
    [sym_asserterror_keyword] = ACTIONS(2523),
    [anon_sym_in] = ACTIONS(2521),
    [anon_sym_IN] = ACTIONS(2521),
    [anon_sym_In] = ACTIONS(2521),
    [sym_page_keyword] = ACTIONS(2521),
    [anon_sym_codeunit] = ACTIONS(2521),
    [anon_sym_CODEUNIT] = ACTIONS(2521),
    [anon_sym_Codeunit] = ACTIONS(2521),
    [anon_sym_CodeUnit] = ACTIONS(2521),
    [anon_sym_COdeunit] = ACTIONS(2521),
    [anon_sym_codeUnit] = ACTIONS(2521),
    [sym_report_keyword] = ACTIONS(2521),
    [sym_query_keyword] = ACTIONS(2521),
    [anon_sym_xmlport] = ACTIONS(2521),
    [anon_sym_XMLPORT] = ACTIONS(2521),
    [anon_sym_Xmlport] = ACTIONS(2521),
    [anon_sym_XMLport] = ACTIONS(2521),
    [anon_sym_XMLPort] = ACTIONS(2521),
    [anon_sym_XmlPort] = ACTIONS(2521),
    [anon_sym_enum] = ACTIONS(2521),
    [anon_sym_ENUM] = ACTIONS(2521),
    [anon_sym_Enum] = ACTIONS(2521),
    [anon_sym_eNUM] = ACTIONS(2521),
    [anon_sym_eNum] = ACTIONS(2521),
    [anon_sym_ENum] = ACTIONS(2521),
    [sym_quoted_identifier] = ACTIONS(2523),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2523),
    [sym_integer] = ACTIONS(2521),
    [sym_continue_as_identifier] = ACTIONS(2523),
    [sym_preproc_open] = ACTIONS(2523),
    [sym_end_keyword] = ACTIONS(2523),
  },
  [STATE(1207)] = {
    [sym_identifier] = ACTIONS(2555),
    [anon_sym_SEMI] = ACTIONS(2557),
    [anon_sym_DOT] = ACTIONS(2555),
    [anon_sym_EQ] = ACTIONS(2557),
    [anon_sym_DASH] = ACTIONS(2555),
    [aux_sym_boolean_token1] = ACTIONS(2555),
    [aux_sym_boolean_token2] = ACTIONS(2555),
    [sym_decimal] = ACTIONS(2555),
    [anon_sym_LPAREN] = ACTIONS(2557),
    [anon_sym_DOT_DOT] = ACTIONS(2557),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2555),
    [anon_sym_STAR] = ACTIONS(2555),
    [anon_sym_LBRACK] = ACTIONS(2557),
    [aux_sym_record_type_token1] = ACTIONS(2555),
    [aux_sym_basic_type_token21] = ACTIONS(2555),
    [aux_sym_basic_type_token22] = ACTIONS(2555),
    [aux_sym_basic_type_token48] = ACTIONS(2555),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2555),
    [anon_sym_COLON_COLON] = ACTIONS(2557),
    [anon_sym_POUNDif] = ACTIONS(2557),
    [anon_sym_POUNDIF] = ACTIONS(2557),
    [anon_sym_POUNDIf] = ACTIONS(2557),
    [anon_sym_not] = ACTIONS(2555),
    [anon_sym_NOT] = ACTIONS(2555),
    [anon_sym_Not] = ACTIONS(2555),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2557),
    [aux_sym__expression_token1] = ACTIONS(2557),
    [aux_sym__expression_token2] = ACTIONS(2555),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2555),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2555),
    [anon_sym_SLASH] = ACTIONS(2555),
    [anon_sym_div] = ACTIONS(2555),
    [anon_sym_DIV] = ACTIONS(2555),
    [anon_sym_Div] = ACTIONS(2555),
    [anon_sym_mod] = ACTIONS(2555),
    [anon_sym_MOD] = ACTIONS(2555),
    [anon_sym_Mod] = ACTIONS(2555),
    [anon_sym_PLUS] = ACTIONS(2555),
    [anon_sym_GT_EQ] = ACTIONS(2557),
    [anon_sym_LT_EQ] = ACTIONS(2557),
    [anon_sym_GT] = ACTIONS(2555),
    [anon_sym_LT] = ACTIONS(2555),
    [anon_sym_LT_GT] = ACTIONS(2557),
    [anon_sym_and] = ACTIONS(2555),
    [anon_sym_AND] = ACTIONS(2555),
    [anon_sym_And] = ACTIONS(2555),
    [anon_sym_or] = ACTIONS(2555),
    [anon_sym_OR] = ACTIONS(2555),
    [anon_sym_Or] = ACTIONS(2555),
    [anon_sym_xor] = ACTIONS(2555),
    [anon_sym_XOR] = ACTIONS(2555),
    [anon_sym_Xor] = ACTIONS(2555),
    [anon_sym_QMARK] = ACTIONS(2557),
    [sym_datetime_literal] = ACTIONS(2557),
    [sym_date_literal] = ACTIONS(2555),
    [sym_time_literal] = ACTIONS(2555),
    [sym_biginteger_literal] = ACTIONS(2557),
    [anon_sym_if] = ACTIONS(2555),
    [anon_sym_IF] = ACTIONS(2555),
    [anon_sym_If] = ACTIONS(2555),
    [anon_sym_else] = ACTIONS(2555),
    [anon_sym_ELSE] = ACTIONS(2555),
    [anon_sym_Else] = ACTIONS(2555),
    [anon_sym_case] = ACTIONS(2555),
    [anon_sym_CASE] = ACTIONS(2555),
    [anon_sym_Case] = ACTIONS(2555),
    [anon_sym_for] = ACTIONS(2555),
    [anon_sym_FOR] = ACTIONS(2555),
    [anon_sym_For] = ACTIONS(2555),
    [anon_sym_foreach] = ACTIONS(2555),
    [anon_sym_FOREACH] = ACTIONS(2555),
    [anon_sym_Foreach] = ACTIONS(2555),
    [anon_sym_while] = ACTIONS(2555),
    [anon_sym_WHILE] = ACTIONS(2555),
    [anon_sym_While] = ACTIONS(2555),
    [anon_sym_repeat] = ACTIONS(2555),
    [anon_sym_REPEAT] = ACTIONS(2555),
    [anon_sym_Repeat] = ACTIONS(2555),
    [anon_sym_exit] = ACTIONS(2555),
    [anon_sym_EXIT] = ACTIONS(2555),
    [anon_sym_Exit] = ACTIONS(2555),
    [anon_sym_continue] = ACTIONS(2555),
    [anon_sym_CONTINUE] = ACTIONS(2555),
    [anon_sym_Continue] = ACTIONS(2555),
    [anon_sym_break] = ACTIONS(2555),
    [anon_sym_BREAK] = ACTIONS(2555),
    [anon_sym_Break] = ACTIONS(2555),
    [anon_sym_with] = ACTIONS(2555),
    [anon_sym_WITH] = ACTIONS(2555),
    [anon_sym_With] = ACTIONS(2555),
    [sym_asserterror_keyword] = ACTIONS(2557),
    [anon_sym_in] = ACTIONS(2555),
    [anon_sym_IN] = ACTIONS(2555),
    [anon_sym_In] = ACTIONS(2555),
    [sym_page_keyword] = ACTIONS(2555),
    [anon_sym_codeunit] = ACTIONS(2555),
    [anon_sym_CODEUNIT] = ACTIONS(2555),
    [anon_sym_Codeunit] = ACTIONS(2555),
    [anon_sym_CodeUnit] = ACTIONS(2555),
    [anon_sym_COdeunit] = ACTIONS(2555),
    [anon_sym_codeUnit] = ACTIONS(2555),
    [sym_report_keyword] = ACTIONS(2555),
    [sym_query_keyword] = ACTIONS(2555),
    [anon_sym_xmlport] = ACTIONS(2555),
    [anon_sym_XMLPORT] = ACTIONS(2555),
    [anon_sym_Xmlport] = ACTIONS(2555),
    [anon_sym_XMLport] = ACTIONS(2555),
    [anon_sym_XMLPort] = ACTIONS(2555),
    [anon_sym_XmlPort] = ACTIONS(2555),
    [anon_sym_enum] = ACTIONS(2555),
    [anon_sym_ENUM] = ACTIONS(2555),
    [anon_sym_Enum] = ACTIONS(2555),
    [anon_sym_eNUM] = ACTIONS(2555),
    [anon_sym_eNum] = ACTIONS(2555),
    [anon_sym_ENum] = ACTIONS(2555),
    [sym_quoted_identifier] = ACTIONS(2557),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2557),
    [sym_integer] = ACTIONS(2555),
    [sym_continue_as_identifier] = ACTIONS(2557),
    [sym_preproc_open] = ACTIONS(2557),
    [sym_end_keyword] = ACTIONS(2557),
  },
  [STATE(1208)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_SEMI] = ACTIONS(2428),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2426),
    [anon_sym_COLON_COLON] = ACTIONS(2835),
    [anon_sym_POUNDif] = ACTIONS(2428),
    [anon_sym_POUNDIF] = ACTIONS(2428),
    [anon_sym_POUNDIf] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_IF] = ACTIONS(2426),
    [anon_sym_If] = ACTIONS(2426),
    [anon_sym_else] = ACTIONS(2426),
    [anon_sym_ELSE] = ACTIONS(2426),
    [anon_sym_Else] = ACTIONS(2426),
    [anon_sym_case] = ACTIONS(2426),
    [anon_sym_CASE] = ACTIONS(2426),
    [anon_sym_Case] = ACTIONS(2426),
    [anon_sym_for] = ACTIONS(2426),
    [anon_sym_FOR] = ACTIONS(2426),
    [anon_sym_For] = ACTIONS(2426),
    [anon_sym_foreach] = ACTIONS(2426),
    [anon_sym_FOREACH] = ACTIONS(2426),
    [anon_sym_Foreach] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(2426),
    [anon_sym_WHILE] = ACTIONS(2426),
    [anon_sym_While] = ACTIONS(2426),
    [anon_sym_repeat] = ACTIONS(2426),
    [anon_sym_REPEAT] = ACTIONS(2426),
    [anon_sym_Repeat] = ACTIONS(2426),
    [anon_sym_exit] = ACTIONS(2426),
    [anon_sym_EXIT] = ACTIONS(2426),
    [anon_sym_Exit] = ACTIONS(2426),
    [anon_sym_continue] = ACTIONS(2426),
    [anon_sym_CONTINUE] = ACTIONS(2426),
    [anon_sym_Continue] = ACTIONS(2426),
    [anon_sym_break] = ACTIONS(2426),
    [anon_sym_BREAK] = ACTIONS(2426),
    [anon_sym_Break] = ACTIONS(2426),
    [anon_sym_with] = ACTIONS(2426),
    [anon_sym_WITH] = ACTIONS(2426),
    [anon_sym_With] = ACTIONS(2426),
    [sym_asserterror_keyword] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_open] = ACTIONS(2428),
    [sym_end_keyword] = ACTIONS(2428),
  },
  [STATE(1209)] = {
    [sym_identifier] = ACTIONS(2525),
    [anon_sym_SEMI] = ACTIONS(2527),
    [anon_sym_DOT] = ACTIONS(2525),
    [anon_sym_EQ] = ACTIONS(2527),
    [anon_sym_DASH] = ACTIONS(2525),
    [aux_sym_boolean_token1] = ACTIONS(2525),
    [aux_sym_boolean_token2] = ACTIONS(2525),
    [sym_decimal] = ACTIONS(2525),
    [anon_sym_LPAREN] = ACTIONS(2527),
    [anon_sym_DOT_DOT] = ACTIONS(2527),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2525),
    [anon_sym_STAR] = ACTIONS(2525),
    [anon_sym_LBRACK] = ACTIONS(2527),
    [aux_sym_record_type_token1] = ACTIONS(2525),
    [aux_sym_basic_type_token21] = ACTIONS(2525),
    [aux_sym_basic_type_token22] = ACTIONS(2525),
    [aux_sym_basic_type_token48] = ACTIONS(2525),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2525),
    [anon_sym_COLON_COLON] = ACTIONS(2527),
    [anon_sym_POUNDif] = ACTIONS(2527),
    [anon_sym_POUNDIF] = ACTIONS(2527),
    [anon_sym_POUNDIf] = ACTIONS(2527),
    [anon_sym_not] = ACTIONS(2525),
    [anon_sym_NOT] = ACTIONS(2525),
    [anon_sym_Not] = ACTIONS(2525),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2527),
    [aux_sym__expression_token1] = ACTIONS(2527),
    [aux_sym__expression_token2] = ACTIONS(2525),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2525),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2525),
    [anon_sym_SLASH] = ACTIONS(2525),
    [anon_sym_div] = ACTIONS(2525),
    [anon_sym_DIV] = ACTIONS(2525),
    [anon_sym_Div] = ACTIONS(2525),
    [anon_sym_mod] = ACTIONS(2525),
    [anon_sym_MOD] = ACTIONS(2525),
    [anon_sym_Mod] = ACTIONS(2525),
    [anon_sym_PLUS] = ACTIONS(2525),
    [anon_sym_GT_EQ] = ACTIONS(2527),
    [anon_sym_LT_EQ] = ACTIONS(2527),
    [anon_sym_GT] = ACTIONS(2525),
    [anon_sym_LT] = ACTIONS(2525),
    [anon_sym_LT_GT] = ACTIONS(2527),
    [anon_sym_and] = ACTIONS(2525),
    [anon_sym_AND] = ACTIONS(2525),
    [anon_sym_And] = ACTIONS(2525),
    [anon_sym_or] = ACTIONS(2525),
    [anon_sym_OR] = ACTIONS(2525),
    [anon_sym_Or] = ACTIONS(2525),
    [anon_sym_xor] = ACTIONS(2525),
    [anon_sym_XOR] = ACTIONS(2525),
    [anon_sym_Xor] = ACTIONS(2525),
    [anon_sym_QMARK] = ACTIONS(2527),
    [sym_datetime_literal] = ACTIONS(2527),
    [sym_date_literal] = ACTIONS(2525),
    [sym_time_literal] = ACTIONS(2525),
    [sym_biginteger_literal] = ACTIONS(2527),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_IF] = ACTIONS(2525),
    [anon_sym_If] = ACTIONS(2525),
    [anon_sym_else] = ACTIONS(2525),
    [anon_sym_ELSE] = ACTIONS(2525),
    [anon_sym_Else] = ACTIONS(2525),
    [anon_sym_case] = ACTIONS(2525),
    [anon_sym_CASE] = ACTIONS(2525),
    [anon_sym_Case] = ACTIONS(2525),
    [anon_sym_for] = ACTIONS(2525),
    [anon_sym_FOR] = ACTIONS(2525),
    [anon_sym_For] = ACTIONS(2525),
    [anon_sym_foreach] = ACTIONS(2525),
    [anon_sym_FOREACH] = ACTIONS(2525),
    [anon_sym_Foreach] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(2525),
    [anon_sym_WHILE] = ACTIONS(2525),
    [anon_sym_While] = ACTIONS(2525),
    [anon_sym_repeat] = ACTIONS(2525),
    [anon_sym_REPEAT] = ACTIONS(2525),
    [anon_sym_Repeat] = ACTIONS(2525),
    [anon_sym_exit] = ACTIONS(2525),
    [anon_sym_EXIT] = ACTIONS(2525),
    [anon_sym_Exit] = ACTIONS(2525),
    [anon_sym_continue] = ACTIONS(2525),
    [anon_sym_CONTINUE] = ACTIONS(2525),
    [anon_sym_Continue] = ACTIONS(2525),
    [anon_sym_break] = ACTIONS(2525),
    [anon_sym_BREAK] = ACTIONS(2525),
    [anon_sym_Break] = ACTIONS(2525),
    [anon_sym_with] = ACTIONS(2525),
    [anon_sym_WITH] = ACTIONS(2525),
    [anon_sym_With] = ACTIONS(2525),
    [sym_asserterror_keyword] = ACTIONS(2527),
    [anon_sym_in] = ACTIONS(2525),
    [anon_sym_IN] = ACTIONS(2525),
    [anon_sym_In] = ACTIONS(2525),
    [sym_page_keyword] = ACTIONS(2525),
    [anon_sym_codeunit] = ACTIONS(2525),
    [anon_sym_CODEUNIT] = ACTIONS(2525),
    [anon_sym_Codeunit] = ACTIONS(2525),
    [anon_sym_CodeUnit] = ACTIONS(2525),
    [anon_sym_COdeunit] = ACTIONS(2525),
    [anon_sym_codeUnit] = ACTIONS(2525),
    [sym_report_keyword] = ACTIONS(2525),
    [sym_query_keyword] = ACTIONS(2525),
    [anon_sym_xmlport] = ACTIONS(2525),
    [anon_sym_XMLPORT] = ACTIONS(2525),
    [anon_sym_Xmlport] = ACTIONS(2525),
    [anon_sym_XMLport] = ACTIONS(2525),
    [anon_sym_XMLPort] = ACTIONS(2525),
    [anon_sym_XmlPort] = ACTIONS(2525),
    [anon_sym_enum] = ACTIONS(2525),
    [anon_sym_ENUM] = ACTIONS(2525),
    [anon_sym_Enum] = ACTIONS(2525),
    [anon_sym_eNUM] = ACTIONS(2525),
    [anon_sym_eNum] = ACTIONS(2525),
    [anon_sym_ENum] = ACTIONS(2525),
    [sym_quoted_identifier] = ACTIONS(2527),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2527),
    [sym_integer] = ACTIONS(2525),
    [sym_continue_as_identifier] = ACTIONS(2527),
    [sym_preproc_open] = ACTIONS(2527),
    [sym_end_keyword] = ACTIONS(2527),
  },
  [STATE(1210)] = {
    [sym_identifier] = ACTIONS(2396),
    [anon_sym_SEMI] = ACTIONS(2398),
    [anon_sym_DOT] = ACTIONS(2396),
    [anon_sym_EQ] = ACTIONS(2398),
    [anon_sym_DASH] = ACTIONS(2396),
    [aux_sym_boolean_token1] = ACTIONS(2396),
    [aux_sym_boolean_token2] = ACTIONS(2396),
    [sym_decimal] = ACTIONS(2396),
    [anon_sym_LPAREN] = ACTIONS(2398),
    [anon_sym_DOT_DOT] = ACTIONS(2398),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2396),
    [anon_sym_STAR] = ACTIONS(2396),
    [anon_sym_LBRACK] = ACTIONS(2398),
    [aux_sym_record_type_token1] = ACTIONS(2396),
    [aux_sym_basic_type_token21] = ACTIONS(2396),
    [aux_sym_basic_type_token22] = ACTIONS(2396),
    [aux_sym_basic_type_token48] = ACTIONS(2396),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2396),
    [anon_sym_POUNDif] = ACTIONS(2398),
    [anon_sym_POUNDIF] = ACTIONS(2398),
    [anon_sym_POUNDIf] = ACTIONS(2398),
    [anon_sym_not] = ACTIONS(2396),
    [anon_sym_NOT] = ACTIONS(2396),
    [anon_sym_Not] = ACTIONS(2396),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2398),
    [aux_sym__expression_token1] = ACTIONS(2398),
    [aux_sym__expression_token2] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2396),
    [anon_sym_SLASH] = ACTIONS(2396),
    [anon_sym_div] = ACTIONS(2396),
    [anon_sym_DIV] = ACTIONS(2396),
    [anon_sym_Div] = ACTIONS(2396),
    [anon_sym_mod] = ACTIONS(2396),
    [anon_sym_MOD] = ACTIONS(2396),
    [anon_sym_Mod] = ACTIONS(2396),
    [anon_sym_PLUS] = ACTIONS(2396),
    [anon_sym_GT_EQ] = ACTIONS(2398),
    [anon_sym_LT_EQ] = ACTIONS(2398),
    [anon_sym_GT] = ACTIONS(2396),
    [anon_sym_LT] = ACTIONS(2396),
    [anon_sym_LT_GT] = ACTIONS(2398),
    [anon_sym_and] = ACTIONS(2396),
    [anon_sym_AND] = ACTIONS(2396),
    [anon_sym_And] = ACTIONS(2396),
    [anon_sym_or] = ACTIONS(2396),
    [anon_sym_OR] = ACTIONS(2396),
    [anon_sym_Or] = ACTIONS(2396),
    [anon_sym_xor] = ACTIONS(2396),
    [anon_sym_XOR] = ACTIONS(2396),
    [anon_sym_Xor] = ACTIONS(2396),
    [anon_sym_QMARK] = ACTIONS(2398),
    [sym_datetime_literal] = ACTIONS(2398),
    [sym_date_literal] = ACTIONS(2396),
    [sym_time_literal] = ACTIONS(2396),
    [sym_biginteger_literal] = ACTIONS(2398),
    [anon_sym_if] = ACTIONS(2396),
    [anon_sym_IF] = ACTIONS(2396),
    [anon_sym_If] = ACTIONS(2396),
    [anon_sym_else] = ACTIONS(2396),
    [anon_sym_ELSE] = ACTIONS(2396),
    [anon_sym_Else] = ACTIONS(2396),
    [anon_sym_case] = ACTIONS(2396),
    [anon_sym_CASE] = ACTIONS(2396),
    [anon_sym_Case] = ACTIONS(2396),
    [anon_sym_for] = ACTIONS(2396),
    [anon_sym_FOR] = ACTIONS(2396),
    [anon_sym_For] = ACTIONS(2396),
    [anon_sym_foreach] = ACTIONS(2396),
    [anon_sym_FOREACH] = ACTIONS(2396),
    [anon_sym_Foreach] = ACTIONS(2396),
    [anon_sym_while] = ACTIONS(2396),
    [anon_sym_WHILE] = ACTIONS(2396),
    [anon_sym_While] = ACTIONS(2396),
    [anon_sym_repeat] = ACTIONS(2396),
    [anon_sym_REPEAT] = ACTIONS(2396),
    [anon_sym_Repeat] = ACTIONS(2396),
    [anon_sym_exit] = ACTIONS(2396),
    [anon_sym_EXIT] = ACTIONS(2396),
    [anon_sym_Exit] = ACTIONS(2396),
    [anon_sym_continue] = ACTIONS(2396),
    [anon_sym_CONTINUE] = ACTIONS(2396),
    [anon_sym_Continue] = ACTIONS(2396),
    [anon_sym_break] = ACTIONS(2396),
    [anon_sym_BREAK] = ACTIONS(2396),
    [anon_sym_Break] = ACTIONS(2396),
    [anon_sym_with] = ACTIONS(2396),
    [anon_sym_WITH] = ACTIONS(2396),
    [anon_sym_With] = ACTIONS(2396),
    [sym_asserterror_keyword] = ACTIONS(2398),
    [anon_sym_in] = ACTIONS(2396),
    [anon_sym_IN] = ACTIONS(2396),
    [anon_sym_In] = ACTIONS(2396),
    [sym_page_keyword] = ACTIONS(2396),
    [anon_sym_codeunit] = ACTIONS(2396),
    [anon_sym_CODEUNIT] = ACTIONS(2396),
    [anon_sym_Codeunit] = ACTIONS(2396),
    [anon_sym_CodeUnit] = ACTIONS(2396),
    [anon_sym_COdeunit] = ACTIONS(2396),
    [anon_sym_codeUnit] = ACTIONS(2396),
    [sym_report_keyword] = ACTIONS(2396),
    [sym_query_keyword] = ACTIONS(2396),
    [anon_sym_xmlport] = ACTIONS(2396),
    [anon_sym_XMLPORT] = ACTIONS(2396),
    [anon_sym_Xmlport] = ACTIONS(2396),
    [anon_sym_XMLport] = ACTIONS(2396),
    [anon_sym_XMLPort] = ACTIONS(2396),
    [anon_sym_XmlPort] = ACTIONS(2396),
    [anon_sym_enum] = ACTIONS(2396),
    [anon_sym_ENUM] = ACTIONS(2396),
    [anon_sym_Enum] = ACTIONS(2396),
    [anon_sym_eNUM] = ACTIONS(2396),
    [anon_sym_eNum] = ACTIONS(2396),
    [anon_sym_ENum] = ACTIONS(2396),
    [sym_temporary_keyword] = ACTIONS(2396),
    [sym_quoted_identifier] = ACTIONS(2398),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2398),
    [sym_integer] = ACTIONS(2396),
    [sym_continue_as_identifier] = ACTIONS(2398),
    [sym_preproc_open] = ACTIONS(2398),
    [sym_end_keyword] = ACTIONS(2398),
  },
  [STATE(1211)] = {
    [sym_identifier] = ACTIONS(2551),
    [anon_sym_SEMI] = ACTIONS(2553),
    [anon_sym_DOT] = ACTIONS(2551),
    [anon_sym_EQ] = ACTIONS(2553),
    [anon_sym_COMMA] = ACTIONS(2553),
    [anon_sym_DASH] = ACTIONS(2551),
    [aux_sym_boolean_token1] = ACTIONS(2551),
    [aux_sym_boolean_token2] = ACTIONS(2551),
    [sym_decimal] = ACTIONS(2551),
    [anon_sym_LPAREN] = ACTIONS(2553),
    [anon_sym_DOT_DOT] = ACTIONS(2553),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2551),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_LBRACK] = ACTIONS(2553),
    [aux_sym_record_type_token1] = ACTIONS(2551),
    [aux_sym_basic_type_token21] = ACTIONS(2551),
    [aux_sym_basic_type_token22] = ACTIONS(2551),
    [aux_sym_basic_type_token48] = ACTIONS(2551),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2551),
    [anon_sym_POUNDif] = ACTIONS(2553),
    [anon_sym_POUNDIF] = ACTIONS(2553),
    [anon_sym_POUNDIf] = ACTIONS(2553),
    [anon_sym_not] = ACTIONS(2551),
    [anon_sym_NOT] = ACTIONS(2551),
    [anon_sym_Not] = ACTIONS(2551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2553),
    [aux_sym__expression_token1] = ACTIONS(2553),
    [aux_sym__expression_token2] = ACTIONS(2551),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2551),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2551),
    [anon_sym_SLASH] = ACTIONS(2551),
    [anon_sym_div] = ACTIONS(2551),
    [anon_sym_DIV] = ACTIONS(2551),
    [anon_sym_Div] = ACTIONS(2551),
    [anon_sym_mod] = ACTIONS(2551),
    [anon_sym_MOD] = ACTIONS(2551),
    [anon_sym_Mod] = ACTIONS(2551),
    [anon_sym_PLUS] = ACTIONS(2551),
    [anon_sym_GT_EQ] = ACTIONS(2553),
    [anon_sym_LT_EQ] = ACTIONS(2553),
    [anon_sym_GT] = ACTIONS(2551),
    [anon_sym_LT] = ACTIONS(2551),
    [anon_sym_LT_GT] = ACTIONS(2553),
    [anon_sym_and] = ACTIONS(2551),
    [anon_sym_AND] = ACTIONS(2551),
    [anon_sym_And] = ACTIONS(2551),
    [anon_sym_or] = ACTIONS(2551),
    [anon_sym_OR] = ACTIONS(2551),
    [anon_sym_Or] = ACTIONS(2551),
    [anon_sym_xor] = ACTIONS(2551),
    [anon_sym_XOR] = ACTIONS(2551),
    [anon_sym_Xor] = ACTIONS(2551),
    [anon_sym_QMARK] = ACTIONS(2553),
    [sym_datetime_literal] = ACTIONS(2553),
    [sym_date_literal] = ACTIONS(2551),
    [sym_time_literal] = ACTIONS(2551),
    [sym_biginteger_literal] = ACTIONS(2553),
    [anon_sym_if] = ACTIONS(2551),
    [anon_sym_IF] = ACTIONS(2551),
    [anon_sym_If] = ACTIONS(2551),
    [anon_sym_else] = ACTIONS(2551),
    [anon_sym_ELSE] = ACTIONS(2551),
    [anon_sym_Else] = ACTIONS(2551),
    [anon_sym_case] = ACTIONS(2551),
    [anon_sym_CASE] = ACTIONS(2551),
    [anon_sym_Case] = ACTIONS(2551),
    [anon_sym_for] = ACTIONS(2551),
    [anon_sym_FOR] = ACTIONS(2551),
    [anon_sym_For] = ACTIONS(2551),
    [anon_sym_foreach] = ACTIONS(2551),
    [anon_sym_FOREACH] = ACTIONS(2551),
    [anon_sym_Foreach] = ACTIONS(2551),
    [anon_sym_while] = ACTIONS(2551),
    [anon_sym_WHILE] = ACTIONS(2551),
    [anon_sym_While] = ACTIONS(2551),
    [anon_sym_repeat] = ACTIONS(2551),
    [anon_sym_REPEAT] = ACTIONS(2551),
    [anon_sym_Repeat] = ACTIONS(2551),
    [anon_sym_exit] = ACTIONS(2551),
    [anon_sym_EXIT] = ACTIONS(2551),
    [anon_sym_Exit] = ACTIONS(2551),
    [anon_sym_continue] = ACTIONS(2551),
    [anon_sym_CONTINUE] = ACTIONS(2551),
    [anon_sym_Continue] = ACTIONS(2551),
    [anon_sym_break] = ACTIONS(2551),
    [anon_sym_BREAK] = ACTIONS(2551),
    [anon_sym_Break] = ACTIONS(2551),
    [anon_sym_with] = ACTIONS(2551),
    [anon_sym_WITH] = ACTIONS(2551),
    [anon_sym_With] = ACTIONS(2551),
    [sym_asserterror_keyword] = ACTIONS(2553),
    [anon_sym_in] = ACTIONS(2551),
    [anon_sym_IN] = ACTIONS(2551),
    [anon_sym_In] = ACTIONS(2551),
    [sym_page_keyword] = ACTIONS(2551),
    [anon_sym_codeunit] = ACTIONS(2551),
    [anon_sym_CODEUNIT] = ACTIONS(2551),
    [anon_sym_Codeunit] = ACTIONS(2551),
    [anon_sym_CodeUnit] = ACTIONS(2551),
    [anon_sym_COdeunit] = ACTIONS(2551),
    [anon_sym_codeUnit] = ACTIONS(2551),
    [sym_report_keyword] = ACTIONS(2551),
    [sym_query_keyword] = ACTIONS(2551),
    [anon_sym_xmlport] = ACTIONS(2551),
    [anon_sym_XMLPORT] = ACTIONS(2551),
    [anon_sym_Xmlport] = ACTIONS(2551),
    [anon_sym_XMLport] = ACTIONS(2551),
    [anon_sym_XMLPort] = ACTIONS(2551),
    [anon_sym_XmlPort] = ACTIONS(2551),
    [anon_sym_enum] = ACTIONS(2551),
    [anon_sym_ENUM] = ACTIONS(2551),
    [anon_sym_Enum] = ACTIONS(2551),
    [anon_sym_eNUM] = ACTIONS(2551),
    [anon_sym_eNum] = ACTIONS(2551),
    [anon_sym_ENum] = ACTIONS(2551),
    [sym_quoted_identifier] = ACTIONS(2553),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2553),
    [sym_integer] = ACTIONS(2551),
    [sym_continue_as_identifier] = ACTIONS(2553),
    [sym_preproc_open] = ACTIONS(2553),
    [sym_end_keyword] = ACTIONS(2553),
  },
  [STATE(1212)] = {
    [sym_identifier] = ACTIONS(2539),
    [anon_sym_SEMI] = ACTIONS(2541),
    [anon_sym_DOT] = ACTIONS(2539),
    [anon_sym_EQ] = ACTIONS(2541),
    [anon_sym_COMMA] = ACTIONS(2541),
    [anon_sym_DASH] = ACTIONS(2539),
    [aux_sym_boolean_token1] = ACTIONS(2539),
    [aux_sym_boolean_token2] = ACTIONS(2539),
    [sym_decimal] = ACTIONS(2539),
    [anon_sym_LPAREN] = ACTIONS(2541),
    [anon_sym_DOT_DOT] = ACTIONS(2541),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2539),
    [anon_sym_STAR] = ACTIONS(2539),
    [anon_sym_LBRACK] = ACTIONS(2541),
    [aux_sym_record_type_token1] = ACTIONS(2539),
    [aux_sym_basic_type_token21] = ACTIONS(2539),
    [aux_sym_basic_type_token22] = ACTIONS(2539),
    [aux_sym_basic_type_token48] = ACTIONS(2539),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2539),
    [anon_sym_POUNDif] = ACTIONS(2541),
    [anon_sym_POUNDIF] = ACTIONS(2541),
    [anon_sym_POUNDIf] = ACTIONS(2541),
    [anon_sym_not] = ACTIONS(2539),
    [anon_sym_NOT] = ACTIONS(2539),
    [anon_sym_Not] = ACTIONS(2539),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2541),
    [aux_sym__expression_token1] = ACTIONS(2541),
    [aux_sym__expression_token2] = ACTIONS(2539),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2539),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2539),
    [anon_sym_SLASH] = ACTIONS(2539),
    [anon_sym_div] = ACTIONS(2539),
    [anon_sym_DIV] = ACTIONS(2539),
    [anon_sym_Div] = ACTIONS(2539),
    [anon_sym_mod] = ACTIONS(2539),
    [anon_sym_MOD] = ACTIONS(2539),
    [anon_sym_Mod] = ACTIONS(2539),
    [anon_sym_PLUS] = ACTIONS(2539),
    [anon_sym_GT_EQ] = ACTIONS(2541),
    [anon_sym_LT_EQ] = ACTIONS(2541),
    [anon_sym_GT] = ACTIONS(2539),
    [anon_sym_LT] = ACTIONS(2539),
    [anon_sym_LT_GT] = ACTIONS(2541),
    [anon_sym_and] = ACTIONS(2539),
    [anon_sym_AND] = ACTIONS(2539),
    [anon_sym_And] = ACTIONS(2539),
    [anon_sym_or] = ACTIONS(2539),
    [anon_sym_OR] = ACTIONS(2539),
    [anon_sym_Or] = ACTIONS(2539),
    [anon_sym_xor] = ACTIONS(2539),
    [anon_sym_XOR] = ACTIONS(2539),
    [anon_sym_Xor] = ACTIONS(2539),
    [anon_sym_QMARK] = ACTIONS(2541),
    [sym_datetime_literal] = ACTIONS(2541),
    [sym_date_literal] = ACTIONS(2539),
    [sym_time_literal] = ACTIONS(2539),
    [sym_biginteger_literal] = ACTIONS(2541),
    [anon_sym_if] = ACTIONS(2539),
    [anon_sym_IF] = ACTIONS(2539),
    [anon_sym_If] = ACTIONS(2539),
    [anon_sym_else] = ACTIONS(2539),
    [anon_sym_ELSE] = ACTIONS(2539),
    [anon_sym_Else] = ACTIONS(2539),
    [anon_sym_case] = ACTIONS(2539),
    [anon_sym_CASE] = ACTIONS(2539),
    [anon_sym_Case] = ACTIONS(2539),
    [anon_sym_for] = ACTIONS(2539),
    [anon_sym_FOR] = ACTIONS(2539),
    [anon_sym_For] = ACTIONS(2539),
    [anon_sym_foreach] = ACTIONS(2539),
    [anon_sym_FOREACH] = ACTIONS(2539),
    [anon_sym_Foreach] = ACTIONS(2539),
    [anon_sym_while] = ACTIONS(2539),
    [anon_sym_WHILE] = ACTIONS(2539),
    [anon_sym_While] = ACTIONS(2539),
    [anon_sym_repeat] = ACTIONS(2539),
    [anon_sym_REPEAT] = ACTIONS(2539),
    [anon_sym_Repeat] = ACTIONS(2539),
    [anon_sym_exit] = ACTIONS(2539),
    [anon_sym_EXIT] = ACTIONS(2539),
    [anon_sym_Exit] = ACTIONS(2539),
    [anon_sym_continue] = ACTIONS(2539),
    [anon_sym_CONTINUE] = ACTIONS(2539),
    [anon_sym_Continue] = ACTIONS(2539),
    [anon_sym_break] = ACTIONS(2539),
    [anon_sym_BREAK] = ACTIONS(2539),
    [anon_sym_Break] = ACTIONS(2539),
    [anon_sym_with] = ACTIONS(2539),
    [anon_sym_WITH] = ACTIONS(2539),
    [anon_sym_With] = ACTIONS(2539),
    [sym_asserterror_keyword] = ACTIONS(2541),
    [anon_sym_in] = ACTIONS(2539),
    [anon_sym_IN] = ACTIONS(2539),
    [anon_sym_In] = ACTIONS(2539),
    [sym_page_keyword] = ACTIONS(2539),
    [anon_sym_codeunit] = ACTIONS(2539),
    [anon_sym_CODEUNIT] = ACTIONS(2539),
    [anon_sym_Codeunit] = ACTIONS(2539),
    [anon_sym_CodeUnit] = ACTIONS(2539),
    [anon_sym_COdeunit] = ACTIONS(2539),
    [anon_sym_codeUnit] = ACTIONS(2539),
    [sym_report_keyword] = ACTIONS(2539),
    [sym_query_keyword] = ACTIONS(2539),
    [anon_sym_xmlport] = ACTIONS(2539),
    [anon_sym_XMLPORT] = ACTIONS(2539),
    [anon_sym_Xmlport] = ACTIONS(2539),
    [anon_sym_XMLport] = ACTIONS(2539),
    [anon_sym_XMLPort] = ACTIONS(2539),
    [anon_sym_XmlPort] = ACTIONS(2539),
    [anon_sym_enum] = ACTIONS(2539),
    [anon_sym_ENUM] = ACTIONS(2539),
    [anon_sym_Enum] = ACTIONS(2539),
    [anon_sym_eNUM] = ACTIONS(2539),
    [anon_sym_eNum] = ACTIONS(2539),
    [anon_sym_ENum] = ACTIONS(2539),
    [sym_quoted_identifier] = ACTIONS(2541),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2541),
    [sym_integer] = ACTIONS(2539),
    [sym_continue_as_identifier] = ACTIONS(2541),
    [sym_preproc_open] = ACTIONS(2541),
    [sym_end_keyword] = ACTIONS(2541),
  },
  [STATE(1213)] = {
    [sym_identifier] = ACTIONS(2565),
    [anon_sym_SEMI] = ACTIONS(2567),
    [anon_sym_DOT] = ACTIONS(2565),
    [anon_sym_EQ] = ACTIONS(2567),
    [anon_sym_DASH] = ACTIONS(2565),
    [aux_sym_boolean_token1] = ACTIONS(2565),
    [aux_sym_boolean_token2] = ACTIONS(2565),
    [sym_decimal] = ACTIONS(2565),
    [anon_sym_LPAREN] = ACTIONS(2567),
    [anon_sym_DOT_DOT] = ACTIONS(2567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2565),
    [anon_sym_STAR] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2567),
    [aux_sym_record_type_token1] = ACTIONS(2565),
    [aux_sym_basic_type_token21] = ACTIONS(2565),
    [aux_sym_basic_type_token22] = ACTIONS(2565),
    [aux_sym_basic_type_token48] = ACTIONS(2565),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_POUNDif] = ACTIONS(2567),
    [anon_sym_POUNDIF] = ACTIONS(2567),
    [anon_sym_POUNDIf] = ACTIONS(2567),
    [anon_sym_not] = ACTIONS(2565),
    [anon_sym_NOT] = ACTIONS(2565),
    [anon_sym_Not] = ACTIONS(2565),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2567),
    [aux_sym__expression_token1] = ACTIONS(2567),
    [aux_sym__expression_token2] = ACTIONS(2565),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2565),
    [anon_sym_SLASH] = ACTIONS(2565),
    [anon_sym_div] = ACTIONS(2565),
    [anon_sym_DIV] = ACTIONS(2565),
    [anon_sym_Div] = ACTIONS(2565),
    [anon_sym_mod] = ACTIONS(2565),
    [anon_sym_MOD] = ACTIONS(2565),
    [anon_sym_Mod] = ACTIONS(2565),
    [anon_sym_PLUS] = ACTIONS(2565),
    [anon_sym_GT_EQ] = ACTIONS(2567),
    [anon_sym_LT_EQ] = ACTIONS(2567),
    [anon_sym_GT] = ACTIONS(2565),
    [anon_sym_LT] = ACTIONS(2565),
    [anon_sym_LT_GT] = ACTIONS(2567),
    [anon_sym_and] = ACTIONS(2565),
    [anon_sym_AND] = ACTIONS(2565),
    [anon_sym_And] = ACTIONS(2565),
    [anon_sym_or] = ACTIONS(2565),
    [anon_sym_OR] = ACTIONS(2565),
    [anon_sym_Or] = ACTIONS(2565),
    [anon_sym_xor] = ACTIONS(2565),
    [anon_sym_XOR] = ACTIONS(2565),
    [anon_sym_Xor] = ACTIONS(2565),
    [anon_sym_QMARK] = ACTIONS(2567),
    [sym_datetime_literal] = ACTIONS(2567),
    [sym_date_literal] = ACTIONS(2565),
    [sym_time_literal] = ACTIONS(2565),
    [sym_biginteger_literal] = ACTIONS(2567),
    [anon_sym_if] = ACTIONS(2565),
    [anon_sym_IF] = ACTIONS(2565),
    [anon_sym_If] = ACTIONS(2565),
    [anon_sym_else] = ACTIONS(2565),
    [anon_sym_ELSE] = ACTIONS(2565),
    [anon_sym_Else] = ACTIONS(2565),
    [anon_sym_case] = ACTIONS(2565),
    [anon_sym_CASE] = ACTIONS(2565),
    [anon_sym_Case] = ACTIONS(2565),
    [anon_sym_for] = ACTIONS(2565),
    [anon_sym_FOR] = ACTIONS(2565),
    [anon_sym_For] = ACTIONS(2565),
    [anon_sym_foreach] = ACTIONS(2565),
    [anon_sym_FOREACH] = ACTIONS(2565),
    [anon_sym_Foreach] = ACTIONS(2565),
    [anon_sym_while] = ACTIONS(2565),
    [anon_sym_WHILE] = ACTIONS(2565),
    [anon_sym_While] = ACTIONS(2565),
    [anon_sym_repeat] = ACTIONS(2565),
    [anon_sym_REPEAT] = ACTIONS(2565),
    [anon_sym_Repeat] = ACTIONS(2565),
    [anon_sym_exit] = ACTIONS(2565),
    [anon_sym_EXIT] = ACTIONS(2565),
    [anon_sym_Exit] = ACTIONS(2565),
    [anon_sym_continue] = ACTIONS(2565),
    [anon_sym_CONTINUE] = ACTIONS(2565),
    [anon_sym_Continue] = ACTIONS(2565),
    [anon_sym_break] = ACTIONS(2565),
    [anon_sym_BREAK] = ACTIONS(2565),
    [anon_sym_Break] = ACTIONS(2565),
    [anon_sym_with] = ACTIONS(2565),
    [anon_sym_WITH] = ACTIONS(2565),
    [anon_sym_With] = ACTIONS(2565),
    [sym_asserterror_keyword] = ACTIONS(2567),
    [anon_sym_in] = ACTIONS(2565),
    [anon_sym_IN] = ACTIONS(2565),
    [anon_sym_In] = ACTIONS(2565),
    [sym_page_keyword] = ACTIONS(2565),
    [anon_sym_codeunit] = ACTIONS(2565),
    [anon_sym_CODEUNIT] = ACTIONS(2565),
    [anon_sym_Codeunit] = ACTIONS(2565),
    [anon_sym_CodeUnit] = ACTIONS(2565),
    [anon_sym_COdeunit] = ACTIONS(2565),
    [anon_sym_codeUnit] = ACTIONS(2565),
    [sym_report_keyword] = ACTIONS(2565),
    [sym_query_keyword] = ACTIONS(2565),
    [anon_sym_xmlport] = ACTIONS(2565),
    [anon_sym_XMLPORT] = ACTIONS(2565),
    [anon_sym_Xmlport] = ACTIONS(2565),
    [anon_sym_XMLport] = ACTIONS(2565),
    [anon_sym_XMLPort] = ACTIONS(2565),
    [anon_sym_XmlPort] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_ENUM] = ACTIONS(2565),
    [anon_sym_Enum] = ACTIONS(2565),
    [anon_sym_eNUM] = ACTIONS(2565),
    [anon_sym_eNum] = ACTIONS(2565),
    [anon_sym_ENum] = ACTIONS(2565),
    [sym_quoted_identifier] = ACTIONS(2567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2567),
    [sym_integer] = ACTIONS(2565),
    [sym_continue_as_identifier] = ACTIONS(2567),
    [sym_preproc_open] = ACTIONS(2567),
    [sym_end_keyword] = ACTIONS(2567),
  },
  [STATE(1214)] = {
    [sym_identifier] = ACTIONS(2403),
    [anon_sym_SEMI] = ACTIONS(2405),
    [anon_sym_DOT] = ACTIONS(2403),
    [anon_sym_EQ] = ACTIONS(2405),
    [anon_sym_COMMA] = ACTIONS(2405),
    [anon_sym_DASH] = ACTIONS(2403),
    [aux_sym_boolean_token1] = ACTIONS(2403),
    [aux_sym_boolean_token2] = ACTIONS(2403),
    [sym_decimal] = ACTIONS(2403),
    [anon_sym_LPAREN] = ACTIONS(2405),
    [anon_sym_DOT_DOT] = ACTIONS(2405),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2403),
    [anon_sym_STAR] = ACTIONS(2403),
    [anon_sym_LBRACK] = ACTIONS(2405),
    [aux_sym_record_type_token1] = ACTIONS(2403),
    [aux_sym_basic_type_token21] = ACTIONS(2403),
    [aux_sym_basic_type_token22] = ACTIONS(2403),
    [aux_sym_basic_type_token48] = ACTIONS(2403),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2403),
    [anon_sym_POUNDif] = ACTIONS(2405),
    [anon_sym_POUNDIF] = ACTIONS(2405),
    [anon_sym_POUNDIf] = ACTIONS(2405),
    [anon_sym_not] = ACTIONS(2403),
    [anon_sym_NOT] = ACTIONS(2403),
    [anon_sym_Not] = ACTIONS(2403),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2405),
    [aux_sym__expression_token1] = ACTIONS(2405),
    [aux_sym__expression_token2] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2403),
    [anon_sym_SLASH] = ACTIONS(2403),
    [anon_sym_div] = ACTIONS(2403),
    [anon_sym_DIV] = ACTIONS(2403),
    [anon_sym_Div] = ACTIONS(2403),
    [anon_sym_mod] = ACTIONS(2403),
    [anon_sym_MOD] = ACTIONS(2403),
    [anon_sym_Mod] = ACTIONS(2403),
    [anon_sym_PLUS] = ACTIONS(2403),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_LT_GT] = ACTIONS(2405),
    [anon_sym_and] = ACTIONS(2403),
    [anon_sym_AND] = ACTIONS(2403),
    [anon_sym_And] = ACTIONS(2403),
    [anon_sym_or] = ACTIONS(2403),
    [anon_sym_OR] = ACTIONS(2403),
    [anon_sym_Or] = ACTIONS(2403),
    [anon_sym_xor] = ACTIONS(2403),
    [anon_sym_XOR] = ACTIONS(2403),
    [anon_sym_Xor] = ACTIONS(2403),
    [anon_sym_QMARK] = ACTIONS(2405),
    [sym_datetime_literal] = ACTIONS(2405),
    [sym_date_literal] = ACTIONS(2403),
    [sym_time_literal] = ACTIONS(2403),
    [sym_biginteger_literal] = ACTIONS(2405),
    [anon_sym_if] = ACTIONS(2403),
    [anon_sym_IF] = ACTIONS(2403),
    [anon_sym_If] = ACTIONS(2403),
    [anon_sym_else] = ACTIONS(2403),
    [anon_sym_ELSE] = ACTIONS(2403),
    [anon_sym_Else] = ACTIONS(2403),
    [anon_sym_case] = ACTIONS(2403),
    [anon_sym_CASE] = ACTIONS(2403),
    [anon_sym_Case] = ACTIONS(2403),
    [anon_sym_for] = ACTIONS(2403),
    [anon_sym_FOR] = ACTIONS(2403),
    [anon_sym_For] = ACTIONS(2403),
    [anon_sym_foreach] = ACTIONS(2403),
    [anon_sym_FOREACH] = ACTIONS(2403),
    [anon_sym_Foreach] = ACTIONS(2403),
    [anon_sym_while] = ACTIONS(2403),
    [anon_sym_WHILE] = ACTIONS(2403),
    [anon_sym_While] = ACTIONS(2403),
    [anon_sym_repeat] = ACTIONS(2403),
    [anon_sym_REPEAT] = ACTIONS(2403),
    [anon_sym_Repeat] = ACTIONS(2403),
    [anon_sym_exit] = ACTIONS(2403),
    [anon_sym_EXIT] = ACTIONS(2403),
    [anon_sym_Exit] = ACTIONS(2403),
    [anon_sym_continue] = ACTIONS(2403),
    [anon_sym_CONTINUE] = ACTIONS(2403),
    [anon_sym_Continue] = ACTIONS(2403),
    [anon_sym_break] = ACTIONS(2403),
    [anon_sym_BREAK] = ACTIONS(2403),
    [anon_sym_Break] = ACTIONS(2403),
    [anon_sym_with] = ACTIONS(2403),
    [anon_sym_WITH] = ACTIONS(2403),
    [anon_sym_With] = ACTIONS(2403),
    [sym_asserterror_keyword] = ACTIONS(2405),
    [anon_sym_in] = ACTIONS(2403),
    [anon_sym_IN] = ACTIONS(2403),
    [anon_sym_In] = ACTIONS(2403),
    [sym_page_keyword] = ACTIONS(2403),
    [anon_sym_codeunit] = ACTIONS(2403),
    [anon_sym_CODEUNIT] = ACTIONS(2403),
    [anon_sym_Codeunit] = ACTIONS(2403),
    [anon_sym_CodeUnit] = ACTIONS(2403),
    [anon_sym_COdeunit] = ACTIONS(2403),
    [anon_sym_codeUnit] = ACTIONS(2403),
    [sym_report_keyword] = ACTIONS(2403),
    [sym_query_keyword] = ACTIONS(2403),
    [anon_sym_xmlport] = ACTIONS(2403),
    [anon_sym_XMLPORT] = ACTIONS(2403),
    [anon_sym_Xmlport] = ACTIONS(2403),
    [anon_sym_XMLport] = ACTIONS(2403),
    [anon_sym_XMLPort] = ACTIONS(2403),
    [anon_sym_XmlPort] = ACTIONS(2403),
    [anon_sym_enum] = ACTIONS(2403),
    [anon_sym_ENUM] = ACTIONS(2403),
    [anon_sym_Enum] = ACTIONS(2403),
    [anon_sym_eNUM] = ACTIONS(2403),
    [anon_sym_eNum] = ACTIONS(2403),
    [anon_sym_ENum] = ACTIONS(2403),
    [sym_quoted_identifier] = ACTIONS(2405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2405),
    [sym_integer] = ACTIONS(2403),
    [sym_continue_as_identifier] = ACTIONS(2405),
    [sym_preproc_open] = ACTIONS(2405),
    [sym_end_keyword] = ACTIONS(2405),
  },
  [STATE(1215)] = {
    [sym_identifier] = ACTIONS(2529),
    [anon_sym_SEMI] = ACTIONS(2531),
    [anon_sym_DOT] = ACTIONS(2529),
    [anon_sym_EQ] = ACTIONS(2531),
    [anon_sym_COMMA] = ACTIONS(2531),
    [anon_sym_DASH] = ACTIONS(2529),
    [aux_sym_boolean_token1] = ACTIONS(2529),
    [aux_sym_boolean_token2] = ACTIONS(2529),
    [sym_decimal] = ACTIONS(2529),
    [anon_sym_LPAREN] = ACTIONS(2531),
    [anon_sym_DOT_DOT] = ACTIONS(2531),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2529),
    [anon_sym_STAR] = ACTIONS(2529),
    [anon_sym_LBRACK] = ACTIONS(2531),
    [aux_sym_record_type_token1] = ACTIONS(2529),
    [aux_sym_basic_type_token21] = ACTIONS(2529),
    [aux_sym_basic_type_token22] = ACTIONS(2529),
    [aux_sym_basic_type_token48] = ACTIONS(2529),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2529),
    [anon_sym_POUNDif] = ACTIONS(2531),
    [anon_sym_POUNDIF] = ACTIONS(2531),
    [anon_sym_POUNDIf] = ACTIONS(2531),
    [anon_sym_not] = ACTIONS(2529),
    [anon_sym_NOT] = ACTIONS(2529),
    [anon_sym_Not] = ACTIONS(2529),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2531),
    [aux_sym__expression_token1] = ACTIONS(2531),
    [aux_sym__expression_token2] = ACTIONS(2529),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2529),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2529),
    [anon_sym_SLASH] = ACTIONS(2529),
    [anon_sym_div] = ACTIONS(2529),
    [anon_sym_DIV] = ACTIONS(2529),
    [anon_sym_Div] = ACTIONS(2529),
    [anon_sym_mod] = ACTIONS(2529),
    [anon_sym_MOD] = ACTIONS(2529),
    [anon_sym_Mod] = ACTIONS(2529),
    [anon_sym_PLUS] = ACTIONS(2529),
    [anon_sym_GT_EQ] = ACTIONS(2531),
    [anon_sym_LT_EQ] = ACTIONS(2531),
    [anon_sym_GT] = ACTIONS(2529),
    [anon_sym_LT] = ACTIONS(2529),
    [anon_sym_LT_GT] = ACTIONS(2531),
    [anon_sym_and] = ACTIONS(2529),
    [anon_sym_AND] = ACTIONS(2529),
    [anon_sym_And] = ACTIONS(2529),
    [anon_sym_or] = ACTIONS(2529),
    [anon_sym_OR] = ACTIONS(2529),
    [anon_sym_Or] = ACTIONS(2529),
    [anon_sym_xor] = ACTIONS(2529),
    [anon_sym_XOR] = ACTIONS(2529),
    [anon_sym_Xor] = ACTIONS(2529),
    [anon_sym_QMARK] = ACTIONS(2531),
    [sym_datetime_literal] = ACTIONS(2531),
    [sym_date_literal] = ACTIONS(2529),
    [sym_time_literal] = ACTIONS(2529),
    [sym_biginteger_literal] = ACTIONS(2531),
    [anon_sym_if] = ACTIONS(2529),
    [anon_sym_IF] = ACTIONS(2529),
    [anon_sym_If] = ACTIONS(2529),
    [anon_sym_else] = ACTIONS(2529),
    [anon_sym_ELSE] = ACTIONS(2529),
    [anon_sym_Else] = ACTIONS(2529),
    [anon_sym_case] = ACTIONS(2529),
    [anon_sym_CASE] = ACTIONS(2529),
    [anon_sym_Case] = ACTIONS(2529),
    [anon_sym_for] = ACTIONS(2529),
    [anon_sym_FOR] = ACTIONS(2529),
    [anon_sym_For] = ACTIONS(2529),
    [anon_sym_foreach] = ACTIONS(2529),
    [anon_sym_FOREACH] = ACTIONS(2529),
    [anon_sym_Foreach] = ACTIONS(2529),
    [anon_sym_while] = ACTIONS(2529),
    [anon_sym_WHILE] = ACTIONS(2529),
    [anon_sym_While] = ACTIONS(2529),
    [anon_sym_repeat] = ACTIONS(2529),
    [anon_sym_REPEAT] = ACTIONS(2529),
    [anon_sym_Repeat] = ACTIONS(2529),
    [anon_sym_exit] = ACTIONS(2529),
    [anon_sym_EXIT] = ACTIONS(2529),
    [anon_sym_Exit] = ACTIONS(2529),
    [anon_sym_continue] = ACTIONS(2529),
    [anon_sym_CONTINUE] = ACTIONS(2529),
    [anon_sym_Continue] = ACTIONS(2529),
    [anon_sym_break] = ACTIONS(2529),
    [anon_sym_BREAK] = ACTIONS(2529),
    [anon_sym_Break] = ACTIONS(2529),
    [anon_sym_with] = ACTIONS(2529),
    [anon_sym_WITH] = ACTIONS(2529),
    [anon_sym_With] = ACTIONS(2529),
    [sym_asserterror_keyword] = ACTIONS(2531),
    [anon_sym_in] = ACTIONS(2529),
    [anon_sym_IN] = ACTIONS(2529),
    [anon_sym_In] = ACTIONS(2529),
    [sym_page_keyword] = ACTIONS(2529),
    [anon_sym_codeunit] = ACTIONS(2529),
    [anon_sym_CODEUNIT] = ACTIONS(2529),
    [anon_sym_Codeunit] = ACTIONS(2529),
    [anon_sym_CodeUnit] = ACTIONS(2529),
    [anon_sym_COdeunit] = ACTIONS(2529),
    [anon_sym_codeUnit] = ACTIONS(2529),
    [sym_report_keyword] = ACTIONS(2529),
    [sym_query_keyword] = ACTIONS(2529),
    [anon_sym_xmlport] = ACTIONS(2529),
    [anon_sym_XMLPORT] = ACTIONS(2529),
    [anon_sym_Xmlport] = ACTIONS(2529),
    [anon_sym_XMLport] = ACTIONS(2529),
    [anon_sym_XMLPort] = ACTIONS(2529),
    [anon_sym_XmlPort] = ACTIONS(2529),
    [anon_sym_enum] = ACTIONS(2529),
    [anon_sym_ENUM] = ACTIONS(2529),
    [anon_sym_Enum] = ACTIONS(2529),
    [anon_sym_eNUM] = ACTIONS(2529),
    [anon_sym_eNum] = ACTIONS(2529),
    [anon_sym_ENum] = ACTIONS(2529),
    [sym_quoted_identifier] = ACTIONS(2531),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2531),
    [sym_integer] = ACTIONS(2529),
    [sym_continue_as_identifier] = ACTIONS(2531),
    [sym_preproc_open] = ACTIONS(2531),
    [sym_end_keyword] = ACTIONS(2531),
  },
  [STATE(1216)] = {
    [sym_identifier] = ACTIONS(2543),
    [anon_sym_SEMI] = ACTIONS(2545),
    [anon_sym_DOT] = ACTIONS(2543),
    [anon_sym_EQ] = ACTIONS(2545),
    [anon_sym_DASH] = ACTIONS(2543),
    [aux_sym_boolean_token1] = ACTIONS(2543),
    [aux_sym_boolean_token2] = ACTIONS(2543),
    [sym_decimal] = ACTIONS(2543),
    [anon_sym_LPAREN] = ACTIONS(2545),
    [anon_sym_DOT_DOT] = ACTIONS(2545),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2543),
    [anon_sym_STAR] = ACTIONS(2543),
    [anon_sym_LBRACK] = ACTIONS(2545),
    [aux_sym_record_type_token1] = ACTIONS(2543),
    [aux_sym_basic_type_token21] = ACTIONS(2543),
    [aux_sym_basic_type_token22] = ACTIONS(2543),
    [aux_sym_basic_type_token48] = ACTIONS(2543),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2543),
    [anon_sym_COLON_COLON] = ACTIONS(2545),
    [anon_sym_POUNDif] = ACTIONS(2545),
    [anon_sym_POUNDIF] = ACTIONS(2545),
    [anon_sym_POUNDIf] = ACTIONS(2545),
    [anon_sym_not] = ACTIONS(2543),
    [anon_sym_NOT] = ACTIONS(2543),
    [anon_sym_Not] = ACTIONS(2543),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2545),
    [aux_sym__expression_token1] = ACTIONS(2545),
    [aux_sym__expression_token2] = ACTIONS(2543),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2543),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2543),
    [anon_sym_SLASH] = ACTIONS(2543),
    [anon_sym_div] = ACTIONS(2543),
    [anon_sym_DIV] = ACTIONS(2543),
    [anon_sym_Div] = ACTIONS(2543),
    [anon_sym_mod] = ACTIONS(2543),
    [anon_sym_MOD] = ACTIONS(2543),
    [anon_sym_Mod] = ACTIONS(2543),
    [anon_sym_PLUS] = ACTIONS(2543),
    [anon_sym_GT_EQ] = ACTIONS(2545),
    [anon_sym_LT_EQ] = ACTIONS(2545),
    [anon_sym_GT] = ACTIONS(2543),
    [anon_sym_LT] = ACTIONS(2543),
    [anon_sym_LT_GT] = ACTIONS(2545),
    [anon_sym_and] = ACTIONS(2543),
    [anon_sym_AND] = ACTIONS(2543),
    [anon_sym_And] = ACTIONS(2543),
    [anon_sym_or] = ACTIONS(2543),
    [anon_sym_OR] = ACTIONS(2543),
    [anon_sym_Or] = ACTIONS(2543),
    [anon_sym_xor] = ACTIONS(2543),
    [anon_sym_XOR] = ACTIONS(2543),
    [anon_sym_Xor] = ACTIONS(2543),
    [anon_sym_QMARK] = ACTIONS(2545),
    [sym_datetime_literal] = ACTIONS(2545),
    [sym_date_literal] = ACTIONS(2543),
    [sym_time_literal] = ACTIONS(2543),
    [sym_biginteger_literal] = ACTIONS(2545),
    [anon_sym_if] = ACTIONS(2543),
    [anon_sym_IF] = ACTIONS(2543),
    [anon_sym_If] = ACTIONS(2543),
    [anon_sym_else] = ACTIONS(2543),
    [anon_sym_ELSE] = ACTIONS(2543),
    [anon_sym_Else] = ACTIONS(2543),
    [anon_sym_case] = ACTIONS(2543),
    [anon_sym_CASE] = ACTIONS(2543),
    [anon_sym_Case] = ACTIONS(2543),
    [anon_sym_for] = ACTIONS(2543),
    [anon_sym_FOR] = ACTIONS(2543),
    [anon_sym_For] = ACTIONS(2543),
    [anon_sym_foreach] = ACTIONS(2543),
    [anon_sym_FOREACH] = ACTIONS(2543),
    [anon_sym_Foreach] = ACTIONS(2543),
    [anon_sym_while] = ACTIONS(2543),
    [anon_sym_WHILE] = ACTIONS(2543),
    [anon_sym_While] = ACTIONS(2543),
    [anon_sym_repeat] = ACTIONS(2543),
    [anon_sym_REPEAT] = ACTIONS(2543),
    [anon_sym_Repeat] = ACTIONS(2543),
    [anon_sym_exit] = ACTIONS(2543),
    [anon_sym_EXIT] = ACTIONS(2543),
    [anon_sym_Exit] = ACTIONS(2543),
    [anon_sym_continue] = ACTIONS(2543),
    [anon_sym_CONTINUE] = ACTIONS(2543),
    [anon_sym_Continue] = ACTIONS(2543),
    [anon_sym_break] = ACTIONS(2543),
    [anon_sym_BREAK] = ACTIONS(2543),
    [anon_sym_Break] = ACTIONS(2543),
    [anon_sym_with] = ACTIONS(2543),
    [anon_sym_WITH] = ACTIONS(2543),
    [anon_sym_With] = ACTIONS(2543),
    [sym_asserterror_keyword] = ACTIONS(2545),
    [anon_sym_in] = ACTIONS(2543),
    [anon_sym_IN] = ACTIONS(2543),
    [anon_sym_In] = ACTIONS(2543),
    [sym_page_keyword] = ACTIONS(2543),
    [anon_sym_codeunit] = ACTIONS(2543),
    [anon_sym_CODEUNIT] = ACTIONS(2543),
    [anon_sym_Codeunit] = ACTIONS(2543),
    [anon_sym_CodeUnit] = ACTIONS(2543),
    [anon_sym_COdeunit] = ACTIONS(2543),
    [anon_sym_codeUnit] = ACTIONS(2543),
    [sym_report_keyword] = ACTIONS(2543),
    [sym_query_keyword] = ACTIONS(2543),
    [anon_sym_xmlport] = ACTIONS(2543),
    [anon_sym_XMLPORT] = ACTIONS(2543),
    [anon_sym_Xmlport] = ACTIONS(2543),
    [anon_sym_XMLport] = ACTIONS(2543),
    [anon_sym_XMLPort] = ACTIONS(2543),
    [anon_sym_XmlPort] = ACTIONS(2543),
    [anon_sym_enum] = ACTIONS(2543),
    [anon_sym_ENUM] = ACTIONS(2543),
    [anon_sym_Enum] = ACTIONS(2543),
    [anon_sym_eNUM] = ACTIONS(2543),
    [anon_sym_eNum] = ACTIONS(2543),
    [anon_sym_ENum] = ACTIONS(2543),
    [sym_quoted_identifier] = ACTIONS(2545),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2545),
    [sym_integer] = ACTIONS(2543),
    [sym_continue_as_identifier] = ACTIONS(2545),
    [sym_preproc_open] = ACTIONS(2545),
    [sym_end_keyword] = ACTIONS(2545),
  },
  [STATE(1217)] = {
    [sym_identifier] = ACTIONS(2547),
    [anon_sym_SEMI] = ACTIONS(2549),
    [anon_sym_DOT] = ACTIONS(2547),
    [anon_sym_EQ] = ACTIONS(2549),
    [anon_sym_DASH] = ACTIONS(2547),
    [aux_sym_boolean_token1] = ACTIONS(2547),
    [aux_sym_boolean_token2] = ACTIONS(2547),
    [sym_decimal] = ACTIONS(2547),
    [anon_sym_LPAREN] = ACTIONS(2549),
    [anon_sym_DOT_DOT] = ACTIONS(2549),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2547),
    [anon_sym_STAR] = ACTIONS(2547),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [aux_sym_record_type_token1] = ACTIONS(2547),
    [aux_sym_basic_type_token21] = ACTIONS(2547),
    [aux_sym_basic_type_token22] = ACTIONS(2547),
    [aux_sym_basic_type_token48] = ACTIONS(2547),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2547),
    [anon_sym_COLON_COLON] = ACTIONS(2549),
    [anon_sym_POUNDif] = ACTIONS(2549),
    [anon_sym_POUNDIF] = ACTIONS(2549),
    [anon_sym_POUNDIf] = ACTIONS(2549),
    [anon_sym_not] = ACTIONS(2547),
    [anon_sym_NOT] = ACTIONS(2547),
    [anon_sym_Not] = ACTIONS(2547),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2549),
    [aux_sym__expression_token1] = ACTIONS(2549),
    [aux_sym__expression_token2] = ACTIONS(2547),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2547),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2547),
    [anon_sym_SLASH] = ACTIONS(2547),
    [anon_sym_div] = ACTIONS(2547),
    [anon_sym_DIV] = ACTIONS(2547),
    [anon_sym_Div] = ACTIONS(2547),
    [anon_sym_mod] = ACTIONS(2547),
    [anon_sym_MOD] = ACTIONS(2547),
    [anon_sym_Mod] = ACTIONS(2547),
    [anon_sym_PLUS] = ACTIONS(2547),
    [anon_sym_GT_EQ] = ACTIONS(2549),
    [anon_sym_LT_EQ] = ACTIONS(2549),
    [anon_sym_GT] = ACTIONS(2547),
    [anon_sym_LT] = ACTIONS(2547),
    [anon_sym_LT_GT] = ACTIONS(2549),
    [anon_sym_and] = ACTIONS(2547),
    [anon_sym_AND] = ACTIONS(2547),
    [anon_sym_And] = ACTIONS(2547),
    [anon_sym_or] = ACTIONS(2547),
    [anon_sym_OR] = ACTIONS(2547),
    [anon_sym_Or] = ACTIONS(2547),
    [anon_sym_xor] = ACTIONS(2547),
    [anon_sym_XOR] = ACTIONS(2547),
    [anon_sym_Xor] = ACTIONS(2547),
    [anon_sym_QMARK] = ACTIONS(2549),
    [sym_datetime_literal] = ACTIONS(2549),
    [sym_date_literal] = ACTIONS(2547),
    [sym_time_literal] = ACTIONS(2547),
    [sym_biginteger_literal] = ACTIONS(2549),
    [anon_sym_if] = ACTIONS(2547),
    [anon_sym_IF] = ACTIONS(2547),
    [anon_sym_If] = ACTIONS(2547),
    [anon_sym_else] = ACTIONS(2547),
    [anon_sym_ELSE] = ACTIONS(2547),
    [anon_sym_Else] = ACTIONS(2547),
    [anon_sym_case] = ACTIONS(2547),
    [anon_sym_CASE] = ACTIONS(2547),
    [anon_sym_Case] = ACTIONS(2547),
    [anon_sym_for] = ACTIONS(2547),
    [anon_sym_FOR] = ACTIONS(2547),
    [anon_sym_For] = ACTIONS(2547),
    [anon_sym_foreach] = ACTIONS(2547),
    [anon_sym_FOREACH] = ACTIONS(2547),
    [anon_sym_Foreach] = ACTIONS(2547),
    [anon_sym_while] = ACTIONS(2547),
    [anon_sym_WHILE] = ACTIONS(2547),
    [anon_sym_While] = ACTIONS(2547),
    [anon_sym_repeat] = ACTIONS(2547),
    [anon_sym_REPEAT] = ACTIONS(2547),
    [anon_sym_Repeat] = ACTIONS(2547),
    [anon_sym_exit] = ACTIONS(2547),
    [anon_sym_EXIT] = ACTIONS(2547),
    [anon_sym_Exit] = ACTIONS(2547),
    [anon_sym_continue] = ACTIONS(2547),
    [anon_sym_CONTINUE] = ACTIONS(2547),
    [anon_sym_Continue] = ACTIONS(2547),
    [anon_sym_break] = ACTIONS(2547),
    [anon_sym_BREAK] = ACTIONS(2547),
    [anon_sym_Break] = ACTIONS(2547),
    [anon_sym_with] = ACTIONS(2547),
    [anon_sym_WITH] = ACTIONS(2547),
    [anon_sym_With] = ACTIONS(2547),
    [sym_asserterror_keyword] = ACTIONS(2549),
    [anon_sym_in] = ACTIONS(2547),
    [anon_sym_IN] = ACTIONS(2547),
    [anon_sym_In] = ACTIONS(2547),
    [sym_page_keyword] = ACTIONS(2547),
    [anon_sym_codeunit] = ACTIONS(2547),
    [anon_sym_CODEUNIT] = ACTIONS(2547),
    [anon_sym_Codeunit] = ACTIONS(2547),
    [anon_sym_CodeUnit] = ACTIONS(2547),
    [anon_sym_COdeunit] = ACTIONS(2547),
    [anon_sym_codeUnit] = ACTIONS(2547),
    [sym_report_keyword] = ACTIONS(2547),
    [sym_query_keyword] = ACTIONS(2547),
    [anon_sym_xmlport] = ACTIONS(2547),
    [anon_sym_XMLPORT] = ACTIONS(2547),
    [anon_sym_Xmlport] = ACTIONS(2547),
    [anon_sym_XMLport] = ACTIONS(2547),
    [anon_sym_XMLPort] = ACTIONS(2547),
    [anon_sym_XmlPort] = ACTIONS(2547),
    [anon_sym_enum] = ACTIONS(2547),
    [anon_sym_ENUM] = ACTIONS(2547),
    [anon_sym_Enum] = ACTIONS(2547),
    [anon_sym_eNUM] = ACTIONS(2547),
    [anon_sym_eNum] = ACTIONS(2547),
    [anon_sym_ENum] = ACTIONS(2547),
    [sym_quoted_identifier] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2549),
    [sym_integer] = ACTIONS(2547),
    [sym_continue_as_identifier] = ACTIONS(2549),
    [sym_preproc_open] = ACTIONS(2549),
    [sym_end_keyword] = ACTIONS(2549),
  },
  [STATE(1218)] = {
    [sym_identifier] = ACTIONS(2645),
    [anon_sym_SEMI] = ACTIONS(2647),
    [anon_sym_DOT] = ACTIONS(2645),
    [anon_sym_EQ] = ACTIONS(2647),
    [anon_sym_DASH] = ACTIONS(2645),
    [aux_sym_boolean_token1] = ACTIONS(2645),
    [aux_sym_boolean_token2] = ACTIONS(2645),
    [sym_decimal] = ACTIONS(2645),
    [anon_sym_LPAREN] = ACTIONS(2647),
    [anon_sym_DOT_DOT] = ACTIONS(2647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2645),
    [anon_sym_STAR] = ACTIONS(2645),
    [anon_sym_LBRACK] = ACTIONS(2647),
    [aux_sym_record_type_token1] = ACTIONS(2645),
    [aux_sym_basic_type_token21] = ACTIONS(2645),
    [aux_sym_basic_type_token22] = ACTIONS(2645),
    [aux_sym_basic_type_token48] = ACTIONS(2645),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2645),
    [anon_sym_POUNDif] = ACTIONS(2647),
    [anon_sym_POUNDIF] = ACTIONS(2647),
    [anon_sym_POUNDIf] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2645),
    [anon_sym_NOT] = ACTIONS(2645),
    [anon_sym_Not] = ACTIONS(2645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2647),
    [aux_sym__expression_token1] = ACTIONS(2647),
    [aux_sym__expression_token2] = ACTIONS(2645),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2645),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2645),
    [anon_sym_SLASH] = ACTIONS(2645),
    [anon_sym_div] = ACTIONS(2645),
    [anon_sym_DIV] = ACTIONS(2645),
    [anon_sym_Div] = ACTIONS(2645),
    [anon_sym_mod] = ACTIONS(2645),
    [anon_sym_MOD] = ACTIONS(2645),
    [anon_sym_Mod] = ACTIONS(2645),
    [anon_sym_PLUS] = ACTIONS(2645),
    [anon_sym_GT_EQ] = ACTIONS(2647),
    [anon_sym_LT_EQ] = ACTIONS(2647),
    [anon_sym_GT] = ACTIONS(2645),
    [anon_sym_LT] = ACTIONS(2645),
    [anon_sym_LT_GT] = ACTIONS(2647),
    [anon_sym_and] = ACTIONS(2645),
    [anon_sym_AND] = ACTIONS(2645),
    [anon_sym_And] = ACTIONS(2645),
    [anon_sym_or] = ACTIONS(2645),
    [anon_sym_OR] = ACTIONS(2645),
    [anon_sym_Or] = ACTIONS(2645),
    [anon_sym_xor] = ACTIONS(2645),
    [anon_sym_XOR] = ACTIONS(2645),
    [anon_sym_Xor] = ACTIONS(2645),
    [anon_sym_QMARK] = ACTIONS(2647),
    [sym_datetime_literal] = ACTIONS(2647),
    [sym_date_literal] = ACTIONS(2645),
    [sym_time_literal] = ACTIONS(2645),
    [sym_biginteger_literal] = ACTIONS(2647),
    [anon_sym_if] = ACTIONS(2645),
    [anon_sym_IF] = ACTIONS(2645),
    [anon_sym_If] = ACTIONS(2645),
    [anon_sym_else] = ACTIONS(2645),
    [anon_sym_ELSE] = ACTIONS(2645),
    [anon_sym_Else] = ACTIONS(2645),
    [anon_sym_case] = ACTIONS(2645),
    [anon_sym_CASE] = ACTIONS(2645),
    [anon_sym_Case] = ACTIONS(2645),
    [anon_sym_for] = ACTIONS(2645),
    [anon_sym_FOR] = ACTIONS(2645),
    [anon_sym_For] = ACTIONS(2645),
    [anon_sym_foreach] = ACTIONS(2645),
    [anon_sym_FOREACH] = ACTIONS(2645),
    [anon_sym_Foreach] = ACTIONS(2645),
    [anon_sym_while] = ACTIONS(2645),
    [anon_sym_WHILE] = ACTIONS(2645),
    [anon_sym_While] = ACTIONS(2645),
    [anon_sym_repeat] = ACTIONS(2645),
    [anon_sym_REPEAT] = ACTIONS(2645),
    [anon_sym_Repeat] = ACTIONS(2645),
    [anon_sym_exit] = ACTIONS(2645),
    [anon_sym_EXIT] = ACTIONS(2645),
    [anon_sym_Exit] = ACTIONS(2645),
    [anon_sym_continue] = ACTIONS(2645),
    [anon_sym_CONTINUE] = ACTIONS(2645),
    [anon_sym_Continue] = ACTIONS(2645),
    [anon_sym_break] = ACTIONS(2645),
    [anon_sym_BREAK] = ACTIONS(2645),
    [anon_sym_Break] = ACTIONS(2645),
    [anon_sym_with] = ACTIONS(2645),
    [anon_sym_WITH] = ACTIONS(2645),
    [anon_sym_With] = ACTIONS(2645),
    [sym_asserterror_keyword] = ACTIONS(2647),
    [anon_sym_in] = ACTIONS(2645),
    [anon_sym_IN] = ACTIONS(2645),
    [anon_sym_In] = ACTIONS(2645),
    [sym_page_keyword] = ACTIONS(2645),
    [anon_sym_codeunit] = ACTIONS(2645),
    [anon_sym_CODEUNIT] = ACTIONS(2645),
    [anon_sym_Codeunit] = ACTIONS(2645),
    [anon_sym_CodeUnit] = ACTIONS(2645),
    [anon_sym_COdeunit] = ACTIONS(2645),
    [anon_sym_codeUnit] = ACTIONS(2645),
    [sym_report_keyword] = ACTIONS(2645),
    [sym_query_keyword] = ACTIONS(2645),
    [anon_sym_xmlport] = ACTIONS(2645),
    [anon_sym_XMLPORT] = ACTIONS(2645),
    [anon_sym_Xmlport] = ACTIONS(2645),
    [anon_sym_XMLport] = ACTIONS(2645),
    [anon_sym_XMLPort] = ACTIONS(2645),
    [anon_sym_XmlPort] = ACTIONS(2645),
    [anon_sym_enum] = ACTIONS(2645),
    [anon_sym_ENUM] = ACTIONS(2645),
    [anon_sym_Enum] = ACTIONS(2645),
    [anon_sym_eNUM] = ACTIONS(2645),
    [anon_sym_eNum] = ACTIONS(2645),
    [anon_sym_ENum] = ACTIONS(2645),
    [sym_quoted_identifier] = ACTIONS(2647),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2647),
    [sym_integer] = ACTIONS(2645),
    [sym_continue_as_identifier] = ACTIONS(2647),
    [sym_preproc_open] = ACTIONS(2647),
    [sym_end_keyword] = ACTIONS(2647),
  },
  [STATE(1219)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_SEMI] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2593),
    [anon_sym_POUNDif] = ACTIONS(2595),
    [anon_sym_POUNDIF] = ACTIONS(2595),
    [anon_sym_POUNDIf] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_if] = ACTIONS(2593),
    [anon_sym_IF] = ACTIONS(2593),
    [anon_sym_If] = ACTIONS(2593),
    [anon_sym_else] = ACTIONS(2593),
    [anon_sym_ELSE] = ACTIONS(2593),
    [anon_sym_Else] = ACTIONS(2593),
    [anon_sym_case] = ACTIONS(2593),
    [anon_sym_CASE] = ACTIONS(2593),
    [anon_sym_Case] = ACTIONS(2593),
    [anon_sym_for] = ACTIONS(2593),
    [anon_sym_FOR] = ACTIONS(2593),
    [anon_sym_For] = ACTIONS(2593),
    [anon_sym_foreach] = ACTIONS(2593),
    [anon_sym_FOREACH] = ACTIONS(2593),
    [anon_sym_Foreach] = ACTIONS(2593),
    [anon_sym_while] = ACTIONS(2593),
    [anon_sym_WHILE] = ACTIONS(2593),
    [anon_sym_While] = ACTIONS(2593),
    [anon_sym_repeat] = ACTIONS(2593),
    [anon_sym_REPEAT] = ACTIONS(2593),
    [anon_sym_Repeat] = ACTIONS(2593),
    [anon_sym_exit] = ACTIONS(2593),
    [anon_sym_EXIT] = ACTIONS(2593),
    [anon_sym_Exit] = ACTIONS(2593),
    [anon_sym_continue] = ACTIONS(2593),
    [anon_sym_CONTINUE] = ACTIONS(2593),
    [anon_sym_Continue] = ACTIONS(2593),
    [anon_sym_break] = ACTIONS(2593),
    [anon_sym_BREAK] = ACTIONS(2593),
    [anon_sym_Break] = ACTIONS(2593),
    [anon_sym_with] = ACTIONS(2593),
    [anon_sym_WITH] = ACTIONS(2593),
    [anon_sym_With] = ACTIONS(2593),
    [sym_asserterror_keyword] = ACTIONS(2595),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_open] = ACTIONS(2595),
    [sym_end_keyword] = ACTIONS(2595),
  },
  [STATE(1220)] = {
    [sym_identifier] = ACTIONS(2637),
    [anon_sym_SEMI] = ACTIONS(2639),
    [anon_sym_DOT] = ACTIONS(2637),
    [anon_sym_EQ] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [aux_sym_boolean_token1] = ACTIONS(2637),
    [aux_sym_boolean_token2] = ACTIONS(2637),
    [sym_decimal] = ACTIONS(2637),
    [anon_sym_LPAREN] = ACTIONS(2639),
    [anon_sym_DOT_DOT] = ACTIONS(2639),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(2637),
    [anon_sym_LBRACK] = ACTIONS(2639),
    [aux_sym_record_type_token1] = ACTIONS(2637),
    [aux_sym_basic_type_token21] = ACTIONS(2637),
    [aux_sym_basic_type_token22] = ACTIONS(2637),
    [aux_sym_basic_type_token48] = ACTIONS(2637),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2637),
    [anon_sym_POUNDif] = ACTIONS(2639),
    [anon_sym_POUNDIF] = ACTIONS(2639),
    [anon_sym_POUNDIf] = ACTIONS(2639),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_NOT] = ACTIONS(2637),
    [anon_sym_Not] = ACTIONS(2637),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2639),
    [aux_sym__expression_token1] = ACTIONS(2639),
    [aux_sym__expression_token2] = ACTIONS(2637),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2637),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2637),
    [anon_sym_SLASH] = ACTIONS(2637),
    [anon_sym_div] = ACTIONS(2637),
    [anon_sym_DIV] = ACTIONS(2637),
    [anon_sym_Div] = ACTIONS(2637),
    [anon_sym_mod] = ACTIONS(2637),
    [anon_sym_MOD] = ACTIONS(2637),
    [anon_sym_Mod] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_GT_EQ] = ACTIONS(2639),
    [anon_sym_LT_EQ] = ACTIONS(2639),
    [anon_sym_GT] = ACTIONS(2637),
    [anon_sym_LT] = ACTIONS(2637),
    [anon_sym_LT_GT] = ACTIONS(2639),
    [anon_sym_and] = ACTIONS(2637),
    [anon_sym_AND] = ACTIONS(2637),
    [anon_sym_And] = ACTIONS(2637),
    [anon_sym_or] = ACTIONS(2637),
    [anon_sym_OR] = ACTIONS(2637),
    [anon_sym_Or] = ACTIONS(2637),
    [anon_sym_xor] = ACTIONS(2637),
    [anon_sym_XOR] = ACTIONS(2637),
    [anon_sym_Xor] = ACTIONS(2637),
    [anon_sym_QMARK] = ACTIONS(2639),
    [sym_datetime_literal] = ACTIONS(2639),
    [sym_date_literal] = ACTIONS(2637),
    [sym_time_literal] = ACTIONS(2637),
    [sym_biginteger_literal] = ACTIONS(2639),
    [anon_sym_if] = ACTIONS(2637),
    [anon_sym_IF] = ACTIONS(2637),
    [anon_sym_If] = ACTIONS(2637),
    [anon_sym_else] = ACTIONS(2637),
    [anon_sym_ELSE] = ACTIONS(2637),
    [anon_sym_Else] = ACTIONS(2637),
    [anon_sym_case] = ACTIONS(2637),
    [anon_sym_CASE] = ACTIONS(2637),
    [anon_sym_Case] = ACTIONS(2637),
    [anon_sym_for] = ACTIONS(2637),
    [anon_sym_FOR] = ACTIONS(2637),
    [anon_sym_For] = ACTIONS(2637),
    [anon_sym_foreach] = ACTIONS(2637),
    [anon_sym_FOREACH] = ACTIONS(2637),
    [anon_sym_Foreach] = ACTIONS(2637),
    [anon_sym_while] = ACTIONS(2637),
    [anon_sym_WHILE] = ACTIONS(2637),
    [anon_sym_While] = ACTIONS(2637),
    [anon_sym_repeat] = ACTIONS(2637),
    [anon_sym_REPEAT] = ACTIONS(2637),
    [anon_sym_Repeat] = ACTIONS(2637),
    [anon_sym_exit] = ACTIONS(2637),
    [anon_sym_EXIT] = ACTIONS(2637),
    [anon_sym_Exit] = ACTIONS(2637),
    [anon_sym_continue] = ACTIONS(2637),
    [anon_sym_CONTINUE] = ACTIONS(2637),
    [anon_sym_Continue] = ACTIONS(2637),
    [anon_sym_break] = ACTIONS(2637),
    [anon_sym_BREAK] = ACTIONS(2637),
    [anon_sym_Break] = ACTIONS(2637),
    [anon_sym_with] = ACTIONS(2637),
    [anon_sym_WITH] = ACTIONS(2637),
    [anon_sym_With] = ACTIONS(2637),
    [sym_asserterror_keyword] = ACTIONS(2639),
    [anon_sym_in] = ACTIONS(2637),
    [anon_sym_IN] = ACTIONS(2637),
    [anon_sym_In] = ACTIONS(2637),
    [sym_page_keyword] = ACTIONS(2637),
    [anon_sym_codeunit] = ACTIONS(2637),
    [anon_sym_CODEUNIT] = ACTIONS(2637),
    [anon_sym_Codeunit] = ACTIONS(2637),
    [anon_sym_CodeUnit] = ACTIONS(2637),
    [anon_sym_COdeunit] = ACTIONS(2637),
    [anon_sym_codeUnit] = ACTIONS(2637),
    [sym_report_keyword] = ACTIONS(2637),
    [sym_query_keyword] = ACTIONS(2637),
    [anon_sym_xmlport] = ACTIONS(2637),
    [anon_sym_XMLPORT] = ACTIONS(2637),
    [anon_sym_Xmlport] = ACTIONS(2637),
    [anon_sym_XMLport] = ACTIONS(2637),
    [anon_sym_XMLPort] = ACTIONS(2637),
    [anon_sym_XmlPort] = ACTIONS(2637),
    [anon_sym_enum] = ACTIONS(2637),
    [anon_sym_ENUM] = ACTIONS(2637),
    [anon_sym_Enum] = ACTIONS(2637),
    [anon_sym_eNUM] = ACTIONS(2637),
    [anon_sym_eNum] = ACTIONS(2637),
    [anon_sym_ENum] = ACTIONS(2637),
    [sym_quoted_identifier] = ACTIONS(2639),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2639),
    [sym_integer] = ACTIONS(2637),
    [sym_continue_as_identifier] = ACTIONS(2639),
    [sym_preproc_open] = ACTIONS(2639),
    [sym_end_keyword] = ACTIONS(2639),
  },
  [STATE(1221)] = {
    [sym_identifier] = ACTIONS(2597),
    [anon_sym_SEMI] = ACTIONS(2599),
    [anon_sym_DOT] = ACTIONS(2597),
    [anon_sym_EQ] = ACTIONS(2599),
    [anon_sym_DASH] = ACTIONS(2597),
    [aux_sym_boolean_token1] = ACTIONS(2597),
    [aux_sym_boolean_token2] = ACTIONS(2597),
    [sym_decimal] = ACTIONS(2597),
    [anon_sym_LPAREN] = ACTIONS(2599),
    [anon_sym_DOT_DOT] = ACTIONS(2599),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2597),
    [anon_sym_STAR] = ACTIONS(2597),
    [anon_sym_LBRACK] = ACTIONS(2599),
    [aux_sym_record_type_token1] = ACTIONS(2597),
    [aux_sym_basic_type_token21] = ACTIONS(2597),
    [aux_sym_basic_type_token22] = ACTIONS(2597),
    [aux_sym_basic_type_token48] = ACTIONS(2597),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2597),
    [anon_sym_POUNDif] = ACTIONS(2599),
    [anon_sym_POUNDIF] = ACTIONS(2599),
    [anon_sym_POUNDIf] = ACTIONS(2599),
    [anon_sym_not] = ACTIONS(2597),
    [anon_sym_NOT] = ACTIONS(2597),
    [anon_sym_Not] = ACTIONS(2597),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2599),
    [aux_sym__expression_token1] = ACTIONS(2599),
    [aux_sym__expression_token2] = ACTIONS(2597),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2597),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2597),
    [anon_sym_SLASH] = ACTIONS(2597),
    [anon_sym_div] = ACTIONS(2597),
    [anon_sym_DIV] = ACTIONS(2597),
    [anon_sym_Div] = ACTIONS(2597),
    [anon_sym_mod] = ACTIONS(2597),
    [anon_sym_MOD] = ACTIONS(2597),
    [anon_sym_Mod] = ACTIONS(2597),
    [anon_sym_PLUS] = ACTIONS(2597),
    [anon_sym_GT_EQ] = ACTIONS(2599),
    [anon_sym_LT_EQ] = ACTIONS(2599),
    [anon_sym_GT] = ACTIONS(2597),
    [anon_sym_LT] = ACTIONS(2597),
    [anon_sym_LT_GT] = ACTIONS(2599),
    [anon_sym_and] = ACTIONS(2597),
    [anon_sym_AND] = ACTIONS(2597),
    [anon_sym_And] = ACTIONS(2597),
    [anon_sym_or] = ACTIONS(2597),
    [anon_sym_OR] = ACTIONS(2597),
    [anon_sym_Or] = ACTIONS(2597),
    [anon_sym_xor] = ACTIONS(2597),
    [anon_sym_XOR] = ACTIONS(2597),
    [anon_sym_Xor] = ACTIONS(2597),
    [anon_sym_QMARK] = ACTIONS(2599),
    [sym_datetime_literal] = ACTIONS(2599),
    [sym_date_literal] = ACTIONS(2597),
    [sym_time_literal] = ACTIONS(2597),
    [sym_biginteger_literal] = ACTIONS(2599),
    [anon_sym_if] = ACTIONS(2597),
    [anon_sym_IF] = ACTIONS(2597),
    [anon_sym_If] = ACTIONS(2597),
    [anon_sym_else] = ACTIONS(2597),
    [anon_sym_ELSE] = ACTIONS(2597),
    [anon_sym_Else] = ACTIONS(2597),
    [anon_sym_case] = ACTIONS(2597),
    [anon_sym_CASE] = ACTIONS(2597),
    [anon_sym_Case] = ACTIONS(2597),
    [anon_sym_for] = ACTIONS(2597),
    [anon_sym_FOR] = ACTIONS(2597),
    [anon_sym_For] = ACTIONS(2597),
    [anon_sym_foreach] = ACTIONS(2597),
    [anon_sym_FOREACH] = ACTIONS(2597),
    [anon_sym_Foreach] = ACTIONS(2597),
    [anon_sym_while] = ACTIONS(2597),
    [anon_sym_WHILE] = ACTIONS(2597),
    [anon_sym_While] = ACTIONS(2597),
    [anon_sym_repeat] = ACTIONS(2597),
    [anon_sym_REPEAT] = ACTIONS(2597),
    [anon_sym_Repeat] = ACTIONS(2597),
    [anon_sym_exit] = ACTIONS(2597),
    [anon_sym_EXIT] = ACTIONS(2597),
    [anon_sym_Exit] = ACTIONS(2597),
    [anon_sym_continue] = ACTIONS(2597),
    [anon_sym_CONTINUE] = ACTIONS(2597),
    [anon_sym_Continue] = ACTIONS(2597),
    [anon_sym_break] = ACTIONS(2597),
    [anon_sym_BREAK] = ACTIONS(2597),
    [anon_sym_Break] = ACTIONS(2597),
    [anon_sym_with] = ACTIONS(2597),
    [anon_sym_WITH] = ACTIONS(2597),
    [anon_sym_With] = ACTIONS(2597),
    [sym_asserterror_keyword] = ACTIONS(2599),
    [anon_sym_in] = ACTIONS(2597),
    [anon_sym_IN] = ACTIONS(2597),
    [anon_sym_In] = ACTIONS(2597),
    [sym_page_keyword] = ACTIONS(2597),
    [anon_sym_codeunit] = ACTIONS(2597),
    [anon_sym_CODEUNIT] = ACTIONS(2597),
    [anon_sym_Codeunit] = ACTIONS(2597),
    [anon_sym_CodeUnit] = ACTIONS(2597),
    [anon_sym_COdeunit] = ACTIONS(2597),
    [anon_sym_codeUnit] = ACTIONS(2597),
    [sym_report_keyword] = ACTIONS(2597),
    [sym_query_keyword] = ACTIONS(2597),
    [anon_sym_xmlport] = ACTIONS(2597),
    [anon_sym_XMLPORT] = ACTIONS(2597),
    [anon_sym_Xmlport] = ACTIONS(2597),
    [anon_sym_XMLport] = ACTIONS(2597),
    [anon_sym_XMLPort] = ACTIONS(2597),
    [anon_sym_XmlPort] = ACTIONS(2597),
    [anon_sym_enum] = ACTIONS(2597),
    [anon_sym_ENUM] = ACTIONS(2597),
    [anon_sym_Enum] = ACTIONS(2597),
    [anon_sym_eNUM] = ACTIONS(2597),
    [anon_sym_eNum] = ACTIONS(2597),
    [anon_sym_ENum] = ACTIONS(2597),
    [sym_quoted_identifier] = ACTIONS(2599),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2599),
    [sym_integer] = ACTIONS(2597),
    [sym_continue_as_identifier] = ACTIONS(2599),
    [sym_preproc_open] = ACTIONS(2599),
    [sym_end_keyword] = ACTIONS(2599),
  },
  [STATE(1222)] = {
    [sym_identifier] = ACTIONS(2601),
    [anon_sym_SEMI] = ACTIONS(2603),
    [anon_sym_DOT] = ACTIONS(2601),
    [anon_sym_EQ] = ACTIONS(2603),
    [anon_sym_DASH] = ACTIONS(2601),
    [aux_sym_boolean_token1] = ACTIONS(2601),
    [aux_sym_boolean_token2] = ACTIONS(2601),
    [sym_decimal] = ACTIONS(2601),
    [anon_sym_LPAREN] = ACTIONS(2603),
    [anon_sym_DOT_DOT] = ACTIONS(2603),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2601),
    [anon_sym_STAR] = ACTIONS(2601),
    [anon_sym_LBRACK] = ACTIONS(2603),
    [aux_sym_record_type_token1] = ACTIONS(2601),
    [aux_sym_basic_type_token21] = ACTIONS(2601),
    [aux_sym_basic_type_token22] = ACTIONS(2601),
    [aux_sym_basic_type_token48] = ACTIONS(2601),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2601),
    [anon_sym_POUNDif] = ACTIONS(2603),
    [anon_sym_POUNDIF] = ACTIONS(2603),
    [anon_sym_POUNDIf] = ACTIONS(2603),
    [anon_sym_not] = ACTIONS(2601),
    [anon_sym_NOT] = ACTIONS(2601),
    [anon_sym_Not] = ACTIONS(2601),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2603),
    [aux_sym__expression_token1] = ACTIONS(2603),
    [aux_sym__expression_token2] = ACTIONS(2601),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2601),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2601),
    [anon_sym_SLASH] = ACTIONS(2601),
    [anon_sym_div] = ACTIONS(2601),
    [anon_sym_DIV] = ACTIONS(2601),
    [anon_sym_Div] = ACTIONS(2601),
    [anon_sym_mod] = ACTIONS(2601),
    [anon_sym_MOD] = ACTIONS(2601),
    [anon_sym_Mod] = ACTIONS(2601),
    [anon_sym_PLUS] = ACTIONS(2601),
    [anon_sym_GT_EQ] = ACTIONS(2603),
    [anon_sym_LT_EQ] = ACTIONS(2603),
    [anon_sym_GT] = ACTIONS(2601),
    [anon_sym_LT] = ACTIONS(2601),
    [anon_sym_LT_GT] = ACTIONS(2603),
    [anon_sym_and] = ACTIONS(2601),
    [anon_sym_AND] = ACTIONS(2601),
    [anon_sym_And] = ACTIONS(2601),
    [anon_sym_or] = ACTIONS(2601),
    [anon_sym_OR] = ACTIONS(2601),
    [anon_sym_Or] = ACTIONS(2601),
    [anon_sym_xor] = ACTIONS(2601),
    [anon_sym_XOR] = ACTIONS(2601),
    [anon_sym_Xor] = ACTIONS(2601),
    [anon_sym_QMARK] = ACTIONS(2603),
    [sym_datetime_literal] = ACTIONS(2603),
    [sym_date_literal] = ACTIONS(2601),
    [sym_time_literal] = ACTIONS(2601),
    [sym_biginteger_literal] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2601),
    [anon_sym_IF] = ACTIONS(2601),
    [anon_sym_If] = ACTIONS(2601),
    [anon_sym_else] = ACTIONS(2601),
    [anon_sym_ELSE] = ACTIONS(2601),
    [anon_sym_Else] = ACTIONS(2601),
    [anon_sym_case] = ACTIONS(2601),
    [anon_sym_CASE] = ACTIONS(2601),
    [anon_sym_Case] = ACTIONS(2601),
    [anon_sym_for] = ACTIONS(2601),
    [anon_sym_FOR] = ACTIONS(2601),
    [anon_sym_For] = ACTIONS(2601),
    [anon_sym_foreach] = ACTIONS(2601),
    [anon_sym_FOREACH] = ACTIONS(2601),
    [anon_sym_Foreach] = ACTIONS(2601),
    [anon_sym_while] = ACTIONS(2601),
    [anon_sym_WHILE] = ACTIONS(2601),
    [anon_sym_While] = ACTIONS(2601),
    [anon_sym_repeat] = ACTIONS(2601),
    [anon_sym_REPEAT] = ACTIONS(2601),
    [anon_sym_Repeat] = ACTIONS(2601),
    [anon_sym_exit] = ACTIONS(2601),
    [anon_sym_EXIT] = ACTIONS(2601),
    [anon_sym_Exit] = ACTIONS(2601),
    [anon_sym_continue] = ACTIONS(2601),
    [anon_sym_CONTINUE] = ACTIONS(2601),
    [anon_sym_Continue] = ACTIONS(2601),
    [anon_sym_break] = ACTIONS(2601),
    [anon_sym_BREAK] = ACTIONS(2601),
    [anon_sym_Break] = ACTIONS(2601),
    [anon_sym_with] = ACTIONS(2601),
    [anon_sym_WITH] = ACTIONS(2601),
    [anon_sym_With] = ACTIONS(2601),
    [sym_asserterror_keyword] = ACTIONS(2603),
    [anon_sym_in] = ACTIONS(2601),
    [anon_sym_IN] = ACTIONS(2601),
    [anon_sym_In] = ACTIONS(2601),
    [sym_page_keyword] = ACTIONS(2601),
    [anon_sym_codeunit] = ACTIONS(2601),
    [anon_sym_CODEUNIT] = ACTIONS(2601),
    [anon_sym_Codeunit] = ACTIONS(2601),
    [anon_sym_CodeUnit] = ACTIONS(2601),
    [anon_sym_COdeunit] = ACTIONS(2601),
    [anon_sym_codeUnit] = ACTIONS(2601),
    [sym_report_keyword] = ACTIONS(2601),
    [sym_query_keyword] = ACTIONS(2601),
    [anon_sym_xmlport] = ACTIONS(2601),
    [anon_sym_XMLPORT] = ACTIONS(2601),
    [anon_sym_Xmlport] = ACTIONS(2601),
    [anon_sym_XMLport] = ACTIONS(2601),
    [anon_sym_XMLPort] = ACTIONS(2601),
    [anon_sym_XmlPort] = ACTIONS(2601),
    [anon_sym_enum] = ACTIONS(2601),
    [anon_sym_ENUM] = ACTIONS(2601),
    [anon_sym_Enum] = ACTIONS(2601),
    [anon_sym_eNUM] = ACTIONS(2601),
    [anon_sym_eNum] = ACTIONS(2601),
    [anon_sym_ENum] = ACTIONS(2601),
    [sym_quoted_identifier] = ACTIONS(2603),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2603),
    [sym_integer] = ACTIONS(2601),
    [sym_continue_as_identifier] = ACTIONS(2603),
    [sym_preproc_open] = ACTIONS(2603),
    [sym_end_keyword] = ACTIONS(2603),
  },
  [STATE(1223)] = {
    [sym_identifier] = ACTIONS(2609),
    [anon_sym_SEMI] = ACTIONS(2611),
    [anon_sym_DOT] = ACTIONS(2609),
    [anon_sym_EQ] = ACTIONS(2611),
    [anon_sym_DASH] = ACTIONS(2609),
    [aux_sym_boolean_token1] = ACTIONS(2609),
    [aux_sym_boolean_token2] = ACTIONS(2609),
    [sym_decimal] = ACTIONS(2609),
    [anon_sym_LPAREN] = ACTIONS(2611),
    [anon_sym_DOT_DOT] = ACTIONS(2611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2609),
    [anon_sym_STAR] = ACTIONS(2609),
    [anon_sym_LBRACK] = ACTIONS(2611),
    [aux_sym_record_type_token1] = ACTIONS(2609),
    [aux_sym_basic_type_token21] = ACTIONS(2609),
    [aux_sym_basic_type_token22] = ACTIONS(2609),
    [aux_sym_basic_type_token48] = ACTIONS(2609),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2609),
    [anon_sym_POUNDif] = ACTIONS(2611),
    [anon_sym_POUNDIF] = ACTIONS(2611),
    [anon_sym_POUNDIf] = ACTIONS(2611),
    [anon_sym_not] = ACTIONS(2609),
    [anon_sym_NOT] = ACTIONS(2609),
    [anon_sym_Not] = ACTIONS(2609),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2611),
    [aux_sym__expression_token1] = ACTIONS(2611),
    [aux_sym__expression_token2] = ACTIONS(2609),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2609),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2609),
    [anon_sym_SLASH] = ACTIONS(2609),
    [anon_sym_div] = ACTIONS(2609),
    [anon_sym_DIV] = ACTIONS(2609),
    [anon_sym_Div] = ACTIONS(2609),
    [anon_sym_mod] = ACTIONS(2609),
    [anon_sym_MOD] = ACTIONS(2609),
    [anon_sym_Mod] = ACTIONS(2609),
    [anon_sym_PLUS] = ACTIONS(2609),
    [anon_sym_GT_EQ] = ACTIONS(2611),
    [anon_sym_LT_EQ] = ACTIONS(2611),
    [anon_sym_GT] = ACTIONS(2609),
    [anon_sym_LT] = ACTIONS(2609),
    [anon_sym_LT_GT] = ACTIONS(2611),
    [anon_sym_and] = ACTIONS(2609),
    [anon_sym_AND] = ACTIONS(2609),
    [anon_sym_And] = ACTIONS(2609),
    [anon_sym_or] = ACTIONS(2609),
    [anon_sym_OR] = ACTIONS(2609),
    [anon_sym_Or] = ACTIONS(2609),
    [anon_sym_xor] = ACTIONS(2609),
    [anon_sym_XOR] = ACTIONS(2609),
    [anon_sym_Xor] = ACTIONS(2609),
    [anon_sym_QMARK] = ACTIONS(2611),
    [sym_datetime_literal] = ACTIONS(2611),
    [sym_date_literal] = ACTIONS(2609),
    [sym_time_literal] = ACTIONS(2609),
    [sym_biginteger_literal] = ACTIONS(2611),
    [anon_sym_if] = ACTIONS(2609),
    [anon_sym_IF] = ACTIONS(2609),
    [anon_sym_If] = ACTIONS(2609),
    [anon_sym_else] = ACTIONS(2609),
    [anon_sym_ELSE] = ACTIONS(2609),
    [anon_sym_Else] = ACTIONS(2609),
    [anon_sym_case] = ACTIONS(2609),
    [anon_sym_CASE] = ACTIONS(2609),
    [anon_sym_Case] = ACTIONS(2609),
    [anon_sym_for] = ACTIONS(2609),
    [anon_sym_FOR] = ACTIONS(2609),
    [anon_sym_For] = ACTIONS(2609),
    [anon_sym_foreach] = ACTIONS(2609),
    [anon_sym_FOREACH] = ACTIONS(2609),
    [anon_sym_Foreach] = ACTIONS(2609),
    [anon_sym_while] = ACTIONS(2609),
    [anon_sym_WHILE] = ACTIONS(2609),
    [anon_sym_While] = ACTIONS(2609),
    [anon_sym_repeat] = ACTIONS(2609),
    [anon_sym_REPEAT] = ACTIONS(2609),
    [anon_sym_Repeat] = ACTIONS(2609),
    [anon_sym_exit] = ACTIONS(2609),
    [anon_sym_EXIT] = ACTIONS(2609),
    [anon_sym_Exit] = ACTIONS(2609),
    [anon_sym_continue] = ACTIONS(2609),
    [anon_sym_CONTINUE] = ACTIONS(2609),
    [anon_sym_Continue] = ACTIONS(2609),
    [anon_sym_break] = ACTIONS(2609),
    [anon_sym_BREAK] = ACTIONS(2609),
    [anon_sym_Break] = ACTIONS(2609),
    [anon_sym_with] = ACTIONS(2609),
    [anon_sym_WITH] = ACTIONS(2609),
    [anon_sym_With] = ACTIONS(2609),
    [sym_asserterror_keyword] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(2609),
    [anon_sym_IN] = ACTIONS(2609),
    [anon_sym_In] = ACTIONS(2609),
    [sym_page_keyword] = ACTIONS(2609),
    [anon_sym_codeunit] = ACTIONS(2609),
    [anon_sym_CODEUNIT] = ACTIONS(2609),
    [anon_sym_Codeunit] = ACTIONS(2609),
    [anon_sym_CodeUnit] = ACTIONS(2609),
    [anon_sym_COdeunit] = ACTIONS(2609),
    [anon_sym_codeUnit] = ACTIONS(2609),
    [sym_report_keyword] = ACTIONS(2609),
    [sym_query_keyword] = ACTIONS(2609),
    [anon_sym_xmlport] = ACTIONS(2609),
    [anon_sym_XMLPORT] = ACTIONS(2609),
    [anon_sym_Xmlport] = ACTIONS(2609),
    [anon_sym_XMLport] = ACTIONS(2609),
    [anon_sym_XMLPort] = ACTIONS(2609),
    [anon_sym_XmlPort] = ACTIONS(2609),
    [anon_sym_enum] = ACTIONS(2609),
    [anon_sym_ENUM] = ACTIONS(2609),
    [anon_sym_Enum] = ACTIONS(2609),
    [anon_sym_eNUM] = ACTIONS(2609),
    [anon_sym_eNum] = ACTIONS(2609),
    [anon_sym_ENum] = ACTIONS(2609),
    [sym_quoted_identifier] = ACTIONS(2611),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2611),
    [sym_integer] = ACTIONS(2609),
    [sym_continue_as_identifier] = ACTIONS(2611),
    [sym_preproc_open] = ACTIONS(2611),
    [sym_end_keyword] = ACTIONS(2611),
  },
  [STATE(1224)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_SEMI] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2593),
    [anon_sym_POUNDif] = ACTIONS(2595),
    [anon_sym_POUNDIF] = ACTIONS(2595),
    [anon_sym_POUNDIf] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_if] = ACTIONS(2593),
    [anon_sym_IF] = ACTIONS(2593),
    [anon_sym_If] = ACTIONS(2593),
    [anon_sym_else] = ACTIONS(2593),
    [anon_sym_ELSE] = ACTIONS(2593),
    [anon_sym_Else] = ACTIONS(2593),
    [anon_sym_case] = ACTIONS(2593),
    [anon_sym_CASE] = ACTIONS(2593),
    [anon_sym_Case] = ACTIONS(2593),
    [anon_sym_for] = ACTIONS(2593),
    [anon_sym_FOR] = ACTIONS(2593),
    [anon_sym_For] = ACTIONS(2593),
    [anon_sym_foreach] = ACTIONS(2593),
    [anon_sym_FOREACH] = ACTIONS(2593),
    [anon_sym_Foreach] = ACTIONS(2593),
    [anon_sym_while] = ACTIONS(2593),
    [anon_sym_WHILE] = ACTIONS(2593),
    [anon_sym_While] = ACTIONS(2593),
    [anon_sym_repeat] = ACTIONS(2593),
    [anon_sym_REPEAT] = ACTIONS(2593),
    [anon_sym_Repeat] = ACTIONS(2593),
    [anon_sym_exit] = ACTIONS(2593),
    [anon_sym_EXIT] = ACTIONS(2593),
    [anon_sym_Exit] = ACTIONS(2593),
    [anon_sym_continue] = ACTIONS(2593),
    [anon_sym_CONTINUE] = ACTIONS(2593),
    [anon_sym_Continue] = ACTIONS(2593),
    [anon_sym_break] = ACTIONS(2593),
    [anon_sym_BREAK] = ACTIONS(2593),
    [anon_sym_Break] = ACTIONS(2593),
    [anon_sym_with] = ACTIONS(2593),
    [anon_sym_WITH] = ACTIONS(2593),
    [anon_sym_With] = ACTIONS(2593),
    [sym_asserterror_keyword] = ACTIONS(2595),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_open] = ACTIONS(2595),
    [sym_end_keyword] = ACTIONS(2595),
  },
  [STATE(1225)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_SEMI] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2593),
    [anon_sym_POUNDif] = ACTIONS(2595),
    [anon_sym_POUNDIF] = ACTIONS(2595),
    [anon_sym_POUNDIf] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_if] = ACTIONS(2593),
    [anon_sym_IF] = ACTIONS(2593),
    [anon_sym_If] = ACTIONS(2593),
    [anon_sym_else] = ACTIONS(2593),
    [anon_sym_ELSE] = ACTIONS(2593),
    [anon_sym_Else] = ACTIONS(2593),
    [anon_sym_case] = ACTIONS(2593),
    [anon_sym_CASE] = ACTIONS(2593),
    [anon_sym_Case] = ACTIONS(2593),
    [anon_sym_for] = ACTIONS(2593),
    [anon_sym_FOR] = ACTIONS(2593),
    [anon_sym_For] = ACTIONS(2593),
    [anon_sym_foreach] = ACTIONS(2593),
    [anon_sym_FOREACH] = ACTIONS(2593),
    [anon_sym_Foreach] = ACTIONS(2593),
    [anon_sym_while] = ACTIONS(2593),
    [anon_sym_WHILE] = ACTIONS(2593),
    [anon_sym_While] = ACTIONS(2593),
    [anon_sym_repeat] = ACTIONS(2593),
    [anon_sym_REPEAT] = ACTIONS(2593),
    [anon_sym_Repeat] = ACTIONS(2593),
    [anon_sym_exit] = ACTIONS(2593),
    [anon_sym_EXIT] = ACTIONS(2593),
    [anon_sym_Exit] = ACTIONS(2593),
    [anon_sym_continue] = ACTIONS(2593),
    [anon_sym_CONTINUE] = ACTIONS(2593),
    [anon_sym_Continue] = ACTIONS(2593),
    [anon_sym_break] = ACTIONS(2593),
    [anon_sym_BREAK] = ACTIONS(2593),
    [anon_sym_Break] = ACTIONS(2593),
    [anon_sym_with] = ACTIONS(2593),
    [anon_sym_WITH] = ACTIONS(2593),
    [anon_sym_With] = ACTIONS(2593),
    [sym_asserterror_keyword] = ACTIONS(2595),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_open] = ACTIONS(2595),
    [sym_end_keyword] = ACTIONS(2595),
  },
  [STATE(1226)] = {
    [sym_identifier] = ACTIONS(2613),
    [anon_sym_SEMI] = ACTIONS(2615),
    [anon_sym_DOT] = ACTIONS(2613),
    [anon_sym_EQ] = ACTIONS(2615),
    [anon_sym_DASH] = ACTIONS(2613),
    [aux_sym_boolean_token1] = ACTIONS(2613),
    [aux_sym_boolean_token2] = ACTIONS(2613),
    [sym_decimal] = ACTIONS(2613),
    [anon_sym_LPAREN] = ACTIONS(2615),
    [anon_sym_DOT_DOT] = ACTIONS(2615),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2613),
    [anon_sym_STAR] = ACTIONS(2613),
    [anon_sym_LBRACK] = ACTIONS(2837),
    [aux_sym_record_type_token1] = ACTIONS(2613),
    [aux_sym_basic_type_token21] = ACTIONS(2613),
    [aux_sym_basic_type_token22] = ACTIONS(2613),
    [aux_sym_basic_type_token48] = ACTIONS(2613),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2613),
    [anon_sym_POUNDif] = ACTIONS(2615),
    [anon_sym_POUNDIF] = ACTIONS(2615),
    [anon_sym_POUNDIf] = ACTIONS(2615),
    [anon_sym_not] = ACTIONS(2613),
    [anon_sym_NOT] = ACTIONS(2613),
    [anon_sym_Not] = ACTIONS(2613),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2615),
    [aux_sym__expression_token1] = ACTIONS(2615),
    [aux_sym__expression_token2] = ACTIONS(2613),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2613),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2613),
    [anon_sym_SLASH] = ACTIONS(2613),
    [anon_sym_div] = ACTIONS(2613),
    [anon_sym_DIV] = ACTIONS(2613),
    [anon_sym_Div] = ACTIONS(2613),
    [anon_sym_mod] = ACTIONS(2613),
    [anon_sym_MOD] = ACTIONS(2613),
    [anon_sym_Mod] = ACTIONS(2613),
    [anon_sym_PLUS] = ACTIONS(2613),
    [anon_sym_GT_EQ] = ACTIONS(2615),
    [anon_sym_LT_EQ] = ACTIONS(2615),
    [anon_sym_GT] = ACTIONS(2613),
    [anon_sym_LT] = ACTIONS(2613),
    [anon_sym_LT_GT] = ACTIONS(2615),
    [anon_sym_and] = ACTIONS(2613),
    [anon_sym_AND] = ACTIONS(2613),
    [anon_sym_And] = ACTIONS(2613),
    [anon_sym_or] = ACTIONS(2613),
    [anon_sym_OR] = ACTIONS(2613),
    [anon_sym_Or] = ACTIONS(2613),
    [anon_sym_xor] = ACTIONS(2613),
    [anon_sym_XOR] = ACTIONS(2613),
    [anon_sym_Xor] = ACTIONS(2613),
    [anon_sym_QMARK] = ACTIONS(2615),
    [sym_datetime_literal] = ACTIONS(2615),
    [sym_date_literal] = ACTIONS(2613),
    [sym_time_literal] = ACTIONS(2613),
    [sym_biginteger_literal] = ACTIONS(2615),
    [anon_sym_if] = ACTIONS(2613),
    [anon_sym_IF] = ACTIONS(2613),
    [anon_sym_If] = ACTIONS(2613),
    [anon_sym_else] = ACTIONS(2613),
    [anon_sym_ELSE] = ACTIONS(2613),
    [anon_sym_Else] = ACTIONS(2613),
    [anon_sym_case] = ACTIONS(2613),
    [anon_sym_CASE] = ACTIONS(2613),
    [anon_sym_Case] = ACTIONS(2613),
    [anon_sym_for] = ACTIONS(2613),
    [anon_sym_FOR] = ACTIONS(2613),
    [anon_sym_For] = ACTIONS(2613),
    [anon_sym_foreach] = ACTIONS(2613),
    [anon_sym_FOREACH] = ACTIONS(2613),
    [anon_sym_Foreach] = ACTIONS(2613),
    [anon_sym_while] = ACTIONS(2613),
    [anon_sym_WHILE] = ACTIONS(2613),
    [anon_sym_While] = ACTIONS(2613),
    [anon_sym_repeat] = ACTIONS(2613),
    [anon_sym_REPEAT] = ACTIONS(2613),
    [anon_sym_Repeat] = ACTIONS(2613),
    [anon_sym_exit] = ACTIONS(2613),
    [anon_sym_EXIT] = ACTIONS(2613),
    [anon_sym_Exit] = ACTIONS(2613),
    [anon_sym_continue] = ACTIONS(2613),
    [anon_sym_CONTINUE] = ACTIONS(2613),
    [anon_sym_Continue] = ACTIONS(2613),
    [anon_sym_break] = ACTIONS(2613),
    [anon_sym_BREAK] = ACTIONS(2613),
    [anon_sym_Break] = ACTIONS(2613),
    [anon_sym_with] = ACTIONS(2613),
    [anon_sym_WITH] = ACTIONS(2613),
    [anon_sym_With] = ACTIONS(2613),
    [sym_asserterror_keyword] = ACTIONS(2615),
    [anon_sym_in] = ACTIONS(2613),
    [anon_sym_IN] = ACTIONS(2613),
    [anon_sym_In] = ACTIONS(2613),
    [sym_page_keyword] = ACTIONS(2613),
    [anon_sym_codeunit] = ACTIONS(2613),
    [anon_sym_CODEUNIT] = ACTIONS(2613),
    [anon_sym_Codeunit] = ACTIONS(2613),
    [anon_sym_CodeUnit] = ACTIONS(2613),
    [anon_sym_COdeunit] = ACTIONS(2613),
    [anon_sym_codeUnit] = ACTIONS(2613),
    [sym_report_keyword] = ACTIONS(2613),
    [sym_query_keyword] = ACTIONS(2613),
    [anon_sym_xmlport] = ACTIONS(2613),
    [anon_sym_XMLPORT] = ACTIONS(2613),
    [anon_sym_Xmlport] = ACTIONS(2613),
    [anon_sym_XMLport] = ACTIONS(2613),
    [anon_sym_XMLPort] = ACTIONS(2613),
    [anon_sym_XmlPort] = ACTIONS(2613),
    [anon_sym_enum] = ACTIONS(2613),
    [anon_sym_ENUM] = ACTIONS(2613),
    [anon_sym_Enum] = ACTIONS(2613),
    [anon_sym_eNUM] = ACTIONS(2613),
    [anon_sym_eNum] = ACTIONS(2613),
    [anon_sym_ENum] = ACTIONS(2613),
    [sym_quoted_identifier] = ACTIONS(2615),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2615),
    [sym_integer] = ACTIONS(2613),
    [sym_continue_as_identifier] = ACTIONS(2615),
    [sym_preproc_open] = ACTIONS(2615),
    [sym_end_keyword] = ACTIONS(2615),
  },
  [STATE(1227)] = {
    [sym_identifier] = ACTIONS(2605),
    [anon_sym_SEMI] = ACTIONS(2607),
    [anon_sym_DOT] = ACTIONS(2605),
    [anon_sym_EQ] = ACTIONS(2607),
    [anon_sym_DASH] = ACTIONS(2605),
    [aux_sym_boolean_token1] = ACTIONS(2605),
    [aux_sym_boolean_token2] = ACTIONS(2605),
    [sym_decimal] = ACTIONS(2605),
    [anon_sym_LPAREN] = ACTIONS(2607),
    [anon_sym_DOT_DOT] = ACTIONS(2607),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2605),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_LBRACK] = ACTIONS(2607),
    [aux_sym_record_type_token1] = ACTIONS(2605),
    [aux_sym_basic_type_token21] = ACTIONS(2605),
    [aux_sym_basic_type_token22] = ACTIONS(2605),
    [aux_sym_basic_type_token48] = ACTIONS(2605),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2605),
    [anon_sym_POUNDif] = ACTIONS(2607),
    [anon_sym_POUNDIF] = ACTIONS(2607),
    [anon_sym_POUNDIf] = ACTIONS(2607),
    [anon_sym_not] = ACTIONS(2605),
    [anon_sym_NOT] = ACTIONS(2605),
    [anon_sym_Not] = ACTIONS(2605),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2607),
    [aux_sym__expression_token1] = ACTIONS(2607),
    [aux_sym__expression_token2] = ACTIONS(2605),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2605),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2605),
    [anon_sym_SLASH] = ACTIONS(2605),
    [anon_sym_div] = ACTIONS(2605),
    [anon_sym_DIV] = ACTIONS(2605),
    [anon_sym_Div] = ACTIONS(2605),
    [anon_sym_mod] = ACTIONS(2605),
    [anon_sym_MOD] = ACTIONS(2605),
    [anon_sym_Mod] = ACTIONS(2605),
    [anon_sym_PLUS] = ACTIONS(2605),
    [anon_sym_GT_EQ] = ACTIONS(2607),
    [anon_sym_LT_EQ] = ACTIONS(2607),
    [anon_sym_GT] = ACTIONS(2605),
    [anon_sym_LT] = ACTIONS(2605),
    [anon_sym_LT_GT] = ACTIONS(2607),
    [anon_sym_and] = ACTIONS(2605),
    [anon_sym_AND] = ACTIONS(2605),
    [anon_sym_And] = ACTIONS(2605),
    [anon_sym_or] = ACTIONS(2605),
    [anon_sym_OR] = ACTIONS(2605),
    [anon_sym_Or] = ACTIONS(2605),
    [anon_sym_xor] = ACTIONS(2605),
    [anon_sym_XOR] = ACTIONS(2605),
    [anon_sym_Xor] = ACTIONS(2605),
    [anon_sym_QMARK] = ACTIONS(2607),
    [sym_datetime_literal] = ACTIONS(2607),
    [sym_date_literal] = ACTIONS(2605),
    [sym_time_literal] = ACTIONS(2605),
    [sym_biginteger_literal] = ACTIONS(2607),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_IF] = ACTIONS(2605),
    [anon_sym_If] = ACTIONS(2605),
    [anon_sym_else] = ACTIONS(2605),
    [anon_sym_ELSE] = ACTIONS(2605),
    [anon_sym_Else] = ACTIONS(2605),
    [anon_sym_case] = ACTIONS(2605),
    [anon_sym_CASE] = ACTIONS(2605),
    [anon_sym_Case] = ACTIONS(2605),
    [anon_sym_for] = ACTIONS(2605),
    [anon_sym_FOR] = ACTIONS(2605),
    [anon_sym_For] = ACTIONS(2605),
    [anon_sym_foreach] = ACTIONS(2605),
    [anon_sym_FOREACH] = ACTIONS(2605),
    [anon_sym_Foreach] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(2605),
    [anon_sym_WHILE] = ACTIONS(2605),
    [anon_sym_While] = ACTIONS(2605),
    [anon_sym_repeat] = ACTIONS(2605),
    [anon_sym_REPEAT] = ACTIONS(2605),
    [anon_sym_Repeat] = ACTIONS(2605),
    [anon_sym_exit] = ACTIONS(2605),
    [anon_sym_EXIT] = ACTIONS(2605),
    [anon_sym_Exit] = ACTIONS(2605),
    [anon_sym_continue] = ACTIONS(2605),
    [anon_sym_CONTINUE] = ACTIONS(2605),
    [anon_sym_Continue] = ACTIONS(2605),
    [anon_sym_break] = ACTIONS(2605),
    [anon_sym_BREAK] = ACTIONS(2605),
    [anon_sym_Break] = ACTIONS(2605),
    [anon_sym_with] = ACTIONS(2605),
    [anon_sym_WITH] = ACTIONS(2605),
    [anon_sym_With] = ACTIONS(2605),
    [sym_asserterror_keyword] = ACTIONS(2607),
    [anon_sym_in] = ACTIONS(2605),
    [anon_sym_IN] = ACTIONS(2605),
    [anon_sym_In] = ACTIONS(2605),
    [sym_page_keyword] = ACTIONS(2605),
    [anon_sym_codeunit] = ACTIONS(2605),
    [anon_sym_CODEUNIT] = ACTIONS(2605),
    [anon_sym_Codeunit] = ACTIONS(2605),
    [anon_sym_CodeUnit] = ACTIONS(2605),
    [anon_sym_COdeunit] = ACTIONS(2605),
    [anon_sym_codeUnit] = ACTIONS(2605),
    [sym_report_keyword] = ACTIONS(2605),
    [sym_query_keyword] = ACTIONS(2605),
    [anon_sym_xmlport] = ACTIONS(2605),
    [anon_sym_XMLPORT] = ACTIONS(2605),
    [anon_sym_Xmlport] = ACTIONS(2605),
    [anon_sym_XMLport] = ACTIONS(2605),
    [anon_sym_XMLPort] = ACTIONS(2605),
    [anon_sym_XmlPort] = ACTIONS(2605),
    [anon_sym_enum] = ACTIONS(2605),
    [anon_sym_ENUM] = ACTIONS(2605),
    [anon_sym_Enum] = ACTIONS(2605),
    [anon_sym_eNUM] = ACTIONS(2605),
    [anon_sym_eNum] = ACTIONS(2605),
    [anon_sym_ENum] = ACTIONS(2605),
    [sym_quoted_identifier] = ACTIONS(2607),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2607),
    [sym_integer] = ACTIONS(2605),
    [sym_continue_as_identifier] = ACTIONS(2607),
    [sym_preproc_open] = ACTIONS(2607),
    [sym_end_keyword] = ACTIONS(2607),
  },
  [STATE(1228)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2585),
    [anon_sym_POUNDif] = ACTIONS(2587),
    [anon_sym_POUNDIF] = ACTIONS(2587),
    [anon_sym_POUNDIf] = ACTIONS(2587),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_IF] = ACTIONS(2585),
    [anon_sym_If] = ACTIONS(2585),
    [anon_sym_else] = ACTIONS(2585),
    [anon_sym_ELSE] = ACTIONS(2585),
    [anon_sym_Else] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_CASE] = ACTIONS(2585),
    [anon_sym_Case] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_FOR] = ACTIONS(2585),
    [anon_sym_For] = ACTIONS(2585),
    [anon_sym_foreach] = ACTIONS(2585),
    [anon_sym_FOREACH] = ACTIONS(2585),
    [anon_sym_Foreach] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_WHILE] = ACTIONS(2585),
    [anon_sym_While] = ACTIONS(2585),
    [anon_sym_repeat] = ACTIONS(2585),
    [anon_sym_REPEAT] = ACTIONS(2585),
    [anon_sym_Repeat] = ACTIONS(2585),
    [anon_sym_exit] = ACTIONS(2585),
    [anon_sym_EXIT] = ACTIONS(2585),
    [anon_sym_Exit] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_CONTINUE] = ACTIONS(2585),
    [anon_sym_Continue] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_BREAK] = ACTIONS(2585),
    [anon_sym_Break] = ACTIONS(2585),
    [anon_sym_with] = ACTIONS(2585),
    [anon_sym_WITH] = ACTIONS(2585),
    [anon_sym_With] = ACTIONS(2585),
    [sym_asserterror_keyword] = ACTIONS(2587),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_open] = ACTIONS(2587),
    [sym_end_keyword] = ACTIONS(2587),
  },
  [STATE(1229)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2585),
    [anon_sym_POUNDif] = ACTIONS(2587),
    [anon_sym_POUNDIF] = ACTIONS(2587),
    [anon_sym_POUNDIf] = ACTIONS(2587),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_IF] = ACTIONS(2585),
    [anon_sym_If] = ACTIONS(2585),
    [anon_sym_else] = ACTIONS(2585),
    [anon_sym_ELSE] = ACTIONS(2585),
    [anon_sym_Else] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_CASE] = ACTIONS(2585),
    [anon_sym_Case] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_FOR] = ACTIONS(2585),
    [anon_sym_For] = ACTIONS(2585),
    [anon_sym_foreach] = ACTIONS(2585),
    [anon_sym_FOREACH] = ACTIONS(2585),
    [anon_sym_Foreach] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_WHILE] = ACTIONS(2585),
    [anon_sym_While] = ACTIONS(2585),
    [anon_sym_repeat] = ACTIONS(2585),
    [anon_sym_REPEAT] = ACTIONS(2585),
    [anon_sym_Repeat] = ACTIONS(2585),
    [anon_sym_exit] = ACTIONS(2585),
    [anon_sym_EXIT] = ACTIONS(2585),
    [anon_sym_Exit] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_CONTINUE] = ACTIONS(2585),
    [anon_sym_Continue] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_BREAK] = ACTIONS(2585),
    [anon_sym_Break] = ACTIONS(2585),
    [anon_sym_with] = ACTIONS(2585),
    [anon_sym_WITH] = ACTIONS(2585),
    [anon_sym_With] = ACTIONS(2585),
    [sym_asserterror_keyword] = ACTIONS(2587),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_open] = ACTIONS(2587),
    [sym_end_keyword] = ACTIONS(2587),
  },
  [STATE(1230)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2585),
    [anon_sym_POUNDif] = ACTIONS(2587),
    [anon_sym_POUNDIF] = ACTIONS(2587),
    [anon_sym_POUNDIf] = ACTIONS(2587),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_IF] = ACTIONS(2585),
    [anon_sym_If] = ACTIONS(2585),
    [anon_sym_else] = ACTIONS(2585),
    [anon_sym_ELSE] = ACTIONS(2585),
    [anon_sym_Else] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_CASE] = ACTIONS(2585),
    [anon_sym_Case] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_FOR] = ACTIONS(2585),
    [anon_sym_For] = ACTIONS(2585),
    [anon_sym_foreach] = ACTIONS(2585),
    [anon_sym_FOREACH] = ACTIONS(2585),
    [anon_sym_Foreach] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_WHILE] = ACTIONS(2585),
    [anon_sym_While] = ACTIONS(2585),
    [anon_sym_repeat] = ACTIONS(2585),
    [anon_sym_REPEAT] = ACTIONS(2585),
    [anon_sym_Repeat] = ACTIONS(2585),
    [anon_sym_exit] = ACTIONS(2585),
    [anon_sym_EXIT] = ACTIONS(2585),
    [anon_sym_Exit] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_CONTINUE] = ACTIONS(2585),
    [anon_sym_Continue] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_BREAK] = ACTIONS(2585),
    [anon_sym_Break] = ACTIONS(2585),
    [anon_sym_with] = ACTIONS(2585),
    [anon_sym_WITH] = ACTIONS(2585),
    [anon_sym_With] = ACTIONS(2585),
    [sym_asserterror_keyword] = ACTIONS(2587),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_open] = ACTIONS(2587),
    [sym_end_keyword] = ACTIONS(2587),
  },
  [STATE(1231)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_SEMI] = ACTIONS(2591),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2589),
    [anon_sym_POUNDif] = ACTIONS(2591),
    [anon_sym_POUNDIF] = ACTIONS(2591),
    [anon_sym_POUNDIf] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_if] = ACTIONS(2589),
    [anon_sym_IF] = ACTIONS(2589),
    [anon_sym_If] = ACTIONS(2589),
    [anon_sym_else] = ACTIONS(2589),
    [anon_sym_ELSE] = ACTIONS(2589),
    [anon_sym_Else] = ACTIONS(2589),
    [anon_sym_case] = ACTIONS(2589),
    [anon_sym_CASE] = ACTIONS(2589),
    [anon_sym_Case] = ACTIONS(2589),
    [anon_sym_for] = ACTIONS(2589),
    [anon_sym_FOR] = ACTIONS(2589),
    [anon_sym_For] = ACTIONS(2589),
    [anon_sym_foreach] = ACTIONS(2589),
    [anon_sym_FOREACH] = ACTIONS(2589),
    [anon_sym_Foreach] = ACTIONS(2589),
    [anon_sym_while] = ACTIONS(2589),
    [anon_sym_WHILE] = ACTIONS(2589),
    [anon_sym_While] = ACTIONS(2589),
    [anon_sym_repeat] = ACTIONS(2589),
    [anon_sym_REPEAT] = ACTIONS(2589),
    [anon_sym_Repeat] = ACTIONS(2589),
    [anon_sym_exit] = ACTIONS(2589),
    [anon_sym_EXIT] = ACTIONS(2589),
    [anon_sym_Exit] = ACTIONS(2589),
    [anon_sym_continue] = ACTIONS(2589),
    [anon_sym_CONTINUE] = ACTIONS(2589),
    [anon_sym_Continue] = ACTIONS(2589),
    [anon_sym_break] = ACTIONS(2589),
    [anon_sym_BREAK] = ACTIONS(2589),
    [anon_sym_Break] = ACTIONS(2589),
    [anon_sym_with] = ACTIONS(2589),
    [anon_sym_WITH] = ACTIONS(2589),
    [anon_sym_With] = ACTIONS(2589),
    [sym_asserterror_keyword] = ACTIONS(2591),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_open] = ACTIONS(2591),
    [sym_end_keyword] = ACTIONS(2591),
  },
  [STATE(1232)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_SEMI] = ACTIONS(2591),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2589),
    [anon_sym_POUNDif] = ACTIONS(2591),
    [anon_sym_POUNDIF] = ACTIONS(2591),
    [anon_sym_POUNDIf] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_if] = ACTIONS(2589),
    [anon_sym_IF] = ACTIONS(2589),
    [anon_sym_If] = ACTIONS(2589),
    [anon_sym_else] = ACTIONS(2589),
    [anon_sym_ELSE] = ACTIONS(2589),
    [anon_sym_Else] = ACTIONS(2589),
    [anon_sym_case] = ACTIONS(2589),
    [anon_sym_CASE] = ACTIONS(2589),
    [anon_sym_Case] = ACTIONS(2589),
    [anon_sym_for] = ACTIONS(2589),
    [anon_sym_FOR] = ACTIONS(2589),
    [anon_sym_For] = ACTIONS(2589),
    [anon_sym_foreach] = ACTIONS(2589),
    [anon_sym_FOREACH] = ACTIONS(2589),
    [anon_sym_Foreach] = ACTIONS(2589),
    [anon_sym_while] = ACTIONS(2589),
    [anon_sym_WHILE] = ACTIONS(2589),
    [anon_sym_While] = ACTIONS(2589),
    [anon_sym_repeat] = ACTIONS(2589),
    [anon_sym_REPEAT] = ACTIONS(2589),
    [anon_sym_Repeat] = ACTIONS(2589),
    [anon_sym_exit] = ACTIONS(2589),
    [anon_sym_EXIT] = ACTIONS(2589),
    [anon_sym_Exit] = ACTIONS(2589),
    [anon_sym_continue] = ACTIONS(2589),
    [anon_sym_CONTINUE] = ACTIONS(2589),
    [anon_sym_Continue] = ACTIONS(2589),
    [anon_sym_break] = ACTIONS(2589),
    [anon_sym_BREAK] = ACTIONS(2589),
    [anon_sym_Break] = ACTIONS(2589),
    [anon_sym_with] = ACTIONS(2589),
    [anon_sym_WITH] = ACTIONS(2589),
    [anon_sym_With] = ACTIONS(2589),
    [sym_asserterror_keyword] = ACTIONS(2591),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_open] = ACTIONS(2591),
    [sym_end_keyword] = ACTIONS(2591),
  },
  [STATE(1233)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_SEMI] = ACTIONS(2591),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2589),
    [anon_sym_POUNDif] = ACTIONS(2591),
    [anon_sym_POUNDIF] = ACTIONS(2591),
    [anon_sym_POUNDIf] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_if] = ACTIONS(2589),
    [anon_sym_IF] = ACTIONS(2589),
    [anon_sym_If] = ACTIONS(2589),
    [anon_sym_else] = ACTIONS(2589),
    [anon_sym_ELSE] = ACTIONS(2589),
    [anon_sym_Else] = ACTIONS(2589),
    [anon_sym_case] = ACTIONS(2589),
    [anon_sym_CASE] = ACTIONS(2589),
    [anon_sym_Case] = ACTIONS(2589),
    [anon_sym_for] = ACTIONS(2589),
    [anon_sym_FOR] = ACTIONS(2589),
    [anon_sym_For] = ACTIONS(2589),
    [anon_sym_foreach] = ACTIONS(2589),
    [anon_sym_FOREACH] = ACTIONS(2589),
    [anon_sym_Foreach] = ACTIONS(2589),
    [anon_sym_while] = ACTIONS(2589),
    [anon_sym_WHILE] = ACTIONS(2589),
    [anon_sym_While] = ACTIONS(2589),
    [anon_sym_repeat] = ACTIONS(2589),
    [anon_sym_REPEAT] = ACTIONS(2589),
    [anon_sym_Repeat] = ACTIONS(2589),
    [anon_sym_exit] = ACTIONS(2589),
    [anon_sym_EXIT] = ACTIONS(2589),
    [anon_sym_Exit] = ACTIONS(2589),
    [anon_sym_continue] = ACTIONS(2589),
    [anon_sym_CONTINUE] = ACTIONS(2589),
    [anon_sym_Continue] = ACTIONS(2589),
    [anon_sym_break] = ACTIONS(2589),
    [anon_sym_BREAK] = ACTIONS(2589),
    [anon_sym_Break] = ACTIONS(2589),
    [anon_sym_with] = ACTIONS(2589),
    [anon_sym_WITH] = ACTIONS(2589),
    [anon_sym_With] = ACTIONS(2589),
    [sym_asserterror_keyword] = ACTIONS(2591),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_open] = ACTIONS(2591),
    [sym_end_keyword] = ACTIONS(2591),
  },
  [STATE(1234)] = {
    [sym_identifier] = ACTIONS(2649),
    [anon_sym_SEMI] = ACTIONS(2651),
    [anon_sym_DOT] = ACTIONS(2649),
    [anon_sym_EQ] = ACTIONS(2651),
    [anon_sym_DASH] = ACTIONS(2649),
    [aux_sym_boolean_token1] = ACTIONS(2649),
    [aux_sym_boolean_token2] = ACTIONS(2649),
    [sym_decimal] = ACTIONS(2649),
    [anon_sym_LPAREN] = ACTIONS(2651),
    [anon_sym_DOT_DOT] = ACTIONS(2651),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2649),
    [anon_sym_STAR] = ACTIONS(2649),
    [anon_sym_LBRACK] = ACTIONS(2651),
    [aux_sym_record_type_token1] = ACTIONS(2649),
    [aux_sym_basic_type_token21] = ACTIONS(2649),
    [aux_sym_basic_type_token22] = ACTIONS(2649),
    [aux_sym_basic_type_token48] = ACTIONS(2649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2649),
    [anon_sym_POUNDif] = ACTIONS(2651),
    [anon_sym_POUNDIF] = ACTIONS(2651),
    [anon_sym_POUNDIf] = ACTIONS(2651),
    [anon_sym_not] = ACTIONS(2649),
    [anon_sym_NOT] = ACTIONS(2649),
    [anon_sym_Not] = ACTIONS(2649),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2651),
    [aux_sym__expression_token1] = ACTIONS(2651),
    [aux_sym__expression_token2] = ACTIONS(2649),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2649),
    [anon_sym_SLASH] = ACTIONS(2649),
    [anon_sym_div] = ACTIONS(2649),
    [anon_sym_DIV] = ACTIONS(2649),
    [anon_sym_Div] = ACTIONS(2649),
    [anon_sym_mod] = ACTIONS(2649),
    [anon_sym_MOD] = ACTIONS(2649),
    [anon_sym_Mod] = ACTIONS(2649),
    [anon_sym_PLUS] = ACTIONS(2649),
    [anon_sym_GT_EQ] = ACTIONS(2651),
    [anon_sym_LT_EQ] = ACTIONS(2651),
    [anon_sym_GT] = ACTIONS(2649),
    [anon_sym_LT] = ACTIONS(2649),
    [anon_sym_LT_GT] = ACTIONS(2651),
    [anon_sym_and] = ACTIONS(2649),
    [anon_sym_AND] = ACTIONS(2649),
    [anon_sym_And] = ACTIONS(2649),
    [anon_sym_or] = ACTIONS(2649),
    [anon_sym_OR] = ACTIONS(2649),
    [anon_sym_Or] = ACTIONS(2649),
    [anon_sym_xor] = ACTIONS(2649),
    [anon_sym_XOR] = ACTIONS(2649),
    [anon_sym_Xor] = ACTIONS(2649),
    [anon_sym_QMARK] = ACTIONS(2651),
    [sym_datetime_literal] = ACTIONS(2651),
    [sym_date_literal] = ACTIONS(2649),
    [sym_time_literal] = ACTIONS(2649),
    [sym_biginteger_literal] = ACTIONS(2651),
    [anon_sym_if] = ACTIONS(2649),
    [anon_sym_IF] = ACTIONS(2649),
    [anon_sym_If] = ACTIONS(2649),
    [anon_sym_else] = ACTIONS(2649),
    [anon_sym_ELSE] = ACTIONS(2649),
    [anon_sym_Else] = ACTIONS(2649),
    [anon_sym_case] = ACTIONS(2649),
    [anon_sym_CASE] = ACTIONS(2649),
    [anon_sym_Case] = ACTIONS(2649),
    [anon_sym_for] = ACTIONS(2649),
    [anon_sym_FOR] = ACTIONS(2649),
    [anon_sym_For] = ACTIONS(2649),
    [anon_sym_foreach] = ACTIONS(2649),
    [anon_sym_FOREACH] = ACTIONS(2649),
    [anon_sym_Foreach] = ACTIONS(2649),
    [anon_sym_while] = ACTIONS(2649),
    [anon_sym_WHILE] = ACTIONS(2649),
    [anon_sym_While] = ACTIONS(2649),
    [anon_sym_repeat] = ACTIONS(2649),
    [anon_sym_REPEAT] = ACTIONS(2649),
    [anon_sym_Repeat] = ACTIONS(2649),
    [anon_sym_exit] = ACTIONS(2649),
    [anon_sym_EXIT] = ACTIONS(2649),
    [anon_sym_Exit] = ACTIONS(2649),
    [anon_sym_continue] = ACTIONS(2649),
    [anon_sym_CONTINUE] = ACTIONS(2649),
    [anon_sym_Continue] = ACTIONS(2649),
    [anon_sym_break] = ACTIONS(2649),
    [anon_sym_BREAK] = ACTIONS(2649),
    [anon_sym_Break] = ACTIONS(2649),
    [anon_sym_with] = ACTIONS(2649),
    [anon_sym_WITH] = ACTIONS(2649),
    [anon_sym_With] = ACTIONS(2649),
    [sym_asserterror_keyword] = ACTIONS(2651),
    [anon_sym_in] = ACTIONS(2649),
    [anon_sym_IN] = ACTIONS(2649),
    [anon_sym_In] = ACTIONS(2649),
    [sym_page_keyword] = ACTIONS(2649),
    [anon_sym_codeunit] = ACTIONS(2649),
    [anon_sym_CODEUNIT] = ACTIONS(2649),
    [anon_sym_Codeunit] = ACTIONS(2649),
    [anon_sym_CodeUnit] = ACTIONS(2649),
    [anon_sym_COdeunit] = ACTIONS(2649),
    [anon_sym_codeUnit] = ACTIONS(2649),
    [sym_report_keyword] = ACTIONS(2649),
    [sym_query_keyword] = ACTIONS(2649),
    [anon_sym_xmlport] = ACTIONS(2649),
    [anon_sym_XMLPORT] = ACTIONS(2649),
    [anon_sym_Xmlport] = ACTIONS(2649),
    [anon_sym_XMLport] = ACTIONS(2649),
    [anon_sym_XMLPort] = ACTIONS(2649),
    [anon_sym_XmlPort] = ACTIONS(2649),
    [anon_sym_enum] = ACTIONS(2649),
    [anon_sym_ENUM] = ACTIONS(2649),
    [anon_sym_Enum] = ACTIONS(2649),
    [anon_sym_eNUM] = ACTIONS(2649),
    [anon_sym_eNum] = ACTIONS(2649),
    [anon_sym_ENum] = ACTIONS(2649),
    [sym_quoted_identifier] = ACTIONS(2651),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2651),
    [sym_integer] = ACTIONS(2649),
    [sym_continue_as_identifier] = ACTIONS(2651),
    [sym_preproc_open] = ACTIONS(2651),
    [sym_end_keyword] = ACTIONS(2651),
  },
  [STATE(1235)] = {
    [sym_identifier] = ACTIONS(2625),
    [anon_sym_SEMI] = ACTIONS(2627),
    [anon_sym_DOT] = ACTIONS(2625),
    [anon_sym_EQ] = ACTIONS(2627),
    [anon_sym_DASH] = ACTIONS(2625),
    [aux_sym_boolean_token1] = ACTIONS(2625),
    [aux_sym_boolean_token2] = ACTIONS(2625),
    [sym_decimal] = ACTIONS(2625),
    [anon_sym_LPAREN] = ACTIONS(2627),
    [anon_sym_DOT_DOT] = ACTIONS(2627),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2625),
    [anon_sym_STAR] = ACTIONS(2625),
    [anon_sym_LBRACK] = ACTIONS(2627),
    [aux_sym_record_type_token1] = ACTIONS(2625),
    [aux_sym_basic_type_token21] = ACTIONS(2625),
    [aux_sym_basic_type_token22] = ACTIONS(2625),
    [aux_sym_basic_type_token48] = ACTIONS(2625),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2625),
    [anon_sym_POUNDif] = ACTIONS(2627),
    [anon_sym_POUNDIF] = ACTIONS(2627),
    [anon_sym_POUNDIf] = ACTIONS(2627),
    [anon_sym_not] = ACTIONS(2625),
    [anon_sym_NOT] = ACTIONS(2625),
    [anon_sym_Not] = ACTIONS(2625),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2627),
    [aux_sym__expression_token1] = ACTIONS(2627),
    [aux_sym__expression_token2] = ACTIONS(2625),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2625),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2625),
    [anon_sym_SLASH] = ACTIONS(2625),
    [anon_sym_div] = ACTIONS(2625),
    [anon_sym_DIV] = ACTIONS(2625),
    [anon_sym_Div] = ACTIONS(2625),
    [anon_sym_mod] = ACTIONS(2625),
    [anon_sym_MOD] = ACTIONS(2625),
    [anon_sym_Mod] = ACTIONS(2625),
    [anon_sym_PLUS] = ACTIONS(2625),
    [anon_sym_GT_EQ] = ACTIONS(2627),
    [anon_sym_LT_EQ] = ACTIONS(2627),
    [anon_sym_GT] = ACTIONS(2625),
    [anon_sym_LT] = ACTIONS(2625),
    [anon_sym_LT_GT] = ACTIONS(2627),
    [anon_sym_and] = ACTIONS(2625),
    [anon_sym_AND] = ACTIONS(2625),
    [anon_sym_And] = ACTIONS(2625),
    [anon_sym_or] = ACTIONS(2625),
    [anon_sym_OR] = ACTIONS(2625),
    [anon_sym_Or] = ACTIONS(2625),
    [anon_sym_xor] = ACTIONS(2625),
    [anon_sym_XOR] = ACTIONS(2625),
    [anon_sym_Xor] = ACTIONS(2625),
    [anon_sym_QMARK] = ACTIONS(2627),
    [sym_datetime_literal] = ACTIONS(2627),
    [sym_date_literal] = ACTIONS(2625),
    [sym_time_literal] = ACTIONS(2625),
    [sym_biginteger_literal] = ACTIONS(2627),
    [anon_sym_if] = ACTIONS(2625),
    [anon_sym_IF] = ACTIONS(2625),
    [anon_sym_If] = ACTIONS(2625),
    [anon_sym_else] = ACTIONS(2625),
    [anon_sym_ELSE] = ACTIONS(2625),
    [anon_sym_Else] = ACTIONS(2625),
    [anon_sym_case] = ACTIONS(2625),
    [anon_sym_CASE] = ACTIONS(2625),
    [anon_sym_Case] = ACTIONS(2625),
    [anon_sym_for] = ACTIONS(2625),
    [anon_sym_FOR] = ACTIONS(2625),
    [anon_sym_For] = ACTIONS(2625),
    [anon_sym_foreach] = ACTIONS(2625),
    [anon_sym_FOREACH] = ACTIONS(2625),
    [anon_sym_Foreach] = ACTIONS(2625),
    [anon_sym_while] = ACTIONS(2625),
    [anon_sym_WHILE] = ACTIONS(2625),
    [anon_sym_While] = ACTIONS(2625),
    [anon_sym_repeat] = ACTIONS(2625),
    [anon_sym_REPEAT] = ACTIONS(2625),
    [anon_sym_Repeat] = ACTIONS(2625),
    [anon_sym_exit] = ACTIONS(2625),
    [anon_sym_EXIT] = ACTIONS(2625),
    [anon_sym_Exit] = ACTIONS(2625),
    [anon_sym_continue] = ACTIONS(2625),
    [anon_sym_CONTINUE] = ACTIONS(2625),
    [anon_sym_Continue] = ACTIONS(2625),
    [anon_sym_break] = ACTIONS(2625),
    [anon_sym_BREAK] = ACTIONS(2625),
    [anon_sym_Break] = ACTIONS(2625),
    [anon_sym_with] = ACTIONS(2625),
    [anon_sym_WITH] = ACTIONS(2625),
    [anon_sym_With] = ACTIONS(2625),
    [sym_asserterror_keyword] = ACTIONS(2627),
    [anon_sym_in] = ACTIONS(2625),
    [anon_sym_IN] = ACTIONS(2625),
    [anon_sym_In] = ACTIONS(2625),
    [sym_page_keyword] = ACTIONS(2625),
    [anon_sym_codeunit] = ACTIONS(2625),
    [anon_sym_CODEUNIT] = ACTIONS(2625),
    [anon_sym_Codeunit] = ACTIONS(2625),
    [anon_sym_CodeUnit] = ACTIONS(2625),
    [anon_sym_COdeunit] = ACTIONS(2625),
    [anon_sym_codeUnit] = ACTIONS(2625),
    [sym_report_keyword] = ACTIONS(2625),
    [sym_query_keyword] = ACTIONS(2625),
    [anon_sym_xmlport] = ACTIONS(2625),
    [anon_sym_XMLPORT] = ACTIONS(2625),
    [anon_sym_Xmlport] = ACTIONS(2625),
    [anon_sym_XMLport] = ACTIONS(2625),
    [anon_sym_XMLPort] = ACTIONS(2625),
    [anon_sym_XmlPort] = ACTIONS(2625),
    [anon_sym_enum] = ACTIONS(2625),
    [anon_sym_ENUM] = ACTIONS(2625),
    [anon_sym_Enum] = ACTIONS(2625),
    [anon_sym_eNUM] = ACTIONS(2625),
    [anon_sym_eNum] = ACTIONS(2625),
    [anon_sym_ENum] = ACTIONS(2625),
    [sym_quoted_identifier] = ACTIONS(2627),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2627),
    [sym_integer] = ACTIONS(2625),
    [sym_continue_as_identifier] = ACTIONS(2627),
    [sym_preproc_open] = ACTIONS(2627),
    [sym_end_keyword] = ACTIONS(2627),
  },
  [STATE(1236)] = {
    [sym_identifier] = ACTIONS(2629),
    [anon_sym_SEMI] = ACTIONS(2631),
    [anon_sym_DOT] = ACTIONS(2629),
    [anon_sym_EQ] = ACTIONS(2631),
    [anon_sym_DASH] = ACTIONS(2629),
    [aux_sym_boolean_token1] = ACTIONS(2629),
    [aux_sym_boolean_token2] = ACTIONS(2629),
    [sym_decimal] = ACTIONS(2629),
    [anon_sym_LPAREN] = ACTIONS(2631),
    [anon_sym_DOT_DOT] = ACTIONS(2631),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2629),
    [anon_sym_STAR] = ACTIONS(2629),
    [anon_sym_LBRACK] = ACTIONS(2631),
    [aux_sym_record_type_token1] = ACTIONS(2629),
    [aux_sym_basic_type_token21] = ACTIONS(2629),
    [aux_sym_basic_type_token22] = ACTIONS(2629),
    [aux_sym_basic_type_token48] = ACTIONS(2629),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2629),
    [anon_sym_POUNDif] = ACTIONS(2631),
    [anon_sym_POUNDIF] = ACTIONS(2631),
    [anon_sym_POUNDIf] = ACTIONS(2631),
    [anon_sym_not] = ACTIONS(2629),
    [anon_sym_NOT] = ACTIONS(2629),
    [anon_sym_Not] = ACTIONS(2629),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2631),
    [aux_sym__expression_token1] = ACTIONS(2631),
    [aux_sym__expression_token2] = ACTIONS(2629),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2629),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2629),
    [anon_sym_SLASH] = ACTIONS(2629),
    [anon_sym_div] = ACTIONS(2629),
    [anon_sym_DIV] = ACTIONS(2629),
    [anon_sym_Div] = ACTIONS(2629),
    [anon_sym_mod] = ACTIONS(2629),
    [anon_sym_MOD] = ACTIONS(2629),
    [anon_sym_Mod] = ACTIONS(2629),
    [anon_sym_PLUS] = ACTIONS(2629),
    [anon_sym_GT_EQ] = ACTIONS(2631),
    [anon_sym_LT_EQ] = ACTIONS(2631),
    [anon_sym_GT] = ACTIONS(2629),
    [anon_sym_LT] = ACTIONS(2629),
    [anon_sym_LT_GT] = ACTIONS(2631),
    [anon_sym_and] = ACTIONS(2629),
    [anon_sym_AND] = ACTIONS(2629),
    [anon_sym_And] = ACTIONS(2629),
    [anon_sym_or] = ACTIONS(2629),
    [anon_sym_OR] = ACTIONS(2629),
    [anon_sym_Or] = ACTIONS(2629),
    [anon_sym_xor] = ACTIONS(2629),
    [anon_sym_XOR] = ACTIONS(2629),
    [anon_sym_Xor] = ACTIONS(2629),
    [anon_sym_QMARK] = ACTIONS(2631),
    [sym_datetime_literal] = ACTIONS(2631),
    [sym_date_literal] = ACTIONS(2629),
    [sym_time_literal] = ACTIONS(2629),
    [sym_biginteger_literal] = ACTIONS(2631),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_IF] = ACTIONS(2629),
    [anon_sym_If] = ACTIONS(2629),
    [anon_sym_else] = ACTIONS(2629),
    [anon_sym_ELSE] = ACTIONS(2629),
    [anon_sym_Else] = ACTIONS(2629),
    [anon_sym_case] = ACTIONS(2629),
    [anon_sym_CASE] = ACTIONS(2629),
    [anon_sym_Case] = ACTIONS(2629),
    [anon_sym_for] = ACTIONS(2629),
    [anon_sym_FOR] = ACTIONS(2629),
    [anon_sym_For] = ACTIONS(2629),
    [anon_sym_foreach] = ACTIONS(2629),
    [anon_sym_FOREACH] = ACTIONS(2629),
    [anon_sym_Foreach] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(2629),
    [anon_sym_WHILE] = ACTIONS(2629),
    [anon_sym_While] = ACTIONS(2629),
    [anon_sym_repeat] = ACTIONS(2629),
    [anon_sym_REPEAT] = ACTIONS(2629),
    [anon_sym_Repeat] = ACTIONS(2629),
    [anon_sym_exit] = ACTIONS(2629),
    [anon_sym_EXIT] = ACTIONS(2629),
    [anon_sym_Exit] = ACTIONS(2629),
    [anon_sym_continue] = ACTIONS(2629),
    [anon_sym_CONTINUE] = ACTIONS(2629),
    [anon_sym_Continue] = ACTIONS(2629),
    [anon_sym_break] = ACTIONS(2629),
    [anon_sym_BREAK] = ACTIONS(2629),
    [anon_sym_Break] = ACTIONS(2629),
    [anon_sym_with] = ACTIONS(2629),
    [anon_sym_WITH] = ACTIONS(2629),
    [anon_sym_With] = ACTIONS(2629),
    [sym_asserterror_keyword] = ACTIONS(2631),
    [anon_sym_in] = ACTIONS(2629),
    [anon_sym_IN] = ACTIONS(2629),
    [anon_sym_In] = ACTIONS(2629),
    [sym_page_keyword] = ACTIONS(2629),
    [anon_sym_codeunit] = ACTIONS(2629),
    [anon_sym_CODEUNIT] = ACTIONS(2629),
    [anon_sym_Codeunit] = ACTIONS(2629),
    [anon_sym_CodeUnit] = ACTIONS(2629),
    [anon_sym_COdeunit] = ACTIONS(2629),
    [anon_sym_codeUnit] = ACTIONS(2629),
    [sym_report_keyword] = ACTIONS(2629),
    [sym_query_keyword] = ACTIONS(2629),
    [anon_sym_xmlport] = ACTIONS(2629),
    [anon_sym_XMLPORT] = ACTIONS(2629),
    [anon_sym_Xmlport] = ACTIONS(2629),
    [anon_sym_XMLport] = ACTIONS(2629),
    [anon_sym_XMLPort] = ACTIONS(2629),
    [anon_sym_XmlPort] = ACTIONS(2629),
    [anon_sym_enum] = ACTIONS(2629),
    [anon_sym_ENUM] = ACTIONS(2629),
    [anon_sym_Enum] = ACTIONS(2629),
    [anon_sym_eNUM] = ACTIONS(2629),
    [anon_sym_eNum] = ACTIONS(2629),
    [anon_sym_ENum] = ACTIONS(2629),
    [sym_quoted_identifier] = ACTIONS(2631),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2631),
    [sym_integer] = ACTIONS(2629),
    [sym_continue_as_identifier] = ACTIONS(2631),
    [sym_preproc_open] = ACTIONS(2631),
    [sym_end_keyword] = ACTIONS(2631),
  },
  [STATE(1237)] = {
    [sym_identifier] = ACTIONS(2633),
    [anon_sym_SEMI] = ACTIONS(2635),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_EQ] = ACTIONS(2635),
    [anon_sym_DASH] = ACTIONS(2633),
    [aux_sym_boolean_token1] = ACTIONS(2633),
    [aux_sym_boolean_token2] = ACTIONS(2633),
    [sym_decimal] = ACTIONS(2633),
    [anon_sym_LPAREN] = ACTIONS(2635),
    [anon_sym_DOT_DOT] = ACTIONS(2635),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2633),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [aux_sym_record_type_token1] = ACTIONS(2633),
    [aux_sym_basic_type_token21] = ACTIONS(2633),
    [aux_sym_basic_type_token22] = ACTIONS(2633),
    [aux_sym_basic_type_token48] = ACTIONS(2633),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2633),
    [anon_sym_POUNDif] = ACTIONS(2635),
    [anon_sym_POUNDIF] = ACTIONS(2635),
    [anon_sym_POUNDIf] = ACTIONS(2635),
    [anon_sym_not] = ACTIONS(2633),
    [anon_sym_NOT] = ACTIONS(2633),
    [anon_sym_Not] = ACTIONS(2633),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2635),
    [aux_sym__expression_token1] = ACTIONS(2635),
    [aux_sym__expression_token2] = ACTIONS(2633),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2633),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2633),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_div] = ACTIONS(2633),
    [anon_sym_DIV] = ACTIONS(2633),
    [anon_sym_Div] = ACTIONS(2633),
    [anon_sym_mod] = ACTIONS(2633),
    [anon_sym_MOD] = ACTIONS(2633),
    [anon_sym_Mod] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_GT] = ACTIONS(2635),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_AND] = ACTIONS(2633),
    [anon_sym_And] = ACTIONS(2633),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_OR] = ACTIONS(2633),
    [anon_sym_Or] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_XOR] = ACTIONS(2633),
    [anon_sym_Xor] = ACTIONS(2633),
    [anon_sym_QMARK] = ACTIONS(2635),
    [sym_datetime_literal] = ACTIONS(2635),
    [sym_date_literal] = ACTIONS(2633),
    [sym_time_literal] = ACTIONS(2633),
    [sym_biginteger_literal] = ACTIONS(2635),
    [anon_sym_if] = ACTIONS(2633),
    [anon_sym_IF] = ACTIONS(2633),
    [anon_sym_If] = ACTIONS(2633),
    [anon_sym_else] = ACTIONS(2633),
    [anon_sym_ELSE] = ACTIONS(2633),
    [anon_sym_Else] = ACTIONS(2633),
    [anon_sym_case] = ACTIONS(2633),
    [anon_sym_CASE] = ACTIONS(2633),
    [anon_sym_Case] = ACTIONS(2633),
    [anon_sym_for] = ACTIONS(2633),
    [anon_sym_FOR] = ACTIONS(2633),
    [anon_sym_For] = ACTIONS(2633),
    [anon_sym_foreach] = ACTIONS(2633),
    [anon_sym_FOREACH] = ACTIONS(2633),
    [anon_sym_Foreach] = ACTIONS(2633),
    [anon_sym_while] = ACTIONS(2633),
    [anon_sym_WHILE] = ACTIONS(2633),
    [anon_sym_While] = ACTIONS(2633),
    [anon_sym_repeat] = ACTIONS(2633),
    [anon_sym_REPEAT] = ACTIONS(2633),
    [anon_sym_Repeat] = ACTIONS(2633),
    [anon_sym_exit] = ACTIONS(2633),
    [anon_sym_EXIT] = ACTIONS(2633),
    [anon_sym_Exit] = ACTIONS(2633),
    [anon_sym_continue] = ACTIONS(2633),
    [anon_sym_CONTINUE] = ACTIONS(2633),
    [anon_sym_Continue] = ACTIONS(2633),
    [anon_sym_break] = ACTIONS(2633),
    [anon_sym_BREAK] = ACTIONS(2633),
    [anon_sym_Break] = ACTIONS(2633),
    [anon_sym_with] = ACTIONS(2633),
    [anon_sym_WITH] = ACTIONS(2633),
    [anon_sym_With] = ACTIONS(2633),
    [sym_asserterror_keyword] = ACTIONS(2635),
    [anon_sym_in] = ACTIONS(2633),
    [anon_sym_IN] = ACTIONS(2633),
    [anon_sym_In] = ACTIONS(2633),
    [sym_page_keyword] = ACTIONS(2633),
    [anon_sym_codeunit] = ACTIONS(2633),
    [anon_sym_CODEUNIT] = ACTIONS(2633),
    [anon_sym_Codeunit] = ACTIONS(2633),
    [anon_sym_CodeUnit] = ACTIONS(2633),
    [anon_sym_COdeunit] = ACTIONS(2633),
    [anon_sym_codeUnit] = ACTIONS(2633),
    [sym_report_keyword] = ACTIONS(2633),
    [sym_query_keyword] = ACTIONS(2633),
    [anon_sym_xmlport] = ACTIONS(2633),
    [anon_sym_XMLPORT] = ACTIONS(2633),
    [anon_sym_Xmlport] = ACTIONS(2633),
    [anon_sym_XMLport] = ACTIONS(2633),
    [anon_sym_XMLPort] = ACTIONS(2633),
    [anon_sym_XmlPort] = ACTIONS(2633),
    [anon_sym_enum] = ACTIONS(2633),
    [anon_sym_ENUM] = ACTIONS(2633),
    [anon_sym_Enum] = ACTIONS(2633),
    [anon_sym_eNUM] = ACTIONS(2633),
    [anon_sym_eNum] = ACTIONS(2633),
    [anon_sym_ENum] = ACTIONS(2633),
    [sym_quoted_identifier] = ACTIONS(2635),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2635),
    [sym_integer] = ACTIONS(2633),
    [sym_continue_as_identifier] = ACTIONS(2635),
    [sym_preproc_open] = ACTIONS(2635),
    [sym_end_keyword] = ACTIONS(2635),
  },
  [STATE(1238)] = {
    [sym_identifier] = ACTIONS(2641),
    [anon_sym_SEMI] = ACTIONS(2643),
    [anon_sym_DOT] = ACTIONS(2641),
    [anon_sym_EQ] = ACTIONS(2643),
    [anon_sym_DASH] = ACTIONS(2641),
    [aux_sym_boolean_token1] = ACTIONS(2641),
    [aux_sym_boolean_token2] = ACTIONS(2641),
    [sym_decimal] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_DOT_DOT] = ACTIONS(2643),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2641),
    [anon_sym_STAR] = ACTIONS(2641),
    [anon_sym_LBRACK] = ACTIONS(2643),
    [aux_sym_record_type_token1] = ACTIONS(2641),
    [aux_sym_basic_type_token21] = ACTIONS(2641),
    [aux_sym_basic_type_token22] = ACTIONS(2641),
    [aux_sym_basic_type_token48] = ACTIONS(2641),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2641),
    [anon_sym_POUNDif] = ACTIONS(2643),
    [anon_sym_POUNDIF] = ACTIONS(2643),
    [anon_sym_POUNDIf] = ACTIONS(2643),
    [anon_sym_not] = ACTIONS(2641),
    [anon_sym_NOT] = ACTIONS(2641),
    [anon_sym_Not] = ACTIONS(2641),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2643),
    [aux_sym__expression_token1] = ACTIONS(2643),
    [aux_sym__expression_token2] = ACTIONS(2641),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2641),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2641),
    [anon_sym_SLASH] = ACTIONS(2641),
    [anon_sym_div] = ACTIONS(2641),
    [anon_sym_DIV] = ACTIONS(2641),
    [anon_sym_Div] = ACTIONS(2641),
    [anon_sym_mod] = ACTIONS(2641),
    [anon_sym_MOD] = ACTIONS(2641),
    [anon_sym_Mod] = ACTIONS(2641),
    [anon_sym_PLUS] = ACTIONS(2641),
    [anon_sym_GT_EQ] = ACTIONS(2643),
    [anon_sym_LT_EQ] = ACTIONS(2643),
    [anon_sym_GT] = ACTIONS(2641),
    [anon_sym_LT] = ACTIONS(2641),
    [anon_sym_LT_GT] = ACTIONS(2643),
    [anon_sym_and] = ACTIONS(2641),
    [anon_sym_AND] = ACTIONS(2641),
    [anon_sym_And] = ACTIONS(2641),
    [anon_sym_or] = ACTIONS(2641),
    [anon_sym_OR] = ACTIONS(2641),
    [anon_sym_Or] = ACTIONS(2641),
    [anon_sym_xor] = ACTIONS(2641),
    [anon_sym_XOR] = ACTIONS(2641),
    [anon_sym_Xor] = ACTIONS(2641),
    [anon_sym_QMARK] = ACTIONS(2643),
    [sym_datetime_literal] = ACTIONS(2643),
    [sym_date_literal] = ACTIONS(2641),
    [sym_time_literal] = ACTIONS(2641),
    [sym_biginteger_literal] = ACTIONS(2643),
    [anon_sym_if] = ACTIONS(2641),
    [anon_sym_IF] = ACTIONS(2641),
    [anon_sym_If] = ACTIONS(2641),
    [anon_sym_else] = ACTIONS(2641),
    [anon_sym_ELSE] = ACTIONS(2641),
    [anon_sym_Else] = ACTIONS(2641),
    [anon_sym_case] = ACTIONS(2641),
    [anon_sym_CASE] = ACTIONS(2641),
    [anon_sym_Case] = ACTIONS(2641),
    [anon_sym_for] = ACTIONS(2641),
    [anon_sym_FOR] = ACTIONS(2641),
    [anon_sym_For] = ACTIONS(2641),
    [anon_sym_foreach] = ACTIONS(2641),
    [anon_sym_FOREACH] = ACTIONS(2641),
    [anon_sym_Foreach] = ACTIONS(2641),
    [anon_sym_while] = ACTIONS(2641),
    [anon_sym_WHILE] = ACTIONS(2641),
    [anon_sym_While] = ACTIONS(2641),
    [anon_sym_repeat] = ACTIONS(2641),
    [anon_sym_REPEAT] = ACTIONS(2641),
    [anon_sym_Repeat] = ACTIONS(2641),
    [anon_sym_exit] = ACTIONS(2641),
    [anon_sym_EXIT] = ACTIONS(2641),
    [anon_sym_Exit] = ACTIONS(2641),
    [anon_sym_continue] = ACTIONS(2641),
    [anon_sym_CONTINUE] = ACTIONS(2641),
    [anon_sym_Continue] = ACTIONS(2641),
    [anon_sym_break] = ACTIONS(2641),
    [anon_sym_BREAK] = ACTIONS(2641),
    [anon_sym_Break] = ACTIONS(2641),
    [anon_sym_with] = ACTIONS(2641),
    [anon_sym_WITH] = ACTIONS(2641),
    [anon_sym_With] = ACTIONS(2641),
    [sym_asserterror_keyword] = ACTIONS(2643),
    [anon_sym_in] = ACTIONS(2641),
    [anon_sym_IN] = ACTIONS(2641),
    [anon_sym_In] = ACTIONS(2641),
    [sym_page_keyword] = ACTIONS(2641),
    [anon_sym_codeunit] = ACTIONS(2641),
    [anon_sym_CODEUNIT] = ACTIONS(2641),
    [anon_sym_Codeunit] = ACTIONS(2641),
    [anon_sym_CodeUnit] = ACTIONS(2641),
    [anon_sym_COdeunit] = ACTIONS(2641),
    [anon_sym_codeUnit] = ACTIONS(2641),
    [sym_report_keyword] = ACTIONS(2641),
    [sym_query_keyword] = ACTIONS(2641),
    [anon_sym_xmlport] = ACTIONS(2641),
    [anon_sym_XMLPORT] = ACTIONS(2641),
    [anon_sym_Xmlport] = ACTIONS(2641),
    [anon_sym_XMLport] = ACTIONS(2641),
    [anon_sym_XMLPort] = ACTIONS(2641),
    [anon_sym_XmlPort] = ACTIONS(2641),
    [anon_sym_enum] = ACTIONS(2641),
    [anon_sym_ENUM] = ACTIONS(2641),
    [anon_sym_Enum] = ACTIONS(2641),
    [anon_sym_eNUM] = ACTIONS(2641),
    [anon_sym_eNum] = ACTIONS(2641),
    [anon_sym_ENum] = ACTIONS(2641),
    [sym_quoted_identifier] = ACTIONS(2643),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2643),
    [sym_integer] = ACTIONS(2641),
    [sym_continue_as_identifier] = ACTIONS(2643),
    [sym_preproc_open] = ACTIONS(2643),
    [sym_end_keyword] = ACTIONS(2643),
  },
  [STATE(1239)] = {
    [sym_identifier] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym_DOT] = ACTIONS(2573),
    [anon_sym_EQ] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2573),
    [aux_sym_boolean_token1] = ACTIONS(2573),
    [aux_sym_boolean_token2] = ACTIONS(2573),
    [sym_decimal] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2575),
    [anon_sym_DOT_DOT] = ACTIONS(2575),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2575),
    [aux_sym_record_type_token1] = ACTIONS(2573),
    [aux_sym_basic_type_token21] = ACTIONS(2573),
    [aux_sym_basic_type_token22] = ACTIONS(2573),
    [aux_sym_basic_type_token48] = ACTIONS(2573),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2573),
    [anon_sym_POUNDif] = ACTIONS(2575),
    [anon_sym_POUNDIF] = ACTIONS(2575),
    [anon_sym_POUNDIf] = ACTIONS(2575),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_NOT] = ACTIONS(2573),
    [anon_sym_Not] = ACTIONS(2573),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2575),
    [aux_sym__expression_token1] = ACTIONS(2575),
    [aux_sym__expression_token2] = ACTIONS(2573),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2573),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2573),
    [anon_sym_SLASH] = ACTIONS(2573),
    [anon_sym_div] = ACTIONS(2573),
    [anon_sym_DIV] = ACTIONS(2573),
    [anon_sym_Div] = ACTIONS(2573),
    [anon_sym_mod] = ACTIONS(2573),
    [anon_sym_MOD] = ACTIONS(2573),
    [anon_sym_Mod] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_GT_EQ] = ACTIONS(2575),
    [anon_sym_LT_EQ] = ACTIONS(2575),
    [anon_sym_GT] = ACTIONS(2573),
    [anon_sym_LT] = ACTIONS(2573),
    [anon_sym_LT_GT] = ACTIONS(2575),
    [anon_sym_and] = ACTIONS(2573),
    [anon_sym_AND] = ACTIONS(2573),
    [anon_sym_And] = ACTIONS(2573),
    [anon_sym_or] = ACTIONS(2573),
    [anon_sym_OR] = ACTIONS(2573),
    [anon_sym_Or] = ACTIONS(2573),
    [anon_sym_xor] = ACTIONS(2573),
    [anon_sym_XOR] = ACTIONS(2573),
    [anon_sym_Xor] = ACTIONS(2573),
    [anon_sym_QMARK] = ACTIONS(2575),
    [sym_datetime_literal] = ACTIONS(2575),
    [sym_date_literal] = ACTIONS(2573),
    [sym_time_literal] = ACTIONS(2573),
    [sym_biginteger_literal] = ACTIONS(2575),
    [anon_sym_if] = ACTIONS(2573),
    [anon_sym_IF] = ACTIONS(2573),
    [anon_sym_If] = ACTIONS(2573),
    [anon_sym_else] = ACTIONS(2573),
    [anon_sym_ELSE] = ACTIONS(2573),
    [anon_sym_Else] = ACTIONS(2573),
    [anon_sym_case] = ACTIONS(2573),
    [anon_sym_CASE] = ACTIONS(2573),
    [anon_sym_Case] = ACTIONS(2573),
    [anon_sym_for] = ACTIONS(2573),
    [anon_sym_FOR] = ACTIONS(2573),
    [anon_sym_For] = ACTIONS(2573),
    [anon_sym_foreach] = ACTIONS(2573),
    [anon_sym_FOREACH] = ACTIONS(2573),
    [anon_sym_Foreach] = ACTIONS(2573),
    [anon_sym_while] = ACTIONS(2573),
    [anon_sym_WHILE] = ACTIONS(2573),
    [anon_sym_While] = ACTIONS(2573),
    [anon_sym_repeat] = ACTIONS(2573),
    [anon_sym_REPEAT] = ACTIONS(2573),
    [anon_sym_Repeat] = ACTIONS(2573),
    [anon_sym_exit] = ACTIONS(2573),
    [anon_sym_EXIT] = ACTIONS(2573),
    [anon_sym_Exit] = ACTIONS(2573),
    [anon_sym_continue] = ACTIONS(2573),
    [anon_sym_CONTINUE] = ACTIONS(2573),
    [anon_sym_Continue] = ACTIONS(2573),
    [anon_sym_break] = ACTIONS(2573),
    [anon_sym_BREAK] = ACTIONS(2573),
    [anon_sym_Break] = ACTIONS(2573),
    [anon_sym_with] = ACTIONS(2573),
    [anon_sym_WITH] = ACTIONS(2573),
    [anon_sym_With] = ACTIONS(2573),
    [sym_asserterror_keyword] = ACTIONS(2575),
    [anon_sym_in] = ACTIONS(2573),
    [anon_sym_IN] = ACTIONS(2573),
    [anon_sym_In] = ACTIONS(2573),
    [sym_page_keyword] = ACTIONS(2573),
    [anon_sym_codeunit] = ACTIONS(2573),
    [anon_sym_CODEUNIT] = ACTIONS(2573),
    [anon_sym_Codeunit] = ACTIONS(2573),
    [anon_sym_CodeUnit] = ACTIONS(2573),
    [anon_sym_COdeunit] = ACTIONS(2573),
    [anon_sym_codeUnit] = ACTIONS(2573),
    [sym_report_keyword] = ACTIONS(2573),
    [sym_query_keyword] = ACTIONS(2573),
    [anon_sym_xmlport] = ACTIONS(2573),
    [anon_sym_XMLPORT] = ACTIONS(2573),
    [anon_sym_Xmlport] = ACTIONS(2573),
    [anon_sym_XMLport] = ACTIONS(2573),
    [anon_sym_XMLPort] = ACTIONS(2573),
    [anon_sym_XmlPort] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_ENUM] = ACTIONS(2573),
    [anon_sym_Enum] = ACTIONS(2573),
    [anon_sym_eNUM] = ACTIONS(2573),
    [anon_sym_eNum] = ACTIONS(2573),
    [anon_sym_ENum] = ACTIONS(2573),
    [sym_quoted_identifier] = ACTIONS(2575),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2575),
    [sym_integer] = ACTIONS(2573),
    [sym_continue_as_identifier] = ACTIONS(2575),
    [sym_preproc_open] = ACTIONS(2575),
    [sym_end_keyword] = ACTIONS(2575),
  },
  [STATE(1240)] = {
    [sym_identifier] = ACTIONS(2577),
    [anon_sym_SEMI] = ACTIONS(2579),
    [anon_sym_DOT] = ACTIONS(2577),
    [anon_sym_EQ] = ACTIONS(2579),
    [anon_sym_DASH] = ACTIONS(2577),
    [aux_sym_boolean_token1] = ACTIONS(2577),
    [aux_sym_boolean_token2] = ACTIONS(2577),
    [sym_decimal] = ACTIONS(2577),
    [anon_sym_LPAREN] = ACTIONS(2579),
    [anon_sym_DOT_DOT] = ACTIONS(2579),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2577),
    [anon_sym_STAR] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [aux_sym_record_type_token1] = ACTIONS(2577),
    [aux_sym_basic_type_token21] = ACTIONS(2577),
    [aux_sym_basic_type_token22] = ACTIONS(2577),
    [aux_sym_basic_type_token48] = ACTIONS(2577),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2577),
    [anon_sym_POUNDif] = ACTIONS(2579),
    [anon_sym_POUNDIF] = ACTIONS(2579),
    [anon_sym_POUNDIf] = ACTIONS(2579),
    [anon_sym_not] = ACTIONS(2577),
    [anon_sym_NOT] = ACTIONS(2577),
    [anon_sym_Not] = ACTIONS(2577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2579),
    [aux_sym__expression_token1] = ACTIONS(2579),
    [aux_sym__expression_token2] = ACTIONS(2577),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2577),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2577),
    [anon_sym_SLASH] = ACTIONS(2577),
    [anon_sym_div] = ACTIONS(2577),
    [anon_sym_DIV] = ACTIONS(2577),
    [anon_sym_Div] = ACTIONS(2577),
    [anon_sym_mod] = ACTIONS(2577),
    [anon_sym_MOD] = ACTIONS(2577),
    [anon_sym_Mod] = ACTIONS(2577),
    [anon_sym_PLUS] = ACTIONS(2577),
    [anon_sym_GT_EQ] = ACTIONS(2579),
    [anon_sym_LT_EQ] = ACTIONS(2579),
    [anon_sym_GT] = ACTIONS(2577),
    [anon_sym_LT] = ACTIONS(2577),
    [anon_sym_LT_GT] = ACTIONS(2579),
    [anon_sym_and] = ACTIONS(2577),
    [anon_sym_AND] = ACTIONS(2577),
    [anon_sym_And] = ACTIONS(2577),
    [anon_sym_or] = ACTIONS(2577),
    [anon_sym_OR] = ACTIONS(2577),
    [anon_sym_Or] = ACTIONS(2577),
    [anon_sym_xor] = ACTIONS(2577),
    [anon_sym_XOR] = ACTIONS(2577),
    [anon_sym_Xor] = ACTIONS(2577),
    [anon_sym_QMARK] = ACTIONS(2579),
    [sym_datetime_literal] = ACTIONS(2579),
    [sym_date_literal] = ACTIONS(2577),
    [sym_time_literal] = ACTIONS(2577),
    [sym_biginteger_literal] = ACTIONS(2579),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_IF] = ACTIONS(2577),
    [anon_sym_If] = ACTIONS(2577),
    [anon_sym_else] = ACTIONS(2577),
    [anon_sym_ELSE] = ACTIONS(2577),
    [anon_sym_Else] = ACTIONS(2577),
    [anon_sym_case] = ACTIONS(2577),
    [anon_sym_CASE] = ACTIONS(2577),
    [anon_sym_Case] = ACTIONS(2577),
    [anon_sym_for] = ACTIONS(2577),
    [anon_sym_FOR] = ACTIONS(2577),
    [anon_sym_For] = ACTIONS(2577),
    [anon_sym_foreach] = ACTIONS(2577),
    [anon_sym_FOREACH] = ACTIONS(2577),
    [anon_sym_Foreach] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(2577),
    [anon_sym_WHILE] = ACTIONS(2577),
    [anon_sym_While] = ACTIONS(2577),
    [anon_sym_repeat] = ACTIONS(2577),
    [anon_sym_REPEAT] = ACTIONS(2577),
    [anon_sym_Repeat] = ACTIONS(2577),
    [anon_sym_exit] = ACTIONS(2577),
    [anon_sym_EXIT] = ACTIONS(2577),
    [anon_sym_Exit] = ACTIONS(2577),
    [anon_sym_continue] = ACTIONS(2577),
    [anon_sym_CONTINUE] = ACTIONS(2577),
    [anon_sym_Continue] = ACTIONS(2577),
    [anon_sym_break] = ACTIONS(2577),
    [anon_sym_BREAK] = ACTIONS(2577),
    [anon_sym_Break] = ACTIONS(2577),
    [anon_sym_with] = ACTIONS(2577),
    [anon_sym_WITH] = ACTIONS(2577),
    [anon_sym_With] = ACTIONS(2577),
    [sym_asserterror_keyword] = ACTIONS(2579),
    [anon_sym_in] = ACTIONS(2577),
    [anon_sym_IN] = ACTIONS(2577),
    [anon_sym_In] = ACTIONS(2577),
    [sym_page_keyword] = ACTIONS(2577),
    [anon_sym_codeunit] = ACTIONS(2577),
    [anon_sym_CODEUNIT] = ACTIONS(2577),
    [anon_sym_Codeunit] = ACTIONS(2577),
    [anon_sym_CodeUnit] = ACTIONS(2577),
    [anon_sym_COdeunit] = ACTIONS(2577),
    [anon_sym_codeUnit] = ACTIONS(2577),
    [sym_report_keyword] = ACTIONS(2577),
    [sym_query_keyword] = ACTIONS(2577),
    [anon_sym_xmlport] = ACTIONS(2577),
    [anon_sym_XMLPORT] = ACTIONS(2577),
    [anon_sym_Xmlport] = ACTIONS(2577),
    [anon_sym_XMLport] = ACTIONS(2577),
    [anon_sym_XMLPort] = ACTIONS(2577),
    [anon_sym_XmlPort] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_ENUM] = ACTIONS(2577),
    [anon_sym_Enum] = ACTIONS(2577),
    [anon_sym_eNUM] = ACTIONS(2577),
    [anon_sym_eNum] = ACTIONS(2577),
    [anon_sym_ENum] = ACTIONS(2577),
    [sym_quoted_identifier] = ACTIONS(2579),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2579),
    [sym_integer] = ACTIONS(2577),
    [sym_continue_as_identifier] = ACTIONS(2579),
    [sym_preproc_open] = ACTIONS(2579),
    [sym_end_keyword] = ACTIONS(2579),
  },
  [STATE(1241)] = {
    [sym_identifier] = ACTIONS(2581),
    [anon_sym_SEMI] = ACTIONS(2583),
    [anon_sym_DOT] = ACTIONS(2581),
    [anon_sym_EQ] = ACTIONS(2583),
    [anon_sym_DASH] = ACTIONS(2581),
    [aux_sym_boolean_token1] = ACTIONS(2581),
    [aux_sym_boolean_token2] = ACTIONS(2581),
    [sym_decimal] = ACTIONS(2581),
    [anon_sym_LPAREN] = ACTIONS(2583),
    [anon_sym_DOT_DOT] = ACTIONS(2583),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2581),
    [anon_sym_STAR] = ACTIONS(2581),
    [anon_sym_LBRACK] = ACTIONS(2583),
    [aux_sym_record_type_token1] = ACTIONS(2581),
    [aux_sym_basic_type_token21] = ACTIONS(2581),
    [aux_sym_basic_type_token22] = ACTIONS(2581),
    [aux_sym_basic_type_token48] = ACTIONS(2581),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2581),
    [anon_sym_POUNDif] = ACTIONS(2583),
    [anon_sym_POUNDIF] = ACTIONS(2583),
    [anon_sym_POUNDIf] = ACTIONS(2583),
    [anon_sym_not] = ACTIONS(2581),
    [anon_sym_NOT] = ACTIONS(2581),
    [anon_sym_Not] = ACTIONS(2581),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2583),
    [aux_sym__expression_token1] = ACTIONS(2583),
    [aux_sym__expression_token2] = ACTIONS(2581),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2581),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2581),
    [anon_sym_SLASH] = ACTIONS(2581),
    [anon_sym_div] = ACTIONS(2581),
    [anon_sym_DIV] = ACTIONS(2581),
    [anon_sym_Div] = ACTIONS(2581),
    [anon_sym_mod] = ACTIONS(2581),
    [anon_sym_MOD] = ACTIONS(2581),
    [anon_sym_Mod] = ACTIONS(2581),
    [anon_sym_PLUS] = ACTIONS(2581),
    [anon_sym_GT_EQ] = ACTIONS(2583),
    [anon_sym_LT_EQ] = ACTIONS(2583),
    [anon_sym_GT] = ACTIONS(2581),
    [anon_sym_LT] = ACTIONS(2581),
    [anon_sym_LT_GT] = ACTIONS(2583),
    [anon_sym_and] = ACTIONS(2581),
    [anon_sym_AND] = ACTIONS(2581),
    [anon_sym_And] = ACTIONS(2581),
    [anon_sym_or] = ACTIONS(2581),
    [anon_sym_OR] = ACTIONS(2581),
    [anon_sym_Or] = ACTIONS(2581),
    [anon_sym_xor] = ACTIONS(2581),
    [anon_sym_XOR] = ACTIONS(2581),
    [anon_sym_Xor] = ACTIONS(2581),
    [anon_sym_QMARK] = ACTIONS(2583),
    [sym_datetime_literal] = ACTIONS(2583),
    [sym_date_literal] = ACTIONS(2581),
    [sym_time_literal] = ACTIONS(2581),
    [sym_biginteger_literal] = ACTIONS(2583),
    [anon_sym_if] = ACTIONS(2581),
    [anon_sym_IF] = ACTIONS(2581),
    [anon_sym_If] = ACTIONS(2581),
    [anon_sym_else] = ACTIONS(2581),
    [anon_sym_ELSE] = ACTIONS(2581),
    [anon_sym_Else] = ACTIONS(2581),
    [anon_sym_case] = ACTIONS(2581),
    [anon_sym_CASE] = ACTIONS(2581),
    [anon_sym_Case] = ACTIONS(2581),
    [anon_sym_for] = ACTIONS(2581),
    [anon_sym_FOR] = ACTIONS(2581),
    [anon_sym_For] = ACTIONS(2581),
    [anon_sym_foreach] = ACTIONS(2581),
    [anon_sym_FOREACH] = ACTIONS(2581),
    [anon_sym_Foreach] = ACTIONS(2581),
    [anon_sym_while] = ACTIONS(2581),
    [anon_sym_WHILE] = ACTIONS(2581),
    [anon_sym_While] = ACTIONS(2581),
    [anon_sym_repeat] = ACTIONS(2581),
    [anon_sym_REPEAT] = ACTIONS(2581),
    [anon_sym_Repeat] = ACTIONS(2581),
    [anon_sym_exit] = ACTIONS(2581),
    [anon_sym_EXIT] = ACTIONS(2581),
    [anon_sym_Exit] = ACTIONS(2581),
    [anon_sym_continue] = ACTIONS(2581),
    [anon_sym_CONTINUE] = ACTIONS(2581),
    [anon_sym_Continue] = ACTIONS(2581),
    [anon_sym_break] = ACTIONS(2581),
    [anon_sym_BREAK] = ACTIONS(2581),
    [anon_sym_Break] = ACTIONS(2581),
    [anon_sym_with] = ACTIONS(2581),
    [anon_sym_WITH] = ACTIONS(2581),
    [anon_sym_With] = ACTIONS(2581),
    [sym_asserterror_keyword] = ACTIONS(2583),
    [anon_sym_in] = ACTIONS(2581),
    [anon_sym_IN] = ACTIONS(2581),
    [anon_sym_In] = ACTIONS(2581),
    [sym_page_keyword] = ACTIONS(2581),
    [anon_sym_codeunit] = ACTIONS(2581),
    [anon_sym_CODEUNIT] = ACTIONS(2581),
    [anon_sym_Codeunit] = ACTIONS(2581),
    [anon_sym_CodeUnit] = ACTIONS(2581),
    [anon_sym_COdeunit] = ACTIONS(2581),
    [anon_sym_codeUnit] = ACTIONS(2581),
    [sym_report_keyword] = ACTIONS(2581),
    [sym_query_keyword] = ACTIONS(2581),
    [anon_sym_xmlport] = ACTIONS(2581),
    [anon_sym_XMLPORT] = ACTIONS(2581),
    [anon_sym_Xmlport] = ACTIONS(2581),
    [anon_sym_XMLport] = ACTIONS(2581),
    [anon_sym_XMLPort] = ACTIONS(2581),
    [anon_sym_XmlPort] = ACTIONS(2581),
    [anon_sym_enum] = ACTIONS(2581),
    [anon_sym_ENUM] = ACTIONS(2581),
    [anon_sym_Enum] = ACTIONS(2581),
    [anon_sym_eNUM] = ACTIONS(2581),
    [anon_sym_eNum] = ACTIONS(2581),
    [anon_sym_ENum] = ACTIONS(2581),
    [sym_quoted_identifier] = ACTIONS(2583),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2583),
    [sym_integer] = ACTIONS(2581),
    [sym_continue_as_identifier] = ACTIONS(2583),
    [sym_preproc_open] = ACTIONS(2583),
    [sym_end_keyword] = ACTIONS(2583),
  },
  [STATE(1242)] = {
    [sym_identifier] = ACTIONS(2569),
    [anon_sym_SEMI] = ACTIONS(2571),
    [anon_sym_DOT] = ACTIONS(2569),
    [anon_sym_EQ] = ACTIONS(2571),
    [anon_sym_DASH] = ACTIONS(2569),
    [aux_sym_boolean_token1] = ACTIONS(2569),
    [aux_sym_boolean_token2] = ACTIONS(2569),
    [sym_decimal] = ACTIONS(2569),
    [anon_sym_LPAREN] = ACTIONS(2571),
    [anon_sym_DOT_DOT] = ACTIONS(2571),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2569),
    [anon_sym_STAR] = ACTIONS(2569),
    [anon_sym_LBRACK] = ACTIONS(2571),
    [aux_sym_record_type_token1] = ACTIONS(2569),
    [aux_sym_basic_type_token21] = ACTIONS(2569),
    [aux_sym_basic_type_token22] = ACTIONS(2569),
    [aux_sym_basic_type_token48] = ACTIONS(2569),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2569),
    [anon_sym_POUNDif] = ACTIONS(2571),
    [anon_sym_POUNDIF] = ACTIONS(2571),
    [anon_sym_POUNDIf] = ACTIONS(2571),
    [anon_sym_not] = ACTIONS(2569),
    [anon_sym_NOT] = ACTIONS(2569),
    [anon_sym_Not] = ACTIONS(2569),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2571),
    [aux_sym__expression_token1] = ACTIONS(2571),
    [aux_sym__expression_token2] = ACTIONS(2569),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2569),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2569),
    [anon_sym_SLASH] = ACTIONS(2569),
    [anon_sym_div] = ACTIONS(2569),
    [anon_sym_DIV] = ACTIONS(2569),
    [anon_sym_Div] = ACTIONS(2569),
    [anon_sym_mod] = ACTIONS(2569),
    [anon_sym_MOD] = ACTIONS(2569),
    [anon_sym_Mod] = ACTIONS(2569),
    [anon_sym_PLUS] = ACTIONS(2569),
    [anon_sym_GT_EQ] = ACTIONS(2571),
    [anon_sym_LT_EQ] = ACTIONS(2571),
    [anon_sym_GT] = ACTIONS(2569),
    [anon_sym_LT] = ACTIONS(2569),
    [anon_sym_LT_GT] = ACTIONS(2571),
    [anon_sym_and] = ACTIONS(2569),
    [anon_sym_AND] = ACTIONS(2569),
    [anon_sym_And] = ACTIONS(2569),
    [anon_sym_or] = ACTIONS(2569),
    [anon_sym_OR] = ACTIONS(2569),
    [anon_sym_Or] = ACTIONS(2569),
    [anon_sym_xor] = ACTIONS(2569),
    [anon_sym_XOR] = ACTIONS(2569),
    [anon_sym_Xor] = ACTIONS(2569),
    [anon_sym_QMARK] = ACTIONS(2571),
    [sym_datetime_literal] = ACTIONS(2571),
    [sym_date_literal] = ACTIONS(2569),
    [sym_time_literal] = ACTIONS(2569),
    [sym_biginteger_literal] = ACTIONS(2571),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_IF] = ACTIONS(2569),
    [anon_sym_If] = ACTIONS(2569),
    [anon_sym_else] = ACTIONS(2569),
    [anon_sym_ELSE] = ACTIONS(2569),
    [anon_sym_Else] = ACTIONS(2569),
    [anon_sym_case] = ACTIONS(2569),
    [anon_sym_CASE] = ACTIONS(2569),
    [anon_sym_Case] = ACTIONS(2569),
    [anon_sym_for] = ACTIONS(2569),
    [anon_sym_FOR] = ACTIONS(2569),
    [anon_sym_For] = ACTIONS(2569),
    [anon_sym_foreach] = ACTIONS(2569),
    [anon_sym_FOREACH] = ACTIONS(2569),
    [anon_sym_Foreach] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2569),
    [anon_sym_WHILE] = ACTIONS(2569),
    [anon_sym_While] = ACTIONS(2569),
    [anon_sym_repeat] = ACTIONS(2569),
    [anon_sym_REPEAT] = ACTIONS(2569),
    [anon_sym_Repeat] = ACTIONS(2569),
    [anon_sym_exit] = ACTIONS(2569),
    [anon_sym_EXIT] = ACTIONS(2569),
    [anon_sym_Exit] = ACTIONS(2569),
    [anon_sym_continue] = ACTIONS(2569),
    [anon_sym_CONTINUE] = ACTIONS(2569),
    [anon_sym_Continue] = ACTIONS(2569),
    [anon_sym_break] = ACTIONS(2569),
    [anon_sym_BREAK] = ACTIONS(2569),
    [anon_sym_Break] = ACTIONS(2569),
    [anon_sym_with] = ACTIONS(2569),
    [anon_sym_WITH] = ACTIONS(2569),
    [anon_sym_With] = ACTIONS(2569),
    [sym_asserterror_keyword] = ACTIONS(2571),
    [anon_sym_in] = ACTIONS(2569),
    [anon_sym_IN] = ACTIONS(2569),
    [anon_sym_In] = ACTIONS(2569),
    [sym_page_keyword] = ACTIONS(2569),
    [anon_sym_codeunit] = ACTIONS(2569),
    [anon_sym_CODEUNIT] = ACTIONS(2569),
    [anon_sym_Codeunit] = ACTIONS(2569),
    [anon_sym_CodeUnit] = ACTIONS(2569),
    [anon_sym_COdeunit] = ACTIONS(2569),
    [anon_sym_codeUnit] = ACTIONS(2569),
    [sym_report_keyword] = ACTIONS(2569),
    [sym_query_keyword] = ACTIONS(2569),
    [anon_sym_xmlport] = ACTIONS(2569),
    [anon_sym_XMLPORT] = ACTIONS(2569),
    [anon_sym_Xmlport] = ACTIONS(2569),
    [anon_sym_XMLport] = ACTIONS(2569),
    [anon_sym_XMLPort] = ACTIONS(2569),
    [anon_sym_XmlPort] = ACTIONS(2569),
    [anon_sym_enum] = ACTIONS(2569),
    [anon_sym_ENUM] = ACTIONS(2569),
    [anon_sym_Enum] = ACTIONS(2569),
    [anon_sym_eNUM] = ACTIONS(2569),
    [anon_sym_eNum] = ACTIONS(2569),
    [anon_sym_ENum] = ACTIONS(2569),
    [sym_quoted_identifier] = ACTIONS(2571),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2571),
    [sym_integer] = ACTIONS(2569),
    [sym_continue_as_identifier] = ACTIONS(2571),
    [sym_preproc_open] = ACTIONS(2571),
    [sym_end_keyword] = ACTIONS(2571),
  },
  [STATE(1243)] = {
    [sym_identifier] = ACTIONS(2619),
    [anon_sym_SEMI] = ACTIONS(2621),
    [anon_sym_DOT] = ACTIONS(2619),
    [anon_sym_EQ] = ACTIONS(2621),
    [anon_sym_DASH] = ACTIONS(2619),
    [aux_sym_boolean_token1] = ACTIONS(2619),
    [aux_sym_boolean_token2] = ACTIONS(2619),
    [sym_decimal] = ACTIONS(2619),
    [anon_sym_LPAREN] = ACTIONS(2621),
    [anon_sym_DOT_DOT] = ACTIONS(2621),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2619),
    [anon_sym_STAR] = ACTIONS(2619),
    [anon_sym_LBRACK] = ACTIONS(2839),
    [aux_sym_record_type_token1] = ACTIONS(2619),
    [aux_sym_basic_type_token21] = ACTIONS(2619),
    [aux_sym_basic_type_token22] = ACTIONS(2619),
    [aux_sym_basic_type_token48] = ACTIONS(2619),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2619),
    [anon_sym_POUNDif] = ACTIONS(2621),
    [anon_sym_POUNDIF] = ACTIONS(2621),
    [anon_sym_POUNDIf] = ACTIONS(2621),
    [anon_sym_not] = ACTIONS(2619),
    [anon_sym_NOT] = ACTIONS(2619),
    [anon_sym_Not] = ACTIONS(2619),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2621),
    [aux_sym__expression_token1] = ACTIONS(2621),
    [aux_sym__expression_token2] = ACTIONS(2619),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2619),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2619),
    [anon_sym_SLASH] = ACTIONS(2619),
    [anon_sym_div] = ACTIONS(2619),
    [anon_sym_DIV] = ACTIONS(2619),
    [anon_sym_Div] = ACTIONS(2619),
    [anon_sym_mod] = ACTIONS(2619),
    [anon_sym_MOD] = ACTIONS(2619),
    [anon_sym_Mod] = ACTIONS(2619),
    [anon_sym_PLUS] = ACTIONS(2619),
    [anon_sym_GT_EQ] = ACTIONS(2621),
    [anon_sym_LT_EQ] = ACTIONS(2621),
    [anon_sym_GT] = ACTIONS(2619),
    [anon_sym_LT] = ACTIONS(2619),
    [anon_sym_LT_GT] = ACTIONS(2621),
    [anon_sym_and] = ACTIONS(2619),
    [anon_sym_AND] = ACTIONS(2619),
    [anon_sym_And] = ACTIONS(2619),
    [anon_sym_or] = ACTIONS(2619),
    [anon_sym_OR] = ACTIONS(2619),
    [anon_sym_Or] = ACTIONS(2619),
    [anon_sym_xor] = ACTIONS(2619),
    [anon_sym_XOR] = ACTIONS(2619),
    [anon_sym_Xor] = ACTIONS(2619),
    [anon_sym_QMARK] = ACTIONS(2621),
    [sym_datetime_literal] = ACTIONS(2621),
    [sym_date_literal] = ACTIONS(2619),
    [sym_time_literal] = ACTIONS(2619),
    [sym_biginteger_literal] = ACTIONS(2621),
    [anon_sym_if] = ACTIONS(2619),
    [anon_sym_IF] = ACTIONS(2619),
    [anon_sym_If] = ACTIONS(2619),
    [anon_sym_else] = ACTIONS(2619),
    [anon_sym_ELSE] = ACTIONS(2619),
    [anon_sym_Else] = ACTIONS(2619),
    [anon_sym_case] = ACTIONS(2619),
    [anon_sym_CASE] = ACTIONS(2619),
    [anon_sym_Case] = ACTIONS(2619),
    [anon_sym_for] = ACTIONS(2619),
    [anon_sym_FOR] = ACTIONS(2619),
    [anon_sym_For] = ACTIONS(2619),
    [anon_sym_foreach] = ACTIONS(2619),
    [anon_sym_FOREACH] = ACTIONS(2619),
    [anon_sym_Foreach] = ACTIONS(2619),
    [anon_sym_while] = ACTIONS(2619),
    [anon_sym_WHILE] = ACTIONS(2619),
    [anon_sym_While] = ACTIONS(2619),
    [anon_sym_repeat] = ACTIONS(2619),
    [anon_sym_REPEAT] = ACTIONS(2619),
    [anon_sym_Repeat] = ACTIONS(2619),
    [anon_sym_exit] = ACTIONS(2619),
    [anon_sym_EXIT] = ACTIONS(2619),
    [anon_sym_Exit] = ACTIONS(2619),
    [anon_sym_continue] = ACTIONS(2619),
    [anon_sym_CONTINUE] = ACTIONS(2619),
    [anon_sym_Continue] = ACTIONS(2619),
    [anon_sym_break] = ACTIONS(2619),
    [anon_sym_BREAK] = ACTIONS(2619),
    [anon_sym_Break] = ACTIONS(2619),
    [anon_sym_with] = ACTIONS(2619),
    [anon_sym_WITH] = ACTIONS(2619),
    [anon_sym_With] = ACTIONS(2619),
    [sym_asserterror_keyword] = ACTIONS(2621),
    [anon_sym_in] = ACTIONS(2619),
    [anon_sym_IN] = ACTIONS(2619),
    [anon_sym_In] = ACTIONS(2619),
    [sym_page_keyword] = ACTIONS(2619),
    [anon_sym_codeunit] = ACTIONS(2619),
    [anon_sym_CODEUNIT] = ACTIONS(2619),
    [anon_sym_Codeunit] = ACTIONS(2619),
    [anon_sym_CodeUnit] = ACTIONS(2619),
    [anon_sym_COdeunit] = ACTIONS(2619),
    [anon_sym_codeUnit] = ACTIONS(2619),
    [sym_report_keyword] = ACTIONS(2619),
    [sym_query_keyword] = ACTIONS(2619),
    [anon_sym_xmlport] = ACTIONS(2619),
    [anon_sym_XMLPORT] = ACTIONS(2619),
    [anon_sym_Xmlport] = ACTIONS(2619),
    [anon_sym_XMLport] = ACTIONS(2619),
    [anon_sym_XMLPort] = ACTIONS(2619),
    [anon_sym_XmlPort] = ACTIONS(2619),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_ENUM] = ACTIONS(2619),
    [anon_sym_Enum] = ACTIONS(2619),
    [anon_sym_eNUM] = ACTIONS(2619),
    [anon_sym_eNum] = ACTIONS(2619),
    [anon_sym_ENum] = ACTIONS(2619),
    [sym_quoted_identifier] = ACTIONS(2621),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2621),
    [sym_integer] = ACTIONS(2619),
    [sym_continue_as_identifier] = ACTIONS(2621),
    [sym_preproc_open] = ACTIONS(2621),
    [sym_end_keyword] = ACTIONS(2621),
  },
  [STATE(1244)] = {
    [ts_builtin_sym_end] = ACTIONS(2841),
    [sym_identifier] = ACTIONS(2843),
    [anon_sym_SEMI] = ACTIONS(2841),
    [anon_sym_LBRACE] = ACTIONS(2841),
    [anon_sym_RBRACE] = ACTIONS(2841),
    [anon_sym_RPAREN] = ACTIONS(2841),
    [aux_sym_where_condition_token1] = ACTIONS(2843),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2843),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2843),
    [anon_sym_LBRACK] = ACTIONS(2841),
    [aux_sym_basic_type_token6] = ACTIONS(2843),
    [aux_sym_basic_type_token22] = ACTIONS(2843),
    [aux_sym_basic_type_token53] = ACTIONS(2843),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2843),
    [aux_sym_addafter_modification_token1] = ACTIONS(2843),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2843),
    [aux_sym_modify_modification_token1] = ACTIONS(2843),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2843),
    [aux_sym_movelast_modification_token1] = ACTIONS(2843),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2843),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2843),
    [aux_sym_separator_action_token1] = ACTIONS(2843),
    [aux_sym_add_dataset_modification_token1] = ACTIONS(2843),
    [aux_sym_type_declaration_token1] = ACTIONS(2843),
    [anon_sym_POUNDif] = ACTIONS(2841),
    [anon_sym_POUNDIF] = ACTIONS(2841),
    [anon_sym_POUNDIf] = ACTIONS(2841),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2843),
    [anon_sym_tableextension] = ACTIONS(2843),
    [anon_sym_TABLEEXTENSION] = ACTIONS(2843),
    [anon_sym_Tableextension] = ACTIONS(2843),
    [anon_sym_TableExtension] = ACTIONS(2843),
    [anon_sym_tableExtension] = ACTIONS(2843),
    [sym_page_keyword] = ACTIONS(2843),
    [anon_sym_pageextension] = ACTIONS(2843),
    [anon_sym_PAGEEXTENSION] = ACTIONS(2843),
    [anon_sym_Pageextension] = ACTIONS(2843),
    [anon_sym_PageExtension] = ACTIONS(2843),
    [anon_sym_pageExtension] = ACTIONS(2843),
    [anon_sym_codeunit] = ACTIONS(2843),
    [anon_sym_CODEUNIT] = ACTIONS(2843),
    [anon_sym_Codeunit] = ACTIONS(2843),
    [anon_sym_CodeUnit] = ACTIONS(2843),
    [anon_sym_COdeunit] = ACTIONS(2843),
    [anon_sym_codeUnit] = ACTIONS(2843),
    [sym_report_keyword] = ACTIONS(2843),
    [anon_sym_reportextension] = ACTIONS(2843),
    [anon_sym_REPORTEXTENSION] = ACTIONS(2843),
    [anon_sym_Reportextension] = ACTIONS(2843),
    [anon_sym_ReportExtension] = ACTIONS(2843),
    [anon_sym_reportExtension] = ACTIONS(2843),
    [sym_query_keyword] = ACTIONS(2843),
    [anon_sym_xmlport] = ACTIONS(2843),
    [anon_sym_XMLPORT] = ACTIONS(2843),
    [anon_sym_Xmlport] = ACTIONS(2843),
    [anon_sym_XMLport] = ACTIONS(2843),
    [anon_sym_XMLPort] = ACTIONS(2843),
    [anon_sym_XmlPort] = ACTIONS(2843),
    [anon_sym_enum] = ACTIONS(2843),
    [anon_sym_ENUM] = ACTIONS(2843),
    [anon_sym_Enum] = ACTIONS(2843),
    [anon_sym_eNUM] = ACTIONS(2843),
    [anon_sym_eNum] = ACTIONS(2843),
    [anon_sym_ENum] = ACTIONS(2843),
    [anon_sym_enumextension] = ACTIONS(2843),
    [anon_sym_ENUMEXTENSION] = ACTIONS(2843),
    [anon_sym_Enumextension] = ACTIONS(2843),
    [anon_sym_EnumExtension] = ACTIONS(2843),
    [anon_sym_enumExtension] = ACTIONS(2843),
    [sym_interface_keyword] = ACTIONS(2843),
    [anon_sym_controladdin] = ACTIONS(2843),
    [anon_sym_CONTROLADDIN] = ACTIONS(2843),
    [anon_sym_Controladdin] = ACTIONS(2843),
    [anon_sym_ControlAddIn] = ACTIONS(2843),
    [anon_sym_ControlAddin] = ACTIONS(2843),
    [anon_sym_controlAddIn] = ACTIONS(2843),
    [anon_sym_controlAddin] = ACTIONS(2843),
    [anon_sym_dotnet] = ACTIONS(2843),
    [anon_sym_DOTNET] = ACTIONS(2843),
    [anon_sym_Dotnet] = ACTIONS(2843),
    [anon_sym_DotNet] = ACTIONS(2843),
    [anon_sym_dotNet] = ACTIONS(2843),
    [sym_profile_keyword] = ACTIONS(2843),
    [anon_sym_profileextension] = ACTIONS(2843),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(2843),
    [anon_sym_Profileextension] = ACTIONS(2843),
    [anon_sym_ProfileExtension] = ACTIONS(2843),
    [anon_sym_profileExtension] = ACTIONS(2843),
    [anon_sym_permissionset] = ACTIONS(2843),
    [anon_sym_PERMISSIONSET] = ACTIONS(2843),
    [anon_sym_Permissionset] = ACTIONS(2843),
    [anon_sym_PermissionSet] = ACTIONS(2843),
    [anon_sym_permissionSet] = ACTIONS(2843),
    [anon_sym_permissionsetextension] = ACTIONS(2843),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(2843),
    [anon_sym_Permissionsetextension] = ACTIONS(2843),
    [anon_sym_PermissionSetExtension] = ACTIONS(2843),
    [anon_sym_permissionSetExtension] = ACTIONS(2843),
    [sym_entitlement_keyword] = ACTIONS(2843),
    [anon_sym_pagecustomization] = ACTIONS(2843),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(2843),
    [anon_sym_Pagecustomization] = ACTIONS(2843),
    [anon_sym_PageCustomization] = ACTIONS(2843),
    [anon_sym_pageCustomization] = ACTIONS(2843),
    [sym_using_keyword] = ACTIONS(2843),
    [sym_key_keyword] = ACTIONS(2843),
    [sym_area_keyword] = ACTIONS(2843),
    [sym_group_keyword] = ACTIONS(2843),
    [sym_repeater_keyword] = ACTIONS(2843),
    [sym_cuegroup_keyword] = ACTIONS(2843),
    [sym_fixed_keyword] = ACTIONS(2843),
    [sym_grid_keyword] = ACTIONS(2843),
    [sym_part_keyword] = ACTIONS(2843),
    [sym_systempart_keyword] = ACTIONS(2843),
    [sym_usercontrol_keyword] = ACTIONS(2843),
    [sym_dataset_keyword] = ACTIONS(2843),
    [sym_dataitem_keyword] = ACTIONS(2843),
    [sym_quoted_identifier] = ACTIONS(2841),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(2841),
  },
  [STATE(1245)] = {
    [sym__body_element] = STATE(4061),
    [sym_empty_statement] = STATE(4061),
    [sym_property] = STATE(4061),
    [sym_fields_section] = STATE(4061),
    [sym_keys_section] = STATE(4061),
    [sym_fieldgroups_section] = STATE(4061),
    [sym_enum_value_declaration] = STATE(4061),
    [sym_labels_section] = STATE(4061),
    [sym_layout_section] = STATE(4061),
    [sym__layout_element] = STATE(4062),
    [sym_area_section] = STATE(4062),
    [sym_group_section] = STATE(4062),
    [sym_repeater_section] = STATE(4062),
    [sym_cuegroup_section] = STATE(4062),
    [sym_fixed_section] = STATE(4062),
    [sym_grid_section] = STATE(4062),
    [sym_page_field] = STATE(4062),
    [sym_part_section] = STATE(4062),
    [sym_systempart_section] = STATE(4062),
    [sym_usercontrol_section] = STATE(4062),
    [sym_preproc_split_field] = STATE(4062),
    [sym__field_header] = STATE(7840),
    [sym_label_section] = STATE(4062),
    [sym_addfirst_modification] = STATE(4062),
    [sym_addlast_modification] = STATE(4062),
    [sym_addafter_modification] = STATE(4062),
    [sym_addbefore_modification] = STATE(4062),
    [sym_modify_modification] = STATE(4059),
    [sym_movefirst_modification] = STATE(4062),
    [sym_movelast_modification] = STATE(4062),
    [sym_moveafter_modification] = STATE(4062),
    [sym_movebefore_modification] = STATE(4062),
    [sym_actions_section] = STATE(4061),
    [sym_views_section] = STATE(4061),
    [sym_dataset_section] = STATE(4061),
    [sym_requestpage_section] = STATE(4061),
    [sym_rendering_section] = STATE(4061),
    [sym_elements_section] = STATE(4061),
    [sym_schema_section] = STATE(4061),
    [sym_assembly_declaration] = STATE(4061),
    [sym_event_declaration] = STATE(4061),
    [sym_procedure] = STATE(4061),
    [sym_preproc_split_procedure] = STATE(4061),
    [sym__procedure_header] = STATE(8087),
    [sym_procedure_modifier] = STATE(12657),
    [sym_trigger_declaration] = STATE(4061),
    [sym_var_section] = STATE(4061),
    [sym_attribute_item] = STATE(3722),
    [sym_preproc_conditional] = STATE(4061),
    [sym_preproc_if] = STATE(1250),
    [sym_preproc_elif] = STATE(1367),
    [sym_preproc_else] = STATE(1381),
    [sym_preproc_endif] = STATE(4995),
    [sym_preproc_conditional_layout] = STATE(4062),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(2739),
    [aux_sym_layout_section_repeat1] = STATE(3445),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_repeat1] = STATE(8094),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7841),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(1366),
    [aux_sym_preproc_conditional_layout_mixed_repeat2] = STATE(7942),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_where_condition_token1] = ACTIONS(2847),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2849),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2851),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token6] = ACTIONS(2855),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(2859),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2861),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2865),
    [aux_sym_movelast_modification_token1] = ACTIONS(2867),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2869),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2871),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(2883),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(2905),
    [sym_group_keyword] = ACTIONS(2907),
    [sym_repeater_keyword] = ACTIONS(2909),
    [sym_cuegroup_keyword] = ACTIONS(2911),
    [sym_fixed_keyword] = ACTIONS(2913),
    [sym_grid_keyword] = ACTIONS(2915),
    [sym_part_keyword] = ACTIONS(2917),
    [sym_systempart_keyword] = ACTIONS(2919),
    [sym_usercontrol_keyword] = ACTIONS(2921),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(1246)] = {
    [sym_boolean] = STATE(1498),
    [sym_option_member_list] = STATE(1512),
    [sym_option_member] = STATE(1441),
    [sym_keyword_identifier] = STATE(1498),
    [sym_codeunit_keyword] = STATE(1440),
    [sym_xmlport_keyword] = STATE(1440),
    [sym_enum_keyword] = STATE(1440),
    [sym_keyword_as_identifier] = STATE(1498),
    [aux_sym_option_member_list_repeat2] = STATE(1248),
    [sym_identifier] = ACTIONS(2939),
    [anon_sym_SEMI] = ACTIONS(275),
    [anon_sym_DOT] = ACTIONS(277),
    [anon_sym_EQ] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(2941),
    [anon_sym_COLON] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(2943),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(275),
    [aux_sym_where_condition_token1] = ACTIONS(2945),
    [anon_sym_DOT_DOT] = ACTIONS(275),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(275),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(2947),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_basic_type_token53] = ACTIONS(2945),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2945),
    [aux_sym_separator_action_token1] = ACTIONS(2945),
    [aux_sym_type_declaration_token1] = ACTIONS(2945),
    [anon_sym_POUNDif] = ACTIONS(275),
    [anon_sym_POUNDIF] = ACTIONS(275),
    [anon_sym_POUNDIf] = ACTIONS(275),
    [anon_sym_not] = ACTIONS(277),
    [anon_sym_NOT] = ACTIONS(277),
    [anon_sym_Not] = ACTIONS(277),
    [anon_sym_POUNDelif] = ACTIONS(275),
    [anon_sym_POUNDELIF] = ACTIONS(275),
    [anon_sym_POUNDElif] = ACTIONS(275),
    [anon_sym_POUNDelse] = ACTIONS(275),
    [anon_sym_POUNDELSE] = ACTIONS(275),
    [anon_sym_POUNDElse] = ACTIONS(275),
    [anon_sym_POUNDendif] = ACTIONS(275),
    [anon_sym_POUNDENDIF] = ACTIONS(275),
    [anon_sym_POUNDEndif] = ACTIONS(275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(275),
    [aux_sym__expression_token1] = ACTIONS(275),
    [aux_sym__expression_token2] = ACTIONS(275),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(582),
    [anon_sym_SLASH] = ACTIONS(277),
    [anon_sym_div] = ACTIONS(277),
    [anon_sym_DIV] = ACTIONS(277),
    [anon_sym_Div] = ACTIONS(277),
    [anon_sym_mod] = ACTIONS(277),
    [anon_sym_MOD] = ACTIONS(277),
    [anon_sym_Mod] = ACTIONS(277),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(275),
    [anon_sym_LT_EQ] = ACTIONS(275),
    [anon_sym_GT] = ACTIONS(277),
    [anon_sym_LT] = ACTIONS(277),
    [anon_sym_LT_GT] = ACTIONS(275),
    [anon_sym_and] = ACTIONS(277),
    [anon_sym_AND] = ACTIONS(277),
    [anon_sym_And] = ACTIONS(277),
    [anon_sym_or] = ACTIONS(277),
    [anon_sym_OR] = ACTIONS(277),
    [anon_sym_Or] = ACTIONS(277),
    [anon_sym_xor] = ACTIONS(277),
    [anon_sym_XOR] = ACTIONS(277),
    [anon_sym_Xor] = ACTIONS(277),
    [anon_sym_QMARK] = ACTIONS(275),
    [sym_datetime_literal] = ACTIONS(275),
    [sym_date_literal] = ACTIONS(277),
    [sym_time_literal] = ACTIONS(277),
    [sym_biginteger_literal] = ACTIONS(275),
    [anon_sym_else] = ACTIONS(277),
    [anon_sym_ELSE] = ACTIONS(277),
    [anon_sym_Else] = ACTIONS(277),
    [anon_sym_in] = ACTIONS(277),
    [anon_sym_IN] = ACTIONS(277),
    [anon_sym_In] = ACTIONS(277),
    [sym_page_keyword] = ACTIONS(582),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(582),
    [sym_query_keyword] = ACTIONS(582),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_local_keyword] = ACTIONS(2939),
    [sym_internal_keyword] = ACTIONS(2939),
    [sym_protected_keyword] = ACTIONS(2939),
    [sym_key_keyword] = ACTIONS(2945),
    [sym_dataset_keyword] = ACTIONS(2945),
    [sym_quoted_identifier] = ACTIONS(2949),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2949),
    [sym_integer] = ACTIONS(2939),
    [sym_continue_as_identifier] = ACTIONS(275),
    [sym_preproc_open] = ACTIONS(275),
    [sym_preproc_close] = ACTIONS(275),
  },
  [STATE(1247)] = {
    [sym_boolean] = STATE(1091),
    [sym_code_block] = STATE(1910),
    [sym_assignment_expression] = STATE(1091),
    [sym__expression] = STATE(1091),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1091),
    [sym_multiplicative_expression] = STATE(1091),
    [sym_additive_expression] = STATE(1091),
    [sym_comparison_expression] = STATE(1091),
    [sym_logical_expression] = STATE(1091),
    [sym_ternary_expression] = STATE(1091),
    [sym_unary_expression] = STATE(1091),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1091),
    [sym_list_literal] = STATE(1091),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1091),
    [sym__literal_value] = STATE(1091),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_SEMI] = ACTIONS(2735),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(2951),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2739),
    [anon_sym_POUNDif] = ACTIONS(2735),
    [anon_sym_POUNDIF] = ACTIONS(2735),
    [anon_sym_POUNDIf] = ACTIONS(2735),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [anon_sym_POUNDelse] = ACTIONS(2735),
    [anon_sym_POUNDELSE] = ACTIONS(2735),
    [anon_sym_POUNDElse] = ACTIONS(2735),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(2953),
    [sym_date_literal] = ACTIONS(2951),
    [sym_time_literal] = ACTIONS(2951),
    [sym_biginteger_literal] = ACTIONS(2953),
    [anon_sym_if] = ACTIONS(2739),
    [anon_sym_IF] = ACTIONS(2739),
    [anon_sym_If] = ACTIONS(2739),
    [anon_sym_else] = ACTIONS(2739),
    [anon_sym_ELSE] = ACTIONS(2739),
    [anon_sym_Else] = ACTIONS(2739),
    [anon_sym_case] = ACTIONS(2739),
    [anon_sym_CASE] = ACTIONS(2739),
    [anon_sym_Case] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2739),
    [anon_sym_FOR] = ACTIONS(2739),
    [anon_sym_For] = ACTIONS(2739),
    [anon_sym_foreach] = ACTIONS(2739),
    [anon_sym_FOREACH] = ACTIONS(2739),
    [anon_sym_Foreach] = ACTIONS(2739),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_WHILE] = ACTIONS(2739),
    [anon_sym_While] = ACTIONS(2739),
    [anon_sym_repeat] = ACTIONS(2739),
    [anon_sym_REPEAT] = ACTIONS(2739),
    [anon_sym_Repeat] = ACTIONS(2739),
    [anon_sym_until] = ACTIONS(2739),
    [anon_sym_UNTIL] = ACTIONS(2739),
    [anon_sym_Until] = ACTIONS(2739),
    [anon_sym_exit] = ACTIONS(2739),
    [anon_sym_EXIT] = ACTIONS(2739),
    [anon_sym_Exit] = ACTIONS(2739),
    [anon_sym_continue] = ACTIONS(2739),
    [anon_sym_CONTINUE] = ACTIONS(2739),
    [anon_sym_Continue] = ACTIONS(2739),
    [anon_sym_break] = ACTIONS(2739),
    [anon_sym_BREAK] = ACTIONS(2739),
    [anon_sym_Break] = ACTIONS(2739),
    [anon_sym_with] = ACTIONS(2739),
    [anon_sym_WITH] = ACTIONS(2739),
    [anon_sym_With] = ACTIONS(2739),
    [sym_asserterror_keyword] = ACTIONS(2735),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2953),
    [sym_integer] = ACTIONS(2951),
    [sym_continue_as_identifier] = ACTIONS(2953),
    [sym_preproc_open] = ACTIONS(2735),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(1248)] = {
    [sym_boolean] = STATE(1498),
    [sym_option_member] = STATE(1449),
    [sym_keyword_identifier] = STATE(1498),
    [sym_codeunit_keyword] = STATE(1440),
    [sym_xmlport_keyword] = STATE(1440),
    [sym_enum_keyword] = STATE(1440),
    [sym_keyword_as_identifier] = STATE(1498),
    [aux_sym_option_member_list_repeat2] = STATE(1368),
    [sym_identifier] = ACTIONS(2939),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(2955),
    [anon_sym_COLON] = ACTIONS(376),
    [anon_sym_DASH] = ACTIONS(2943),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(376),
    [anon_sym_LPAREN] = ACTIONS(374),
    [aux_sym_where_condition_token1] = ACTIONS(2945),
    [anon_sym_DOT_DOT] = ACTIONS(374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(2947),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_basic_type_token53] = ACTIONS(2945),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2945),
    [aux_sym_separator_action_token1] = ACTIONS(2945),
    [aux_sym_type_declaration_token1] = ACTIONS(2945),
    [anon_sym_POUNDif] = ACTIONS(374),
    [anon_sym_POUNDIF] = ACTIONS(374),
    [anon_sym_POUNDIf] = ACTIONS(374),
    [anon_sym_not] = ACTIONS(376),
    [anon_sym_NOT] = ACTIONS(376),
    [anon_sym_Not] = ACTIONS(376),
    [anon_sym_POUNDelif] = ACTIONS(374),
    [anon_sym_POUNDELIF] = ACTIONS(374),
    [anon_sym_POUNDElif] = ACTIONS(374),
    [anon_sym_POUNDelse] = ACTIONS(374),
    [anon_sym_POUNDELSE] = ACTIONS(374),
    [anon_sym_POUNDElse] = ACTIONS(374),
    [anon_sym_POUNDendif] = ACTIONS(374),
    [anon_sym_POUNDENDIF] = ACTIONS(374),
    [anon_sym_POUNDEndif] = ACTIONS(374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(374),
    [aux_sym__expression_token1] = ACTIONS(374),
    [aux_sym__expression_token2] = ACTIONS(374),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(582),
    [anon_sym_SLASH] = ACTIONS(376),
    [anon_sym_div] = ACTIONS(376),
    [anon_sym_DIV] = ACTIONS(376),
    [anon_sym_Div] = ACTIONS(376),
    [anon_sym_mod] = ACTIONS(376),
    [anon_sym_MOD] = ACTIONS(376),
    [anon_sym_Mod] = ACTIONS(376),
    [anon_sym_PLUS] = ACTIONS(376),
    [anon_sym_GT_EQ] = ACTIONS(374),
    [anon_sym_LT_EQ] = ACTIONS(374),
    [anon_sym_GT] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(376),
    [anon_sym_LT_GT] = ACTIONS(374),
    [anon_sym_and] = ACTIONS(376),
    [anon_sym_AND] = ACTIONS(376),
    [anon_sym_And] = ACTIONS(376),
    [anon_sym_or] = ACTIONS(376),
    [anon_sym_OR] = ACTIONS(376),
    [anon_sym_Or] = ACTIONS(376),
    [anon_sym_xor] = ACTIONS(376),
    [anon_sym_XOR] = ACTIONS(376),
    [anon_sym_Xor] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(374),
    [sym_datetime_literal] = ACTIONS(374),
    [sym_date_literal] = ACTIONS(376),
    [sym_time_literal] = ACTIONS(376),
    [sym_biginteger_literal] = ACTIONS(374),
    [anon_sym_else] = ACTIONS(376),
    [anon_sym_ELSE] = ACTIONS(376),
    [anon_sym_Else] = ACTIONS(376),
    [anon_sym_in] = ACTIONS(376),
    [anon_sym_IN] = ACTIONS(376),
    [anon_sym_In] = ACTIONS(376),
    [sym_page_keyword] = ACTIONS(582),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(582),
    [sym_query_keyword] = ACTIONS(582),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_local_keyword] = ACTIONS(2939),
    [sym_internal_keyword] = ACTIONS(2939),
    [sym_protected_keyword] = ACTIONS(2939),
    [sym_key_keyword] = ACTIONS(2945),
    [sym_dataset_keyword] = ACTIONS(2945),
    [sym_quoted_identifier] = ACTIONS(2949),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2949),
    [sym_integer] = ACTIONS(2939),
    [sym_continue_as_identifier] = ACTIONS(374),
    [sym_preproc_open] = ACTIONS(374),
    [sym_preproc_close] = ACTIONS(374),
  },
  [STATE(1249)] = {
    [sym__body_element] = STATE(2755),
    [sym_empty_statement] = STATE(2755),
    [sym_property] = STATE(2755),
    [sym_fields_section] = STATE(2755),
    [sym_keys_section] = STATE(2755),
    [sym_fieldgroups_section] = STATE(2755),
    [sym_enum_value_declaration] = STATE(2755),
    [sym_labels_section] = STATE(2755),
    [sym_layout_section] = STATE(2755),
    [sym__layout_element] = STATE(3458),
    [sym_area_section] = STATE(3458),
    [sym_group_section] = STATE(3458),
    [sym_repeater_section] = STATE(3458),
    [sym_cuegroup_section] = STATE(3458),
    [sym_fixed_section] = STATE(3458),
    [sym_grid_section] = STATE(3458),
    [sym_page_field] = STATE(3458),
    [sym_part_section] = STATE(3458),
    [sym_systempart_section] = STATE(3458),
    [sym_usercontrol_section] = STATE(3458),
    [sym_preproc_split_field] = STATE(3458),
    [sym__field_header] = STATE(7888),
    [sym_label_section] = STATE(3458),
    [sym_addfirst_modification] = STATE(3458),
    [sym_addlast_modification] = STATE(3458),
    [sym_addafter_modification] = STATE(3458),
    [sym_addbefore_modification] = STATE(3458),
    [sym_modify_modification] = STATE(4501),
    [sym_movefirst_modification] = STATE(3458),
    [sym_movelast_modification] = STATE(3458),
    [sym_moveafter_modification] = STATE(3458),
    [sym_movebefore_modification] = STATE(3458),
    [sym_actions_section] = STATE(2755),
    [sym_views_section] = STATE(2755),
    [sym_dataset_section] = STATE(2755),
    [sym_requestpage_section] = STATE(2755),
    [sym_rendering_section] = STATE(2755),
    [sym_elements_section] = STATE(2755),
    [sym_schema_section] = STATE(2755),
    [sym_assembly_declaration] = STATE(2755),
    [sym_event_declaration] = STATE(2755),
    [sym_procedure] = STATE(2755),
    [sym_preproc_split_procedure] = STATE(2755),
    [sym__procedure_header] = STATE(8089),
    [sym_procedure_modifier] = STATE(12657),
    [sym_trigger_declaration] = STATE(2755),
    [sym_var_section] = STATE(2755),
    [sym_attribute_item] = STATE(3722),
    [sym_preproc_conditional] = STATE(2755),
    [sym_preproc_if] = STATE(1249),
    [sym_preproc_elif] = STATE(1371),
    [sym_preproc_else] = STATE(1383),
    [sym_preproc_endif] = STATE(4099),
    [sym_preproc_conditional_layout] = STATE(3458),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(2755),
    [aux_sym_layout_section_repeat1] = STATE(3458),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_repeat1] = STATE(8159),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7891),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_where_condition_token1] = ACTIONS(2957),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token6] = ACTIONS(2963),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(2883),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(1250)] = {
    [sym__body_element] = STATE(2755),
    [sym_empty_statement] = STATE(2755),
    [sym_property] = STATE(2755),
    [sym_fields_section] = STATE(2755),
    [sym_keys_section] = STATE(2755),
    [sym_fieldgroups_section] = STATE(2755),
    [sym_enum_value_declaration] = STATE(2755),
    [sym_labels_section] = STATE(2755),
    [sym_layout_section] = STATE(2755),
    [sym__layout_element] = STATE(3462),
    [sym_area_section] = STATE(3462),
    [sym_group_section] = STATE(3462),
    [sym_repeater_section] = STATE(3462),
    [sym_cuegroup_section] = STATE(3462),
    [sym_fixed_section] = STATE(3462),
    [sym_grid_section] = STATE(3462),
    [sym_page_field] = STATE(3462),
    [sym_part_section] = STATE(3462),
    [sym_systempart_section] = STATE(3462),
    [sym_usercontrol_section] = STATE(3462),
    [sym_preproc_split_field] = STATE(3462),
    [sym__field_header] = STATE(7919),
    [sym_label_section] = STATE(3462),
    [sym_addfirst_modification] = STATE(3462),
    [sym_addlast_modification] = STATE(3462),
    [sym_addafter_modification] = STATE(3462),
    [sym_addbefore_modification] = STATE(3462),
    [sym_modify_modification] = STATE(4501),
    [sym_movefirst_modification] = STATE(3462),
    [sym_movelast_modification] = STATE(3462),
    [sym_moveafter_modification] = STATE(3462),
    [sym_movebefore_modification] = STATE(3462),
    [sym_actions_section] = STATE(2755),
    [sym_views_section] = STATE(2755),
    [sym_dataset_section] = STATE(2755),
    [sym_requestpage_section] = STATE(2755),
    [sym_rendering_section] = STATE(2755),
    [sym_elements_section] = STATE(2755),
    [sym_schema_section] = STATE(2755),
    [sym_assembly_declaration] = STATE(2755),
    [sym_event_declaration] = STATE(2755),
    [sym_procedure] = STATE(2755),
    [sym_preproc_split_procedure] = STATE(2755),
    [sym__procedure_header] = STATE(8089),
    [sym_procedure_modifier] = STATE(12657),
    [sym_trigger_declaration] = STATE(2755),
    [sym_var_section] = STATE(2755),
    [sym_attribute_item] = STATE(3722),
    [sym_preproc_conditional] = STATE(2755),
    [sym_preproc_if] = STATE(1249),
    [sym_preproc_elif] = STATE(1371),
    [sym_preproc_else] = STATE(1384),
    [sym_preproc_endif] = STATE(4107),
    [sym_preproc_conditional_layout] = STATE(3462),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(2755),
    [aux_sym_layout_section_repeat1] = STATE(3462),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_repeat1] = STATE(8159),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7920),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_where_condition_token1] = ACTIONS(2957),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token6] = ACTIONS(2963),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(2883),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(1251)] = {
    [sym_boolean] = STATE(1498),
    [sym_option_member] = STATE(1510),
    [sym_keyword_identifier] = STATE(1498),
    [sym_codeunit_keyword] = STATE(1440),
    [sym_xmlport_keyword] = STATE(1440),
    [sym_enum_keyword] = STATE(1440),
    [sym_keyword_as_identifier] = STATE(1498),
    [sym_identifier] = ACTIONS(2997),
    [anon_sym_SEMI] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(391),
    [anon_sym_EQ] = ACTIONS(389),
    [anon_sym_COMMA] = ACTIONS(389),
    [anon_sym_COLON] = ACTIONS(391),
    [anon_sym_DASH] = ACTIONS(3000),
    [aux_sym_boolean_token1] = ACTIONS(3003),
    [aux_sym_boolean_token2] = ACTIONS(3003),
    [sym_decimal] = ACTIONS(391),
    [anon_sym_LPAREN] = ACTIONS(389),
    [aux_sym_where_condition_token1] = ACTIONS(2945),
    [anon_sym_DOT_DOT] = ACTIONS(389),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3006),
    [anon_sym_STAR] = ACTIONS(391),
    [anon_sym_LBRACK] = ACTIONS(389),
    [aux_sym_record_type_token1] = ACTIONS(3006),
    [aux_sym_basic_type_token21] = ACTIONS(3006),
    [aux_sym_basic_type_token22] = ACTIONS(3009),
    [aux_sym_basic_type_token48] = ACTIONS(3006),
    [aux_sym_basic_type_token53] = ACTIONS(2945),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2945),
    [aux_sym_separator_action_token1] = ACTIONS(2945),
    [aux_sym_type_declaration_token1] = ACTIONS(2945),
    [anon_sym_POUNDif] = ACTIONS(389),
    [anon_sym_POUNDIF] = ACTIONS(389),
    [anon_sym_POUNDIf] = ACTIONS(389),
    [anon_sym_not] = ACTIONS(391),
    [anon_sym_NOT] = ACTIONS(391),
    [anon_sym_Not] = ACTIONS(391),
    [anon_sym_POUNDelif] = ACTIONS(389),
    [anon_sym_POUNDELIF] = ACTIONS(389),
    [anon_sym_POUNDElif] = ACTIONS(389),
    [anon_sym_POUNDelse] = ACTIONS(389),
    [anon_sym_POUNDELSE] = ACTIONS(389),
    [anon_sym_POUNDElse] = ACTIONS(389),
    [anon_sym_POUNDendif] = ACTIONS(389),
    [anon_sym_POUNDENDIF] = ACTIONS(389),
    [anon_sym_POUNDEndif] = ACTIONS(389),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(389),
    [aux_sym__expression_token1] = ACTIONS(389),
    [aux_sym__expression_token2] = ACTIONS(389),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3006),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3006),
    [anon_sym_SLASH] = ACTIONS(391),
    [anon_sym_div] = ACTIONS(391),
    [anon_sym_DIV] = ACTIONS(391),
    [anon_sym_Div] = ACTIONS(391),
    [anon_sym_mod] = ACTIONS(391),
    [anon_sym_MOD] = ACTIONS(391),
    [anon_sym_Mod] = ACTIONS(391),
    [anon_sym_PLUS] = ACTIONS(391),
    [anon_sym_GT_EQ] = ACTIONS(389),
    [anon_sym_LT_EQ] = ACTIONS(389),
    [anon_sym_GT] = ACTIONS(391),
    [anon_sym_LT] = ACTIONS(391),
    [anon_sym_LT_GT] = ACTIONS(389),
    [anon_sym_and] = ACTIONS(391),
    [anon_sym_AND] = ACTIONS(391),
    [anon_sym_And] = ACTIONS(391),
    [anon_sym_or] = ACTIONS(391),
    [anon_sym_OR] = ACTIONS(391),
    [anon_sym_Or] = ACTIONS(391),
    [anon_sym_xor] = ACTIONS(391),
    [anon_sym_XOR] = ACTIONS(391),
    [anon_sym_Xor] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(389),
    [sym_datetime_literal] = ACTIONS(389),
    [sym_date_literal] = ACTIONS(391),
    [sym_time_literal] = ACTIONS(391),
    [sym_biginteger_literal] = ACTIONS(389),
    [anon_sym_else] = ACTIONS(391),
    [anon_sym_ELSE] = ACTIONS(391),
    [anon_sym_Else] = ACTIONS(391),
    [anon_sym_in] = ACTIONS(391),
    [anon_sym_IN] = ACTIONS(391),
    [anon_sym_In] = ACTIONS(391),
    [sym_page_keyword] = ACTIONS(3006),
    [anon_sym_codeunit] = ACTIONS(3012),
    [anon_sym_CODEUNIT] = ACTIONS(3012),
    [anon_sym_Codeunit] = ACTIONS(3012),
    [anon_sym_CodeUnit] = ACTIONS(3012),
    [anon_sym_COdeunit] = ACTIONS(3012),
    [anon_sym_codeUnit] = ACTIONS(3012),
    [sym_report_keyword] = ACTIONS(3006),
    [sym_query_keyword] = ACTIONS(3006),
    [anon_sym_xmlport] = ACTIONS(3015),
    [anon_sym_XMLPORT] = ACTIONS(3015),
    [anon_sym_Xmlport] = ACTIONS(3015),
    [anon_sym_XMLport] = ACTIONS(3015),
    [anon_sym_XMLPort] = ACTIONS(3015),
    [anon_sym_XmlPort] = ACTIONS(3015),
    [anon_sym_enum] = ACTIONS(3018),
    [anon_sym_ENUM] = ACTIONS(3018),
    [anon_sym_Enum] = ACTIONS(3018),
    [anon_sym_eNUM] = ACTIONS(3018),
    [anon_sym_eNum] = ACTIONS(3018),
    [anon_sym_ENum] = ACTIONS(3018),
    [sym_local_keyword] = ACTIONS(2939),
    [sym_internal_keyword] = ACTIONS(2939),
    [sym_protected_keyword] = ACTIONS(2939),
    [sym_key_keyword] = ACTIONS(2945),
    [sym_dataset_keyword] = ACTIONS(2945),
    [sym_quoted_identifier] = ACTIONS(3021),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3021),
    [sym_integer] = ACTIONS(2997),
    [sym_continue_as_identifier] = ACTIONS(389),
    [sym_preproc_open] = ACTIONS(389),
    [sym_preproc_close] = ACTIONS(389),
  },
  [STATE(1252)] = {
    [sym_type_specification] = STATE(12568),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1253)] = {
    [sym_type_specification] = STATE(11822),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1254)] = {
    [sym_type_specification] = STATE(11919),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1255)] = {
    [sym_type_specification] = STATE(11259),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(11163),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1256)] = {
    [sym_type_specification] = STATE(11499),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1257)] = {
    [sym_boolean] = STATE(6346),
    [sym_link_value] = STATE(7327),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(7668),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym_preproc_conditional_permissions] = STATE(5958),
    [sym_tabledata_permission] = STATE(6826),
    [sym_implementation_value] = STATE(7268),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1370),
    [sym_preproc_elif] = STATE(1374),
    [sym_preproc_else] = STATE(1386),
    [sym_preproc_endif] = STATE(6840),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4852),
    [sym_xmlport_keyword] = STATE(4852),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7711),
    [sym_keyword_as_identifier] = STATE(7711),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(7022),
    [aux_sym_preproc_conditional_link_values_repeat2] = STATE(8072),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(8073),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(5958),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(8074),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(7026),
    [aux_sym_preproc_conditional_impl_values_repeat2] = STATE(8078),
    [sym_identifier] = ACTIONS(3054),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token1] = ACTIONS(3064),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3066),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDelif] = ACTIONS(3072),
    [anon_sym_POUNDELIF] = ACTIONS(3072),
    [anon_sym_POUNDElif] = ACTIONS(3072),
    [anon_sym_POUNDelse] = ACTIONS(3074),
    [anon_sym_POUNDELSE] = ACTIONS(3074),
    [anon_sym_POUNDElse] = ACTIONS(3074),
    [anon_sym_POUNDendif] = ACTIONS(3076),
    [anon_sym_POUNDENDIF] = ACTIONS(3076),
    [anon_sym_POUNDEndif] = ACTIONS(3076),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_table_keyword] = ACTIONS(3064),
    [sym_page_keyword] = ACTIONS(3080),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3080),
    [sym_query_keyword] = ACTIONS(3080),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3082),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(3076),
  },
  [STATE(1258)] = {
    [sym_type_specification] = STATE(4843),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1259)] = {
    [sym_type_specification] = STATE(11286),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1260)] = {
    [sym_type_specification] = STATE(6848),
    [sym_text_type] = STATE(6858),
    [sym_code_type] = STATE(6858),
    [sym_option_type] = STATE(6855),
    [sym_record_type] = STATE(6855),
    [sym_dotnet_type] = STATE(6855),
    [sym_object_reference_type] = STATE(6855),
    [sym_array_type] = STATE(6859),
    [sym_list_type] = STATE(6859),
    [sym_dictionary_type] = STATE(6859),
    [sym_basic_type] = STATE(6855),
    [sym_codeunit_keyword] = STATE(7883),
    [sym_xmlport_keyword] = STATE(7883),
    [sym_enum_keyword] = STATE(7883),
    [sym_controladdin_keyword] = STATE(7883),
    [sym_dotnet_keyword] = STATE(7716),
    [sym_identifier] = ACTIONS(3086),
    [aux_sym_text_type_token1] = ACTIONS(3088),
    [aux_sym_code_type_token1] = ACTIONS(3090),
    [aux_sym_option_type_token1] = ACTIONS(3092),
    [aux_sym_record_type_token1] = ACTIONS(3094),
    [aux_sym_object_reference_type_token1] = ACTIONS(3096),
    [aux_sym_object_reference_type_token2] = ACTIONS(3096),
    [aux_sym_array_type_token1] = ACTIONS(3098),
    [aux_sym_list_type_token1] = ACTIONS(3100),
    [aux_sym_dictionary_type_token1] = ACTIONS(3102),
    [aux_sym_basic_type_token1] = ACTIONS(3104),
    [aux_sym_basic_type_token2] = ACTIONS(3104),
    [aux_sym_basic_type_token3] = ACTIONS(3104),
    [aux_sym_basic_type_token4] = ACTIONS(3104),
    [aux_sym_basic_type_token5] = ACTIONS(3104),
    [aux_sym_basic_type_token6] = ACTIONS(3106),
    [aux_sym_basic_type_token7] = ACTIONS(3104),
    [aux_sym_basic_type_token8] = ACTIONS(3104),
    [aux_sym_basic_type_token9] = ACTIONS(3104),
    [aux_sym_basic_type_token10] = ACTIONS(3104),
    [aux_sym_basic_type_token11] = ACTIONS(3104),
    [aux_sym_basic_type_token12] = ACTIONS(3104),
    [aux_sym_basic_type_token13] = ACTIONS(3108),
    [aux_sym_basic_type_token14] = ACTIONS(3104),
    [aux_sym_basic_type_token15] = ACTIONS(3104),
    [aux_sym_basic_type_token16] = ACTIONS(3104),
    [aux_sym_basic_type_token17] = ACTIONS(3104),
    [aux_sym_basic_type_token18] = ACTIONS(3104),
    [aux_sym_basic_type_token19] = ACTIONS(3104),
    [aux_sym_basic_type_token20] = ACTIONS(3104),
    [aux_sym_basic_type_token21] = ACTIONS(3104),
    [aux_sym_basic_type_token22] = ACTIONS(3104),
    [aux_sym_basic_type_token23] = ACTIONS(3104),
    [aux_sym_basic_type_token24] = ACTIONS(3104),
    [aux_sym_basic_type_token25] = ACTIONS(3104),
    [aux_sym_basic_type_token26] = ACTIONS(3104),
    [aux_sym_basic_type_token27] = ACTIONS(3104),
    [aux_sym_basic_type_token28] = ACTIONS(3104),
    [aux_sym_basic_type_token29] = ACTIONS(3104),
    [aux_sym_basic_type_token30] = ACTIONS(3104),
    [aux_sym_basic_type_token31] = ACTIONS(3104),
    [aux_sym_basic_type_token32] = ACTIONS(3104),
    [aux_sym_basic_type_token33] = ACTIONS(3104),
    [aux_sym_basic_type_token34] = ACTIONS(3104),
    [aux_sym_basic_type_token35] = ACTIONS(3104),
    [aux_sym_basic_type_token36] = ACTIONS(3104),
    [aux_sym_basic_type_token37] = ACTIONS(3104),
    [aux_sym_basic_type_token38] = ACTIONS(3104),
    [aux_sym_basic_type_token39] = ACTIONS(3104),
    [aux_sym_basic_type_token40] = ACTIONS(3104),
    [aux_sym_basic_type_token41] = ACTIONS(3104),
    [aux_sym_basic_type_token42] = ACTIONS(3104),
    [aux_sym_basic_type_token43] = ACTIONS(3104),
    [aux_sym_basic_type_token44] = ACTIONS(3104),
    [aux_sym_basic_type_token45] = ACTIONS(3104),
    [aux_sym_basic_type_token46] = ACTIONS(3104),
    [aux_sym_basic_type_token47] = ACTIONS(3104),
    [aux_sym_basic_type_token48] = ACTIONS(3104),
    [aux_sym_basic_type_token49] = ACTIONS(3104),
    [aux_sym_basic_type_token50] = ACTIONS(3104),
    [aux_sym_basic_type_token51] = ACTIONS(3104),
    [aux_sym_basic_type_token52] = ACTIONS(3104),
    [aux_sym_basic_type_token53] = ACTIONS(3104),
    [aux_sym_basic_type_token54] = ACTIONS(3104),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3096),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3096),
    [sym_query_keyword] = ACTIONS(3096),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3096),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3110),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1261)] = {
    [sym_type_specification] = STATE(11988),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(11202),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1262)] = {
    [sym_type_specification] = STATE(12008),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1263)] = {
    [sym_type_specification] = STATE(12055),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1264)] = {
    [sym_type_specification] = STATE(12070),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1265)] = {
    [sym_type_specification] = STATE(12318),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1266)] = {
    [sym_type_specification] = STATE(12080),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1267)] = {
    [sym_type_specification] = STATE(11153),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1268)] = {
    [sym_type_specification] = STATE(11644),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1269)] = {
    [sym_type_specification] = STATE(11398),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1270)] = {
    [sym_type_specification] = STATE(11482),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1271)] = {
    [sym_type_specification] = STATE(1224),
    [sym_text_type] = STATE(1232),
    [sym_code_type] = STATE(1232),
    [sym_option_type] = STATE(1231),
    [sym_record_type] = STATE(1231),
    [sym_dotnet_type] = STATE(1231),
    [sym_object_reference_type] = STATE(1231),
    [sym_array_type] = STATE(1233),
    [sym_list_type] = STATE(1233),
    [sym_dictionary_type] = STATE(1233),
    [sym_basic_type] = STATE(1231),
    [sym_codeunit_keyword] = STATE(8162),
    [sym_xmlport_keyword] = STATE(8162),
    [sym_enum_keyword] = STATE(8162),
    [sym_controladdin_keyword] = STATE(8162),
    [sym_dotnet_keyword] = STATE(7685),
    [sym_identifier] = ACTIONS(3112),
    [aux_sym_text_type_token1] = ACTIONS(3114),
    [aux_sym_code_type_token1] = ACTIONS(3116),
    [aux_sym_option_type_token1] = ACTIONS(3118),
    [aux_sym_record_type_token1] = ACTIONS(3120),
    [aux_sym_object_reference_type_token1] = ACTIONS(3122),
    [aux_sym_object_reference_type_token2] = ACTIONS(3122),
    [aux_sym_array_type_token1] = ACTIONS(3124),
    [aux_sym_list_type_token1] = ACTIONS(3126),
    [aux_sym_dictionary_type_token1] = ACTIONS(3128),
    [aux_sym_basic_type_token1] = ACTIONS(3130),
    [aux_sym_basic_type_token2] = ACTIONS(3130),
    [aux_sym_basic_type_token3] = ACTIONS(3130),
    [aux_sym_basic_type_token4] = ACTIONS(3130),
    [aux_sym_basic_type_token5] = ACTIONS(3130),
    [aux_sym_basic_type_token6] = ACTIONS(3132),
    [aux_sym_basic_type_token7] = ACTIONS(3130),
    [aux_sym_basic_type_token8] = ACTIONS(3130),
    [aux_sym_basic_type_token9] = ACTIONS(3130),
    [aux_sym_basic_type_token10] = ACTIONS(3130),
    [aux_sym_basic_type_token11] = ACTIONS(3130),
    [aux_sym_basic_type_token12] = ACTIONS(3130),
    [aux_sym_basic_type_token13] = ACTIONS(3134),
    [aux_sym_basic_type_token14] = ACTIONS(3130),
    [aux_sym_basic_type_token15] = ACTIONS(3130),
    [aux_sym_basic_type_token16] = ACTIONS(3130),
    [aux_sym_basic_type_token17] = ACTIONS(3130),
    [aux_sym_basic_type_token18] = ACTIONS(3130),
    [aux_sym_basic_type_token19] = ACTIONS(3130),
    [aux_sym_basic_type_token20] = ACTIONS(3130),
    [aux_sym_basic_type_token21] = ACTIONS(3130),
    [aux_sym_basic_type_token22] = ACTIONS(3130),
    [aux_sym_basic_type_token23] = ACTIONS(3130),
    [aux_sym_basic_type_token24] = ACTIONS(3130),
    [aux_sym_basic_type_token25] = ACTIONS(3130),
    [aux_sym_basic_type_token26] = ACTIONS(3130),
    [aux_sym_basic_type_token27] = ACTIONS(3130),
    [aux_sym_basic_type_token28] = ACTIONS(3130),
    [aux_sym_basic_type_token29] = ACTIONS(3130),
    [aux_sym_basic_type_token30] = ACTIONS(3130),
    [aux_sym_basic_type_token31] = ACTIONS(3130),
    [aux_sym_basic_type_token32] = ACTIONS(3130),
    [aux_sym_basic_type_token33] = ACTIONS(3130),
    [aux_sym_basic_type_token34] = ACTIONS(3130),
    [aux_sym_basic_type_token35] = ACTIONS(3130),
    [aux_sym_basic_type_token36] = ACTIONS(3130),
    [aux_sym_basic_type_token37] = ACTIONS(3130),
    [aux_sym_basic_type_token38] = ACTIONS(3130),
    [aux_sym_basic_type_token39] = ACTIONS(3130),
    [aux_sym_basic_type_token40] = ACTIONS(3130),
    [aux_sym_basic_type_token41] = ACTIONS(3130),
    [aux_sym_basic_type_token42] = ACTIONS(3130),
    [aux_sym_basic_type_token43] = ACTIONS(3130),
    [aux_sym_basic_type_token44] = ACTIONS(3130),
    [aux_sym_basic_type_token45] = ACTIONS(3130),
    [aux_sym_basic_type_token46] = ACTIONS(3130),
    [aux_sym_basic_type_token47] = ACTIONS(3130),
    [aux_sym_basic_type_token48] = ACTIONS(3130),
    [aux_sym_basic_type_token49] = ACTIONS(3130),
    [aux_sym_basic_type_token50] = ACTIONS(3130),
    [aux_sym_basic_type_token51] = ACTIONS(3130),
    [aux_sym_basic_type_token52] = ACTIONS(3130),
    [aux_sym_basic_type_token53] = ACTIONS(3130),
    [aux_sym_basic_type_token54] = ACTIONS(3130),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3122),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3122),
    [sym_query_keyword] = ACTIONS(3122),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3122),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3136),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1272)] = {
    [sym_type_specification] = STATE(12623),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1273)] = {
    [sym_type_specification] = STATE(6179),
    [sym_text_type] = STATE(6041),
    [sym_code_type] = STATE(6041),
    [sym_option_type] = STATE(6040),
    [sym_record_type] = STATE(6040),
    [sym_dotnet_type] = STATE(6040),
    [sym_object_reference_type] = STATE(6040),
    [sym_array_type] = STATE(6042),
    [sym_list_type] = STATE(6042),
    [sym_dictionary_type] = STATE(6042),
    [sym_basic_type] = STATE(6040),
    [sym_codeunit_keyword] = STATE(7853),
    [sym_xmlport_keyword] = STATE(7853),
    [sym_enum_keyword] = STATE(7853),
    [sym_controladdin_keyword] = STATE(7853),
    [sym_dotnet_keyword] = STATE(7709),
    [sym_identifier] = ACTIONS(3138),
    [aux_sym_text_type_token1] = ACTIONS(3140),
    [aux_sym_code_type_token1] = ACTIONS(3142),
    [aux_sym_option_type_token1] = ACTIONS(3144),
    [aux_sym_record_type_token1] = ACTIONS(3146),
    [aux_sym_object_reference_type_token1] = ACTIONS(3148),
    [aux_sym_object_reference_type_token2] = ACTIONS(3148),
    [aux_sym_array_type_token1] = ACTIONS(3150),
    [aux_sym_list_type_token1] = ACTIONS(3152),
    [aux_sym_dictionary_type_token1] = ACTIONS(3154),
    [aux_sym_basic_type_token1] = ACTIONS(3156),
    [aux_sym_basic_type_token2] = ACTIONS(3156),
    [aux_sym_basic_type_token3] = ACTIONS(3156),
    [aux_sym_basic_type_token4] = ACTIONS(3156),
    [aux_sym_basic_type_token5] = ACTIONS(3156),
    [aux_sym_basic_type_token6] = ACTIONS(3158),
    [aux_sym_basic_type_token7] = ACTIONS(3156),
    [aux_sym_basic_type_token8] = ACTIONS(3156),
    [aux_sym_basic_type_token9] = ACTIONS(3156),
    [aux_sym_basic_type_token10] = ACTIONS(3156),
    [aux_sym_basic_type_token11] = ACTIONS(3156),
    [aux_sym_basic_type_token12] = ACTIONS(3156),
    [aux_sym_basic_type_token13] = ACTIONS(3160),
    [aux_sym_basic_type_token14] = ACTIONS(3156),
    [aux_sym_basic_type_token15] = ACTIONS(3156),
    [aux_sym_basic_type_token16] = ACTIONS(3156),
    [aux_sym_basic_type_token17] = ACTIONS(3156),
    [aux_sym_basic_type_token18] = ACTIONS(3156),
    [aux_sym_basic_type_token19] = ACTIONS(3156),
    [aux_sym_basic_type_token20] = ACTIONS(3156),
    [aux_sym_basic_type_token21] = ACTIONS(3156),
    [aux_sym_basic_type_token22] = ACTIONS(3156),
    [aux_sym_basic_type_token23] = ACTIONS(3156),
    [aux_sym_basic_type_token24] = ACTIONS(3156),
    [aux_sym_basic_type_token25] = ACTIONS(3156),
    [aux_sym_basic_type_token26] = ACTIONS(3156),
    [aux_sym_basic_type_token27] = ACTIONS(3156),
    [aux_sym_basic_type_token28] = ACTIONS(3156),
    [aux_sym_basic_type_token29] = ACTIONS(3156),
    [aux_sym_basic_type_token30] = ACTIONS(3156),
    [aux_sym_basic_type_token31] = ACTIONS(3156),
    [aux_sym_basic_type_token32] = ACTIONS(3156),
    [aux_sym_basic_type_token33] = ACTIONS(3156),
    [aux_sym_basic_type_token34] = ACTIONS(3156),
    [aux_sym_basic_type_token35] = ACTIONS(3156),
    [aux_sym_basic_type_token36] = ACTIONS(3156),
    [aux_sym_basic_type_token37] = ACTIONS(3156),
    [aux_sym_basic_type_token38] = ACTIONS(3156),
    [aux_sym_basic_type_token39] = ACTIONS(3156),
    [aux_sym_basic_type_token40] = ACTIONS(3156),
    [aux_sym_basic_type_token41] = ACTIONS(3156),
    [aux_sym_basic_type_token42] = ACTIONS(3156),
    [aux_sym_basic_type_token43] = ACTIONS(3156),
    [aux_sym_basic_type_token44] = ACTIONS(3156),
    [aux_sym_basic_type_token45] = ACTIONS(3156),
    [aux_sym_basic_type_token46] = ACTIONS(3156),
    [aux_sym_basic_type_token47] = ACTIONS(3156),
    [aux_sym_basic_type_token48] = ACTIONS(3156),
    [aux_sym_basic_type_token49] = ACTIONS(3156),
    [aux_sym_basic_type_token50] = ACTIONS(3156),
    [aux_sym_basic_type_token51] = ACTIONS(3156),
    [aux_sym_basic_type_token52] = ACTIONS(3156),
    [aux_sym_basic_type_token53] = ACTIONS(3156),
    [aux_sym_basic_type_token54] = ACTIONS(3156),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3148),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3148),
    [sym_query_keyword] = ACTIONS(3148),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3148),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3162),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1274)] = {
    [sym_type_specification] = STATE(8941),
    [sym_text_type] = STATE(8924),
    [sym_code_type] = STATE(8924),
    [sym_option_type] = STATE(8918),
    [sym_record_type] = STATE(8918),
    [sym_dotnet_type] = STATE(8918),
    [sym_object_reference_type] = STATE(8918),
    [sym_array_type] = STATE(8926),
    [sym_list_type] = STATE(8926),
    [sym_dictionary_type] = STATE(8926),
    [sym_basic_type] = STATE(8918),
    [sym_codeunit_keyword] = STATE(7798),
    [sym_xmlport_keyword] = STATE(7798),
    [sym_enum_keyword] = STATE(7798),
    [sym_controladdin_keyword] = STATE(7798),
    [sym_dotnet_keyword] = STATE(7641),
    [sym_identifier] = ACTIONS(3164),
    [aux_sym_text_type_token1] = ACTIONS(3166),
    [aux_sym_code_type_token1] = ACTIONS(3168),
    [aux_sym_option_type_token1] = ACTIONS(3170),
    [aux_sym_record_type_token1] = ACTIONS(3172),
    [aux_sym_object_reference_type_token1] = ACTIONS(3174),
    [aux_sym_object_reference_type_token2] = ACTIONS(3174),
    [aux_sym_array_type_token1] = ACTIONS(3176),
    [aux_sym_list_type_token1] = ACTIONS(3178),
    [aux_sym_dictionary_type_token1] = ACTIONS(3180),
    [aux_sym_basic_type_token1] = ACTIONS(3182),
    [aux_sym_basic_type_token2] = ACTIONS(3182),
    [aux_sym_basic_type_token3] = ACTIONS(3182),
    [aux_sym_basic_type_token4] = ACTIONS(3182),
    [aux_sym_basic_type_token5] = ACTIONS(3182),
    [aux_sym_basic_type_token6] = ACTIONS(3184),
    [aux_sym_basic_type_token7] = ACTIONS(3182),
    [aux_sym_basic_type_token8] = ACTIONS(3182),
    [aux_sym_basic_type_token9] = ACTIONS(3182),
    [aux_sym_basic_type_token10] = ACTIONS(3182),
    [aux_sym_basic_type_token11] = ACTIONS(3182),
    [aux_sym_basic_type_token12] = ACTIONS(3182),
    [aux_sym_basic_type_token13] = ACTIONS(3186),
    [aux_sym_basic_type_token14] = ACTIONS(3182),
    [aux_sym_basic_type_token15] = ACTIONS(3182),
    [aux_sym_basic_type_token16] = ACTIONS(3182),
    [aux_sym_basic_type_token17] = ACTIONS(3182),
    [aux_sym_basic_type_token18] = ACTIONS(3182),
    [aux_sym_basic_type_token19] = ACTIONS(3182),
    [aux_sym_basic_type_token20] = ACTIONS(3182),
    [aux_sym_basic_type_token21] = ACTIONS(3182),
    [aux_sym_basic_type_token22] = ACTIONS(3182),
    [aux_sym_basic_type_token23] = ACTIONS(3182),
    [aux_sym_basic_type_token24] = ACTIONS(3182),
    [aux_sym_basic_type_token25] = ACTIONS(3182),
    [aux_sym_basic_type_token26] = ACTIONS(3182),
    [aux_sym_basic_type_token27] = ACTIONS(3182),
    [aux_sym_basic_type_token28] = ACTIONS(3182),
    [aux_sym_basic_type_token29] = ACTIONS(3182),
    [aux_sym_basic_type_token30] = ACTIONS(3182),
    [aux_sym_basic_type_token31] = ACTIONS(3182),
    [aux_sym_basic_type_token32] = ACTIONS(3182),
    [aux_sym_basic_type_token33] = ACTIONS(3182),
    [aux_sym_basic_type_token34] = ACTIONS(3182),
    [aux_sym_basic_type_token35] = ACTIONS(3182),
    [aux_sym_basic_type_token36] = ACTIONS(3182),
    [aux_sym_basic_type_token37] = ACTIONS(3182),
    [aux_sym_basic_type_token38] = ACTIONS(3182),
    [aux_sym_basic_type_token39] = ACTIONS(3182),
    [aux_sym_basic_type_token40] = ACTIONS(3182),
    [aux_sym_basic_type_token41] = ACTIONS(3182),
    [aux_sym_basic_type_token42] = ACTIONS(3182),
    [aux_sym_basic_type_token43] = ACTIONS(3182),
    [aux_sym_basic_type_token44] = ACTIONS(3182),
    [aux_sym_basic_type_token45] = ACTIONS(3182),
    [aux_sym_basic_type_token46] = ACTIONS(3182),
    [aux_sym_basic_type_token47] = ACTIONS(3182),
    [aux_sym_basic_type_token48] = ACTIONS(3182),
    [aux_sym_basic_type_token49] = ACTIONS(3182),
    [aux_sym_basic_type_token50] = ACTIONS(3182),
    [aux_sym_basic_type_token51] = ACTIONS(3182),
    [aux_sym_basic_type_token52] = ACTIONS(3182),
    [aux_sym_basic_type_token53] = ACTIONS(3182),
    [aux_sym_basic_type_token54] = ACTIONS(3182),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3174),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3174),
    [sym_query_keyword] = ACTIONS(3174),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3174),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3188),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1275)] = {
    [sym_type_specification] = STATE(11604),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1276)] = {
    [sym_type_specification] = STATE(8905),
    [sym_text_type] = STATE(8924),
    [sym_code_type] = STATE(8924),
    [sym_option_type] = STATE(8918),
    [sym_record_type] = STATE(8918),
    [sym_dotnet_type] = STATE(8918),
    [sym_object_reference_type] = STATE(8918),
    [sym_array_type] = STATE(8926),
    [sym_list_type] = STATE(8926),
    [sym_dictionary_type] = STATE(8926),
    [sym_basic_type] = STATE(8918),
    [sym_codeunit_keyword] = STATE(7798),
    [sym_xmlport_keyword] = STATE(7798),
    [sym_enum_keyword] = STATE(7798),
    [sym_controladdin_keyword] = STATE(7798),
    [sym_dotnet_keyword] = STATE(7641),
    [sym_identifier] = ACTIONS(3164),
    [aux_sym_text_type_token1] = ACTIONS(3166),
    [aux_sym_code_type_token1] = ACTIONS(3168),
    [aux_sym_option_type_token1] = ACTIONS(3170),
    [aux_sym_record_type_token1] = ACTIONS(3172),
    [aux_sym_object_reference_type_token1] = ACTIONS(3174),
    [aux_sym_object_reference_type_token2] = ACTIONS(3174),
    [aux_sym_array_type_token1] = ACTIONS(3176),
    [aux_sym_list_type_token1] = ACTIONS(3178),
    [aux_sym_dictionary_type_token1] = ACTIONS(3180),
    [aux_sym_basic_type_token1] = ACTIONS(3182),
    [aux_sym_basic_type_token2] = ACTIONS(3182),
    [aux_sym_basic_type_token3] = ACTIONS(3182),
    [aux_sym_basic_type_token4] = ACTIONS(3182),
    [aux_sym_basic_type_token5] = ACTIONS(3182),
    [aux_sym_basic_type_token6] = ACTIONS(3184),
    [aux_sym_basic_type_token7] = ACTIONS(3182),
    [aux_sym_basic_type_token8] = ACTIONS(3182),
    [aux_sym_basic_type_token9] = ACTIONS(3182),
    [aux_sym_basic_type_token10] = ACTIONS(3182),
    [aux_sym_basic_type_token11] = ACTIONS(3182),
    [aux_sym_basic_type_token12] = ACTIONS(3182),
    [aux_sym_basic_type_token13] = ACTIONS(3186),
    [aux_sym_basic_type_token14] = ACTIONS(3182),
    [aux_sym_basic_type_token15] = ACTIONS(3182),
    [aux_sym_basic_type_token16] = ACTIONS(3182),
    [aux_sym_basic_type_token17] = ACTIONS(3182),
    [aux_sym_basic_type_token18] = ACTIONS(3182),
    [aux_sym_basic_type_token19] = ACTIONS(3182),
    [aux_sym_basic_type_token20] = ACTIONS(3182),
    [aux_sym_basic_type_token21] = ACTIONS(3182),
    [aux_sym_basic_type_token22] = ACTIONS(3182),
    [aux_sym_basic_type_token23] = ACTIONS(3182),
    [aux_sym_basic_type_token24] = ACTIONS(3182),
    [aux_sym_basic_type_token25] = ACTIONS(3182),
    [aux_sym_basic_type_token26] = ACTIONS(3182),
    [aux_sym_basic_type_token27] = ACTIONS(3182),
    [aux_sym_basic_type_token28] = ACTIONS(3182),
    [aux_sym_basic_type_token29] = ACTIONS(3182),
    [aux_sym_basic_type_token30] = ACTIONS(3182),
    [aux_sym_basic_type_token31] = ACTIONS(3182),
    [aux_sym_basic_type_token32] = ACTIONS(3182),
    [aux_sym_basic_type_token33] = ACTIONS(3182),
    [aux_sym_basic_type_token34] = ACTIONS(3182),
    [aux_sym_basic_type_token35] = ACTIONS(3182),
    [aux_sym_basic_type_token36] = ACTIONS(3182),
    [aux_sym_basic_type_token37] = ACTIONS(3182),
    [aux_sym_basic_type_token38] = ACTIONS(3182),
    [aux_sym_basic_type_token39] = ACTIONS(3182),
    [aux_sym_basic_type_token40] = ACTIONS(3182),
    [aux_sym_basic_type_token41] = ACTIONS(3182),
    [aux_sym_basic_type_token42] = ACTIONS(3182),
    [aux_sym_basic_type_token43] = ACTIONS(3182),
    [aux_sym_basic_type_token44] = ACTIONS(3182),
    [aux_sym_basic_type_token45] = ACTIONS(3182),
    [aux_sym_basic_type_token46] = ACTIONS(3182),
    [aux_sym_basic_type_token47] = ACTIONS(3182),
    [aux_sym_basic_type_token48] = ACTIONS(3182),
    [aux_sym_basic_type_token49] = ACTIONS(3182),
    [aux_sym_basic_type_token50] = ACTIONS(3182),
    [aux_sym_basic_type_token51] = ACTIONS(3182),
    [aux_sym_basic_type_token52] = ACTIONS(3182),
    [aux_sym_basic_type_token53] = ACTIONS(3182),
    [aux_sym_basic_type_token54] = ACTIONS(3182),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3174),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3174),
    [sym_query_keyword] = ACTIONS(3174),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3174),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3188),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1277)] = {
    [sym_type_specification] = STATE(12136),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(11122),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1278)] = {
    [sym_type_specification] = STATE(11685),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1279)] = {
    [sym_type_specification] = STATE(12118),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(11250),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1280)] = {
    [sym_type_specification] = STATE(12134),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1281)] = {
    [sym_type_specification] = STATE(1017),
    [sym_text_type] = STATE(1020),
    [sym_code_type] = STATE(1020),
    [sym_option_type] = STATE(1036),
    [sym_record_type] = STATE(1036),
    [sym_dotnet_type] = STATE(1036),
    [sym_object_reference_type] = STATE(1036),
    [sym_array_type] = STATE(1039),
    [sym_list_type] = STATE(1039),
    [sym_dictionary_type] = STATE(1039),
    [sym_basic_type] = STATE(1036),
    [sym_codeunit_keyword] = STATE(7909),
    [sym_xmlport_keyword] = STATE(7909),
    [sym_enum_keyword] = STATE(7909),
    [sym_controladdin_keyword] = STATE(7909),
    [sym_dotnet_keyword] = STATE(7643),
    [sym_identifier] = ACTIONS(3190),
    [aux_sym_text_type_token1] = ACTIONS(3192),
    [aux_sym_code_type_token1] = ACTIONS(3194),
    [aux_sym_option_type_token1] = ACTIONS(3196),
    [aux_sym_record_type_token1] = ACTIONS(3198),
    [aux_sym_object_reference_type_token1] = ACTIONS(3200),
    [aux_sym_object_reference_type_token2] = ACTIONS(3200),
    [aux_sym_array_type_token1] = ACTIONS(3202),
    [aux_sym_list_type_token1] = ACTIONS(3204),
    [aux_sym_dictionary_type_token1] = ACTIONS(3206),
    [aux_sym_basic_type_token1] = ACTIONS(3208),
    [aux_sym_basic_type_token2] = ACTIONS(3208),
    [aux_sym_basic_type_token3] = ACTIONS(3208),
    [aux_sym_basic_type_token4] = ACTIONS(3208),
    [aux_sym_basic_type_token5] = ACTIONS(3208),
    [aux_sym_basic_type_token6] = ACTIONS(3210),
    [aux_sym_basic_type_token7] = ACTIONS(3208),
    [aux_sym_basic_type_token8] = ACTIONS(3208),
    [aux_sym_basic_type_token9] = ACTIONS(3208),
    [aux_sym_basic_type_token10] = ACTIONS(3208),
    [aux_sym_basic_type_token11] = ACTIONS(3208),
    [aux_sym_basic_type_token12] = ACTIONS(3208),
    [aux_sym_basic_type_token13] = ACTIONS(3212),
    [aux_sym_basic_type_token14] = ACTIONS(3208),
    [aux_sym_basic_type_token15] = ACTIONS(3208),
    [aux_sym_basic_type_token16] = ACTIONS(3208),
    [aux_sym_basic_type_token17] = ACTIONS(3208),
    [aux_sym_basic_type_token18] = ACTIONS(3208),
    [aux_sym_basic_type_token19] = ACTIONS(3208),
    [aux_sym_basic_type_token20] = ACTIONS(3208),
    [aux_sym_basic_type_token21] = ACTIONS(3208),
    [aux_sym_basic_type_token22] = ACTIONS(3208),
    [aux_sym_basic_type_token23] = ACTIONS(3208),
    [aux_sym_basic_type_token24] = ACTIONS(3208),
    [aux_sym_basic_type_token25] = ACTIONS(3208),
    [aux_sym_basic_type_token26] = ACTIONS(3208),
    [aux_sym_basic_type_token27] = ACTIONS(3208),
    [aux_sym_basic_type_token28] = ACTIONS(3208),
    [aux_sym_basic_type_token29] = ACTIONS(3208),
    [aux_sym_basic_type_token30] = ACTIONS(3208),
    [aux_sym_basic_type_token31] = ACTIONS(3208),
    [aux_sym_basic_type_token32] = ACTIONS(3208),
    [aux_sym_basic_type_token33] = ACTIONS(3208),
    [aux_sym_basic_type_token34] = ACTIONS(3208),
    [aux_sym_basic_type_token35] = ACTIONS(3208),
    [aux_sym_basic_type_token36] = ACTIONS(3208),
    [aux_sym_basic_type_token37] = ACTIONS(3208),
    [aux_sym_basic_type_token38] = ACTIONS(3208),
    [aux_sym_basic_type_token39] = ACTIONS(3208),
    [aux_sym_basic_type_token40] = ACTIONS(3208),
    [aux_sym_basic_type_token41] = ACTIONS(3208),
    [aux_sym_basic_type_token42] = ACTIONS(3208),
    [aux_sym_basic_type_token43] = ACTIONS(3208),
    [aux_sym_basic_type_token44] = ACTIONS(3208),
    [aux_sym_basic_type_token45] = ACTIONS(3208),
    [aux_sym_basic_type_token46] = ACTIONS(3208),
    [aux_sym_basic_type_token47] = ACTIONS(3208),
    [aux_sym_basic_type_token48] = ACTIONS(3208),
    [aux_sym_basic_type_token49] = ACTIONS(3208),
    [aux_sym_basic_type_token50] = ACTIONS(3208),
    [aux_sym_basic_type_token51] = ACTIONS(3208),
    [aux_sym_basic_type_token52] = ACTIONS(3208),
    [aux_sym_basic_type_token53] = ACTIONS(3208),
    [aux_sym_basic_type_token54] = ACTIONS(3208),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3200),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3200),
    [sym_query_keyword] = ACTIONS(3200),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3200),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3214),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1282)] = {
    [sym_type_specification] = STATE(12165),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1283)] = {
    [sym_type_specification] = STATE(11748),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1284)] = {
    [sym_type_specification] = STATE(12188),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1285)] = {
    [sym_type_specification] = STATE(1018),
    [sym_text_type] = STATE(1020),
    [sym_code_type] = STATE(1020),
    [sym_option_type] = STATE(1036),
    [sym_record_type] = STATE(1036),
    [sym_dotnet_type] = STATE(1036),
    [sym_object_reference_type] = STATE(1036),
    [sym_array_type] = STATE(1039),
    [sym_list_type] = STATE(1039),
    [sym_dictionary_type] = STATE(1039),
    [sym_basic_type] = STATE(1036),
    [sym_codeunit_keyword] = STATE(7909),
    [sym_xmlport_keyword] = STATE(7909),
    [sym_enum_keyword] = STATE(7909),
    [sym_controladdin_keyword] = STATE(7909),
    [sym_dotnet_keyword] = STATE(7643),
    [sym_identifier] = ACTIONS(3190),
    [aux_sym_text_type_token1] = ACTIONS(3192),
    [aux_sym_code_type_token1] = ACTIONS(3194),
    [aux_sym_option_type_token1] = ACTIONS(3196),
    [aux_sym_record_type_token1] = ACTIONS(3198),
    [aux_sym_object_reference_type_token1] = ACTIONS(3200),
    [aux_sym_object_reference_type_token2] = ACTIONS(3200),
    [aux_sym_array_type_token1] = ACTIONS(3202),
    [aux_sym_list_type_token1] = ACTIONS(3204),
    [aux_sym_dictionary_type_token1] = ACTIONS(3206),
    [aux_sym_basic_type_token1] = ACTIONS(3208),
    [aux_sym_basic_type_token2] = ACTIONS(3208),
    [aux_sym_basic_type_token3] = ACTIONS(3208),
    [aux_sym_basic_type_token4] = ACTIONS(3208),
    [aux_sym_basic_type_token5] = ACTIONS(3208),
    [aux_sym_basic_type_token6] = ACTIONS(3210),
    [aux_sym_basic_type_token7] = ACTIONS(3208),
    [aux_sym_basic_type_token8] = ACTIONS(3208),
    [aux_sym_basic_type_token9] = ACTIONS(3208),
    [aux_sym_basic_type_token10] = ACTIONS(3208),
    [aux_sym_basic_type_token11] = ACTIONS(3208),
    [aux_sym_basic_type_token12] = ACTIONS(3208),
    [aux_sym_basic_type_token13] = ACTIONS(3212),
    [aux_sym_basic_type_token14] = ACTIONS(3208),
    [aux_sym_basic_type_token15] = ACTIONS(3208),
    [aux_sym_basic_type_token16] = ACTIONS(3208),
    [aux_sym_basic_type_token17] = ACTIONS(3208),
    [aux_sym_basic_type_token18] = ACTIONS(3208),
    [aux_sym_basic_type_token19] = ACTIONS(3208),
    [aux_sym_basic_type_token20] = ACTIONS(3208),
    [aux_sym_basic_type_token21] = ACTIONS(3208),
    [aux_sym_basic_type_token22] = ACTIONS(3208),
    [aux_sym_basic_type_token23] = ACTIONS(3208),
    [aux_sym_basic_type_token24] = ACTIONS(3208),
    [aux_sym_basic_type_token25] = ACTIONS(3208),
    [aux_sym_basic_type_token26] = ACTIONS(3208),
    [aux_sym_basic_type_token27] = ACTIONS(3208),
    [aux_sym_basic_type_token28] = ACTIONS(3208),
    [aux_sym_basic_type_token29] = ACTIONS(3208),
    [aux_sym_basic_type_token30] = ACTIONS(3208),
    [aux_sym_basic_type_token31] = ACTIONS(3208),
    [aux_sym_basic_type_token32] = ACTIONS(3208),
    [aux_sym_basic_type_token33] = ACTIONS(3208),
    [aux_sym_basic_type_token34] = ACTIONS(3208),
    [aux_sym_basic_type_token35] = ACTIONS(3208),
    [aux_sym_basic_type_token36] = ACTIONS(3208),
    [aux_sym_basic_type_token37] = ACTIONS(3208),
    [aux_sym_basic_type_token38] = ACTIONS(3208),
    [aux_sym_basic_type_token39] = ACTIONS(3208),
    [aux_sym_basic_type_token40] = ACTIONS(3208),
    [aux_sym_basic_type_token41] = ACTIONS(3208),
    [aux_sym_basic_type_token42] = ACTIONS(3208),
    [aux_sym_basic_type_token43] = ACTIONS(3208),
    [aux_sym_basic_type_token44] = ACTIONS(3208),
    [aux_sym_basic_type_token45] = ACTIONS(3208),
    [aux_sym_basic_type_token46] = ACTIONS(3208),
    [aux_sym_basic_type_token47] = ACTIONS(3208),
    [aux_sym_basic_type_token48] = ACTIONS(3208),
    [aux_sym_basic_type_token49] = ACTIONS(3208),
    [aux_sym_basic_type_token50] = ACTIONS(3208),
    [aux_sym_basic_type_token51] = ACTIONS(3208),
    [aux_sym_basic_type_token52] = ACTIONS(3208),
    [aux_sym_basic_type_token53] = ACTIONS(3208),
    [aux_sym_basic_type_token54] = ACTIONS(3208),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3200),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3200),
    [sym_query_keyword] = ACTIONS(3200),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3200),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3214),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1286)] = {
    [sym_type_specification] = STATE(1147),
    [sym_text_type] = STATE(1148),
    [sym_code_type] = STATE(1148),
    [sym_option_type] = STATE(1146),
    [sym_record_type] = STATE(1146),
    [sym_dotnet_type] = STATE(1146),
    [sym_object_reference_type] = STATE(1146),
    [sym_array_type] = STATE(1151),
    [sym_list_type] = STATE(1151),
    [sym_dictionary_type] = STATE(1151),
    [sym_basic_type] = STATE(1146),
    [sym_codeunit_keyword] = STATE(7968),
    [sym_xmlport_keyword] = STATE(7968),
    [sym_enum_keyword] = STATE(7968),
    [sym_controladdin_keyword] = STATE(7968),
    [sym_dotnet_keyword] = STATE(7651),
    [sym_identifier] = ACTIONS(3216),
    [aux_sym_text_type_token1] = ACTIONS(3218),
    [aux_sym_code_type_token1] = ACTIONS(3220),
    [aux_sym_option_type_token1] = ACTIONS(3222),
    [aux_sym_record_type_token1] = ACTIONS(3224),
    [aux_sym_object_reference_type_token1] = ACTIONS(3226),
    [aux_sym_object_reference_type_token2] = ACTIONS(3226),
    [aux_sym_array_type_token1] = ACTIONS(3228),
    [aux_sym_list_type_token1] = ACTIONS(3230),
    [aux_sym_dictionary_type_token1] = ACTIONS(3232),
    [aux_sym_basic_type_token1] = ACTIONS(3234),
    [aux_sym_basic_type_token2] = ACTIONS(3234),
    [aux_sym_basic_type_token3] = ACTIONS(3234),
    [aux_sym_basic_type_token4] = ACTIONS(3234),
    [aux_sym_basic_type_token5] = ACTIONS(3234),
    [aux_sym_basic_type_token6] = ACTIONS(3236),
    [aux_sym_basic_type_token7] = ACTIONS(3234),
    [aux_sym_basic_type_token8] = ACTIONS(3234),
    [aux_sym_basic_type_token9] = ACTIONS(3234),
    [aux_sym_basic_type_token10] = ACTIONS(3234),
    [aux_sym_basic_type_token11] = ACTIONS(3234),
    [aux_sym_basic_type_token12] = ACTIONS(3234),
    [aux_sym_basic_type_token13] = ACTIONS(3238),
    [aux_sym_basic_type_token14] = ACTIONS(3234),
    [aux_sym_basic_type_token15] = ACTIONS(3234),
    [aux_sym_basic_type_token16] = ACTIONS(3234),
    [aux_sym_basic_type_token17] = ACTIONS(3234),
    [aux_sym_basic_type_token18] = ACTIONS(3234),
    [aux_sym_basic_type_token19] = ACTIONS(3234),
    [aux_sym_basic_type_token20] = ACTIONS(3234),
    [aux_sym_basic_type_token21] = ACTIONS(3234),
    [aux_sym_basic_type_token22] = ACTIONS(3234),
    [aux_sym_basic_type_token23] = ACTIONS(3234),
    [aux_sym_basic_type_token24] = ACTIONS(3234),
    [aux_sym_basic_type_token25] = ACTIONS(3234),
    [aux_sym_basic_type_token26] = ACTIONS(3234),
    [aux_sym_basic_type_token27] = ACTIONS(3234),
    [aux_sym_basic_type_token28] = ACTIONS(3234),
    [aux_sym_basic_type_token29] = ACTIONS(3234),
    [aux_sym_basic_type_token30] = ACTIONS(3234),
    [aux_sym_basic_type_token31] = ACTIONS(3234),
    [aux_sym_basic_type_token32] = ACTIONS(3234),
    [aux_sym_basic_type_token33] = ACTIONS(3234),
    [aux_sym_basic_type_token34] = ACTIONS(3234),
    [aux_sym_basic_type_token35] = ACTIONS(3234),
    [aux_sym_basic_type_token36] = ACTIONS(3234),
    [aux_sym_basic_type_token37] = ACTIONS(3234),
    [aux_sym_basic_type_token38] = ACTIONS(3234),
    [aux_sym_basic_type_token39] = ACTIONS(3234),
    [aux_sym_basic_type_token40] = ACTIONS(3234),
    [aux_sym_basic_type_token41] = ACTIONS(3234),
    [aux_sym_basic_type_token42] = ACTIONS(3234),
    [aux_sym_basic_type_token43] = ACTIONS(3234),
    [aux_sym_basic_type_token44] = ACTIONS(3234),
    [aux_sym_basic_type_token45] = ACTIONS(3234),
    [aux_sym_basic_type_token46] = ACTIONS(3234),
    [aux_sym_basic_type_token47] = ACTIONS(3234),
    [aux_sym_basic_type_token48] = ACTIONS(3234),
    [aux_sym_basic_type_token49] = ACTIONS(3234),
    [aux_sym_basic_type_token50] = ACTIONS(3234),
    [aux_sym_basic_type_token51] = ACTIONS(3234),
    [aux_sym_basic_type_token52] = ACTIONS(3234),
    [aux_sym_basic_type_token53] = ACTIONS(3234),
    [aux_sym_basic_type_token54] = ACTIONS(3234),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3226),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3226),
    [sym_query_keyword] = ACTIONS(3226),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3226),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3240),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1287)] = {
    [sym_type_specification] = STATE(11784),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1288)] = {
    [sym_type_specification] = STATE(11803),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1289)] = {
    [sym_type_specification] = STATE(11815),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1290)] = {
    [sym_type_specification] = STATE(11825),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1291)] = {
    [sym_type_specification] = STATE(11834),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1292)] = {
    [sym_type_specification] = STATE(11843),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1293)] = {
    [sym_type_specification] = STATE(11852),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1294)] = {
    [sym_type_specification] = STATE(11859),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1295)] = {
    [sym_type_specification] = STATE(1130),
    [sym_text_type] = STATE(1148),
    [sym_code_type] = STATE(1148),
    [sym_option_type] = STATE(1146),
    [sym_record_type] = STATE(1146),
    [sym_dotnet_type] = STATE(1146),
    [sym_object_reference_type] = STATE(1146),
    [sym_array_type] = STATE(1151),
    [sym_list_type] = STATE(1151),
    [sym_dictionary_type] = STATE(1151),
    [sym_basic_type] = STATE(1146),
    [sym_codeunit_keyword] = STATE(7968),
    [sym_xmlport_keyword] = STATE(7968),
    [sym_enum_keyword] = STATE(7968),
    [sym_controladdin_keyword] = STATE(7968),
    [sym_dotnet_keyword] = STATE(7651),
    [sym_identifier] = ACTIONS(3216),
    [aux_sym_text_type_token1] = ACTIONS(3218),
    [aux_sym_code_type_token1] = ACTIONS(3220),
    [aux_sym_option_type_token1] = ACTIONS(3222),
    [aux_sym_record_type_token1] = ACTIONS(3224),
    [aux_sym_object_reference_type_token1] = ACTIONS(3226),
    [aux_sym_object_reference_type_token2] = ACTIONS(3226),
    [aux_sym_array_type_token1] = ACTIONS(3228),
    [aux_sym_list_type_token1] = ACTIONS(3230),
    [aux_sym_dictionary_type_token1] = ACTIONS(3232),
    [aux_sym_basic_type_token1] = ACTIONS(3234),
    [aux_sym_basic_type_token2] = ACTIONS(3234),
    [aux_sym_basic_type_token3] = ACTIONS(3234),
    [aux_sym_basic_type_token4] = ACTIONS(3234),
    [aux_sym_basic_type_token5] = ACTIONS(3234),
    [aux_sym_basic_type_token6] = ACTIONS(3236),
    [aux_sym_basic_type_token7] = ACTIONS(3234),
    [aux_sym_basic_type_token8] = ACTIONS(3234),
    [aux_sym_basic_type_token9] = ACTIONS(3234),
    [aux_sym_basic_type_token10] = ACTIONS(3234),
    [aux_sym_basic_type_token11] = ACTIONS(3234),
    [aux_sym_basic_type_token12] = ACTIONS(3234),
    [aux_sym_basic_type_token13] = ACTIONS(3238),
    [aux_sym_basic_type_token14] = ACTIONS(3234),
    [aux_sym_basic_type_token15] = ACTIONS(3234),
    [aux_sym_basic_type_token16] = ACTIONS(3234),
    [aux_sym_basic_type_token17] = ACTIONS(3234),
    [aux_sym_basic_type_token18] = ACTIONS(3234),
    [aux_sym_basic_type_token19] = ACTIONS(3234),
    [aux_sym_basic_type_token20] = ACTIONS(3234),
    [aux_sym_basic_type_token21] = ACTIONS(3234),
    [aux_sym_basic_type_token22] = ACTIONS(3234),
    [aux_sym_basic_type_token23] = ACTIONS(3234),
    [aux_sym_basic_type_token24] = ACTIONS(3234),
    [aux_sym_basic_type_token25] = ACTIONS(3234),
    [aux_sym_basic_type_token26] = ACTIONS(3234),
    [aux_sym_basic_type_token27] = ACTIONS(3234),
    [aux_sym_basic_type_token28] = ACTIONS(3234),
    [aux_sym_basic_type_token29] = ACTIONS(3234),
    [aux_sym_basic_type_token30] = ACTIONS(3234),
    [aux_sym_basic_type_token31] = ACTIONS(3234),
    [aux_sym_basic_type_token32] = ACTIONS(3234),
    [aux_sym_basic_type_token33] = ACTIONS(3234),
    [aux_sym_basic_type_token34] = ACTIONS(3234),
    [aux_sym_basic_type_token35] = ACTIONS(3234),
    [aux_sym_basic_type_token36] = ACTIONS(3234),
    [aux_sym_basic_type_token37] = ACTIONS(3234),
    [aux_sym_basic_type_token38] = ACTIONS(3234),
    [aux_sym_basic_type_token39] = ACTIONS(3234),
    [aux_sym_basic_type_token40] = ACTIONS(3234),
    [aux_sym_basic_type_token41] = ACTIONS(3234),
    [aux_sym_basic_type_token42] = ACTIONS(3234),
    [aux_sym_basic_type_token43] = ACTIONS(3234),
    [aux_sym_basic_type_token44] = ACTIONS(3234),
    [aux_sym_basic_type_token45] = ACTIONS(3234),
    [aux_sym_basic_type_token46] = ACTIONS(3234),
    [aux_sym_basic_type_token47] = ACTIONS(3234),
    [aux_sym_basic_type_token48] = ACTIONS(3234),
    [aux_sym_basic_type_token49] = ACTIONS(3234),
    [aux_sym_basic_type_token50] = ACTIONS(3234),
    [aux_sym_basic_type_token51] = ACTIONS(3234),
    [aux_sym_basic_type_token52] = ACTIONS(3234),
    [aux_sym_basic_type_token53] = ACTIONS(3234),
    [aux_sym_basic_type_token54] = ACTIONS(3234),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3226),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3226),
    [sym_query_keyword] = ACTIONS(3226),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3226),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3240),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1296)] = {
    [sym_type_specification] = STATE(6193),
    [sym_text_type] = STATE(6041),
    [sym_code_type] = STATE(6041),
    [sym_option_type] = STATE(6040),
    [sym_record_type] = STATE(6040),
    [sym_dotnet_type] = STATE(6040),
    [sym_object_reference_type] = STATE(6040),
    [sym_array_type] = STATE(6042),
    [sym_list_type] = STATE(6042),
    [sym_dictionary_type] = STATE(6042),
    [sym_basic_type] = STATE(6040),
    [sym_codeunit_keyword] = STATE(7853),
    [sym_xmlport_keyword] = STATE(7853),
    [sym_enum_keyword] = STATE(7853),
    [sym_controladdin_keyword] = STATE(7853),
    [sym_dotnet_keyword] = STATE(7709),
    [sym_identifier] = ACTIONS(3138),
    [aux_sym_text_type_token1] = ACTIONS(3140),
    [aux_sym_code_type_token1] = ACTIONS(3142),
    [aux_sym_option_type_token1] = ACTIONS(3144),
    [aux_sym_record_type_token1] = ACTIONS(3146),
    [aux_sym_object_reference_type_token1] = ACTIONS(3148),
    [aux_sym_object_reference_type_token2] = ACTIONS(3148),
    [aux_sym_array_type_token1] = ACTIONS(3150),
    [aux_sym_list_type_token1] = ACTIONS(3152),
    [aux_sym_dictionary_type_token1] = ACTIONS(3154),
    [aux_sym_basic_type_token1] = ACTIONS(3156),
    [aux_sym_basic_type_token2] = ACTIONS(3156),
    [aux_sym_basic_type_token3] = ACTIONS(3156),
    [aux_sym_basic_type_token4] = ACTIONS(3156),
    [aux_sym_basic_type_token5] = ACTIONS(3156),
    [aux_sym_basic_type_token6] = ACTIONS(3158),
    [aux_sym_basic_type_token7] = ACTIONS(3156),
    [aux_sym_basic_type_token8] = ACTIONS(3156),
    [aux_sym_basic_type_token9] = ACTIONS(3156),
    [aux_sym_basic_type_token10] = ACTIONS(3156),
    [aux_sym_basic_type_token11] = ACTIONS(3156),
    [aux_sym_basic_type_token12] = ACTIONS(3156),
    [aux_sym_basic_type_token13] = ACTIONS(3160),
    [aux_sym_basic_type_token14] = ACTIONS(3156),
    [aux_sym_basic_type_token15] = ACTIONS(3156),
    [aux_sym_basic_type_token16] = ACTIONS(3156),
    [aux_sym_basic_type_token17] = ACTIONS(3156),
    [aux_sym_basic_type_token18] = ACTIONS(3156),
    [aux_sym_basic_type_token19] = ACTIONS(3156),
    [aux_sym_basic_type_token20] = ACTIONS(3156),
    [aux_sym_basic_type_token21] = ACTIONS(3156),
    [aux_sym_basic_type_token22] = ACTIONS(3156),
    [aux_sym_basic_type_token23] = ACTIONS(3156),
    [aux_sym_basic_type_token24] = ACTIONS(3156),
    [aux_sym_basic_type_token25] = ACTIONS(3156),
    [aux_sym_basic_type_token26] = ACTIONS(3156),
    [aux_sym_basic_type_token27] = ACTIONS(3156),
    [aux_sym_basic_type_token28] = ACTIONS(3156),
    [aux_sym_basic_type_token29] = ACTIONS(3156),
    [aux_sym_basic_type_token30] = ACTIONS(3156),
    [aux_sym_basic_type_token31] = ACTIONS(3156),
    [aux_sym_basic_type_token32] = ACTIONS(3156),
    [aux_sym_basic_type_token33] = ACTIONS(3156),
    [aux_sym_basic_type_token34] = ACTIONS(3156),
    [aux_sym_basic_type_token35] = ACTIONS(3156),
    [aux_sym_basic_type_token36] = ACTIONS(3156),
    [aux_sym_basic_type_token37] = ACTIONS(3156),
    [aux_sym_basic_type_token38] = ACTIONS(3156),
    [aux_sym_basic_type_token39] = ACTIONS(3156),
    [aux_sym_basic_type_token40] = ACTIONS(3156),
    [aux_sym_basic_type_token41] = ACTIONS(3156),
    [aux_sym_basic_type_token42] = ACTIONS(3156),
    [aux_sym_basic_type_token43] = ACTIONS(3156),
    [aux_sym_basic_type_token44] = ACTIONS(3156),
    [aux_sym_basic_type_token45] = ACTIONS(3156),
    [aux_sym_basic_type_token46] = ACTIONS(3156),
    [aux_sym_basic_type_token47] = ACTIONS(3156),
    [aux_sym_basic_type_token48] = ACTIONS(3156),
    [aux_sym_basic_type_token49] = ACTIONS(3156),
    [aux_sym_basic_type_token50] = ACTIONS(3156),
    [aux_sym_basic_type_token51] = ACTIONS(3156),
    [aux_sym_basic_type_token52] = ACTIONS(3156),
    [aux_sym_basic_type_token53] = ACTIONS(3156),
    [aux_sym_basic_type_token54] = ACTIONS(3156),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3148),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3148),
    [sym_query_keyword] = ACTIONS(3148),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3148),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3162),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1297)] = {
    [sym_type_specification] = STATE(4817),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1298)] = {
    [sym_type_specification] = STATE(4835),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3242),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3244),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1299)] = {
    [sym_type_specification] = STATE(2141),
    [sym_text_type] = STATE(2207),
    [sym_code_type] = STATE(2207),
    [sym_option_type] = STATE(2206),
    [sym_record_type] = STATE(2206),
    [sym_dotnet_type] = STATE(2206),
    [sym_object_reference_type] = STATE(2206),
    [sym_array_type] = STATE(2209),
    [sym_list_type] = STATE(2209),
    [sym_dictionary_type] = STATE(2209),
    [sym_basic_type] = STATE(2206),
    [sym_codeunit_keyword] = STATE(8093),
    [sym_xmlport_keyword] = STATE(8093),
    [sym_enum_keyword] = STATE(8093),
    [sym_controladdin_keyword] = STATE(8093),
    [sym_dotnet_keyword] = STATE(7721),
    [sym_identifier] = ACTIONS(3246),
    [aux_sym_text_type_token1] = ACTIONS(3248),
    [aux_sym_code_type_token1] = ACTIONS(3250),
    [aux_sym_option_type_token1] = ACTIONS(3252),
    [aux_sym_record_type_token1] = ACTIONS(3254),
    [aux_sym_object_reference_type_token1] = ACTIONS(3256),
    [aux_sym_object_reference_type_token2] = ACTIONS(3256),
    [aux_sym_array_type_token1] = ACTIONS(3258),
    [aux_sym_list_type_token1] = ACTIONS(3260),
    [aux_sym_dictionary_type_token1] = ACTIONS(3262),
    [aux_sym_basic_type_token1] = ACTIONS(3264),
    [aux_sym_basic_type_token2] = ACTIONS(3264),
    [aux_sym_basic_type_token3] = ACTIONS(3264),
    [aux_sym_basic_type_token4] = ACTIONS(3264),
    [aux_sym_basic_type_token5] = ACTIONS(3264),
    [aux_sym_basic_type_token6] = ACTIONS(3266),
    [aux_sym_basic_type_token7] = ACTIONS(3264),
    [aux_sym_basic_type_token8] = ACTIONS(3264),
    [aux_sym_basic_type_token9] = ACTIONS(3264),
    [aux_sym_basic_type_token10] = ACTIONS(3264),
    [aux_sym_basic_type_token11] = ACTIONS(3264),
    [aux_sym_basic_type_token12] = ACTIONS(3264),
    [aux_sym_basic_type_token13] = ACTIONS(3268),
    [aux_sym_basic_type_token14] = ACTIONS(3264),
    [aux_sym_basic_type_token15] = ACTIONS(3264),
    [aux_sym_basic_type_token16] = ACTIONS(3264),
    [aux_sym_basic_type_token17] = ACTIONS(3264),
    [aux_sym_basic_type_token18] = ACTIONS(3264),
    [aux_sym_basic_type_token19] = ACTIONS(3264),
    [aux_sym_basic_type_token20] = ACTIONS(3264),
    [aux_sym_basic_type_token21] = ACTIONS(3264),
    [aux_sym_basic_type_token22] = ACTIONS(3264),
    [aux_sym_basic_type_token23] = ACTIONS(3264),
    [aux_sym_basic_type_token24] = ACTIONS(3264),
    [aux_sym_basic_type_token25] = ACTIONS(3264),
    [aux_sym_basic_type_token26] = ACTIONS(3264),
    [aux_sym_basic_type_token27] = ACTIONS(3264),
    [aux_sym_basic_type_token28] = ACTIONS(3264),
    [aux_sym_basic_type_token29] = ACTIONS(3264),
    [aux_sym_basic_type_token30] = ACTIONS(3264),
    [aux_sym_basic_type_token31] = ACTIONS(3264),
    [aux_sym_basic_type_token32] = ACTIONS(3264),
    [aux_sym_basic_type_token33] = ACTIONS(3264),
    [aux_sym_basic_type_token34] = ACTIONS(3264),
    [aux_sym_basic_type_token35] = ACTIONS(3264),
    [aux_sym_basic_type_token36] = ACTIONS(3264),
    [aux_sym_basic_type_token37] = ACTIONS(3264),
    [aux_sym_basic_type_token38] = ACTIONS(3264),
    [aux_sym_basic_type_token39] = ACTIONS(3264),
    [aux_sym_basic_type_token40] = ACTIONS(3264),
    [aux_sym_basic_type_token41] = ACTIONS(3264),
    [aux_sym_basic_type_token42] = ACTIONS(3264),
    [aux_sym_basic_type_token43] = ACTIONS(3264),
    [aux_sym_basic_type_token44] = ACTIONS(3264),
    [aux_sym_basic_type_token45] = ACTIONS(3264),
    [aux_sym_basic_type_token46] = ACTIONS(3264),
    [aux_sym_basic_type_token47] = ACTIONS(3264),
    [aux_sym_basic_type_token48] = ACTIONS(3264),
    [aux_sym_basic_type_token49] = ACTIONS(3264),
    [aux_sym_basic_type_token50] = ACTIONS(3264),
    [aux_sym_basic_type_token51] = ACTIONS(3264),
    [aux_sym_basic_type_token52] = ACTIONS(3264),
    [aux_sym_basic_type_token53] = ACTIONS(3264),
    [aux_sym_basic_type_token54] = ACTIONS(3264),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3256),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3256),
    [sym_query_keyword] = ACTIONS(3256),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3256),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3270),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1300)] = {
    [sym_type_specification] = STATE(12247),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1301)] = {
    [sym_type_specification] = STATE(12416),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1302)] = {
    [sym_type_specification] = STATE(1225),
    [sym_text_type] = STATE(1232),
    [sym_code_type] = STATE(1232),
    [sym_option_type] = STATE(1231),
    [sym_record_type] = STATE(1231),
    [sym_dotnet_type] = STATE(1231),
    [sym_object_reference_type] = STATE(1231),
    [sym_array_type] = STATE(1233),
    [sym_list_type] = STATE(1233),
    [sym_dictionary_type] = STATE(1233),
    [sym_basic_type] = STATE(1231),
    [sym_codeunit_keyword] = STATE(8162),
    [sym_xmlport_keyword] = STATE(8162),
    [sym_enum_keyword] = STATE(8162),
    [sym_controladdin_keyword] = STATE(8162),
    [sym_dotnet_keyword] = STATE(7685),
    [sym_identifier] = ACTIONS(3112),
    [aux_sym_text_type_token1] = ACTIONS(3114),
    [aux_sym_code_type_token1] = ACTIONS(3116),
    [aux_sym_option_type_token1] = ACTIONS(3118),
    [aux_sym_record_type_token1] = ACTIONS(3120),
    [aux_sym_object_reference_type_token1] = ACTIONS(3122),
    [aux_sym_object_reference_type_token2] = ACTIONS(3122),
    [aux_sym_array_type_token1] = ACTIONS(3124),
    [aux_sym_list_type_token1] = ACTIONS(3126),
    [aux_sym_dictionary_type_token1] = ACTIONS(3128),
    [aux_sym_basic_type_token1] = ACTIONS(3130),
    [aux_sym_basic_type_token2] = ACTIONS(3130),
    [aux_sym_basic_type_token3] = ACTIONS(3130),
    [aux_sym_basic_type_token4] = ACTIONS(3130),
    [aux_sym_basic_type_token5] = ACTIONS(3130),
    [aux_sym_basic_type_token6] = ACTIONS(3132),
    [aux_sym_basic_type_token7] = ACTIONS(3130),
    [aux_sym_basic_type_token8] = ACTIONS(3130),
    [aux_sym_basic_type_token9] = ACTIONS(3130),
    [aux_sym_basic_type_token10] = ACTIONS(3130),
    [aux_sym_basic_type_token11] = ACTIONS(3130),
    [aux_sym_basic_type_token12] = ACTIONS(3130),
    [aux_sym_basic_type_token13] = ACTIONS(3134),
    [aux_sym_basic_type_token14] = ACTIONS(3130),
    [aux_sym_basic_type_token15] = ACTIONS(3130),
    [aux_sym_basic_type_token16] = ACTIONS(3130),
    [aux_sym_basic_type_token17] = ACTIONS(3130),
    [aux_sym_basic_type_token18] = ACTIONS(3130),
    [aux_sym_basic_type_token19] = ACTIONS(3130),
    [aux_sym_basic_type_token20] = ACTIONS(3130),
    [aux_sym_basic_type_token21] = ACTIONS(3130),
    [aux_sym_basic_type_token22] = ACTIONS(3130),
    [aux_sym_basic_type_token23] = ACTIONS(3130),
    [aux_sym_basic_type_token24] = ACTIONS(3130),
    [aux_sym_basic_type_token25] = ACTIONS(3130),
    [aux_sym_basic_type_token26] = ACTIONS(3130),
    [aux_sym_basic_type_token27] = ACTIONS(3130),
    [aux_sym_basic_type_token28] = ACTIONS(3130),
    [aux_sym_basic_type_token29] = ACTIONS(3130),
    [aux_sym_basic_type_token30] = ACTIONS(3130),
    [aux_sym_basic_type_token31] = ACTIONS(3130),
    [aux_sym_basic_type_token32] = ACTIONS(3130),
    [aux_sym_basic_type_token33] = ACTIONS(3130),
    [aux_sym_basic_type_token34] = ACTIONS(3130),
    [aux_sym_basic_type_token35] = ACTIONS(3130),
    [aux_sym_basic_type_token36] = ACTIONS(3130),
    [aux_sym_basic_type_token37] = ACTIONS(3130),
    [aux_sym_basic_type_token38] = ACTIONS(3130),
    [aux_sym_basic_type_token39] = ACTIONS(3130),
    [aux_sym_basic_type_token40] = ACTIONS(3130),
    [aux_sym_basic_type_token41] = ACTIONS(3130),
    [aux_sym_basic_type_token42] = ACTIONS(3130),
    [aux_sym_basic_type_token43] = ACTIONS(3130),
    [aux_sym_basic_type_token44] = ACTIONS(3130),
    [aux_sym_basic_type_token45] = ACTIONS(3130),
    [aux_sym_basic_type_token46] = ACTIONS(3130),
    [aux_sym_basic_type_token47] = ACTIONS(3130),
    [aux_sym_basic_type_token48] = ACTIONS(3130),
    [aux_sym_basic_type_token49] = ACTIONS(3130),
    [aux_sym_basic_type_token50] = ACTIONS(3130),
    [aux_sym_basic_type_token51] = ACTIONS(3130),
    [aux_sym_basic_type_token52] = ACTIONS(3130),
    [aux_sym_basic_type_token53] = ACTIONS(3130),
    [aux_sym_basic_type_token54] = ACTIONS(3130),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3122),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3122),
    [sym_query_keyword] = ACTIONS(3122),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3122),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3136),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1303)] = {
    [sym_type_specification] = STATE(2142),
    [sym_text_type] = STATE(2207),
    [sym_code_type] = STATE(2207),
    [sym_option_type] = STATE(2206),
    [sym_record_type] = STATE(2206),
    [sym_dotnet_type] = STATE(2206),
    [sym_object_reference_type] = STATE(2206),
    [sym_array_type] = STATE(2209),
    [sym_list_type] = STATE(2209),
    [sym_dictionary_type] = STATE(2209),
    [sym_basic_type] = STATE(2206),
    [sym_codeunit_keyword] = STATE(8093),
    [sym_xmlport_keyword] = STATE(8093),
    [sym_enum_keyword] = STATE(8093),
    [sym_controladdin_keyword] = STATE(8093),
    [sym_dotnet_keyword] = STATE(7721),
    [sym_identifier] = ACTIONS(3246),
    [aux_sym_text_type_token1] = ACTIONS(3248),
    [aux_sym_code_type_token1] = ACTIONS(3250),
    [aux_sym_option_type_token1] = ACTIONS(3252),
    [aux_sym_record_type_token1] = ACTIONS(3254),
    [aux_sym_object_reference_type_token1] = ACTIONS(3256),
    [aux_sym_object_reference_type_token2] = ACTIONS(3256),
    [aux_sym_array_type_token1] = ACTIONS(3258),
    [aux_sym_list_type_token1] = ACTIONS(3260),
    [aux_sym_dictionary_type_token1] = ACTIONS(3262),
    [aux_sym_basic_type_token1] = ACTIONS(3264),
    [aux_sym_basic_type_token2] = ACTIONS(3264),
    [aux_sym_basic_type_token3] = ACTIONS(3264),
    [aux_sym_basic_type_token4] = ACTIONS(3264),
    [aux_sym_basic_type_token5] = ACTIONS(3264),
    [aux_sym_basic_type_token6] = ACTIONS(3266),
    [aux_sym_basic_type_token7] = ACTIONS(3264),
    [aux_sym_basic_type_token8] = ACTIONS(3264),
    [aux_sym_basic_type_token9] = ACTIONS(3264),
    [aux_sym_basic_type_token10] = ACTIONS(3264),
    [aux_sym_basic_type_token11] = ACTIONS(3264),
    [aux_sym_basic_type_token12] = ACTIONS(3264),
    [aux_sym_basic_type_token13] = ACTIONS(3268),
    [aux_sym_basic_type_token14] = ACTIONS(3264),
    [aux_sym_basic_type_token15] = ACTIONS(3264),
    [aux_sym_basic_type_token16] = ACTIONS(3264),
    [aux_sym_basic_type_token17] = ACTIONS(3264),
    [aux_sym_basic_type_token18] = ACTIONS(3264),
    [aux_sym_basic_type_token19] = ACTIONS(3264),
    [aux_sym_basic_type_token20] = ACTIONS(3264),
    [aux_sym_basic_type_token21] = ACTIONS(3264),
    [aux_sym_basic_type_token22] = ACTIONS(3264),
    [aux_sym_basic_type_token23] = ACTIONS(3264),
    [aux_sym_basic_type_token24] = ACTIONS(3264),
    [aux_sym_basic_type_token25] = ACTIONS(3264),
    [aux_sym_basic_type_token26] = ACTIONS(3264),
    [aux_sym_basic_type_token27] = ACTIONS(3264),
    [aux_sym_basic_type_token28] = ACTIONS(3264),
    [aux_sym_basic_type_token29] = ACTIONS(3264),
    [aux_sym_basic_type_token30] = ACTIONS(3264),
    [aux_sym_basic_type_token31] = ACTIONS(3264),
    [aux_sym_basic_type_token32] = ACTIONS(3264),
    [aux_sym_basic_type_token33] = ACTIONS(3264),
    [aux_sym_basic_type_token34] = ACTIONS(3264),
    [aux_sym_basic_type_token35] = ACTIONS(3264),
    [aux_sym_basic_type_token36] = ACTIONS(3264),
    [aux_sym_basic_type_token37] = ACTIONS(3264),
    [aux_sym_basic_type_token38] = ACTIONS(3264),
    [aux_sym_basic_type_token39] = ACTIONS(3264),
    [aux_sym_basic_type_token40] = ACTIONS(3264),
    [aux_sym_basic_type_token41] = ACTIONS(3264),
    [aux_sym_basic_type_token42] = ACTIONS(3264),
    [aux_sym_basic_type_token43] = ACTIONS(3264),
    [aux_sym_basic_type_token44] = ACTIONS(3264),
    [aux_sym_basic_type_token45] = ACTIONS(3264),
    [aux_sym_basic_type_token46] = ACTIONS(3264),
    [aux_sym_basic_type_token47] = ACTIONS(3264),
    [aux_sym_basic_type_token48] = ACTIONS(3264),
    [aux_sym_basic_type_token49] = ACTIONS(3264),
    [aux_sym_basic_type_token50] = ACTIONS(3264),
    [aux_sym_basic_type_token51] = ACTIONS(3264),
    [aux_sym_basic_type_token52] = ACTIONS(3264),
    [aux_sym_basic_type_token53] = ACTIONS(3264),
    [aux_sym_basic_type_token54] = ACTIONS(3264),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3256),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3256),
    [sym_query_keyword] = ACTIONS(3256),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3256),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3270),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1304)] = {
    [sym_type_specification] = STATE(11982),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1305)] = {
    [sym_type_specification] = STATE(12510),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1306)] = {
    [sym_type_specification] = STATE(1152),
    [sym_text_type] = STATE(1148),
    [sym_code_type] = STATE(1148),
    [sym_option_type] = STATE(1146),
    [sym_record_type] = STATE(1146),
    [sym_dotnet_type] = STATE(1146),
    [sym_object_reference_type] = STATE(1146),
    [sym_array_type] = STATE(1151),
    [sym_list_type] = STATE(1151),
    [sym_dictionary_type] = STATE(1151),
    [sym_basic_type] = STATE(1146),
    [sym_codeunit_keyword] = STATE(7968),
    [sym_xmlport_keyword] = STATE(7968),
    [sym_enum_keyword] = STATE(7968),
    [sym_controladdin_keyword] = STATE(7968),
    [sym_dotnet_keyword] = STATE(7651),
    [sym_identifier] = ACTIONS(3216),
    [aux_sym_text_type_token1] = ACTIONS(3218),
    [aux_sym_code_type_token1] = ACTIONS(3220),
    [aux_sym_option_type_token1] = ACTIONS(3222),
    [aux_sym_record_type_token1] = ACTIONS(3224),
    [aux_sym_object_reference_type_token1] = ACTIONS(3226),
    [aux_sym_object_reference_type_token2] = ACTIONS(3226),
    [aux_sym_array_type_token1] = ACTIONS(3228),
    [aux_sym_list_type_token1] = ACTIONS(3230),
    [aux_sym_dictionary_type_token1] = ACTIONS(3232),
    [aux_sym_basic_type_token1] = ACTIONS(3234),
    [aux_sym_basic_type_token2] = ACTIONS(3234),
    [aux_sym_basic_type_token3] = ACTIONS(3234),
    [aux_sym_basic_type_token4] = ACTIONS(3234),
    [aux_sym_basic_type_token5] = ACTIONS(3234),
    [aux_sym_basic_type_token6] = ACTIONS(3236),
    [aux_sym_basic_type_token7] = ACTIONS(3234),
    [aux_sym_basic_type_token8] = ACTIONS(3234),
    [aux_sym_basic_type_token9] = ACTIONS(3234),
    [aux_sym_basic_type_token10] = ACTIONS(3234),
    [aux_sym_basic_type_token11] = ACTIONS(3234),
    [aux_sym_basic_type_token12] = ACTIONS(3234),
    [aux_sym_basic_type_token13] = ACTIONS(3238),
    [aux_sym_basic_type_token14] = ACTIONS(3234),
    [aux_sym_basic_type_token15] = ACTIONS(3234),
    [aux_sym_basic_type_token16] = ACTIONS(3234),
    [aux_sym_basic_type_token17] = ACTIONS(3234),
    [aux_sym_basic_type_token18] = ACTIONS(3234),
    [aux_sym_basic_type_token19] = ACTIONS(3234),
    [aux_sym_basic_type_token20] = ACTIONS(3234),
    [aux_sym_basic_type_token21] = ACTIONS(3234),
    [aux_sym_basic_type_token22] = ACTIONS(3234),
    [aux_sym_basic_type_token23] = ACTIONS(3234),
    [aux_sym_basic_type_token24] = ACTIONS(3234),
    [aux_sym_basic_type_token25] = ACTIONS(3234),
    [aux_sym_basic_type_token26] = ACTIONS(3234),
    [aux_sym_basic_type_token27] = ACTIONS(3234),
    [aux_sym_basic_type_token28] = ACTIONS(3234),
    [aux_sym_basic_type_token29] = ACTIONS(3234),
    [aux_sym_basic_type_token30] = ACTIONS(3234),
    [aux_sym_basic_type_token31] = ACTIONS(3234),
    [aux_sym_basic_type_token32] = ACTIONS(3234),
    [aux_sym_basic_type_token33] = ACTIONS(3234),
    [aux_sym_basic_type_token34] = ACTIONS(3234),
    [aux_sym_basic_type_token35] = ACTIONS(3234),
    [aux_sym_basic_type_token36] = ACTIONS(3234),
    [aux_sym_basic_type_token37] = ACTIONS(3234),
    [aux_sym_basic_type_token38] = ACTIONS(3234),
    [aux_sym_basic_type_token39] = ACTIONS(3234),
    [aux_sym_basic_type_token40] = ACTIONS(3234),
    [aux_sym_basic_type_token41] = ACTIONS(3234),
    [aux_sym_basic_type_token42] = ACTIONS(3234),
    [aux_sym_basic_type_token43] = ACTIONS(3234),
    [aux_sym_basic_type_token44] = ACTIONS(3234),
    [aux_sym_basic_type_token45] = ACTIONS(3234),
    [aux_sym_basic_type_token46] = ACTIONS(3234),
    [aux_sym_basic_type_token47] = ACTIONS(3234),
    [aux_sym_basic_type_token48] = ACTIONS(3234),
    [aux_sym_basic_type_token49] = ACTIONS(3234),
    [aux_sym_basic_type_token50] = ACTIONS(3234),
    [aux_sym_basic_type_token51] = ACTIONS(3234),
    [aux_sym_basic_type_token52] = ACTIONS(3234),
    [aux_sym_basic_type_token53] = ACTIONS(3234),
    [aux_sym_basic_type_token54] = ACTIONS(3234),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3226),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3226),
    [sym_query_keyword] = ACTIONS(3226),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3226),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3240),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1307)] = {
    [sym_type_specification] = STATE(12658),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1308)] = {
    [sym_type_specification] = STATE(1150),
    [sym_text_type] = STATE(1148),
    [sym_code_type] = STATE(1148),
    [sym_option_type] = STATE(1146),
    [sym_record_type] = STATE(1146),
    [sym_dotnet_type] = STATE(1146),
    [sym_object_reference_type] = STATE(1146),
    [sym_array_type] = STATE(1151),
    [sym_list_type] = STATE(1151),
    [sym_dictionary_type] = STATE(1151),
    [sym_basic_type] = STATE(1146),
    [sym_codeunit_keyword] = STATE(7968),
    [sym_xmlport_keyword] = STATE(7968),
    [sym_enum_keyword] = STATE(7968),
    [sym_controladdin_keyword] = STATE(7968),
    [sym_dotnet_keyword] = STATE(7651),
    [sym_identifier] = ACTIONS(3216),
    [aux_sym_text_type_token1] = ACTIONS(3218),
    [aux_sym_code_type_token1] = ACTIONS(3220),
    [aux_sym_option_type_token1] = ACTIONS(3222),
    [aux_sym_record_type_token1] = ACTIONS(3224),
    [aux_sym_object_reference_type_token1] = ACTIONS(3226),
    [aux_sym_object_reference_type_token2] = ACTIONS(3226),
    [aux_sym_array_type_token1] = ACTIONS(3228),
    [aux_sym_list_type_token1] = ACTIONS(3230),
    [aux_sym_dictionary_type_token1] = ACTIONS(3232),
    [aux_sym_basic_type_token1] = ACTIONS(3234),
    [aux_sym_basic_type_token2] = ACTIONS(3234),
    [aux_sym_basic_type_token3] = ACTIONS(3234),
    [aux_sym_basic_type_token4] = ACTIONS(3234),
    [aux_sym_basic_type_token5] = ACTIONS(3234),
    [aux_sym_basic_type_token6] = ACTIONS(3236),
    [aux_sym_basic_type_token7] = ACTIONS(3234),
    [aux_sym_basic_type_token8] = ACTIONS(3234),
    [aux_sym_basic_type_token9] = ACTIONS(3234),
    [aux_sym_basic_type_token10] = ACTIONS(3234),
    [aux_sym_basic_type_token11] = ACTIONS(3234),
    [aux_sym_basic_type_token12] = ACTIONS(3234),
    [aux_sym_basic_type_token13] = ACTIONS(3238),
    [aux_sym_basic_type_token14] = ACTIONS(3234),
    [aux_sym_basic_type_token15] = ACTIONS(3234),
    [aux_sym_basic_type_token16] = ACTIONS(3234),
    [aux_sym_basic_type_token17] = ACTIONS(3234),
    [aux_sym_basic_type_token18] = ACTIONS(3234),
    [aux_sym_basic_type_token19] = ACTIONS(3234),
    [aux_sym_basic_type_token20] = ACTIONS(3234),
    [aux_sym_basic_type_token21] = ACTIONS(3234),
    [aux_sym_basic_type_token22] = ACTIONS(3234),
    [aux_sym_basic_type_token23] = ACTIONS(3234),
    [aux_sym_basic_type_token24] = ACTIONS(3234),
    [aux_sym_basic_type_token25] = ACTIONS(3234),
    [aux_sym_basic_type_token26] = ACTIONS(3234),
    [aux_sym_basic_type_token27] = ACTIONS(3234),
    [aux_sym_basic_type_token28] = ACTIONS(3234),
    [aux_sym_basic_type_token29] = ACTIONS(3234),
    [aux_sym_basic_type_token30] = ACTIONS(3234),
    [aux_sym_basic_type_token31] = ACTIONS(3234),
    [aux_sym_basic_type_token32] = ACTIONS(3234),
    [aux_sym_basic_type_token33] = ACTIONS(3234),
    [aux_sym_basic_type_token34] = ACTIONS(3234),
    [aux_sym_basic_type_token35] = ACTIONS(3234),
    [aux_sym_basic_type_token36] = ACTIONS(3234),
    [aux_sym_basic_type_token37] = ACTIONS(3234),
    [aux_sym_basic_type_token38] = ACTIONS(3234),
    [aux_sym_basic_type_token39] = ACTIONS(3234),
    [aux_sym_basic_type_token40] = ACTIONS(3234),
    [aux_sym_basic_type_token41] = ACTIONS(3234),
    [aux_sym_basic_type_token42] = ACTIONS(3234),
    [aux_sym_basic_type_token43] = ACTIONS(3234),
    [aux_sym_basic_type_token44] = ACTIONS(3234),
    [aux_sym_basic_type_token45] = ACTIONS(3234),
    [aux_sym_basic_type_token46] = ACTIONS(3234),
    [aux_sym_basic_type_token47] = ACTIONS(3234),
    [aux_sym_basic_type_token48] = ACTIONS(3234),
    [aux_sym_basic_type_token49] = ACTIONS(3234),
    [aux_sym_basic_type_token50] = ACTIONS(3234),
    [aux_sym_basic_type_token51] = ACTIONS(3234),
    [aux_sym_basic_type_token52] = ACTIONS(3234),
    [aux_sym_basic_type_token53] = ACTIONS(3234),
    [aux_sym_basic_type_token54] = ACTIONS(3234),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3226),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3226),
    [sym_query_keyword] = ACTIONS(3226),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3226),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3240),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1309)] = {
    [sym_type_specification] = STATE(12569),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(11194),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1310)] = {
    [sym_type_specification] = STATE(12619),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1311)] = {
    [sym_type_specification] = STATE(2198),
    [sym_text_type] = STATE(2207),
    [sym_code_type] = STATE(2207),
    [sym_option_type] = STATE(2206),
    [sym_record_type] = STATE(2206),
    [sym_dotnet_type] = STATE(2206),
    [sym_object_reference_type] = STATE(2206),
    [sym_array_type] = STATE(2209),
    [sym_list_type] = STATE(2209),
    [sym_dictionary_type] = STATE(2209),
    [sym_basic_type] = STATE(2206),
    [sym_codeunit_keyword] = STATE(8093),
    [sym_xmlport_keyword] = STATE(8093),
    [sym_enum_keyword] = STATE(8093),
    [sym_controladdin_keyword] = STATE(8093),
    [sym_dotnet_keyword] = STATE(7721),
    [sym_identifier] = ACTIONS(3246),
    [aux_sym_text_type_token1] = ACTIONS(3248),
    [aux_sym_code_type_token1] = ACTIONS(3250),
    [aux_sym_option_type_token1] = ACTIONS(3252),
    [aux_sym_record_type_token1] = ACTIONS(3254),
    [aux_sym_object_reference_type_token1] = ACTIONS(3256),
    [aux_sym_object_reference_type_token2] = ACTIONS(3256),
    [aux_sym_array_type_token1] = ACTIONS(3258),
    [aux_sym_list_type_token1] = ACTIONS(3260),
    [aux_sym_dictionary_type_token1] = ACTIONS(3262),
    [aux_sym_basic_type_token1] = ACTIONS(3264),
    [aux_sym_basic_type_token2] = ACTIONS(3264),
    [aux_sym_basic_type_token3] = ACTIONS(3264),
    [aux_sym_basic_type_token4] = ACTIONS(3264),
    [aux_sym_basic_type_token5] = ACTIONS(3264),
    [aux_sym_basic_type_token6] = ACTIONS(3266),
    [aux_sym_basic_type_token7] = ACTIONS(3264),
    [aux_sym_basic_type_token8] = ACTIONS(3264),
    [aux_sym_basic_type_token9] = ACTIONS(3264),
    [aux_sym_basic_type_token10] = ACTIONS(3264),
    [aux_sym_basic_type_token11] = ACTIONS(3264),
    [aux_sym_basic_type_token12] = ACTIONS(3264),
    [aux_sym_basic_type_token13] = ACTIONS(3268),
    [aux_sym_basic_type_token14] = ACTIONS(3264),
    [aux_sym_basic_type_token15] = ACTIONS(3264),
    [aux_sym_basic_type_token16] = ACTIONS(3264),
    [aux_sym_basic_type_token17] = ACTIONS(3264),
    [aux_sym_basic_type_token18] = ACTIONS(3264),
    [aux_sym_basic_type_token19] = ACTIONS(3264),
    [aux_sym_basic_type_token20] = ACTIONS(3264),
    [aux_sym_basic_type_token21] = ACTIONS(3264),
    [aux_sym_basic_type_token22] = ACTIONS(3264),
    [aux_sym_basic_type_token23] = ACTIONS(3264),
    [aux_sym_basic_type_token24] = ACTIONS(3264),
    [aux_sym_basic_type_token25] = ACTIONS(3264),
    [aux_sym_basic_type_token26] = ACTIONS(3264),
    [aux_sym_basic_type_token27] = ACTIONS(3264),
    [aux_sym_basic_type_token28] = ACTIONS(3264),
    [aux_sym_basic_type_token29] = ACTIONS(3264),
    [aux_sym_basic_type_token30] = ACTIONS(3264),
    [aux_sym_basic_type_token31] = ACTIONS(3264),
    [aux_sym_basic_type_token32] = ACTIONS(3264),
    [aux_sym_basic_type_token33] = ACTIONS(3264),
    [aux_sym_basic_type_token34] = ACTIONS(3264),
    [aux_sym_basic_type_token35] = ACTIONS(3264),
    [aux_sym_basic_type_token36] = ACTIONS(3264),
    [aux_sym_basic_type_token37] = ACTIONS(3264),
    [aux_sym_basic_type_token38] = ACTIONS(3264),
    [aux_sym_basic_type_token39] = ACTIONS(3264),
    [aux_sym_basic_type_token40] = ACTIONS(3264),
    [aux_sym_basic_type_token41] = ACTIONS(3264),
    [aux_sym_basic_type_token42] = ACTIONS(3264),
    [aux_sym_basic_type_token43] = ACTIONS(3264),
    [aux_sym_basic_type_token44] = ACTIONS(3264),
    [aux_sym_basic_type_token45] = ACTIONS(3264),
    [aux_sym_basic_type_token46] = ACTIONS(3264),
    [aux_sym_basic_type_token47] = ACTIONS(3264),
    [aux_sym_basic_type_token48] = ACTIONS(3264),
    [aux_sym_basic_type_token49] = ACTIONS(3264),
    [aux_sym_basic_type_token50] = ACTIONS(3264),
    [aux_sym_basic_type_token51] = ACTIONS(3264),
    [aux_sym_basic_type_token52] = ACTIONS(3264),
    [aux_sym_basic_type_token53] = ACTIONS(3264),
    [aux_sym_basic_type_token54] = ACTIONS(3264),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3256),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3256),
    [sym_query_keyword] = ACTIONS(3256),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3256),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3270),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1312)] = {
    [sym_type_specification] = STATE(1038),
    [sym_text_type] = STATE(1020),
    [sym_code_type] = STATE(1020),
    [sym_option_type] = STATE(1036),
    [sym_record_type] = STATE(1036),
    [sym_dotnet_type] = STATE(1036),
    [sym_object_reference_type] = STATE(1036),
    [sym_array_type] = STATE(1039),
    [sym_list_type] = STATE(1039),
    [sym_dictionary_type] = STATE(1039),
    [sym_basic_type] = STATE(1036),
    [sym_codeunit_keyword] = STATE(7909),
    [sym_xmlport_keyword] = STATE(7909),
    [sym_enum_keyword] = STATE(7909),
    [sym_controladdin_keyword] = STATE(7909),
    [sym_dotnet_keyword] = STATE(7643),
    [sym_identifier] = ACTIONS(3190),
    [aux_sym_text_type_token1] = ACTIONS(3192),
    [aux_sym_code_type_token1] = ACTIONS(3194),
    [aux_sym_option_type_token1] = ACTIONS(3196),
    [aux_sym_record_type_token1] = ACTIONS(3198),
    [aux_sym_object_reference_type_token1] = ACTIONS(3200),
    [aux_sym_object_reference_type_token2] = ACTIONS(3200),
    [aux_sym_array_type_token1] = ACTIONS(3202),
    [aux_sym_list_type_token1] = ACTIONS(3204),
    [aux_sym_dictionary_type_token1] = ACTIONS(3206),
    [aux_sym_basic_type_token1] = ACTIONS(3208),
    [aux_sym_basic_type_token2] = ACTIONS(3208),
    [aux_sym_basic_type_token3] = ACTIONS(3208),
    [aux_sym_basic_type_token4] = ACTIONS(3208),
    [aux_sym_basic_type_token5] = ACTIONS(3208),
    [aux_sym_basic_type_token6] = ACTIONS(3210),
    [aux_sym_basic_type_token7] = ACTIONS(3208),
    [aux_sym_basic_type_token8] = ACTIONS(3208),
    [aux_sym_basic_type_token9] = ACTIONS(3208),
    [aux_sym_basic_type_token10] = ACTIONS(3208),
    [aux_sym_basic_type_token11] = ACTIONS(3208),
    [aux_sym_basic_type_token12] = ACTIONS(3208),
    [aux_sym_basic_type_token13] = ACTIONS(3212),
    [aux_sym_basic_type_token14] = ACTIONS(3208),
    [aux_sym_basic_type_token15] = ACTIONS(3208),
    [aux_sym_basic_type_token16] = ACTIONS(3208),
    [aux_sym_basic_type_token17] = ACTIONS(3208),
    [aux_sym_basic_type_token18] = ACTIONS(3208),
    [aux_sym_basic_type_token19] = ACTIONS(3208),
    [aux_sym_basic_type_token20] = ACTIONS(3208),
    [aux_sym_basic_type_token21] = ACTIONS(3208),
    [aux_sym_basic_type_token22] = ACTIONS(3208),
    [aux_sym_basic_type_token23] = ACTIONS(3208),
    [aux_sym_basic_type_token24] = ACTIONS(3208),
    [aux_sym_basic_type_token25] = ACTIONS(3208),
    [aux_sym_basic_type_token26] = ACTIONS(3208),
    [aux_sym_basic_type_token27] = ACTIONS(3208),
    [aux_sym_basic_type_token28] = ACTIONS(3208),
    [aux_sym_basic_type_token29] = ACTIONS(3208),
    [aux_sym_basic_type_token30] = ACTIONS(3208),
    [aux_sym_basic_type_token31] = ACTIONS(3208),
    [aux_sym_basic_type_token32] = ACTIONS(3208),
    [aux_sym_basic_type_token33] = ACTIONS(3208),
    [aux_sym_basic_type_token34] = ACTIONS(3208),
    [aux_sym_basic_type_token35] = ACTIONS(3208),
    [aux_sym_basic_type_token36] = ACTIONS(3208),
    [aux_sym_basic_type_token37] = ACTIONS(3208),
    [aux_sym_basic_type_token38] = ACTIONS(3208),
    [aux_sym_basic_type_token39] = ACTIONS(3208),
    [aux_sym_basic_type_token40] = ACTIONS(3208),
    [aux_sym_basic_type_token41] = ACTIONS(3208),
    [aux_sym_basic_type_token42] = ACTIONS(3208),
    [aux_sym_basic_type_token43] = ACTIONS(3208),
    [aux_sym_basic_type_token44] = ACTIONS(3208),
    [aux_sym_basic_type_token45] = ACTIONS(3208),
    [aux_sym_basic_type_token46] = ACTIONS(3208),
    [aux_sym_basic_type_token47] = ACTIONS(3208),
    [aux_sym_basic_type_token48] = ACTIONS(3208),
    [aux_sym_basic_type_token49] = ACTIONS(3208),
    [aux_sym_basic_type_token50] = ACTIONS(3208),
    [aux_sym_basic_type_token51] = ACTIONS(3208),
    [aux_sym_basic_type_token52] = ACTIONS(3208),
    [aux_sym_basic_type_token53] = ACTIONS(3208),
    [aux_sym_basic_type_token54] = ACTIONS(3208),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3200),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3200),
    [sym_query_keyword] = ACTIONS(3200),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3200),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3214),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1313)] = {
    [sym_type_specification] = STATE(1021),
    [sym_text_type] = STATE(1020),
    [sym_code_type] = STATE(1020),
    [sym_option_type] = STATE(1036),
    [sym_record_type] = STATE(1036),
    [sym_dotnet_type] = STATE(1036),
    [sym_object_reference_type] = STATE(1036),
    [sym_array_type] = STATE(1039),
    [sym_list_type] = STATE(1039),
    [sym_dictionary_type] = STATE(1039),
    [sym_basic_type] = STATE(1036),
    [sym_codeunit_keyword] = STATE(7909),
    [sym_xmlport_keyword] = STATE(7909),
    [sym_enum_keyword] = STATE(7909),
    [sym_controladdin_keyword] = STATE(7909),
    [sym_dotnet_keyword] = STATE(7643),
    [sym_identifier] = ACTIONS(3190),
    [aux_sym_text_type_token1] = ACTIONS(3192),
    [aux_sym_code_type_token1] = ACTIONS(3194),
    [aux_sym_option_type_token1] = ACTIONS(3196),
    [aux_sym_record_type_token1] = ACTIONS(3198),
    [aux_sym_object_reference_type_token1] = ACTIONS(3200),
    [aux_sym_object_reference_type_token2] = ACTIONS(3200),
    [aux_sym_array_type_token1] = ACTIONS(3202),
    [aux_sym_list_type_token1] = ACTIONS(3204),
    [aux_sym_dictionary_type_token1] = ACTIONS(3206),
    [aux_sym_basic_type_token1] = ACTIONS(3208),
    [aux_sym_basic_type_token2] = ACTIONS(3208),
    [aux_sym_basic_type_token3] = ACTIONS(3208),
    [aux_sym_basic_type_token4] = ACTIONS(3208),
    [aux_sym_basic_type_token5] = ACTIONS(3208),
    [aux_sym_basic_type_token6] = ACTIONS(3210),
    [aux_sym_basic_type_token7] = ACTIONS(3208),
    [aux_sym_basic_type_token8] = ACTIONS(3208),
    [aux_sym_basic_type_token9] = ACTIONS(3208),
    [aux_sym_basic_type_token10] = ACTIONS(3208),
    [aux_sym_basic_type_token11] = ACTIONS(3208),
    [aux_sym_basic_type_token12] = ACTIONS(3208),
    [aux_sym_basic_type_token13] = ACTIONS(3212),
    [aux_sym_basic_type_token14] = ACTIONS(3208),
    [aux_sym_basic_type_token15] = ACTIONS(3208),
    [aux_sym_basic_type_token16] = ACTIONS(3208),
    [aux_sym_basic_type_token17] = ACTIONS(3208),
    [aux_sym_basic_type_token18] = ACTIONS(3208),
    [aux_sym_basic_type_token19] = ACTIONS(3208),
    [aux_sym_basic_type_token20] = ACTIONS(3208),
    [aux_sym_basic_type_token21] = ACTIONS(3208),
    [aux_sym_basic_type_token22] = ACTIONS(3208),
    [aux_sym_basic_type_token23] = ACTIONS(3208),
    [aux_sym_basic_type_token24] = ACTIONS(3208),
    [aux_sym_basic_type_token25] = ACTIONS(3208),
    [aux_sym_basic_type_token26] = ACTIONS(3208),
    [aux_sym_basic_type_token27] = ACTIONS(3208),
    [aux_sym_basic_type_token28] = ACTIONS(3208),
    [aux_sym_basic_type_token29] = ACTIONS(3208),
    [aux_sym_basic_type_token30] = ACTIONS(3208),
    [aux_sym_basic_type_token31] = ACTIONS(3208),
    [aux_sym_basic_type_token32] = ACTIONS(3208),
    [aux_sym_basic_type_token33] = ACTIONS(3208),
    [aux_sym_basic_type_token34] = ACTIONS(3208),
    [aux_sym_basic_type_token35] = ACTIONS(3208),
    [aux_sym_basic_type_token36] = ACTIONS(3208),
    [aux_sym_basic_type_token37] = ACTIONS(3208),
    [aux_sym_basic_type_token38] = ACTIONS(3208),
    [aux_sym_basic_type_token39] = ACTIONS(3208),
    [aux_sym_basic_type_token40] = ACTIONS(3208),
    [aux_sym_basic_type_token41] = ACTIONS(3208),
    [aux_sym_basic_type_token42] = ACTIONS(3208),
    [aux_sym_basic_type_token43] = ACTIONS(3208),
    [aux_sym_basic_type_token44] = ACTIONS(3208),
    [aux_sym_basic_type_token45] = ACTIONS(3208),
    [aux_sym_basic_type_token46] = ACTIONS(3208),
    [aux_sym_basic_type_token47] = ACTIONS(3208),
    [aux_sym_basic_type_token48] = ACTIONS(3208),
    [aux_sym_basic_type_token49] = ACTIONS(3208),
    [aux_sym_basic_type_token50] = ACTIONS(3208),
    [aux_sym_basic_type_token51] = ACTIONS(3208),
    [aux_sym_basic_type_token52] = ACTIONS(3208),
    [aux_sym_basic_type_token53] = ACTIONS(3208),
    [aux_sym_basic_type_token54] = ACTIONS(3208),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3200),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3200),
    [sym_query_keyword] = ACTIONS(3200),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3200),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3214),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1314)] = {
    [sym_type_specification] = STATE(2197),
    [sym_text_type] = STATE(2207),
    [sym_code_type] = STATE(2207),
    [sym_option_type] = STATE(2206),
    [sym_record_type] = STATE(2206),
    [sym_dotnet_type] = STATE(2206),
    [sym_object_reference_type] = STATE(2206),
    [sym_array_type] = STATE(2209),
    [sym_list_type] = STATE(2209),
    [sym_dictionary_type] = STATE(2209),
    [sym_basic_type] = STATE(2206),
    [sym_codeunit_keyword] = STATE(8093),
    [sym_xmlport_keyword] = STATE(8093),
    [sym_enum_keyword] = STATE(8093),
    [sym_controladdin_keyword] = STATE(8093),
    [sym_dotnet_keyword] = STATE(7721),
    [sym_identifier] = ACTIONS(3246),
    [aux_sym_text_type_token1] = ACTIONS(3248),
    [aux_sym_code_type_token1] = ACTIONS(3250),
    [aux_sym_option_type_token1] = ACTIONS(3252),
    [aux_sym_record_type_token1] = ACTIONS(3254),
    [aux_sym_object_reference_type_token1] = ACTIONS(3256),
    [aux_sym_object_reference_type_token2] = ACTIONS(3256),
    [aux_sym_array_type_token1] = ACTIONS(3258),
    [aux_sym_list_type_token1] = ACTIONS(3260),
    [aux_sym_dictionary_type_token1] = ACTIONS(3262),
    [aux_sym_basic_type_token1] = ACTIONS(3264),
    [aux_sym_basic_type_token2] = ACTIONS(3264),
    [aux_sym_basic_type_token3] = ACTIONS(3264),
    [aux_sym_basic_type_token4] = ACTIONS(3264),
    [aux_sym_basic_type_token5] = ACTIONS(3264),
    [aux_sym_basic_type_token6] = ACTIONS(3266),
    [aux_sym_basic_type_token7] = ACTIONS(3264),
    [aux_sym_basic_type_token8] = ACTIONS(3264),
    [aux_sym_basic_type_token9] = ACTIONS(3264),
    [aux_sym_basic_type_token10] = ACTIONS(3264),
    [aux_sym_basic_type_token11] = ACTIONS(3264),
    [aux_sym_basic_type_token12] = ACTIONS(3264),
    [aux_sym_basic_type_token13] = ACTIONS(3268),
    [aux_sym_basic_type_token14] = ACTIONS(3264),
    [aux_sym_basic_type_token15] = ACTIONS(3264),
    [aux_sym_basic_type_token16] = ACTIONS(3264),
    [aux_sym_basic_type_token17] = ACTIONS(3264),
    [aux_sym_basic_type_token18] = ACTIONS(3264),
    [aux_sym_basic_type_token19] = ACTIONS(3264),
    [aux_sym_basic_type_token20] = ACTIONS(3264),
    [aux_sym_basic_type_token21] = ACTIONS(3264),
    [aux_sym_basic_type_token22] = ACTIONS(3264),
    [aux_sym_basic_type_token23] = ACTIONS(3264),
    [aux_sym_basic_type_token24] = ACTIONS(3264),
    [aux_sym_basic_type_token25] = ACTIONS(3264),
    [aux_sym_basic_type_token26] = ACTIONS(3264),
    [aux_sym_basic_type_token27] = ACTIONS(3264),
    [aux_sym_basic_type_token28] = ACTIONS(3264),
    [aux_sym_basic_type_token29] = ACTIONS(3264),
    [aux_sym_basic_type_token30] = ACTIONS(3264),
    [aux_sym_basic_type_token31] = ACTIONS(3264),
    [aux_sym_basic_type_token32] = ACTIONS(3264),
    [aux_sym_basic_type_token33] = ACTIONS(3264),
    [aux_sym_basic_type_token34] = ACTIONS(3264),
    [aux_sym_basic_type_token35] = ACTIONS(3264),
    [aux_sym_basic_type_token36] = ACTIONS(3264),
    [aux_sym_basic_type_token37] = ACTIONS(3264),
    [aux_sym_basic_type_token38] = ACTIONS(3264),
    [aux_sym_basic_type_token39] = ACTIONS(3264),
    [aux_sym_basic_type_token40] = ACTIONS(3264),
    [aux_sym_basic_type_token41] = ACTIONS(3264),
    [aux_sym_basic_type_token42] = ACTIONS(3264),
    [aux_sym_basic_type_token43] = ACTIONS(3264),
    [aux_sym_basic_type_token44] = ACTIONS(3264),
    [aux_sym_basic_type_token45] = ACTIONS(3264),
    [aux_sym_basic_type_token46] = ACTIONS(3264),
    [aux_sym_basic_type_token47] = ACTIONS(3264),
    [aux_sym_basic_type_token48] = ACTIONS(3264),
    [aux_sym_basic_type_token49] = ACTIONS(3264),
    [aux_sym_basic_type_token50] = ACTIONS(3264),
    [aux_sym_basic_type_token51] = ACTIONS(3264),
    [aux_sym_basic_type_token52] = ACTIONS(3264),
    [aux_sym_basic_type_token53] = ACTIONS(3264),
    [aux_sym_basic_type_token54] = ACTIONS(3264),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3256),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3256),
    [sym_query_keyword] = ACTIONS(3256),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3256),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3270),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1315)] = {
    [sym_type_specification] = STATE(11957),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1316)] = {
    [sym_type_specification] = STATE(6872),
    [sym_text_type] = STATE(6858),
    [sym_code_type] = STATE(6858),
    [sym_option_type] = STATE(6855),
    [sym_record_type] = STATE(6855),
    [sym_dotnet_type] = STATE(6855),
    [sym_object_reference_type] = STATE(6855),
    [sym_array_type] = STATE(6859),
    [sym_list_type] = STATE(6859),
    [sym_dictionary_type] = STATE(6859),
    [sym_basic_type] = STATE(6855),
    [sym_codeunit_keyword] = STATE(7883),
    [sym_xmlport_keyword] = STATE(7883),
    [sym_enum_keyword] = STATE(7883),
    [sym_controladdin_keyword] = STATE(7883),
    [sym_dotnet_keyword] = STATE(7716),
    [sym_identifier] = ACTIONS(3086),
    [aux_sym_text_type_token1] = ACTIONS(3088),
    [aux_sym_code_type_token1] = ACTIONS(3090),
    [aux_sym_option_type_token1] = ACTIONS(3092),
    [aux_sym_record_type_token1] = ACTIONS(3094),
    [aux_sym_object_reference_type_token1] = ACTIONS(3096),
    [aux_sym_object_reference_type_token2] = ACTIONS(3096),
    [aux_sym_array_type_token1] = ACTIONS(3098),
    [aux_sym_list_type_token1] = ACTIONS(3100),
    [aux_sym_dictionary_type_token1] = ACTIONS(3102),
    [aux_sym_basic_type_token1] = ACTIONS(3104),
    [aux_sym_basic_type_token2] = ACTIONS(3104),
    [aux_sym_basic_type_token3] = ACTIONS(3104),
    [aux_sym_basic_type_token4] = ACTIONS(3104),
    [aux_sym_basic_type_token5] = ACTIONS(3104),
    [aux_sym_basic_type_token6] = ACTIONS(3106),
    [aux_sym_basic_type_token7] = ACTIONS(3104),
    [aux_sym_basic_type_token8] = ACTIONS(3104),
    [aux_sym_basic_type_token9] = ACTIONS(3104),
    [aux_sym_basic_type_token10] = ACTIONS(3104),
    [aux_sym_basic_type_token11] = ACTIONS(3104),
    [aux_sym_basic_type_token12] = ACTIONS(3104),
    [aux_sym_basic_type_token13] = ACTIONS(3108),
    [aux_sym_basic_type_token14] = ACTIONS(3104),
    [aux_sym_basic_type_token15] = ACTIONS(3104),
    [aux_sym_basic_type_token16] = ACTIONS(3104),
    [aux_sym_basic_type_token17] = ACTIONS(3104),
    [aux_sym_basic_type_token18] = ACTIONS(3104),
    [aux_sym_basic_type_token19] = ACTIONS(3104),
    [aux_sym_basic_type_token20] = ACTIONS(3104),
    [aux_sym_basic_type_token21] = ACTIONS(3104),
    [aux_sym_basic_type_token22] = ACTIONS(3104),
    [aux_sym_basic_type_token23] = ACTIONS(3104),
    [aux_sym_basic_type_token24] = ACTIONS(3104),
    [aux_sym_basic_type_token25] = ACTIONS(3104),
    [aux_sym_basic_type_token26] = ACTIONS(3104),
    [aux_sym_basic_type_token27] = ACTIONS(3104),
    [aux_sym_basic_type_token28] = ACTIONS(3104),
    [aux_sym_basic_type_token29] = ACTIONS(3104),
    [aux_sym_basic_type_token30] = ACTIONS(3104),
    [aux_sym_basic_type_token31] = ACTIONS(3104),
    [aux_sym_basic_type_token32] = ACTIONS(3104),
    [aux_sym_basic_type_token33] = ACTIONS(3104),
    [aux_sym_basic_type_token34] = ACTIONS(3104),
    [aux_sym_basic_type_token35] = ACTIONS(3104),
    [aux_sym_basic_type_token36] = ACTIONS(3104),
    [aux_sym_basic_type_token37] = ACTIONS(3104),
    [aux_sym_basic_type_token38] = ACTIONS(3104),
    [aux_sym_basic_type_token39] = ACTIONS(3104),
    [aux_sym_basic_type_token40] = ACTIONS(3104),
    [aux_sym_basic_type_token41] = ACTIONS(3104),
    [aux_sym_basic_type_token42] = ACTIONS(3104),
    [aux_sym_basic_type_token43] = ACTIONS(3104),
    [aux_sym_basic_type_token44] = ACTIONS(3104),
    [aux_sym_basic_type_token45] = ACTIONS(3104),
    [aux_sym_basic_type_token46] = ACTIONS(3104),
    [aux_sym_basic_type_token47] = ACTIONS(3104),
    [aux_sym_basic_type_token48] = ACTIONS(3104),
    [aux_sym_basic_type_token49] = ACTIONS(3104),
    [aux_sym_basic_type_token50] = ACTIONS(3104),
    [aux_sym_basic_type_token51] = ACTIONS(3104),
    [aux_sym_basic_type_token52] = ACTIONS(3104),
    [aux_sym_basic_type_token53] = ACTIONS(3104),
    [aux_sym_basic_type_token54] = ACTIONS(3104),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3096),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3096),
    [sym_query_keyword] = ACTIONS(3096),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3096),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3110),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1317)] = {
    [sym_type_specification] = STATE(12260),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1318)] = {
    [sym_type_specification] = STATE(7397),
    [sym_text_type] = STATE(7404),
    [sym_code_type] = STATE(7404),
    [sym_option_type] = STATE(7403),
    [sym_record_type] = STATE(7403),
    [sym_dotnet_type] = STATE(7403),
    [sym_object_reference_type] = STATE(7403),
    [sym_array_type] = STATE(7405),
    [sym_list_type] = STATE(7405),
    [sym_dictionary_type] = STATE(7405),
    [sym_basic_type] = STATE(7403),
    [sym_codeunit_keyword] = STATE(7975),
    [sym_xmlport_keyword] = STATE(7975),
    [sym_enum_keyword] = STATE(7975),
    [sym_controladdin_keyword] = STATE(7975),
    [sym_dotnet_keyword] = STATE(7692),
    [sym_identifier] = ACTIONS(3272),
    [aux_sym_text_type_token1] = ACTIONS(3274),
    [aux_sym_code_type_token1] = ACTIONS(3276),
    [aux_sym_option_type_token1] = ACTIONS(3278),
    [aux_sym_record_type_token1] = ACTIONS(3280),
    [aux_sym_object_reference_type_token1] = ACTIONS(3282),
    [aux_sym_object_reference_type_token2] = ACTIONS(3282),
    [aux_sym_array_type_token1] = ACTIONS(3284),
    [aux_sym_list_type_token1] = ACTIONS(3286),
    [aux_sym_dictionary_type_token1] = ACTIONS(3288),
    [aux_sym_basic_type_token1] = ACTIONS(3290),
    [aux_sym_basic_type_token2] = ACTIONS(3290),
    [aux_sym_basic_type_token3] = ACTIONS(3290),
    [aux_sym_basic_type_token4] = ACTIONS(3290),
    [aux_sym_basic_type_token5] = ACTIONS(3290),
    [aux_sym_basic_type_token6] = ACTIONS(3292),
    [aux_sym_basic_type_token7] = ACTIONS(3290),
    [aux_sym_basic_type_token8] = ACTIONS(3290),
    [aux_sym_basic_type_token9] = ACTIONS(3290),
    [aux_sym_basic_type_token10] = ACTIONS(3290),
    [aux_sym_basic_type_token11] = ACTIONS(3290),
    [aux_sym_basic_type_token12] = ACTIONS(3290),
    [aux_sym_basic_type_token13] = ACTIONS(3294),
    [aux_sym_basic_type_token14] = ACTIONS(3290),
    [aux_sym_basic_type_token15] = ACTIONS(3290),
    [aux_sym_basic_type_token16] = ACTIONS(3290),
    [aux_sym_basic_type_token17] = ACTIONS(3290),
    [aux_sym_basic_type_token18] = ACTIONS(3290),
    [aux_sym_basic_type_token19] = ACTIONS(3290),
    [aux_sym_basic_type_token20] = ACTIONS(3290),
    [aux_sym_basic_type_token21] = ACTIONS(3290),
    [aux_sym_basic_type_token22] = ACTIONS(3290),
    [aux_sym_basic_type_token23] = ACTIONS(3290),
    [aux_sym_basic_type_token24] = ACTIONS(3290),
    [aux_sym_basic_type_token25] = ACTIONS(3290),
    [aux_sym_basic_type_token26] = ACTIONS(3290),
    [aux_sym_basic_type_token27] = ACTIONS(3290),
    [aux_sym_basic_type_token28] = ACTIONS(3290),
    [aux_sym_basic_type_token29] = ACTIONS(3290),
    [aux_sym_basic_type_token30] = ACTIONS(3290),
    [aux_sym_basic_type_token31] = ACTIONS(3290),
    [aux_sym_basic_type_token32] = ACTIONS(3290),
    [aux_sym_basic_type_token33] = ACTIONS(3290),
    [aux_sym_basic_type_token34] = ACTIONS(3290),
    [aux_sym_basic_type_token35] = ACTIONS(3290),
    [aux_sym_basic_type_token36] = ACTIONS(3290),
    [aux_sym_basic_type_token37] = ACTIONS(3290),
    [aux_sym_basic_type_token38] = ACTIONS(3290),
    [aux_sym_basic_type_token39] = ACTIONS(3290),
    [aux_sym_basic_type_token40] = ACTIONS(3290),
    [aux_sym_basic_type_token41] = ACTIONS(3290),
    [aux_sym_basic_type_token42] = ACTIONS(3290),
    [aux_sym_basic_type_token43] = ACTIONS(3290),
    [aux_sym_basic_type_token44] = ACTIONS(3290),
    [aux_sym_basic_type_token45] = ACTIONS(3290),
    [aux_sym_basic_type_token46] = ACTIONS(3290),
    [aux_sym_basic_type_token47] = ACTIONS(3290),
    [aux_sym_basic_type_token48] = ACTIONS(3290),
    [aux_sym_basic_type_token49] = ACTIONS(3290),
    [aux_sym_basic_type_token50] = ACTIONS(3290),
    [aux_sym_basic_type_token51] = ACTIONS(3290),
    [aux_sym_basic_type_token52] = ACTIONS(3290),
    [aux_sym_basic_type_token53] = ACTIONS(3290),
    [aux_sym_basic_type_token54] = ACTIONS(3290),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3282),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3282),
    [sym_query_keyword] = ACTIONS(3282),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3282),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3296),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1319)] = {
    [sym_type_specification] = STATE(1528),
    [sym_text_type] = STATE(1508),
    [sym_code_type] = STATE(1508),
    [sym_option_type] = STATE(1507),
    [sym_record_type] = STATE(1507),
    [sym_dotnet_type] = STATE(1507),
    [sym_object_reference_type] = STATE(1507),
    [sym_array_type] = STATE(1509),
    [sym_list_type] = STATE(1509),
    [sym_dictionary_type] = STATE(1509),
    [sym_basic_type] = STATE(1507),
    [sym_codeunit_keyword] = STATE(7860),
    [sym_xmlport_keyword] = STATE(7860),
    [sym_enum_keyword] = STATE(7860),
    [sym_controladdin_keyword] = STATE(7860),
    [sym_dotnet_keyword] = STATE(7771),
    [sym_identifier] = ACTIONS(3298),
    [aux_sym_text_type_token1] = ACTIONS(3300),
    [aux_sym_code_type_token1] = ACTIONS(3302),
    [aux_sym_option_type_token1] = ACTIONS(3304),
    [aux_sym_record_type_token1] = ACTIONS(3306),
    [aux_sym_object_reference_type_token1] = ACTIONS(3308),
    [aux_sym_object_reference_type_token2] = ACTIONS(3308),
    [aux_sym_array_type_token1] = ACTIONS(3310),
    [aux_sym_list_type_token1] = ACTIONS(3312),
    [aux_sym_dictionary_type_token1] = ACTIONS(3314),
    [aux_sym_basic_type_token1] = ACTIONS(3316),
    [aux_sym_basic_type_token2] = ACTIONS(3316),
    [aux_sym_basic_type_token3] = ACTIONS(3316),
    [aux_sym_basic_type_token4] = ACTIONS(3316),
    [aux_sym_basic_type_token5] = ACTIONS(3316),
    [aux_sym_basic_type_token6] = ACTIONS(3318),
    [aux_sym_basic_type_token7] = ACTIONS(3316),
    [aux_sym_basic_type_token8] = ACTIONS(3316),
    [aux_sym_basic_type_token9] = ACTIONS(3316),
    [aux_sym_basic_type_token10] = ACTIONS(3316),
    [aux_sym_basic_type_token11] = ACTIONS(3316),
    [aux_sym_basic_type_token12] = ACTIONS(3316),
    [aux_sym_basic_type_token13] = ACTIONS(3320),
    [aux_sym_basic_type_token14] = ACTIONS(3316),
    [aux_sym_basic_type_token15] = ACTIONS(3316),
    [aux_sym_basic_type_token16] = ACTIONS(3316),
    [aux_sym_basic_type_token17] = ACTIONS(3316),
    [aux_sym_basic_type_token18] = ACTIONS(3316),
    [aux_sym_basic_type_token19] = ACTIONS(3316),
    [aux_sym_basic_type_token20] = ACTIONS(3316),
    [aux_sym_basic_type_token21] = ACTIONS(3316),
    [aux_sym_basic_type_token22] = ACTIONS(3316),
    [aux_sym_basic_type_token23] = ACTIONS(3316),
    [aux_sym_basic_type_token24] = ACTIONS(3316),
    [aux_sym_basic_type_token25] = ACTIONS(3316),
    [aux_sym_basic_type_token26] = ACTIONS(3316),
    [aux_sym_basic_type_token27] = ACTIONS(3316),
    [aux_sym_basic_type_token28] = ACTIONS(3316),
    [aux_sym_basic_type_token29] = ACTIONS(3316),
    [aux_sym_basic_type_token30] = ACTIONS(3316),
    [aux_sym_basic_type_token31] = ACTIONS(3316),
    [aux_sym_basic_type_token32] = ACTIONS(3316),
    [aux_sym_basic_type_token33] = ACTIONS(3316),
    [aux_sym_basic_type_token34] = ACTIONS(3316),
    [aux_sym_basic_type_token35] = ACTIONS(3316),
    [aux_sym_basic_type_token36] = ACTIONS(3316),
    [aux_sym_basic_type_token37] = ACTIONS(3316),
    [aux_sym_basic_type_token38] = ACTIONS(3316),
    [aux_sym_basic_type_token39] = ACTIONS(3316),
    [aux_sym_basic_type_token40] = ACTIONS(3316),
    [aux_sym_basic_type_token41] = ACTIONS(3316),
    [aux_sym_basic_type_token42] = ACTIONS(3316),
    [aux_sym_basic_type_token43] = ACTIONS(3316),
    [aux_sym_basic_type_token44] = ACTIONS(3316),
    [aux_sym_basic_type_token45] = ACTIONS(3316),
    [aux_sym_basic_type_token46] = ACTIONS(3316),
    [aux_sym_basic_type_token47] = ACTIONS(3316),
    [aux_sym_basic_type_token48] = ACTIONS(3316),
    [aux_sym_basic_type_token49] = ACTIONS(3316),
    [aux_sym_basic_type_token50] = ACTIONS(3316),
    [aux_sym_basic_type_token51] = ACTIONS(3316),
    [aux_sym_basic_type_token52] = ACTIONS(3316),
    [aux_sym_basic_type_token53] = ACTIONS(3316),
    [aux_sym_basic_type_token54] = ACTIONS(3316),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3308),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3308),
    [sym_query_keyword] = ACTIONS(3308),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3308),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1320)] = {
    [sym_type_specification] = STATE(1519),
    [sym_text_type] = STATE(1508),
    [sym_code_type] = STATE(1508),
    [sym_option_type] = STATE(1507),
    [sym_record_type] = STATE(1507),
    [sym_dotnet_type] = STATE(1507),
    [sym_object_reference_type] = STATE(1507),
    [sym_array_type] = STATE(1509),
    [sym_list_type] = STATE(1509),
    [sym_dictionary_type] = STATE(1509),
    [sym_basic_type] = STATE(1507),
    [sym_codeunit_keyword] = STATE(7860),
    [sym_xmlport_keyword] = STATE(7860),
    [sym_enum_keyword] = STATE(7860),
    [sym_controladdin_keyword] = STATE(7860),
    [sym_dotnet_keyword] = STATE(7771),
    [sym_identifier] = ACTIONS(3298),
    [aux_sym_text_type_token1] = ACTIONS(3300),
    [aux_sym_code_type_token1] = ACTIONS(3302),
    [aux_sym_option_type_token1] = ACTIONS(3304),
    [aux_sym_record_type_token1] = ACTIONS(3306),
    [aux_sym_object_reference_type_token1] = ACTIONS(3308),
    [aux_sym_object_reference_type_token2] = ACTIONS(3308),
    [aux_sym_array_type_token1] = ACTIONS(3310),
    [aux_sym_list_type_token1] = ACTIONS(3312),
    [aux_sym_dictionary_type_token1] = ACTIONS(3314),
    [aux_sym_basic_type_token1] = ACTIONS(3316),
    [aux_sym_basic_type_token2] = ACTIONS(3316),
    [aux_sym_basic_type_token3] = ACTIONS(3316),
    [aux_sym_basic_type_token4] = ACTIONS(3316),
    [aux_sym_basic_type_token5] = ACTIONS(3316),
    [aux_sym_basic_type_token6] = ACTIONS(3318),
    [aux_sym_basic_type_token7] = ACTIONS(3316),
    [aux_sym_basic_type_token8] = ACTIONS(3316),
    [aux_sym_basic_type_token9] = ACTIONS(3316),
    [aux_sym_basic_type_token10] = ACTIONS(3316),
    [aux_sym_basic_type_token11] = ACTIONS(3316),
    [aux_sym_basic_type_token12] = ACTIONS(3316),
    [aux_sym_basic_type_token13] = ACTIONS(3320),
    [aux_sym_basic_type_token14] = ACTIONS(3316),
    [aux_sym_basic_type_token15] = ACTIONS(3316),
    [aux_sym_basic_type_token16] = ACTIONS(3316),
    [aux_sym_basic_type_token17] = ACTIONS(3316),
    [aux_sym_basic_type_token18] = ACTIONS(3316),
    [aux_sym_basic_type_token19] = ACTIONS(3316),
    [aux_sym_basic_type_token20] = ACTIONS(3316),
    [aux_sym_basic_type_token21] = ACTIONS(3316),
    [aux_sym_basic_type_token22] = ACTIONS(3316),
    [aux_sym_basic_type_token23] = ACTIONS(3316),
    [aux_sym_basic_type_token24] = ACTIONS(3316),
    [aux_sym_basic_type_token25] = ACTIONS(3316),
    [aux_sym_basic_type_token26] = ACTIONS(3316),
    [aux_sym_basic_type_token27] = ACTIONS(3316),
    [aux_sym_basic_type_token28] = ACTIONS(3316),
    [aux_sym_basic_type_token29] = ACTIONS(3316),
    [aux_sym_basic_type_token30] = ACTIONS(3316),
    [aux_sym_basic_type_token31] = ACTIONS(3316),
    [aux_sym_basic_type_token32] = ACTIONS(3316),
    [aux_sym_basic_type_token33] = ACTIONS(3316),
    [aux_sym_basic_type_token34] = ACTIONS(3316),
    [aux_sym_basic_type_token35] = ACTIONS(3316),
    [aux_sym_basic_type_token36] = ACTIONS(3316),
    [aux_sym_basic_type_token37] = ACTIONS(3316),
    [aux_sym_basic_type_token38] = ACTIONS(3316),
    [aux_sym_basic_type_token39] = ACTIONS(3316),
    [aux_sym_basic_type_token40] = ACTIONS(3316),
    [aux_sym_basic_type_token41] = ACTIONS(3316),
    [aux_sym_basic_type_token42] = ACTIONS(3316),
    [aux_sym_basic_type_token43] = ACTIONS(3316),
    [aux_sym_basic_type_token44] = ACTIONS(3316),
    [aux_sym_basic_type_token45] = ACTIONS(3316),
    [aux_sym_basic_type_token46] = ACTIONS(3316),
    [aux_sym_basic_type_token47] = ACTIONS(3316),
    [aux_sym_basic_type_token48] = ACTIONS(3316),
    [aux_sym_basic_type_token49] = ACTIONS(3316),
    [aux_sym_basic_type_token50] = ACTIONS(3316),
    [aux_sym_basic_type_token51] = ACTIONS(3316),
    [aux_sym_basic_type_token52] = ACTIONS(3316),
    [aux_sym_basic_type_token53] = ACTIONS(3316),
    [aux_sym_basic_type_token54] = ACTIONS(3316),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3308),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3308),
    [sym_query_keyword] = ACTIONS(3308),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3308),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1321)] = {
    [sym_type_specification] = STATE(1520),
    [sym_text_type] = STATE(1508),
    [sym_code_type] = STATE(1508),
    [sym_option_type] = STATE(1507),
    [sym_record_type] = STATE(1507),
    [sym_dotnet_type] = STATE(1507),
    [sym_object_reference_type] = STATE(1507),
    [sym_array_type] = STATE(1509),
    [sym_list_type] = STATE(1509),
    [sym_dictionary_type] = STATE(1509),
    [sym_basic_type] = STATE(1507),
    [sym_codeunit_keyword] = STATE(7860),
    [sym_xmlport_keyword] = STATE(7860),
    [sym_enum_keyword] = STATE(7860),
    [sym_controladdin_keyword] = STATE(7860),
    [sym_dotnet_keyword] = STATE(7771),
    [sym_identifier] = ACTIONS(3298),
    [aux_sym_text_type_token1] = ACTIONS(3300),
    [aux_sym_code_type_token1] = ACTIONS(3302),
    [aux_sym_option_type_token1] = ACTIONS(3304),
    [aux_sym_record_type_token1] = ACTIONS(3306),
    [aux_sym_object_reference_type_token1] = ACTIONS(3308),
    [aux_sym_object_reference_type_token2] = ACTIONS(3308),
    [aux_sym_array_type_token1] = ACTIONS(3310),
    [aux_sym_list_type_token1] = ACTIONS(3312),
    [aux_sym_dictionary_type_token1] = ACTIONS(3314),
    [aux_sym_basic_type_token1] = ACTIONS(3316),
    [aux_sym_basic_type_token2] = ACTIONS(3316),
    [aux_sym_basic_type_token3] = ACTIONS(3316),
    [aux_sym_basic_type_token4] = ACTIONS(3316),
    [aux_sym_basic_type_token5] = ACTIONS(3316),
    [aux_sym_basic_type_token6] = ACTIONS(3318),
    [aux_sym_basic_type_token7] = ACTIONS(3316),
    [aux_sym_basic_type_token8] = ACTIONS(3316),
    [aux_sym_basic_type_token9] = ACTIONS(3316),
    [aux_sym_basic_type_token10] = ACTIONS(3316),
    [aux_sym_basic_type_token11] = ACTIONS(3316),
    [aux_sym_basic_type_token12] = ACTIONS(3316),
    [aux_sym_basic_type_token13] = ACTIONS(3320),
    [aux_sym_basic_type_token14] = ACTIONS(3316),
    [aux_sym_basic_type_token15] = ACTIONS(3316),
    [aux_sym_basic_type_token16] = ACTIONS(3316),
    [aux_sym_basic_type_token17] = ACTIONS(3316),
    [aux_sym_basic_type_token18] = ACTIONS(3316),
    [aux_sym_basic_type_token19] = ACTIONS(3316),
    [aux_sym_basic_type_token20] = ACTIONS(3316),
    [aux_sym_basic_type_token21] = ACTIONS(3316),
    [aux_sym_basic_type_token22] = ACTIONS(3316),
    [aux_sym_basic_type_token23] = ACTIONS(3316),
    [aux_sym_basic_type_token24] = ACTIONS(3316),
    [aux_sym_basic_type_token25] = ACTIONS(3316),
    [aux_sym_basic_type_token26] = ACTIONS(3316),
    [aux_sym_basic_type_token27] = ACTIONS(3316),
    [aux_sym_basic_type_token28] = ACTIONS(3316),
    [aux_sym_basic_type_token29] = ACTIONS(3316),
    [aux_sym_basic_type_token30] = ACTIONS(3316),
    [aux_sym_basic_type_token31] = ACTIONS(3316),
    [aux_sym_basic_type_token32] = ACTIONS(3316),
    [aux_sym_basic_type_token33] = ACTIONS(3316),
    [aux_sym_basic_type_token34] = ACTIONS(3316),
    [aux_sym_basic_type_token35] = ACTIONS(3316),
    [aux_sym_basic_type_token36] = ACTIONS(3316),
    [aux_sym_basic_type_token37] = ACTIONS(3316),
    [aux_sym_basic_type_token38] = ACTIONS(3316),
    [aux_sym_basic_type_token39] = ACTIONS(3316),
    [aux_sym_basic_type_token40] = ACTIONS(3316),
    [aux_sym_basic_type_token41] = ACTIONS(3316),
    [aux_sym_basic_type_token42] = ACTIONS(3316),
    [aux_sym_basic_type_token43] = ACTIONS(3316),
    [aux_sym_basic_type_token44] = ACTIONS(3316),
    [aux_sym_basic_type_token45] = ACTIONS(3316),
    [aux_sym_basic_type_token46] = ACTIONS(3316),
    [aux_sym_basic_type_token47] = ACTIONS(3316),
    [aux_sym_basic_type_token48] = ACTIONS(3316),
    [aux_sym_basic_type_token49] = ACTIONS(3316),
    [aux_sym_basic_type_token50] = ACTIONS(3316),
    [aux_sym_basic_type_token51] = ACTIONS(3316),
    [aux_sym_basic_type_token52] = ACTIONS(3316),
    [aux_sym_basic_type_token53] = ACTIONS(3316),
    [aux_sym_basic_type_token54] = ACTIONS(3316),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3308),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3308),
    [sym_query_keyword] = ACTIONS(3308),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3308),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1322)] = {
    [sym_type_specification] = STATE(12082),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(11206),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1323)] = {
    [sym_type_specification] = STATE(12192),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1324)] = {
    [sym_type_specification] = STATE(12666),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1325)] = {
    [sym_type_specification] = STATE(12646),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1326)] = {
    [sym_type_specification] = STATE(12307),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1327)] = {
    [sym_type_specification] = STATE(6038),
    [sym_text_type] = STATE(6188),
    [sym_code_type] = STATE(6188),
    [sym_option_type] = STATE(6145),
    [sym_record_type] = STATE(6145),
    [sym_dotnet_type] = STATE(6145),
    [sym_object_reference_type] = STATE(6145),
    [sym_array_type] = STATE(6190),
    [sym_list_type] = STATE(6190),
    [sym_dictionary_type] = STATE(6190),
    [sym_basic_type] = STATE(6145),
    [sym_codeunit_keyword] = STATE(8077),
    [sym_xmlport_keyword] = STATE(8077),
    [sym_enum_keyword] = STATE(8077),
    [sym_controladdin_keyword] = STATE(8077),
    [sym_dotnet_keyword] = STATE(7640),
    [sym_identifier] = ACTIONS(3324),
    [aux_sym_text_type_token1] = ACTIONS(3326),
    [aux_sym_code_type_token1] = ACTIONS(3328),
    [aux_sym_option_type_token1] = ACTIONS(3330),
    [aux_sym_record_type_token1] = ACTIONS(3332),
    [aux_sym_object_reference_type_token1] = ACTIONS(3334),
    [aux_sym_object_reference_type_token2] = ACTIONS(3334),
    [aux_sym_array_type_token1] = ACTIONS(3336),
    [aux_sym_list_type_token1] = ACTIONS(3338),
    [aux_sym_dictionary_type_token1] = ACTIONS(3340),
    [aux_sym_basic_type_token1] = ACTIONS(3342),
    [aux_sym_basic_type_token2] = ACTIONS(3342),
    [aux_sym_basic_type_token3] = ACTIONS(3342),
    [aux_sym_basic_type_token4] = ACTIONS(3342),
    [aux_sym_basic_type_token5] = ACTIONS(3342),
    [aux_sym_basic_type_token6] = ACTIONS(3344),
    [aux_sym_basic_type_token7] = ACTIONS(3342),
    [aux_sym_basic_type_token8] = ACTIONS(3342),
    [aux_sym_basic_type_token9] = ACTIONS(3342),
    [aux_sym_basic_type_token10] = ACTIONS(3342),
    [aux_sym_basic_type_token11] = ACTIONS(3342),
    [aux_sym_basic_type_token12] = ACTIONS(3342),
    [aux_sym_basic_type_token13] = ACTIONS(3346),
    [aux_sym_basic_type_token14] = ACTIONS(3342),
    [aux_sym_basic_type_token15] = ACTIONS(3342),
    [aux_sym_basic_type_token16] = ACTIONS(3342),
    [aux_sym_basic_type_token17] = ACTIONS(3342),
    [aux_sym_basic_type_token18] = ACTIONS(3342),
    [aux_sym_basic_type_token19] = ACTIONS(3342),
    [aux_sym_basic_type_token20] = ACTIONS(3342),
    [aux_sym_basic_type_token21] = ACTIONS(3342),
    [aux_sym_basic_type_token22] = ACTIONS(3342),
    [aux_sym_basic_type_token23] = ACTIONS(3342),
    [aux_sym_basic_type_token24] = ACTIONS(3342),
    [aux_sym_basic_type_token25] = ACTIONS(3342),
    [aux_sym_basic_type_token26] = ACTIONS(3342),
    [aux_sym_basic_type_token27] = ACTIONS(3342),
    [aux_sym_basic_type_token28] = ACTIONS(3342),
    [aux_sym_basic_type_token29] = ACTIONS(3342),
    [aux_sym_basic_type_token30] = ACTIONS(3342),
    [aux_sym_basic_type_token31] = ACTIONS(3342),
    [aux_sym_basic_type_token32] = ACTIONS(3342),
    [aux_sym_basic_type_token33] = ACTIONS(3342),
    [aux_sym_basic_type_token34] = ACTIONS(3342),
    [aux_sym_basic_type_token35] = ACTIONS(3342),
    [aux_sym_basic_type_token36] = ACTIONS(3342),
    [aux_sym_basic_type_token37] = ACTIONS(3342),
    [aux_sym_basic_type_token38] = ACTIONS(3342),
    [aux_sym_basic_type_token39] = ACTIONS(3342),
    [aux_sym_basic_type_token40] = ACTIONS(3342),
    [aux_sym_basic_type_token41] = ACTIONS(3342),
    [aux_sym_basic_type_token42] = ACTIONS(3342),
    [aux_sym_basic_type_token43] = ACTIONS(3342),
    [aux_sym_basic_type_token44] = ACTIONS(3342),
    [aux_sym_basic_type_token45] = ACTIONS(3342),
    [aux_sym_basic_type_token46] = ACTIONS(3342),
    [aux_sym_basic_type_token47] = ACTIONS(3342),
    [aux_sym_basic_type_token48] = ACTIONS(3342),
    [aux_sym_basic_type_token49] = ACTIONS(3342),
    [aux_sym_basic_type_token50] = ACTIONS(3342),
    [aux_sym_basic_type_token51] = ACTIONS(3342),
    [aux_sym_basic_type_token52] = ACTIONS(3342),
    [aux_sym_basic_type_token53] = ACTIONS(3342),
    [aux_sym_basic_type_token54] = ACTIONS(3342),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3334),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3334),
    [sym_query_keyword] = ACTIONS(3334),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3334),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3348),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1328)] = {
    [sym_type_specification] = STATE(6048),
    [sym_text_type] = STATE(6188),
    [sym_code_type] = STATE(6188),
    [sym_option_type] = STATE(6145),
    [sym_record_type] = STATE(6145),
    [sym_dotnet_type] = STATE(6145),
    [sym_object_reference_type] = STATE(6145),
    [sym_array_type] = STATE(6190),
    [sym_list_type] = STATE(6190),
    [sym_dictionary_type] = STATE(6190),
    [sym_basic_type] = STATE(6145),
    [sym_codeunit_keyword] = STATE(8077),
    [sym_xmlport_keyword] = STATE(8077),
    [sym_enum_keyword] = STATE(8077),
    [sym_controladdin_keyword] = STATE(8077),
    [sym_dotnet_keyword] = STATE(7640),
    [sym_identifier] = ACTIONS(3324),
    [aux_sym_text_type_token1] = ACTIONS(3326),
    [aux_sym_code_type_token1] = ACTIONS(3328),
    [aux_sym_option_type_token1] = ACTIONS(3330),
    [aux_sym_record_type_token1] = ACTIONS(3332),
    [aux_sym_object_reference_type_token1] = ACTIONS(3334),
    [aux_sym_object_reference_type_token2] = ACTIONS(3334),
    [aux_sym_array_type_token1] = ACTIONS(3336),
    [aux_sym_list_type_token1] = ACTIONS(3338),
    [aux_sym_dictionary_type_token1] = ACTIONS(3340),
    [aux_sym_basic_type_token1] = ACTIONS(3342),
    [aux_sym_basic_type_token2] = ACTIONS(3342),
    [aux_sym_basic_type_token3] = ACTIONS(3342),
    [aux_sym_basic_type_token4] = ACTIONS(3342),
    [aux_sym_basic_type_token5] = ACTIONS(3342),
    [aux_sym_basic_type_token6] = ACTIONS(3344),
    [aux_sym_basic_type_token7] = ACTIONS(3342),
    [aux_sym_basic_type_token8] = ACTIONS(3342),
    [aux_sym_basic_type_token9] = ACTIONS(3342),
    [aux_sym_basic_type_token10] = ACTIONS(3342),
    [aux_sym_basic_type_token11] = ACTIONS(3342),
    [aux_sym_basic_type_token12] = ACTIONS(3342),
    [aux_sym_basic_type_token13] = ACTIONS(3346),
    [aux_sym_basic_type_token14] = ACTIONS(3342),
    [aux_sym_basic_type_token15] = ACTIONS(3342),
    [aux_sym_basic_type_token16] = ACTIONS(3342),
    [aux_sym_basic_type_token17] = ACTIONS(3342),
    [aux_sym_basic_type_token18] = ACTIONS(3342),
    [aux_sym_basic_type_token19] = ACTIONS(3342),
    [aux_sym_basic_type_token20] = ACTIONS(3342),
    [aux_sym_basic_type_token21] = ACTIONS(3342),
    [aux_sym_basic_type_token22] = ACTIONS(3342),
    [aux_sym_basic_type_token23] = ACTIONS(3342),
    [aux_sym_basic_type_token24] = ACTIONS(3342),
    [aux_sym_basic_type_token25] = ACTIONS(3342),
    [aux_sym_basic_type_token26] = ACTIONS(3342),
    [aux_sym_basic_type_token27] = ACTIONS(3342),
    [aux_sym_basic_type_token28] = ACTIONS(3342),
    [aux_sym_basic_type_token29] = ACTIONS(3342),
    [aux_sym_basic_type_token30] = ACTIONS(3342),
    [aux_sym_basic_type_token31] = ACTIONS(3342),
    [aux_sym_basic_type_token32] = ACTIONS(3342),
    [aux_sym_basic_type_token33] = ACTIONS(3342),
    [aux_sym_basic_type_token34] = ACTIONS(3342),
    [aux_sym_basic_type_token35] = ACTIONS(3342),
    [aux_sym_basic_type_token36] = ACTIONS(3342),
    [aux_sym_basic_type_token37] = ACTIONS(3342),
    [aux_sym_basic_type_token38] = ACTIONS(3342),
    [aux_sym_basic_type_token39] = ACTIONS(3342),
    [aux_sym_basic_type_token40] = ACTIONS(3342),
    [aux_sym_basic_type_token41] = ACTIONS(3342),
    [aux_sym_basic_type_token42] = ACTIONS(3342),
    [aux_sym_basic_type_token43] = ACTIONS(3342),
    [aux_sym_basic_type_token44] = ACTIONS(3342),
    [aux_sym_basic_type_token45] = ACTIONS(3342),
    [aux_sym_basic_type_token46] = ACTIONS(3342),
    [aux_sym_basic_type_token47] = ACTIONS(3342),
    [aux_sym_basic_type_token48] = ACTIONS(3342),
    [aux_sym_basic_type_token49] = ACTIONS(3342),
    [aux_sym_basic_type_token50] = ACTIONS(3342),
    [aux_sym_basic_type_token51] = ACTIONS(3342),
    [aux_sym_basic_type_token52] = ACTIONS(3342),
    [aux_sym_basic_type_token53] = ACTIONS(3342),
    [aux_sym_basic_type_token54] = ACTIONS(3342),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3334),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3334),
    [sym_query_keyword] = ACTIONS(3334),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3334),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3348),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1329)] = {
    [sym_type_specification] = STATE(4843),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3242),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3244),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1330)] = {
    [sym_type_specification] = STATE(8811),
    [sym_text_type] = STATE(8818),
    [sym_code_type] = STATE(8818),
    [sym_option_type] = STATE(8817),
    [sym_record_type] = STATE(8817),
    [sym_dotnet_type] = STATE(8817),
    [sym_object_reference_type] = STATE(8817),
    [sym_array_type] = STATE(8819),
    [sym_list_type] = STATE(8819),
    [sym_dictionary_type] = STATE(8819),
    [sym_basic_type] = STATE(8817),
    [sym_codeunit_keyword] = STATE(8015),
    [sym_xmlport_keyword] = STATE(8015),
    [sym_enum_keyword] = STATE(8015),
    [sym_controladdin_keyword] = STATE(8015),
    [sym_dotnet_keyword] = STATE(7673),
    [sym_identifier] = ACTIONS(3350),
    [aux_sym_text_type_token1] = ACTIONS(3352),
    [aux_sym_code_type_token1] = ACTIONS(3354),
    [aux_sym_option_type_token1] = ACTIONS(3356),
    [aux_sym_record_type_token1] = ACTIONS(3358),
    [aux_sym_object_reference_type_token1] = ACTIONS(3360),
    [aux_sym_object_reference_type_token2] = ACTIONS(3360),
    [aux_sym_array_type_token1] = ACTIONS(3362),
    [aux_sym_list_type_token1] = ACTIONS(3364),
    [aux_sym_dictionary_type_token1] = ACTIONS(3366),
    [aux_sym_basic_type_token1] = ACTIONS(3368),
    [aux_sym_basic_type_token2] = ACTIONS(3368),
    [aux_sym_basic_type_token3] = ACTIONS(3368),
    [aux_sym_basic_type_token4] = ACTIONS(3368),
    [aux_sym_basic_type_token5] = ACTIONS(3368),
    [aux_sym_basic_type_token6] = ACTIONS(3370),
    [aux_sym_basic_type_token7] = ACTIONS(3368),
    [aux_sym_basic_type_token8] = ACTIONS(3368),
    [aux_sym_basic_type_token9] = ACTIONS(3368),
    [aux_sym_basic_type_token10] = ACTIONS(3368),
    [aux_sym_basic_type_token11] = ACTIONS(3368),
    [aux_sym_basic_type_token12] = ACTIONS(3368),
    [aux_sym_basic_type_token13] = ACTIONS(3372),
    [aux_sym_basic_type_token14] = ACTIONS(3368),
    [aux_sym_basic_type_token15] = ACTIONS(3368),
    [aux_sym_basic_type_token16] = ACTIONS(3368),
    [aux_sym_basic_type_token17] = ACTIONS(3368),
    [aux_sym_basic_type_token18] = ACTIONS(3368),
    [aux_sym_basic_type_token19] = ACTIONS(3368),
    [aux_sym_basic_type_token20] = ACTIONS(3368),
    [aux_sym_basic_type_token21] = ACTIONS(3368),
    [aux_sym_basic_type_token22] = ACTIONS(3368),
    [aux_sym_basic_type_token23] = ACTIONS(3368),
    [aux_sym_basic_type_token24] = ACTIONS(3368),
    [aux_sym_basic_type_token25] = ACTIONS(3368),
    [aux_sym_basic_type_token26] = ACTIONS(3368),
    [aux_sym_basic_type_token27] = ACTIONS(3368),
    [aux_sym_basic_type_token28] = ACTIONS(3368),
    [aux_sym_basic_type_token29] = ACTIONS(3368),
    [aux_sym_basic_type_token30] = ACTIONS(3368),
    [aux_sym_basic_type_token31] = ACTIONS(3368),
    [aux_sym_basic_type_token32] = ACTIONS(3368),
    [aux_sym_basic_type_token33] = ACTIONS(3368),
    [aux_sym_basic_type_token34] = ACTIONS(3368),
    [aux_sym_basic_type_token35] = ACTIONS(3368),
    [aux_sym_basic_type_token36] = ACTIONS(3368),
    [aux_sym_basic_type_token37] = ACTIONS(3368),
    [aux_sym_basic_type_token38] = ACTIONS(3368),
    [aux_sym_basic_type_token39] = ACTIONS(3368),
    [aux_sym_basic_type_token40] = ACTIONS(3368),
    [aux_sym_basic_type_token41] = ACTIONS(3368),
    [aux_sym_basic_type_token42] = ACTIONS(3368),
    [aux_sym_basic_type_token43] = ACTIONS(3368),
    [aux_sym_basic_type_token44] = ACTIONS(3368),
    [aux_sym_basic_type_token45] = ACTIONS(3368),
    [aux_sym_basic_type_token46] = ACTIONS(3368),
    [aux_sym_basic_type_token47] = ACTIONS(3368),
    [aux_sym_basic_type_token48] = ACTIONS(3368),
    [aux_sym_basic_type_token49] = ACTIONS(3368),
    [aux_sym_basic_type_token50] = ACTIONS(3368),
    [aux_sym_basic_type_token51] = ACTIONS(3368),
    [aux_sym_basic_type_token52] = ACTIONS(3368),
    [aux_sym_basic_type_token53] = ACTIONS(3368),
    [aux_sym_basic_type_token54] = ACTIONS(3368),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3360),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3360),
    [sym_query_keyword] = ACTIONS(3360),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3360),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3374),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1331)] = {
    [sym_type_specification] = STATE(11771),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(11210),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1332)] = {
    [sym_type_specification] = STATE(12451),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1333)] = {
    [sym_type_specification] = STATE(11352),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1334)] = {
    [sym_type_specification] = STATE(12329),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1335)] = {
    [sym_type_specification] = STATE(2191),
    [sym_text_type] = STATE(2171),
    [sym_code_type] = STATE(2171),
    [sym_option_type] = STATE(2169),
    [sym_record_type] = STATE(2169),
    [sym_dotnet_type] = STATE(2169),
    [sym_object_reference_type] = STATE(2169),
    [sym_array_type] = STATE(2172),
    [sym_list_type] = STATE(2172),
    [sym_dictionary_type] = STATE(2172),
    [sym_basic_type] = STATE(2169),
    [sym_codeunit_keyword] = STATE(7924),
    [sym_xmlport_keyword] = STATE(7924),
    [sym_enum_keyword] = STATE(7924),
    [sym_controladdin_keyword] = STATE(7924),
    [sym_dotnet_keyword] = STATE(7752),
    [sym_identifier] = ACTIONS(3376),
    [aux_sym_text_type_token1] = ACTIONS(3378),
    [aux_sym_code_type_token1] = ACTIONS(3380),
    [aux_sym_option_type_token1] = ACTIONS(3382),
    [aux_sym_record_type_token1] = ACTIONS(3384),
    [aux_sym_object_reference_type_token1] = ACTIONS(3386),
    [aux_sym_object_reference_type_token2] = ACTIONS(3386),
    [aux_sym_array_type_token1] = ACTIONS(3388),
    [aux_sym_list_type_token1] = ACTIONS(3390),
    [aux_sym_dictionary_type_token1] = ACTIONS(3392),
    [aux_sym_basic_type_token1] = ACTIONS(3394),
    [aux_sym_basic_type_token2] = ACTIONS(3394),
    [aux_sym_basic_type_token3] = ACTIONS(3394),
    [aux_sym_basic_type_token4] = ACTIONS(3394),
    [aux_sym_basic_type_token5] = ACTIONS(3394),
    [aux_sym_basic_type_token6] = ACTIONS(3396),
    [aux_sym_basic_type_token7] = ACTIONS(3394),
    [aux_sym_basic_type_token8] = ACTIONS(3394),
    [aux_sym_basic_type_token9] = ACTIONS(3394),
    [aux_sym_basic_type_token10] = ACTIONS(3394),
    [aux_sym_basic_type_token11] = ACTIONS(3394),
    [aux_sym_basic_type_token12] = ACTIONS(3394),
    [aux_sym_basic_type_token13] = ACTIONS(3398),
    [aux_sym_basic_type_token14] = ACTIONS(3394),
    [aux_sym_basic_type_token15] = ACTIONS(3394),
    [aux_sym_basic_type_token16] = ACTIONS(3394),
    [aux_sym_basic_type_token17] = ACTIONS(3394),
    [aux_sym_basic_type_token18] = ACTIONS(3394),
    [aux_sym_basic_type_token19] = ACTIONS(3394),
    [aux_sym_basic_type_token20] = ACTIONS(3394),
    [aux_sym_basic_type_token21] = ACTIONS(3394),
    [aux_sym_basic_type_token22] = ACTIONS(3394),
    [aux_sym_basic_type_token23] = ACTIONS(3394),
    [aux_sym_basic_type_token24] = ACTIONS(3394),
    [aux_sym_basic_type_token25] = ACTIONS(3394),
    [aux_sym_basic_type_token26] = ACTIONS(3394),
    [aux_sym_basic_type_token27] = ACTIONS(3394),
    [aux_sym_basic_type_token28] = ACTIONS(3394),
    [aux_sym_basic_type_token29] = ACTIONS(3394),
    [aux_sym_basic_type_token30] = ACTIONS(3394),
    [aux_sym_basic_type_token31] = ACTIONS(3394),
    [aux_sym_basic_type_token32] = ACTIONS(3394),
    [aux_sym_basic_type_token33] = ACTIONS(3394),
    [aux_sym_basic_type_token34] = ACTIONS(3394),
    [aux_sym_basic_type_token35] = ACTIONS(3394),
    [aux_sym_basic_type_token36] = ACTIONS(3394),
    [aux_sym_basic_type_token37] = ACTIONS(3394),
    [aux_sym_basic_type_token38] = ACTIONS(3394),
    [aux_sym_basic_type_token39] = ACTIONS(3394),
    [aux_sym_basic_type_token40] = ACTIONS(3394),
    [aux_sym_basic_type_token41] = ACTIONS(3394),
    [aux_sym_basic_type_token42] = ACTIONS(3394),
    [aux_sym_basic_type_token43] = ACTIONS(3394),
    [aux_sym_basic_type_token44] = ACTIONS(3394),
    [aux_sym_basic_type_token45] = ACTIONS(3394),
    [aux_sym_basic_type_token46] = ACTIONS(3394),
    [aux_sym_basic_type_token47] = ACTIONS(3394),
    [aux_sym_basic_type_token48] = ACTIONS(3394),
    [aux_sym_basic_type_token49] = ACTIONS(3394),
    [aux_sym_basic_type_token50] = ACTIONS(3394),
    [aux_sym_basic_type_token51] = ACTIONS(3394),
    [aux_sym_basic_type_token52] = ACTIONS(3394),
    [aux_sym_basic_type_token53] = ACTIONS(3394),
    [aux_sym_basic_type_token54] = ACTIONS(3394),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3386),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3386),
    [sym_query_keyword] = ACTIONS(3386),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3386),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3400),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1336)] = {
    [sym_type_specification] = STATE(4835),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8101),
    [sym_xmlport_keyword] = STATE(8101),
    [sym_enum_keyword] = STATE(8101),
    [sym_controladdin_keyword] = STATE(8101),
    [sym_dotnet_keyword] = STATE(7675),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3402),
    [aux_sym_record_type_token1] = ACTIONS(3404),
    [aux_sym_object_reference_type_token1] = ACTIONS(3406),
    [aux_sym_object_reference_type_token2] = ACTIONS(3406),
    [aux_sym_array_type_token1] = ACTIONS(3408),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3406),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3406),
    [sym_query_keyword] = ACTIONS(3406),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3406),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1337)] = {
    [sym_type_specification] = STATE(12336),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1338)] = {
    [sym_type_specification] = STATE(4817),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3242),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3244),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1339)] = {
    [sym_type_specification] = STATE(7399),
    [sym_text_type] = STATE(7404),
    [sym_code_type] = STATE(7404),
    [sym_option_type] = STATE(7403),
    [sym_record_type] = STATE(7403),
    [sym_dotnet_type] = STATE(7403),
    [sym_object_reference_type] = STATE(7403),
    [sym_array_type] = STATE(7405),
    [sym_list_type] = STATE(7405),
    [sym_dictionary_type] = STATE(7405),
    [sym_basic_type] = STATE(7403),
    [sym_codeunit_keyword] = STATE(7975),
    [sym_xmlport_keyword] = STATE(7975),
    [sym_enum_keyword] = STATE(7975),
    [sym_controladdin_keyword] = STATE(7975),
    [sym_dotnet_keyword] = STATE(7692),
    [sym_identifier] = ACTIONS(3272),
    [aux_sym_text_type_token1] = ACTIONS(3274),
    [aux_sym_code_type_token1] = ACTIONS(3276),
    [aux_sym_option_type_token1] = ACTIONS(3278),
    [aux_sym_record_type_token1] = ACTIONS(3280),
    [aux_sym_object_reference_type_token1] = ACTIONS(3282),
    [aux_sym_object_reference_type_token2] = ACTIONS(3282),
    [aux_sym_array_type_token1] = ACTIONS(3284),
    [aux_sym_list_type_token1] = ACTIONS(3286),
    [aux_sym_dictionary_type_token1] = ACTIONS(3288),
    [aux_sym_basic_type_token1] = ACTIONS(3290),
    [aux_sym_basic_type_token2] = ACTIONS(3290),
    [aux_sym_basic_type_token3] = ACTIONS(3290),
    [aux_sym_basic_type_token4] = ACTIONS(3290),
    [aux_sym_basic_type_token5] = ACTIONS(3290),
    [aux_sym_basic_type_token6] = ACTIONS(3292),
    [aux_sym_basic_type_token7] = ACTIONS(3290),
    [aux_sym_basic_type_token8] = ACTIONS(3290),
    [aux_sym_basic_type_token9] = ACTIONS(3290),
    [aux_sym_basic_type_token10] = ACTIONS(3290),
    [aux_sym_basic_type_token11] = ACTIONS(3290),
    [aux_sym_basic_type_token12] = ACTIONS(3290),
    [aux_sym_basic_type_token13] = ACTIONS(3294),
    [aux_sym_basic_type_token14] = ACTIONS(3290),
    [aux_sym_basic_type_token15] = ACTIONS(3290),
    [aux_sym_basic_type_token16] = ACTIONS(3290),
    [aux_sym_basic_type_token17] = ACTIONS(3290),
    [aux_sym_basic_type_token18] = ACTIONS(3290),
    [aux_sym_basic_type_token19] = ACTIONS(3290),
    [aux_sym_basic_type_token20] = ACTIONS(3290),
    [aux_sym_basic_type_token21] = ACTIONS(3290),
    [aux_sym_basic_type_token22] = ACTIONS(3290),
    [aux_sym_basic_type_token23] = ACTIONS(3290),
    [aux_sym_basic_type_token24] = ACTIONS(3290),
    [aux_sym_basic_type_token25] = ACTIONS(3290),
    [aux_sym_basic_type_token26] = ACTIONS(3290),
    [aux_sym_basic_type_token27] = ACTIONS(3290),
    [aux_sym_basic_type_token28] = ACTIONS(3290),
    [aux_sym_basic_type_token29] = ACTIONS(3290),
    [aux_sym_basic_type_token30] = ACTIONS(3290),
    [aux_sym_basic_type_token31] = ACTIONS(3290),
    [aux_sym_basic_type_token32] = ACTIONS(3290),
    [aux_sym_basic_type_token33] = ACTIONS(3290),
    [aux_sym_basic_type_token34] = ACTIONS(3290),
    [aux_sym_basic_type_token35] = ACTIONS(3290),
    [aux_sym_basic_type_token36] = ACTIONS(3290),
    [aux_sym_basic_type_token37] = ACTIONS(3290),
    [aux_sym_basic_type_token38] = ACTIONS(3290),
    [aux_sym_basic_type_token39] = ACTIONS(3290),
    [aux_sym_basic_type_token40] = ACTIONS(3290),
    [aux_sym_basic_type_token41] = ACTIONS(3290),
    [aux_sym_basic_type_token42] = ACTIONS(3290),
    [aux_sym_basic_type_token43] = ACTIONS(3290),
    [aux_sym_basic_type_token44] = ACTIONS(3290),
    [aux_sym_basic_type_token45] = ACTIONS(3290),
    [aux_sym_basic_type_token46] = ACTIONS(3290),
    [aux_sym_basic_type_token47] = ACTIONS(3290),
    [aux_sym_basic_type_token48] = ACTIONS(3290),
    [aux_sym_basic_type_token49] = ACTIONS(3290),
    [aux_sym_basic_type_token50] = ACTIONS(3290),
    [aux_sym_basic_type_token51] = ACTIONS(3290),
    [aux_sym_basic_type_token52] = ACTIONS(3290),
    [aux_sym_basic_type_token53] = ACTIONS(3290),
    [aux_sym_basic_type_token54] = ACTIONS(3290),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3282),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3282),
    [sym_query_keyword] = ACTIONS(3282),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3282),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3296),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1340)] = {
    [sym_type_specification] = STATE(2192),
    [sym_text_type] = STATE(2171),
    [sym_code_type] = STATE(2171),
    [sym_option_type] = STATE(2169),
    [sym_record_type] = STATE(2169),
    [sym_dotnet_type] = STATE(2169),
    [sym_object_reference_type] = STATE(2169),
    [sym_array_type] = STATE(2172),
    [sym_list_type] = STATE(2172),
    [sym_dictionary_type] = STATE(2172),
    [sym_basic_type] = STATE(2169),
    [sym_codeunit_keyword] = STATE(7924),
    [sym_xmlport_keyword] = STATE(7924),
    [sym_enum_keyword] = STATE(7924),
    [sym_controladdin_keyword] = STATE(7924),
    [sym_dotnet_keyword] = STATE(7752),
    [sym_identifier] = ACTIONS(3376),
    [aux_sym_text_type_token1] = ACTIONS(3378),
    [aux_sym_code_type_token1] = ACTIONS(3380),
    [aux_sym_option_type_token1] = ACTIONS(3382),
    [aux_sym_record_type_token1] = ACTIONS(3384),
    [aux_sym_object_reference_type_token1] = ACTIONS(3386),
    [aux_sym_object_reference_type_token2] = ACTIONS(3386),
    [aux_sym_array_type_token1] = ACTIONS(3388),
    [aux_sym_list_type_token1] = ACTIONS(3390),
    [aux_sym_dictionary_type_token1] = ACTIONS(3392),
    [aux_sym_basic_type_token1] = ACTIONS(3394),
    [aux_sym_basic_type_token2] = ACTIONS(3394),
    [aux_sym_basic_type_token3] = ACTIONS(3394),
    [aux_sym_basic_type_token4] = ACTIONS(3394),
    [aux_sym_basic_type_token5] = ACTIONS(3394),
    [aux_sym_basic_type_token6] = ACTIONS(3396),
    [aux_sym_basic_type_token7] = ACTIONS(3394),
    [aux_sym_basic_type_token8] = ACTIONS(3394),
    [aux_sym_basic_type_token9] = ACTIONS(3394),
    [aux_sym_basic_type_token10] = ACTIONS(3394),
    [aux_sym_basic_type_token11] = ACTIONS(3394),
    [aux_sym_basic_type_token12] = ACTIONS(3394),
    [aux_sym_basic_type_token13] = ACTIONS(3398),
    [aux_sym_basic_type_token14] = ACTIONS(3394),
    [aux_sym_basic_type_token15] = ACTIONS(3394),
    [aux_sym_basic_type_token16] = ACTIONS(3394),
    [aux_sym_basic_type_token17] = ACTIONS(3394),
    [aux_sym_basic_type_token18] = ACTIONS(3394),
    [aux_sym_basic_type_token19] = ACTIONS(3394),
    [aux_sym_basic_type_token20] = ACTIONS(3394),
    [aux_sym_basic_type_token21] = ACTIONS(3394),
    [aux_sym_basic_type_token22] = ACTIONS(3394),
    [aux_sym_basic_type_token23] = ACTIONS(3394),
    [aux_sym_basic_type_token24] = ACTIONS(3394),
    [aux_sym_basic_type_token25] = ACTIONS(3394),
    [aux_sym_basic_type_token26] = ACTIONS(3394),
    [aux_sym_basic_type_token27] = ACTIONS(3394),
    [aux_sym_basic_type_token28] = ACTIONS(3394),
    [aux_sym_basic_type_token29] = ACTIONS(3394),
    [aux_sym_basic_type_token30] = ACTIONS(3394),
    [aux_sym_basic_type_token31] = ACTIONS(3394),
    [aux_sym_basic_type_token32] = ACTIONS(3394),
    [aux_sym_basic_type_token33] = ACTIONS(3394),
    [aux_sym_basic_type_token34] = ACTIONS(3394),
    [aux_sym_basic_type_token35] = ACTIONS(3394),
    [aux_sym_basic_type_token36] = ACTIONS(3394),
    [aux_sym_basic_type_token37] = ACTIONS(3394),
    [aux_sym_basic_type_token38] = ACTIONS(3394),
    [aux_sym_basic_type_token39] = ACTIONS(3394),
    [aux_sym_basic_type_token40] = ACTIONS(3394),
    [aux_sym_basic_type_token41] = ACTIONS(3394),
    [aux_sym_basic_type_token42] = ACTIONS(3394),
    [aux_sym_basic_type_token43] = ACTIONS(3394),
    [aux_sym_basic_type_token44] = ACTIONS(3394),
    [aux_sym_basic_type_token45] = ACTIONS(3394),
    [aux_sym_basic_type_token46] = ACTIONS(3394),
    [aux_sym_basic_type_token47] = ACTIONS(3394),
    [aux_sym_basic_type_token48] = ACTIONS(3394),
    [aux_sym_basic_type_token49] = ACTIONS(3394),
    [aux_sym_basic_type_token50] = ACTIONS(3394),
    [aux_sym_basic_type_token51] = ACTIONS(3394),
    [aux_sym_basic_type_token52] = ACTIONS(3394),
    [aux_sym_basic_type_token53] = ACTIONS(3394),
    [aux_sym_basic_type_token54] = ACTIONS(3394),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3386),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3386),
    [sym_query_keyword] = ACTIONS(3386),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3386),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3400),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1341)] = {
    [sym_type_specification] = STATE(4817),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8101),
    [sym_xmlport_keyword] = STATE(8101),
    [sym_enum_keyword] = STATE(8101),
    [sym_controladdin_keyword] = STATE(8101),
    [sym_dotnet_keyword] = STATE(7675),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3402),
    [aux_sym_record_type_token1] = ACTIONS(3404),
    [aux_sym_object_reference_type_token1] = ACTIONS(3406),
    [aux_sym_object_reference_type_token2] = ACTIONS(3406),
    [aux_sym_array_type_token1] = ACTIONS(3408),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3406),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3406),
    [sym_query_keyword] = ACTIONS(3406),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3406),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1342)] = {
    [sym_type_specification] = STATE(7396),
    [sym_text_type] = STATE(7404),
    [sym_code_type] = STATE(7404),
    [sym_option_type] = STATE(7403),
    [sym_record_type] = STATE(7403),
    [sym_dotnet_type] = STATE(7403),
    [sym_object_reference_type] = STATE(7403),
    [sym_array_type] = STATE(7405),
    [sym_list_type] = STATE(7405),
    [sym_dictionary_type] = STATE(7405),
    [sym_basic_type] = STATE(7403),
    [sym_codeunit_keyword] = STATE(7975),
    [sym_xmlport_keyword] = STATE(7975),
    [sym_enum_keyword] = STATE(7975),
    [sym_controladdin_keyword] = STATE(7975),
    [sym_dotnet_keyword] = STATE(7692),
    [sym_identifier] = ACTIONS(3272),
    [aux_sym_text_type_token1] = ACTIONS(3274),
    [aux_sym_code_type_token1] = ACTIONS(3276),
    [aux_sym_option_type_token1] = ACTIONS(3278),
    [aux_sym_record_type_token1] = ACTIONS(3280),
    [aux_sym_object_reference_type_token1] = ACTIONS(3282),
    [aux_sym_object_reference_type_token2] = ACTIONS(3282),
    [aux_sym_array_type_token1] = ACTIONS(3284),
    [aux_sym_list_type_token1] = ACTIONS(3286),
    [aux_sym_dictionary_type_token1] = ACTIONS(3288),
    [aux_sym_basic_type_token1] = ACTIONS(3290),
    [aux_sym_basic_type_token2] = ACTIONS(3290),
    [aux_sym_basic_type_token3] = ACTIONS(3290),
    [aux_sym_basic_type_token4] = ACTIONS(3290),
    [aux_sym_basic_type_token5] = ACTIONS(3290),
    [aux_sym_basic_type_token6] = ACTIONS(3292),
    [aux_sym_basic_type_token7] = ACTIONS(3290),
    [aux_sym_basic_type_token8] = ACTIONS(3290),
    [aux_sym_basic_type_token9] = ACTIONS(3290),
    [aux_sym_basic_type_token10] = ACTIONS(3290),
    [aux_sym_basic_type_token11] = ACTIONS(3290),
    [aux_sym_basic_type_token12] = ACTIONS(3290),
    [aux_sym_basic_type_token13] = ACTIONS(3294),
    [aux_sym_basic_type_token14] = ACTIONS(3290),
    [aux_sym_basic_type_token15] = ACTIONS(3290),
    [aux_sym_basic_type_token16] = ACTIONS(3290),
    [aux_sym_basic_type_token17] = ACTIONS(3290),
    [aux_sym_basic_type_token18] = ACTIONS(3290),
    [aux_sym_basic_type_token19] = ACTIONS(3290),
    [aux_sym_basic_type_token20] = ACTIONS(3290),
    [aux_sym_basic_type_token21] = ACTIONS(3290),
    [aux_sym_basic_type_token22] = ACTIONS(3290),
    [aux_sym_basic_type_token23] = ACTIONS(3290),
    [aux_sym_basic_type_token24] = ACTIONS(3290),
    [aux_sym_basic_type_token25] = ACTIONS(3290),
    [aux_sym_basic_type_token26] = ACTIONS(3290),
    [aux_sym_basic_type_token27] = ACTIONS(3290),
    [aux_sym_basic_type_token28] = ACTIONS(3290),
    [aux_sym_basic_type_token29] = ACTIONS(3290),
    [aux_sym_basic_type_token30] = ACTIONS(3290),
    [aux_sym_basic_type_token31] = ACTIONS(3290),
    [aux_sym_basic_type_token32] = ACTIONS(3290),
    [aux_sym_basic_type_token33] = ACTIONS(3290),
    [aux_sym_basic_type_token34] = ACTIONS(3290),
    [aux_sym_basic_type_token35] = ACTIONS(3290),
    [aux_sym_basic_type_token36] = ACTIONS(3290),
    [aux_sym_basic_type_token37] = ACTIONS(3290),
    [aux_sym_basic_type_token38] = ACTIONS(3290),
    [aux_sym_basic_type_token39] = ACTIONS(3290),
    [aux_sym_basic_type_token40] = ACTIONS(3290),
    [aux_sym_basic_type_token41] = ACTIONS(3290),
    [aux_sym_basic_type_token42] = ACTIONS(3290),
    [aux_sym_basic_type_token43] = ACTIONS(3290),
    [aux_sym_basic_type_token44] = ACTIONS(3290),
    [aux_sym_basic_type_token45] = ACTIONS(3290),
    [aux_sym_basic_type_token46] = ACTIONS(3290),
    [aux_sym_basic_type_token47] = ACTIONS(3290),
    [aux_sym_basic_type_token48] = ACTIONS(3290),
    [aux_sym_basic_type_token49] = ACTIONS(3290),
    [aux_sym_basic_type_token50] = ACTIONS(3290),
    [aux_sym_basic_type_token51] = ACTIONS(3290),
    [aux_sym_basic_type_token52] = ACTIONS(3290),
    [aux_sym_basic_type_token53] = ACTIONS(3290),
    [aux_sym_basic_type_token54] = ACTIONS(3290),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3282),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3282),
    [sym_query_keyword] = ACTIONS(3282),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3282),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3296),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1343)] = {
    [sym_type_specification] = STATE(6870),
    [sym_text_type] = STATE(6858),
    [sym_code_type] = STATE(6858),
    [sym_option_type] = STATE(6855),
    [sym_record_type] = STATE(6855),
    [sym_dotnet_type] = STATE(6855),
    [sym_object_reference_type] = STATE(6855),
    [sym_array_type] = STATE(6859),
    [sym_list_type] = STATE(6859),
    [sym_dictionary_type] = STATE(6859),
    [sym_basic_type] = STATE(6855),
    [sym_codeunit_keyword] = STATE(7883),
    [sym_xmlport_keyword] = STATE(7883),
    [sym_enum_keyword] = STATE(7883),
    [sym_controladdin_keyword] = STATE(7883),
    [sym_dotnet_keyword] = STATE(7716),
    [sym_identifier] = ACTIONS(3086),
    [aux_sym_text_type_token1] = ACTIONS(3088),
    [aux_sym_code_type_token1] = ACTIONS(3090),
    [aux_sym_option_type_token1] = ACTIONS(3092),
    [aux_sym_record_type_token1] = ACTIONS(3094),
    [aux_sym_object_reference_type_token1] = ACTIONS(3096),
    [aux_sym_object_reference_type_token2] = ACTIONS(3096),
    [aux_sym_array_type_token1] = ACTIONS(3098),
    [aux_sym_list_type_token1] = ACTIONS(3100),
    [aux_sym_dictionary_type_token1] = ACTIONS(3102),
    [aux_sym_basic_type_token1] = ACTIONS(3104),
    [aux_sym_basic_type_token2] = ACTIONS(3104),
    [aux_sym_basic_type_token3] = ACTIONS(3104),
    [aux_sym_basic_type_token4] = ACTIONS(3104),
    [aux_sym_basic_type_token5] = ACTIONS(3104),
    [aux_sym_basic_type_token6] = ACTIONS(3106),
    [aux_sym_basic_type_token7] = ACTIONS(3104),
    [aux_sym_basic_type_token8] = ACTIONS(3104),
    [aux_sym_basic_type_token9] = ACTIONS(3104),
    [aux_sym_basic_type_token10] = ACTIONS(3104),
    [aux_sym_basic_type_token11] = ACTIONS(3104),
    [aux_sym_basic_type_token12] = ACTIONS(3104),
    [aux_sym_basic_type_token13] = ACTIONS(3108),
    [aux_sym_basic_type_token14] = ACTIONS(3104),
    [aux_sym_basic_type_token15] = ACTIONS(3104),
    [aux_sym_basic_type_token16] = ACTIONS(3104),
    [aux_sym_basic_type_token17] = ACTIONS(3104),
    [aux_sym_basic_type_token18] = ACTIONS(3104),
    [aux_sym_basic_type_token19] = ACTIONS(3104),
    [aux_sym_basic_type_token20] = ACTIONS(3104),
    [aux_sym_basic_type_token21] = ACTIONS(3104),
    [aux_sym_basic_type_token22] = ACTIONS(3104),
    [aux_sym_basic_type_token23] = ACTIONS(3104),
    [aux_sym_basic_type_token24] = ACTIONS(3104),
    [aux_sym_basic_type_token25] = ACTIONS(3104),
    [aux_sym_basic_type_token26] = ACTIONS(3104),
    [aux_sym_basic_type_token27] = ACTIONS(3104),
    [aux_sym_basic_type_token28] = ACTIONS(3104),
    [aux_sym_basic_type_token29] = ACTIONS(3104),
    [aux_sym_basic_type_token30] = ACTIONS(3104),
    [aux_sym_basic_type_token31] = ACTIONS(3104),
    [aux_sym_basic_type_token32] = ACTIONS(3104),
    [aux_sym_basic_type_token33] = ACTIONS(3104),
    [aux_sym_basic_type_token34] = ACTIONS(3104),
    [aux_sym_basic_type_token35] = ACTIONS(3104),
    [aux_sym_basic_type_token36] = ACTIONS(3104),
    [aux_sym_basic_type_token37] = ACTIONS(3104),
    [aux_sym_basic_type_token38] = ACTIONS(3104),
    [aux_sym_basic_type_token39] = ACTIONS(3104),
    [aux_sym_basic_type_token40] = ACTIONS(3104),
    [aux_sym_basic_type_token41] = ACTIONS(3104),
    [aux_sym_basic_type_token42] = ACTIONS(3104),
    [aux_sym_basic_type_token43] = ACTIONS(3104),
    [aux_sym_basic_type_token44] = ACTIONS(3104),
    [aux_sym_basic_type_token45] = ACTIONS(3104),
    [aux_sym_basic_type_token46] = ACTIONS(3104),
    [aux_sym_basic_type_token47] = ACTIONS(3104),
    [aux_sym_basic_type_token48] = ACTIONS(3104),
    [aux_sym_basic_type_token49] = ACTIONS(3104),
    [aux_sym_basic_type_token50] = ACTIONS(3104),
    [aux_sym_basic_type_token51] = ACTIONS(3104),
    [aux_sym_basic_type_token52] = ACTIONS(3104),
    [aux_sym_basic_type_token53] = ACTIONS(3104),
    [aux_sym_basic_type_token54] = ACTIONS(3104),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3096),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3096),
    [sym_query_keyword] = ACTIONS(3096),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3096),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3110),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1344)] = {
    [sym_type_specification] = STATE(4843),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8101),
    [sym_xmlport_keyword] = STATE(8101),
    [sym_enum_keyword] = STATE(8101),
    [sym_controladdin_keyword] = STATE(8101),
    [sym_dotnet_keyword] = STATE(7675),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3402),
    [aux_sym_record_type_token1] = ACTIONS(3404),
    [aux_sym_object_reference_type_token1] = ACTIONS(3406),
    [aux_sym_object_reference_type_token2] = ACTIONS(3406),
    [aux_sym_array_type_token1] = ACTIONS(3408),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3406),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3406),
    [sym_query_keyword] = ACTIONS(3406),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3406),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1345)] = {
    [sym_type_specification] = STATE(6185),
    [sym_text_type] = STATE(6041),
    [sym_code_type] = STATE(6041),
    [sym_option_type] = STATE(6040),
    [sym_record_type] = STATE(6040),
    [sym_dotnet_type] = STATE(6040),
    [sym_object_reference_type] = STATE(6040),
    [sym_array_type] = STATE(6042),
    [sym_list_type] = STATE(6042),
    [sym_dictionary_type] = STATE(6042),
    [sym_basic_type] = STATE(6040),
    [sym_codeunit_keyword] = STATE(7853),
    [sym_xmlport_keyword] = STATE(7853),
    [sym_enum_keyword] = STATE(7853),
    [sym_controladdin_keyword] = STATE(7853),
    [sym_dotnet_keyword] = STATE(7709),
    [sym_identifier] = ACTIONS(3138),
    [aux_sym_text_type_token1] = ACTIONS(3140),
    [aux_sym_code_type_token1] = ACTIONS(3142),
    [aux_sym_option_type_token1] = ACTIONS(3144),
    [aux_sym_record_type_token1] = ACTIONS(3146),
    [aux_sym_object_reference_type_token1] = ACTIONS(3148),
    [aux_sym_object_reference_type_token2] = ACTIONS(3148),
    [aux_sym_array_type_token1] = ACTIONS(3150),
    [aux_sym_list_type_token1] = ACTIONS(3152),
    [aux_sym_dictionary_type_token1] = ACTIONS(3154),
    [aux_sym_basic_type_token1] = ACTIONS(3156),
    [aux_sym_basic_type_token2] = ACTIONS(3156),
    [aux_sym_basic_type_token3] = ACTIONS(3156),
    [aux_sym_basic_type_token4] = ACTIONS(3156),
    [aux_sym_basic_type_token5] = ACTIONS(3156),
    [aux_sym_basic_type_token6] = ACTIONS(3158),
    [aux_sym_basic_type_token7] = ACTIONS(3156),
    [aux_sym_basic_type_token8] = ACTIONS(3156),
    [aux_sym_basic_type_token9] = ACTIONS(3156),
    [aux_sym_basic_type_token10] = ACTIONS(3156),
    [aux_sym_basic_type_token11] = ACTIONS(3156),
    [aux_sym_basic_type_token12] = ACTIONS(3156),
    [aux_sym_basic_type_token13] = ACTIONS(3160),
    [aux_sym_basic_type_token14] = ACTIONS(3156),
    [aux_sym_basic_type_token15] = ACTIONS(3156),
    [aux_sym_basic_type_token16] = ACTIONS(3156),
    [aux_sym_basic_type_token17] = ACTIONS(3156),
    [aux_sym_basic_type_token18] = ACTIONS(3156),
    [aux_sym_basic_type_token19] = ACTIONS(3156),
    [aux_sym_basic_type_token20] = ACTIONS(3156),
    [aux_sym_basic_type_token21] = ACTIONS(3156),
    [aux_sym_basic_type_token22] = ACTIONS(3156),
    [aux_sym_basic_type_token23] = ACTIONS(3156),
    [aux_sym_basic_type_token24] = ACTIONS(3156),
    [aux_sym_basic_type_token25] = ACTIONS(3156),
    [aux_sym_basic_type_token26] = ACTIONS(3156),
    [aux_sym_basic_type_token27] = ACTIONS(3156),
    [aux_sym_basic_type_token28] = ACTIONS(3156),
    [aux_sym_basic_type_token29] = ACTIONS(3156),
    [aux_sym_basic_type_token30] = ACTIONS(3156),
    [aux_sym_basic_type_token31] = ACTIONS(3156),
    [aux_sym_basic_type_token32] = ACTIONS(3156),
    [aux_sym_basic_type_token33] = ACTIONS(3156),
    [aux_sym_basic_type_token34] = ACTIONS(3156),
    [aux_sym_basic_type_token35] = ACTIONS(3156),
    [aux_sym_basic_type_token36] = ACTIONS(3156),
    [aux_sym_basic_type_token37] = ACTIONS(3156),
    [aux_sym_basic_type_token38] = ACTIONS(3156),
    [aux_sym_basic_type_token39] = ACTIONS(3156),
    [aux_sym_basic_type_token40] = ACTIONS(3156),
    [aux_sym_basic_type_token41] = ACTIONS(3156),
    [aux_sym_basic_type_token42] = ACTIONS(3156),
    [aux_sym_basic_type_token43] = ACTIONS(3156),
    [aux_sym_basic_type_token44] = ACTIONS(3156),
    [aux_sym_basic_type_token45] = ACTIONS(3156),
    [aux_sym_basic_type_token46] = ACTIONS(3156),
    [aux_sym_basic_type_token47] = ACTIONS(3156),
    [aux_sym_basic_type_token48] = ACTIONS(3156),
    [aux_sym_basic_type_token49] = ACTIONS(3156),
    [aux_sym_basic_type_token50] = ACTIONS(3156),
    [aux_sym_basic_type_token51] = ACTIONS(3156),
    [aux_sym_basic_type_token52] = ACTIONS(3156),
    [aux_sym_basic_type_token53] = ACTIONS(3156),
    [aux_sym_basic_type_token54] = ACTIONS(3156),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3148),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3148),
    [sym_query_keyword] = ACTIONS(3148),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3148),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3162),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1346)] = {
    [sym_type_specification] = STATE(1240),
    [sym_text_type] = STATE(1232),
    [sym_code_type] = STATE(1232),
    [sym_option_type] = STATE(1231),
    [sym_record_type] = STATE(1231),
    [sym_dotnet_type] = STATE(1231),
    [sym_object_reference_type] = STATE(1231),
    [sym_array_type] = STATE(1233),
    [sym_list_type] = STATE(1233),
    [sym_dictionary_type] = STATE(1233),
    [sym_basic_type] = STATE(1231),
    [sym_codeunit_keyword] = STATE(8162),
    [sym_xmlport_keyword] = STATE(8162),
    [sym_enum_keyword] = STATE(8162),
    [sym_controladdin_keyword] = STATE(8162),
    [sym_dotnet_keyword] = STATE(7685),
    [sym_identifier] = ACTIONS(3112),
    [aux_sym_text_type_token1] = ACTIONS(3114),
    [aux_sym_code_type_token1] = ACTIONS(3116),
    [aux_sym_option_type_token1] = ACTIONS(3118),
    [aux_sym_record_type_token1] = ACTIONS(3120),
    [aux_sym_object_reference_type_token1] = ACTIONS(3122),
    [aux_sym_object_reference_type_token2] = ACTIONS(3122),
    [aux_sym_array_type_token1] = ACTIONS(3124),
    [aux_sym_list_type_token1] = ACTIONS(3126),
    [aux_sym_dictionary_type_token1] = ACTIONS(3128),
    [aux_sym_basic_type_token1] = ACTIONS(3130),
    [aux_sym_basic_type_token2] = ACTIONS(3130),
    [aux_sym_basic_type_token3] = ACTIONS(3130),
    [aux_sym_basic_type_token4] = ACTIONS(3130),
    [aux_sym_basic_type_token5] = ACTIONS(3130),
    [aux_sym_basic_type_token6] = ACTIONS(3132),
    [aux_sym_basic_type_token7] = ACTIONS(3130),
    [aux_sym_basic_type_token8] = ACTIONS(3130),
    [aux_sym_basic_type_token9] = ACTIONS(3130),
    [aux_sym_basic_type_token10] = ACTIONS(3130),
    [aux_sym_basic_type_token11] = ACTIONS(3130),
    [aux_sym_basic_type_token12] = ACTIONS(3130),
    [aux_sym_basic_type_token13] = ACTIONS(3134),
    [aux_sym_basic_type_token14] = ACTIONS(3130),
    [aux_sym_basic_type_token15] = ACTIONS(3130),
    [aux_sym_basic_type_token16] = ACTIONS(3130),
    [aux_sym_basic_type_token17] = ACTIONS(3130),
    [aux_sym_basic_type_token18] = ACTIONS(3130),
    [aux_sym_basic_type_token19] = ACTIONS(3130),
    [aux_sym_basic_type_token20] = ACTIONS(3130),
    [aux_sym_basic_type_token21] = ACTIONS(3130),
    [aux_sym_basic_type_token22] = ACTIONS(3130),
    [aux_sym_basic_type_token23] = ACTIONS(3130),
    [aux_sym_basic_type_token24] = ACTIONS(3130),
    [aux_sym_basic_type_token25] = ACTIONS(3130),
    [aux_sym_basic_type_token26] = ACTIONS(3130),
    [aux_sym_basic_type_token27] = ACTIONS(3130),
    [aux_sym_basic_type_token28] = ACTIONS(3130),
    [aux_sym_basic_type_token29] = ACTIONS(3130),
    [aux_sym_basic_type_token30] = ACTIONS(3130),
    [aux_sym_basic_type_token31] = ACTIONS(3130),
    [aux_sym_basic_type_token32] = ACTIONS(3130),
    [aux_sym_basic_type_token33] = ACTIONS(3130),
    [aux_sym_basic_type_token34] = ACTIONS(3130),
    [aux_sym_basic_type_token35] = ACTIONS(3130),
    [aux_sym_basic_type_token36] = ACTIONS(3130),
    [aux_sym_basic_type_token37] = ACTIONS(3130),
    [aux_sym_basic_type_token38] = ACTIONS(3130),
    [aux_sym_basic_type_token39] = ACTIONS(3130),
    [aux_sym_basic_type_token40] = ACTIONS(3130),
    [aux_sym_basic_type_token41] = ACTIONS(3130),
    [aux_sym_basic_type_token42] = ACTIONS(3130),
    [aux_sym_basic_type_token43] = ACTIONS(3130),
    [aux_sym_basic_type_token44] = ACTIONS(3130),
    [aux_sym_basic_type_token45] = ACTIONS(3130),
    [aux_sym_basic_type_token46] = ACTIONS(3130),
    [aux_sym_basic_type_token47] = ACTIONS(3130),
    [aux_sym_basic_type_token48] = ACTIONS(3130),
    [aux_sym_basic_type_token49] = ACTIONS(3130),
    [aux_sym_basic_type_token50] = ACTIONS(3130),
    [aux_sym_basic_type_token51] = ACTIONS(3130),
    [aux_sym_basic_type_token52] = ACTIONS(3130),
    [aux_sym_basic_type_token53] = ACTIONS(3130),
    [aux_sym_basic_type_token54] = ACTIONS(3130),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3122),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3122),
    [sym_query_keyword] = ACTIONS(3122),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3122),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3136),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1347)] = {
    [sym_type_specification] = STATE(8803),
    [sym_text_type] = STATE(8818),
    [sym_code_type] = STATE(8818),
    [sym_option_type] = STATE(8817),
    [sym_record_type] = STATE(8817),
    [sym_dotnet_type] = STATE(8817),
    [sym_object_reference_type] = STATE(8817),
    [sym_array_type] = STATE(8819),
    [sym_list_type] = STATE(8819),
    [sym_dictionary_type] = STATE(8819),
    [sym_basic_type] = STATE(8817),
    [sym_codeunit_keyword] = STATE(8015),
    [sym_xmlport_keyword] = STATE(8015),
    [sym_enum_keyword] = STATE(8015),
    [sym_controladdin_keyword] = STATE(8015),
    [sym_dotnet_keyword] = STATE(7673),
    [sym_identifier] = ACTIONS(3350),
    [aux_sym_text_type_token1] = ACTIONS(3352),
    [aux_sym_code_type_token1] = ACTIONS(3354),
    [aux_sym_option_type_token1] = ACTIONS(3356),
    [aux_sym_record_type_token1] = ACTIONS(3358),
    [aux_sym_object_reference_type_token1] = ACTIONS(3360),
    [aux_sym_object_reference_type_token2] = ACTIONS(3360),
    [aux_sym_array_type_token1] = ACTIONS(3362),
    [aux_sym_list_type_token1] = ACTIONS(3364),
    [aux_sym_dictionary_type_token1] = ACTIONS(3366),
    [aux_sym_basic_type_token1] = ACTIONS(3368),
    [aux_sym_basic_type_token2] = ACTIONS(3368),
    [aux_sym_basic_type_token3] = ACTIONS(3368),
    [aux_sym_basic_type_token4] = ACTIONS(3368),
    [aux_sym_basic_type_token5] = ACTIONS(3368),
    [aux_sym_basic_type_token6] = ACTIONS(3370),
    [aux_sym_basic_type_token7] = ACTIONS(3368),
    [aux_sym_basic_type_token8] = ACTIONS(3368),
    [aux_sym_basic_type_token9] = ACTIONS(3368),
    [aux_sym_basic_type_token10] = ACTIONS(3368),
    [aux_sym_basic_type_token11] = ACTIONS(3368),
    [aux_sym_basic_type_token12] = ACTIONS(3368),
    [aux_sym_basic_type_token13] = ACTIONS(3372),
    [aux_sym_basic_type_token14] = ACTIONS(3368),
    [aux_sym_basic_type_token15] = ACTIONS(3368),
    [aux_sym_basic_type_token16] = ACTIONS(3368),
    [aux_sym_basic_type_token17] = ACTIONS(3368),
    [aux_sym_basic_type_token18] = ACTIONS(3368),
    [aux_sym_basic_type_token19] = ACTIONS(3368),
    [aux_sym_basic_type_token20] = ACTIONS(3368),
    [aux_sym_basic_type_token21] = ACTIONS(3368),
    [aux_sym_basic_type_token22] = ACTIONS(3368),
    [aux_sym_basic_type_token23] = ACTIONS(3368),
    [aux_sym_basic_type_token24] = ACTIONS(3368),
    [aux_sym_basic_type_token25] = ACTIONS(3368),
    [aux_sym_basic_type_token26] = ACTIONS(3368),
    [aux_sym_basic_type_token27] = ACTIONS(3368),
    [aux_sym_basic_type_token28] = ACTIONS(3368),
    [aux_sym_basic_type_token29] = ACTIONS(3368),
    [aux_sym_basic_type_token30] = ACTIONS(3368),
    [aux_sym_basic_type_token31] = ACTIONS(3368),
    [aux_sym_basic_type_token32] = ACTIONS(3368),
    [aux_sym_basic_type_token33] = ACTIONS(3368),
    [aux_sym_basic_type_token34] = ACTIONS(3368),
    [aux_sym_basic_type_token35] = ACTIONS(3368),
    [aux_sym_basic_type_token36] = ACTIONS(3368),
    [aux_sym_basic_type_token37] = ACTIONS(3368),
    [aux_sym_basic_type_token38] = ACTIONS(3368),
    [aux_sym_basic_type_token39] = ACTIONS(3368),
    [aux_sym_basic_type_token40] = ACTIONS(3368),
    [aux_sym_basic_type_token41] = ACTIONS(3368),
    [aux_sym_basic_type_token42] = ACTIONS(3368),
    [aux_sym_basic_type_token43] = ACTIONS(3368),
    [aux_sym_basic_type_token44] = ACTIONS(3368),
    [aux_sym_basic_type_token45] = ACTIONS(3368),
    [aux_sym_basic_type_token46] = ACTIONS(3368),
    [aux_sym_basic_type_token47] = ACTIONS(3368),
    [aux_sym_basic_type_token48] = ACTIONS(3368),
    [aux_sym_basic_type_token49] = ACTIONS(3368),
    [aux_sym_basic_type_token50] = ACTIONS(3368),
    [aux_sym_basic_type_token51] = ACTIONS(3368),
    [aux_sym_basic_type_token52] = ACTIONS(3368),
    [aux_sym_basic_type_token53] = ACTIONS(3368),
    [aux_sym_basic_type_token54] = ACTIONS(3368),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3360),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3360),
    [sym_query_keyword] = ACTIONS(3360),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3360),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3374),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1348)] = {
    [sym_type_specification] = STATE(8812),
    [sym_text_type] = STATE(8818),
    [sym_code_type] = STATE(8818),
    [sym_option_type] = STATE(8817),
    [sym_record_type] = STATE(8817),
    [sym_dotnet_type] = STATE(8817),
    [sym_object_reference_type] = STATE(8817),
    [sym_array_type] = STATE(8819),
    [sym_list_type] = STATE(8819),
    [sym_dictionary_type] = STATE(8819),
    [sym_basic_type] = STATE(8817),
    [sym_codeunit_keyword] = STATE(8015),
    [sym_xmlport_keyword] = STATE(8015),
    [sym_enum_keyword] = STATE(8015),
    [sym_controladdin_keyword] = STATE(8015),
    [sym_dotnet_keyword] = STATE(7673),
    [sym_identifier] = ACTIONS(3350),
    [aux_sym_text_type_token1] = ACTIONS(3352),
    [aux_sym_code_type_token1] = ACTIONS(3354),
    [aux_sym_option_type_token1] = ACTIONS(3356),
    [aux_sym_record_type_token1] = ACTIONS(3358),
    [aux_sym_object_reference_type_token1] = ACTIONS(3360),
    [aux_sym_object_reference_type_token2] = ACTIONS(3360),
    [aux_sym_array_type_token1] = ACTIONS(3362),
    [aux_sym_list_type_token1] = ACTIONS(3364),
    [aux_sym_dictionary_type_token1] = ACTIONS(3366),
    [aux_sym_basic_type_token1] = ACTIONS(3368),
    [aux_sym_basic_type_token2] = ACTIONS(3368),
    [aux_sym_basic_type_token3] = ACTIONS(3368),
    [aux_sym_basic_type_token4] = ACTIONS(3368),
    [aux_sym_basic_type_token5] = ACTIONS(3368),
    [aux_sym_basic_type_token6] = ACTIONS(3370),
    [aux_sym_basic_type_token7] = ACTIONS(3368),
    [aux_sym_basic_type_token8] = ACTIONS(3368),
    [aux_sym_basic_type_token9] = ACTIONS(3368),
    [aux_sym_basic_type_token10] = ACTIONS(3368),
    [aux_sym_basic_type_token11] = ACTIONS(3368),
    [aux_sym_basic_type_token12] = ACTIONS(3368),
    [aux_sym_basic_type_token13] = ACTIONS(3372),
    [aux_sym_basic_type_token14] = ACTIONS(3368),
    [aux_sym_basic_type_token15] = ACTIONS(3368),
    [aux_sym_basic_type_token16] = ACTIONS(3368),
    [aux_sym_basic_type_token17] = ACTIONS(3368),
    [aux_sym_basic_type_token18] = ACTIONS(3368),
    [aux_sym_basic_type_token19] = ACTIONS(3368),
    [aux_sym_basic_type_token20] = ACTIONS(3368),
    [aux_sym_basic_type_token21] = ACTIONS(3368),
    [aux_sym_basic_type_token22] = ACTIONS(3368),
    [aux_sym_basic_type_token23] = ACTIONS(3368),
    [aux_sym_basic_type_token24] = ACTIONS(3368),
    [aux_sym_basic_type_token25] = ACTIONS(3368),
    [aux_sym_basic_type_token26] = ACTIONS(3368),
    [aux_sym_basic_type_token27] = ACTIONS(3368),
    [aux_sym_basic_type_token28] = ACTIONS(3368),
    [aux_sym_basic_type_token29] = ACTIONS(3368),
    [aux_sym_basic_type_token30] = ACTIONS(3368),
    [aux_sym_basic_type_token31] = ACTIONS(3368),
    [aux_sym_basic_type_token32] = ACTIONS(3368),
    [aux_sym_basic_type_token33] = ACTIONS(3368),
    [aux_sym_basic_type_token34] = ACTIONS(3368),
    [aux_sym_basic_type_token35] = ACTIONS(3368),
    [aux_sym_basic_type_token36] = ACTIONS(3368),
    [aux_sym_basic_type_token37] = ACTIONS(3368),
    [aux_sym_basic_type_token38] = ACTIONS(3368),
    [aux_sym_basic_type_token39] = ACTIONS(3368),
    [aux_sym_basic_type_token40] = ACTIONS(3368),
    [aux_sym_basic_type_token41] = ACTIONS(3368),
    [aux_sym_basic_type_token42] = ACTIONS(3368),
    [aux_sym_basic_type_token43] = ACTIONS(3368),
    [aux_sym_basic_type_token44] = ACTIONS(3368),
    [aux_sym_basic_type_token45] = ACTIONS(3368),
    [aux_sym_basic_type_token46] = ACTIONS(3368),
    [aux_sym_basic_type_token47] = ACTIONS(3368),
    [aux_sym_basic_type_token48] = ACTIONS(3368),
    [aux_sym_basic_type_token49] = ACTIONS(3368),
    [aux_sym_basic_type_token50] = ACTIONS(3368),
    [aux_sym_basic_type_token51] = ACTIONS(3368),
    [aux_sym_basic_type_token52] = ACTIONS(3368),
    [aux_sym_basic_type_token53] = ACTIONS(3368),
    [aux_sym_basic_type_token54] = ACTIONS(3368),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3360),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3360),
    [sym_query_keyword] = ACTIONS(3360),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3360),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3374),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1349)] = {
    [sym_type_specification] = STATE(4834),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3242),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3244),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1350)] = {
    [sym_type_specification] = STATE(11615),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(11154),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1351)] = {
    [sym_type_specification] = STATE(12470),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1352)] = {
    [sym_type_specification] = STATE(6186),
    [sym_text_type] = STATE(6188),
    [sym_code_type] = STATE(6188),
    [sym_option_type] = STATE(6145),
    [sym_record_type] = STATE(6145),
    [sym_dotnet_type] = STATE(6145),
    [sym_object_reference_type] = STATE(6145),
    [sym_array_type] = STATE(6190),
    [sym_list_type] = STATE(6190),
    [sym_dictionary_type] = STATE(6190),
    [sym_basic_type] = STATE(6145),
    [sym_codeunit_keyword] = STATE(8077),
    [sym_xmlport_keyword] = STATE(8077),
    [sym_enum_keyword] = STATE(8077),
    [sym_controladdin_keyword] = STATE(8077),
    [sym_dotnet_keyword] = STATE(7640),
    [sym_identifier] = ACTIONS(3324),
    [aux_sym_text_type_token1] = ACTIONS(3326),
    [aux_sym_code_type_token1] = ACTIONS(3328),
    [aux_sym_option_type_token1] = ACTIONS(3330),
    [aux_sym_record_type_token1] = ACTIONS(3332),
    [aux_sym_object_reference_type_token1] = ACTIONS(3334),
    [aux_sym_object_reference_type_token2] = ACTIONS(3334),
    [aux_sym_array_type_token1] = ACTIONS(3336),
    [aux_sym_list_type_token1] = ACTIONS(3338),
    [aux_sym_dictionary_type_token1] = ACTIONS(3340),
    [aux_sym_basic_type_token1] = ACTIONS(3342),
    [aux_sym_basic_type_token2] = ACTIONS(3342),
    [aux_sym_basic_type_token3] = ACTIONS(3342),
    [aux_sym_basic_type_token4] = ACTIONS(3342),
    [aux_sym_basic_type_token5] = ACTIONS(3342),
    [aux_sym_basic_type_token6] = ACTIONS(3344),
    [aux_sym_basic_type_token7] = ACTIONS(3342),
    [aux_sym_basic_type_token8] = ACTIONS(3342),
    [aux_sym_basic_type_token9] = ACTIONS(3342),
    [aux_sym_basic_type_token10] = ACTIONS(3342),
    [aux_sym_basic_type_token11] = ACTIONS(3342),
    [aux_sym_basic_type_token12] = ACTIONS(3342),
    [aux_sym_basic_type_token13] = ACTIONS(3346),
    [aux_sym_basic_type_token14] = ACTIONS(3342),
    [aux_sym_basic_type_token15] = ACTIONS(3342),
    [aux_sym_basic_type_token16] = ACTIONS(3342),
    [aux_sym_basic_type_token17] = ACTIONS(3342),
    [aux_sym_basic_type_token18] = ACTIONS(3342),
    [aux_sym_basic_type_token19] = ACTIONS(3342),
    [aux_sym_basic_type_token20] = ACTIONS(3342),
    [aux_sym_basic_type_token21] = ACTIONS(3342),
    [aux_sym_basic_type_token22] = ACTIONS(3342),
    [aux_sym_basic_type_token23] = ACTIONS(3342),
    [aux_sym_basic_type_token24] = ACTIONS(3342),
    [aux_sym_basic_type_token25] = ACTIONS(3342),
    [aux_sym_basic_type_token26] = ACTIONS(3342),
    [aux_sym_basic_type_token27] = ACTIONS(3342),
    [aux_sym_basic_type_token28] = ACTIONS(3342),
    [aux_sym_basic_type_token29] = ACTIONS(3342),
    [aux_sym_basic_type_token30] = ACTIONS(3342),
    [aux_sym_basic_type_token31] = ACTIONS(3342),
    [aux_sym_basic_type_token32] = ACTIONS(3342),
    [aux_sym_basic_type_token33] = ACTIONS(3342),
    [aux_sym_basic_type_token34] = ACTIONS(3342),
    [aux_sym_basic_type_token35] = ACTIONS(3342),
    [aux_sym_basic_type_token36] = ACTIONS(3342),
    [aux_sym_basic_type_token37] = ACTIONS(3342),
    [aux_sym_basic_type_token38] = ACTIONS(3342),
    [aux_sym_basic_type_token39] = ACTIONS(3342),
    [aux_sym_basic_type_token40] = ACTIONS(3342),
    [aux_sym_basic_type_token41] = ACTIONS(3342),
    [aux_sym_basic_type_token42] = ACTIONS(3342),
    [aux_sym_basic_type_token43] = ACTIONS(3342),
    [aux_sym_basic_type_token44] = ACTIONS(3342),
    [aux_sym_basic_type_token45] = ACTIONS(3342),
    [aux_sym_basic_type_token46] = ACTIONS(3342),
    [aux_sym_basic_type_token47] = ACTIONS(3342),
    [aux_sym_basic_type_token48] = ACTIONS(3342),
    [aux_sym_basic_type_token49] = ACTIONS(3342),
    [aux_sym_basic_type_token50] = ACTIONS(3342),
    [aux_sym_basic_type_token51] = ACTIONS(3342),
    [aux_sym_basic_type_token52] = ACTIONS(3342),
    [aux_sym_basic_type_token53] = ACTIONS(3342),
    [aux_sym_basic_type_token54] = ACTIONS(3342),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3334),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3334),
    [sym_query_keyword] = ACTIONS(3334),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3334),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3348),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1353)] = {
    [sym_type_specification] = STATE(11169),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1354)] = {
    [sym_type_specification] = STATE(6195),
    [sym_text_type] = STATE(6188),
    [sym_code_type] = STATE(6188),
    [sym_option_type] = STATE(6145),
    [sym_record_type] = STATE(6145),
    [sym_dotnet_type] = STATE(6145),
    [sym_object_reference_type] = STATE(6145),
    [sym_array_type] = STATE(6190),
    [sym_list_type] = STATE(6190),
    [sym_dictionary_type] = STATE(6190),
    [sym_basic_type] = STATE(6145),
    [sym_codeunit_keyword] = STATE(8077),
    [sym_xmlport_keyword] = STATE(8077),
    [sym_enum_keyword] = STATE(8077),
    [sym_controladdin_keyword] = STATE(8077),
    [sym_dotnet_keyword] = STATE(7640),
    [sym_identifier] = ACTIONS(3324),
    [aux_sym_text_type_token1] = ACTIONS(3326),
    [aux_sym_code_type_token1] = ACTIONS(3328),
    [aux_sym_option_type_token1] = ACTIONS(3330),
    [aux_sym_record_type_token1] = ACTIONS(3332),
    [aux_sym_object_reference_type_token1] = ACTIONS(3334),
    [aux_sym_object_reference_type_token2] = ACTIONS(3334),
    [aux_sym_array_type_token1] = ACTIONS(3336),
    [aux_sym_list_type_token1] = ACTIONS(3338),
    [aux_sym_dictionary_type_token1] = ACTIONS(3340),
    [aux_sym_basic_type_token1] = ACTIONS(3342),
    [aux_sym_basic_type_token2] = ACTIONS(3342),
    [aux_sym_basic_type_token3] = ACTIONS(3342),
    [aux_sym_basic_type_token4] = ACTIONS(3342),
    [aux_sym_basic_type_token5] = ACTIONS(3342),
    [aux_sym_basic_type_token6] = ACTIONS(3344),
    [aux_sym_basic_type_token7] = ACTIONS(3342),
    [aux_sym_basic_type_token8] = ACTIONS(3342),
    [aux_sym_basic_type_token9] = ACTIONS(3342),
    [aux_sym_basic_type_token10] = ACTIONS(3342),
    [aux_sym_basic_type_token11] = ACTIONS(3342),
    [aux_sym_basic_type_token12] = ACTIONS(3342),
    [aux_sym_basic_type_token13] = ACTIONS(3346),
    [aux_sym_basic_type_token14] = ACTIONS(3342),
    [aux_sym_basic_type_token15] = ACTIONS(3342),
    [aux_sym_basic_type_token16] = ACTIONS(3342),
    [aux_sym_basic_type_token17] = ACTIONS(3342),
    [aux_sym_basic_type_token18] = ACTIONS(3342),
    [aux_sym_basic_type_token19] = ACTIONS(3342),
    [aux_sym_basic_type_token20] = ACTIONS(3342),
    [aux_sym_basic_type_token21] = ACTIONS(3342),
    [aux_sym_basic_type_token22] = ACTIONS(3342),
    [aux_sym_basic_type_token23] = ACTIONS(3342),
    [aux_sym_basic_type_token24] = ACTIONS(3342),
    [aux_sym_basic_type_token25] = ACTIONS(3342),
    [aux_sym_basic_type_token26] = ACTIONS(3342),
    [aux_sym_basic_type_token27] = ACTIONS(3342),
    [aux_sym_basic_type_token28] = ACTIONS(3342),
    [aux_sym_basic_type_token29] = ACTIONS(3342),
    [aux_sym_basic_type_token30] = ACTIONS(3342),
    [aux_sym_basic_type_token31] = ACTIONS(3342),
    [aux_sym_basic_type_token32] = ACTIONS(3342),
    [aux_sym_basic_type_token33] = ACTIONS(3342),
    [aux_sym_basic_type_token34] = ACTIONS(3342),
    [aux_sym_basic_type_token35] = ACTIONS(3342),
    [aux_sym_basic_type_token36] = ACTIONS(3342),
    [aux_sym_basic_type_token37] = ACTIONS(3342),
    [aux_sym_basic_type_token38] = ACTIONS(3342),
    [aux_sym_basic_type_token39] = ACTIONS(3342),
    [aux_sym_basic_type_token40] = ACTIONS(3342),
    [aux_sym_basic_type_token41] = ACTIONS(3342),
    [aux_sym_basic_type_token42] = ACTIONS(3342),
    [aux_sym_basic_type_token43] = ACTIONS(3342),
    [aux_sym_basic_type_token44] = ACTIONS(3342),
    [aux_sym_basic_type_token45] = ACTIONS(3342),
    [aux_sym_basic_type_token46] = ACTIONS(3342),
    [aux_sym_basic_type_token47] = ACTIONS(3342),
    [aux_sym_basic_type_token48] = ACTIONS(3342),
    [aux_sym_basic_type_token49] = ACTIONS(3342),
    [aux_sym_basic_type_token50] = ACTIONS(3342),
    [aux_sym_basic_type_token51] = ACTIONS(3342),
    [aux_sym_basic_type_token52] = ACTIONS(3342),
    [aux_sym_basic_type_token53] = ACTIONS(3342),
    [aux_sym_basic_type_token54] = ACTIONS(3342),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3334),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3334),
    [sym_query_keyword] = ACTIONS(3334),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3334),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3348),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1355)] = {
    [sym_type_specification] = STATE(12487),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1356)] = {
    [sym_type_specification] = STATE(8932),
    [sym_text_type] = STATE(8924),
    [sym_code_type] = STATE(8924),
    [sym_option_type] = STATE(8918),
    [sym_record_type] = STATE(8918),
    [sym_dotnet_type] = STATE(8918),
    [sym_object_reference_type] = STATE(8918),
    [sym_array_type] = STATE(8926),
    [sym_list_type] = STATE(8926),
    [sym_dictionary_type] = STATE(8926),
    [sym_basic_type] = STATE(8918),
    [sym_codeunit_keyword] = STATE(7798),
    [sym_xmlport_keyword] = STATE(7798),
    [sym_enum_keyword] = STATE(7798),
    [sym_controladdin_keyword] = STATE(7798),
    [sym_dotnet_keyword] = STATE(7641),
    [sym_identifier] = ACTIONS(3164),
    [aux_sym_text_type_token1] = ACTIONS(3166),
    [aux_sym_code_type_token1] = ACTIONS(3168),
    [aux_sym_option_type_token1] = ACTIONS(3170),
    [aux_sym_record_type_token1] = ACTIONS(3172),
    [aux_sym_object_reference_type_token1] = ACTIONS(3174),
    [aux_sym_object_reference_type_token2] = ACTIONS(3174),
    [aux_sym_array_type_token1] = ACTIONS(3176),
    [aux_sym_list_type_token1] = ACTIONS(3178),
    [aux_sym_dictionary_type_token1] = ACTIONS(3180),
    [aux_sym_basic_type_token1] = ACTIONS(3182),
    [aux_sym_basic_type_token2] = ACTIONS(3182),
    [aux_sym_basic_type_token3] = ACTIONS(3182),
    [aux_sym_basic_type_token4] = ACTIONS(3182),
    [aux_sym_basic_type_token5] = ACTIONS(3182),
    [aux_sym_basic_type_token6] = ACTIONS(3184),
    [aux_sym_basic_type_token7] = ACTIONS(3182),
    [aux_sym_basic_type_token8] = ACTIONS(3182),
    [aux_sym_basic_type_token9] = ACTIONS(3182),
    [aux_sym_basic_type_token10] = ACTIONS(3182),
    [aux_sym_basic_type_token11] = ACTIONS(3182),
    [aux_sym_basic_type_token12] = ACTIONS(3182),
    [aux_sym_basic_type_token13] = ACTIONS(3186),
    [aux_sym_basic_type_token14] = ACTIONS(3182),
    [aux_sym_basic_type_token15] = ACTIONS(3182),
    [aux_sym_basic_type_token16] = ACTIONS(3182),
    [aux_sym_basic_type_token17] = ACTIONS(3182),
    [aux_sym_basic_type_token18] = ACTIONS(3182),
    [aux_sym_basic_type_token19] = ACTIONS(3182),
    [aux_sym_basic_type_token20] = ACTIONS(3182),
    [aux_sym_basic_type_token21] = ACTIONS(3182),
    [aux_sym_basic_type_token22] = ACTIONS(3182),
    [aux_sym_basic_type_token23] = ACTIONS(3182),
    [aux_sym_basic_type_token24] = ACTIONS(3182),
    [aux_sym_basic_type_token25] = ACTIONS(3182),
    [aux_sym_basic_type_token26] = ACTIONS(3182),
    [aux_sym_basic_type_token27] = ACTIONS(3182),
    [aux_sym_basic_type_token28] = ACTIONS(3182),
    [aux_sym_basic_type_token29] = ACTIONS(3182),
    [aux_sym_basic_type_token30] = ACTIONS(3182),
    [aux_sym_basic_type_token31] = ACTIONS(3182),
    [aux_sym_basic_type_token32] = ACTIONS(3182),
    [aux_sym_basic_type_token33] = ACTIONS(3182),
    [aux_sym_basic_type_token34] = ACTIONS(3182),
    [aux_sym_basic_type_token35] = ACTIONS(3182),
    [aux_sym_basic_type_token36] = ACTIONS(3182),
    [aux_sym_basic_type_token37] = ACTIONS(3182),
    [aux_sym_basic_type_token38] = ACTIONS(3182),
    [aux_sym_basic_type_token39] = ACTIONS(3182),
    [aux_sym_basic_type_token40] = ACTIONS(3182),
    [aux_sym_basic_type_token41] = ACTIONS(3182),
    [aux_sym_basic_type_token42] = ACTIONS(3182),
    [aux_sym_basic_type_token43] = ACTIONS(3182),
    [aux_sym_basic_type_token44] = ACTIONS(3182),
    [aux_sym_basic_type_token45] = ACTIONS(3182),
    [aux_sym_basic_type_token46] = ACTIONS(3182),
    [aux_sym_basic_type_token47] = ACTIONS(3182),
    [aux_sym_basic_type_token48] = ACTIONS(3182),
    [aux_sym_basic_type_token49] = ACTIONS(3182),
    [aux_sym_basic_type_token50] = ACTIONS(3182),
    [aux_sym_basic_type_token51] = ACTIONS(3182),
    [aux_sym_basic_type_token52] = ACTIONS(3182),
    [aux_sym_basic_type_token53] = ACTIONS(3182),
    [aux_sym_basic_type_token54] = ACTIONS(3182),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3174),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3174),
    [sym_query_keyword] = ACTIONS(3174),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3174),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3188),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1357)] = {
    [sym_type_specification] = STATE(11692),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1358)] = {
    [sym_type_specification] = STATE(1241),
    [sym_text_type] = STATE(1232),
    [sym_code_type] = STATE(1232),
    [sym_option_type] = STATE(1231),
    [sym_record_type] = STATE(1231),
    [sym_dotnet_type] = STATE(1231),
    [sym_object_reference_type] = STATE(1231),
    [sym_array_type] = STATE(1233),
    [sym_list_type] = STATE(1233),
    [sym_dictionary_type] = STATE(1233),
    [sym_basic_type] = STATE(1231),
    [sym_codeunit_keyword] = STATE(8162),
    [sym_xmlport_keyword] = STATE(8162),
    [sym_enum_keyword] = STATE(8162),
    [sym_controladdin_keyword] = STATE(8162),
    [sym_dotnet_keyword] = STATE(7685),
    [sym_identifier] = ACTIONS(3112),
    [aux_sym_text_type_token1] = ACTIONS(3114),
    [aux_sym_code_type_token1] = ACTIONS(3116),
    [aux_sym_option_type_token1] = ACTIONS(3118),
    [aux_sym_record_type_token1] = ACTIONS(3120),
    [aux_sym_object_reference_type_token1] = ACTIONS(3122),
    [aux_sym_object_reference_type_token2] = ACTIONS(3122),
    [aux_sym_array_type_token1] = ACTIONS(3124),
    [aux_sym_list_type_token1] = ACTIONS(3126),
    [aux_sym_dictionary_type_token1] = ACTIONS(3128),
    [aux_sym_basic_type_token1] = ACTIONS(3130),
    [aux_sym_basic_type_token2] = ACTIONS(3130),
    [aux_sym_basic_type_token3] = ACTIONS(3130),
    [aux_sym_basic_type_token4] = ACTIONS(3130),
    [aux_sym_basic_type_token5] = ACTIONS(3130),
    [aux_sym_basic_type_token6] = ACTIONS(3132),
    [aux_sym_basic_type_token7] = ACTIONS(3130),
    [aux_sym_basic_type_token8] = ACTIONS(3130),
    [aux_sym_basic_type_token9] = ACTIONS(3130),
    [aux_sym_basic_type_token10] = ACTIONS(3130),
    [aux_sym_basic_type_token11] = ACTIONS(3130),
    [aux_sym_basic_type_token12] = ACTIONS(3130),
    [aux_sym_basic_type_token13] = ACTIONS(3134),
    [aux_sym_basic_type_token14] = ACTIONS(3130),
    [aux_sym_basic_type_token15] = ACTIONS(3130),
    [aux_sym_basic_type_token16] = ACTIONS(3130),
    [aux_sym_basic_type_token17] = ACTIONS(3130),
    [aux_sym_basic_type_token18] = ACTIONS(3130),
    [aux_sym_basic_type_token19] = ACTIONS(3130),
    [aux_sym_basic_type_token20] = ACTIONS(3130),
    [aux_sym_basic_type_token21] = ACTIONS(3130),
    [aux_sym_basic_type_token22] = ACTIONS(3130),
    [aux_sym_basic_type_token23] = ACTIONS(3130),
    [aux_sym_basic_type_token24] = ACTIONS(3130),
    [aux_sym_basic_type_token25] = ACTIONS(3130),
    [aux_sym_basic_type_token26] = ACTIONS(3130),
    [aux_sym_basic_type_token27] = ACTIONS(3130),
    [aux_sym_basic_type_token28] = ACTIONS(3130),
    [aux_sym_basic_type_token29] = ACTIONS(3130),
    [aux_sym_basic_type_token30] = ACTIONS(3130),
    [aux_sym_basic_type_token31] = ACTIONS(3130),
    [aux_sym_basic_type_token32] = ACTIONS(3130),
    [aux_sym_basic_type_token33] = ACTIONS(3130),
    [aux_sym_basic_type_token34] = ACTIONS(3130),
    [aux_sym_basic_type_token35] = ACTIONS(3130),
    [aux_sym_basic_type_token36] = ACTIONS(3130),
    [aux_sym_basic_type_token37] = ACTIONS(3130),
    [aux_sym_basic_type_token38] = ACTIONS(3130),
    [aux_sym_basic_type_token39] = ACTIONS(3130),
    [aux_sym_basic_type_token40] = ACTIONS(3130),
    [aux_sym_basic_type_token41] = ACTIONS(3130),
    [aux_sym_basic_type_token42] = ACTIONS(3130),
    [aux_sym_basic_type_token43] = ACTIONS(3130),
    [aux_sym_basic_type_token44] = ACTIONS(3130),
    [aux_sym_basic_type_token45] = ACTIONS(3130),
    [aux_sym_basic_type_token46] = ACTIONS(3130),
    [aux_sym_basic_type_token47] = ACTIONS(3130),
    [aux_sym_basic_type_token48] = ACTIONS(3130),
    [aux_sym_basic_type_token49] = ACTIONS(3130),
    [aux_sym_basic_type_token50] = ACTIONS(3130),
    [aux_sym_basic_type_token51] = ACTIONS(3130),
    [aux_sym_basic_type_token52] = ACTIONS(3130),
    [aux_sym_basic_type_token53] = ACTIONS(3130),
    [aux_sym_basic_type_token54] = ACTIONS(3130),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3122),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3122),
    [sym_query_keyword] = ACTIONS(3122),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3122),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3136),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1359)] = {
    [sym_type_specification] = STATE(12665),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1360)] = {
    [sym_type_specification] = STATE(2148),
    [sym_text_type] = STATE(2171),
    [sym_code_type] = STATE(2171),
    [sym_option_type] = STATE(2169),
    [sym_record_type] = STATE(2169),
    [sym_dotnet_type] = STATE(2169),
    [sym_object_reference_type] = STATE(2169),
    [sym_array_type] = STATE(2172),
    [sym_list_type] = STATE(2172),
    [sym_dictionary_type] = STATE(2172),
    [sym_basic_type] = STATE(2169),
    [sym_codeunit_keyword] = STATE(7924),
    [sym_xmlport_keyword] = STATE(7924),
    [sym_enum_keyword] = STATE(7924),
    [sym_controladdin_keyword] = STATE(7924),
    [sym_dotnet_keyword] = STATE(7752),
    [sym_identifier] = ACTIONS(3376),
    [aux_sym_text_type_token1] = ACTIONS(3378),
    [aux_sym_code_type_token1] = ACTIONS(3380),
    [aux_sym_option_type_token1] = ACTIONS(3382),
    [aux_sym_record_type_token1] = ACTIONS(3384),
    [aux_sym_object_reference_type_token1] = ACTIONS(3386),
    [aux_sym_object_reference_type_token2] = ACTIONS(3386),
    [aux_sym_array_type_token1] = ACTIONS(3388),
    [aux_sym_list_type_token1] = ACTIONS(3390),
    [aux_sym_dictionary_type_token1] = ACTIONS(3392),
    [aux_sym_basic_type_token1] = ACTIONS(3394),
    [aux_sym_basic_type_token2] = ACTIONS(3394),
    [aux_sym_basic_type_token3] = ACTIONS(3394),
    [aux_sym_basic_type_token4] = ACTIONS(3394),
    [aux_sym_basic_type_token5] = ACTIONS(3394),
    [aux_sym_basic_type_token6] = ACTIONS(3396),
    [aux_sym_basic_type_token7] = ACTIONS(3394),
    [aux_sym_basic_type_token8] = ACTIONS(3394),
    [aux_sym_basic_type_token9] = ACTIONS(3394),
    [aux_sym_basic_type_token10] = ACTIONS(3394),
    [aux_sym_basic_type_token11] = ACTIONS(3394),
    [aux_sym_basic_type_token12] = ACTIONS(3394),
    [aux_sym_basic_type_token13] = ACTIONS(3398),
    [aux_sym_basic_type_token14] = ACTIONS(3394),
    [aux_sym_basic_type_token15] = ACTIONS(3394),
    [aux_sym_basic_type_token16] = ACTIONS(3394),
    [aux_sym_basic_type_token17] = ACTIONS(3394),
    [aux_sym_basic_type_token18] = ACTIONS(3394),
    [aux_sym_basic_type_token19] = ACTIONS(3394),
    [aux_sym_basic_type_token20] = ACTIONS(3394),
    [aux_sym_basic_type_token21] = ACTIONS(3394),
    [aux_sym_basic_type_token22] = ACTIONS(3394),
    [aux_sym_basic_type_token23] = ACTIONS(3394),
    [aux_sym_basic_type_token24] = ACTIONS(3394),
    [aux_sym_basic_type_token25] = ACTIONS(3394),
    [aux_sym_basic_type_token26] = ACTIONS(3394),
    [aux_sym_basic_type_token27] = ACTIONS(3394),
    [aux_sym_basic_type_token28] = ACTIONS(3394),
    [aux_sym_basic_type_token29] = ACTIONS(3394),
    [aux_sym_basic_type_token30] = ACTIONS(3394),
    [aux_sym_basic_type_token31] = ACTIONS(3394),
    [aux_sym_basic_type_token32] = ACTIONS(3394),
    [aux_sym_basic_type_token33] = ACTIONS(3394),
    [aux_sym_basic_type_token34] = ACTIONS(3394),
    [aux_sym_basic_type_token35] = ACTIONS(3394),
    [aux_sym_basic_type_token36] = ACTIONS(3394),
    [aux_sym_basic_type_token37] = ACTIONS(3394),
    [aux_sym_basic_type_token38] = ACTIONS(3394),
    [aux_sym_basic_type_token39] = ACTIONS(3394),
    [aux_sym_basic_type_token40] = ACTIONS(3394),
    [aux_sym_basic_type_token41] = ACTIONS(3394),
    [aux_sym_basic_type_token42] = ACTIONS(3394),
    [aux_sym_basic_type_token43] = ACTIONS(3394),
    [aux_sym_basic_type_token44] = ACTIONS(3394),
    [aux_sym_basic_type_token45] = ACTIONS(3394),
    [aux_sym_basic_type_token46] = ACTIONS(3394),
    [aux_sym_basic_type_token47] = ACTIONS(3394),
    [aux_sym_basic_type_token48] = ACTIONS(3394),
    [aux_sym_basic_type_token49] = ACTIONS(3394),
    [aux_sym_basic_type_token50] = ACTIONS(3394),
    [aux_sym_basic_type_token51] = ACTIONS(3394),
    [aux_sym_basic_type_token52] = ACTIONS(3394),
    [aux_sym_basic_type_token53] = ACTIONS(3394),
    [aux_sym_basic_type_token54] = ACTIONS(3394),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3386),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3386),
    [sym_query_keyword] = ACTIONS(3386),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3386),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3400),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1361)] = {
    [sym_type_specification] = STATE(2149),
    [sym_text_type] = STATE(2171),
    [sym_code_type] = STATE(2171),
    [sym_option_type] = STATE(2169),
    [sym_record_type] = STATE(2169),
    [sym_dotnet_type] = STATE(2169),
    [sym_object_reference_type] = STATE(2169),
    [sym_array_type] = STATE(2172),
    [sym_list_type] = STATE(2172),
    [sym_dictionary_type] = STATE(2172),
    [sym_basic_type] = STATE(2169),
    [sym_codeunit_keyword] = STATE(7924),
    [sym_xmlport_keyword] = STATE(7924),
    [sym_enum_keyword] = STATE(7924),
    [sym_controladdin_keyword] = STATE(7924),
    [sym_dotnet_keyword] = STATE(7752),
    [sym_identifier] = ACTIONS(3376),
    [aux_sym_text_type_token1] = ACTIONS(3378),
    [aux_sym_code_type_token1] = ACTIONS(3380),
    [aux_sym_option_type_token1] = ACTIONS(3382),
    [aux_sym_record_type_token1] = ACTIONS(3384),
    [aux_sym_object_reference_type_token1] = ACTIONS(3386),
    [aux_sym_object_reference_type_token2] = ACTIONS(3386),
    [aux_sym_array_type_token1] = ACTIONS(3388),
    [aux_sym_list_type_token1] = ACTIONS(3390),
    [aux_sym_dictionary_type_token1] = ACTIONS(3392),
    [aux_sym_basic_type_token1] = ACTIONS(3394),
    [aux_sym_basic_type_token2] = ACTIONS(3394),
    [aux_sym_basic_type_token3] = ACTIONS(3394),
    [aux_sym_basic_type_token4] = ACTIONS(3394),
    [aux_sym_basic_type_token5] = ACTIONS(3394),
    [aux_sym_basic_type_token6] = ACTIONS(3396),
    [aux_sym_basic_type_token7] = ACTIONS(3394),
    [aux_sym_basic_type_token8] = ACTIONS(3394),
    [aux_sym_basic_type_token9] = ACTIONS(3394),
    [aux_sym_basic_type_token10] = ACTIONS(3394),
    [aux_sym_basic_type_token11] = ACTIONS(3394),
    [aux_sym_basic_type_token12] = ACTIONS(3394),
    [aux_sym_basic_type_token13] = ACTIONS(3398),
    [aux_sym_basic_type_token14] = ACTIONS(3394),
    [aux_sym_basic_type_token15] = ACTIONS(3394),
    [aux_sym_basic_type_token16] = ACTIONS(3394),
    [aux_sym_basic_type_token17] = ACTIONS(3394),
    [aux_sym_basic_type_token18] = ACTIONS(3394),
    [aux_sym_basic_type_token19] = ACTIONS(3394),
    [aux_sym_basic_type_token20] = ACTIONS(3394),
    [aux_sym_basic_type_token21] = ACTIONS(3394),
    [aux_sym_basic_type_token22] = ACTIONS(3394),
    [aux_sym_basic_type_token23] = ACTIONS(3394),
    [aux_sym_basic_type_token24] = ACTIONS(3394),
    [aux_sym_basic_type_token25] = ACTIONS(3394),
    [aux_sym_basic_type_token26] = ACTIONS(3394),
    [aux_sym_basic_type_token27] = ACTIONS(3394),
    [aux_sym_basic_type_token28] = ACTIONS(3394),
    [aux_sym_basic_type_token29] = ACTIONS(3394),
    [aux_sym_basic_type_token30] = ACTIONS(3394),
    [aux_sym_basic_type_token31] = ACTIONS(3394),
    [aux_sym_basic_type_token32] = ACTIONS(3394),
    [aux_sym_basic_type_token33] = ACTIONS(3394),
    [aux_sym_basic_type_token34] = ACTIONS(3394),
    [aux_sym_basic_type_token35] = ACTIONS(3394),
    [aux_sym_basic_type_token36] = ACTIONS(3394),
    [aux_sym_basic_type_token37] = ACTIONS(3394),
    [aux_sym_basic_type_token38] = ACTIONS(3394),
    [aux_sym_basic_type_token39] = ACTIONS(3394),
    [aux_sym_basic_type_token40] = ACTIONS(3394),
    [aux_sym_basic_type_token41] = ACTIONS(3394),
    [aux_sym_basic_type_token42] = ACTIONS(3394),
    [aux_sym_basic_type_token43] = ACTIONS(3394),
    [aux_sym_basic_type_token44] = ACTIONS(3394),
    [aux_sym_basic_type_token45] = ACTIONS(3394),
    [aux_sym_basic_type_token46] = ACTIONS(3394),
    [aux_sym_basic_type_token47] = ACTIONS(3394),
    [aux_sym_basic_type_token48] = ACTIONS(3394),
    [aux_sym_basic_type_token49] = ACTIONS(3394),
    [aux_sym_basic_type_token50] = ACTIONS(3394),
    [aux_sym_basic_type_token51] = ACTIONS(3394),
    [aux_sym_basic_type_token52] = ACTIONS(3394),
    [aux_sym_basic_type_token53] = ACTIONS(3394),
    [aux_sym_basic_type_token54] = ACTIONS(3394),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3386),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3386),
    [sym_query_keyword] = ACTIONS(3386),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3386),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3400),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1362)] = {
    [sym_type_specification] = STATE(4834),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8101),
    [sym_xmlport_keyword] = STATE(8101),
    [sym_enum_keyword] = STATE(8101),
    [sym_controladdin_keyword] = STATE(8101),
    [sym_dotnet_keyword] = STATE(7675),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3402),
    [aux_sym_record_type_token1] = ACTIONS(3404),
    [aux_sym_object_reference_type_token1] = ACTIONS(3406),
    [aux_sym_object_reference_type_token2] = ACTIONS(3406),
    [aux_sym_array_type_token1] = ACTIONS(3408),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3406),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3406),
    [sym_query_keyword] = ACTIONS(3406),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3406),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1363)] = {
    [sym_type_specification] = STATE(12557),
    [sym_text_type] = STATE(4819),
    [sym_code_type] = STATE(4819),
    [sym_option_type] = STATE(4842),
    [sym_record_type] = STATE(4842),
    [sym_dotnet_type] = STATE(4842),
    [sym_object_reference_type] = STATE(4842),
    [sym_array_type] = STATE(4823),
    [sym_list_type] = STATE(4823),
    [sym_dictionary_type] = STATE(4823),
    [sym_basic_type] = STATE(4842),
    [sym_codeunit_keyword] = STATE(8136),
    [sym_xmlport_keyword] = STATE(8136),
    [sym_enum_keyword] = STATE(8136),
    [sym_controladdin_keyword] = STATE(8136),
    [sym_dotnet_keyword] = STATE(7698),
    [sym_identifier] = ACTIONS(3024),
    [aux_sym_text_type_token1] = ACTIONS(3026),
    [aux_sym_code_type_token1] = ACTIONS(3028),
    [aux_sym_option_type_token1] = ACTIONS(3030),
    [aux_sym_record_type_token1] = ACTIONS(3032),
    [aux_sym_object_reference_type_token1] = ACTIONS(3034),
    [aux_sym_object_reference_type_token2] = ACTIONS(3034),
    [aux_sym_array_type_token1] = ACTIONS(3036),
    [aux_sym_list_type_token1] = ACTIONS(3038),
    [aux_sym_dictionary_type_token1] = ACTIONS(3040),
    [aux_sym_basic_type_token1] = ACTIONS(3042),
    [aux_sym_basic_type_token2] = ACTIONS(3042),
    [aux_sym_basic_type_token3] = ACTIONS(3042),
    [aux_sym_basic_type_token4] = ACTIONS(3042),
    [aux_sym_basic_type_token5] = ACTIONS(3042),
    [aux_sym_basic_type_token6] = ACTIONS(3044),
    [aux_sym_basic_type_token7] = ACTIONS(3042),
    [aux_sym_basic_type_token8] = ACTIONS(3042),
    [aux_sym_basic_type_token9] = ACTIONS(3042),
    [aux_sym_basic_type_token10] = ACTIONS(3042),
    [aux_sym_basic_type_token11] = ACTIONS(3042),
    [aux_sym_basic_type_token12] = ACTIONS(3042),
    [aux_sym_basic_type_token13] = ACTIONS(3046),
    [aux_sym_basic_type_token14] = ACTIONS(3042),
    [aux_sym_basic_type_token15] = ACTIONS(3042),
    [aux_sym_basic_type_token16] = ACTIONS(3042),
    [aux_sym_basic_type_token17] = ACTIONS(3042),
    [aux_sym_basic_type_token18] = ACTIONS(3042),
    [aux_sym_basic_type_token19] = ACTIONS(3042),
    [aux_sym_basic_type_token20] = ACTIONS(3042),
    [aux_sym_basic_type_token21] = ACTIONS(3042),
    [aux_sym_basic_type_token22] = ACTIONS(3042),
    [aux_sym_basic_type_token23] = ACTIONS(3042),
    [aux_sym_basic_type_token24] = ACTIONS(3042),
    [aux_sym_basic_type_token25] = ACTIONS(3042),
    [aux_sym_basic_type_token26] = ACTIONS(3042),
    [aux_sym_basic_type_token27] = ACTIONS(3042),
    [aux_sym_basic_type_token28] = ACTIONS(3042),
    [aux_sym_basic_type_token29] = ACTIONS(3042),
    [aux_sym_basic_type_token30] = ACTIONS(3042),
    [aux_sym_basic_type_token31] = ACTIONS(3042),
    [aux_sym_basic_type_token32] = ACTIONS(3042),
    [aux_sym_basic_type_token33] = ACTIONS(3042),
    [aux_sym_basic_type_token34] = ACTIONS(3042),
    [aux_sym_basic_type_token35] = ACTIONS(3042),
    [aux_sym_basic_type_token36] = ACTIONS(3042),
    [aux_sym_basic_type_token37] = ACTIONS(3042),
    [aux_sym_basic_type_token38] = ACTIONS(3042),
    [aux_sym_basic_type_token39] = ACTIONS(3042),
    [aux_sym_basic_type_token40] = ACTIONS(3042),
    [aux_sym_basic_type_token41] = ACTIONS(3042),
    [aux_sym_basic_type_token42] = ACTIONS(3042),
    [aux_sym_basic_type_token43] = ACTIONS(3042),
    [aux_sym_basic_type_token44] = ACTIONS(3042),
    [aux_sym_basic_type_token45] = ACTIONS(3042),
    [aux_sym_basic_type_token46] = ACTIONS(3042),
    [aux_sym_basic_type_token47] = ACTIONS(3042),
    [aux_sym_basic_type_token48] = ACTIONS(3042),
    [aux_sym_basic_type_token49] = ACTIONS(3042),
    [aux_sym_basic_type_token50] = ACTIONS(3042),
    [aux_sym_basic_type_token51] = ACTIONS(3042),
    [aux_sym_basic_type_token52] = ACTIONS(3042),
    [aux_sym_basic_type_token53] = ACTIONS(3042),
    [aux_sym_basic_type_token54] = ACTIONS(3042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3034),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3034),
    [sym_query_keyword] = ACTIONS(3034),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3034),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1364)] = {
    [sym_type_specification] = STATE(1529),
    [sym_text_type] = STATE(1508),
    [sym_code_type] = STATE(1508),
    [sym_option_type] = STATE(1507),
    [sym_record_type] = STATE(1507),
    [sym_dotnet_type] = STATE(1507),
    [sym_object_reference_type] = STATE(1507),
    [sym_array_type] = STATE(1509),
    [sym_list_type] = STATE(1509),
    [sym_dictionary_type] = STATE(1509),
    [sym_basic_type] = STATE(1507),
    [sym_codeunit_keyword] = STATE(7860),
    [sym_xmlport_keyword] = STATE(7860),
    [sym_enum_keyword] = STATE(7860),
    [sym_controladdin_keyword] = STATE(7860),
    [sym_dotnet_keyword] = STATE(7771),
    [sym_identifier] = ACTIONS(3298),
    [aux_sym_text_type_token1] = ACTIONS(3300),
    [aux_sym_code_type_token1] = ACTIONS(3302),
    [aux_sym_option_type_token1] = ACTIONS(3304),
    [aux_sym_record_type_token1] = ACTIONS(3306),
    [aux_sym_object_reference_type_token1] = ACTIONS(3308),
    [aux_sym_object_reference_type_token2] = ACTIONS(3308),
    [aux_sym_array_type_token1] = ACTIONS(3310),
    [aux_sym_list_type_token1] = ACTIONS(3312),
    [aux_sym_dictionary_type_token1] = ACTIONS(3314),
    [aux_sym_basic_type_token1] = ACTIONS(3316),
    [aux_sym_basic_type_token2] = ACTIONS(3316),
    [aux_sym_basic_type_token3] = ACTIONS(3316),
    [aux_sym_basic_type_token4] = ACTIONS(3316),
    [aux_sym_basic_type_token5] = ACTIONS(3316),
    [aux_sym_basic_type_token6] = ACTIONS(3318),
    [aux_sym_basic_type_token7] = ACTIONS(3316),
    [aux_sym_basic_type_token8] = ACTIONS(3316),
    [aux_sym_basic_type_token9] = ACTIONS(3316),
    [aux_sym_basic_type_token10] = ACTIONS(3316),
    [aux_sym_basic_type_token11] = ACTIONS(3316),
    [aux_sym_basic_type_token12] = ACTIONS(3316),
    [aux_sym_basic_type_token13] = ACTIONS(3320),
    [aux_sym_basic_type_token14] = ACTIONS(3316),
    [aux_sym_basic_type_token15] = ACTIONS(3316),
    [aux_sym_basic_type_token16] = ACTIONS(3316),
    [aux_sym_basic_type_token17] = ACTIONS(3316),
    [aux_sym_basic_type_token18] = ACTIONS(3316),
    [aux_sym_basic_type_token19] = ACTIONS(3316),
    [aux_sym_basic_type_token20] = ACTIONS(3316),
    [aux_sym_basic_type_token21] = ACTIONS(3316),
    [aux_sym_basic_type_token22] = ACTIONS(3316),
    [aux_sym_basic_type_token23] = ACTIONS(3316),
    [aux_sym_basic_type_token24] = ACTIONS(3316),
    [aux_sym_basic_type_token25] = ACTIONS(3316),
    [aux_sym_basic_type_token26] = ACTIONS(3316),
    [aux_sym_basic_type_token27] = ACTIONS(3316),
    [aux_sym_basic_type_token28] = ACTIONS(3316),
    [aux_sym_basic_type_token29] = ACTIONS(3316),
    [aux_sym_basic_type_token30] = ACTIONS(3316),
    [aux_sym_basic_type_token31] = ACTIONS(3316),
    [aux_sym_basic_type_token32] = ACTIONS(3316),
    [aux_sym_basic_type_token33] = ACTIONS(3316),
    [aux_sym_basic_type_token34] = ACTIONS(3316),
    [aux_sym_basic_type_token35] = ACTIONS(3316),
    [aux_sym_basic_type_token36] = ACTIONS(3316),
    [aux_sym_basic_type_token37] = ACTIONS(3316),
    [aux_sym_basic_type_token38] = ACTIONS(3316),
    [aux_sym_basic_type_token39] = ACTIONS(3316),
    [aux_sym_basic_type_token40] = ACTIONS(3316),
    [aux_sym_basic_type_token41] = ACTIONS(3316),
    [aux_sym_basic_type_token42] = ACTIONS(3316),
    [aux_sym_basic_type_token43] = ACTIONS(3316),
    [aux_sym_basic_type_token44] = ACTIONS(3316),
    [aux_sym_basic_type_token45] = ACTIONS(3316),
    [aux_sym_basic_type_token46] = ACTIONS(3316),
    [aux_sym_basic_type_token47] = ACTIONS(3316),
    [aux_sym_basic_type_token48] = ACTIONS(3316),
    [aux_sym_basic_type_token49] = ACTIONS(3316),
    [aux_sym_basic_type_token50] = ACTIONS(3316),
    [aux_sym_basic_type_token51] = ACTIONS(3316),
    [aux_sym_basic_type_token52] = ACTIONS(3316),
    [aux_sym_basic_type_token53] = ACTIONS(3316),
    [aux_sym_basic_type_token54] = ACTIONS(3316),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(3308),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3308),
    [sym_query_keyword] = ACTIONS(3308),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(3308),
    [anon_sym_controladdin] = ACTIONS(3048),
    [anon_sym_CONTROLADDIN] = ACTIONS(3048),
    [anon_sym_Controladdin] = ACTIONS(3048),
    [anon_sym_ControlAddIn] = ACTIONS(3048),
    [anon_sym_ControlAddin] = ACTIONS(3048),
    [anon_sym_controlAddIn] = ACTIONS(3048),
    [anon_sym_controlAddin] = ACTIONS(3048),
    [anon_sym_dotnet] = ACTIONS(3050),
    [anon_sym_DOTNET] = ACTIONS(3050),
    [anon_sym_Dotnet] = ACTIONS(3050),
    [anon_sym_DotNet] = ACTIONS(3050),
    [anon_sym_dotNet] = ACTIONS(3050),
    [sym_quoted_identifier] = ACTIONS(3322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(1365)] = {
    [sym_boolean] = STATE(1165),
    [sym_code_block] = STATE(2268),
    [sym_assignment_expression] = STATE(1165),
    [sym__expression] = STATE(1165),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1165),
    [sym_multiplicative_expression] = STATE(1165),
    [sym_additive_expression] = STATE(1165),
    [sym_comparison_expression] = STATE(1165),
    [sym_logical_expression] = STATE(1165),
    [sym_ternary_expression] = STATE(1165),
    [sym_unary_expression] = STATE(1165),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1165),
    [sym_list_literal] = STATE(1165),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1165),
    [sym__literal_value] = STATE(1165),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(2735),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(3410),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(844),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2739),
    [anon_sym_POUNDif] = ACTIONS(2735),
    [anon_sym_POUNDIF] = ACTIONS(2735),
    [anon_sym_POUNDIf] = ACTIONS(2735),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(3412),
    [sym_date_literal] = ACTIONS(3410),
    [sym_time_literal] = ACTIONS(3410),
    [sym_biginteger_literal] = ACTIONS(3412),
    [anon_sym_if] = ACTIONS(2739),
    [anon_sym_IF] = ACTIONS(2739),
    [anon_sym_If] = ACTIONS(2739),
    [anon_sym_else] = ACTIONS(2739),
    [anon_sym_ELSE] = ACTIONS(2739),
    [anon_sym_Else] = ACTIONS(2739),
    [anon_sym_case] = ACTIONS(2739),
    [anon_sym_CASE] = ACTIONS(2739),
    [anon_sym_Case] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2739),
    [anon_sym_FOR] = ACTIONS(2739),
    [anon_sym_For] = ACTIONS(2739),
    [anon_sym_foreach] = ACTIONS(2739),
    [anon_sym_FOREACH] = ACTIONS(2739),
    [anon_sym_Foreach] = ACTIONS(2739),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_WHILE] = ACTIONS(2739),
    [anon_sym_While] = ACTIONS(2739),
    [anon_sym_repeat] = ACTIONS(2739),
    [anon_sym_REPEAT] = ACTIONS(2739),
    [anon_sym_Repeat] = ACTIONS(2739),
    [anon_sym_exit] = ACTIONS(2739),
    [anon_sym_EXIT] = ACTIONS(2739),
    [anon_sym_Exit] = ACTIONS(2739),
    [anon_sym_continue] = ACTIONS(2739),
    [anon_sym_CONTINUE] = ACTIONS(2739),
    [anon_sym_Continue] = ACTIONS(2739),
    [anon_sym_break] = ACTIONS(2739),
    [anon_sym_BREAK] = ACTIONS(2739),
    [anon_sym_Break] = ACTIONS(2739),
    [anon_sym_with] = ACTIONS(2739),
    [anon_sym_WITH] = ACTIONS(2739),
    [anon_sym_With] = ACTIONS(2739),
    [sym_asserterror_keyword] = ACTIONS(2735),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3412),
    [sym_integer] = ACTIONS(3410),
    [sym_continue_as_identifier] = ACTIONS(3412),
    [sym_preproc_open] = ACTIONS(2735),
    [sym_begin_keyword] = ACTIONS(846),
    [sym_end_keyword] = ACTIONS(2735),
  },
  [STATE(1366)] = {
    [sym__body_element] = STATE(1378),
    [sym_empty_statement] = STATE(1378),
    [sym_property] = STATE(1378),
    [sym_fields_section] = STATE(1378),
    [sym_keys_section] = STATE(1378),
    [sym_fieldgroups_section] = STATE(1378),
    [sym_enum_value_declaration] = STATE(1378),
    [sym_labels_section] = STATE(1378),
    [sym_layout_section] = STATE(1378),
    [sym__layout_element] = STATE(1378),
    [sym_area_section] = STATE(1378),
    [sym_group_section] = STATE(1378),
    [sym_repeater_section] = STATE(1378),
    [sym_cuegroup_section] = STATE(1378),
    [sym_fixed_section] = STATE(1378),
    [sym_grid_section] = STATE(1378),
    [sym_page_field] = STATE(1378),
    [sym_part_section] = STATE(1378),
    [sym_systempart_section] = STATE(1378),
    [sym_usercontrol_section] = STATE(1378),
    [sym_preproc_split_field] = STATE(1378),
    [sym_label_section] = STATE(1378),
    [sym_addfirst_modification] = STATE(1378),
    [sym_addlast_modification] = STATE(1378),
    [sym_addafter_modification] = STATE(1378),
    [sym_addbefore_modification] = STATE(1378),
    [sym_modify_modification] = STATE(4059),
    [sym_movefirst_modification] = STATE(1378),
    [sym_movelast_modification] = STATE(1378),
    [sym_moveafter_modification] = STATE(1378),
    [sym_movebefore_modification] = STATE(1378),
    [sym_actions_section] = STATE(1378),
    [sym_views_section] = STATE(1378),
    [sym_dataset_section] = STATE(1378),
    [sym_requestpage_section] = STATE(1378),
    [sym_rendering_section] = STATE(1378),
    [sym_elements_section] = STATE(1378),
    [sym_schema_section] = STATE(1378),
    [sym_assembly_declaration] = STATE(1378),
    [sym_event_declaration] = STATE(1378),
    [sym_procedure] = STATE(1378),
    [sym_preproc_split_procedure] = STATE(1378),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(1378),
    [sym_var_section] = STATE(1378),
    [sym_attribute_item] = STATE(1378),
    [sym_preproc_conditional] = STATE(1378),
    [sym_preproc_if] = STATE(1250),
    [sym_preproc_elif] = STATE(1375),
    [sym_preproc_else] = STATE(1391),
    [sym_preproc_endif] = STATE(5035),
    [sym_preproc_conditional_layout] = STATE(1378),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(1378),
    [aux_sym_preproc_conditional_layout_mixed_repeat2] = STATE(8020),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_where_condition_token1] = ACTIONS(3414),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2849),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2851),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token6] = ACTIONS(2855),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(2859),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2861),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2865),
    [aux_sym_movelast_modification_token1] = ACTIONS(2867),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2869),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2871),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(2905),
    [sym_group_keyword] = ACTIONS(2907),
    [sym_repeater_keyword] = ACTIONS(2909),
    [sym_cuegroup_keyword] = ACTIONS(2911),
    [sym_fixed_keyword] = ACTIONS(2913),
    [sym_grid_keyword] = ACTIONS(2915),
    [sym_part_keyword] = ACTIONS(2917),
    [sym_systempart_keyword] = ACTIONS(2919),
    [sym_usercontrol_keyword] = ACTIONS(2921),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(1367)] = {
    [sym__body_element] = STATE(4061),
    [sym_empty_statement] = STATE(4061),
    [sym_property] = STATE(4061),
    [sym_fields_section] = STATE(4061),
    [sym_keys_section] = STATE(4061),
    [sym_fieldgroups_section] = STATE(4061),
    [sym_enum_value_declaration] = STATE(4061),
    [sym_labels_section] = STATE(4061),
    [sym_layout_section] = STATE(4061),
    [sym__layout_element] = STATE(4062),
    [sym_area_section] = STATE(4062),
    [sym_group_section] = STATE(4062),
    [sym_repeater_section] = STATE(4062),
    [sym_cuegroup_section] = STATE(4062),
    [sym_fixed_section] = STATE(4062),
    [sym_grid_section] = STATE(4062),
    [sym_page_field] = STATE(4062),
    [sym_part_section] = STATE(4062),
    [sym_systempart_section] = STATE(4062),
    [sym_usercontrol_section] = STATE(4062),
    [sym_preproc_split_field] = STATE(4062),
    [sym_label_section] = STATE(4062),
    [sym_addfirst_modification] = STATE(4062),
    [sym_addlast_modification] = STATE(4062),
    [sym_addafter_modification] = STATE(4062),
    [sym_addbefore_modification] = STATE(4062),
    [sym_modify_modification] = STATE(4059),
    [sym_movefirst_modification] = STATE(4062),
    [sym_movelast_modification] = STATE(4062),
    [sym_moveafter_modification] = STATE(4062),
    [sym_movebefore_modification] = STATE(4062),
    [sym_actions_section] = STATE(4061),
    [sym_views_section] = STATE(4061),
    [sym_dataset_section] = STATE(4061),
    [sym_requestpage_section] = STATE(4061),
    [sym_rendering_section] = STATE(4061),
    [sym_elements_section] = STATE(4061),
    [sym_schema_section] = STATE(4061),
    [sym_assembly_declaration] = STATE(4061),
    [sym_event_declaration] = STATE(4061),
    [sym_procedure] = STATE(4061),
    [sym_preproc_split_procedure] = STATE(4061),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(4061),
    [sym_var_section] = STATE(4061),
    [sym_attribute_item] = STATE(4061),
    [sym_preproc_conditional] = STATE(4061),
    [sym_preproc_if] = STATE(1250),
    [sym_preproc_conditional_layout] = STATE(4062),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3335),
    [aux_sym_layout_section_repeat1] = STATE(3890),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(1377),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_where_condition_token1] = ACTIONS(3414),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2849),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2851),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token6] = ACTIONS(2855),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(2859),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2861),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2865),
    [aux_sym_movelast_modification_token1] = ACTIONS(2867),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2869),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2871),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(3418),
    [anon_sym_POUNDELIF] = ACTIONS(3418),
    [anon_sym_POUNDElif] = ACTIONS(3418),
    [anon_sym_POUNDelse] = ACTIONS(3418),
    [anon_sym_POUNDELSE] = ACTIONS(3418),
    [anon_sym_POUNDElse] = ACTIONS(3418),
    [anon_sym_POUNDendif] = ACTIONS(3418),
    [anon_sym_POUNDENDIF] = ACTIONS(3418),
    [anon_sym_POUNDEndif] = ACTIONS(3418),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(2905),
    [sym_group_keyword] = ACTIONS(2907),
    [sym_repeater_keyword] = ACTIONS(2909),
    [sym_cuegroup_keyword] = ACTIONS(2911),
    [sym_fixed_keyword] = ACTIONS(2913),
    [sym_grid_keyword] = ACTIONS(2915),
    [sym_part_keyword] = ACTIONS(2917),
    [sym_systempart_keyword] = ACTIONS(2919),
    [sym_usercontrol_keyword] = ACTIONS(2921),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(3418),
  },
  [STATE(1368)] = {
    [aux_sym_option_member_list_repeat2] = STATE(1368),
    [sym_identifier] = ACTIONS(565),
    [anon_sym_SEMI] = ACTIONS(567),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_EQ] = ACTIONS(567),
    [anon_sym_COMMA] = ACTIONS(3422),
    [anon_sym_COLON] = ACTIONS(565),
    [anon_sym_DASH] = ACTIONS(565),
    [aux_sym_boolean_token1] = ACTIONS(565),
    [aux_sym_boolean_token2] = ACTIONS(565),
    [sym_decimal] = ACTIONS(565),
    [anon_sym_LPAREN] = ACTIONS(567),
    [aux_sym_where_condition_token1] = ACTIONS(565),
    [anon_sym_DOT_DOT] = ACTIONS(567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(565),
    [anon_sym_STAR] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [aux_sym_record_type_token1] = ACTIONS(565),
    [aux_sym_basic_type_token21] = ACTIONS(565),
    [aux_sym_basic_type_token22] = ACTIONS(565),
    [aux_sym_basic_type_token48] = ACTIONS(565),
    [aux_sym_basic_type_token53] = ACTIONS(565),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(565),
    [aux_sym_separator_action_token1] = ACTIONS(565),
    [aux_sym_type_declaration_token1] = ACTIONS(565),
    [anon_sym_POUNDif] = ACTIONS(567),
    [anon_sym_POUNDIF] = ACTIONS(567),
    [anon_sym_POUNDIf] = ACTIONS(567),
    [anon_sym_not] = ACTIONS(565),
    [anon_sym_NOT] = ACTIONS(565),
    [anon_sym_Not] = ACTIONS(565),
    [anon_sym_POUNDelif] = ACTIONS(567),
    [anon_sym_POUNDELIF] = ACTIONS(567),
    [anon_sym_POUNDElif] = ACTIONS(567),
    [anon_sym_POUNDelse] = ACTIONS(567),
    [anon_sym_POUNDELSE] = ACTIONS(567),
    [anon_sym_POUNDElse] = ACTIONS(567),
    [anon_sym_POUNDendif] = ACTIONS(567),
    [anon_sym_POUNDENDIF] = ACTIONS(567),
    [anon_sym_POUNDEndif] = ACTIONS(567),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(567),
    [aux_sym__expression_token1] = ACTIONS(567),
    [aux_sym__expression_token2] = ACTIONS(567),
    [aux_sym_keyword_identifier_token1] = ACTIONS(565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(565),
    [anon_sym_SLASH] = ACTIONS(565),
    [anon_sym_div] = ACTIONS(565),
    [anon_sym_DIV] = ACTIONS(565),
    [anon_sym_Div] = ACTIONS(565),
    [anon_sym_mod] = ACTIONS(565),
    [anon_sym_MOD] = ACTIONS(565),
    [anon_sym_Mod] = ACTIONS(565),
    [anon_sym_PLUS] = ACTIONS(565),
    [anon_sym_GT_EQ] = ACTIONS(567),
    [anon_sym_LT_EQ] = ACTIONS(567),
    [anon_sym_GT] = ACTIONS(565),
    [anon_sym_LT] = ACTIONS(565),
    [anon_sym_LT_GT] = ACTIONS(567),
    [anon_sym_and] = ACTIONS(565),
    [anon_sym_AND] = ACTIONS(565),
    [anon_sym_And] = ACTIONS(565),
    [anon_sym_or] = ACTIONS(565),
    [anon_sym_OR] = ACTIONS(565),
    [anon_sym_Or] = ACTIONS(565),
    [anon_sym_xor] = ACTIONS(565),
    [anon_sym_XOR] = ACTIONS(565),
    [anon_sym_Xor] = ACTIONS(565),
    [anon_sym_QMARK] = ACTIONS(567),
    [sym_datetime_literal] = ACTIONS(567),
    [sym_date_literal] = ACTIONS(565),
    [sym_time_literal] = ACTIONS(565),
    [sym_biginteger_literal] = ACTIONS(567),
    [anon_sym_else] = ACTIONS(565),
    [anon_sym_ELSE] = ACTIONS(565),
    [anon_sym_Else] = ACTIONS(565),
    [anon_sym_in] = ACTIONS(565),
    [anon_sym_IN] = ACTIONS(565),
    [anon_sym_In] = ACTIONS(565),
    [sym_page_keyword] = ACTIONS(565),
    [anon_sym_codeunit] = ACTIONS(565),
    [anon_sym_CODEUNIT] = ACTIONS(565),
    [anon_sym_Codeunit] = ACTIONS(565),
    [anon_sym_CodeUnit] = ACTIONS(565),
    [anon_sym_COdeunit] = ACTIONS(565),
    [anon_sym_codeUnit] = ACTIONS(565),
    [sym_report_keyword] = ACTIONS(565),
    [sym_query_keyword] = ACTIONS(565),
    [anon_sym_xmlport] = ACTIONS(565),
    [anon_sym_XMLPORT] = ACTIONS(565),
    [anon_sym_Xmlport] = ACTIONS(565),
    [anon_sym_XMLport] = ACTIONS(565),
    [anon_sym_XMLPort] = ACTIONS(565),
    [anon_sym_XmlPort] = ACTIONS(565),
    [anon_sym_enum] = ACTIONS(565),
    [anon_sym_ENUM] = ACTIONS(565),
    [anon_sym_Enum] = ACTIONS(565),
    [anon_sym_eNUM] = ACTIONS(565),
    [anon_sym_eNum] = ACTIONS(565),
    [anon_sym_ENum] = ACTIONS(565),
    [sym_local_keyword] = ACTIONS(565),
    [sym_internal_keyword] = ACTIONS(565),
    [sym_protected_keyword] = ACTIONS(565),
    [sym_key_keyword] = ACTIONS(565),
    [sym_dataset_keyword] = ACTIONS(565),
    [sym_quoted_identifier] = ACTIONS(567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(567),
    [sym_integer] = ACTIONS(565),
    [sym_continue_as_identifier] = ACTIONS(567),
    [sym_preproc_open] = ACTIONS(567),
    [sym_preproc_close] = ACTIONS(567),
  },
  [STATE(1369)] = {
    [sym_boolean] = STATE(2179),
    [sym_option_member_list] = STATE(2214),
    [sym_option_member] = STATE(2101),
    [sym_keyword_identifier] = STATE(2179),
    [sym_codeunit_keyword] = STATE(2098),
    [sym_xmlport_keyword] = STATE(2098),
    [sym_enum_keyword] = STATE(2098),
    [sym_keyword_as_identifier] = STATE(2179),
    [aux_sym_option_member_list_repeat2] = STATE(1376),
    [sym_identifier] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(275),
    [anon_sym_DOT] = ACTIONS(277),
    [anon_sym_EQ] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(3429),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(275),
    [aux_sym_where_condition_token1] = ACTIONS(3431),
    [anon_sym_DOT_DOT] = ACTIONS(275),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(275),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(3433),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_basic_type_token53] = ACTIONS(3431),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3431),
    [aux_sym_separator_action_token1] = ACTIONS(3431),
    [aux_sym_type_declaration_token1] = ACTIONS(3431),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(277),
    [anon_sym_POUNDif] = ACTIONS(275),
    [anon_sym_POUNDIF] = ACTIONS(275),
    [anon_sym_POUNDIf] = ACTIONS(275),
    [anon_sym_not] = ACTIONS(277),
    [anon_sym_NOT] = ACTIONS(277),
    [anon_sym_Not] = ACTIONS(277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(275),
    [aux_sym__expression_token1] = ACTIONS(275),
    [aux_sym__expression_token2] = ACTIONS(275),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(612),
    [anon_sym_SLASH] = ACTIONS(277),
    [anon_sym_div] = ACTIONS(277),
    [anon_sym_DIV] = ACTIONS(277),
    [anon_sym_Div] = ACTIONS(277),
    [anon_sym_mod] = ACTIONS(277),
    [anon_sym_MOD] = ACTIONS(277),
    [anon_sym_Mod] = ACTIONS(277),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(275),
    [anon_sym_LT_EQ] = ACTIONS(275),
    [anon_sym_GT] = ACTIONS(277),
    [anon_sym_LT] = ACTIONS(277),
    [anon_sym_LT_GT] = ACTIONS(275),
    [anon_sym_and] = ACTIONS(277),
    [anon_sym_AND] = ACTIONS(277),
    [anon_sym_And] = ACTIONS(277),
    [anon_sym_or] = ACTIONS(277),
    [anon_sym_OR] = ACTIONS(277),
    [anon_sym_Or] = ACTIONS(277),
    [anon_sym_xor] = ACTIONS(277),
    [anon_sym_XOR] = ACTIONS(277),
    [anon_sym_Xor] = ACTIONS(277),
    [anon_sym_QMARK] = ACTIONS(275),
    [sym_datetime_literal] = ACTIONS(275),
    [sym_date_literal] = ACTIONS(277),
    [sym_time_literal] = ACTIONS(277),
    [sym_biginteger_literal] = ACTIONS(275),
    [anon_sym_else] = ACTIONS(277),
    [anon_sym_ELSE] = ACTIONS(277),
    [anon_sym_Else] = ACTIONS(277),
    [anon_sym_in] = ACTIONS(277),
    [anon_sym_IN] = ACTIONS(277),
    [anon_sym_In] = ACTIONS(277),
    [sym_page_keyword] = ACTIONS(612),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(612),
    [sym_query_keyword] = ACTIONS(612),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_local_keyword] = ACTIONS(3425),
    [sym_internal_keyword] = ACTIONS(3425),
    [sym_protected_keyword] = ACTIONS(3425),
    [sym_key_keyword] = ACTIONS(3431),
    [sym_dataset_keyword] = ACTIONS(3431),
    [sym_quoted_identifier] = ACTIONS(3435),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3435),
    [sym_integer] = ACTIONS(3425),
    [sym_continue_as_identifier] = ACTIONS(275),
    [sym_preproc_open] = ACTIONS(275),
  },
  [STATE(1370)] = {
    [sym_boolean] = STATE(6346),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(7737),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym_preproc_conditional_permissions] = STATE(5962),
    [sym_tabledata_permission] = STATE(6826),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1370),
    [sym_preproc_elif] = STATE(1382),
    [sym_preproc_else] = STATE(1504),
    [sym_preproc_endif] = STATE(6834),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4852),
    [sym_xmlport_keyword] = STATE(4852),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7706),
    [sym_keyword_as_identifier] = STATE(7706),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(8172),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(5962),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(8173),
    [sym_identifier] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token1] = ACTIONS(3064),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3066),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDelif] = ACTIONS(3072),
    [anon_sym_POUNDELIF] = ACTIONS(3072),
    [anon_sym_POUNDElif] = ACTIONS(3072),
    [anon_sym_POUNDelse] = ACTIONS(3074),
    [anon_sym_POUNDELSE] = ACTIONS(3074),
    [anon_sym_POUNDElse] = ACTIONS(3074),
    [anon_sym_POUNDendif] = ACTIONS(3439),
    [anon_sym_POUNDENDIF] = ACTIONS(3439),
    [anon_sym_POUNDEndif] = ACTIONS(3439),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_table_keyword] = ACTIONS(3064),
    [sym_page_keyword] = ACTIONS(3080),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3080),
    [sym_query_keyword] = ACTIONS(3080),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(3439),
  },
  [STATE(1371)] = {
    [sym__body_element] = STATE(3335),
    [sym_empty_statement] = STATE(3335),
    [sym_property] = STATE(3335),
    [sym_fields_section] = STATE(3335),
    [sym_keys_section] = STATE(3335),
    [sym_fieldgroups_section] = STATE(3335),
    [sym_enum_value_declaration] = STATE(3335),
    [sym_labels_section] = STATE(3335),
    [sym_layout_section] = STATE(3335),
    [sym__layout_element] = STATE(3890),
    [sym_area_section] = STATE(3890),
    [sym_group_section] = STATE(3890),
    [sym_repeater_section] = STATE(3890),
    [sym_cuegroup_section] = STATE(3890),
    [sym_fixed_section] = STATE(3890),
    [sym_grid_section] = STATE(3890),
    [sym_page_field] = STATE(3890),
    [sym_part_section] = STATE(3890),
    [sym_systempart_section] = STATE(3890),
    [sym_usercontrol_section] = STATE(3890),
    [sym_preproc_split_field] = STATE(3890),
    [sym_label_section] = STATE(3890),
    [sym_addfirst_modification] = STATE(3890),
    [sym_addlast_modification] = STATE(3890),
    [sym_addafter_modification] = STATE(3890),
    [sym_addbefore_modification] = STATE(3890),
    [sym_modify_modification] = STATE(4501),
    [sym_movefirst_modification] = STATE(3890),
    [sym_movelast_modification] = STATE(3890),
    [sym_moveafter_modification] = STATE(3890),
    [sym_movebefore_modification] = STATE(3890),
    [sym_actions_section] = STATE(3335),
    [sym_views_section] = STATE(3335),
    [sym_dataset_section] = STATE(3335),
    [sym_requestpage_section] = STATE(3335),
    [sym_rendering_section] = STATE(3335),
    [sym_elements_section] = STATE(3335),
    [sym_schema_section] = STATE(3335),
    [sym_assembly_declaration] = STATE(3335),
    [sym_event_declaration] = STATE(3335),
    [sym_procedure] = STATE(3335),
    [sym_preproc_split_procedure] = STATE(3335),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3335),
    [sym_var_section] = STATE(3335),
    [sym_attribute_item] = STATE(3335),
    [sym_preproc_conditional] = STATE(3335),
    [sym_preproc_if] = STATE(1249),
    [sym_preproc_conditional_layout] = STATE(3890),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3335),
    [aux_sym_layout_section_repeat1] = STATE(3890),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_where_condition_token1] = ACTIONS(3443),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token6] = ACTIONS(2963),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(3445),
    [anon_sym_POUNDELIF] = ACTIONS(3445),
    [anon_sym_POUNDElif] = ACTIONS(3445),
    [anon_sym_POUNDelse] = ACTIONS(3445),
    [anon_sym_POUNDELSE] = ACTIONS(3445),
    [anon_sym_POUNDElse] = ACTIONS(3445),
    [anon_sym_POUNDendif] = ACTIONS(3445),
    [anon_sym_POUNDENDIF] = ACTIONS(3445),
    [anon_sym_POUNDEndif] = ACTIONS(3445),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(3445),
  },
  [STATE(1372)] = {
    [sym_boolean] = STATE(2155),
    [sym_option_member_list] = STATE(2182),
    [sym_option_member] = STATE(2110),
    [sym_keyword_identifier] = STATE(2155),
    [sym_codeunit_keyword] = STATE(2124),
    [sym_xmlport_keyword] = STATE(2124),
    [sym_enum_keyword] = STATE(2124),
    [sym_keyword_as_identifier] = STATE(2155),
    [aux_sym_option_member_list_repeat2] = STATE(1373),
    [sym_identifier] = ACTIONS(3448),
    [anon_sym_DOT] = ACTIONS(277),
    [anon_sym_EQ] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(3450),
    [anon_sym_DASH] = ACTIONS(3452),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(275),
    [aux_sym_where_condition_token1] = ACTIONS(3456),
    [anon_sym_DOT_DOT] = ACTIONS(275),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(275),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3460),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [aux_sym_basic_type_token53] = ACTIONS(3456),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3456),
    [aux_sym_separator_action_token1] = ACTIONS(3456),
    [aux_sym_type_declaration_token1] = ACTIONS(3456),
    [anon_sym_not] = ACTIONS(277),
    [anon_sym_NOT] = ACTIONS(277),
    [anon_sym_Not] = ACTIONS(277),
    [anon_sym_POUNDelif] = ACTIONS(275),
    [anon_sym_POUNDELIF] = ACTIONS(275),
    [anon_sym_POUNDElif] = ACTIONS(275),
    [anon_sym_POUNDelse] = ACTIONS(275),
    [anon_sym_POUNDELSE] = ACTIONS(275),
    [anon_sym_POUNDElse] = ACTIONS(275),
    [anon_sym_POUNDendif] = ACTIONS(275),
    [anon_sym_POUNDENDIF] = ACTIONS(275),
    [anon_sym_POUNDEndif] = ACTIONS(275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(275),
    [aux_sym__expression_token1] = ACTIONS(275),
    [aux_sym__expression_token2] = ACTIONS(275),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3458),
    [anon_sym_SLASH] = ACTIONS(277),
    [anon_sym_div] = ACTIONS(277),
    [anon_sym_DIV] = ACTIONS(277),
    [anon_sym_Div] = ACTIONS(277),
    [anon_sym_mod] = ACTIONS(277),
    [anon_sym_MOD] = ACTIONS(277),
    [anon_sym_Mod] = ACTIONS(277),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(275),
    [anon_sym_LT_EQ] = ACTIONS(275),
    [anon_sym_GT] = ACTIONS(277),
    [anon_sym_LT] = ACTIONS(277),
    [anon_sym_LT_GT] = ACTIONS(275),
    [anon_sym_and] = ACTIONS(277),
    [anon_sym_AND] = ACTIONS(277),
    [anon_sym_And] = ACTIONS(277),
    [anon_sym_or] = ACTIONS(277),
    [anon_sym_OR] = ACTIONS(277),
    [anon_sym_Or] = ACTIONS(277),
    [anon_sym_xor] = ACTIONS(277),
    [anon_sym_XOR] = ACTIONS(277),
    [anon_sym_Xor] = ACTIONS(277),
    [anon_sym_QMARK] = ACTIONS(275),
    [sym_datetime_literal] = ACTIONS(275),
    [sym_date_literal] = ACTIONS(277),
    [sym_time_literal] = ACTIONS(277),
    [sym_biginteger_literal] = ACTIONS(275),
    [anon_sym_in] = ACTIONS(277),
    [anon_sym_IN] = ACTIONS(277),
    [anon_sym_In] = ACTIONS(277),
    [sym_page_keyword] = ACTIONS(3458),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(3458),
    [sym_query_keyword] = ACTIONS(3458),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_local_keyword] = ACTIONS(3448),
    [sym_internal_keyword] = ACTIONS(3448),
    [sym_protected_keyword] = ACTIONS(3448),
    [sym_key_keyword] = ACTIONS(3456),
    [sym_dataset_keyword] = ACTIONS(3456),
    [sym_quoted_identifier] = ACTIONS(3468),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3468),
    [sym_integer] = ACTIONS(3448),
    [sym_continue_as_identifier] = ACTIONS(275),
    [sym_preproc_close] = ACTIONS(275),
  },
  [STATE(1373)] = {
    [sym_boolean] = STATE(2155),
    [sym_option_member] = STATE(2127),
    [sym_keyword_identifier] = STATE(2155),
    [sym_codeunit_keyword] = STATE(2124),
    [sym_xmlport_keyword] = STATE(2124),
    [sym_enum_keyword] = STATE(2124),
    [sym_keyword_as_identifier] = STATE(2155),
    [aux_sym_option_member_list_repeat2] = STATE(1428),
    [sym_identifier] = ACTIONS(3448),
    [anon_sym_DOT] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(3470),
    [anon_sym_DASH] = ACTIONS(3452),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(376),
    [anon_sym_LPAREN] = ACTIONS(374),
    [aux_sym_where_condition_token1] = ACTIONS(3456),
    [anon_sym_DOT_DOT] = ACTIONS(374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3460),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [aux_sym_basic_type_token53] = ACTIONS(3456),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3456),
    [aux_sym_separator_action_token1] = ACTIONS(3456),
    [aux_sym_type_declaration_token1] = ACTIONS(3456),
    [anon_sym_not] = ACTIONS(376),
    [anon_sym_NOT] = ACTIONS(376),
    [anon_sym_Not] = ACTIONS(376),
    [anon_sym_POUNDelif] = ACTIONS(374),
    [anon_sym_POUNDELIF] = ACTIONS(374),
    [anon_sym_POUNDElif] = ACTIONS(374),
    [anon_sym_POUNDelse] = ACTIONS(374),
    [anon_sym_POUNDELSE] = ACTIONS(374),
    [anon_sym_POUNDElse] = ACTIONS(374),
    [anon_sym_POUNDendif] = ACTIONS(374),
    [anon_sym_POUNDENDIF] = ACTIONS(374),
    [anon_sym_POUNDEndif] = ACTIONS(374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(374),
    [aux_sym__expression_token1] = ACTIONS(374),
    [aux_sym__expression_token2] = ACTIONS(374),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3458),
    [anon_sym_SLASH] = ACTIONS(376),
    [anon_sym_div] = ACTIONS(376),
    [anon_sym_DIV] = ACTIONS(376),
    [anon_sym_Div] = ACTIONS(376),
    [anon_sym_mod] = ACTIONS(376),
    [anon_sym_MOD] = ACTIONS(376),
    [anon_sym_Mod] = ACTIONS(376),
    [anon_sym_PLUS] = ACTIONS(376),
    [anon_sym_GT_EQ] = ACTIONS(374),
    [anon_sym_LT_EQ] = ACTIONS(374),
    [anon_sym_GT] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(376),
    [anon_sym_LT_GT] = ACTIONS(374),
    [anon_sym_and] = ACTIONS(376),
    [anon_sym_AND] = ACTIONS(376),
    [anon_sym_And] = ACTIONS(376),
    [anon_sym_or] = ACTIONS(376),
    [anon_sym_OR] = ACTIONS(376),
    [anon_sym_Or] = ACTIONS(376),
    [anon_sym_xor] = ACTIONS(376),
    [anon_sym_XOR] = ACTIONS(376),
    [anon_sym_Xor] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(374),
    [sym_datetime_literal] = ACTIONS(374),
    [sym_date_literal] = ACTIONS(376),
    [sym_time_literal] = ACTIONS(376),
    [sym_biginteger_literal] = ACTIONS(374),
    [anon_sym_in] = ACTIONS(376),
    [anon_sym_IN] = ACTIONS(376),
    [anon_sym_In] = ACTIONS(376),
    [sym_page_keyword] = ACTIONS(3458),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(3458),
    [sym_query_keyword] = ACTIONS(3458),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_local_keyword] = ACTIONS(3448),
    [sym_internal_keyword] = ACTIONS(3448),
    [sym_protected_keyword] = ACTIONS(3448),
    [sym_key_keyword] = ACTIONS(3456),
    [sym_dataset_keyword] = ACTIONS(3456),
    [sym_quoted_identifier] = ACTIONS(3468),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3468),
    [sym_integer] = ACTIONS(3448),
    [sym_continue_as_identifier] = ACTIONS(374),
    [sym_preproc_close] = ACTIONS(374),
  },
  [STATE(1374)] = {
    [sym_boolean] = STATE(6346),
    [sym_link_value] = STATE(7327),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(8837),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym_preproc_conditional_permissions] = STATE(6271),
    [sym_tabledata_permission] = STATE(6826),
    [sym_implementation_value] = STATE(7268),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1370),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4852),
    [sym_xmlport_keyword] = STATE(4852),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7711),
    [sym_keyword_as_identifier] = STATE(7711),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(7215),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(6271),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(7216),
    [sym_identifier] = ACTIONS(3054),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token1] = ACTIONS(3064),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3066),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDelif] = ACTIONS(3472),
    [anon_sym_POUNDELIF] = ACTIONS(3472),
    [anon_sym_POUNDElif] = ACTIONS(3472),
    [anon_sym_POUNDelse] = ACTIONS(3472),
    [anon_sym_POUNDELSE] = ACTIONS(3472),
    [anon_sym_POUNDElse] = ACTIONS(3472),
    [anon_sym_POUNDendif] = ACTIONS(3472),
    [anon_sym_POUNDENDIF] = ACTIONS(3472),
    [anon_sym_POUNDEndif] = ACTIONS(3472),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_table_keyword] = ACTIONS(3064),
    [sym_page_keyword] = ACTIONS(3080),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3080),
    [sym_query_keyword] = ACTIONS(3080),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3082),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(3472),
  },
  [STATE(1375)] = {
    [sym__body_element] = STATE(1377),
    [sym_empty_statement] = STATE(1377),
    [sym_property] = STATE(1377),
    [sym_fields_section] = STATE(1377),
    [sym_keys_section] = STATE(1377),
    [sym_fieldgroups_section] = STATE(1377),
    [sym_enum_value_declaration] = STATE(1377),
    [sym_labels_section] = STATE(1377),
    [sym_layout_section] = STATE(1377),
    [sym__layout_element] = STATE(1377),
    [sym_area_section] = STATE(1377),
    [sym_group_section] = STATE(1377),
    [sym_repeater_section] = STATE(1377),
    [sym_cuegroup_section] = STATE(1377),
    [sym_fixed_section] = STATE(1377),
    [sym_grid_section] = STATE(1377),
    [sym_page_field] = STATE(1377),
    [sym_part_section] = STATE(1377),
    [sym_systempart_section] = STATE(1377),
    [sym_usercontrol_section] = STATE(1377),
    [sym_preproc_split_field] = STATE(1377),
    [sym_label_section] = STATE(1377),
    [sym_addfirst_modification] = STATE(1377),
    [sym_addlast_modification] = STATE(1377),
    [sym_addafter_modification] = STATE(1377),
    [sym_addbefore_modification] = STATE(1377),
    [sym_modify_modification] = STATE(4059),
    [sym_movefirst_modification] = STATE(1377),
    [sym_movelast_modification] = STATE(1377),
    [sym_moveafter_modification] = STATE(1377),
    [sym_movebefore_modification] = STATE(1377),
    [sym_actions_section] = STATE(1377),
    [sym_views_section] = STATE(1377),
    [sym_dataset_section] = STATE(1377),
    [sym_requestpage_section] = STATE(1377),
    [sym_rendering_section] = STATE(1377),
    [sym_elements_section] = STATE(1377),
    [sym_schema_section] = STATE(1377),
    [sym_assembly_declaration] = STATE(1377),
    [sym_event_declaration] = STATE(1377),
    [sym_procedure] = STATE(1377),
    [sym_preproc_split_procedure] = STATE(1377),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(1377),
    [sym_var_section] = STATE(1377),
    [sym_attribute_item] = STATE(1377),
    [sym_preproc_conditional] = STATE(1377),
    [sym_preproc_if] = STATE(1250),
    [sym_preproc_conditional_layout] = STATE(1377),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(1377),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_where_condition_token1] = ACTIONS(3414),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2849),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2851),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token6] = ACTIONS(2855),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(2859),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2861),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2865),
    [aux_sym_movelast_modification_token1] = ACTIONS(2867),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2869),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2871),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(3477),
    [anon_sym_POUNDELIF] = ACTIONS(3477),
    [anon_sym_POUNDElif] = ACTIONS(3477),
    [anon_sym_POUNDelse] = ACTIONS(3477),
    [anon_sym_POUNDELSE] = ACTIONS(3477),
    [anon_sym_POUNDElse] = ACTIONS(3477),
    [anon_sym_POUNDendif] = ACTIONS(3477),
    [anon_sym_POUNDENDIF] = ACTIONS(3477),
    [anon_sym_POUNDEndif] = ACTIONS(3477),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(2905),
    [sym_group_keyword] = ACTIONS(2907),
    [sym_repeater_keyword] = ACTIONS(2909),
    [sym_cuegroup_keyword] = ACTIONS(2911),
    [sym_fixed_keyword] = ACTIONS(2913),
    [sym_grid_keyword] = ACTIONS(2915),
    [sym_part_keyword] = ACTIONS(2917),
    [sym_systempart_keyword] = ACTIONS(2919),
    [sym_usercontrol_keyword] = ACTIONS(2921),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(3477),
  },
  [STATE(1376)] = {
    [sym_boolean] = STATE(2179),
    [sym_option_member] = STATE(2113),
    [sym_keyword_identifier] = STATE(2179),
    [sym_codeunit_keyword] = STATE(2098),
    [sym_xmlport_keyword] = STATE(2098),
    [sym_enum_keyword] = STATE(2098),
    [sym_keyword_as_identifier] = STATE(2179),
    [aux_sym_option_member_list_repeat2] = STATE(1424),
    [sym_identifier] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(3479),
    [anon_sym_COLON] = ACTIONS(376),
    [anon_sym_DASH] = ACTIONS(3429),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(376),
    [anon_sym_LPAREN] = ACTIONS(374),
    [aux_sym_where_condition_token1] = ACTIONS(3431),
    [anon_sym_DOT_DOT] = ACTIONS(374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(3433),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_basic_type_token53] = ACTIONS(3431),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3431),
    [aux_sym_separator_action_token1] = ACTIONS(3431),
    [aux_sym_type_declaration_token1] = ACTIONS(3431),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(376),
    [anon_sym_POUNDif] = ACTIONS(374),
    [anon_sym_POUNDIF] = ACTIONS(374),
    [anon_sym_POUNDIf] = ACTIONS(374),
    [anon_sym_not] = ACTIONS(376),
    [anon_sym_NOT] = ACTIONS(376),
    [anon_sym_Not] = ACTIONS(376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(374),
    [aux_sym__expression_token1] = ACTIONS(374),
    [aux_sym__expression_token2] = ACTIONS(374),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(612),
    [anon_sym_SLASH] = ACTIONS(376),
    [anon_sym_div] = ACTIONS(376),
    [anon_sym_DIV] = ACTIONS(376),
    [anon_sym_Div] = ACTIONS(376),
    [anon_sym_mod] = ACTIONS(376),
    [anon_sym_MOD] = ACTIONS(376),
    [anon_sym_Mod] = ACTIONS(376),
    [anon_sym_PLUS] = ACTIONS(376),
    [anon_sym_GT_EQ] = ACTIONS(374),
    [anon_sym_LT_EQ] = ACTIONS(374),
    [anon_sym_GT] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(376),
    [anon_sym_LT_GT] = ACTIONS(374),
    [anon_sym_and] = ACTIONS(376),
    [anon_sym_AND] = ACTIONS(376),
    [anon_sym_And] = ACTIONS(376),
    [anon_sym_or] = ACTIONS(376),
    [anon_sym_OR] = ACTIONS(376),
    [anon_sym_Or] = ACTIONS(376),
    [anon_sym_xor] = ACTIONS(376),
    [anon_sym_XOR] = ACTIONS(376),
    [anon_sym_Xor] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(374),
    [sym_datetime_literal] = ACTIONS(374),
    [sym_date_literal] = ACTIONS(376),
    [sym_time_literal] = ACTIONS(376),
    [sym_biginteger_literal] = ACTIONS(374),
    [anon_sym_else] = ACTIONS(376),
    [anon_sym_ELSE] = ACTIONS(376),
    [anon_sym_Else] = ACTIONS(376),
    [anon_sym_in] = ACTIONS(376),
    [anon_sym_IN] = ACTIONS(376),
    [anon_sym_In] = ACTIONS(376),
    [sym_page_keyword] = ACTIONS(612),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(612),
    [sym_query_keyword] = ACTIONS(612),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_local_keyword] = ACTIONS(3425),
    [sym_internal_keyword] = ACTIONS(3425),
    [sym_protected_keyword] = ACTIONS(3425),
    [sym_key_keyword] = ACTIONS(3431),
    [sym_dataset_keyword] = ACTIONS(3431),
    [sym_quoted_identifier] = ACTIONS(3435),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3435),
    [sym_integer] = ACTIONS(3425),
    [sym_continue_as_identifier] = ACTIONS(374),
    [sym_preproc_open] = ACTIONS(374),
  },
  [STATE(1377)] = {
    [sym__body_element] = STATE(1378),
    [sym_empty_statement] = STATE(1378),
    [sym_property] = STATE(1378),
    [sym_fields_section] = STATE(1378),
    [sym_keys_section] = STATE(1378),
    [sym_fieldgroups_section] = STATE(1378),
    [sym_enum_value_declaration] = STATE(1378),
    [sym_labels_section] = STATE(1378),
    [sym_layout_section] = STATE(1378),
    [sym__layout_element] = STATE(1378),
    [sym_area_section] = STATE(1378),
    [sym_group_section] = STATE(1378),
    [sym_repeater_section] = STATE(1378),
    [sym_cuegroup_section] = STATE(1378),
    [sym_fixed_section] = STATE(1378),
    [sym_grid_section] = STATE(1378),
    [sym_page_field] = STATE(1378),
    [sym_part_section] = STATE(1378),
    [sym_systempart_section] = STATE(1378),
    [sym_usercontrol_section] = STATE(1378),
    [sym_preproc_split_field] = STATE(1378),
    [sym_label_section] = STATE(1378),
    [sym_addfirst_modification] = STATE(1378),
    [sym_addlast_modification] = STATE(1378),
    [sym_addafter_modification] = STATE(1378),
    [sym_addbefore_modification] = STATE(1378),
    [sym_modify_modification] = STATE(4059),
    [sym_movefirst_modification] = STATE(1378),
    [sym_movelast_modification] = STATE(1378),
    [sym_moveafter_modification] = STATE(1378),
    [sym_movebefore_modification] = STATE(1378),
    [sym_actions_section] = STATE(1378),
    [sym_views_section] = STATE(1378),
    [sym_dataset_section] = STATE(1378),
    [sym_requestpage_section] = STATE(1378),
    [sym_rendering_section] = STATE(1378),
    [sym_elements_section] = STATE(1378),
    [sym_schema_section] = STATE(1378),
    [sym_assembly_declaration] = STATE(1378),
    [sym_event_declaration] = STATE(1378),
    [sym_procedure] = STATE(1378),
    [sym_preproc_split_procedure] = STATE(1378),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(1378),
    [sym_var_section] = STATE(1378),
    [sym_attribute_item] = STATE(1378),
    [sym_preproc_conditional] = STATE(1378),
    [sym_preproc_if] = STATE(1250),
    [sym_preproc_conditional_layout] = STATE(1378),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(1378),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_where_condition_token1] = ACTIONS(3414),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2849),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2851),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token6] = ACTIONS(2855),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(2859),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2861),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2865),
    [aux_sym_movelast_modification_token1] = ACTIONS(2867),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2869),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2871),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(3481),
    [anon_sym_POUNDELIF] = ACTIONS(3481),
    [anon_sym_POUNDElif] = ACTIONS(3481),
    [anon_sym_POUNDelse] = ACTIONS(3481),
    [anon_sym_POUNDELSE] = ACTIONS(3481),
    [anon_sym_POUNDElse] = ACTIONS(3481),
    [anon_sym_POUNDendif] = ACTIONS(3481),
    [anon_sym_POUNDENDIF] = ACTIONS(3481),
    [anon_sym_POUNDEndif] = ACTIONS(3481),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(2905),
    [sym_group_keyword] = ACTIONS(2907),
    [sym_repeater_keyword] = ACTIONS(2909),
    [sym_cuegroup_keyword] = ACTIONS(2911),
    [sym_fixed_keyword] = ACTIONS(2913),
    [sym_grid_keyword] = ACTIONS(2915),
    [sym_part_keyword] = ACTIONS(2917),
    [sym_systempart_keyword] = ACTIONS(2919),
    [sym_usercontrol_keyword] = ACTIONS(2921),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(3481),
  },
  [STATE(1378)] = {
    [sym__body_element] = STATE(1378),
    [sym_empty_statement] = STATE(1378),
    [sym_property] = STATE(1378),
    [sym_fields_section] = STATE(1378),
    [sym_keys_section] = STATE(1378),
    [sym_fieldgroups_section] = STATE(1378),
    [sym_enum_value_declaration] = STATE(1378),
    [sym_labels_section] = STATE(1378),
    [sym_layout_section] = STATE(1378),
    [sym__layout_element] = STATE(1378),
    [sym_area_section] = STATE(1378),
    [sym_group_section] = STATE(1378),
    [sym_repeater_section] = STATE(1378),
    [sym_cuegroup_section] = STATE(1378),
    [sym_fixed_section] = STATE(1378),
    [sym_grid_section] = STATE(1378),
    [sym_page_field] = STATE(1378),
    [sym_part_section] = STATE(1378),
    [sym_systempart_section] = STATE(1378),
    [sym_usercontrol_section] = STATE(1378),
    [sym_preproc_split_field] = STATE(1378),
    [sym_label_section] = STATE(1378),
    [sym_addfirst_modification] = STATE(1378),
    [sym_addlast_modification] = STATE(1378),
    [sym_addafter_modification] = STATE(1378),
    [sym_addbefore_modification] = STATE(1378),
    [sym_modify_modification] = STATE(4059),
    [sym_movefirst_modification] = STATE(1378),
    [sym_movelast_modification] = STATE(1378),
    [sym_moveafter_modification] = STATE(1378),
    [sym_movebefore_modification] = STATE(1378),
    [sym_actions_section] = STATE(1378),
    [sym_views_section] = STATE(1378),
    [sym_dataset_section] = STATE(1378),
    [sym_requestpage_section] = STATE(1378),
    [sym_rendering_section] = STATE(1378),
    [sym_elements_section] = STATE(1378),
    [sym_schema_section] = STATE(1378),
    [sym_assembly_declaration] = STATE(1378),
    [sym_event_declaration] = STATE(1378),
    [sym_procedure] = STATE(1378),
    [sym_preproc_split_procedure] = STATE(1378),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(1378),
    [sym_var_section] = STATE(1378),
    [sym_attribute_item] = STATE(1378),
    [sym_preproc_conditional] = STATE(1378),
    [sym_preproc_if] = STATE(1250),
    [sym_preproc_conditional_layout] = STATE(1378),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(1378),
    [anon_sym_SEMI] = ACTIONS(3483),
    [aux_sym_where_condition_token1] = ACTIONS(3486),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3489),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3492),
    [anon_sym_LBRACK] = ACTIONS(3495),
    [aux_sym_basic_type_token6] = ACTIONS(3498),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3501),
    [aux_sym_addafter_modification_token1] = ACTIONS(3504),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3507),
    [aux_sym_modify_modification_token1] = ACTIONS(3510),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3513),
    [aux_sym_movelast_modification_token1] = ACTIONS(3516),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3519),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3522),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3525),
    [anon_sym_POUNDif] = ACTIONS(3528),
    [anon_sym_POUNDIF] = ACTIONS(3528),
    [anon_sym_POUNDIf] = ACTIONS(3528),
    [anon_sym_POUNDelif] = ACTIONS(3531),
    [anon_sym_POUNDELIF] = ACTIONS(3531),
    [anon_sym_POUNDElif] = ACTIONS(3531),
    [anon_sym_POUNDelse] = ACTIONS(3531),
    [anon_sym_POUNDELSE] = ACTIONS(3531),
    [anon_sym_POUNDElse] = ACTIONS(3531),
    [anon_sym_POUNDendif] = ACTIONS(3531),
    [anon_sym_POUNDENDIF] = ACTIONS(3531),
    [anon_sym_POUNDEndif] = ACTIONS(3531),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3533),
    [sym_trigger_keyword] = ACTIONS(3536),
    [sym_var_keyword] = ACTIONS(3539),
    [sym_local_keyword] = ACTIONS(3542),
    [sym_internal_keyword] = ACTIONS(3545),
    [sym_protected_keyword] = ACTIONS(3542),
    [sym_event_keyword] = ACTIONS(3548),
    [sym_fields_keyword] = ACTIONS(3551),
    [sym_keys_keyword] = ACTIONS(3554),
    [sym_fieldgroups_keyword] = ACTIONS(3557),
    [sym_actions_keyword] = ACTIONS(3560),
    [sym_layout_keyword] = ACTIONS(3563),
    [sym_area_keyword] = ACTIONS(3566),
    [sym_group_keyword] = ACTIONS(3569),
    [sym_repeater_keyword] = ACTIONS(3572),
    [sym_cuegroup_keyword] = ACTIONS(3575),
    [sym_fixed_keyword] = ACTIONS(3578),
    [sym_grid_keyword] = ACTIONS(3581),
    [sym_part_keyword] = ACTIONS(3584),
    [sym_systempart_keyword] = ACTIONS(3587),
    [sym_usercontrol_keyword] = ACTIONS(3590),
    [sym_dataset_keyword] = ACTIONS(3593),
    [sym_elements_keyword] = ACTIONS(3596),
    [sym_labels_keyword] = ACTIONS(3599),
    [sym_rendering_keyword] = ACTIONS(3602),
    [sym_requestpage_keyword] = ACTIONS(3605),
    [sym_schema_keyword] = ACTIONS(3608),
    [sym_views_keyword] = ACTIONS(3611),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3614),
    [sym_preproc_open] = ACTIONS(3528),
    [sym_preproc_close] = ACTIONS(3531),
  },
  [STATE(1379)] = {
    [sym_boolean] = STATE(2155),
    [sym_option_member] = STATE(2174),
    [sym_keyword_identifier] = STATE(2155),
    [sym_codeunit_keyword] = STATE(2124),
    [sym_xmlport_keyword] = STATE(2124),
    [sym_enum_keyword] = STATE(2124),
    [sym_keyword_as_identifier] = STATE(2155),
    [sym_identifier] = ACTIONS(3617),
    [anon_sym_DOT] = ACTIONS(391),
    [anon_sym_EQ] = ACTIONS(389),
    [anon_sym_COMMA] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(3620),
    [aux_sym_boolean_token1] = ACTIONS(3623),
    [aux_sym_boolean_token2] = ACTIONS(3623),
    [sym_decimal] = ACTIONS(391),
    [anon_sym_LPAREN] = ACTIONS(389),
    [aux_sym_where_condition_token1] = ACTIONS(3456),
    [anon_sym_DOT_DOT] = ACTIONS(389),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3626),
    [anon_sym_STAR] = ACTIONS(391),
    [anon_sym_LBRACK] = ACTIONS(389),
    [aux_sym_record_type_token1] = ACTIONS(3626),
    [aux_sym_basic_type_token21] = ACTIONS(3626),
    [aux_sym_basic_type_token22] = ACTIONS(3629),
    [aux_sym_basic_type_token48] = ACTIONS(3626),
    [aux_sym_basic_type_token53] = ACTIONS(3456),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3456),
    [aux_sym_separator_action_token1] = ACTIONS(3456),
    [aux_sym_type_declaration_token1] = ACTIONS(3456),
    [anon_sym_not] = ACTIONS(391),
    [anon_sym_NOT] = ACTIONS(391),
    [anon_sym_Not] = ACTIONS(391),
    [anon_sym_POUNDelif] = ACTIONS(389),
    [anon_sym_POUNDELIF] = ACTIONS(389),
    [anon_sym_POUNDElif] = ACTIONS(389),
    [anon_sym_POUNDelse] = ACTIONS(389),
    [anon_sym_POUNDELSE] = ACTIONS(389),
    [anon_sym_POUNDElse] = ACTIONS(389),
    [anon_sym_POUNDendif] = ACTIONS(389),
    [anon_sym_POUNDENDIF] = ACTIONS(389),
    [anon_sym_POUNDEndif] = ACTIONS(389),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(389),
    [aux_sym__expression_token1] = ACTIONS(389),
    [aux_sym__expression_token2] = ACTIONS(389),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3626),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3626),
    [anon_sym_SLASH] = ACTIONS(391),
    [anon_sym_div] = ACTIONS(391),
    [anon_sym_DIV] = ACTIONS(391),
    [anon_sym_Div] = ACTIONS(391),
    [anon_sym_mod] = ACTIONS(391),
    [anon_sym_MOD] = ACTIONS(391),
    [anon_sym_Mod] = ACTIONS(391),
    [anon_sym_PLUS] = ACTIONS(391),
    [anon_sym_GT_EQ] = ACTIONS(389),
    [anon_sym_LT_EQ] = ACTIONS(389),
    [anon_sym_GT] = ACTIONS(391),
    [anon_sym_LT] = ACTIONS(391),
    [anon_sym_LT_GT] = ACTIONS(389),
    [anon_sym_and] = ACTIONS(391),
    [anon_sym_AND] = ACTIONS(391),
    [anon_sym_And] = ACTIONS(391),
    [anon_sym_or] = ACTIONS(391),
    [anon_sym_OR] = ACTIONS(391),
    [anon_sym_Or] = ACTIONS(391),
    [anon_sym_xor] = ACTIONS(391),
    [anon_sym_XOR] = ACTIONS(391),
    [anon_sym_Xor] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(389),
    [sym_datetime_literal] = ACTIONS(389),
    [sym_date_literal] = ACTIONS(391),
    [sym_time_literal] = ACTIONS(391),
    [sym_biginteger_literal] = ACTIONS(389),
    [anon_sym_in] = ACTIONS(391),
    [anon_sym_IN] = ACTIONS(391),
    [anon_sym_In] = ACTIONS(391),
    [sym_page_keyword] = ACTIONS(3626),
    [anon_sym_codeunit] = ACTIONS(3632),
    [anon_sym_CODEUNIT] = ACTIONS(3632),
    [anon_sym_Codeunit] = ACTIONS(3632),
    [anon_sym_CodeUnit] = ACTIONS(3632),
    [anon_sym_COdeunit] = ACTIONS(3632),
    [anon_sym_codeUnit] = ACTIONS(3632),
    [sym_report_keyword] = ACTIONS(3626),
    [sym_query_keyword] = ACTIONS(3626),
    [anon_sym_xmlport] = ACTIONS(3635),
    [anon_sym_XMLPORT] = ACTIONS(3635),
    [anon_sym_Xmlport] = ACTIONS(3635),
    [anon_sym_XMLport] = ACTIONS(3635),
    [anon_sym_XMLPort] = ACTIONS(3635),
    [anon_sym_XmlPort] = ACTIONS(3635),
    [anon_sym_enum] = ACTIONS(3638),
    [anon_sym_ENUM] = ACTIONS(3638),
    [anon_sym_Enum] = ACTIONS(3638),
    [anon_sym_eNUM] = ACTIONS(3638),
    [anon_sym_eNum] = ACTIONS(3638),
    [anon_sym_ENum] = ACTIONS(3638),
    [sym_local_keyword] = ACTIONS(3448),
    [sym_internal_keyword] = ACTIONS(3448),
    [sym_protected_keyword] = ACTIONS(3448),
    [sym_key_keyword] = ACTIONS(3456),
    [sym_dataset_keyword] = ACTIONS(3456),
    [sym_quoted_identifier] = ACTIONS(3641),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3641),
    [sym_integer] = ACTIONS(3617),
    [sym_continue_as_identifier] = ACTIONS(389),
    [sym_preproc_close] = ACTIONS(389),
  },
  [STATE(1380)] = {
    [sym_boolean] = STATE(2179),
    [sym_option_member] = STATE(2210),
    [sym_keyword_identifier] = STATE(2179),
    [sym_codeunit_keyword] = STATE(2098),
    [sym_xmlport_keyword] = STATE(2098),
    [sym_enum_keyword] = STATE(2098),
    [sym_keyword_as_identifier] = STATE(2179),
    [sym_identifier] = ACTIONS(3644),
    [anon_sym_SEMI] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(391),
    [anon_sym_EQ] = ACTIONS(389),
    [anon_sym_COMMA] = ACTIONS(389),
    [anon_sym_COLON] = ACTIONS(391),
    [anon_sym_DASH] = ACTIONS(3647),
    [aux_sym_boolean_token1] = ACTIONS(3650),
    [aux_sym_boolean_token2] = ACTIONS(3650),
    [sym_decimal] = ACTIONS(391),
    [anon_sym_LPAREN] = ACTIONS(389),
    [aux_sym_where_condition_token1] = ACTIONS(3431),
    [anon_sym_DOT_DOT] = ACTIONS(389),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3653),
    [anon_sym_STAR] = ACTIONS(391),
    [anon_sym_LBRACK] = ACTIONS(389),
    [aux_sym_record_type_token1] = ACTIONS(3653),
    [aux_sym_basic_type_token21] = ACTIONS(3653),
    [aux_sym_basic_type_token22] = ACTIONS(3656),
    [aux_sym_basic_type_token48] = ACTIONS(3653),
    [aux_sym_basic_type_token53] = ACTIONS(3431),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3431),
    [aux_sym_separator_action_token1] = ACTIONS(3431),
    [aux_sym_type_declaration_token1] = ACTIONS(3431),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(391),
    [anon_sym_POUNDif] = ACTIONS(389),
    [anon_sym_POUNDIF] = ACTIONS(389),
    [anon_sym_POUNDIf] = ACTIONS(389),
    [anon_sym_not] = ACTIONS(391),
    [anon_sym_NOT] = ACTIONS(391),
    [anon_sym_Not] = ACTIONS(391),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(389),
    [aux_sym__expression_token1] = ACTIONS(389),
    [aux_sym__expression_token2] = ACTIONS(389),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3653),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3653),
    [anon_sym_SLASH] = ACTIONS(391),
    [anon_sym_div] = ACTIONS(391),
    [anon_sym_DIV] = ACTIONS(391),
    [anon_sym_Div] = ACTIONS(391),
    [anon_sym_mod] = ACTIONS(391),
    [anon_sym_MOD] = ACTIONS(391),
    [anon_sym_Mod] = ACTIONS(391),
    [anon_sym_PLUS] = ACTIONS(391),
    [anon_sym_GT_EQ] = ACTIONS(389),
    [anon_sym_LT_EQ] = ACTIONS(389),
    [anon_sym_GT] = ACTIONS(391),
    [anon_sym_LT] = ACTIONS(391),
    [anon_sym_LT_GT] = ACTIONS(389),
    [anon_sym_and] = ACTIONS(391),
    [anon_sym_AND] = ACTIONS(391),
    [anon_sym_And] = ACTIONS(391),
    [anon_sym_or] = ACTIONS(391),
    [anon_sym_OR] = ACTIONS(391),
    [anon_sym_Or] = ACTIONS(391),
    [anon_sym_xor] = ACTIONS(391),
    [anon_sym_XOR] = ACTIONS(391),
    [anon_sym_Xor] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(389),
    [sym_datetime_literal] = ACTIONS(389),
    [sym_date_literal] = ACTIONS(391),
    [sym_time_literal] = ACTIONS(391),
    [sym_biginteger_literal] = ACTIONS(389),
    [anon_sym_else] = ACTIONS(391),
    [anon_sym_ELSE] = ACTIONS(391),
    [anon_sym_Else] = ACTIONS(391),
    [anon_sym_in] = ACTIONS(391),
    [anon_sym_IN] = ACTIONS(391),
    [anon_sym_In] = ACTIONS(391),
    [sym_page_keyword] = ACTIONS(3653),
    [anon_sym_codeunit] = ACTIONS(3659),
    [anon_sym_CODEUNIT] = ACTIONS(3659),
    [anon_sym_Codeunit] = ACTIONS(3659),
    [anon_sym_CodeUnit] = ACTIONS(3659),
    [anon_sym_COdeunit] = ACTIONS(3659),
    [anon_sym_codeUnit] = ACTIONS(3659),
    [sym_report_keyword] = ACTIONS(3653),
    [sym_query_keyword] = ACTIONS(3653),
    [anon_sym_xmlport] = ACTIONS(3662),
    [anon_sym_XMLPORT] = ACTIONS(3662),
    [anon_sym_Xmlport] = ACTIONS(3662),
    [anon_sym_XMLport] = ACTIONS(3662),
    [anon_sym_XMLPort] = ACTIONS(3662),
    [anon_sym_XmlPort] = ACTIONS(3662),
    [anon_sym_enum] = ACTIONS(3665),
    [anon_sym_ENUM] = ACTIONS(3665),
    [anon_sym_Enum] = ACTIONS(3665),
    [anon_sym_eNUM] = ACTIONS(3665),
    [anon_sym_eNum] = ACTIONS(3665),
    [anon_sym_ENum] = ACTIONS(3665),
    [sym_local_keyword] = ACTIONS(3425),
    [sym_internal_keyword] = ACTIONS(3425),
    [sym_protected_keyword] = ACTIONS(3425),
    [sym_key_keyword] = ACTIONS(3431),
    [sym_dataset_keyword] = ACTIONS(3431),
    [sym_quoted_identifier] = ACTIONS(3668),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3668),
    [sym_integer] = ACTIONS(3644),
    [sym_continue_as_identifier] = ACTIONS(389),
    [sym_preproc_open] = ACTIONS(389),
  },
  [STATE(1381)] = {
    [sym__body_element] = STATE(4061),
    [sym_empty_statement] = STATE(4061),
    [sym_property] = STATE(4061),
    [sym_fields_section] = STATE(4061),
    [sym_keys_section] = STATE(4061),
    [sym_fieldgroups_section] = STATE(4061),
    [sym_enum_value_declaration] = STATE(4061),
    [sym_labels_section] = STATE(4061),
    [sym_layout_section] = STATE(4061),
    [sym__layout_element] = STATE(4062),
    [sym_area_section] = STATE(4062),
    [sym_group_section] = STATE(4062),
    [sym_repeater_section] = STATE(4062),
    [sym_cuegroup_section] = STATE(4062),
    [sym_fixed_section] = STATE(4062),
    [sym_grid_section] = STATE(4062),
    [sym_page_field] = STATE(4062),
    [sym_part_section] = STATE(4062),
    [sym_systempart_section] = STATE(4062),
    [sym_usercontrol_section] = STATE(4062),
    [sym_preproc_split_field] = STATE(4062),
    [sym_label_section] = STATE(4062),
    [sym_addfirst_modification] = STATE(4062),
    [sym_addlast_modification] = STATE(4062),
    [sym_addafter_modification] = STATE(4062),
    [sym_addbefore_modification] = STATE(4062),
    [sym_modify_modification] = STATE(4059),
    [sym_movefirst_modification] = STATE(4062),
    [sym_movelast_modification] = STATE(4062),
    [sym_moveafter_modification] = STATE(4062),
    [sym_movebefore_modification] = STATE(4062),
    [sym_actions_section] = STATE(4061),
    [sym_views_section] = STATE(4061),
    [sym_dataset_section] = STATE(4061),
    [sym_requestpage_section] = STATE(4061),
    [sym_rendering_section] = STATE(4061),
    [sym_elements_section] = STATE(4061),
    [sym_schema_section] = STATE(4061),
    [sym_assembly_declaration] = STATE(4061),
    [sym_event_declaration] = STATE(4061),
    [sym_procedure] = STATE(4061),
    [sym_preproc_split_procedure] = STATE(4061),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(4061),
    [sym_var_section] = STATE(4061),
    [sym_attribute_item] = STATE(4061),
    [sym_preproc_conditional] = STATE(4061),
    [sym_preproc_if] = STATE(1250),
    [sym_preproc_endif] = STATE(5090),
    [sym_preproc_conditional_layout] = STATE(4062),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3490),
    [aux_sym_layout_section_repeat1] = STATE(4700),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(1390),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_where_condition_token1] = ACTIONS(3414),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2849),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2851),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token6] = ACTIONS(2855),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(2859),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2861),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2865),
    [aux_sym_movelast_modification_token1] = ACTIONS(2867),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2869),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2871),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(2905),
    [sym_group_keyword] = ACTIONS(2907),
    [sym_repeater_keyword] = ACTIONS(2909),
    [sym_cuegroup_keyword] = ACTIONS(2911),
    [sym_fixed_keyword] = ACTIONS(2913),
    [sym_grid_keyword] = ACTIONS(2915),
    [sym_part_keyword] = ACTIONS(2917),
    [sym_systempart_keyword] = ACTIONS(2919),
    [sym_usercontrol_keyword] = ACTIONS(2921),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(1382)] = {
    [sym_boolean] = STATE(6346),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(8837),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym_preproc_conditional_permissions] = STATE(6271),
    [sym_tabledata_permission] = STATE(6826),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1370),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4852),
    [sym_xmlport_keyword] = STATE(4852),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7706),
    [sym_keyword_as_identifier] = STATE(7706),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(6271),
    [sym_identifier] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token1] = ACTIONS(3064),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3066),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDelif] = ACTIONS(3671),
    [anon_sym_POUNDELIF] = ACTIONS(3671),
    [anon_sym_POUNDElif] = ACTIONS(3671),
    [anon_sym_POUNDelse] = ACTIONS(3671),
    [anon_sym_POUNDELSE] = ACTIONS(3671),
    [anon_sym_POUNDElse] = ACTIONS(3671),
    [anon_sym_POUNDendif] = ACTIONS(3671),
    [anon_sym_POUNDENDIF] = ACTIONS(3671),
    [anon_sym_POUNDEndif] = ACTIONS(3671),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_table_keyword] = ACTIONS(3064),
    [sym_page_keyword] = ACTIONS(3080),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3080),
    [sym_query_keyword] = ACTIONS(3080),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(3671),
  },
  [STATE(1383)] = {
    [sym__body_element] = STATE(3482),
    [sym_empty_statement] = STATE(3482),
    [sym_property] = STATE(3482),
    [sym_fields_section] = STATE(3482),
    [sym_keys_section] = STATE(3482),
    [sym_fieldgroups_section] = STATE(3482),
    [sym_enum_value_declaration] = STATE(3482),
    [sym_labels_section] = STATE(3482),
    [sym_layout_section] = STATE(3482),
    [sym__layout_element] = STATE(4709),
    [sym_area_section] = STATE(4709),
    [sym_group_section] = STATE(4709),
    [sym_repeater_section] = STATE(4709),
    [sym_cuegroup_section] = STATE(4709),
    [sym_fixed_section] = STATE(4709),
    [sym_grid_section] = STATE(4709),
    [sym_page_field] = STATE(4709),
    [sym_part_section] = STATE(4709),
    [sym_systempart_section] = STATE(4709),
    [sym_usercontrol_section] = STATE(4709),
    [sym_preproc_split_field] = STATE(4709),
    [sym_label_section] = STATE(4709),
    [sym_addfirst_modification] = STATE(4709),
    [sym_addlast_modification] = STATE(4709),
    [sym_addafter_modification] = STATE(4709),
    [sym_addbefore_modification] = STATE(4709),
    [sym_modify_modification] = STATE(4501),
    [sym_movefirst_modification] = STATE(4709),
    [sym_movelast_modification] = STATE(4709),
    [sym_moveafter_modification] = STATE(4709),
    [sym_movebefore_modification] = STATE(4709),
    [sym_actions_section] = STATE(3482),
    [sym_views_section] = STATE(3482),
    [sym_dataset_section] = STATE(3482),
    [sym_requestpage_section] = STATE(3482),
    [sym_rendering_section] = STATE(3482),
    [sym_elements_section] = STATE(3482),
    [sym_schema_section] = STATE(3482),
    [sym_assembly_declaration] = STATE(3482),
    [sym_event_declaration] = STATE(3482),
    [sym_procedure] = STATE(3482),
    [sym_preproc_split_procedure] = STATE(3482),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3482),
    [sym_var_section] = STATE(3482),
    [sym_attribute_item] = STATE(3482),
    [sym_preproc_conditional] = STATE(3482),
    [sym_preproc_if] = STATE(1249),
    [sym_preproc_endif] = STATE(4117),
    [sym_preproc_conditional_layout] = STATE(4709),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3482),
    [aux_sym_layout_section_repeat1] = STATE(4709),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_where_condition_token1] = ACTIONS(3443),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token6] = ACTIONS(2963),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(1384)] = {
    [sym__body_element] = STATE(3482),
    [sym_empty_statement] = STATE(3482),
    [sym_property] = STATE(3482),
    [sym_fields_section] = STATE(3482),
    [sym_keys_section] = STATE(3482),
    [sym_fieldgroups_section] = STATE(3482),
    [sym_enum_value_declaration] = STATE(3482),
    [sym_labels_section] = STATE(3482),
    [sym_layout_section] = STATE(3482),
    [sym__layout_element] = STATE(4710),
    [sym_area_section] = STATE(4710),
    [sym_group_section] = STATE(4710),
    [sym_repeater_section] = STATE(4710),
    [sym_cuegroup_section] = STATE(4710),
    [sym_fixed_section] = STATE(4710),
    [sym_grid_section] = STATE(4710),
    [sym_page_field] = STATE(4710),
    [sym_part_section] = STATE(4710),
    [sym_systempart_section] = STATE(4710),
    [sym_usercontrol_section] = STATE(4710),
    [sym_preproc_split_field] = STATE(4710),
    [sym_label_section] = STATE(4710),
    [sym_addfirst_modification] = STATE(4710),
    [sym_addlast_modification] = STATE(4710),
    [sym_addafter_modification] = STATE(4710),
    [sym_addbefore_modification] = STATE(4710),
    [sym_modify_modification] = STATE(4501),
    [sym_movefirst_modification] = STATE(4710),
    [sym_movelast_modification] = STATE(4710),
    [sym_moveafter_modification] = STATE(4710),
    [sym_movebefore_modification] = STATE(4710),
    [sym_actions_section] = STATE(3482),
    [sym_views_section] = STATE(3482),
    [sym_dataset_section] = STATE(3482),
    [sym_requestpage_section] = STATE(3482),
    [sym_rendering_section] = STATE(3482),
    [sym_elements_section] = STATE(3482),
    [sym_schema_section] = STATE(3482),
    [sym_assembly_declaration] = STATE(3482),
    [sym_event_declaration] = STATE(3482),
    [sym_procedure] = STATE(3482),
    [sym_preproc_split_procedure] = STATE(3482),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3482),
    [sym_var_section] = STATE(3482),
    [sym_attribute_item] = STATE(3482),
    [sym_preproc_conditional] = STATE(3482),
    [sym_preproc_if] = STATE(1249),
    [sym_preproc_endif] = STATE(4178),
    [sym_preproc_conditional_layout] = STATE(4710),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3482),
    [aux_sym_layout_section_repeat1] = STATE(4710),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_where_condition_token1] = ACTIONS(3443),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token6] = ACTIONS(2963),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(1385)] = {
    [sym_boolean] = STATE(6346),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(7668),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1387),
    [sym_preproc_elif] = STATE(1503),
    [sym_preproc_else] = STATE(1767),
    [sym_preproc_endif] = STATE(11549),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7706),
    [sym_keyword_as_identifier] = STATE(7706),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(8073),
    [sym_identifier] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDelif] = ACTIONS(3072),
    [anon_sym_POUNDELIF] = ACTIONS(3072),
    [anon_sym_POUNDElif] = ACTIONS(3072),
    [anon_sym_POUNDelse] = ACTIONS(3074),
    [anon_sym_POUNDELSE] = ACTIONS(3074),
    [anon_sym_POUNDElse] = ACTIONS(3074),
    [anon_sym_POUNDendif] = ACTIONS(223),
    [anon_sym_POUNDENDIF] = ACTIONS(223),
    [anon_sym_POUNDEndif] = ACTIONS(223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(223),
  },
  [STATE(1386)] = {
    [sym_boolean] = STATE(6346),
    [sym_link_value] = STATE(7327),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(9180),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym_preproc_conditional_permissions] = STATE(6825),
    [sym_tabledata_permission] = STATE(6826),
    [sym_implementation_value] = STATE(7268),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1370),
    [sym_preproc_endif] = STATE(6801),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4852),
    [sym_xmlport_keyword] = STATE(4852),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7711),
    [sym_keyword_as_identifier] = STATE(7711),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(7417),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(6825),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(7452),
    [sym_identifier] = ACTIONS(3054),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token1] = ACTIONS(3064),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3066),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDendif] = ACTIONS(3076),
    [anon_sym_POUNDENDIF] = ACTIONS(3076),
    [anon_sym_POUNDEndif] = ACTIONS(3076),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_table_keyword] = ACTIONS(3064),
    [sym_page_keyword] = ACTIONS(3080),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3080),
    [sym_query_keyword] = ACTIONS(3080),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3082),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(3076),
  },
  [STATE(1387)] = {
    [sym_boolean] = STATE(6346),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(7737),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1387),
    [sym_preproc_elif] = STATE(1503),
    [sym_preproc_else] = STATE(1765),
    [sym_preproc_endif] = STATE(8778),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7706),
    [sym_keyword_as_identifier] = STATE(7706),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(8172),
    [sym_identifier] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDelif] = ACTIONS(3072),
    [anon_sym_POUNDELIF] = ACTIONS(3072),
    [anon_sym_POUNDElif] = ACTIONS(3072),
    [anon_sym_POUNDelse] = ACTIONS(3074),
    [anon_sym_POUNDELSE] = ACTIONS(3074),
    [anon_sym_POUNDElse] = ACTIONS(3074),
    [anon_sym_POUNDendif] = ACTIONS(3674),
    [anon_sym_POUNDENDIF] = ACTIONS(3674),
    [anon_sym_POUNDEndif] = ACTIONS(3674),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(3674),
  },
  [STATE(1388)] = {
    [sym__body_element] = STATE(1392),
    [sym_empty_statement] = STATE(1392),
    [sym_property] = STATE(1392),
    [sym_fields_section] = STATE(1392),
    [sym_keys_section] = STATE(1392),
    [sym_fieldgroups_section] = STATE(1392),
    [sym_enum_value_declaration] = STATE(1392),
    [sym_labels_section] = STATE(1392),
    [sym_layout_section] = STATE(1392),
    [sym__layout_element] = STATE(1392),
    [sym_area_section] = STATE(1392),
    [sym_group_section] = STATE(1392),
    [sym_repeater_section] = STATE(1392),
    [sym_cuegroup_section] = STATE(1392),
    [sym_fixed_section] = STATE(1392),
    [sym_grid_section] = STATE(1392),
    [sym_page_field] = STATE(1392),
    [sym_part_section] = STATE(1392),
    [sym_systempart_section] = STATE(1392),
    [sym_usercontrol_section] = STATE(1392),
    [sym_preproc_split_field] = STATE(1392),
    [sym_label_section] = STATE(1392),
    [sym_addfirst_modification] = STATE(1392),
    [sym_addlast_modification] = STATE(1392),
    [sym_addafter_modification] = STATE(1392),
    [sym_addbefore_modification] = STATE(1392),
    [sym_modify_modification] = STATE(4059),
    [sym_movefirst_modification] = STATE(1392),
    [sym_movelast_modification] = STATE(1392),
    [sym_moveafter_modification] = STATE(1392),
    [sym_movebefore_modification] = STATE(1392),
    [sym_actions_section] = STATE(1392),
    [sym_views_section] = STATE(1392),
    [sym_dataset_section] = STATE(1392),
    [sym_requestpage_section] = STATE(1392),
    [sym_rendering_section] = STATE(1392),
    [sym_elements_section] = STATE(1392),
    [sym_schema_section] = STATE(1392),
    [sym_assembly_declaration] = STATE(1392),
    [sym_event_declaration] = STATE(1392),
    [sym_procedure] = STATE(1392),
    [sym_preproc_split_procedure] = STATE(1392),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(1392),
    [sym_var_section] = STATE(1392),
    [sym_attribute_item] = STATE(1392),
    [sym_preproc_conditional] = STATE(1392),
    [sym_preproc_if] = STATE(1250),
    [sym_preproc_endif] = STATE(4980),
    [sym_preproc_conditional_layout] = STATE(1392),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(1392),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_where_condition_token1] = ACTIONS(3414),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2849),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2851),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token6] = ACTIONS(2855),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(2859),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2861),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2865),
    [aux_sym_movelast_modification_token1] = ACTIONS(2867),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2869),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2871),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(2905),
    [sym_group_keyword] = ACTIONS(2907),
    [sym_repeater_keyword] = ACTIONS(2909),
    [sym_cuegroup_keyword] = ACTIONS(2911),
    [sym_fixed_keyword] = ACTIONS(2913),
    [sym_grid_keyword] = ACTIONS(2915),
    [sym_part_keyword] = ACTIONS(2917),
    [sym_systempart_keyword] = ACTIONS(2919),
    [sym_usercontrol_keyword] = ACTIONS(2921),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(1389)] = {
    [sym__body_element] = STATE(1378),
    [sym_empty_statement] = STATE(1378),
    [sym_property] = STATE(1378),
    [sym_fields_section] = STATE(1378),
    [sym_keys_section] = STATE(1378),
    [sym_fieldgroups_section] = STATE(1378),
    [sym_enum_value_declaration] = STATE(1378),
    [sym_labels_section] = STATE(1378),
    [sym_layout_section] = STATE(1378),
    [sym__layout_element] = STATE(1378),
    [sym_area_section] = STATE(1378),
    [sym_group_section] = STATE(1378),
    [sym_repeater_section] = STATE(1378),
    [sym_cuegroup_section] = STATE(1378),
    [sym_fixed_section] = STATE(1378),
    [sym_grid_section] = STATE(1378),
    [sym_page_field] = STATE(1378),
    [sym_part_section] = STATE(1378),
    [sym_systempart_section] = STATE(1378),
    [sym_usercontrol_section] = STATE(1378),
    [sym_preproc_split_field] = STATE(1378),
    [sym_label_section] = STATE(1378),
    [sym_addfirst_modification] = STATE(1378),
    [sym_addlast_modification] = STATE(1378),
    [sym_addafter_modification] = STATE(1378),
    [sym_addbefore_modification] = STATE(1378),
    [sym_modify_modification] = STATE(4059),
    [sym_movefirst_modification] = STATE(1378),
    [sym_movelast_modification] = STATE(1378),
    [sym_moveafter_modification] = STATE(1378),
    [sym_movebefore_modification] = STATE(1378),
    [sym_actions_section] = STATE(1378),
    [sym_views_section] = STATE(1378),
    [sym_dataset_section] = STATE(1378),
    [sym_requestpage_section] = STATE(1378),
    [sym_rendering_section] = STATE(1378),
    [sym_elements_section] = STATE(1378),
    [sym_schema_section] = STATE(1378),
    [sym_assembly_declaration] = STATE(1378),
    [sym_event_declaration] = STATE(1378),
    [sym_procedure] = STATE(1378),
    [sym_preproc_split_procedure] = STATE(1378),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(1378),
    [sym_var_section] = STATE(1378),
    [sym_attribute_item] = STATE(1378),
    [sym_preproc_conditional] = STATE(1378),
    [sym_preproc_if] = STATE(1250),
    [sym_preproc_endif] = STATE(4980),
    [sym_preproc_conditional_layout] = STATE(1378),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(1378),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_where_condition_token1] = ACTIONS(3414),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2849),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2851),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token6] = ACTIONS(2855),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(2859),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2861),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2865),
    [aux_sym_movelast_modification_token1] = ACTIONS(2867),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2869),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2871),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(2905),
    [sym_group_keyword] = ACTIONS(2907),
    [sym_repeater_keyword] = ACTIONS(2909),
    [sym_cuegroup_keyword] = ACTIONS(2911),
    [sym_fixed_keyword] = ACTIONS(2913),
    [sym_grid_keyword] = ACTIONS(2915),
    [sym_part_keyword] = ACTIONS(2917),
    [sym_systempart_keyword] = ACTIONS(2919),
    [sym_usercontrol_keyword] = ACTIONS(2921),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(1390)] = {
    [sym__body_element] = STATE(1378),
    [sym_empty_statement] = STATE(1378),
    [sym_property] = STATE(1378),
    [sym_fields_section] = STATE(1378),
    [sym_keys_section] = STATE(1378),
    [sym_fieldgroups_section] = STATE(1378),
    [sym_enum_value_declaration] = STATE(1378),
    [sym_labels_section] = STATE(1378),
    [sym_layout_section] = STATE(1378),
    [sym__layout_element] = STATE(1378),
    [sym_area_section] = STATE(1378),
    [sym_group_section] = STATE(1378),
    [sym_repeater_section] = STATE(1378),
    [sym_cuegroup_section] = STATE(1378),
    [sym_fixed_section] = STATE(1378),
    [sym_grid_section] = STATE(1378),
    [sym_page_field] = STATE(1378),
    [sym_part_section] = STATE(1378),
    [sym_systempart_section] = STATE(1378),
    [sym_usercontrol_section] = STATE(1378),
    [sym_preproc_split_field] = STATE(1378),
    [sym_label_section] = STATE(1378),
    [sym_addfirst_modification] = STATE(1378),
    [sym_addlast_modification] = STATE(1378),
    [sym_addafter_modification] = STATE(1378),
    [sym_addbefore_modification] = STATE(1378),
    [sym_modify_modification] = STATE(4059),
    [sym_movefirst_modification] = STATE(1378),
    [sym_movelast_modification] = STATE(1378),
    [sym_moveafter_modification] = STATE(1378),
    [sym_movebefore_modification] = STATE(1378),
    [sym_actions_section] = STATE(1378),
    [sym_views_section] = STATE(1378),
    [sym_dataset_section] = STATE(1378),
    [sym_requestpage_section] = STATE(1378),
    [sym_rendering_section] = STATE(1378),
    [sym_elements_section] = STATE(1378),
    [sym_schema_section] = STATE(1378),
    [sym_assembly_declaration] = STATE(1378),
    [sym_event_declaration] = STATE(1378),
    [sym_procedure] = STATE(1378),
    [sym_preproc_split_procedure] = STATE(1378),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(1378),
    [sym_var_section] = STATE(1378),
    [sym_attribute_item] = STATE(1378),
    [sym_preproc_conditional] = STATE(1378),
    [sym_preproc_if] = STATE(1250),
    [sym_preproc_endif] = STATE(5084),
    [sym_preproc_conditional_layout] = STATE(1378),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(1378),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_where_condition_token1] = ACTIONS(3414),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2849),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2851),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token6] = ACTIONS(2855),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(2859),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2861),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2865),
    [aux_sym_movelast_modification_token1] = ACTIONS(2867),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2869),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2871),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(2905),
    [sym_group_keyword] = ACTIONS(2907),
    [sym_repeater_keyword] = ACTIONS(2909),
    [sym_cuegroup_keyword] = ACTIONS(2911),
    [sym_fixed_keyword] = ACTIONS(2913),
    [sym_grid_keyword] = ACTIONS(2915),
    [sym_part_keyword] = ACTIONS(2917),
    [sym_systempart_keyword] = ACTIONS(2919),
    [sym_usercontrol_keyword] = ACTIONS(2921),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(1391)] = {
    [sym__body_element] = STATE(1389),
    [sym_empty_statement] = STATE(1389),
    [sym_property] = STATE(1389),
    [sym_fields_section] = STATE(1389),
    [sym_keys_section] = STATE(1389),
    [sym_fieldgroups_section] = STATE(1389),
    [sym_enum_value_declaration] = STATE(1389),
    [sym_labels_section] = STATE(1389),
    [sym_layout_section] = STATE(1389),
    [sym__layout_element] = STATE(1389),
    [sym_area_section] = STATE(1389),
    [sym_group_section] = STATE(1389),
    [sym_repeater_section] = STATE(1389),
    [sym_cuegroup_section] = STATE(1389),
    [sym_fixed_section] = STATE(1389),
    [sym_grid_section] = STATE(1389),
    [sym_page_field] = STATE(1389),
    [sym_part_section] = STATE(1389),
    [sym_systempart_section] = STATE(1389),
    [sym_usercontrol_section] = STATE(1389),
    [sym_preproc_split_field] = STATE(1389),
    [sym_label_section] = STATE(1389),
    [sym_addfirst_modification] = STATE(1389),
    [sym_addlast_modification] = STATE(1389),
    [sym_addafter_modification] = STATE(1389),
    [sym_addbefore_modification] = STATE(1389),
    [sym_modify_modification] = STATE(4059),
    [sym_movefirst_modification] = STATE(1389),
    [sym_movelast_modification] = STATE(1389),
    [sym_moveafter_modification] = STATE(1389),
    [sym_movebefore_modification] = STATE(1389),
    [sym_actions_section] = STATE(1389),
    [sym_views_section] = STATE(1389),
    [sym_dataset_section] = STATE(1389),
    [sym_requestpage_section] = STATE(1389),
    [sym_rendering_section] = STATE(1389),
    [sym_elements_section] = STATE(1389),
    [sym_schema_section] = STATE(1389),
    [sym_assembly_declaration] = STATE(1389),
    [sym_event_declaration] = STATE(1389),
    [sym_procedure] = STATE(1389),
    [sym_preproc_split_procedure] = STATE(1389),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(1389),
    [sym_var_section] = STATE(1389),
    [sym_attribute_item] = STATE(1389),
    [sym_preproc_conditional] = STATE(1389),
    [sym_preproc_if] = STATE(1250),
    [sym_preproc_endif] = STATE(5084),
    [sym_preproc_conditional_layout] = STATE(1389),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(1389),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_where_condition_token1] = ACTIONS(3414),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2849),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2851),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token6] = ACTIONS(2855),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(2859),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2861),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2865),
    [aux_sym_movelast_modification_token1] = ACTIONS(2867),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2869),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2871),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(2905),
    [sym_group_keyword] = ACTIONS(2907),
    [sym_repeater_keyword] = ACTIONS(2909),
    [sym_cuegroup_keyword] = ACTIONS(2911),
    [sym_fixed_keyword] = ACTIONS(2913),
    [sym_grid_keyword] = ACTIONS(2915),
    [sym_part_keyword] = ACTIONS(2917),
    [sym_systempart_keyword] = ACTIONS(2919),
    [sym_usercontrol_keyword] = ACTIONS(2921),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(1392)] = {
    [sym__body_element] = STATE(1378),
    [sym_empty_statement] = STATE(1378),
    [sym_property] = STATE(1378),
    [sym_fields_section] = STATE(1378),
    [sym_keys_section] = STATE(1378),
    [sym_fieldgroups_section] = STATE(1378),
    [sym_enum_value_declaration] = STATE(1378),
    [sym_labels_section] = STATE(1378),
    [sym_layout_section] = STATE(1378),
    [sym__layout_element] = STATE(1378),
    [sym_area_section] = STATE(1378),
    [sym_group_section] = STATE(1378),
    [sym_repeater_section] = STATE(1378),
    [sym_cuegroup_section] = STATE(1378),
    [sym_fixed_section] = STATE(1378),
    [sym_grid_section] = STATE(1378),
    [sym_page_field] = STATE(1378),
    [sym_part_section] = STATE(1378),
    [sym_systempart_section] = STATE(1378),
    [sym_usercontrol_section] = STATE(1378),
    [sym_preproc_split_field] = STATE(1378),
    [sym_label_section] = STATE(1378),
    [sym_addfirst_modification] = STATE(1378),
    [sym_addlast_modification] = STATE(1378),
    [sym_addafter_modification] = STATE(1378),
    [sym_addbefore_modification] = STATE(1378),
    [sym_modify_modification] = STATE(4059),
    [sym_movefirst_modification] = STATE(1378),
    [sym_movelast_modification] = STATE(1378),
    [sym_moveafter_modification] = STATE(1378),
    [sym_movebefore_modification] = STATE(1378),
    [sym_actions_section] = STATE(1378),
    [sym_views_section] = STATE(1378),
    [sym_dataset_section] = STATE(1378),
    [sym_requestpage_section] = STATE(1378),
    [sym_rendering_section] = STATE(1378),
    [sym_elements_section] = STATE(1378),
    [sym_schema_section] = STATE(1378),
    [sym_assembly_declaration] = STATE(1378),
    [sym_event_declaration] = STATE(1378),
    [sym_procedure] = STATE(1378),
    [sym_preproc_split_procedure] = STATE(1378),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(1378),
    [sym_var_section] = STATE(1378),
    [sym_attribute_item] = STATE(1378),
    [sym_preproc_conditional] = STATE(1378),
    [sym_preproc_if] = STATE(1250),
    [sym_preproc_endif] = STATE(5081),
    [sym_preproc_conditional_layout] = STATE(1378),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(1378),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_where_condition_token1] = ACTIONS(3414),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2849),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2851),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token6] = ACTIONS(2855),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(2859),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2861),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2865),
    [aux_sym_movelast_modification_token1] = ACTIONS(2867),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2869),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2871),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(2905),
    [sym_group_keyword] = ACTIONS(2907),
    [sym_repeater_keyword] = ACTIONS(2909),
    [sym_cuegroup_keyword] = ACTIONS(2911),
    [sym_fixed_keyword] = ACTIONS(2913),
    [sym_grid_keyword] = ACTIONS(2915),
    [sym_part_keyword] = ACTIONS(2917),
    [sym_systempart_keyword] = ACTIONS(2919),
    [sym_usercontrol_keyword] = ACTIONS(2921),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(1393)] = {
    [sym__body_element] = STATE(2755),
    [sym_empty_statement] = STATE(2755),
    [sym_property] = STATE(4854),
    [sym_fields_section] = STATE(2755),
    [sym_keys_section] = STATE(2755),
    [sym_fieldgroups_section] = STATE(2755),
    [sym_enum_value_declaration] = STATE(2755),
    [sym_labels_section] = STATE(2755),
    [sym_layout_section] = STATE(2755),
    [sym_modify_modification] = STATE(2755),
    [sym_actions_section] = STATE(2755),
    [sym__action_element] = STATE(4703),
    [sym_action_area_section] = STATE(4703),
    [sym_action_group_section] = STATE(4703),
    [sym_action_declaration] = STATE(4703),
    [sym_separator_action] = STATE(4703),
    [sym_actionref_declaration] = STATE(4703),
    [sym_systemaction_declaration] = STATE(4703),
    [sym_fileuploadaction_declaration] = STATE(4703),
    [sym_customaction_declaration] = STATE(4703),
    [sym_addfirst_action_modification] = STATE(4703),
    [sym_addlast_action_modification] = STATE(4703),
    [sym_addafter_action_modification] = STATE(4703),
    [sym_addbefore_action_modification] = STATE(4703),
    [sym_modify_action_modification] = STATE(4703),
    [sym_views_section] = STATE(2755),
    [sym_dataset_section] = STATE(2755),
    [sym_requestpage_section] = STATE(2755),
    [sym_rendering_section] = STATE(2755),
    [sym_elements_section] = STATE(2755),
    [sym_schema_section] = STATE(2755),
    [sym_assembly_declaration] = STATE(2755),
    [sym_event_declaration] = STATE(2755),
    [sym_procedure] = STATE(2755),
    [sym_preproc_split_procedure] = STATE(2755),
    [sym__procedure_header] = STATE(8089),
    [sym_procedure_modifier] = STATE(12657),
    [sym_trigger_declaration] = STATE(4854),
    [sym_var_section] = STATE(2755),
    [sym_attribute_item] = STATE(4853),
    [sym_preproc_conditional] = STATE(2755),
    [sym_preproc_if] = STATE(1393),
    [sym_preproc_elif] = STATE(1738),
    [sym_preproc_else] = STATE(2151),
    [sym_preproc_endif] = STATE(4864),
    [sym_preproc_conditional_actions] = STATE(4703),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(2755),
    [aux_sym_actions_section_repeat1] = STATE(4703),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_repeat1] = STATE(8159),
    [aux_sym_preproc_conditional_actions_repeat1] = STATE(7783),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3676),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3678),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token22] = ACTIONS(3680),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(3682),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3684),
    [aux_sym_modify_modification_token1] = ACTIONS(3686),
    [aux_sym_separator_action_token1] = ACTIONS(3688),
    [aux_sym_actionref_declaration_token1] = ACTIONS(3690),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(3692),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(3694),
    [aux_sym_customaction_declaration_token1] = ACTIONS(3696),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(2883),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(3698),
    [sym_group_keyword] = ACTIONS(3700),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(1394)] = {
    [sym__body_element] = STATE(2739),
    [sym_empty_statement] = STATE(2739),
    [sym_property] = STATE(4854),
    [sym_fields_section] = STATE(2739),
    [sym_keys_section] = STATE(2739),
    [sym_fieldgroups_section] = STATE(2739),
    [sym_enum_value_declaration] = STATE(2739),
    [sym_labels_section] = STATE(2739),
    [sym_layout_section] = STATE(2739),
    [sym_modify_modification] = STATE(2739),
    [sym_actions_section] = STATE(2739),
    [sym__action_element] = STATE(4695),
    [sym_action_area_section] = STATE(4695),
    [sym_action_group_section] = STATE(4695),
    [sym_action_declaration] = STATE(4695),
    [sym_separator_action] = STATE(4695),
    [sym_actionref_declaration] = STATE(4695),
    [sym_systemaction_declaration] = STATE(4695),
    [sym_fileuploadaction_declaration] = STATE(4695),
    [sym_customaction_declaration] = STATE(4695),
    [sym_addfirst_action_modification] = STATE(4695),
    [sym_addlast_action_modification] = STATE(4695),
    [sym_addafter_action_modification] = STATE(4695),
    [sym_addbefore_action_modification] = STATE(4695),
    [sym_modify_action_modification] = STATE(4695),
    [sym_views_section] = STATE(2739),
    [sym_dataset_section] = STATE(2739),
    [sym_requestpage_section] = STATE(2739),
    [sym_rendering_section] = STATE(2739),
    [sym_elements_section] = STATE(2739),
    [sym_schema_section] = STATE(2739),
    [sym_assembly_declaration] = STATE(2739),
    [sym_event_declaration] = STATE(2739),
    [sym_procedure] = STATE(2739),
    [sym_preproc_split_procedure] = STATE(2739),
    [sym__procedure_header] = STATE(8087),
    [sym_procedure_modifier] = STATE(12657),
    [sym_trigger_declaration] = STATE(4854),
    [sym_var_section] = STATE(2739),
    [sym_attribute_item] = STATE(4853),
    [sym_preproc_conditional] = STATE(2739),
    [sym_preproc_if] = STATE(1393),
    [sym_preproc_elif] = STATE(1738),
    [sym_preproc_else] = STATE(2204),
    [sym_preproc_endif] = STATE(5934),
    [sym_preproc_conditional_actions] = STATE(4695),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(2739),
    [aux_sym_actions_section_repeat1] = STATE(4695),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_repeat1] = STATE(8094),
    [aux_sym_preproc_conditional_actions_repeat1] = STATE(7870),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3676),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3678),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token22] = ACTIONS(3680),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(3682),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3684),
    [aux_sym_modify_modification_token1] = ACTIONS(3686),
    [aux_sym_separator_action_token1] = ACTIONS(3688),
    [aux_sym_actionref_declaration_token1] = ACTIONS(3690),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(3692),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(3694),
    [aux_sym_customaction_declaration_token1] = ACTIONS(3696),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(2883),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(3698),
    [sym_group_keyword] = ACTIONS(3700),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(1395)] = {
    [sym_boolean] = STATE(4795),
    [sym_option_member_list] = STATE(4805),
    [sym_option_member] = STATE(4923),
    [sym_keyword_identifier] = STATE(4795),
    [sym_codeunit_keyword] = STATE(4642),
    [sym_xmlport_keyword] = STATE(4642),
    [sym_enum_keyword] = STATE(4642),
    [sym_keyword_as_identifier] = STATE(4795),
    [aux_sym_option_member_list_repeat2] = STATE(1397),
    [sym_identifier] = ACTIONS(2239),
    [anon_sym_SEMI] = ACTIONS(275),
    [anon_sym_DOT] = ACTIONS(277),
    [anon_sym_EQ] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(3702),
    [anon_sym_COLON] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(3704),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [anon_sym_RPAREN] = ACTIONS(275),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_DOT_DOT] = ACTIONS(275),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(275),
    [anon_sym_RBRACK] = ACTIONS(275),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(2221),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(275),
    [aux_sym__expression_token1] = ACTIONS(275),
    [aux_sym__expression_token2] = ACTIONS(275),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(917),
    [anon_sym_SLASH] = ACTIONS(277),
    [anon_sym_div] = ACTIONS(277),
    [anon_sym_DIV] = ACTIONS(277),
    [anon_sym_Div] = ACTIONS(277),
    [anon_sym_mod] = ACTIONS(277),
    [anon_sym_MOD] = ACTIONS(277),
    [anon_sym_Mod] = ACTIONS(277),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(275),
    [anon_sym_LT_EQ] = ACTIONS(275),
    [anon_sym_GT] = ACTIONS(277),
    [anon_sym_LT] = ACTIONS(277),
    [anon_sym_LT_GT] = ACTIONS(275),
    [anon_sym_and] = ACTIONS(277),
    [anon_sym_AND] = ACTIONS(277),
    [anon_sym_And] = ACTIONS(277),
    [anon_sym_or] = ACTIONS(277),
    [anon_sym_OR] = ACTIONS(277),
    [anon_sym_Or] = ACTIONS(277),
    [anon_sym_xor] = ACTIONS(277),
    [anon_sym_XOR] = ACTIONS(277),
    [anon_sym_Xor] = ACTIONS(277),
    [anon_sym_QMARK] = ACTIONS(275),
    [anon_sym_then] = ACTIONS(277),
    [anon_sym_THEN] = ACTIONS(277),
    [anon_sym_Then] = ACTIONS(277),
    [anon_sym_of] = ACTIONS(277),
    [anon_sym_OF] = ACTIONS(277),
    [anon_sym_Of] = ACTIONS(277),
    [anon_sym_do] = ACTIONS(277),
    [anon_sym_DO] = ACTIONS(277),
    [anon_sym_Do] = ACTIONS(277),
    [anon_sym_in] = ACTIONS(277),
    [anon_sym_IN] = ACTIONS(277),
    [anon_sym_In] = ACTIONS(277),
    [sym_page_keyword] = ACTIONS(917),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(917),
    [sym_query_keyword] = ACTIONS(917),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(2239),
    [sym_internal_keyword] = ACTIONS(2239),
    [sym_protected_keyword] = ACTIONS(2239),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_quoted_identifier] = ACTIONS(3706),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3706),
    [sym_integer] = ACTIONS(3706),
  },
  [STATE(1396)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(3710),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(3736),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3740),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(1397)] = {
    [sym_boolean] = STATE(4795),
    [sym_option_member] = STATE(4939),
    [sym_keyword_identifier] = STATE(4795),
    [sym_codeunit_keyword] = STATE(4642),
    [sym_xmlport_keyword] = STATE(4642),
    [sym_enum_keyword] = STATE(4642),
    [sym_keyword_as_identifier] = STATE(4795),
    [aux_sym_option_member_list_repeat2] = STATE(1654),
    [sym_identifier] = ACTIONS(2239),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(3744),
    [anon_sym_COLON] = ACTIONS(376),
    [anon_sym_DASH] = ACTIONS(3704),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [anon_sym_RPAREN] = ACTIONS(374),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_DOT_DOT] = ACTIONS(374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(374),
    [anon_sym_RBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(2221),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(374),
    [aux_sym__expression_token1] = ACTIONS(374),
    [aux_sym__expression_token2] = ACTIONS(374),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(917),
    [anon_sym_SLASH] = ACTIONS(376),
    [anon_sym_div] = ACTIONS(376),
    [anon_sym_DIV] = ACTIONS(376),
    [anon_sym_Div] = ACTIONS(376),
    [anon_sym_mod] = ACTIONS(376),
    [anon_sym_MOD] = ACTIONS(376),
    [anon_sym_Mod] = ACTIONS(376),
    [anon_sym_PLUS] = ACTIONS(376),
    [anon_sym_GT_EQ] = ACTIONS(374),
    [anon_sym_LT_EQ] = ACTIONS(374),
    [anon_sym_GT] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(376),
    [anon_sym_LT_GT] = ACTIONS(374),
    [anon_sym_and] = ACTIONS(376),
    [anon_sym_AND] = ACTIONS(376),
    [anon_sym_And] = ACTIONS(376),
    [anon_sym_or] = ACTIONS(376),
    [anon_sym_OR] = ACTIONS(376),
    [anon_sym_Or] = ACTIONS(376),
    [anon_sym_xor] = ACTIONS(376),
    [anon_sym_XOR] = ACTIONS(376),
    [anon_sym_Xor] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(374),
    [anon_sym_then] = ACTIONS(376),
    [anon_sym_THEN] = ACTIONS(376),
    [anon_sym_Then] = ACTIONS(376),
    [anon_sym_of] = ACTIONS(376),
    [anon_sym_OF] = ACTIONS(376),
    [anon_sym_Of] = ACTIONS(376),
    [anon_sym_do] = ACTIONS(376),
    [anon_sym_DO] = ACTIONS(376),
    [anon_sym_Do] = ACTIONS(376),
    [anon_sym_in] = ACTIONS(376),
    [anon_sym_IN] = ACTIONS(376),
    [anon_sym_In] = ACTIONS(376),
    [sym_page_keyword] = ACTIONS(917),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(917),
    [sym_query_keyword] = ACTIONS(917),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(2239),
    [sym_internal_keyword] = ACTIONS(2239),
    [sym_protected_keyword] = ACTIONS(2239),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_quoted_identifier] = ACTIONS(3706),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3706),
    [sym_integer] = ACTIONS(3706),
  },
  [STATE(1398)] = {
    [sym_boolean] = STATE(1741),
    [sym_preproc_if] = STATE(2441),
    [sym_preproc_elif] = STATE(1732),
    [sym_preproc_else] = STATE(2108),
    [sym_preproc_endif] = STATE(2550),
    [sym_assignment_expression] = STATE(6354),
    [sym_case_branch] = STATE(1522),
    [sym_preproc_split_case_branch] = STATE(3395),
    [aux_sym__case_pattern] = STATE(2579),
    [sym_preproc_conditional_case_patterns] = STATE(2579),
    [sym__single_pattern] = STATE(3450),
    [sym_case_else_branch] = STATE(7977),
    [sym__expression] = STATE(6354),
    [sym_keyword_identifier] = STATE(1684),
    [sym_range_expression] = STATE(1741),
    [sym_multiplicative_expression] = STATE(1741),
    [sym_additive_expression] = STATE(1741),
    [sym_comparison_expression] = STATE(1741),
    [sym_logical_expression] = STATE(1741),
    [sym_ternary_expression] = STATE(6354),
    [sym_unary_expression] = STATE(1741),
    [sym_call_expression] = STATE(1734),
    [sym_member_expression] = STATE(1684),
    [sym_subscript_expression] = STATE(1684),
    [sym_parenthesized_expression] = STATE(1741),
    [sym_list_literal] = STATE(6354),
    [sym_qualified_enum_value] = STATE(1684),
    [sym_database_reference] = STATE(1741),
    [sym__literal_value] = STATE(1741),
    [sym_else_keyword] = STATE(87),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(1522),
    [aux_sym_preproc_conditional_case_repeat2] = STATE(7978),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2431),
    [aux_sym_preproc_split_case_branch_repeat2] = STATE(7979),
    [sym_identifier] = ACTIONS(3746),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(3748),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(3752),
    [sym_date_literal] = ACTIONS(3748),
    [sym_time_literal] = ACTIONS(3748),
    [sym_biginteger_literal] = ACTIONS(3752),
    [anon_sym_else] = ACTIONS(3754),
    [anon_sym_ELSE] = ACTIONS(3754),
    [anon_sym_Else] = ACTIONS(3754),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(3756),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3752),
    [sym_integer] = ACTIONS(3748),
    [sym_continue_as_identifier] = ACTIONS(3758),
    [sym_preproc_open] = ACTIONS(3750),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(1399)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2430),
    [anon_sym_SEMI] = ACTIONS(2432),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2432),
    [anon_sym_COMMA] = ACTIONS(2432),
    [anon_sym_COLON] = ACTIONS(2430),
    [anon_sym_DASH] = ACTIONS(2430),
    [aux_sym_boolean_token1] = ACTIONS(2430),
    [aux_sym_boolean_token2] = ACTIONS(2430),
    [sym_decimal] = ACTIONS(2430),
    [anon_sym_LPAREN] = ACTIONS(2432),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2430),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2430),
    [aux_sym_basic_type_token21] = ACTIONS(2430),
    [aux_sym_basic_type_token22] = ACTIONS(2430),
    [aux_sym_basic_type_token48] = ACTIONS(2430),
    [anon_sym_POUNDif] = ACTIONS(2432),
    [anon_sym_POUNDIF] = ACTIONS(2432),
    [anon_sym_POUNDIf] = ACTIONS(2432),
    [anon_sym_not] = ACTIONS(2430),
    [anon_sym_NOT] = ACTIONS(2430),
    [anon_sym_Not] = ACTIONS(2430),
    [anon_sym_POUNDelif] = ACTIONS(2432),
    [anon_sym_POUNDELIF] = ACTIONS(2432),
    [anon_sym_POUNDElif] = ACTIONS(2432),
    [anon_sym_POUNDelse] = ACTIONS(2432),
    [anon_sym_POUNDELSE] = ACTIONS(2432),
    [anon_sym_POUNDElse] = ACTIONS(2432),
    [anon_sym_POUNDendif] = ACTIONS(2432),
    [anon_sym_POUNDENDIF] = ACTIONS(2432),
    [anon_sym_POUNDEndif] = ACTIONS(2432),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2432),
    [aux_sym__expression_token1] = ACTIONS(2432),
    [aux_sym__expression_token2] = ACTIONS(2432),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2430),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2430),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(2430),
    [anon_sym_GT_EQ] = ACTIONS(2432),
    [anon_sym_LT_EQ] = ACTIONS(2432),
    [anon_sym_GT] = ACTIONS(2430),
    [anon_sym_LT] = ACTIONS(2430),
    [anon_sym_LT_GT] = ACTIONS(2432),
    [anon_sym_and] = ACTIONS(2430),
    [anon_sym_AND] = ACTIONS(2430),
    [anon_sym_And] = ACTIONS(2430),
    [anon_sym_or] = ACTIONS(2430),
    [anon_sym_OR] = ACTIONS(2430),
    [anon_sym_Or] = ACTIONS(2430),
    [anon_sym_xor] = ACTIONS(2430),
    [anon_sym_XOR] = ACTIONS(2430),
    [anon_sym_Xor] = ACTIONS(2430),
    [anon_sym_QMARK] = ACTIONS(2432),
    [sym_datetime_literal] = ACTIONS(2432),
    [sym_date_literal] = ACTIONS(2430),
    [sym_time_literal] = ACTIONS(2430),
    [sym_biginteger_literal] = ACTIONS(2432),
    [anon_sym_else] = ACTIONS(2430),
    [anon_sym_ELSE] = ACTIONS(2430),
    [anon_sym_Else] = ACTIONS(2430),
    [anon_sym_in] = ACTIONS(2430),
    [anon_sym_IN] = ACTIONS(2430),
    [anon_sym_In] = ACTIONS(2430),
    [sym_page_keyword] = ACTIONS(2430),
    [anon_sym_codeunit] = ACTIONS(2430),
    [anon_sym_CODEUNIT] = ACTIONS(2430),
    [anon_sym_Codeunit] = ACTIONS(2430),
    [anon_sym_CodeUnit] = ACTIONS(2430),
    [anon_sym_COdeunit] = ACTIONS(2430),
    [anon_sym_codeUnit] = ACTIONS(2430),
    [sym_report_keyword] = ACTIONS(2430),
    [sym_query_keyword] = ACTIONS(2430),
    [anon_sym_xmlport] = ACTIONS(2430),
    [anon_sym_XMLPORT] = ACTIONS(2430),
    [anon_sym_Xmlport] = ACTIONS(2430),
    [anon_sym_XMLport] = ACTIONS(2430),
    [anon_sym_XMLPort] = ACTIONS(2430),
    [anon_sym_XmlPort] = ACTIONS(2430),
    [anon_sym_enum] = ACTIONS(2430),
    [anon_sym_ENUM] = ACTIONS(2430),
    [anon_sym_Enum] = ACTIONS(2430),
    [anon_sym_eNUM] = ACTIONS(2430),
    [anon_sym_eNum] = ACTIONS(2430),
    [anon_sym_ENum] = ACTIONS(2430),
    [sym_quoted_identifier] = ACTIONS(2432),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2432),
    [sym_integer] = ACTIONS(2430),
    [sym_continue_as_identifier] = ACTIONS(2432),
    [sym_preproc_open] = ACTIONS(2432),
    [sym_preproc_close] = ACTIONS(2432),
  },
  [STATE(1400)] = {
    [sym_argument_list] = STATE(1432),
    [sym_identifier] = ACTIONS(2434),
    [anon_sym_SEMI] = ACTIONS(2436),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_COMMA] = ACTIONS(2436),
    [anon_sym_COLON] = ACTIONS(2434),
    [anon_sym_DASH] = ACTIONS(2434),
    [aux_sym_boolean_token1] = ACTIONS(2434),
    [aux_sym_boolean_token2] = ACTIONS(2434),
    [sym_decimal] = ACTIONS(2434),
    [anon_sym_LPAREN] = ACTIONS(3760),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2434),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [aux_sym_record_type_token1] = ACTIONS(2434),
    [aux_sym_basic_type_token21] = ACTIONS(2434),
    [aux_sym_basic_type_token22] = ACTIONS(2434),
    [aux_sym_basic_type_token48] = ACTIONS(2434),
    [anon_sym_COLON_COLON] = ACTIONS(3762),
    [anon_sym_POUNDif] = ACTIONS(2436),
    [anon_sym_POUNDIF] = ACTIONS(2436),
    [anon_sym_POUNDIf] = ACTIONS(2436),
    [anon_sym_not] = ACTIONS(2434),
    [anon_sym_NOT] = ACTIONS(2434),
    [anon_sym_Not] = ACTIONS(2434),
    [anon_sym_POUNDelif] = ACTIONS(2436),
    [anon_sym_POUNDELIF] = ACTIONS(2436),
    [anon_sym_POUNDElif] = ACTIONS(2436),
    [anon_sym_POUNDelse] = ACTIONS(2436),
    [anon_sym_POUNDELSE] = ACTIONS(2436),
    [anon_sym_POUNDElse] = ACTIONS(2436),
    [anon_sym_POUNDendif] = ACTIONS(2436),
    [anon_sym_POUNDENDIF] = ACTIONS(2436),
    [anon_sym_POUNDEndif] = ACTIONS(2436),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2434),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(2434),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(2436),
    [sym_date_literal] = ACTIONS(2434),
    [sym_time_literal] = ACTIONS(2434),
    [sym_biginteger_literal] = ACTIONS(2436),
    [anon_sym_else] = ACTIONS(2434),
    [anon_sym_ELSE] = ACTIONS(2434),
    [anon_sym_Else] = ACTIONS(2434),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(2434),
    [anon_sym_codeunit] = ACTIONS(2434),
    [anon_sym_CODEUNIT] = ACTIONS(2434),
    [anon_sym_Codeunit] = ACTIONS(2434),
    [anon_sym_CodeUnit] = ACTIONS(2434),
    [anon_sym_COdeunit] = ACTIONS(2434),
    [anon_sym_codeUnit] = ACTIONS(2434),
    [sym_report_keyword] = ACTIONS(2434),
    [sym_query_keyword] = ACTIONS(2434),
    [anon_sym_xmlport] = ACTIONS(2434),
    [anon_sym_XMLPORT] = ACTIONS(2434),
    [anon_sym_Xmlport] = ACTIONS(2434),
    [anon_sym_XMLport] = ACTIONS(2434),
    [anon_sym_XMLPort] = ACTIONS(2434),
    [anon_sym_XmlPort] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2434),
    [anon_sym_ENUM] = ACTIONS(2434),
    [anon_sym_Enum] = ACTIONS(2434),
    [anon_sym_eNUM] = ACTIONS(2434),
    [anon_sym_eNum] = ACTIONS(2434),
    [anon_sym_ENum] = ACTIONS(2434),
    [sym_quoted_identifier] = ACTIONS(2436),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2436),
    [sym_integer] = ACTIONS(2434),
    [sym_continue_as_identifier] = ACTIONS(2436),
    [sym_preproc_open] = ACTIONS(2436),
    [sym_preproc_close] = ACTIONS(2436),
  },
  [STATE(1401)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2360),
    [anon_sym_SEMI] = ACTIONS(2362),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2362),
    [anon_sym_COMMA] = ACTIONS(2362),
    [anon_sym_COLON] = ACTIONS(2360),
    [anon_sym_DASH] = ACTIONS(2360),
    [aux_sym_boolean_token1] = ACTIONS(2360),
    [aux_sym_boolean_token2] = ACTIONS(2360),
    [sym_decimal] = ACTIONS(2360),
    [anon_sym_LPAREN] = ACTIONS(2362),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2360),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2360),
    [aux_sym_basic_type_token21] = ACTIONS(2360),
    [aux_sym_basic_type_token22] = ACTIONS(2360),
    [aux_sym_basic_type_token48] = ACTIONS(2360),
    [anon_sym_POUNDif] = ACTIONS(2362),
    [anon_sym_POUNDIF] = ACTIONS(2362),
    [anon_sym_POUNDIf] = ACTIONS(2362),
    [anon_sym_not] = ACTIONS(2360),
    [anon_sym_NOT] = ACTIONS(2360),
    [anon_sym_Not] = ACTIONS(2360),
    [anon_sym_POUNDelif] = ACTIONS(2362),
    [anon_sym_POUNDELIF] = ACTIONS(2362),
    [anon_sym_POUNDElif] = ACTIONS(2362),
    [anon_sym_POUNDelse] = ACTIONS(2362),
    [anon_sym_POUNDELSE] = ACTIONS(2362),
    [anon_sym_POUNDElse] = ACTIONS(2362),
    [anon_sym_POUNDendif] = ACTIONS(2362),
    [anon_sym_POUNDENDIF] = ACTIONS(2362),
    [anon_sym_POUNDEndif] = ACTIONS(2362),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2362),
    [aux_sym__expression_token1] = ACTIONS(2362),
    [aux_sym__expression_token2] = ACTIONS(2362),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2360),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(2360),
    [anon_sym_GT_EQ] = ACTIONS(2362),
    [anon_sym_LT_EQ] = ACTIONS(2362),
    [anon_sym_GT] = ACTIONS(2360),
    [anon_sym_LT] = ACTIONS(2360),
    [anon_sym_LT_GT] = ACTIONS(2362),
    [anon_sym_and] = ACTIONS(2360),
    [anon_sym_AND] = ACTIONS(2360),
    [anon_sym_And] = ACTIONS(2360),
    [anon_sym_or] = ACTIONS(2360),
    [anon_sym_OR] = ACTIONS(2360),
    [anon_sym_Or] = ACTIONS(2360),
    [anon_sym_xor] = ACTIONS(2360),
    [anon_sym_XOR] = ACTIONS(2360),
    [anon_sym_Xor] = ACTIONS(2360),
    [anon_sym_QMARK] = ACTIONS(2362),
    [sym_datetime_literal] = ACTIONS(2362),
    [sym_date_literal] = ACTIONS(2360),
    [sym_time_literal] = ACTIONS(2360),
    [sym_biginteger_literal] = ACTIONS(2362),
    [anon_sym_else] = ACTIONS(2360),
    [anon_sym_ELSE] = ACTIONS(2360),
    [anon_sym_Else] = ACTIONS(2360),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_IN] = ACTIONS(2360),
    [anon_sym_In] = ACTIONS(2360),
    [sym_page_keyword] = ACTIONS(2360),
    [anon_sym_codeunit] = ACTIONS(2360),
    [anon_sym_CODEUNIT] = ACTIONS(2360),
    [anon_sym_Codeunit] = ACTIONS(2360),
    [anon_sym_CodeUnit] = ACTIONS(2360),
    [anon_sym_COdeunit] = ACTIONS(2360),
    [anon_sym_codeUnit] = ACTIONS(2360),
    [sym_report_keyword] = ACTIONS(2360),
    [sym_query_keyword] = ACTIONS(2360),
    [anon_sym_xmlport] = ACTIONS(2360),
    [anon_sym_XMLPORT] = ACTIONS(2360),
    [anon_sym_Xmlport] = ACTIONS(2360),
    [anon_sym_XMLport] = ACTIONS(2360),
    [anon_sym_XMLPort] = ACTIONS(2360),
    [anon_sym_XmlPort] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_ENUM] = ACTIONS(2360),
    [anon_sym_Enum] = ACTIONS(2360),
    [anon_sym_eNUM] = ACTIONS(2360),
    [anon_sym_eNum] = ACTIONS(2360),
    [anon_sym_ENum] = ACTIONS(2360),
    [sym_quoted_identifier] = ACTIONS(2362),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2362),
    [sym_integer] = ACTIONS(2360),
    [sym_continue_as_identifier] = ACTIONS(2362),
    [sym_preproc_open] = ACTIONS(2362),
    [sym_preproc_close] = ACTIONS(2362),
  },
  [STATE(1402)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2316),
    [anon_sym_SEMI] = ACTIONS(2318),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2318),
    [anon_sym_COMMA] = ACTIONS(2318),
    [anon_sym_COLON] = ACTIONS(2316),
    [anon_sym_DASH] = ACTIONS(2316),
    [aux_sym_boolean_token1] = ACTIONS(2316),
    [aux_sym_boolean_token2] = ACTIONS(2316),
    [sym_decimal] = ACTIONS(2316),
    [anon_sym_LPAREN] = ACTIONS(2318),
    [anon_sym_DOT_DOT] = ACTIONS(2318),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2316),
    [anon_sym_STAR] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2316),
    [aux_sym_basic_type_token21] = ACTIONS(2316),
    [aux_sym_basic_type_token22] = ACTIONS(2316),
    [aux_sym_basic_type_token48] = ACTIONS(2316),
    [anon_sym_POUNDif] = ACTIONS(2318),
    [anon_sym_POUNDIF] = ACTIONS(2318),
    [anon_sym_POUNDIf] = ACTIONS(2318),
    [anon_sym_not] = ACTIONS(2316),
    [anon_sym_NOT] = ACTIONS(2316),
    [anon_sym_Not] = ACTIONS(2316),
    [anon_sym_POUNDelif] = ACTIONS(2318),
    [anon_sym_POUNDELIF] = ACTIONS(2318),
    [anon_sym_POUNDElif] = ACTIONS(2318),
    [anon_sym_POUNDelse] = ACTIONS(2318),
    [anon_sym_POUNDELSE] = ACTIONS(2318),
    [anon_sym_POUNDElse] = ACTIONS(2318),
    [anon_sym_POUNDendif] = ACTIONS(2318),
    [anon_sym_POUNDENDIF] = ACTIONS(2318),
    [anon_sym_POUNDEndif] = ACTIONS(2318),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2318),
    [aux_sym__expression_token1] = ACTIONS(2318),
    [aux_sym__expression_token2] = ACTIONS(2318),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2316),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2316),
    [anon_sym_SLASH] = ACTIONS(2316),
    [anon_sym_div] = ACTIONS(2316),
    [anon_sym_DIV] = ACTIONS(2316),
    [anon_sym_Div] = ACTIONS(2316),
    [anon_sym_mod] = ACTIONS(2316),
    [anon_sym_MOD] = ACTIONS(2316),
    [anon_sym_Mod] = ACTIONS(2316),
    [anon_sym_PLUS] = ACTIONS(2316),
    [anon_sym_GT_EQ] = ACTIONS(2318),
    [anon_sym_LT_EQ] = ACTIONS(2318),
    [anon_sym_GT] = ACTIONS(2316),
    [anon_sym_LT] = ACTIONS(2316),
    [anon_sym_LT_GT] = ACTIONS(2318),
    [anon_sym_and] = ACTIONS(2316),
    [anon_sym_AND] = ACTIONS(2316),
    [anon_sym_And] = ACTIONS(2316),
    [anon_sym_or] = ACTIONS(2316),
    [anon_sym_OR] = ACTIONS(2316),
    [anon_sym_Or] = ACTIONS(2316),
    [anon_sym_xor] = ACTIONS(2316),
    [anon_sym_XOR] = ACTIONS(2316),
    [anon_sym_Xor] = ACTIONS(2316),
    [anon_sym_QMARK] = ACTIONS(2318),
    [sym_datetime_literal] = ACTIONS(2318),
    [sym_date_literal] = ACTIONS(2316),
    [sym_time_literal] = ACTIONS(2316),
    [sym_biginteger_literal] = ACTIONS(2318),
    [anon_sym_else] = ACTIONS(2316),
    [anon_sym_ELSE] = ACTIONS(2316),
    [anon_sym_Else] = ACTIONS(2316),
    [anon_sym_in] = ACTIONS(2316),
    [anon_sym_IN] = ACTIONS(2316),
    [anon_sym_In] = ACTIONS(2316),
    [sym_page_keyword] = ACTIONS(2316),
    [anon_sym_codeunit] = ACTIONS(2316),
    [anon_sym_CODEUNIT] = ACTIONS(2316),
    [anon_sym_Codeunit] = ACTIONS(2316),
    [anon_sym_CodeUnit] = ACTIONS(2316),
    [anon_sym_COdeunit] = ACTIONS(2316),
    [anon_sym_codeUnit] = ACTIONS(2316),
    [sym_report_keyword] = ACTIONS(2316),
    [sym_query_keyword] = ACTIONS(2316),
    [anon_sym_xmlport] = ACTIONS(2316),
    [anon_sym_XMLPORT] = ACTIONS(2316),
    [anon_sym_Xmlport] = ACTIONS(2316),
    [anon_sym_XMLport] = ACTIONS(2316),
    [anon_sym_XMLPort] = ACTIONS(2316),
    [anon_sym_XmlPort] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_ENUM] = ACTIONS(2316),
    [anon_sym_Enum] = ACTIONS(2316),
    [anon_sym_eNUM] = ACTIONS(2316),
    [anon_sym_eNum] = ACTIONS(2316),
    [anon_sym_ENum] = ACTIONS(2316),
    [sym_quoted_identifier] = ACTIONS(2318),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2318),
    [sym_integer] = ACTIONS(2316),
    [sym_continue_as_identifier] = ACTIONS(2318),
    [sym_preproc_open] = ACTIONS(2318),
    [sym_preproc_close] = ACTIONS(2318),
  },
  [STATE(1403)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_COLON] = ACTIONS(2320),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(1404)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2326),
    [anon_sym_SEMI] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2328),
    [anon_sym_COLON] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(3710),
    [aux_sym_boolean_token1] = ACTIONS(2326),
    [aux_sym_boolean_token2] = ACTIONS(2326),
    [sym_decimal] = ACTIONS(2326),
    [anon_sym_LPAREN] = ACTIONS(2328),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2326),
    [aux_sym_basic_type_token21] = ACTIONS(2326),
    [aux_sym_basic_type_token22] = ACTIONS(2326),
    [aux_sym_basic_type_token48] = ACTIONS(2326),
    [anon_sym_POUNDif] = ACTIONS(2328),
    [anon_sym_POUNDIF] = ACTIONS(2328),
    [anon_sym_POUNDIf] = ACTIONS(2328),
    [anon_sym_not] = ACTIONS(2326),
    [anon_sym_NOT] = ACTIONS(2326),
    [anon_sym_Not] = ACTIONS(2326),
    [anon_sym_POUNDelif] = ACTIONS(2328),
    [anon_sym_POUNDELIF] = ACTIONS(2328),
    [anon_sym_POUNDElif] = ACTIONS(2328),
    [anon_sym_POUNDelse] = ACTIONS(2328),
    [anon_sym_POUNDELSE] = ACTIONS(2328),
    [anon_sym_POUNDElse] = ACTIONS(2328),
    [anon_sym_POUNDendif] = ACTIONS(2328),
    [anon_sym_POUNDENDIF] = ACTIONS(2328),
    [anon_sym_POUNDEndif] = ACTIONS(2328),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3764),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2326),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2326),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(3736),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3740),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(3766),
    [anon_sym_OR] = ACTIONS(3768),
    [anon_sym_Or] = ACTIONS(3770),
    [anon_sym_xor] = ACTIONS(3772),
    [anon_sym_XOR] = ACTIONS(3774),
    [anon_sym_Xor] = ACTIONS(3776),
    [anon_sym_QMARK] = ACTIONS(3778),
    [sym_datetime_literal] = ACTIONS(2328),
    [sym_date_literal] = ACTIONS(2326),
    [sym_time_literal] = ACTIONS(2326),
    [sym_biginteger_literal] = ACTIONS(2328),
    [anon_sym_else] = ACTIONS(2326),
    [anon_sym_ELSE] = ACTIONS(2326),
    [anon_sym_Else] = ACTIONS(2326),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2326),
    [anon_sym_codeunit] = ACTIONS(2326),
    [anon_sym_CODEUNIT] = ACTIONS(2326),
    [anon_sym_Codeunit] = ACTIONS(2326),
    [anon_sym_CodeUnit] = ACTIONS(2326),
    [anon_sym_COdeunit] = ACTIONS(2326),
    [anon_sym_codeUnit] = ACTIONS(2326),
    [sym_report_keyword] = ACTIONS(2326),
    [sym_query_keyword] = ACTIONS(2326),
    [anon_sym_xmlport] = ACTIONS(2326),
    [anon_sym_XMLPORT] = ACTIONS(2326),
    [anon_sym_Xmlport] = ACTIONS(2326),
    [anon_sym_XMLport] = ACTIONS(2326),
    [anon_sym_XMLPort] = ACTIONS(2326),
    [anon_sym_XmlPort] = ACTIONS(2326),
    [anon_sym_enum] = ACTIONS(2326),
    [anon_sym_ENUM] = ACTIONS(2326),
    [anon_sym_Enum] = ACTIONS(2326),
    [anon_sym_eNUM] = ACTIONS(2326),
    [anon_sym_eNum] = ACTIONS(2326),
    [anon_sym_ENum] = ACTIONS(2326),
    [sym_quoted_identifier] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2328),
    [sym_integer] = ACTIONS(2326),
    [sym_continue_as_identifier] = ACTIONS(2328),
    [sym_preproc_open] = ACTIONS(2328),
    [sym_preproc_close] = ACTIONS(2328),
  },
  [STATE(1405)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_COLON] = ACTIONS(2320),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(1406)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_COLON] = ACTIONS(2320),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(1407)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_COLON] = ACTIONS(2320),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(1408)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_COLON] = ACTIONS(2320),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(1409)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_COLON] = ACTIONS(2320),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(1410)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_COLON] = ACTIONS(2320),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(1411)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_COLON] = ACTIONS(2320),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(1412)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2360),
    [anon_sym_SEMI] = ACTIONS(2362),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2362),
    [anon_sym_COMMA] = ACTIONS(2362),
    [anon_sym_COLON] = ACTIONS(2360),
    [anon_sym_DASH] = ACTIONS(2360),
    [aux_sym_boolean_token1] = ACTIONS(2360),
    [aux_sym_boolean_token2] = ACTIONS(2360),
    [sym_decimal] = ACTIONS(2360),
    [anon_sym_LPAREN] = ACTIONS(2362),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2360),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2360),
    [aux_sym_basic_type_token21] = ACTIONS(2360),
    [aux_sym_basic_type_token22] = ACTIONS(2360),
    [aux_sym_basic_type_token48] = ACTIONS(2360),
    [anon_sym_POUNDif] = ACTIONS(2362),
    [anon_sym_POUNDIF] = ACTIONS(2362),
    [anon_sym_POUNDIf] = ACTIONS(2362),
    [anon_sym_not] = ACTIONS(2360),
    [anon_sym_NOT] = ACTIONS(2360),
    [anon_sym_Not] = ACTIONS(2360),
    [anon_sym_POUNDelif] = ACTIONS(2362),
    [anon_sym_POUNDELIF] = ACTIONS(2362),
    [anon_sym_POUNDElif] = ACTIONS(2362),
    [anon_sym_POUNDelse] = ACTIONS(2362),
    [anon_sym_POUNDELSE] = ACTIONS(2362),
    [anon_sym_POUNDElse] = ACTIONS(2362),
    [anon_sym_POUNDendif] = ACTIONS(2362),
    [anon_sym_POUNDENDIF] = ACTIONS(2362),
    [anon_sym_POUNDEndif] = ACTIONS(2362),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2362),
    [aux_sym__expression_token1] = ACTIONS(2362),
    [aux_sym__expression_token2] = ACTIONS(2362),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2360),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(2360),
    [anon_sym_GT_EQ] = ACTIONS(2362),
    [anon_sym_LT_EQ] = ACTIONS(2362),
    [anon_sym_GT] = ACTIONS(2360),
    [anon_sym_LT] = ACTIONS(2360),
    [anon_sym_LT_GT] = ACTIONS(2362),
    [anon_sym_and] = ACTIONS(2360),
    [anon_sym_AND] = ACTIONS(2360),
    [anon_sym_And] = ACTIONS(2360),
    [anon_sym_or] = ACTIONS(2360),
    [anon_sym_OR] = ACTIONS(2360),
    [anon_sym_Or] = ACTIONS(2360),
    [anon_sym_xor] = ACTIONS(2360),
    [anon_sym_XOR] = ACTIONS(2360),
    [anon_sym_Xor] = ACTIONS(2360),
    [anon_sym_QMARK] = ACTIONS(2362),
    [sym_datetime_literal] = ACTIONS(2362),
    [sym_date_literal] = ACTIONS(2360),
    [sym_time_literal] = ACTIONS(2360),
    [sym_biginteger_literal] = ACTIONS(2362),
    [anon_sym_else] = ACTIONS(2360),
    [anon_sym_ELSE] = ACTIONS(2360),
    [anon_sym_Else] = ACTIONS(2360),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_IN] = ACTIONS(2360),
    [anon_sym_In] = ACTIONS(2360),
    [sym_page_keyword] = ACTIONS(2360),
    [anon_sym_codeunit] = ACTIONS(2360),
    [anon_sym_CODEUNIT] = ACTIONS(2360),
    [anon_sym_Codeunit] = ACTIONS(2360),
    [anon_sym_CodeUnit] = ACTIONS(2360),
    [anon_sym_COdeunit] = ACTIONS(2360),
    [anon_sym_codeUnit] = ACTIONS(2360),
    [sym_report_keyword] = ACTIONS(2360),
    [sym_query_keyword] = ACTIONS(2360),
    [anon_sym_xmlport] = ACTIONS(2360),
    [anon_sym_XMLPORT] = ACTIONS(2360),
    [anon_sym_Xmlport] = ACTIONS(2360),
    [anon_sym_XMLport] = ACTIONS(2360),
    [anon_sym_XMLPort] = ACTIONS(2360),
    [anon_sym_XmlPort] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_ENUM] = ACTIONS(2360),
    [anon_sym_Enum] = ACTIONS(2360),
    [anon_sym_eNUM] = ACTIONS(2360),
    [anon_sym_eNum] = ACTIONS(2360),
    [anon_sym_ENum] = ACTIONS(2360),
    [sym_quoted_identifier] = ACTIONS(2362),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2362),
    [sym_integer] = ACTIONS(2360),
    [sym_continue_as_identifier] = ACTIONS(2362),
    [sym_preproc_open] = ACTIONS(2362),
    [sym_preproc_close] = ACTIONS(2362),
  },
  [STATE(1413)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(3710),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(3736),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(1414)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(3710),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(3736),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(1415)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(3710),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(3736),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(1416)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(3710),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(3736),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3740),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(1417)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(3710),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(3736),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3740),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(1418)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(3710),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(3736),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3740),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(1419)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(3710),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(3736),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3740),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(1420)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(3710),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(3736),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3740),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(1421)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2364),
    [anon_sym_SEMI] = ACTIONS(2366),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2366),
    [anon_sym_COMMA] = ACTIONS(2366),
    [anon_sym_COLON] = ACTIONS(2364),
    [anon_sym_DASH] = ACTIONS(3710),
    [aux_sym_boolean_token1] = ACTIONS(2364),
    [aux_sym_boolean_token2] = ACTIONS(2364),
    [sym_decimal] = ACTIONS(2364),
    [anon_sym_LPAREN] = ACTIONS(2366),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2364),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2364),
    [aux_sym_basic_type_token21] = ACTIONS(2364),
    [aux_sym_basic_type_token22] = ACTIONS(2364),
    [aux_sym_basic_type_token48] = ACTIONS(2364),
    [anon_sym_POUNDif] = ACTIONS(2366),
    [anon_sym_POUNDIF] = ACTIONS(2366),
    [anon_sym_POUNDIf] = ACTIONS(2366),
    [anon_sym_not] = ACTIONS(2364),
    [anon_sym_NOT] = ACTIONS(2364),
    [anon_sym_Not] = ACTIONS(2364),
    [anon_sym_POUNDelif] = ACTIONS(2366),
    [anon_sym_POUNDELIF] = ACTIONS(2366),
    [anon_sym_POUNDElif] = ACTIONS(2366),
    [anon_sym_POUNDelse] = ACTIONS(2366),
    [anon_sym_POUNDELSE] = ACTIONS(2366),
    [anon_sym_POUNDElse] = ACTIONS(2366),
    [anon_sym_POUNDendif] = ACTIONS(2366),
    [anon_sym_POUNDENDIF] = ACTIONS(2366),
    [anon_sym_POUNDEndif] = ACTIONS(2366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2366),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2364),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2364),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(3736),
    [anon_sym_GT_EQ] = ACTIONS(2366),
    [anon_sym_LT_EQ] = ACTIONS(2366),
    [anon_sym_GT] = ACTIONS(2364),
    [anon_sym_LT] = ACTIONS(2364),
    [anon_sym_LT_GT] = ACTIONS(2366),
    [anon_sym_and] = ACTIONS(2364),
    [anon_sym_AND] = ACTIONS(2364),
    [anon_sym_And] = ACTIONS(2364),
    [anon_sym_or] = ACTIONS(2364),
    [anon_sym_OR] = ACTIONS(2364),
    [anon_sym_Or] = ACTIONS(2364),
    [anon_sym_xor] = ACTIONS(2364),
    [anon_sym_XOR] = ACTIONS(2364),
    [anon_sym_Xor] = ACTIONS(2364),
    [anon_sym_QMARK] = ACTIONS(2366),
    [sym_datetime_literal] = ACTIONS(2366),
    [sym_date_literal] = ACTIONS(2364),
    [sym_time_literal] = ACTIONS(2364),
    [sym_biginteger_literal] = ACTIONS(2366),
    [anon_sym_else] = ACTIONS(2364),
    [anon_sym_ELSE] = ACTIONS(2364),
    [anon_sym_Else] = ACTIONS(2364),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2364),
    [anon_sym_codeunit] = ACTIONS(2364),
    [anon_sym_CODEUNIT] = ACTIONS(2364),
    [anon_sym_Codeunit] = ACTIONS(2364),
    [anon_sym_CodeUnit] = ACTIONS(2364),
    [anon_sym_COdeunit] = ACTIONS(2364),
    [anon_sym_codeUnit] = ACTIONS(2364),
    [sym_report_keyword] = ACTIONS(2364),
    [sym_query_keyword] = ACTIONS(2364),
    [anon_sym_xmlport] = ACTIONS(2364),
    [anon_sym_XMLPORT] = ACTIONS(2364),
    [anon_sym_Xmlport] = ACTIONS(2364),
    [anon_sym_XMLport] = ACTIONS(2364),
    [anon_sym_XMLPort] = ACTIONS(2364),
    [anon_sym_XmlPort] = ACTIONS(2364),
    [anon_sym_enum] = ACTIONS(2364),
    [anon_sym_ENUM] = ACTIONS(2364),
    [anon_sym_Enum] = ACTIONS(2364),
    [anon_sym_eNUM] = ACTIONS(2364),
    [anon_sym_eNum] = ACTIONS(2364),
    [anon_sym_ENum] = ACTIONS(2364),
    [sym_quoted_identifier] = ACTIONS(2366),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2366),
    [sym_integer] = ACTIONS(2364),
    [sym_continue_as_identifier] = ACTIONS(2366),
    [sym_preproc_open] = ACTIONS(2366),
    [sym_preproc_close] = ACTIONS(2366),
  },
  [STATE(1422)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2368),
    [anon_sym_SEMI] = ACTIONS(2370),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2370),
    [anon_sym_COLON] = ACTIONS(2368),
    [anon_sym_DASH] = ACTIONS(3710),
    [aux_sym_boolean_token1] = ACTIONS(2368),
    [aux_sym_boolean_token2] = ACTIONS(2368),
    [sym_decimal] = ACTIONS(2368),
    [anon_sym_LPAREN] = ACTIONS(2370),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2368),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2368),
    [aux_sym_basic_type_token21] = ACTIONS(2368),
    [aux_sym_basic_type_token22] = ACTIONS(2368),
    [aux_sym_basic_type_token48] = ACTIONS(2368),
    [anon_sym_POUNDif] = ACTIONS(2370),
    [anon_sym_POUNDIF] = ACTIONS(2370),
    [anon_sym_POUNDIf] = ACTIONS(2370),
    [anon_sym_not] = ACTIONS(2368),
    [anon_sym_NOT] = ACTIONS(2368),
    [anon_sym_Not] = ACTIONS(2368),
    [anon_sym_POUNDelif] = ACTIONS(2370),
    [anon_sym_POUNDELIF] = ACTIONS(2370),
    [anon_sym_POUNDElif] = ACTIONS(2370),
    [anon_sym_POUNDelse] = ACTIONS(2370),
    [anon_sym_POUNDELSE] = ACTIONS(2370),
    [anon_sym_POUNDElse] = ACTIONS(2370),
    [anon_sym_POUNDendif] = ACTIONS(2370),
    [anon_sym_POUNDENDIF] = ACTIONS(2370),
    [anon_sym_POUNDEndif] = ACTIONS(2370),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2370),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2368),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2368),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(3736),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3740),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(3766),
    [anon_sym_OR] = ACTIONS(3768),
    [anon_sym_Or] = ACTIONS(3770),
    [anon_sym_xor] = ACTIONS(3772),
    [anon_sym_XOR] = ACTIONS(3774),
    [anon_sym_Xor] = ACTIONS(3776),
    [anon_sym_QMARK] = ACTIONS(3778),
    [sym_datetime_literal] = ACTIONS(2370),
    [sym_date_literal] = ACTIONS(2368),
    [sym_time_literal] = ACTIONS(2368),
    [sym_biginteger_literal] = ACTIONS(2370),
    [anon_sym_else] = ACTIONS(2368),
    [anon_sym_ELSE] = ACTIONS(2368),
    [anon_sym_Else] = ACTIONS(2368),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2368),
    [anon_sym_codeunit] = ACTIONS(2368),
    [anon_sym_CODEUNIT] = ACTIONS(2368),
    [anon_sym_Codeunit] = ACTIONS(2368),
    [anon_sym_CodeUnit] = ACTIONS(2368),
    [anon_sym_COdeunit] = ACTIONS(2368),
    [anon_sym_codeUnit] = ACTIONS(2368),
    [sym_report_keyword] = ACTIONS(2368),
    [sym_query_keyword] = ACTIONS(2368),
    [anon_sym_xmlport] = ACTIONS(2368),
    [anon_sym_XMLPORT] = ACTIONS(2368),
    [anon_sym_Xmlport] = ACTIONS(2368),
    [anon_sym_XMLport] = ACTIONS(2368),
    [anon_sym_XMLPort] = ACTIONS(2368),
    [anon_sym_XmlPort] = ACTIONS(2368),
    [anon_sym_enum] = ACTIONS(2368),
    [anon_sym_ENUM] = ACTIONS(2368),
    [anon_sym_Enum] = ACTIONS(2368),
    [anon_sym_eNUM] = ACTIONS(2368),
    [anon_sym_eNum] = ACTIONS(2368),
    [anon_sym_ENum] = ACTIONS(2368),
    [sym_quoted_identifier] = ACTIONS(2370),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2370),
    [sym_integer] = ACTIONS(2368),
    [sym_continue_as_identifier] = ACTIONS(2370),
    [sym_preproc_open] = ACTIONS(2370),
    [sym_preproc_close] = ACTIONS(2370),
  },
  [STATE(1423)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1426),
    [sym_identifier] = ACTIONS(2346),
    [anon_sym_SEMI] = ACTIONS(2348),
    [anon_sym_DOT] = ACTIONS(3780),
    [anon_sym_EQ] = ACTIONS(2348),
    [anon_sym_COMMA] = ACTIONS(2348),
    [anon_sym_COLON] = ACTIONS(2346),
    [anon_sym_DASH] = ACTIONS(2346),
    [aux_sym_boolean_token1] = ACTIONS(2346),
    [aux_sym_boolean_token2] = ACTIONS(2346),
    [sym_decimal] = ACTIONS(2346),
    [anon_sym_LPAREN] = ACTIONS(2348),
    [anon_sym_DOT_DOT] = ACTIONS(2348),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2346),
    [anon_sym_STAR] = ACTIONS(2346),
    [anon_sym_LBRACK] = ACTIONS(2348),
    [aux_sym_record_type_token1] = ACTIONS(2346),
    [aux_sym_basic_type_token21] = ACTIONS(2346),
    [aux_sym_basic_type_token22] = ACTIONS(2346),
    [aux_sym_basic_type_token48] = ACTIONS(2346),
    [anon_sym_POUNDif] = ACTIONS(2348),
    [anon_sym_POUNDIF] = ACTIONS(2348),
    [anon_sym_POUNDIf] = ACTIONS(2348),
    [anon_sym_not] = ACTIONS(2346),
    [anon_sym_NOT] = ACTIONS(2346),
    [anon_sym_Not] = ACTIONS(2346),
    [anon_sym_POUNDelif] = ACTIONS(2348),
    [anon_sym_POUNDELIF] = ACTIONS(2348),
    [anon_sym_POUNDElif] = ACTIONS(2348),
    [anon_sym_POUNDelse] = ACTIONS(2348),
    [anon_sym_POUNDELSE] = ACTIONS(2348),
    [anon_sym_POUNDElse] = ACTIONS(2348),
    [anon_sym_POUNDendif] = ACTIONS(2348),
    [anon_sym_POUNDENDIF] = ACTIONS(2348),
    [anon_sym_POUNDEndif] = ACTIONS(2348),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2348),
    [aux_sym__expression_token1] = ACTIONS(2348),
    [aux_sym__expression_token2] = ACTIONS(2348),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2346),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2346),
    [anon_sym_SLASH] = ACTIONS(2346),
    [anon_sym_div] = ACTIONS(2346),
    [anon_sym_DIV] = ACTIONS(2346),
    [anon_sym_Div] = ACTIONS(2346),
    [anon_sym_mod] = ACTIONS(2346),
    [anon_sym_MOD] = ACTIONS(2346),
    [anon_sym_Mod] = ACTIONS(2346),
    [anon_sym_PLUS] = ACTIONS(2346),
    [anon_sym_GT_EQ] = ACTIONS(2348),
    [anon_sym_LT_EQ] = ACTIONS(2348),
    [anon_sym_GT] = ACTIONS(2346),
    [anon_sym_LT] = ACTIONS(2346),
    [anon_sym_LT_GT] = ACTIONS(2348),
    [anon_sym_and] = ACTIONS(2346),
    [anon_sym_AND] = ACTIONS(2346),
    [anon_sym_And] = ACTIONS(2346),
    [anon_sym_or] = ACTIONS(2346),
    [anon_sym_OR] = ACTIONS(2346),
    [anon_sym_Or] = ACTIONS(2346),
    [anon_sym_xor] = ACTIONS(2346),
    [anon_sym_XOR] = ACTIONS(2346),
    [anon_sym_Xor] = ACTIONS(2346),
    [anon_sym_QMARK] = ACTIONS(2348),
    [sym_datetime_literal] = ACTIONS(2348),
    [sym_date_literal] = ACTIONS(2346),
    [sym_time_literal] = ACTIONS(2346),
    [sym_biginteger_literal] = ACTIONS(2348),
    [anon_sym_else] = ACTIONS(2346),
    [anon_sym_ELSE] = ACTIONS(2346),
    [anon_sym_Else] = ACTIONS(2346),
    [anon_sym_in] = ACTIONS(2346),
    [anon_sym_IN] = ACTIONS(2346),
    [anon_sym_In] = ACTIONS(2346),
    [sym_page_keyword] = ACTIONS(2346),
    [anon_sym_codeunit] = ACTIONS(2346),
    [anon_sym_CODEUNIT] = ACTIONS(2346),
    [anon_sym_Codeunit] = ACTIONS(2346),
    [anon_sym_CodeUnit] = ACTIONS(2346),
    [anon_sym_COdeunit] = ACTIONS(2346),
    [anon_sym_codeUnit] = ACTIONS(2346),
    [sym_report_keyword] = ACTIONS(2346),
    [sym_query_keyword] = ACTIONS(2346),
    [anon_sym_xmlport] = ACTIONS(2346),
    [anon_sym_XMLPORT] = ACTIONS(2346),
    [anon_sym_Xmlport] = ACTIONS(2346),
    [anon_sym_XMLport] = ACTIONS(2346),
    [anon_sym_XMLPort] = ACTIONS(2346),
    [anon_sym_XmlPort] = ACTIONS(2346),
    [anon_sym_enum] = ACTIONS(2346),
    [anon_sym_ENUM] = ACTIONS(2346),
    [anon_sym_Enum] = ACTIONS(2346),
    [anon_sym_eNUM] = ACTIONS(2346),
    [anon_sym_eNum] = ACTIONS(2346),
    [anon_sym_ENum] = ACTIONS(2346),
    [sym_temporary_keyword] = ACTIONS(2346),
    [sym_quoted_identifier] = ACTIONS(2348),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2348),
    [sym_integer] = ACTIONS(2346),
    [sym_continue_as_identifier] = ACTIONS(2348),
    [sym_preproc_open] = ACTIONS(2348),
    [sym_preproc_close] = ACTIONS(2348),
  },
  [STATE(1424)] = {
    [aux_sym_option_member_list_repeat2] = STATE(1424),
    [sym_identifier] = ACTIONS(565),
    [anon_sym_SEMI] = ACTIONS(567),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_EQ] = ACTIONS(567),
    [anon_sym_COMMA] = ACTIONS(3782),
    [anon_sym_COLON] = ACTIONS(565),
    [anon_sym_DASH] = ACTIONS(565),
    [aux_sym_boolean_token1] = ACTIONS(565),
    [aux_sym_boolean_token2] = ACTIONS(565),
    [sym_decimal] = ACTIONS(565),
    [anon_sym_LPAREN] = ACTIONS(567),
    [aux_sym_where_condition_token1] = ACTIONS(565),
    [anon_sym_DOT_DOT] = ACTIONS(567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(565),
    [anon_sym_STAR] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [aux_sym_record_type_token1] = ACTIONS(565),
    [aux_sym_basic_type_token21] = ACTIONS(565),
    [aux_sym_basic_type_token22] = ACTIONS(565),
    [aux_sym_basic_type_token48] = ACTIONS(565),
    [aux_sym_basic_type_token53] = ACTIONS(565),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(565),
    [aux_sym_separator_action_token1] = ACTIONS(565),
    [aux_sym_type_declaration_token1] = ACTIONS(565),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(565),
    [anon_sym_POUNDif] = ACTIONS(567),
    [anon_sym_POUNDIF] = ACTIONS(567),
    [anon_sym_POUNDIf] = ACTIONS(567),
    [anon_sym_not] = ACTIONS(565),
    [anon_sym_NOT] = ACTIONS(565),
    [anon_sym_Not] = ACTIONS(565),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(567),
    [aux_sym__expression_token1] = ACTIONS(567),
    [aux_sym__expression_token2] = ACTIONS(567),
    [aux_sym_keyword_identifier_token1] = ACTIONS(565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(565),
    [anon_sym_SLASH] = ACTIONS(565),
    [anon_sym_div] = ACTIONS(565),
    [anon_sym_DIV] = ACTIONS(565),
    [anon_sym_Div] = ACTIONS(565),
    [anon_sym_mod] = ACTIONS(565),
    [anon_sym_MOD] = ACTIONS(565),
    [anon_sym_Mod] = ACTIONS(565),
    [anon_sym_PLUS] = ACTIONS(565),
    [anon_sym_GT_EQ] = ACTIONS(567),
    [anon_sym_LT_EQ] = ACTIONS(567),
    [anon_sym_GT] = ACTIONS(565),
    [anon_sym_LT] = ACTIONS(565),
    [anon_sym_LT_GT] = ACTIONS(567),
    [anon_sym_and] = ACTIONS(565),
    [anon_sym_AND] = ACTIONS(565),
    [anon_sym_And] = ACTIONS(565),
    [anon_sym_or] = ACTIONS(565),
    [anon_sym_OR] = ACTIONS(565),
    [anon_sym_Or] = ACTIONS(565),
    [anon_sym_xor] = ACTIONS(565),
    [anon_sym_XOR] = ACTIONS(565),
    [anon_sym_Xor] = ACTIONS(565),
    [anon_sym_QMARK] = ACTIONS(567),
    [sym_datetime_literal] = ACTIONS(567),
    [sym_date_literal] = ACTIONS(565),
    [sym_time_literal] = ACTIONS(565),
    [sym_biginteger_literal] = ACTIONS(567),
    [anon_sym_else] = ACTIONS(565),
    [anon_sym_ELSE] = ACTIONS(565),
    [anon_sym_Else] = ACTIONS(565),
    [anon_sym_in] = ACTIONS(565),
    [anon_sym_IN] = ACTIONS(565),
    [anon_sym_In] = ACTIONS(565),
    [sym_page_keyword] = ACTIONS(565),
    [anon_sym_codeunit] = ACTIONS(565),
    [anon_sym_CODEUNIT] = ACTIONS(565),
    [anon_sym_Codeunit] = ACTIONS(565),
    [anon_sym_CodeUnit] = ACTIONS(565),
    [anon_sym_COdeunit] = ACTIONS(565),
    [anon_sym_codeUnit] = ACTIONS(565),
    [sym_report_keyword] = ACTIONS(565),
    [sym_query_keyword] = ACTIONS(565),
    [anon_sym_xmlport] = ACTIONS(565),
    [anon_sym_XMLPORT] = ACTIONS(565),
    [anon_sym_Xmlport] = ACTIONS(565),
    [anon_sym_XMLport] = ACTIONS(565),
    [anon_sym_XMLPort] = ACTIONS(565),
    [anon_sym_XmlPort] = ACTIONS(565),
    [anon_sym_enum] = ACTIONS(565),
    [anon_sym_ENUM] = ACTIONS(565),
    [anon_sym_Enum] = ACTIONS(565),
    [anon_sym_eNUM] = ACTIONS(565),
    [anon_sym_eNum] = ACTIONS(565),
    [anon_sym_ENum] = ACTIONS(565),
    [sym_local_keyword] = ACTIONS(565),
    [sym_internal_keyword] = ACTIONS(565),
    [sym_protected_keyword] = ACTIONS(565),
    [sym_key_keyword] = ACTIONS(565),
    [sym_dataset_keyword] = ACTIONS(565),
    [sym_quoted_identifier] = ACTIONS(567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(567),
    [sym_integer] = ACTIONS(565),
    [sym_continue_as_identifier] = ACTIONS(567),
    [sym_preproc_open] = ACTIONS(567),
  },
  [STATE(1425)] = {
    [sym_identifier] = ACTIONS(2266),
    [anon_sym_SEMI] = ACTIONS(2268),
    [anon_sym_DOT] = ACTIONS(2266),
    [anon_sym_EQ] = ACTIONS(2268),
    [anon_sym_COMMA] = ACTIONS(2268),
    [anon_sym_COLON] = ACTIONS(2266),
    [anon_sym_DASH] = ACTIONS(2266),
    [aux_sym_boolean_token1] = ACTIONS(2266),
    [aux_sym_boolean_token2] = ACTIONS(2266),
    [sym_decimal] = ACTIONS(2266),
    [anon_sym_LPAREN] = ACTIONS(2268),
    [anon_sym_DOT_DOT] = ACTIONS(2268),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2266),
    [anon_sym_STAR] = ACTIONS(2266),
    [anon_sym_LBRACK] = ACTIONS(2268),
    [aux_sym_record_type_token1] = ACTIONS(2266),
    [aux_sym_basic_type_token21] = ACTIONS(2266),
    [aux_sym_basic_type_token22] = ACTIONS(2266),
    [aux_sym_basic_type_token48] = ACTIONS(2266),
    [anon_sym_COLON_COLON] = ACTIONS(2268),
    [anon_sym_POUNDif] = ACTIONS(2268),
    [anon_sym_POUNDIF] = ACTIONS(2268),
    [anon_sym_POUNDIf] = ACTIONS(2268),
    [anon_sym_not] = ACTIONS(2266),
    [anon_sym_NOT] = ACTIONS(2266),
    [anon_sym_Not] = ACTIONS(2266),
    [anon_sym_POUNDelif] = ACTIONS(2268),
    [anon_sym_POUNDELIF] = ACTIONS(2268),
    [anon_sym_POUNDElif] = ACTIONS(2268),
    [anon_sym_POUNDelse] = ACTIONS(2268),
    [anon_sym_POUNDELSE] = ACTIONS(2268),
    [anon_sym_POUNDElse] = ACTIONS(2268),
    [anon_sym_POUNDendif] = ACTIONS(2268),
    [anon_sym_POUNDENDIF] = ACTIONS(2268),
    [anon_sym_POUNDEndif] = ACTIONS(2268),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2268),
    [aux_sym__expression_token1] = ACTIONS(2268),
    [aux_sym__expression_token2] = ACTIONS(2268),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2266),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2266),
    [anon_sym_SLASH] = ACTIONS(2266),
    [anon_sym_div] = ACTIONS(2266),
    [anon_sym_DIV] = ACTIONS(2266),
    [anon_sym_Div] = ACTIONS(2266),
    [anon_sym_mod] = ACTIONS(2266),
    [anon_sym_MOD] = ACTIONS(2266),
    [anon_sym_Mod] = ACTIONS(2266),
    [anon_sym_PLUS] = ACTIONS(2266),
    [anon_sym_GT_EQ] = ACTIONS(2268),
    [anon_sym_LT_EQ] = ACTIONS(2268),
    [anon_sym_GT] = ACTIONS(2266),
    [anon_sym_LT] = ACTIONS(2266),
    [anon_sym_LT_GT] = ACTIONS(2268),
    [anon_sym_and] = ACTIONS(2266),
    [anon_sym_AND] = ACTIONS(2266),
    [anon_sym_And] = ACTIONS(2266),
    [anon_sym_or] = ACTIONS(2266),
    [anon_sym_OR] = ACTIONS(2266),
    [anon_sym_Or] = ACTIONS(2266),
    [anon_sym_xor] = ACTIONS(2266),
    [anon_sym_XOR] = ACTIONS(2266),
    [anon_sym_Xor] = ACTIONS(2266),
    [anon_sym_QMARK] = ACTIONS(2268),
    [sym_datetime_literal] = ACTIONS(2268),
    [sym_date_literal] = ACTIONS(2266),
    [sym_time_literal] = ACTIONS(2266),
    [sym_biginteger_literal] = ACTIONS(2268),
    [anon_sym_else] = ACTIONS(2266),
    [anon_sym_ELSE] = ACTIONS(2266),
    [anon_sym_Else] = ACTIONS(2266),
    [anon_sym_in] = ACTIONS(2266),
    [anon_sym_IN] = ACTIONS(2266),
    [anon_sym_In] = ACTIONS(2266),
    [sym_page_keyword] = ACTIONS(2266),
    [anon_sym_codeunit] = ACTIONS(2266),
    [anon_sym_CODEUNIT] = ACTIONS(2266),
    [anon_sym_Codeunit] = ACTIONS(2266),
    [anon_sym_CodeUnit] = ACTIONS(2266),
    [anon_sym_COdeunit] = ACTIONS(2266),
    [anon_sym_codeUnit] = ACTIONS(2266),
    [sym_report_keyword] = ACTIONS(2266),
    [sym_query_keyword] = ACTIONS(2266),
    [anon_sym_xmlport] = ACTIONS(2266),
    [anon_sym_XMLPORT] = ACTIONS(2266),
    [anon_sym_Xmlport] = ACTIONS(2266),
    [anon_sym_XMLport] = ACTIONS(2266),
    [anon_sym_XMLPort] = ACTIONS(2266),
    [anon_sym_XmlPort] = ACTIONS(2266),
    [anon_sym_enum] = ACTIONS(2266),
    [anon_sym_ENUM] = ACTIONS(2266),
    [anon_sym_Enum] = ACTIONS(2266),
    [anon_sym_eNUM] = ACTIONS(2266),
    [anon_sym_eNum] = ACTIONS(2266),
    [anon_sym_ENum] = ACTIONS(2266),
    [sym_temporary_keyword] = ACTIONS(2266),
    [sym_quoted_identifier] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2268),
    [sym_integer] = ACTIONS(2266),
    [sym_continue_as_identifier] = ACTIONS(2268),
    [sym_preproc_open] = ACTIONS(2268),
    [sym_preproc_close] = ACTIONS(2268),
  },
  [STATE(1426)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1427),
    [sym_identifier] = ACTIONS(2442),
    [anon_sym_SEMI] = ACTIONS(2444),
    [anon_sym_DOT] = ACTIONS(3780),
    [anon_sym_EQ] = ACTIONS(2444),
    [anon_sym_COMMA] = ACTIONS(2444),
    [anon_sym_COLON] = ACTIONS(2442),
    [anon_sym_DASH] = ACTIONS(2442),
    [aux_sym_boolean_token1] = ACTIONS(2442),
    [aux_sym_boolean_token2] = ACTIONS(2442),
    [sym_decimal] = ACTIONS(2442),
    [anon_sym_LPAREN] = ACTIONS(2444),
    [anon_sym_DOT_DOT] = ACTIONS(2444),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2442),
    [anon_sym_STAR] = ACTIONS(2442),
    [anon_sym_LBRACK] = ACTIONS(2444),
    [aux_sym_record_type_token1] = ACTIONS(2442),
    [aux_sym_basic_type_token21] = ACTIONS(2442),
    [aux_sym_basic_type_token22] = ACTIONS(2442),
    [aux_sym_basic_type_token48] = ACTIONS(2442),
    [anon_sym_POUNDif] = ACTIONS(2444),
    [anon_sym_POUNDIF] = ACTIONS(2444),
    [anon_sym_POUNDIf] = ACTIONS(2444),
    [anon_sym_not] = ACTIONS(2442),
    [anon_sym_NOT] = ACTIONS(2442),
    [anon_sym_Not] = ACTIONS(2442),
    [anon_sym_POUNDelif] = ACTIONS(2444),
    [anon_sym_POUNDELIF] = ACTIONS(2444),
    [anon_sym_POUNDElif] = ACTIONS(2444),
    [anon_sym_POUNDelse] = ACTIONS(2444),
    [anon_sym_POUNDELSE] = ACTIONS(2444),
    [anon_sym_POUNDElse] = ACTIONS(2444),
    [anon_sym_POUNDendif] = ACTIONS(2444),
    [anon_sym_POUNDENDIF] = ACTIONS(2444),
    [anon_sym_POUNDEndif] = ACTIONS(2444),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2444),
    [aux_sym__expression_token1] = ACTIONS(2444),
    [aux_sym__expression_token2] = ACTIONS(2444),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2442),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2442),
    [anon_sym_SLASH] = ACTIONS(2442),
    [anon_sym_div] = ACTIONS(2442),
    [anon_sym_DIV] = ACTIONS(2442),
    [anon_sym_Div] = ACTIONS(2442),
    [anon_sym_mod] = ACTIONS(2442),
    [anon_sym_MOD] = ACTIONS(2442),
    [anon_sym_Mod] = ACTIONS(2442),
    [anon_sym_PLUS] = ACTIONS(2442),
    [anon_sym_GT_EQ] = ACTIONS(2444),
    [anon_sym_LT_EQ] = ACTIONS(2444),
    [anon_sym_GT] = ACTIONS(2442),
    [anon_sym_LT] = ACTIONS(2442),
    [anon_sym_LT_GT] = ACTIONS(2444),
    [anon_sym_and] = ACTIONS(2442),
    [anon_sym_AND] = ACTIONS(2442),
    [anon_sym_And] = ACTIONS(2442),
    [anon_sym_or] = ACTIONS(2442),
    [anon_sym_OR] = ACTIONS(2442),
    [anon_sym_Or] = ACTIONS(2442),
    [anon_sym_xor] = ACTIONS(2442),
    [anon_sym_XOR] = ACTIONS(2442),
    [anon_sym_Xor] = ACTIONS(2442),
    [anon_sym_QMARK] = ACTIONS(2444),
    [sym_datetime_literal] = ACTIONS(2444),
    [sym_date_literal] = ACTIONS(2442),
    [sym_time_literal] = ACTIONS(2442),
    [sym_biginteger_literal] = ACTIONS(2444),
    [anon_sym_else] = ACTIONS(2442),
    [anon_sym_ELSE] = ACTIONS(2442),
    [anon_sym_Else] = ACTIONS(2442),
    [anon_sym_in] = ACTIONS(2442),
    [anon_sym_IN] = ACTIONS(2442),
    [anon_sym_In] = ACTIONS(2442),
    [sym_page_keyword] = ACTIONS(2442),
    [anon_sym_codeunit] = ACTIONS(2442),
    [anon_sym_CODEUNIT] = ACTIONS(2442),
    [anon_sym_Codeunit] = ACTIONS(2442),
    [anon_sym_CodeUnit] = ACTIONS(2442),
    [anon_sym_COdeunit] = ACTIONS(2442),
    [anon_sym_codeUnit] = ACTIONS(2442),
    [sym_report_keyword] = ACTIONS(2442),
    [sym_query_keyword] = ACTIONS(2442),
    [anon_sym_xmlport] = ACTIONS(2442),
    [anon_sym_XMLPORT] = ACTIONS(2442),
    [anon_sym_Xmlport] = ACTIONS(2442),
    [anon_sym_XMLport] = ACTIONS(2442),
    [anon_sym_XMLPort] = ACTIONS(2442),
    [anon_sym_XmlPort] = ACTIONS(2442),
    [anon_sym_enum] = ACTIONS(2442),
    [anon_sym_ENUM] = ACTIONS(2442),
    [anon_sym_Enum] = ACTIONS(2442),
    [anon_sym_eNUM] = ACTIONS(2442),
    [anon_sym_eNum] = ACTIONS(2442),
    [anon_sym_ENum] = ACTIONS(2442),
    [sym_temporary_keyword] = ACTIONS(2442),
    [sym_quoted_identifier] = ACTIONS(2444),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2444),
    [sym_integer] = ACTIONS(2442),
    [sym_continue_as_identifier] = ACTIONS(2444),
    [sym_preproc_open] = ACTIONS(2444),
    [sym_preproc_close] = ACTIONS(2444),
  },
  [STATE(1427)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1427),
    [sym_identifier] = ACTIONS(2396),
    [anon_sym_SEMI] = ACTIONS(2398),
    [anon_sym_DOT] = ACTIONS(3785),
    [anon_sym_EQ] = ACTIONS(2398),
    [anon_sym_COMMA] = ACTIONS(2398),
    [anon_sym_COLON] = ACTIONS(2396),
    [anon_sym_DASH] = ACTIONS(2396),
    [aux_sym_boolean_token1] = ACTIONS(2396),
    [aux_sym_boolean_token2] = ACTIONS(2396),
    [sym_decimal] = ACTIONS(2396),
    [anon_sym_LPAREN] = ACTIONS(2398),
    [anon_sym_DOT_DOT] = ACTIONS(2398),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2396),
    [anon_sym_STAR] = ACTIONS(2396),
    [anon_sym_LBRACK] = ACTIONS(2398),
    [aux_sym_record_type_token1] = ACTIONS(2396),
    [aux_sym_basic_type_token21] = ACTIONS(2396),
    [aux_sym_basic_type_token22] = ACTIONS(2396),
    [aux_sym_basic_type_token48] = ACTIONS(2396),
    [anon_sym_POUNDif] = ACTIONS(2398),
    [anon_sym_POUNDIF] = ACTIONS(2398),
    [anon_sym_POUNDIf] = ACTIONS(2398),
    [anon_sym_not] = ACTIONS(2396),
    [anon_sym_NOT] = ACTIONS(2396),
    [anon_sym_Not] = ACTIONS(2396),
    [anon_sym_POUNDelif] = ACTIONS(2398),
    [anon_sym_POUNDELIF] = ACTIONS(2398),
    [anon_sym_POUNDElif] = ACTIONS(2398),
    [anon_sym_POUNDelse] = ACTIONS(2398),
    [anon_sym_POUNDELSE] = ACTIONS(2398),
    [anon_sym_POUNDElse] = ACTIONS(2398),
    [anon_sym_POUNDendif] = ACTIONS(2398),
    [anon_sym_POUNDENDIF] = ACTIONS(2398),
    [anon_sym_POUNDEndif] = ACTIONS(2398),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2398),
    [aux_sym__expression_token1] = ACTIONS(2398),
    [aux_sym__expression_token2] = ACTIONS(2398),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2396),
    [anon_sym_SLASH] = ACTIONS(2396),
    [anon_sym_div] = ACTIONS(2396),
    [anon_sym_DIV] = ACTIONS(2396),
    [anon_sym_Div] = ACTIONS(2396),
    [anon_sym_mod] = ACTIONS(2396),
    [anon_sym_MOD] = ACTIONS(2396),
    [anon_sym_Mod] = ACTIONS(2396),
    [anon_sym_PLUS] = ACTIONS(2396),
    [anon_sym_GT_EQ] = ACTIONS(2398),
    [anon_sym_LT_EQ] = ACTIONS(2398),
    [anon_sym_GT] = ACTIONS(2396),
    [anon_sym_LT] = ACTIONS(2396),
    [anon_sym_LT_GT] = ACTIONS(2398),
    [anon_sym_and] = ACTIONS(2396),
    [anon_sym_AND] = ACTIONS(2396),
    [anon_sym_And] = ACTIONS(2396),
    [anon_sym_or] = ACTIONS(2396),
    [anon_sym_OR] = ACTIONS(2396),
    [anon_sym_Or] = ACTIONS(2396),
    [anon_sym_xor] = ACTIONS(2396),
    [anon_sym_XOR] = ACTIONS(2396),
    [anon_sym_Xor] = ACTIONS(2396),
    [anon_sym_QMARK] = ACTIONS(2398),
    [sym_datetime_literal] = ACTIONS(2398),
    [sym_date_literal] = ACTIONS(2396),
    [sym_time_literal] = ACTIONS(2396),
    [sym_biginteger_literal] = ACTIONS(2398),
    [anon_sym_else] = ACTIONS(2396),
    [anon_sym_ELSE] = ACTIONS(2396),
    [anon_sym_Else] = ACTIONS(2396),
    [anon_sym_in] = ACTIONS(2396),
    [anon_sym_IN] = ACTIONS(2396),
    [anon_sym_In] = ACTIONS(2396),
    [sym_page_keyword] = ACTIONS(2396),
    [anon_sym_codeunit] = ACTIONS(2396),
    [anon_sym_CODEUNIT] = ACTIONS(2396),
    [anon_sym_Codeunit] = ACTIONS(2396),
    [anon_sym_CodeUnit] = ACTIONS(2396),
    [anon_sym_COdeunit] = ACTIONS(2396),
    [anon_sym_codeUnit] = ACTIONS(2396),
    [sym_report_keyword] = ACTIONS(2396),
    [sym_query_keyword] = ACTIONS(2396),
    [anon_sym_xmlport] = ACTIONS(2396),
    [anon_sym_XMLPORT] = ACTIONS(2396),
    [anon_sym_Xmlport] = ACTIONS(2396),
    [anon_sym_XMLport] = ACTIONS(2396),
    [anon_sym_XMLPort] = ACTIONS(2396),
    [anon_sym_XmlPort] = ACTIONS(2396),
    [anon_sym_enum] = ACTIONS(2396),
    [anon_sym_ENUM] = ACTIONS(2396),
    [anon_sym_Enum] = ACTIONS(2396),
    [anon_sym_eNUM] = ACTIONS(2396),
    [anon_sym_eNum] = ACTIONS(2396),
    [anon_sym_ENum] = ACTIONS(2396),
    [sym_temporary_keyword] = ACTIONS(2396),
    [sym_quoted_identifier] = ACTIONS(2398),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2398),
    [sym_integer] = ACTIONS(2396),
    [sym_continue_as_identifier] = ACTIONS(2398),
    [sym_preproc_open] = ACTIONS(2398),
    [sym_preproc_close] = ACTIONS(2398),
  },
  [STATE(1428)] = {
    [aux_sym_option_member_list_repeat2] = STATE(1428),
    [sym_identifier] = ACTIONS(565),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_EQ] = ACTIONS(567),
    [anon_sym_COMMA] = ACTIONS(3788),
    [anon_sym_DASH] = ACTIONS(565),
    [aux_sym_boolean_token1] = ACTIONS(565),
    [aux_sym_boolean_token2] = ACTIONS(565),
    [sym_decimal] = ACTIONS(565),
    [anon_sym_LPAREN] = ACTIONS(567),
    [aux_sym_where_condition_token1] = ACTIONS(565),
    [anon_sym_DOT_DOT] = ACTIONS(567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(565),
    [anon_sym_STAR] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [aux_sym_record_type_token1] = ACTIONS(565),
    [aux_sym_basic_type_token21] = ACTIONS(565),
    [aux_sym_basic_type_token22] = ACTIONS(565),
    [aux_sym_basic_type_token48] = ACTIONS(565),
    [aux_sym_basic_type_token53] = ACTIONS(565),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(565),
    [aux_sym_separator_action_token1] = ACTIONS(565),
    [aux_sym_type_declaration_token1] = ACTIONS(565),
    [anon_sym_not] = ACTIONS(565),
    [anon_sym_NOT] = ACTIONS(565),
    [anon_sym_Not] = ACTIONS(565),
    [anon_sym_POUNDelif] = ACTIONS(567),
    [anon_sym_POUNDELIF] = ACTIONS(567),
    [anon_sym_POUNDElif] = ACTIONS(567),
    [anon_sym_POUNDelse] = ACTIONS(567),
    [anon_sym_POUNDELSE] = ACTIONS(567),
    [anon_sym_POUNDElse] = ACTIONS(567),
    [anon_sym_POUNDendif] = ACTIONS(567),
    [anon_sym_POUNDENDIF] = ACTIONS(567),
    [anon_sym_POUNDEndif] = ACTIONS(567),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(567),
    [aux_sym__expression_token1] = ACTIONS(567),
    [aux_sym__expression_token2] = ACTIONS(567),
    [aux_sym_keyword_identifier_token1] = ACTIONS(565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(565),
    [anon_sym_SLASH] = ACTIONS(565),
    [anon_sym_div] = ACTIONS(565),
    [anon_sym_DIV] = ACTIONS(565),
    [anon_sym_Div] = ACTIONS(565),
    [anon_sym_mod] = ACTIONS(565),
    [anon_sym_MOD] = ACTIONS(565),
    [anon_sym_Mod] = ACTIONS(565),
    [anon_sym_PLUS] = ACTIONS(565),
    [anon_sym_GT_EQ] = ACTIONS(567),
    [anon_sym_LT_EQ] = ACTIONS(567),
    [anon_sym_GT] = ACTIONS(565),
    [anon_sym_LT] = ACTIONS(565),
    [anon_sym_LT_GT] = ACTIONS(567),
    [anon_sym_and] = ACTIONS(565),
    [anon_sym_AND] = ACTIONS(565),
    [anon_sym_And] = ACTIONS(565),
    [anon_sym_or] = ACTIONS(565),
    [anon_sym_OR] = ACTIONS(565),
    [anon_sym_Or] = ACTIONS(565),
    [anon_sym_xor] = ACTIONS(565),
    [anon_sym_XOR] = ACTIONS(565),
    [anon_sym_Xor] = ACTIONS(565),
    [anon_sym_QMARK] = ACTIONS(567),
    [sym_datetime_literal] = ACTIONS(567),
    [sym_date_literal] = ACTIONS(565),
    [sym_time_literal] = ACTIONS(565),
    [sym_biginteger_literal] = ACTIONS(567),
    [anon_sym_in] = ACTIONS(565),
    [anon_sym_IN] = ACTIONS(565),
    [anon_sym_In] = ACTIONS(565),
    [sym_page_keyword] = ACTIONS(565),
    [anon_sym_codeunit] = ACTIONS(565),
    [anon_sym_CODEUNIT] = ACTIONS(565),
    [anon_sym_Codeunit] = ACTIONS(565),
    [anon_sym_CodeUnit] = ACTIONS(565),
    [anon_sym_COdeunit] = ACTIONS(565),
    [anon_sym_codeUnit] = ACTIONS(565),
    [sym_report_keyword] = ACTIONS(565),
    [sym_query_keyword] = ACTIONS(565),
    [anon_sym_xmlport] = ACTIONS(565),
    [anon_sym_XMLPORT] = ACTIONS(565),
    [anon_sym_Xmlport] = ACTIONS(565),
    [anon_sym_XMLport] = ACTIONS(565),
    [anon_sym_XMLPort] = ACTIONS(565),
    [anon_sym_XmlPort] = ACTIONS(565),
    [anon_sym_enum] = ACTIONS(565),
    [anon_sym_ENUM] = ACTIONS(565),
    [anon_sym_Enum] = ACTIONS(565),
    [anon_sym_eNUM] = ACTIONS(565),
    [anon_sym_eNum] = ACTIONS(565),
    [anon_sym_ENum] = ACTIONS(565),
    [sym_local_keyword] = ACTIONS(565),
    [sym_internal_keyword] = ACTIONS(565),
    [sym_protected_keyword] = ACTIONS(565),
    [sym_key_keyword] = ACTIONS(565),
    [sym_dataset_keyword] = ACTIONS(565),
    [sym_quoted_identifier] = ACTIONS(567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(567),
    [sym_integer] = ACTIONS(565),
    [sym_continue_as_identifier] = ACTIONS(567),
    [sym_preproc_close] = ACTIONS(567),
  },
  [STATE(1429)] = {
    [sym_identifier] = ACTIONS(2533),
    [anon_sym_SEMI] = ACTIONS(2535),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym_EQ] = ACTIONS(2535),
    [anon_sym_COMMA] = ACTIONS(2535),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_DASH] = ACTIONS(2533),
    [aux_sym_boolean_token1] = ACTIONS(2533),
    [aux_sym_boolean_token2] = ACTIONS(2533),
    [sym_decimal] = ACTIONS(2533),
    [anon_sym_LPAREN] = ACTIONS(2535),
    [anon_sym_DOT_DOT] = ACTIONS(2535),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2533),
    [anon_sym_STAR] = ACTIONS(2533),
    [anon_sym_LBRACK] = ACTIONS(2535),
    [aux_sym_record_type_token1] = ACTIONS(2533),
    [aux_sym_basic_type_token21] = ACTIONS(2533),
    [aux_sym_basic_type_token22] = ACTIONS(2533),
    [aux_sym_basic_type_token48] = ACTIONS(2533),
    [anon_sym_POUNDif] = ACTIONS(2535),
    [anon_sym_POUNDIF] = ACTIONS(2535),
    [anon_sym_POUNDIf] = ACTIONS(2535),
    [anon_sym_not] = ACTIONS(2533),
    [anon_sym_NOT] = ACTIONS(2533),
    [anon_sym_Not] = ACTIONS(2533),
    [anon_sym_POUNDelif] = ACTIONS(2535),
    [anon_sym_POUNDELIF] = ACTIONS(2535),
    [anon_sym_POUNDElif] = ACTIONS(2535),
    [anon_sym_POUNDelse] = ACTIONS(2535),
    [anon_sym_POUNDELSE] = ACTIONS(2535),
    [anon_sym_POUNDElse] = ACTIONS(2535),
    [anon_sym_POUNDendif] = ACTIONS(2535),
    [anon_sym_POUNDENDIF] = ACTIONS(2535),
    [anon_sym_POUNDEndif] = ACTIONS(2535),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2535),
    [aux_sym__expression_token1] = ACTIONS(2535),
    [aux_sym__expression_token2] = ACTIONS(2535),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2533),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2533),
    [anon_sym_SLASH] = ACTIONS(2533),
    [anon_sym_div] = ACTIONS(2533),
    [anon_sym_DIV] = ACTIONS(2533),
    [anon_sym_Div] = ACTIONS(2533),
    [anon_sym_mod] = ACTIONS(2533),
    [anon_sym_MOD] = ACTIONS(2533),
    [anon_sym_Mod] = ACTIONS(2533),
    [anon_sym_PLUS] = ACTIONS(2533),
    [anon_sym_GT_EQ] = ACTIONS(2535),
    [anon_sym_LT_EQ] = ACTIONS(2535),
    [anon_sym_GT] = ACTIONS(2533),
    [anon_sym_LT] = ACTIONS(2533),
    [anon_sym_LT_GT] = ACTIONS(2535),
    [anon_sym_and] = ACTIONS(2533),
    [anon_sym_AND] = ACTIONS(2533),
    [anon_sym_And] = ACTIONS(2533),
    [anon_sym_or] = ACTIONS(2533),
    [anon_sym_OR] = ACTIONS(2533),
    [anon_sym_Or] = ACTIONS(2533),
    [anon_sym_xor] = ACTIONS(2533),
    [anon_sym_XOR] = ACTIONS(2533),
    [anon_sym_Xor] = ACTIONS(2533),
    [anon_sym_QMARK] = ACTIONS(2535),
    [sym_datetime_literal] = ACTIONS(2535),
    [sym_date_literal] = ACTIONS(2533),
    [sym_time_literal] = ACTIONS(2533),
    [sym_biginteger_literal] = ACTIONS(2535),
    [anon_sym_else] = ACTIONS(2533),
    [anon_sym_ELSE] = ACTIONS(2533),
    [anon_sym_Else] = ACTIONS(2533),
    [anon_sym_in] = ACTIONS(2533),
    [anon_sym_IN] = ACTIONS(2533),
    [anon_sym_In] = ACTIONS(2533),
    [sym_page_keyword] = ACTIONS(2533),
    [anon_sym_codeunit] = ACTIONS(2533),
    [anon_sym_CODEUNIT] = ACTIONS(2533),
    [anon_sym_Codeunit] = ACTIONS(2533),
    [anon_sym_CodeUnit] = ACTIONS(2533),
    [anon_sym_COdeunit] = ACTIONS(2533),
    [anon_sym_codeUnit] = ACTIONS(2533),
    [sym_report_keyword] = ACTIONS(2533),
    [sym_query_keyword] = ACTIONS(2533),
    [anon_sym_xmlport] = ACTIONS(2533),
    [anon_sym_XMLPORT] = ACTIONS(2533),
    [anon_sym_Xmlport] = ACTIONS(2533),
    [anon_sym_XMLport] = ACTIONS(2533),
    [anon_sym_XMLPort] = ACTIONS(2533),
    [anon_sym_XmlPort] = ACTIONS(2533),
    [anon_sym_enum] = ACTIONS(2533),
    [anon_sym_ENUM] = ACTIONS(2533),
    [anon_sym_Enum] = ACTIONS(2533),
    [anon_sym_eNUM] = ACTIONS(2533),
    [anon_sym_eNum] = ACTIONS(2533),
    [anon_sym_ENum] = ACTIONS(2533),
    [sym_temporary_keyword] = ACTIONS(3791),
    [sym_quoted_identifier] = ACTIONS(2535),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2535),
    [sym_integer] = ACTIONS(2533),
    [sym_continue_as_identifier] = ACTIONS(2535),
    [sym_preproc_open] = ACTIONS(2535),
    [sym_preproc_close] = ACTIONS(2535),
  },
  [STATE(1430)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(3795),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1431)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(3879),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1432)] = {
    [sym_identifier] = ACTIONS(2565),
    [anon_sym_SEMI] = ACTIONS(2567),
    [anon_sym_DOT] = ACTIONS(2565),
    [anon_sym_EQ] = ACTIONS(2567),
    [anon_sym_COMMA] = ACTIONS(2567),
    [anon_sym_COLON] = ACTIONS(2565),
    [anon_sym_DASH] = ACTIONS(2565),
    [aux_sym_boolean_token1] = ACTIONS(2565),
    [aux_sym_boolean_token2] = ACTIONS(2565),
    [sym_decimal] = ACTIONS(2565),
    [anon_sym_LPAREN] = ACTIONS(2567),
    [anon_sym_DOT_DOT] = ACTIONS(2567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2565),
    [anon_sym_STAR] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2567),
    [aux_sym_record_type_token1] = ACTIONS(2565),
    [aux_sym_basic_type_token21] = ACTIONS(2565),
    [aux_sym_basic_type_token22] = ACTIONS(2565),
    [aux_sym_basic_type_token48] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_POUNDif] = ACTIONS(2567),
    [anon_sym_POUNDIF] = ACTIONS(2567),
    [anon_sym_POUNDIf] = ACTIONS(2567),
    [anon_sym_not] = ACTIONS(2565),
    [anon_sym_NOT] = ACTIONS(2565),
    [anon_sym_Not] = ACTIONS(2565),
    [anon_sym_POUNDelif] = ACTIONS(2567),
    [anon_sym_POUNDELIF] = ACTIONS(2567),
    [anon_sym_POUNDElif] = ACTIONS(2567),
    [anon_sym_POUNDelse] = ACTIONS(2567),
    [anon_sym_POUNDELSE] = ACTIONS(2567),
    [anon_sym_POUNDElse] = ACTIONS(2567),
    [anon_sym_POUNDendif] = ACTIONS(2567),
    [anon_sym_POUNDENDIF] = ACTIONS(2567),
    [anon_sym_POUNDEndif] = ACTIONS(2567),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2567),
    [aux_sym__expression_token1] = ACTIONS(2567),
    [aux_sym__expression_token2] = ACTIONS(2567),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2565),
    [anon_sym_SLASH] = ACTIONS(2565),
    [anon_sym_div] = ACTIONS(2565),
    [anon_sym_DIV] = ACTIONS(2565),
    [anon_sym_Div] = ACTIONS(2565),
    [anon_sym_mod] = ACTIONS(2565),
    [anon_sym_MOD] = ACTIONS(2565),
    [anon_sym_Mod] = ACTIONS(2565),
    [anon_sym_PLUS] = ACTIONS(2565),
    [anon_sym_GT_EQ] = ACTIONS(2567),
    [anon_sym_LT_EQ] = ACTIONS(2567),
    [anon_sym_GT] = ACTIONS(2565),
    [anon_sym_LT] = ACTIONS(2565),
    [anon_sym_LT_GT] = ACTIONS(2567),
    [anon_sym_and] = ACTIONS(2565),
    [anon_sym_AND] = ACTIONS(2565),
    [anon_sym_And] = ACTIONS(2565),
    [anon_sym_or] = ACTIONS(2565),
    [anon_sym_OR] = ACTIONS(2565),
    [anon_sym_Or] = ACTIONS(2565),
    [anon_sym_xor] = ACTIONS(2565),
    [anon_sym_XOR] = ACTIONS(2565),
    [anon_sym_Xor] = ACTIONS(2565),
    [anon_sym_QMARK] = ACTIONS(2567),
    [sym_datetime_literal] = ACTIONS(2567),
    [sym_date_literal] = ACTIONS(2565),
    [sym_time_literal] = ACTIONS(2565),
    [sym_biginteger_literal] = ACTIONS(2567),
    [anon_sym_else] = ACTIONS(2565),
    [anon_sym_ELSE] = ACTIONS(2565),
    [anon_sym_Else] = ACTIONS(2565),
    [anon_sym_in] = ACTIONS(2565),
    [anon_sym_IN] = ACTIONS(2565),
    [anon_sym_In] = ACTIONS(2565),
    [sym_page_keyword] = ACTIONS(2565),
    [anon_sym_codeunit] = ACTIONS(2565),
    [anon_sym_CODEUNIT] = ACTIONS(2565),
    [anon_sym_Codeunit] = ACTIONS(2565),
    [anon_sym_CodeUnit] = ACTIONS(2565),
    [anon_sym_COdeunit] = ACTIONS(2565),
    [anon_sym_codeUnit] = ACTIONS(2565),
    [sym_report_keyword] = ACTIONS(2565),
    [sym_query_keyword] = ACTIONS(2565),
    [anon_sym_xmlport] = ACTIONS(2565),
    [anon_sym_XMLPORT] = ACTIONS(2565),
    [anon_sym_Xmlport] = ACTIONS(2565),
    [anon_sym_XMLport] = ACTIONS(2565),
    [anon_sym_XMLPort] = ACTIONS(2565),
    [anon_sym_XmlPort] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_ENUM] = ACTIONS(2565),
    [anon_sym_Enum] = ACTIONS(2565),
    [anon_sym_eNUM] = ACTIONS(2565),
    [anon_sym_eNum] = ACTIONS(2565),
    [anon_sym_ENum] = ACTIONS(2565),
    [sym_quoted_identifier] = ACTIONS(2567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2567),
    [sym_integer] = ACTIONS(2565),
    [sym_continue_as_identifier] = ACTIONS(2567),
    [sym_preproc_open] = ACTIONS(2567),
    [sym_preproc_close] = ACTIONS(2567),
  },
  [STATE(1433)] = {
    [sym_identifier] = ACTIONS(2517),
    [anon_sym_SEMI] = ACTIONS(2519),
    [anon_sym_DOT] = ACTIONS(2517),
    [anon_sym_EQ] = ACTIONS(2519),
    [anon_sym_COMMA] = ACTIONS(2519),
    [anon_sym_COLON] = ACTIONS(2517),
    [anon_sym_DASH] = ACTIONS(2517),
    [aux_sym_boolean_token1] = ACTIONS(2517),
    [aux_sym_boolean_token2] = ACTIONS(2517),
    [sym_decimal] = ACTIONS(2517),
    [anon_sym_LPAREN] = ACTIONS(2519),
    [anon_sym_DOT_DOT] = ACTIONS(2519),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2517),
    [anon_sym_STAR] = ACTIONS(2517),
    [anon_sym_LBRACK] = ACTIONS(2519),
    [aux_sym_record_type_token1] = ACTIONS(2517),
    [aux_sym_basic_type_token21] = ACTIONS(2517),
    [aux_sym_basic_type_token22] = ACTIONS(2517),
    [aux_sym_basic_type_token48] = ACTIONS(2517),
    [anon_sym_COLON_COLON] = ACTIONS(2519),
    [anon_sym_POUNDif] = ACTIONS(2519),
    [anon_sym_POUNDIF] = ACTIONS(2519),
    [anon_sym_POUNDIf] = ACTIONS(2519),
    [anon_sym_not] = ACTIONS(2517),
    [anon_sym_NOT] = ACTIONS(2517),
    [anon_sym_Not] = ACTIONS(2517),
    [anon_sym_POUNDelif] = ACTIONS(2519),
    [anon_sym_POUNDELIF] = ACTIONS(2519),
    [anon_sym_POUNDElif] = ACTIONS(2519),
    [anon_sym_POUNDelse] = ACTIONS(2519),
    [anon_sym_POUNDELSE] = ACTIONS(2519),
    [anon_sym_POUNDElse] = ACTIONS(2519),
    [anon_sym_POUNDendif] = ACTIONS(2519),
    [anon_sym_POUNDENDIF] = ACTIONS(2519),
    [anon_sym_POUNDEndif] = ACTIONS(2519),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2519),
    [aux_sym__expression_token1] = ACTIONS(2519),
    [aux_sym__expression_token2] = ACTIONS(2519),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2517),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2517),
    [anon_sym_SLASH] = ACTIONS(2517),
    [anon_sym_div] = ACTIONS(2517),
    [anon_sym_DIV] = ACTIONS(2517),
    [anon_sym_Div] = ACTIONS(2517),
    [anon_sym_mod] = ACTIONS(2517),
    [anon_sym_MOD] = ACTIONS(2517),
    [anon_sym_Mod] = ACTIONS(2517),
    [anon_sym_PLUS] = ACTIONS(2517),
    [anon_sym_GT_EQ] = ACTIONS(2519),
    [anon_sym_LT_EQ] = ACTIONS(2519),
    [anon_sym_GT] = ACTIONS(2517),
    [anon_sym_LT] = ACTIONS(2517),
    [anon_sym_LT_GT] = ACTIONS(2519),
    [anon_sym_and] = ACTIONS(2517),
    [anon_sym_AND] = ACTIONS(2517),
    [anon_sym_And] = ACTIONS(2517),
    [anon_sym_or] = ACTIONS(2517),
    [anon_sym_OR] = ACTIONS(2517),
    [anon_sym_Or] = ACTIONS(2517),
    [anon_sym_xor] = ACTIONS(2517),
    [anon_sym_XOR] = ACTIONS(2517),
    [anon_sym_Xor] = ACTIONS(2517),
    [anon_sym_QMARK] = ACTIONS(2519),
    [sym_datetime_literal] = ACTIONS(2519),
    [sym_date_literal] = ACTIONS(2517),
    [sym_time_literal] = ACTIONS(2517),
    [sym_biginteger_literal] = ACTIONS(2519),
    [anon_sym_else] = ACTIONS(2517),
    [anon_sym_ELSE] = ACTIONS(2517),
    [anon_sym_Else] = ACTIONS(2517),
    [anon_sym_in] = ACTIONS(2517),
    [anon_sym_IN] = ACTIONS(2517),
    [anon_sym_In] = ACTIONS(2517),
    [sym_page_keyword] = ACTIONS(2517),
    [anon_sym_codeunit] = ACTIONS(2517),
    [anon_sym_CODEUNIT] = ACTIONS(2517),
    [anon_sym_Codeunit] = ACTIONS(2517),
    [anon_sym_CodeUnit] = ACTIONS(2517),
    [anon_sym_COdeunit] = ACTIONS(2517),
    [anon_sym_codeUnit] = ACTIONS(2517),
    [sym_report_keyword] = ACTIONS(2517),
    [sym_query_keyword] = ACTIONS(2517),
    [anon_sym_xmlport] = ACTIONS(2517),
    [anon_sym_XMLPORT] = ACTIONS(2517),
    [anon_sym_Xmlport] = ACTIONS(2517),
    [anon_sym_XMLport] = ACTIONS(2517),
    [anon_sym_XMLPort] = ACTIONS(2517),
    [anon_sym_XmlPort] = ACTIONS(2517),
    [anon_sym_enum] = ACTIONS(2517),
    [anon_sym_ENUM] = ACTIONS(2517),
    [anon_sym_Enum] = ACTIONS(2517),
    [anon_sym_eNUM] = ACTIONS(2517),
    [anon_sym_eNum] = ACTIONS(2517),
    [anon_sym_ENum] = ACTIONS(2517),
    [sym_quoted_identifier] = ACTIONS(2519),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2519),
    [sym_integer] = ACTIONS(2517),
    [sym_continue_as_identifier] = ACTIONS(2519),
    [sym_preproc_open] = ACTIONS(2519),
    [sym_preproc_close] = ACTIONS(2519),
  },
  [STATE(1434)] = {
    [sym_identifier] = ACTIONS(2543),
    [anon_sym_SEMI] = ACTIONS(2545),
    [anon_sym_DOT] = ACTIONS(2543),
    [anon_sym_EQ] = ACTIONS(2545),
    [anon_sym_COMMA] = ACTIONS(2545),
    [anon_sym_COLON] = ACTIONS(2543),
    [anon_sym_DASH] = ACTIONS(2543),
    [aux_sym_boolean_token1] = ACTIONS(2543),
    [aux_sym_boolean_token2] = ACTIONS(2543),
    [sym_decimal] = ACTIONS(2543),
    [anon_sym_LPAREN] = ACTIONS(2545),
    [anon_sym_DOT_DOT] = ACTIONS(2545),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2543),
    [anon_sym_STAR] = ACTIONS(2543),
    [anon_sym_LBRACK] = ACTIONS(2545),
    [aux_sym_record_type_token1] = ACTIONS(2543),
    [aux_sym_basic_type_token21] = ACTIONS(2543),
    [aux_sym_basic_type_token22] = ACTIONS(2543),
    [aux_sym_basic_type_token48] = ACTIONS(2543),
    [anon_sym_COLON_COLON] = ACTIONS(2545),
    [anon_sym_POUNDif] = ACTIONS(2545),
    [anon_sym_POUNDIF] = ACTIONS(2545),
    [anon_sym_POUNDIf] = ACTIONS(2545),
    [anon_sym_not] = ACTIONS(2543),
    [anon_sym_NOT] = ACTIONS(2543),
    [anon_sym_Not] = ACTIONS(2543),
    [anon_sym_POUNDelif] = ACTIONS(2545),
    [anon_sym_POUNDELIF] = ACTIONS(2545),
    [anon_sym_POUNDElif] = ACTIONS(2545),
    [anon_sym_POUNDelse] = ACTIONS(2545),
    [anon_sym_POUNDELSE] = ACTIONS(2545),
    [anon_sym_POUNDElse] = ACTIONS(2545),
    [anon_sym_POUNDendif] = ACTIONS(2545),
    [anon_sym_POUNDENDIF] = ACTIONS(2545),
    [anon_sym_POUNDEndif] = ACTIONS(2545),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2545),
    [aux_sym__expression_token1] = ACTIONS(2545),
    [aux_sym__expression_token2] = ACTIONS(2545),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2543),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2543),
    [anon_sym_SLASH] = ACTIONS(2543),
    [anon_sym_div] = ACTIONS(2543),
    [anon_sym_DIV] = ACTIONS(2543),
    [anon_sym_Div] = ACTIONS(2543),
    [anon_sym_mod] = ACTIONS(2543),
    [anon_sym_MOD] = ACTIONS(2543),
    [anon_sym_Mod] = ACTIONS(2543),
    [anon_sym_PLUS] = ACTIONS(2543),
    [anon_sym_GT_EQ] = ACTIONS(2545),
    [anon_sym_LT_EQ] = ACTIONS(2545),
    [anon_sym_GT] = ACTIONS(2543),
    [anon_sym_LT] = ACTIONS(2543),
    [anon_sym_LT_GT] = ACTIONS(2545),
    [anon_sym_and] = ACTIONS(2543),
    [anon_sym_AND] = ACTIONS(2543),
    [anon_sym_And] = ACTIONS(2543),
    [anon_sym_or] = ACTIONS(2543),
    [anon_sym_OR] = ACTIONS(2543),
    [anon_sym_Or] = ACTIONS(2543),
    [anon_sym_xor] = ACTIONS(2543),
    [anon_sym_XOR] = ACTIONS(2543),
    [anon_sym_Xor] = ACTIONS(2543),
    [anon_sym_QMARK] = ACTIONS(2545),
    [sym_datetime_literal] = ACTIONS(2545),
    [sym_date_literal] = ACTIONS(2543),
    [sym_time_literal] = ACTIONS(2543),
    [sym_biginteger_literal] = ACTIONS(2545),
    [anon_sym_else] = ACTIONS(2543),
    [anon_sym_ELSE] = ACTIONS(2543),
    [anon_sym_Else] = ACTIONS(2543),
    [anon_sym_in] = ACTIONS(2543),
    [anon_sym_IN] = ACTIONS(2543),
    [anon_sym_In] = ACTIONS(2543),
    [sym_page_keyword] = ACTIONS(2543),
    [anon_sym_codeunit] = ACTIONS(2543),
    [anon_sym_CODEUNIT] = ACTIONS(2543),
    [anon_sym_Codeunit] = ACTIONS(2543),
    [anon_sym_CodeUnit] = ACTIONS(2543),
    [anon_sym_COdeunit] = ACTIONS(2543),
    [anon_sym_codeUnit] = ACTIONS(2543),
    [sym_report_keyword] = ACTIONS(2543),
    [sym_query_keyword] = ACTIONS(2543),
    [anon_sym_xmlport] = ACTIONS(2543),
    [anon_sym_XMLPORT] = ACTIONS(2543),
    [anon_sym_Xmlport] = ACTIONS(2543),
    [anon_sym_XMLport] = ACTIONS(2543),
    [anon_sym_XMLPort] = ACTIONS(2543),
    [anon_sym_XmlPort] = ACTIONS(2543),
    [anon_sym_enum] = ACTIONS(2543),
    [anon_sym_ENUM] = ACTIONS(2543),
    [anon_sym_Enum] = ACTIONS(2543),
    [anon_sym_eNUM] = ACTIONS(2543),
    [anon_sym_eNum] = ACTIONS(2543),
    [anon_sym_ENum] = ACTIONS(2543),
    [sym_quoted_identifier] = ACTIONS(2545),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2545),
    [sym_integer] = ACTIONS(2543),
    [sym_continue_as_identifier] = ACTIONS(2545),
    [sym_preproc_open] = ACTIONS(2545),
    [sym_preproc_close] = ACTIONS(2545),
  },
  [STATE(1435)] = {
    [sym_identifier] = ACTIONS(2547),
    [anon_sym_SEMI] = ACTIONS(2549),
    [anon_sym_DOT] = ACTIONS(2547),
    [anon_sym_EQ] = ACTIONS(2549),
    [anon_sym_COMMA] = ACTIONS(2549),
    [anon_sym_COLON] = ACTIONS(2547),
    [anon_sym_DASH] = ACTIONS(2547),
    [aux_sym_boolean_token1] = ACTIONS(2547),
    [aux_sym_boolean_token2] = ACTIONS(2547),
    [sym_decimal] = ACTIONS(2547),
    [anon_sym_LPAREN] = ACTIONS(2549),
    [anon_sym_DOT_DOT] = ACTIONS(2549),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2547),
    [anon_sym_STAR] = ACTIONS(2547),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [aux_sym_record_type_token1] = ACTIONS(2547),
    [aux_sym_basic_type_token21] = ACTIONS(2547),
    [aux_sym_basic_type_token22] = ACTIONS(2547),
    [aux_sym_basic_type_token48] = ACTIONS(2547),
    [anon_sym_COLON_COLON] = ACTIONS(2549),
    [anon_sym_POUNDif] = ACTIONS(2549),
    [anon_sym_POUNDIF] = ACTIONS(2549),
    [anon_sym_POUNDIf] = ACTIONS(2549),
    [anon_sym_not] = ACTIONS(2547),
    [anon_sym_NOT] = ACTIONS(2547),
    [anon_sym_Not] = ACTIONS(2547),
    [anon_sym_POUNDelif] = ACTIONS(2549),
    [anon_sym_POUNDELIF] = ACTIONS(2549),
    [anon_sym_POUNDElif] = ACTIONS(2549),
    [anon_sym_POUNDelse] = ACTIONS(2549),
    [anon_sym_POUNDELSE] = ACTIONS(2549),
    [anon_sym_POUNDElse] = ACTIONS(2549),
    [anon_sym_POUNDendif] = ACTIONS(2549),
    [anon_sym_POUNDENDIF] = ACTIONS(2549),
    [anon_sym_POUNDEndif] = ACTIONS(2549),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2549),
    [aux_sym__expression_token1] = ACTIONS(2549),
    [aux_sym__expression_token2] = ACTIONS(2549),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2547),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2547),
    [anon_sym_SLASH] = ACTIONS(2547),
    [anon_sym_div] = ACTIONS(2547),
    [anon_sym_DIV] = ACTIONS(2547),
    [anon_sym_Div] = ACTIONS(2547),
    [anon_sym_mod] = ACTIONS(2547),
    [anon_sym_MOD] = ACTIONS(2547),
    [anon_sym_Mod] = ACTIONS(2547),
    [anon_sym_PLUS] = ACTIONS(2547),
    [anon_sym_GT_EQ] = ACTIONS(2549),
    [anon_sym_LT_EQ] = ACTIONS(2549),
    [anon_sym_GT] = ACTIONS(2547),
    [anon_sym_LT] = ACTIONS(2547),
    [anon_sym_LT_GT] = ACTIONS(2549),
    [anon_sym_and] = ACTIONS(2547),
    [anon_sym_AND] = ACTIONS(2547),
    [anon_sym_And] = ACTIONS(2547),
    [anon_sym_or] = ACTIONS(2547),
    [anon_sym_OR] = ACTIONS(2547),
    [anon_sym_Or] = ACTIONS(2547),
    [anon_sym_xor] = ACTIONS(2547),
    [anon_sym_XOR] = ACTIONS(2547),
    [anon_sym_Xor] = ACTIONS(2547),
    [anon_sym_QMARK] = ACTIONS(2549),
    [sym_datetime_literal] = ACTIONS(2549),
    [sym_date_literal] = ACTIONS(2547),
    [sym_time_literal] = ACTIONS(2547),
    [sym_biginteger_literal] = ACTIONS(2549),
    [anon_sym_else] = ACTIONS(2547),
    [anon_sym_ELSE] = ACTIONS(2547),
    [anon_sym_Else] = ACTIONS(2547),
    [anon_sym_in] = ACTIONS(2547),
    [anon_sym_IN] = ACTIONS(2547),
    [anon_sym_In] = ACTIONS(2547),
    [sym_page_keyword] = ACTIONS(2547),
    [anon_sym_codeunit] = ACTIONS(2547),
    [anon_sym_CODEUNIT] = ACTIONS(2547),
    [anon_sym_Codeunit] = ACTIONS(2547),
    [anon_sym_CodeUnit] = ACTIONS(2547),
    [anon_sym_COdeunit] = ACTIONS(2547),
    [anon_sym_codeUnit] = ACTIONS(2547),
    [sym_report_keyword] = ACTIONS(2547),
    [sym_query_keyword] = ACTIONS(2547),
    [anon_sym_xmlport] = ACTIONS(2547),
    [anon_sym_XMLPORT] = ACTIONS(2547),
    [anon_sym_Xmlport] = ACTIONS(2547),
    [anon_sym_XMLport] = ACTIONS(2547),
    [anon_sym_XMLPort] = ACTIONS(2547),
    [anon_sym_XmlPort] = ACTIONS(2547),
    [anon_sym_enum] = ACTIONS(2547),
    [anon_sym_ENUM] = ACTIONS(2547),
    [anon_sym_Enum] = ACTIONS(2547),
    [anon_sym_eNUM] = ACTIONS(2547),
    [anon_sym_eNum] = ACTIONS(2547),
    [anon_sym_ENum] = ACTIONS(2547),
    [sym_quoted_identifier] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2549),
    [sym_integer] = ACTIONS(2547),
    [sym_continue_as_identifier] = ACTIONS(2549),
    [sym_preproc_open] = ACTIONS(2549),
    [sym_preproc_close] = ACTIONS(2549),
  },
  [STATE(1436)] = {
    [sym_identifier] = ACTIONS(2525),
    [anon_sym_SEMI] = ACTIONS(2527),
    [anon_sym_DOT] = ACTIONS(2525),
    [anon_sym_EQ] = ACTIONS(2527),
    [anon_sym_COMMA] = ACTIONS(2527),
    [anon_sym_COLON] = ACTIONS(2525),
    [anon_sym_DASH] = ACTIONS(2525),
    [aux_sym_boolean_token1] = ACTIONS(2525),
    [aux_sym_boolean_token2] = ACTIONS(2525),
    [sym_decimal] = ACTIONS(2525),
    [anon_sym_LPAREN] = ACTIONS(2527),
    [anon_sym_DOT_DOT] = ACTIONS(2527),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2525),
    [anon_sym_STAR] = ACTIONS(2525),
    [anon_sym_LBRACK] = ACTIONS(2527),
    [aux_sym_record_type_token1] = ACTIONS(2525),
    [aux_sym_basic_type_token21] = ACTIONS(2525),
    [aux_sym_basic_type_token22] = ACTIONS(2525),
    [aux_sym_basic_type_token48] = ACTIONS(2525),
    [anon_sym_COLON_COLON] = ACTIONS(2527),
    [anon_sym_POUNDif] = ACTIONS(2527),
    [anon_sym_POUNDIF] = ACTIONS(2527),
    [anon_sym_POUNDIf] = ACTIONS(2527),
    [anon_sym_not] = ACTIONS(2525),
    [anon_sym_NOT] = ACTIONS(2525),
    [anon_sym_Not] = ACTIONS(2525),
    [anon_sym_POUNDelif] = ACTIONS(2527),
    [anon_sym_POUNDELIF] = ACTIONS(2527),
    [anon_sym_POUNDElif] = ACTIONS(2527),
    [anon_sym_POUNDelse] = ACTIONS(2527),
    [anon_sym_POUNDELSE] = ACTIONS(2527),
    [anon_sym_POUNDElse] = ACTIONS(2527),
    [anon_sym_POUNDendif] = ACTIONS(2527),
    [anon_sym_POUNDENDIF] = ACTIONS(2527),
    [anon_sym_POUNDEndif] = ACTIONS(2527),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2527),
    [aux_sym__expression_token1] = ACTIONS(2527),
    [aux_sym__expression_token2] = ACTIONS(2527),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2525),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2525),
    [anon_sym_SLASH] = ACTIONS(2525),
    [anon_sym_div] = ACTIONS(2525),
    [anon_sym_DIV] = ACTIONS(2525),
    [anon_sym_Div] = ACTIONS(2525),
    [anon_sym_mod] = ACTIONS(2525),
    [anon_sym_MOD] = ACTIONS(2525),
    [anon_sym_Mod] = ACTIONS(2525),
    [anon_sym_PLUS] = ACTIONS(2525),
    [anon_sym_GT_EQ] = ACTIONS(2527),
    [anon_sym_LT_EQ] = ACTIONS(2527),
    [anon_sym_GT] = ACTIONS(2525),
    [anon_sym_LT] = ACTIONS(2525),
    [anon_sym_LT_GT] = ACTIONS(2527),
    [anon_sym_and] = ACTIONS(2525),
    [anon_sym_AND] = ACTIONS(2525),
    [anon_sym_And] = ACTIONS(2525),
    [anon_sym_or] = ACTIONS(2525),
    [anon_sym_OR] = ACTIONS(2525),
    [anon_sym_Or] = ACTIONS(2525),
    [anon_sym_xor] = ACTIONS(2525),
    [anon_sym_XOR] = ACTIONS(2525),
    [anon_sym_Xor] = ACTIONS(2525),
    [anon_sym_QMARK] = ACTIONS(2527),
    [sym_datetime_literal] = ACTIONS(2527),
    [sym_date_literal] = ACTIONS(2525),
    [sym_time_literal] = ACTIONS(2525),
    [sym_biginteger_literal] = ACTIONS(2527),
    [anon_sym_else] = ACTIONS(2525),
    [anon_sym_ELSE] = ACTIONS(2525),
    [anon_sym_Else] = ACTIONS(2525),
    [anon_sym_in] = ACTIONS(2525),
    [anon_sym_IN] = ACTIONS(2525),
    [anon_sym_In] = ACTIONS(2525),
    [sym_page_keyword] = ACTIONS(2525),
    [anon_sym_codeunit] = ACTIONS(2525),
    [anon_sym_CODEUNIT] = ACTIONS(2525),
    [anon_sym_Codeunit] = ACTIONS(2525),
    [anon_sym_CodeUnit] = ACTIONS(2525),
    [anon_sym_COdeunit] = ACTIONS(2525),
    [anon_sym_codeUnit] = ACTIONS(2525),
    [sym_report_keyword] = ACTIONS(2525),
    [sym_query_keyword] = ACTIONS(2525),
    [anon_sym_xmlport] = ACTIONS(2525),
    [anon_sym_XMLPORT] = ACTIONS(2525),
    [anon_sym_Xmlport] = ACTIONS(2525),
    [anon_sym_XMLport] = ACTIONS(2525),
    [anon_sym_XMLPort] = ACTIONS(2525),
    [anon_sym_XmlPort] = ACTIONS(2525),
    [anon_sym_enum] = ACTIONS(2525),
    [anon_sym_ENUM] = ACTIONS(2525),
    [anon_sym_Enum] = ACTIONS(2525),
    [anon_sym_eNUM] = ACTIONS(2525),
    [anon_sym_eNum] = ACTIONS(2525),
    [anon_sym_ENum] = ACTIONS(2525),
    [sym_quoted_identifier] = ACTIONS(2527),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2527),
    [sym_integer] = ACTIONS(2525),
    [sym_continue_as_identifier] = ACTIONS(2527),
    [sym_preproc_open] = ACTIONS(2527),
    [sym_preproc_close] = ACTIONS(2527),
  },
  [STATE(1437)] = {
    [sym_identifier] = ACTIONS(2414),
    [anon_sym_SEMI] = ACTIONS(2416),
    [anon_sym_DOT] = ACTIONS(2414),
    [anon_sym_EQ] = ACTIONS(2416),
    [anon_sym_COMMA] = ACTIONS(2416),
    [anon_sym_COLON] = ACTIONS(2414),
    [anon_sym_DASH] = ACTIONS(2414),
    [aux_sym_boolean_token1] = ACTIONS(2414),
    [aux_sym_boolean_token2] = ACTIONS(2414),
    [sym_decimal] = ACTIONS(2414),
    [anon_sym_LPAREN] = ACTIONS(2416),
    [anon_sym_DOT_DOT] = ACTIONS(2416),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2414),
    [anon_sym_STAR] = ACTIONS(2414),
    [anon_sym_LBRACK] = ACTIONS(2416),
    [aux_sym_record_type_token1] = ACTIONS(2414),
    [aux_sym_basic_type_token21] = ACTIONS(2414),
    [aux_sym_basic_type_token22] = ACTIONS(2414),
    [aux_sym_basic_type_token48] = ACTIONS(2414),
    [anon_sym_COLON_COLON] = ACTIONS(2416),
    [anon_sym_POUNDif] = ACTIONS(2416),
    [anon_sym_POUNDIF] = ACTIONS(2416),
    [anon_sym_POUNDIf] = ACTIONS(2416),
    [anon_sym_not] = ACTIONS(2414),
    [anon_sym_NOT] = ACTIONS(2414),
    [anon_sym_Not] = ACTIONS(2414),
    [anon_sym_POUNDelif] = ACTIONS(2416),
    [anon_sym_POUNDELIF] = ACTIONS(2416),
    [anon_sym_POUNDElif] = ACTIONS(2416),
    [anon_sym_POUNDelse] = ACTIONS(2416),
    [anon_sym_POUNDELSE] = ACTIONS(2416),
    [anon_sym_POUNDElse] = ACTIONS(2416),
    [anon_sym_POUNDendif] = ACTIONS(2416),
    [anon_sym_POUNDENDIF] = ACTIONS(2416),
    [anon_sym_POUNDEndif] = ACTIONS(2416),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2416),
    [aux_sym__expression_token1] = ACTIONS(2416),
    [aux_sym__expression_token2] = ACTIONS(2416),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2414),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2414),
    [anon_sym_SLASH] = ACTIONS(2414),
    [anon_sym_div] = ACTIONS(2414),
    [anon_sym_DIV] = ACTIONS(2414),
    [anon_sym_Div] = ACTIONS(2414),
    [anon_sym_mod] = ACTIONS(2414),
    [anon_sym_MOD] = ACTIONS(2414),
    [anon_sym_Mod] = ACTIONS(2414),
    [anon_sym_PLUS] = ACTIONS(2414),
    [anon_sym_GT_EQ] = ACTIONS(2416),
    [anon_sym_LT_EQ] = ACTIONS(2416),
    [anon_sym_GT] = ACTIONS(2414),
    [anon_sym_LT] = ACTIONS(2414),
    [anon_sym_LT_GT] = ACTIONS(2416),
    [anon_sym_and] = ACTIONS(2414),
    [anon_sym_AND] = ACTIONS(2414),
    [anon_sym_And] = ACTIONS(2414),
    [anon_sym_or] = ACTIONS(2414),
    [anon_sym_OR] = ACTIONS(2414),
    [anon_sym_Or] = ACTIONS(2414),
    [anon_sym_xor] = ACTIONS(2414),
    [anon_sym_XOR] = ACTIONS(2414),
    [anon_sym_Xor] = ACTIONS(2414),
    [anon_sym_QMARK] = ACTIONS(2416),
    [sym_datetime_literal] = ACTIONS(2416),
    [sym_date_literal] = ACTIONS(2414),
    [sym_time_literal] = ACTIONS(2414),
    [sym_biginteger_literal] = ACTIONS(2416),
    [anon_sym_else] = ACTIONS(2414),
    [anon_sym_ELSE] = ACTIONS(2414),
    [anon_sym_Else] = ACTIONS(2414),
    [anon_sym_in] = ACTIONS(2414),
    [anon_sym_IN] = ACTIONS(2414),
    [anon_sym_In] = ACTIONS(2414),
    [sym_page_keyword] = ACTIONS(2414),
    [anon_sym_codeunit] = ACTIONS(2414),
    [anon_sym_CODEUNIT] = ACTIONS(2414),
    [anon_sym_Codeunit] = ACTIONS(2414),
    [anon_sym_CodeUnit] = ACTIONS(2414),
    [anon_sym_COdeunit] = ACTIONS(2414),
    [anon_sym_codeUnit] = ACTIONS(2414),
    [sym_report_keyword] = ACTIONS(2414),
    [sym_query_keyword] = ACTIONS(2414),
    [anon_sym_xmlport] = ACTIONS(2414),
    [anon_sym_XMLPORT] = ACTIONS(2414),
    [anon_sym_Xmlport] = ACTIONS(2414),
    [anon_sym_XMLport] = ACTIONS(2414),
    [anon_sym_XMLPort] = ACTIONS(2414),
    [anon_sym_XmlPort] = ACTIONS(2414),
    [anon_sym_enum] = ACTIONS(2414),
    [anon_sym_ENUM] = ACTIONS(2414),
    [anon_sym_Enum] = ACTIONS(2414),
    [anon_sym_eNUM] = ACTIONS(2414),
    [anon_sym_eNum] = ACTIONS(2414),
    [anon_sym_ENum] = ACTIONS(2414),
    [sym_quoted_identifier] = ACTIONS(2416),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2416),
    [sym_integer] = ACTIONS(2414),
    [sym_continue_as_identifier] = ACTIONS(2416),
    [sym_preproc_open] = ACTIONS(2416),
    [sym_preproc_close] = ACTIONS(2416),
  },
  [STATE(1438)] = {
    [sym_identifier] = ACTIONS(2418),
    [anon_sym_SEMI] = ACTIONS(2420),
    [anon_sym_DOT] = ACTIONS(2418),
    [anon_sym_EQ] = ACTIONS(2420),
    [anon_sym_COMMA] = ACTIONS(2420),
    [anon_sym_COLON] = ACTIONS(2418),
    [anon_sym_DASH] = ACTIONS(2418),
    [aux_sym_boolean_token1] = ACTIONS(2418),
    [aux_sym_boolean_token2] = ACTIONS(2418),
    [sym_decimal] = ACTIONS(2418),
    [anon_sym_LPAREN] = ACTIONS(2420),
    [anon_sym_DOT_DOT] = ACTIONS(2420),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2418),
    [anon_sym_STAR] = ACTIONS(2418),
    [anon_sym_LBRACK] = ACTIONS(2420),
    [aux_sym_record_type_token1] = ACTIONS(2418),
    [aux_sym_basic_type_token21] = ACTIONS(2418),
    [aux_sym_basic_type_token22] = ACTIONS(2418),
    [aux_sym_basic_type_token48] = ACTIONS(2418),
    [anon_sym_COLON_COLON] = ACTIONS(2420),
    [anon_sym_POUNDif] = ACTIONS(2420),
    [anon_sym_POUNDIF] = ACTIONS(2420),
    [anon_sym_POUNDIf] = ACTIONS(2420),
    [anon_sym_not] = ACTIONS(2418),
    [anon_sym_NOT] = ACTIONS(2418),
    [anon_sym_Not] = ACTIONS(2418),
    [anon_sym_POUNDelif] = ACTIONS(2420),
    [anon_sym_POUNDELIF] = ACTIONS(2420),
    [anon_sym_POUNDElif] = ACTIONS(2420),
    [anon_sym_POUNDelse] = ACTIONS(2420),
    [anon_sym_POUNDELSE] = ACTIONS(2420),
    [anon_sym_POUNDElse] = ACTIONS(2420),
    [anon_sym_POUNDendif] = ACTIONS(2420),
    [anon_sym_POUNDENDIF] = ACTIONS(2420),
    [anon_sym_POUNDEndif] = ACTIONS(2420),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2420),
    [aux_sym__expression_token1] = ACTIONS(2420),
    [aux_sym__expression_token2] = ACTIONS(2420),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2418),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2418),
    [anon_sym_SLASH] = ACTIONS(2418),
    [anon_sym_div] = ACTIONS(2418),
    [anon_sym_DIV] = ACTIONS(2418),
    [anon_sym_Div] = ACTIONS(2418),
    [anon_sym_mod] = ACTIONS(2418),
    [anon_sym_MOD] = ACTIONS(2418),
    [anon_sym_Mod] = ACTIONS(2418),
    [anon_sym_PLUS] = ACTIONS(2418),
    [anon_sym_GT_EQ] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(2420),
    [anon_sym_GT] = ACTIONS(2418),
    [anon_sym_LT] = ACTIONS(2418),
    [anon_sym_LT_GT] = ACTIONS(2420),
    [anon_sym_and] = ACTIONS(2418),
    [anon_sym_AND] = ACTIONS(2418),
    [anon_sym_And] = ACTIONS(2418),
    [anon_sym_or] = ACTIONS(2418),
    [anon_sym_OR] = ACTIONS(2418),
    [anon_sym_Or] = ACTIONS(2418),
    [anon_sym_xor] = ACTIONS(2418),
    [anon_sym_XOR] = ACTIONS(2418),
    [anon_sym_Xor] = ACTIONS(2418),
    [anon_sym_QMARK] = ACTIONS(2420),
    [sym_datetime_literal] = ACTIONS(2420),
    [sym_date_literal] = ACTIONS(2418),
    [sym_time_literal] = ACTIONS(2418),
    [sym_biginteger_literal] = ACTIONS(2420),
    [anon_sym_else] = ACTIONS(2418),
    [anon_sym_ELSE] = ACTIONS(2418),
    [anon_sym_Else] = ACTIONS(2418),
    [anon_sym_in] = ACTIONS(2418),
    [anon_sym_IN] = ACTIONS(2418),
    [anon_sym_In] = ACTIONS(2418),
    [sym_page_keyword] = ACTIONS(2418),
    [anon_sym_codeunit] = ACTIONS(2418),
    [anon_sym_CODEUNIT] = ACTIONS(2418),
    [anon_sym_Codeunit] = ACTIONS(2418),
    [anon_sym_CodeUnit] = ACTIONS(2418),
    [anon_sym_COdeunit] = ACTIONS(2418),
    [anon_sym_codeUnit] = ACTIONS(2418),
    [sym_report_keyword] = ACTIONS(2418),
    [sym_query_keyword] = ACTIONS(2418),
    [anon_sym_xmlport] = ACTIONS(2418),
    [anon_sym_XMLPORT] = ACTIONS(2418),
    [anon_sym_Xmlport] = ACTIONS(2418),
    [anon_sym_XMLport] = ACTIONS(2418),
    [anon_sym_XMLPort] = ACTIONS(2418),
    [anon_sym_XmlPort] = ACTIONS(2418),
    [anon_sym_enum] = ACTIONS(2418),
    [anon_sym_ENUM] = ACTIONS(2418),
    [anon_sym_Enum] = ACTIONS(2418),
    [anon_sym_eNUM] = ACTIONS(2418),
    [anon_sym_eNum] = ACTIONS(2418),
    [anon_sym_ENum] = ACTIONS(2418),
    [sym_quoted_identifier] = ACTIONS(2420),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2420),
    [sym_integer] = ACTIONS(2418),
    [sym_continue_as_identifier] = ACTIONS(2420),
    [sym_preproc_open] = ACTIONS(2420),
    [sym_preproc_close] = ACTIONS(2420),
  },
  [STATE(1439)] = {
    [sym_identifier] = ACTIONS(2422),
    [anon_sym_SEMI] = ACTIONS(2424),
    [anon_sym_DOT] = ACTIONS(2422),
    [anon_sym_EQ] = ACTIONS(2424),
    [anon_sym_COMMA] = ACTIONS(2424),
    [anon_sym_COLON] = ACTIONS(2422),
    [anon_sym_DASH] = ACTIONS(2422),
    [aux_sym_boolean_token1] = ACTIONS(2422),
    [aux_sym_boolean_token2] = ACTIONS(2422),
    [sym_decimal] = ACTIONS(2422),
    [anon_sym_LPAREN] = ACTIONS(2424),
    [anon_sym_DOT_DOT] = ACTIONS(2424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2422),
    [anon_sym_STAR] = ACTIONS(2422),
    [anon_sym_LBRACK] = ACTIONS(2424),
    [aux_sym_record_type_token1] = ACTIONS(2422),
    [aux_sym_basic_type_token21] = ACTIONS(2422),
    [aux_sym_basic_type_token22] = ACTIONS(2422),
    [aux_sym_basic_type_token48] = ACTIONS(2422),
    [anon_sym_COLON_COLON] = ACTIONS(2424),
    [anon_sym_POUNDif] = ACTIONS(2424),
    [anon_sym_POUNDIF] = ACTIONS(2424),
    [anon_sym_POUNDIf] = ACTIONS(2424),
    [anon_sym_not] = ACTIONS(2422),
    [anon_sym_NOT] = ACTIONS(2422),
    [anon_sym_Not] = ACTIONS(2422),
    [anon_sym_POUNDelif] = ACTIONS(2424),
    [anon_sym_POUNDELIF] = ACTIONS(2424),
    [anon_sym_POUNDElif] = ACTIONS(2424),
    [anon_sym_POUNDelse] = ACTIONS(2424),
    [anon_sym_POUNDELSE] = ACTIONS(2424),
    [anon_sym_POUNDElse] = ACTIONS(2424),
    [anon_sym_POUNDendif] = ACTIONS(2424),
    [anon_sym_POUNDENDIF] = ACTIONS(2424),
    [anon_sym_POUNDEndif] = ACTIONS(2424),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2424),
    [aux_sym__expression_token1] = ACTIONS(2424),
    [aux_sym__expression_token2] = ACTIONS(2424),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2422),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2422),
    [anon_sym_SLASH] = ACTIONS(2422),
    [anon_sym_div] = ACTIONS(2422),
    [anon_sym_DIV] = ACTIONS(2422),
    [anon_sym_Div] = ACTIONS(2422),
    [anon_sym_mod] = ACTIONS(2422),
    [anon_sym_MOD] = ACTIONS(2422),
    [anon_sym_Mod] = ACTIONS(2422),
    [anon_sym_PLUS] = ACTIONS(2422),
    [anon_sym_GT_EQ] = ACTIONS(2424),
    [anon_sym_LT_EQ] = ACTIONS(2424),
    [anon_sym_GT] = ACTIONS(2422),
    [anon_sym_LT] = ACTIONS(2422),
    [anon_sym_LT_GT] = ACTIONS(2424),
    [anon_sym_and] = ACTIONS(2422),
    [anon_sym_AND] = ACTIONS(2422),
    [anon_sym_And] = ACTIONS(2422),
    [anon_sym_or] = ACTIONS(2422),
    [anon_sym_OR] = ACTIONS(2422),
    [anon_sym_Or] = ACTIONS(2422),
    [anon_sym_xor] = ACTIONS(2422),
    [anon_sym_XOR] = ACTIONS(2422),
    [anon_sym_Xor] = ACTIONS(2422),
    [anon_sym_QMARK] = ACTIONS(2424),
    [sym_datetime_literal] = ACTIONS(2424),
    [sym_date_literal] = ACTIONS(2422),
    [sym_time_literal] = ACTIONS(2422),
    [sym_biginteger_literal] = ACTIONS(2424),
    [anon_sym_else] = ACTIONS(2422),
    [anon_sym_ELSE] = ACTIONS(2422),
    [anon_sym_Else] = ACTIONS(2422),
    [anon_sym_in] = ACTIONS(2422),
    [anon_sym_IN] = ACTIONS(2422),
    [anon_sym_In] = ACTIONS(2422),
    [sym_page_keyword] = ACTIONS(2422),
    [anon_sym_codeunit] = ACTIONS(2422),
    [anon_sym_CODEUNIT] = ACTIONS(2422),
    [anon_sym_Codeunit] = ACTIONS(2422),
    [anon_sym_CodeUnit] = ACTIONS(2422),
    [anon_sym_COdeunit] = ACTIONS(2422),
    [anon_sym_codeUnit] = ACTIONS(2422),
    [sym_report_keyword] = ACTIONS(2422),
    [sym_query_keyword] = ACTIONS(2422),
    [anon_sym_xmlport] = ACTIONS(2422),
    [anon_sym_XMLPORT] = ACTIONS(2422),
    [anon_sym_Xmlport] = ACTIONS(2422),
    [anon_sym_XMLport] = ACTIONS(2422),
    [anon_sym_XMLPort] = ACTIONS(2422),
    [anon_sym_XmlPort] = ACTIONS(2422),
    [anon_sym_enum] = ACTIONS(2422),
    [anon_sym_ENUM] = ACTIONS(2422),
    [anon_sym_Enum] = ACTIONS(2422),
    [anon_sym_eNUM] = ACTIONS(2422),
    [anon_sym_eNum] = ACTIONS(2422),
    [anon_sym_ENum] = ACTIONS(2422),
    [sym_quoted_identifier] = ACTIONS(2424),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2424),
    [sym_integer] = ACTIONS(2422),
    [sym_continue_as_identifier] = ACTIONS(2424),
    [sym_preproc_open] = ACTIONS(2424),
    [sym_preproc_close] = ACTIONS(2424),
  },
  [STATE(1440)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_SEMI] = ACTIONS(2428),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_COMMA] = ACTIONS(2428),
    [anon_sym_COLON] = ACTIONS(2426),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [anon_sym_COLON_COLON] = ACTIONS(2428),
    [anon_sym_POUNDif] = ACTIONS(2428),
    [anon_sym_POUNDIF] = ACTIONS(2428),
    [anon_sym_POUNDIf] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [anon_sym_POUNDelif] = ACTIONS(2428),
    [anon_sym_POUNDELIF] = ACTIONS(2428),
    [anon_sym_POUNDElif] = ACTIONS(2428),
    [anon_sym_POUNDelse] = ACTIONS(2428),
    [anon_sym_POUNDELSE] = ACTIONS(2428),
    [anon_sym_POUNDElse] = ACTIONS(2428),
    [anon_sym_POUNDendif] = ACTIONS(2428),
    [anon_sym_POUNDENDIF] = ACTIONS(2428),
    [anon_sym_POUNDEndif] = ACTIONS(2428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2428),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_else] = ACTIONS(2426),
    [anon_sym_ELSE] = ACTIONS(2426),
    [anon_sym_Else] = ACTIONS(2426),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_open] = ACTIONS(2428),
    [sym_preproc_close] = ACTIONS(2428),
  },
  [STATE(1441)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1447),
    [sym_identifier] = ACTIONS(376),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(3881),
    [anon_sym_COLON] = ACTIONS(376),
    [anon_sym_DASH] = ACTIONS(376),
    [aux_sym_boolean_token1] = ACTIONS(376),
    [aux_sym_boolean_token2] = ACTIONS(376),
    [sym_decimal] = ACTIONS(376),
    [anon_sym_LPAREN] = ACTIONS(374),
    [anon_sym_DOT_DOT] = ACTIONS(374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(376),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(376),
    [aux_sym_basic_type_token21] = ACTIONS(376),
    [aux_sym_basic_type_token22] = ACTIONS(376),
    [aux_sym_basic_type_token48] = ACTIONS(376),
    [anon_sym_POUNDif] = ACTIONS(374),
    [anon_sym_POUNDIF] = ACTIONS(374),
    [anon_sym_POUNDIf] = ACTIONS(374),
    [anon_sym_not] = ACTIONS(376),
    [anon_sym_NOT] = ACTIONS(376),
    [anon_sym_Not] = ACTIONS(376),
    [anon_sym_POUNDelif] = ACTIONS(374),
    [anon_sym_POUNDELIF] = ACTIONS(374),
    [anon_sym_POUNDElif] = ACTIONS(374),
    [anon_sym_POUNDelse] = ACTIONS(374),
    [anon_sym_POUNDELSE] = ACTIONS(374),
    [anon_sym_POUNDElse] = ACTIONS(374),
    [anon_sym_POUNDendif] = ACTIONS(374),
    [anon_sym_POUNDENDIF] = ACTIONS(374),
    [anon_sym_POUNDEndif] = ACTIONS(374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(374),
    [aux_sym__expression_token1] = ACTIONS(374),
    [aux_sym__expression_token2] = ACTIONS(374),
    [aux_sym_keyword_identifier_token1] = ACTIONS(376),
    [aux_sym_keyword_identifier_token2] = ACTIONS(376),
    [anon_sym_SLASH] = ACTIONS(376),
    [anon_sym_div] = ACTIONS(376),
    [anon_sym_DIV] = ACTIONS(376),
    [anon_sym_Div] = ACTIONS(376),
    [anon_sym_mod] = ACTIONS(376),
    [anon_sym_MOD] = ACTIONS(376),
    [anon_sym_Mod] = ACTIONS(376),
    [anon_sym_PLUS] = ACTIONS(376),
    [anon_sym_GT_EQ] = ACTIONS(374),
    [anon_sym_LT_EQ] = ACTIONS(374),
    [anon_sym_GT] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(376),
    [anon_sym_LT_GT] = ACTIONS(374),
    [anon_sym_and] = ACTIONS(376),
    [anon_sym_AND] = ACTIONS(376),
    [anon_sym_And] = ACTIONS(376),
    [anon_sym_or] = ACTIONS(376),
    [anon_sym_OR] = ACTIONS(376),
    [anon_sym_Or] = ACTIONS(376),
    [anon_sym_xor] = ACTIONS(376),
    [anon_sym_XOR] = ACTIONS(376),
    [anon_sym_Xor] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(374),
    [sym_datetime_literal] = ACTIONS(374),
    [sym_date_literal] = ACTIONS(376),
    [sym_time_literal] = ACTIONS(376),
    [sym_biginteger_literal] = ACTIONS(374),
    [anon_sym_else] = ACTIONS(376),
    [anon_sym_ELSE] = ACTIONS(376),
    [anon_sym_Else] = ACTIONS(376),
    [anon_sym_in] = ACTIONS(376),
    [anon_sym_IN] = ACTIONS(376),
    [anon_sym_In] = ACTIONS(376),
    [sym_page_keyword] = ACTIONS(376),
    [anon_sym_codeunit] = ACTIONS(376),
    [anon_sym_CODEUNIT] = ACTIONS(376),
    [anon_sym_Codeunit] = ACTIONS(376),
    [anon_sym_CodeUnit] = ACTIONS(376),
    [anon_sym_COdeunit] = ACTIONS(376),
    [anon_sym_codeUnit] = ACTIONS(376),
    [sym_report_keyword] = ACTIONS(376),
    [sym_query_keyword] = ACTIONS(376),
    [anon_sym_xmlport] = ACTIONS(376),
    [anon_sym_XMLPORT] = ACTIONS(376),
    [anon_sym_Xmlport] = ACTIONS(376),
    [anon_sym_XMLport] = ACTIONS(376),
    [anon_sym_XMLPort] = ACTIONS(376),
    [anon_sym_XmlPort] = ACTIONS(376),
    [anon_sym_enum] = ACTIONS(376),
    [anon_sym_ENUM] = ACTIONS(376),
    [anon_sym_Enum] = ACTIONS(376),
    [anon_sym_eNUM] = ACTIONS(376),
    [anon_sym_eNum] = ACTIONS(376),
    [anon_sym_ENum] = ACTIONS(376),
    [sym_quoted_identifier] = ACTIONS(374),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(374),
    [sym_integer] = ACTIONS(376),
    [sym_continue_as_identifier] = ACTIONS(374),
    [sym_preproc_open] = ACTIONS(374),
    [sym_preproc_close] = ACTIONS(374),
  },
  [STATE(1442)] = {
    [sym_identifier] = ACTIONS(2555),
    [anon_sym_SEMI] = ACTIONS(2557),
    [anon_sym_DOT] = ACTIONS(2555),
    [anon_sym_EQ] = ACTIONS(2557),
    [anon_sym_COMMA] = ACTIONS(2557),
    [anon_sym_COLON] = ACTIONS(2555),
    [anon_sym_DASH] = ACTIONS(2555),
    [aux_sym_boolean_token1] = ACTIONS(2555),
    [aux_sym_boolean_token2] = ACTIONS(2555),
    [sym_decimal] = ACTIONS(2555),
    [anon_sym_LPAREN] = ACTIONS(2557),
    [anon_sym_DOT_DOT] = ACTIONS(2557),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2555),
    [anon_sym_STAR] = ACTIONS(2555),
    [anon_sym_LBRACK] = ACTIONS(2557),
    [aux_sym_record_type_token1] = ACTIONS(2555),
    [aux_sym_basic_type_token21] = ACTIONS(2555),
    [aux_sym_basic_type_token22] = ACTIONS(2555),
    [aux_sym_basic_type_token48] = ACTIONS(2555),
    [anon_sym_COLON_COLON] = ACTIONS(2557),
    [anon_sym_POUNDif] = ACTIONS(2557),
    [anon_sym_POUNDIF] = ACTIONS(2557),
    [anon_sym_POUNDIf] = ACTIONS(2557),
    [anon_sym_not] = ACTIONS(2555),
    [anon_sym_NOT] = ACTIONS(2555),
    [anon_sym_Not] = ACTIONS(2555),
    [anon_sym_POUNDelif] = ACTIONS(2557),
    [anon_sym_POUNDELIF] = ACTIONS(2557),
    [anon_sym_POUNDElif] = ACTIONS(2557),
    [anon_sym_POUNDelse] = ACTIONS(2557),
    [anon_sym_POUNDELSE] = ACTIONS(2557),
    [anon_sym_POUNDElse] = ACTIONS(2557),
    [anon_sym_POUNDendif] = ACTIONS(2557),
    [anon_sym_POUNDENDIF] = ACTIONS(2557),
    [anon_sym_POUNDEndif] = ACTIONS(2557),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2557),
    [aux_sym__expression_token1] = ACTIONS(2557),
    [aux_sym__expression_token2] = ACTIONS(2557),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2555),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2555),
    [anon_sym_SLASH] = ACTIONS(2555),
    [anon_sym_div] = ACTIONS(2555),
    [anon_sym_DIV] = ACTIONS(2555),
    [anon_sym_Div] = ACTIONS(2555),
    [anon_sym_mod] = ACTIONS(2555),
    [anon_sym_MOD] = ACTIONS(2555),
    [anon_sym_Mod] = ACTIONS(2555),
    [anon_sym_PLUS] = ACTIONS(2555),
    [anon_sym_GT_EQ] = ACTIONS(2557),
    [anon_sym_LT_EQ] = ACTIONS(2557),
    [anon_sym_GT] = ACTIONS(2555),
    [anon_sym_LT] = ACTIONS(2555),
    [anon_sym_LT_GT] = ACTIONS(2557),
    [anon_sym_and] = ACTIONS(2555),
    [anon_sym_AND] = ACTIONS(2555),
    [anon_sym_And] = ACTIONS(2555),
    [anon_sym_or] = ACTIONS(2555),
    [anon_sym_OR] = ACTIONS(2555),
    [anon_sym_Or] = ACTIONS(2555),
    [anon_sym_xor] = ACTIONS(2555),
    [anon_sym_XOR] = ACTIONS(2555),
    [anon_sym_Xor] = ACTIONS(2555),
    [anon_sym_QMARK] = ACTIONS(2557),
    [sym_datetime_literal] = ACTIONS(2557),
    [sym_date_literal] = ACTIONS(2555),
    [sym_time_literal] = ACTIONS(2555),
    [sym_biginteger_literal] = ACTIONS(2557),
    [anon_sym_else] = ACTIONS(2555),
    [anon_sym_ELSE] = ACTIONS(2555),
    [anon_sym_Else] = ACTIONS(2555),
    [anon_sym_in] = ACTIONS(2555),
    [anon_sym_IN] = ACTIONS(2555),
    [anon_sym_In] = ACTIONS(2555),
    [sym_page_keyword] = ACTIONS(2555),
    [anon_sym_codeunit] = ACTIONS(2555),
    [anon_sym_CODEUNIT] = ACTIONS(2555),
    [anon_sym_Codeunit] = ACTIONS(2555),
    [anon_sym_CodeUnit] = ACTIONS(2555),
    [anon_sym_COdeunit] = ACTIONS(2555),
    [anon_sym_codeUnit] = ACTIONS(2555),
    [sym_report_keyword] = ACTIONS(2555),
    [sym_query_keyword] = ACTIONS(2555),
    [anon_sym_xmlport] = ACTIONS(2555),
    [anon_sym_XMLPORT] = ACTIONS(2555),
    [anon_sym_Xmlport] = ACTIONS(2555),
    [anon_sym_XMLport] = ACTIONS(2555),
    [anon_sym_XMLPort] = ACTIONS(2555),
    [anon_sym_XmlPort] = ACTIONS(2555),
    [anon_sym_enum] = ACTIONS(2555),
    [anon_sym_ENUM] = ACTIONS(2555),
    [anon_sym_Enum] = ACTIONS(2555),
    [anon_sym_eNUM] = ACTIONS(2555),
    [anon_sym_eNum] = ACTIONS(2555),
    [anon_sym_ENum] = ACTIONS(2555),
    [sym_quoted_identifier] = ACTIONS(2557),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2557),
    [sym_integer] = ACTIONS(2555),
    [sym_continue_as_identifier] = ACTIONS(2557),
    [sym_preproc_open] = ACTIONS(2557),
    [sym_preproc_close] = ACTIONS(2557),
  },
  [STATE(1443)] = {
    [sym_identifier] = ACTIONS(2396),
    [anon_sym_SEMI] = ACTIONS(2398),
    [anon_sym_DOT] = ACTIONS(2396),
    [anon_sym_EQ] = ACTIONS(2398),
    [anon_sym_COMMA] = ACTIONS(2398),
    [anon_sym_COLON] = ACTIONS(2396),
    [anon_sym_DASH] = ACTIONS(2396),
    [aux_sym_boolean_token1] = ACTIONS(2396),
    [aux_sym_boolean_token2] = ACTIONS(2396),
    [sym_decimal] = ACTIONS(2396),
    [anon_sym_LPAREN] = ACTIONS(2398),
    [anon_sym_DOT_DOT] = ACTIONS(2398),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2396),
    [anon_sym_STAR] = ACTIONS(2396),
    [anon_sym_LBRACK] = ACTIONS(2398),
    [aux_sym_record_type_token1] = ACTIONS(2396),
    [aux_sym_basic_type_token21] = ACTIONS(2396),
    [aux_sym_basic_type_token22] = ACTIONS(2396),
    [aux_sym_basic_type_token48] = ACTIONS(2396),
    [anon_sym_POUNDif] = ACTIONS(2398),
    [anon_sym_POUNDIF] = ACTIONS(2398),
    [anon_sym_POUNDIf] = ACTIONS(2398),
    [anon_sym_not] = ACTIONS(2396),
    [anon_sym_NOT] = ACTIONS(2396),
    [anon_sym_Not] = ACTIONS(2396),
    [anon_sym_POUNDelif] = ACTIONS(2398),
    [anon_sym_POUNDELIF] = ACTIONS(2398),
    [anon_sym_POUNDElif] = ACTIONS(2398),
    [anon_sym_POUNDelse] = ACTIONS(2398),
    [anon_sym_POUNDELSE] = ACTIONS(2398),
    [anon_sym_POUNDElse] = ACTIONS(2398),
    [anon_sym_POUNDendif] = ACTIONS(2398),
    [anon_sym_POUNDENDIF] = ACTIONS(2398),
    [anon_sym_POUNDEndif] = ACTIONS(2398),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2398),
    [aux_sym__expression_token1] = ACTIONS(2398),
    [aux_sym__expression_token2] = ACTIONS(2398),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2396),
    [anon_sym_SLASH] = ACTIONS(2396),
    [anon_sym_div] = ACTIONS(2396),
    [anon_sym_DIV] = ACTIONS(2396),
    [anon_sym_Div] = ACTIONS(2396),
    [anon_sym_mod] = ACTIONS(2396),
    [anon_sym_MOD] = ACTIONS(2396),
    [anon_sym_Mod] = ACTIONS(2396),
    [anon_sym_PLUS] = ACTIONS(2396),
    [anon_sym_GT_EQ] = ACTIONS(2398),
    [anon_sym_LT_EQ] = ACTIONS(2398),
    [anon_sym_GT] = ACTIONS(2396),
    [anon_sym_LT] = ACTIONS(2396),
    [anon_sym_LT_GT] = ACTIONS(2398),
    [anon_sym_and] = ACTIONS(2396),
    [anon_sym_AND] = ACTIONS(2396),
    [anon_sym_And] = ACTIONS(2396),
    [anon_sym_or] = ACTIONS(2396),
    [anon_sym_OR] = ACTIONS(2396),
    [anon_sym_Or] = ACTIONS(2396),
    [anon_sym_xor] = ACTIONS(2396),
    [anon_sym_XOR] = ACTIONS(2396),
    [anon_sym_Xor] = ACTIONS(2396),
    [anon_sym_QMARK] = ACTIONS(2398),
    [sym_datetime_literal] = ACTIONS(2398),
    [sym_date_literal] = ACTIONS(2396),
    [sym_time_literal] = ACTIONS(2396),
    [sym_biginteger_literal] = ACTIONS(2398),
    [anon_sym_else] = ACTIONS(2396),
    [anon_sym_ELSE] = ACTIONS(2396),
    [anon_sym_Else] = ACTIONS(2396),
    [anon_sym_in] = ACTIONS(2396),
    [anon_sym_IN] = ACTIONS(2396),
    [anon_sym_In] = ACTIONS(2396),
    [sym_page_keyword] = ACTIONS(2396),
    [anon_sym_codeunit] = ACTIONS(2396),
    [anon_sym_CODEUNIT] = ACTIONS(2396),
    [anon_sym_Codeunit] = ACTIONS(2396),
    [anon_sym_CodeUnit] = ACTIONS(2396),
    [anon_sym_COdeunit] = ACTIONS(2396),
    [anon_sym_codeUnit] = ACTIONS(2396),
    [sym_report_keyword] = ACTIONS(2396),
    [sym_query_keyword] = ACTIONS(2396),
    [anon_sym_xmlport] = ACTIONS(2396),
    [anon_sym_XMLPORT] = ACTIONS(2396),
    [anon_sym_Xmlport] = ACTIONS(2396),
    [anon_sym_XMLport] = ACTIONS(2396),
    [anon_sym_XMLPort] = ACTIONS(2396),
    [anon_sym_XmlPort] = ACTIONS(2396),
    [anon_sym_enum] = ACTIONS(2396),
    [anon_sym_ENUM] = ACTIONS(2396),
    [anon_sym_Enum] = ACTIONS(2396),
    [anon_sym_eNUM] = ACTIONS(2396),
    [anon_sym_eNum] = ACTIONS(2396),
    [anon_sym_ENum] = ACTIONS(2396),
    [sym_temporary_keyword] = ACTIONS(2396),
    [sym_quoted_identifier] = ACTIONS(2398),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2398),
    [sym_integer] = ACTIONS(2396),
    [sym_continue_as_identifier] = ACTIONS(2398),
    [sym_preproc_open] = ACTIONS(2398),
    [sym_preproc_close] = ACTIONS(2398),
  },
  [STATE(1444)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(3883),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1445)] = {
    [sym_identifier] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2563),
    [anon_sym_DOT] = ACTIONS(2561),
    [anon_sym_EQ] = ACTIONS(2563),
    [anon_sym_COMMA] = ACTIONS(2563),
    [anon_sym_COLON] = ACTIONS(2561),
    [anon_sym_DASH] = ACTIONS(2561),
    [aux_sym_boolean_token1] = ACTIONS(2561),
    [aux_sym_boolean_token2] = ACTIONS(2561),
    [sym_decimal] = ACTIONS(2561),
    [anon_sym_LPAREN] = ACTIONS(2563),
    [anon_sym_DOT_DOT] = ACTIONS(2563),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2561),
    [anon_sym_STAR] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2563),
    [aux_sym_record_type_token1] = ACTIONS(2561),
    [aux_sym_basic_type_token21] = ACTIONS(2561),
    [aux_sym_basic_type_token22] = ACTIONS(2561),
    [aux_sym_basic_type_token48] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_POUNDif] = ACTIONS(2563),
    [anon_sym_POUNDIF] = ACTIONS(2563),
    [anon_sym_POUNDIf] = ACTIONS(2563),
    [anon_sym_not] = ACTIONS(2561),
    [anon_sym_NOT] = ACTIONS(2561),
    [anon_sym_Not] = ACTIONS(2561),
    [anon_sym_POUNDelif] = ACTIONS(2563),
    [anon_sym_POUNDELIF] = ACTIONS(2563),
    [anon_sym_POUNDElif] = ACTIONS(2563),
    [anon_sym_POUNDelse] = ACTIONS(2563),
    [anon_sym_POUNDELSE] = ACTIONS(2563),
    [anon_sym_POUNDElse] = ACTIONS(2563),
    [anon_sym_POUNDendif] = ACTIONS(2563),
    [anon_sym_POUNDENDIF] = ACTIONS(2563),
    [anon_sym_POUNDEndif] = ACTIONS(2563),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2563),
    [aux_sym__expression_token1] = ACTIONS(2563),
    [aux_sym__expression_token2] = ACTIONS(2563),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2561),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2561),
    [anon_sym_SLASH] = ACTIONS(2561),
    [anon_sym_div] = ACTIONS(2561),
    [anon_sym_DIV] = ACTIONS(2561),
    [anon_sym_Div] = ACTIONS(2561),
    [anon_sym_mod] = ACTIONS(2561),
    [anon_sym_MOD] = ACTIONS(2561),
    [anon_sym_Mod] = ACTIONS(2561),
    [anon_sym_PLUS] = ACTIONS(2561),
    [anon_sym_GT_EQ] = ACTIONS(2563),
    [anon_sym_LT_EQ] = ACTIONS(2563),
    [anon_sym_GT] = ACTIONS(2561),
    [anon_sym_LT] = ACTIONS(2561),
    [anon_sym_LT_GT] = ACTIONS(2563),
    [anon_sym_and] = ACTIONS(2561),
    [anon_sym_AND] = ACTIONS(2561),
    [anon_sym_And] = ACTIONS(2561),
    [anon_sym_or] = ACTIONS(2561),
    [anon_sym_OR] = ACTIONS(2561),
    [anon_sym_Or] = ACTIONS(2561),
    [anon_sym_xor] = ACTIONS(2561),
    [anon_sym_XOR] = ACTIONS(2561),
    [anon_sym_Xor] = ACTIONS(2561),
    [anon_sym_QMARK] = ACTIONS(2563),
    [sym_datetime_literal] = ACTIONS(2563),
    [sym_date_literal] = ACTIONS(2561),
    [sym_time_literal] = ACTIONS(2561),
    [sym_biginteger_literal] = ACTIONS(2563),
    [anon_sym_else] = ACTIONS(2561),
    [anon_sym_ELSE] = ACTIONS(2561),
    [anon_sym_Else] = ACTIONS(2561),
    [anon_sym_in] = ACTIONS(2561),
    [anon_sym_IN] = ACTIONS(2561),
    [anon_sym_In] = ACTIONS(2561),
    [sym_page_keyword] = ACTIONS(2561),
    [anon_sym_codeunit] = ACTIONS(2561),
    [anon_sym_CODEUNIT] = ACTIONS(2561),
    [anon_sym_Codeunit] = ACTIONS(2561),
    [anon_sym_CodeUnit] = ACTIONS(2561),
    [anon_sym_COdeunit] = ACTIONS(2561),
    [anon_sym_codeUnit] = ACTIONS(2561),
    [sym_report_keyword] = ACTIONS(2561),
    [sym_query_keyword] = ACTIONS(2561),
    [anon_sym_xmlport] = ACTIONS(2561),
    [anon_sym_XMLPORT] = ACTIONS(2561),
    [anon_sym_Xmlport] = ACTIONS(2561),
    [anon_sym_XMLport] = ACTIONS(2561),
    [anon_sym_XMLPort] = ACTIONS(2561),
    [anon_sym_XmlPort] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_ENUM] = ACTIONS(2561),
    [anon_sym_Enum] = ACTIONS(2561),
    [anon_sym_eNUM] = ACTIONS(2561),
    [anon_sym_eNum] = ACTIONS(2561),
    [anon_sym_ENum] = ACTIONS(2561),
    [sym_quoted_identifier] = ACTIONS(2563),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2563),
    [sym_integer] = ACTIONS(2561),
    [sym_continue_as_identifier] = ACTIONS(2563),
    [sym_preproc_open] = ACTIONS(2563),
    [sym_preproc_close] = ACTIONS(2563),
  },
  [STATE(1446)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_SEMI] = ACTIONS(2428),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_COMMA] = ACTIONS(2428),
    [anon_sym_COLON] = ACTIONS(2426),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [anon_sym_COLON_COLON] = ACTIONS(3885),
    [anon_sym_POUNDif] = ACTIONS(2428),
    [anon_sym_POUNDIF] = ACTIONS(2428),
    [anon_sym_POUNDIf] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [anon_sym_POUNDelif] = ACTIONS(2428),
    [anon_sym_POUNDELIF] = ACTIONS(2428),
    [anon_sym_POUNDElif] = ACTIONS(2428),
    [anon_sym_POUNDelse] = ACTIONS(2428),
    [anon_sym_POUNDELSE] = ACTIONS(2428),
    [anon_sym_POUNDElse] = ACTIONS(2428),
    [anon_sym_POUNDendif] = ACTIONS(2428),
    [anon_sym_POUNDENDIF] = ACTIONS(2428),
    [anon_sym_POUNDEndif] = ACTIONS(2428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2428),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_else] = ACTIONS(2426),
    [anon_sym_ELSE] = ACTIONS(2426),
    [anon_sym_Else] = ACTIONS(2426),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_open] = ACTIONS(2428),
    [sym_preproc_close] = ACTIONS(2428),
  },
  [STATE(1447)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1450),
    [sym_identifier] = ACTIONS(2354),
    [anon_sym_SEMI] = ACTIONS(2356),
    [anon_sym_DOT] = ACTIONS(2354),
    [anon_sym_EQ] = ACTIONS(2356),
    [anon_sym_COMMA] = ACTIONS(3881),
    [anon_sym_COLON] = ACTIONS(2354),
    [anon_sym_DASH] = ACTIONS(2354),
    [aux_sym_boolean_token1] = ACTIONS(2354),
    [aux_sym_boolean_token2] = ACTIONS(2354),
    [sym_decimal] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(2356),
    [anon_sym_DOT_DOT] = ACTIONS(2356),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2354),
    [anon_sym_STAR] = ACTIONS(2354),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [aux_sym_record_type_token1] = ACTIONS(2354),
    [aux_sym_basic_type_token21] = ACTIONS(2354),
    [aux_sym_basic_type_token22] = ACTIONS(2354),
    [aux_sym_basic_type_token48] = ACTIONS(2354),
    [anon_sym_POUNDif] = ACTIONS(2356),
    [anon_sym_POUNDIF] = ACTIONS(2356),
    [anon_sym_POUNDIf] = ACTIONS(2356),
    [anon_sym_not] = ACTIONS(2354),
    [anon_sym_NOT] = ACTIONS(2354),
    [anon_sym_Not] = ACTIONS(2354),
    [anon_sym_POUNDelif] = ACTIONS(2356),
    [anon_sym_POUNDELIF] = ACTIONS(2356),
    [anon_sym_POUNDElif] = ACTIONS(2356),
    [anon_sym_POUNDelse] = ACTIONS(2356),
    [anon_sym_POUNDELSE] = ACTIONS(2356),
    [anon_sym_POUNDElse] = ACTIONS(2356),
    [anon_sym_POUNDendif] = ACTIONS(2356),
    [anon_sym_POUNDENDIF] = ACTIONS(2356),
    [anon_sym_POUNDEndif] = ACTIONS(2356),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2356),
    [aux_sym__expression_token1] = ACTIONS(2356),
    [aux_sym__expression_token2] = ACTIONS(2356),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2354),
    [anon_sym_SLASH] = ACTIONS(2354),
    [anon_sym_div] = ACTIONS(2354),
    [anon_sym_DIV] = ACTIONS(2354),
    [anon_sym_Div] = ACTIONS(2354),
    [anon_sym_mod] = ACTIONS(2354),
    [anon_sym_MOD] = ACTIONS(2354),
    [anon_sym_Mod] = ACTIONS(2354),
    [anon_sym_PLUS] = ACTIONS(2354),
    [anon_sym_GT_EQ] = ACTIONS(2356),
    [anon_sym_LT_EQ] = ACTIONS(2356),
    [anon_sym_GT] = ACTIONS(2354),
    [anon_sym_LT] = ACTIONS(2354),
    [anon_sym_LT_GT] = ACTIONS(2356),
    [anon_sym_and] = ACTIONS(2354),
    [anon_sym_AND] = ACTIONS(2354),
    [anon_sym_And] = ACTIONS(2354),
    [anon_sym_or] = ACTIONS(2354),
    [anon_sym_OR] = ACTIONS(2354),
    [anon_sym_Or] = ACTIONS(2354),
    [anon_sym_xor] = ACTIONS(2354),
    [anon_sym_XOR] = ACTIONS(2354),
    [anon_sym_Xor] = ACTIONS(2354),
    [anon_sym_QMARK] = ACTIONS(2356),
    [sym_datetime_literal] = ACTIONS(2356),
    [sym_date_literal] = ACTIONS(2354),
    [sym_time_literal] = ACTIONS(2354),
    [sym_biginteger_literal] = ACTIONS(2356),
    [anon_sym_else] = ACTIONS(2354),
    [anon_sym_ELSE] = ACTIONS(2354),
    [anon_sym_Else] = ACTIONS(2354),
    [anon_sym_in] = ACTIONS(2354),
    [anon_sym_IN] = ACTIONS(2354),
    [anon_sym_In] = ACTIONS(2354),
    [sym_page_keyword] = ACTIONS(2354),
    [anon_sym_codeunit] = ACTIONS(2354),
    [anon_sym_CODEUNIT] = ACTIONS(2354),
    [anon_sym_Codeunit] = ACTIONS(2354),
    [anon_sym_CodeUnit] = ACTIONS(2354),
    [anon_sym_COdeunit] = ACTIONS(2354),
    [anon_sym_codeUnit] = ACTIONS(2354),
    [sym_report_keyword] = ACTIONS(2354),
    [sym_query_keyword] = ACTIONS(2354),
    [anon_sym_xmlport] = ACTIONS(2354),
    [anon_sym_XMLPORT] = ACTIONS(2354),
    [anon_sym_Xmlport] = ACTIONS(2354),
    [anon_sym_XMLport] = ACTIONS(2354),
    [anon_sym_XMLPort] = ACTIONS(2354),
    [anon_sym_XmlPort] = ACTIONS(2354),
    [anon_sym_enum] = ACTIONS(2354),
    [anon_sym_ENUM] = ACTIONS(2354),
    [anon_sym_Enum] = ACTIONS(2354),
    [anon_sym_eNUM] = ACTIONS(2354),
    [anon_sym_eNum] = ACTIONS(2354),
    [anon_sym_ENum] = ACTIONS(2354),
    [sym_quoted_identifier] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2356),
    [sym_integer] = ACTIONS(2354),
    [sym_continue_as_identifier] = ACTIONS(2356),
    [sym_preproc_open] = ACTIONS(2356),
    [sym_preproc_close] = ACTIONS(2356),
  },
  [STATE(1448)] = {
    [sym_identifier] = ACTIONS(2521),
    [anon_sym_SEMI] = ACTIONS(2523),
    [anon_sym_DOT] = ACTIONS(2521),
    [anon_sym_EQ] = ACTIONS(2523),
    [anon_sym_COMMA] = ACTIONS(2523),
    [anon_sym_COLON] = ACTIONS(2521),
    [anon_sym_DASH] = ACTIONS(2521),
    [aux_sym_boolean_token1] = ACTIONS(2521),
    [aux_sym_boolean_token2] = ACTIONS(2521),
    [sym_decimal] = ACTIONS(2521),
    [anon_sym_LPAREN] = ACTIONS(2523),
    [anon_sym_DOT_DOT] = ACTIONS(2523),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2521),
    [anon_sym_STAR] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [aux_sym_record_type_token1] = ACTIONS(2521),
    [aux_sym_basic_type_token21] = ACTIONS(2521),
    [aux_sym_basic_type_token22] = ACTIONS(2521),
    [aux_sym_basic_type_token48] = ACTIONS(2521),
    [anon_sym_COLON_COLON] = ACTIONS(2523),
    [anon_sym_POUNDif] = ACTIONS(2523),
    [anon_sym_POUNDIF] = ACTIONS(2523),
    [anon_sym_POUNDIf] = ACTIONS(2523),
    [anon_sym_not] = ACTIONS(2521),
    [anon_sym_NOT] = ACTIONS(2521),
    [anon_sym_Not] = ACTIONS(2521),
    [anon_sym_POUNDelif] = ACTIONS(2523),
    [anon_sym_POUNDELIF] = ACTIONS(2523),
    [anon_sym_POUNDElif] = ACTIONS(2523),
    [anon_sym_POUNDelse] = ACTIONS(2523),
    [anon_sym_POUNDELSE] = ACTIONS(2523),
    [anon_sym_POUNDElse] = ACTIONS(2523),
    [anon_sym_POUNDendif] = ACTIONS(2523),
    [anon_sym_POUNDENDIF] = ACTIONS(2523),
    [anon_sym_POUNDEndif] = ACTIONS(2523),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2523),
    [aux_sym__expression_token1] = ACTIONS(2523),
    [aux_sym__expression_token2] = ACTIONS(2523),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2521),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2521),
    [anon_sym_SLASH] = ACTIONS(2521),
    [anon_sym_div] = ACTIONS(2521),
    [anon_sym_DIV] = ACTIONS(2521),
    [anon_sym_Div] = ACTIONS(2521),
    [anon_sym_mod] = ACTIONS(2521),
    [anon_sym_MOD] = ACTIONS(2521),
    [anon_sym_Mod] = ACTIONS(2521),
    [anon_sym_PLUS] = ACTIONS(2521),
    [anon_sym_GT_EQ] = ACTIONS(2523),
    [anon_sym_LT_EQ] = ACTIONS(2523),
    [anon_sym_GT] = ACTIONS(2521),
    [anon_sym_LT] = ACTIONS(2521),
    [anon_sym_LT_GT] = ACTIONS(2523),
    [anon_sym_and] = ACTIONS(2521),
    [anon_sym_AND] = ACTIONS(2521),
    [anon_sym_And] = ACTIONS(2521),
    [anon_sym_or] = ACTIONS(2521),
    [anon_sym_OR] = ACTIONS(2521),
    [anon_sym_Or] = ACTIONS(2521),
    [anon_sym_xor] = ACTIONS(2521),
    [anon_sym_XOR] = ACTIONS(2521),
    [anon_sym_Xor] = ACTIONS(2521),
    [anon_sym_QMARK] = ACTIONS(2523),
    [sym_datetime_literal] = ACTIONS(2523),
    [sym_date_literal] = ACTIONS(2521),
    [sym_time_literal] = ACTIONS(2521),
    [sym_biginteger_literal] = ACTIONS(2523),
    [anon_sym_else] = ACTIONS(2521),
    [anon_sym_ELSE] = ACTIONS(2521),
    [anon_sym_Else] = ACTIONS(2521),
    [anon_sym_in] = ACTIONS(2521),
    [anon_sym_IN] = ACTIONS(2521),
    [anon_sym_In] = ACTIONS(2521),
    [sym_page_keyword] = ACTIONS(2521),
    [anon_sym_codeunit] = ACTIONS(2521),
    [anon_sym_CODEUNIT] = ACTIONS(2521),
    [anon_sym_Codeunit] = ACTIONS(2521),
    [anon_sym_CodeUnit] = ACTIONS(2521),
    [anon_sym_COdeunit] = ACTIONS(2521),
    [anon_sym_codeUnit] = ACTIONS(2521),
    [sym_report_keyword] = ACTIONS(2521),
    [sym_query_keyword] = ACTIONS(2521),
    [anon_sym_xmlport] = ACTIONS(2521),
    [anon_sym_XMLPORT] = ACTIONS(2521),
    [anon_sym_Xmlport] = ACTIONS(2521),
    [anon_sym_XMLport] = ACTIONS(2521),
    [anon_sym_XMLPort] = ACTIONS(2521),
    [anon_sym_XmlPort] = ACTIONS(2521),
    [anon_sym_enum] = ACTIONS(2521),
    [anon_sym_ENUM] = ACTIONS(2521),
    [anon_sym_Enum] = ACTIONS(2521),
    [anon_sym_eNUM] = ACTIONS(2521),
    [anon_sym_eNum] = ACTIONS(2521),
    [anon_sym_ENum] = ACTIONS(2521),
    [sym_quoted_identifier] = ACTIONS(2523),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2523),
    [sym_integer] = ACTIONS(2521),
    [sym_continue_as_identifier] = ACTIONS(2523),
    [sym_preproc_open] = ACTIONS(2523),
    [sym_preproc_close] = ACTIONS(2523),
  },
  [STATE(1449)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1452),
    [sym_identifier] = ACTIONS(2354),
    [anon_sym_SEMI] = ACTIONS(2356),
    [anon_sym_DOT] = ACTIONS(2354),
    [anon_sym_EQ] = ACTIONS(2356),
    [anon_sym_COMMA] = ACTIONS(3881),
    [anon_sym_COLON] = ACTIONS(2354),
    [anon_sym_DASH] = ACTIONS(2354),
    [aux_sym_boolean_token1] = ACTIONS(2354),
    [aux_sym_boolean_token2] = ACTIONS(2354),
    [sym_decimal] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(2356),
    [anon_sym_DOT_DOT] = ACTIONS(2356),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2354),
    [anon_sym_STAR] = ACTIONS(2354),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [aux_sym_record_type_token1] = ACTIONS(2354),
    [aux_sym_basic_type_token21] = ACTIONS(2354),
    [aux_sym_basic_type_token22] = ACTIONS(2354),
    [aux_sym_basic_type_token48] = ACTIONS(2354),
    [anon_sym_POUNDif] = ACTIONS(2356),
    [anon_sym_POUNDIF] = ACTIONS(2356),
    [anon_sym_POUNDIf] = ACTIONS(2356),
    [anon_sym_not] = ACTIONS(2354),
    [anon_sym_NOT] = ACTIONS(2354),
    [anon_sym_Not] = ACTIONS(2354),
    [anon_sym_POUNDelif] = ACTIONS(2356),
    [anon_sym_POUNDELIF] = ACTIONS(2356),
    [anon_sym_POUNDElif] = ACTIONS(2356),
    [anon_sym_POUNDelse] = ACTIONS(2356),
    [anon_sym_POUNDELSE] = ACTIONS(2356),
    [anon_sym_POUNDElse] = ACTIONS(2356),
    [anon_sym_POUNDendif] = ACTIONS(2356),
    [anon_sym_POUNDENDIF] = ACTIONS(2356),
    [anon_sym_POUNDEndif] = ACTIONS(2356),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2356),
    [aux_sym__expression_token1] = ACTIONS(2356),
    [aux_sym__expression_token2] = ACTIONS(2356),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2354),
    [anon_sym_SLASH] = ACTIONS(2354),
    [anon_sym_div] = ACTIONS(2354),
    [anon_sym_DIV] = ACTIONS(2354),
    [anon_sym_Div] = ACTIONS(2354),
    [anon_sym_mod] = ACTIONS(2354),
    [anon_sym_MOD] = ACTIONS(2354),
    [anon_sym_Mod] = ACTIONS(2354),
    [anon_sym_PLUS] = ACTIONS(2354),
    [anon_sym_GT_EQ] = ACTIONS(2356),
    [anon_sym_LT_EQ] = ACTIONS(2356),
    [anon_sym_GT] = ACTIONS(2354),
    [anon_sym_LT] = ACTIONS(2354),
    [anon_sym_LT_GT] = ACTIONS(2356),
    [anon_sym_and] = ACTIONS(2354),
    [anon_sym_AND] = ACTIONS(2354),
    [anon_sym_And] = ACTIONS(2354),
    [anon_sym_or] = ACTIONS(2354),
    [anon_sym_OR] = ACTIONS(2354),
    [anon_sym_Or] = ACTIONS(2354),
    [anon_sym_xor] = ACTIONS(2354),
    [anon_sym_XOR] = ACTIONS(2354),
    [anon_sym_Xor] = ACTIONS(2354),
    [anon_sym_QMARK] = ACTIONS(2356),
    [sym_datetime_literal] = ACTIONS(2356),
    [sym_date_literal] = ACTIONS(2354),
    [sym_time_literal] = ACTIONS(2354),
    [sym_biginteger_literal] = ACTIONS(2356),
    [anon_sym_else] = ACTIONS(2354),
    [anon_sym_ELSE] = ACTIONS(2354),
    [anon_sym_Else] = ACTIONS(2354),
    [anon_sym_in] = ACTIONS(2354),
    [anon_sym_IN] = ACTIONS(2354),
    [anon_sym_In] = ACTIONS(2354),
    [sym_page_keyword] = ACTIONS(2354),
    [anon_sym_codeunit] = ACTIONS(2354),
    [anon_sym_CODEUNIT] = ACTIONS(2354),
    [anon_sym_Codeunit] = ACTIONS(2354),
    [anon_sym_CodeUnit] = ACTIONS(2354),
    [anon_sym_COdeunit] = ACTIONS(2354),
    [anon_sym_codeUnit] = ACTIONS(2354),
    [sym_report_keyword] = ACTIONS(2354),
    [sym_query_keyword] = ACTIONS(2354),
    [anon_sym_xmlport] = ACTIONS(2354),
    [anon_sym_XMLPORT] = ACTIONS(2354),
    [anon_sym_Xmlport] = ACTIONS(2354),
    [anon_sym_XMLport] = ACTIONS(2354),
    [anon_sym_XMLPort] = ACTIONS(2354),
    [anon_sym_XmlPort] = ACTIONS(2354),
    [anon_sym_enum] = ACTIONS(2354),
    [anon_sym_ENUM] = ACTIONS(2354),
    [anon_sym_Enum] = ACTIONS(2354),
    [anon_sym_eNUM] = ACTIONS(2354),
    [anon_sym_eNum] = ACTIONS(2354),
    [anon_sym_ENum] = ACTIONS(2354),
    [sym_quoted_identifier] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2356),
    [sym_integer] = ACTIONS(2354),
    [sym_continue_as_identifier] = ACTIONS(2356),
    [sym_preproc_open] = ACTIONS(2356),
    [sym_preproc_close] = ACTIONS(2356),
  },
  [STATE(1450)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1450),
    [sym_identifier] = ACTIONS(2403),
    [anon_sym_SEMI] = ACTIONS(2405),
    [anon_sym_DOT] = ACTIONS(2403),
    [anon_sym_EQ] = ACTIONS(2405),
    [anon_sym_COMMA] = ACTIONS(3887),
    [anon_sym_COLON] = ACTIONS(2403),
    [anon_sym_DASH] = ACTIONS(2403),
    [aux_sym_boolean_token1] = ACTIONS(2403),
    [aux_sym_boolean_token2] = ACTIONS(2403),
    [sym_decimal] = ACTIONS(2403),
    [anon_sym_LPAREN] = ACTIONS(2405),
    [anon_sym_DOT_DOT] = ACTIONS(2405),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2403),
    [anon_sym_STAR] = ACTIONS(2403),
    [anon_sym_LBRACK] = ACTIONS(2405),
    [aux_sym_record_type_token1] = ACTIONS(2403),
    [aux_sym_basic_type_token21] = ACTIONS(2403),
    [aux_sym_basic_type_token22] = ACTIONS(2403),
    [aux_sym_basic_type_token48] = ACTIONS(2403),
    [anon_sym_POUNDif] = ACTIONS(2405),
    [anon_sym_POUNDIF] = ACTIONS(2405),
    [anon_sym_POUNDIf] = ACTIONS(2405),
    [anon_sym_not] = ACTIONS(2403),
    [anon_sym_NOT] = ACTIONS(2403),
    [anon_sym_Not] = ACTIONS(2403),
    [anon_sym_POUNDelif] = ACTIONS(2405),
    [anon_sym_POUNDELIF] = ACTIONS(2405),
    [anon_sym_POUNDElif] = ACTIONS(2405),
    [anon_sym_POUNDelse] = ACTIONS(2405),
    [anon_sym_POUNDELSE] = ACTIONS(2405),
    [anon_sym_POUNDElse] = ACTIONS(2405),
    [anon_sym_POUNDendif] = ACTIONS(2405),
    [anon_sym_POUNDENDIF] = ACTIONS(2405),
    [anon_sym_POUNDEndif] = ACTIONS(2405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2405),
    [aux_sym__expression_token1] = ACTIONS(2405),
    [aux_sym__expression_token2] = ACTIONS(2405),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2403),
    [anon_sym_SLASH] = ACTIONS(2403),
    [anon_sym_div] = ACTIONS(2403),
    [anon_sym_DIV] = ACTIONS(2403),
    [anon_sym_Div] = ACTIONS(2403),
    [anon_sym_mod] = ACTIONS(2403),
    [anon_sym_MOD] = ACTIONS(2403),
    [anon_sym_Mod] = ACTIONS(2403),
    [anon_sym_PLUS] = ACTIONS(2403),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_LT_GT] = ACTIONS(2405),
    [anon_sym_and] = ACTIONS(2403),
    [anon_sym_AND] = ACTIONS(2403),
    [anon_sym_And] = ACTIONS(2403),
    [anon_sym_or] = ACTIONS(2403),
    [anon_sym_OR] = ACTIONS(2403),
    [anon_sym_Or] = ACTIONS(2403),
    [anon_sym_xor] = ACTIONS(2403),
    [anon_sym_XOR] = ACTIONS(2403),
    [anon_sym_Xor] = ACTIONS(2403),
    [anon_sym_QMARK] = ACTIONS(2405),
    [sym_datetime_literal] = ACTIONS(2405),
    [sym_date_literal] = ACTIONS(2403),
    [sym_time_literal] = ACTIONS(2403),
    [sym_biginteger_literal] = ACTIONS(2405),
    [anon_sym_else] = ACTIONS(2403),
    [anon_sym_ELSE] = ACTIONS(2403),
    [anon_sym_Else] = ACTIONS(2403),
    [anon_sym_in] = ACTIONS(2403),
    [anon_sym_IN] = ACTIONS(2403),
    [anon_sym_In] = ACTIONS(2403),
    [sym_page_keyword] = ACTIONS(2403),
    [anon_sym_codeunit] = ACTIONS(2403),
    [anon_sym_CODEUNIT] = ACTIONS(2403),
    [anon_sym_Codeunit] = ACTIONS(2403),
    [anon_sym_CodeUnit] = ACTIONS(2403),
    [anon_sym_COdeunit] = ACTIONS(2403),
    [anon_sym_codeUnit] = ACTIONS(2403),
    [sym_report_keyword] = ACTIONS(2403),
    [sym_query_keyword] = ACTIONS(2403),
    [anon_sym_xmlport] = ACTIONS(2403),
    [anon_sym_XMLPORT] = ACTIONS(2403),
    [anon_sym_Xmlport] = ACTIONS(2403),
    [anon_sym_XMLport] = ACTIONS(2403),
    [anon_sym_XMLPort] = ACTIONS(2403),
    [anon_sym_XmlPort] = ACTIONS(2403),
    [anon_sym_enum] = ACTIONS(2403),
    [anon_sym_ENUM] = ACTIONS(2403),
    [anon_sym_Enum] = ACTIONS(2403),
    [anon_sym_eNUM] = ACTIONS(2403),
    [anon_sym_eNum] = ACTIONS(2403),
    [anon_sym_ENum] = ACTIONS(2403),
    [sym_quoted_identifier] = ACTIONS(2405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2405),
    [sym_integer] = ACTIONS(2403),
    [sym_continue_as_identifier] = ACTIONS(2405),
    [sym_preproc_open] = ACTIONS(2405),
    [sym_preproc_close] = ACTIONS(2405),
  },
  [STATE(1451)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(3890),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1452)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1450),
    [sym_identifier] = ACTIONS(2410),
    [anon_sym_SEMI] = ACTIONS(2412),
    [anon_sym_DOT] = ACTIONS(2410),
    [anon_sym_EQ] = ACTIONS(2412),
    [anon_sym_COMMA] = ACTIONS(3881),
    [anon_sym_COLON] = ACTIONS(2410),
    [anon_sym_DASH] = ACTIONS(2410),
    [aux_sym_boolean_token1] = ACTIONS(2410),
    [aux_sym_boolean_token2] = ACTIONS(2410),
    [sym_decimal] = ACTIONS(2410),
    [anon_sym_LPAREN] = ACTIONS(2412),
    [anon_sym_DOT_DOT] = ACTIONS(2412),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2410),
    [anon_sym_STAR] = ACTIONS(2410),
    [anon_sym_LBRACK] = ACTIONS(2412),
    [aux_sym_record_type_token1] = ACTIONS(2410),
    [aux_sym_basic_type_token21] = ACTIONS(2410),
    [aux_sym_basic_type_token22] = ACTIONS(2410),
    [aux_sym_basic_type_token48] = ACTIONS(2410),
    [anon_sym_POUNDif] = ACTIONS(2412),
    [anon_sym_POUNDIF] = ACTIONS(2412),
    [anon_sym_POUNDIf] = ACTIONS(2412),
    [anon_sym_not] = ACTIONS(2410),
    [anon_sym_NOT] = ACTIONS(2410),
    [anon_sym_Not] = ACTIONS(2410),
    [anon_sym_POUNDelif] = ACTIONS(2412),
    [anon_sym_POUNDELIF] = ACTIONS(2412),
    [anon_sym_POUNDElif] = ACTIONS(2412),
    [anon_sym_POUNDelse] = ACTIONS(2412),
    [anon_sym_POUNDELSE] = ACTIONS(2412),
    [anon_sym_POUNDElse] = ACTIONS(2412),
    [anon_sym_POUNDendif] = ACTIONS(2412),
    [anon_sym_POUNDENDIF] = ACTIONS(2412),
    [anon_sym_POUNDEndif] = ACTIONS(2412),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2412),
    [aux_sym__expression_token1] = ACTIONS(2412),
    [aux_sym__expression_token2] = ACTIONS(2412),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2410),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2410),
    [anon_sym_SLASH] = ACTIONS(2410),
    [anon_sym_div] = ACTIONS(2410),
    [anon_sym_DIV] = ACTIONS(2410),
    [anon_sym_Div] = ACTIONS(2410),
    [anon_sym_mod] = ACTIONS(2410),
    [anon_sym_MOD] = ACTIONS(2410),
    [anon_sym_Mod] = ACTIONS(2410),
    [anon_sym_PLUS] = ACTIONS(2410),
    [anon_sym_GT_EQ] = ACTIONS(2412),
    [anon_sym_LT_EQ] = ACTIONS(2412),
    [anon_sym_GT] = ACTIONS(2410),
    [anon_sym_LT] = ACTIONS(2410),
    [anon_sym_LT_GT] = ACTIONS(2412),
    [anon_sym_and] = ACTIONS(2410),
    [anon_sym_AND] = ACTIONS(2410),
    [anon_sym_And] = ACTIONS(2410),
    [anon_sym_or] = ACTIONS(2410),
    [anon_sym_OR] = ACTIONS(2410),
    [anon_sym_Or] = ACTIONS(2410),
    [anon_sym_xor] = ACTIONS(2410),
    [anon_sym_XOR] = ACTIONS(2410),
    [anon_sym_Xor] = ACTIONS(2410),
    [anon_sym_QMARK] = ACTIONS(2412),
    [sym_datetime_literal] = ACTIONS(2412),
    [sym_date_literal] = ACTIONS(2410),
    [sym_time_literal] = ACTIONS(2410),
    [sym_biginteger_literal] = ACTIONS(2412),
    [anon_sym_else] = ACTIONS(2410),
    [anon_sym_ELSE] = ACTIONS(2410),
    [anon_sym_Else] = ACTIONS(2410),
    [anon_sym_in] = ACTIONS(2410),
    [anon_sym_IN] = ACTIONS(2410),
    [anon_sym_In] = ACTIONS(2410),
    [sym_page_keyword] = ACTIONS(2410),
    [anon_sym_codeunit] = ACTIONS(2410),
    [anon_sym_CODEUNIT] = ACTIONS(2410),
    [anon_sym_Codeunit] = ACTIONS(2410),
    [anon_sym_CodeUnit] = ACTIONS(2410),
    [anon_sym_COdeunit] = ACTIONS(2410),
    [anon_sym_codeUnit] = ACTIONS(2410),
    [sym_report_keyword] = ACTIONS(2410),
    [sym_query_keyword] = ACTIONS(2410),
    [anon_sym_xmlport] = ACTIONS(2410),
    [anon_sym_XMLPORT] = ACTIONS(2410),
    [anon_sym_Xmlport] = ACTIONS(2410),
    [anon_sym_XMLport] = ACTIONS(2410),
    [anon_sym_XMLPort] = ACTIONS(2410),
    [anon_sym_XmlPort] = ACTIONS(2410),
    [anon_sym_enum] = ACTIONS(2410),
    [anon_sym_ENUM] = ACTIONS(2410),
    [anon_sym_Enum] = ACTIONS(2410),
    [anon_sym_eNUM] = ACTIONS(2410),
    [anon_sym_eNum] = ACTIONS(2410),
    [anon_sym_ENum] = ACTIONS(2410),
    [sym_quoted_identifier] = ACTIONS(2412),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2412),
    [sym_integer] = ACTIONS(2410),
    [sym_continue_as_identifier] = ACTIONS(2412),
    [sym_preproc_open] = ACTIONS(2412),
    [sym_preproc_close] = ACTIONS(2412),
  },
  [STATE(1453)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3892),
    [anon_sym_RBRACE] = ACTIONS(3895),
    [aux_sym_where_condition_token1] = ACTIONS(3897),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3900),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3903),
    [anon_sym_LBRACK] = ACTIONS(3906),
    [aux_sym_basic_type_token6] = ACTIONS(3909),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3912),
    [aux_sym_addafter_modification_token1] = ACTIONS(3915),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3918),
    [aux_sym_modify_modification_token1] = ACTIONS(3921),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3924),
    [aux_sym_movelast_modification_token1] = ACTIONS(3927),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3930),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3933),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3936),
    [anon_sym_POUNDif] = ACTIONS(3939),
    [anon_sym_POUNDIF] = ACTIONS(3939),
    [anon_sym_POUNDIf] = ACTIONS(3939),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3942),
    [sym_trigger_keyword] = ACTIONS(3945),
    [sym_var_keyword] = ACTIONS(3948),
    [sym_local_keyword] = ACTIONS(3951),
    [sym_internal_keyword] = ACTIONS(3954),
    [sym_protected_keyword] = ACTIONS(3951),
    [sym_event_keyword] = ACTIONS(3957),
    [sym_fields_keyword] = ACTIONS(3960),
    [sym_keys_keyword] = ACTIONS(3963),
    [sym_fieldgroups_keyword] = ACTIONS(3966),
    [sym_actions_keyword] = ACTIONS(3969),
    [sym_layout_keyword] = ACTIONS(3972),
    [sym_area_keyword] = ACTIONS(3975),
    [sym_group_keyword] = ACTIONS(3978),
    [sym_repeater_keyword] = ACTIONS(3981),
    [sym_cuegroup_keyword] = ACTIONS(3984),
    [sym_fixed_keyword] = ACTIONS(3987),
    [sym_grid_keyword] = ACTIONS(3990),
    [sym_part_keyword] = ACTIONS(3993),
    [sym_systempart_keyword] = ACTIONS(3996),
    [sym_usercontrol_keyword] = ACTIONS(3999),
    [sym_dataset_keyword] = ACTIONS(4002),
    [sym_elements_keyword] = ACTIONS(4005),
    [sym_labels_keyword] = ACTIONS(4008),
    [sym_rendering_keyword] = ACTIONS(4011),
    [sym_requestpage_keyword] = ACTIONS(4014),
    [sym_schema_keyword] = ACTIONS(4017),
    [sym_views_keyword] = ACTIONS(4020),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4023),
    [sym_preproc_open] = ACTIONS(3939),
  },
  [STATE(1454)] = {
    [sym__body_element] = STATE(1459),
    [sym_empty_statement] = STATE(1459),
    [sym_property] = STATE(1459),
    [sym_fields_section] = STATE(1459),
    [sym_keys_section] = STATE(1459),
    [sym_fieldgroups_section] = STATE(1459),
    [sym_enum_value_declaration] = STATE(1459),
    [sym_labels_section] = STATE(1459),
    [sym_layout_section] = STATE(1459),
    [sym__layout_element] = STATE(1459),
    [sym_area_section] = STATE(1459),
    [sym_group_section] = STATE(1459),
    [sym_repeater_section] = STATE(1459),
    [sym_cuegroup_section] = STATE(1459),
    [sym_fixed_section] = STATE(1459),
    [sym_grid_section] = STATE(1459),
    [sym_page_field] = STATE(1459),
    [sym_part_section] = STATE(1459),
    [sym_systempart_section] = STATE(1459),
    [sym_usercontrol_section] = STATE(1459),
    [sym_preproc_split_field] = STATE(1459),
    [sym_label_section] = STATE(1459),
    [sym_addfirst_modification] = STATE(1459),
    [sym_addlast_modification] = STATE(1459),
    [sym_addafter_modification] = STATE(1459),
    [sym_addbefore_modification] = STATE(1459),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1459),
    [sym_movelast_modification] = STATE(1459),
    [sym_moveafter_modification] = STATE(1459),
    [sym_movebefore_modification] = STATE(1459),
    [sym_actions_section] = STATE(1459),
    [sym_views_section] = STATE(1459),
    [sym_dataset_section] = STATE(1459),
    [sym_requestpage_section] = STATE(1459),
    [sym_rendering_section] = STATE(1459),
    [sym_elements_section] = STATE(1459),
    [sym_schema_section] = STATE(1459),
    [sym_assembly_declaration] = STATE(1459),
    [sym_event_declaration] = STATE(1459),
    [sym_procedure] = STATE(1459),
    [sym_preproc_split_procedure] = STATE(1459),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1459),
    [sym_var_section] = STATE(1459),
    [sym_attribute_item] = STATE(1459),
    [sym_preproc_conditional] = STATE(1459),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1459),
    [sym_preproc_conditional_layout_mixed] = STATE(1459),
    [aux_sym_group_section_repeat1] = STATE(1459),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4026),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1455)] = {
    [sym__body_element] = STATE(1460),
    [sym_empty_statement] = STATE(1460),
    [sym_property] = STATE(1460),
    [sym_fields_section] = STATE(1460),
    [sym_keys_section] = STATE(1460),
    [sym_fieldgroups_section] = STATE(1460),
    [sym_enum_value_declaration] = STATE(1460),
    [sym_labels_section] = STATE(1460),
    [sym_layout_section] = STATE(1460),
    [sym__layout_element] = STATE(1460),
    [sym_area_section] = STATE(1460),
    [sym_group_section] = STATE(1460),
    [sym_repeater_section] = STATE(1460),
    [sym_cuegroup_section] = STATE(1460),
    [sym_fixed_section] = STATE(1460),
    [sym_grid_section] = STATE(1460),
    [sym_page_field] = STATE(1460),
    [sym_part_section] = STATE(1460),
    [sym_systempart_section] = STATE(1460),
    [sym_usercontrol_section] = STATE(1460),
    [sym_preproc_split_field] = STATE(1460),
    [sym_label_section] = STATE(1460),
    [sym_addfirst_modification] = STATE(1460),
    [sym_addlast_modification] = STATE(1460),
    [sym_addafter_modification] = STATE(1460),
    [sym_addbefore_modification] = STATE(1460),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1460),
    [sym_movelast_modification] = STATE(1460),
    [sym_moveafter_modification] = STATE(1460),
    [sym_movebefore_modification] = STATE(1460),
    [sym_actions_section] = STATE(1460),
    [sym_views_section] = STATE(1460),
    [sym_dataset_section] = STATE(1460),
    [sym_requestpage_section] = STATE(1460),
    [sym_rendering_section] = STATE(1460),
    [sym_elements_section] = STATE(1460),
    [sym_schema_section] = STATE(1460),
    [sym_assembly_declaration] = STATE(1460),
    [sym_event_declaration] = STATE(1460),
    [sym_procedure] = STATE(1460),
    [sym_preproc_split_procedure] = STATE(1460),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1460),
    [sym_var_section] = STATE(1460),
    [sym_attribute_item] = STATE(1460),
    [sym_preproc_conditional] = STATE(1460),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1460),
    [sym_preproc_conditional_layout_mixed] = STATE(1460),
    [aux_sym_group_section_repeat1] = STATE(1460),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4028),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1456)] = {
    [sym__body_element] = STATE(1461),
    [sym_empty_statement] = STATE(1461),
    [sym_property] = STATE(1461),
    [sym_fields_section] = STATE(1461),
    [sym_keys_section] = STATE(1461),
    [sym_fieldgroups_section] = STATE(1461),
    [sym_enum_value_declaration] = STATE(1461),
    [sym_labels_section] = STATE(1461),
    [sym_layout_section] = STATE(1461),
    [sym__layout_element] = STATE(1461),
    [sym_area_section] = STATE(1461),
    [sym_group_section] = STATE(1461),
    [sym_repeater_section] = STATE(1461),
    [sym_cuegroup_section] = STATE(1461),
    [sym_fixed_section] = STATE(1461),
    [sym_grid_section] = STATE(1461),
    [sym_page_field] = STATE(1461),
    [sym_part_section] = STATE(1461),
    [sym_systempart_section] = STATE(1461),
    [sym_usercontrol_section] = STATE(1461),
    [sym_preproc_split_field] = STATE(1461),
    [sym_label_section] = STATE(1461),
    [sym_addfirst_modification] = STATE(1461),
    [sym_addlast_modification] = STATE(1461),
    [sym_addafter_modification] = STATE(1461),
    [sym_addbefore_modification] = STATE(1461),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1461),
    [sym_movelast_modification] = STATE(1461),
    [sym_moveafter_modification] = STATE(1461),
    [sym_movebefore_modification] = STATE(1461),
    [sym_actions_section] = STATE(1461),
    [sym_views_section] = STATE(1461),
    [sym_dataset_section] = STATE(1461),
    [sym_requestpage_section] = STATE(1461),
    [sym_rendering_section] = STATE(1461),
    [sym_elements_section] = STATE(1461),
    [sym_schema_section] = STATE(1461),
    [sym_assembly_declaration] = STATE(1461),
    [sym_event_declaration] = STATE(1461),
    [sym_procedure] = STATE(1461),
    [sym_preproc_split_procedure] = STATE(1461),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1461),
    [sym_var_section] = STATE(1461),
    [sym_attribute_item] = STATE(1461),
    [sym_preproc_conditional] = STATE(1461),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1461),
    [sym_preproc_conditional_layout_mixed] = STATE(1461),
    [aux_sym_group_section_repeat1] = STATE(1461),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4030),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1457)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4032),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1458)] = {
    [sym__body_element] = STATE(1463),
    [sym_empty_statement] = STATE(1463),
    [sym_property] = STATE(1463),
    [sym_fields_section] = STATE(1463),
    [sym_keys_section] = STATE(1463),
    [sym_fieldgroups_section] = STATE(1463),
    [sym_enum_value_declaration] = STATE(1463),
    [sym_labels_section] = STATE(1463),
    [sym_layout_section] = STATE(1463),
    [sym__layout_element] = STATE(1463),
    [sym_area_section] = STATE(1463),
    [sym_group_section] = STATE(1463),
    [sym_repeater_section] = STATE(1463),
    [sym_cuegroup_section] = STATE(1463),
    [sym_fixed_section] = STATE(1463),
    [sym_grid_section] = STATE(1463),
    [sym_page_field] = STATE(1463),
    [sym_part_section] = STATE(1463),
    [sym_systempart_section] = STATE(1463),
    [sym_usercontrol_section] = STATE(1463),
    [sym_preproc_split_field] = STATE(1463),
    [sym_label_section] = STATE(1463),
    [sym_addfirst_modification] = STATE(1463),
    [sym_addlast_modification] = STATE(1463),
    [sym_addafter_modification] = STATE(1463),
    [sym_addbefore_modification] = STATE(1463),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1463),
    [sym_movelast_modification] = STATE(1463),
    [sym_moveafter_modification] = STATE(1463),
    [sym_movebefore_modification] = STATE(1463),
    [sym_actions_section] = STATE(1463),
    [sym_views_section] = STATE(1463),
    [sym_dataset_section] = STATE(1463),
    [sym_requestpage_section] = STATE(1463),
    [sym_rendering_section] = STATE(1463),
    [sym_elements_section] = STATE(1463),
    [sym_schema_section] = STATE(1463),
    [sym_assembly_declaration] = STATE(1463),
    [sym_event_declaration] = STATE(1463),
    [sym_procedure] = STATE(1463),
    [sym_preproc_split_procedure] = STATE(1463),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1463),
    [sym_var_section] = STATE(1463),
    [sym_attribute_item] = STATE(1463),
    [sym_preproc_conditional] = STATE(1463),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1463),
    [sym_preproc_conditional_layout_mixed] = STATE(1463),
    [aux_sym_group_section_repeat1] = STATE(1463),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4034),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1459)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4036),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1460)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4038),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1461)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4040),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1462)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4042),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1463)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4044),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1464)] = {
    [sym__body_element] = STATE(1469),
    [sym_empty_statement] = STATE(1469),
    [sym_property] = STATE(1469),
    [sym_fields_section] = STATE(1469),
    [sym_keys_section] = STATE(1469),
    [sym_fieldgroups_section] = STATE(1469),
    [sym_enum_value_declaration] = STATE(1469),
    [sym_labels_section] = STATE(1469),
    [sym_layout_section] = STATE(1469),
    [sym__layout_element] = STATE(1469),
    [sym_area_section] = STATE(1469),
    [sym_group_section] = STATE(1469),
    [sym_repeater_section] = STATE(1469),
    [sym_cuegroup_section] = STATE(1469),
    [sym_fixed_section] = STATE(1469),
    [sym_grid_section] = STATE(1469),
    [sym_page_field] = STATE(1469),
    [sym_part_section] = STATE(1469),
    [sym_systempart_section] = STATE(1469),
    [sym_usercontrol_section] = STATE(1469),
    [sym_preproc_split_field] = STATE(1469),
    [sym_label_section] = STATE(1469),
    [sym_addfirst_modification] = STATE(1469),
    [sym_addlast_modification] = STATE(1469),
    [sym_addafter_modification] = STATE(1469),
    [sym_addbefore_modification] = STATE(1469),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1469),
    [sym_movelast_modification] = STATE(1469),
    [sym_moveafter_modification] = STATE(1469),
    [sym_movebefore_modification] = STATE(1469),
    [sym_actions_section] = STATE(1469),
    [sym_views_section] = STATE(1469),
    [sym_dataset_section] = STATE(1469),
    [sym_requestpage_section] = STATE(1469),
    [sym_rendering_section] = STATE(1469),
    [sym_elements_section] = STATE(1469),
    [sym_schema_section] = STATE(1469),
    [sym_assembly_declaration] = STATE(1469),
    [sym_event_declaration] = STATE(1469),
    [sym_procedure] = STATE(1469),
    [sym_preproc_split_procedure] = STATE(1469),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1469),
    [sym_var_section] = STATE(1469),
    [sym_attribute_item] = STATE(1469),
    [sym_preproc_conditional] = STATE(1469),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1469),
    [sym_preproc_conditional_layout_mixed] = STATE(1469),
    [aux_sym_group_section_repeat1] = STATE(1469),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4046),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1465)] = {
    [sym__body_element] = STATE(1470),
    [sym_empty_statement] = STATE(1470),
    [sym_property] = STATE(1470),
    [sym_fields_section] = STATE(1470),
    [sym_keys_section] = STATE(1470),
    [sym_fieldgroups_section] = STATE(1470),
    [sym_enum_value_declaration] = STATE(1470),
    [sym_labels_section] = STATE(1470),
    [sym_layout_section] = STATE(1470),
    [sym__layout_element] = STATE(1470),
    [sym_area_section] = STATE(1470),
    [sym_group_section] = STATE(1470),
    [sym_repeater_section] = STATE(1470),
    [sym_cuegroup_section] = STATE(1470),
    [sym_fixed_section] = STATE(1470),
    [sym_grid_section] = STATE(1470),
    [sym_page_field] = STATE(1470),
    [sym_part_section] = STATE(1470),
    [sym_systempart_section] = STATE(1470),
    [sym_usercontrol_section] = STATE(1470),
    [sym_preproc_split_field] = STATE(1470),
    [sym_label_section] = STATE(1470),
    [sym_addfirst_modification] = STATE(1470),
    [sym_addlast_modification] = STATE(1470),
    [sym_addafter_modification] = STATE(1470),
    [sym_addbefore_modification] = STATE(1470),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1470),
    [sym_movelast_modification] = STATE(1470),
    [sym_moveafter_modification] = STATE(1470),
    [sym_movebefore_modification] = STATE(1470),
    [sym_actions_section] = STATE(1470),
    [sym_views_section] = STATE(1470),
    [sym_dataset_section] = STATE(1470),
    [sym_requestpage_section] = STATE(1470),
    [sym_rendering_section] = STATE(1470),
    [sym_elements_section] = STATE(1470),
    [sym_schema_section] = STATE(1470),
    [sym_assembly_declaration] = STATE(1470),
    [sym_event_declaration] = STATE(1470),
    [sym_procedure] = STATE(1470),
    [sym_preproc_split_procedure] = STATE(1470),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1470),
    [sym_var_section] = STATE(1470),
    [sym_attribute_item] = STATE(1470),
    [sym_preproc_conditional] = STATE(1470),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1470),
    [sym_preproc_conditional_layout_mixed] = STATE(1470),
    [aux_sym_group_section_repeat1] = STATE(1470),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4048),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1466)] = {
    [sym__body_element] = STATE(1471),
    [sym_empty_statement] = STATE(1471),
    [sym_property] = STATE(1471),
    [sym_fields_section] = STATE(1471),
    [sym_keys_section] = STATE(1471),
    [sym_fieldgroups_section] = STATE(1471),
    [sym_enum_value_declaration] = STATE(1471),
    [sym_labels_section] = STATE(1471),
    [sym_layout_section] = STATE(1471),
    [sym__layout_element] = STATE(1471),
    [sym_area_section] = STATE(1471),
    [sym_group_section] = STATE(1471),
    [sym_repeater_section] = STATE(1471),
    [sym_cuegroup_section] = STATE(1471),
    [sym_fixed_section] = STATE(1471),
    [sym_grid_section] = STATE(1471),
    [sym_page_field] = STATE(1471),
    [sym_part_section] = STATE(1471),
    [sym_systempart_section] = STATE(1471),
    [sym_usercontrol_section] = STATE(1471),
    [sym_preproc_split_field] = STATE(1471),
    [sym_label_section] = STATE(1471),
    [sym_addfirst_modification] = STATE(1471),
    [sym_addlast_modification] = STATE(1471),
    [sym_addafter_modification] = STATE(1471),
    [sym_addbefore_modification] = STATE(1471),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1471),
    [sym_movelast_modification] = STATE(1471),
    [sym_moveafter_modification] = STATE(1471),
    [sym_movebefore_modification] = STATE(1471),
    [sym_actions_section] = STATE(1471),
    [sym_views_section] = STATE(1471),
    [sym_dataset_section] = STATE(1471),
    [sym_requestpage_section] = STATE(1471),
    [sym_rendering_section] = STATE(1471),
    [sym_elements_section] = STATE(1471),
    [sym_schema_section] = STATE(1471),
    [sym_assembly_declaration] = STATE(1471),
    [sym_event_declaration] = STATE(1471),
    [sym_procedure] = STATE(1471),
    [sym_preproc_split_procedure] = STATE(1471),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1471),
    [sym_var_section] = STATE(1471),
    [sym_attribute_item] = STATE(1471),
    [sym_preproc_conditional] = STATE(1471),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1471),
    [sym_preproc_conditional_layout_mixed] = STATE(1471),
    [aux_sym_group_section_repeat1] = STATE(1471),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4050),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1467)] = {
    [sym__body_element] = STATE(1472),
    [sym_empty_statement] = STATE(1472),
    [sym_property] = STATE(1472),
    [sym_fields_section] = STATE(1472),
    [sym_keys_section] = STATE(1472),
    [sym_fieldgroups_section] = STATE(1472),
    [sym_enum_value_declaration] = STATE(1472),
    [sym_labels_section] = STATE(1472),
    [sym_layout_section] = STATE(1472),
    [sym__layout_element] = STATE(1472),
    [sym_area_section] = STATE(1472),
    [sym_group_section] = STATE(1472),
    [sym_repeater_section] = STATE(1472),
    [sym_cuegroup_section] = STATE(1472),
    [sym_fixed_section] = STATE(1472),
    [sym_grid_section] = STATE(1472),
    [sym_page_field] = STATE(1472),
    [sym_part_section] = STATE(1472),
    [sym_systempart_section] = STATE(1472),
    [sym_usercontrol_section] = STATE(1472),
    [sym_preproc_split_field] = STATE(1472),
    [sym_label_section] = STATE(1472),
    [sym_addfirst_modification] = STATE(1472),
    [sym_addlast_modification] = STATE(1472),
    [sym_addafter_modification] = STATE(1472),
    [sym_addbefore_modification] = STATE(1472),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1472),
    [sym_movelast_modification] = STATE(1472),
    [sym_moveafter_modification] = STATE(1472),
    [sym_movebefore_modification] = STATE(1472),
    [sym_actions_section] = STATE(1472),
    [sym_views_section] = STATE(1472),
    [sym_dataset_section] = STATE(1472),
    [sym_requestpage_section] = STATE(1472),
    [sym_rendering_section] = STATE(1472),
    [sym_elements_section] = STATE(1472),
    [sym_schema_section] = STATE(1472),
    [sym_assembly_declaration] = STATE(1472),
    [sym_event_declaration] = STATE(1472),
    [sym_procedure] = STATE(1472),
    [sym_preproc_split_procedure] = STATE(1472),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1472),
    [sym_var_section] = STATE(1472),
    [sym_attribute_item] = STATE(1472),
    [sym_preproc_conditional] = STATE(1472),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1472),
    [sym_preproc_conditional_layout_mixed] = STATE(1472),
    [aux_sym_group_section_repeat1] = STATE(1472),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4052),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1468)] = {
    [sym__body_element] = STATE(1473),
    [sym_empty_statement] = STATE(1473),
    [sym_property] = STATE(1473),
    [sym_fields_section] = STATE(1473),
    [sym_keys_section] = STATE(1473),
    [sym_fieldgroups_section] = STATE(1473),
    [sym_enum_value_declaration] = STATE(1473),
    [sym_labels_section] = STATE(1473),
    [sym_layout_section] = STATE(1473),
    [sym__layout_element] = STATE(1473),
    [sym_area_section] = STATE(1473),
    [sym_group_section] = STATE(1473),
    [sym_repeater_section] = STATE(1473),
    [sym_cuegroup_section] = STATE(1473),
    [sym_fixed_section] = STATE(1473),
    [sym_grid_section] = STATE(1473),
    [sym_page_field] = STATE(1473),
    [sym_part_section] = STATE(1473),
    [sym_systempart_section] = STATE(1473),
    [sym_usercontrol_section] = STATE(1473),
    [sym_preproc_split_field] = STATE(1473),
    [sym_label_section] = STATE(1473),
    [sym_addfirst_modification] = STATE(1473),
    [sym_addlast_modification] = STATE(1473),
    [sym_addafter_modification] = STATE(1473),
    [sym_addbefore_modification] = STATE(1473),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1473),
    [sym_movelast_modification] = STATE(1473),
    [sym_moveafter_modification] = STATE(1473),
    [sym_movebefore_modification] = STATE(1473),
    [sym_actions_section] = STATE(1473),
    [sym_views_section] = STATE(1473),
    [sym_dataset_section] = STATE(1473),
    [sym_requestpage_section] = STATE(1473),
    [sym_rendering_section] = STATE(1473),
    [sym_elements_section] = STATE(1473),
    [sym_schema_section] = STATE(1473),
    [sym_assembly_declaration] = STATE(1473),
    [sym_event_declaration] = STATE(1473),
    [sym_procedure] = STATE(1473),
    [sym_preproc_split_procedure] = STATE(1473),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1473),
    [sym_var_section] = STATE(1473),
    [sym_attribute_item] = STATE(1473),
    [sym_preproc_conditional] = STATE(1473),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1473),
    [sym_preproc_conditional_layout_mixed] = STATE(1473),
    [aux_sym_group_section_repeat1] = STATE(1473),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4054),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1469)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4056),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1470)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4058),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1471)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4060),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1472)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4062),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1473)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4064),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1474)] = {
    [sym__body_element] = STATE(1479),
    [sym_empty_statement] = STATE(1479),
    [sym_property] = STATE(1479),
    [sym_fields_section] = STATE(1479),
    [sym_keys_section] = STATE(1479),
    [sym_fieldgroups_section] = STATE(1479),
    [sym_enum_value_declaration] = STATE(1479),
    [sym_labels_section] = STATE(1479),
    [sym_layout_section] = STATE(1479),
    [sym__layout_element] = STATE(1479),
    [sym_area_section] = STATE(1479),
    [sym_group_section] = STATE(1479),
    [sym_repeater_section] = STATE(1479),
    [sym_cuegroup_section] = STATE(1479),
    [sym_fixed_section] = STATE(1479),
    [sym_grid_section] = STATE(1479),
    [sym_page_field] = STATE(1479),
    [sym_part_section] = STATE(1479),
    [sym_systempart_section] = STATE(1479),
    [sym_usercontrol_section] = STATE(1479),
    [sym_preproc_split_field] = STATE(1479),
    [sym_label_section] = STATE(1479),
    [sym_addfirst_modification] = STATE(1479),
    [sym_addlast_modification] = STATE(1479),
    [sym_addafter_modification] = STATE(1479),
    [sym_addbefore_modification] = STATE(1479),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1479),
    [sym_movelast_modification] = STATE(1479),
    [sym_moveafter_modification] = STATE(1479),
    [sym_movebefore_modification] = STATE(1479),
    [sym_actions_section] = STATE(1479),
    [sym_views_section] = STATE(1479),
    [sym_dataset_section] = STATE(1479),
    [sym_requestpage_section] = STATE(1479),
    [sym_rendering_section] = STATE(1479),
    [sym_elements_section] = STATE(1479),
    [sym_schema_section] = STATE(1479),
    [sym_assembly_declaration] = STATE(1479),
    [sym_event_declaration] = STATE(1479),
    [sym_procedure] = STATE(1479),
    [sym_preproc_split_procedure] = STATE(1479),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1479),
    [sym_var_section] = STATE(1479),
    [sym_attribute_item] = STATE(1479),
    [sym_preproc_conditional] = STATE(1479),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1479),
    [sym_preproc_conditional_layout_mixed] = STATE(1479),
    [aux_sym_group_section_repeat1] = STATE(1479),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4066),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1475)] = {
    [sym__body_element] = STATE(1480),
    [sym_empty_statement] = STATE(1480),
    [sym_property] = STATE(1480),
    [sym_fields_section] = STATE(1480),
    [sym_keys_section] = STATE(1480),
    [sym_fieldgroups_section] = STATE(1480),
    [sym_enum_value_declaration] = STATE(1480),
    [sym_labels_section] = STATE(1480),
    [sym_layout_section] = STATE(1480),
    [sym__layout_element] = STATE(1480),
    [sym_area_section] = STATE(1480),
    [sym_group_section] = STATE(1480),
    [sym_repeater_section] = STATE(1480),
    [sym_cuegroup_section] = STATE(1480),
    [sym_fixed_section] = STATE(1480),
    [sym_grid_section] = STATE(1480),
    [sym_page_field] = STATE(1480),
    [sym_part_section] = STATE(1480),
    [sym_systempart_section] = STATE(1480),
    [sym_usercontrol_section] = STATE(1480),
    [sym_preproc_split_field] = STATE(1480),
    [sym_label_section] = STATE(1480),
    [sym_addfirst_modification] = STATE(1480),
    [sym_addlast_modification] = STATE(1480),
    [sym_addafter_modification] = STATE(1480),
    [sym_addbefore_modification] = STATE(1480),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1480),
    [sym_movelast_modification] = STATE(1480),
    [sym_moveafter_modification] = STATE(1480),
    [sym_movebefore_modification] = STATE(1480),
    [sym_actions_section] = STATE(1480),
    [sym_views_section] = STATE(1480),
    [sym_dataset_section] = STATE(1480),
    [sym_requestpage_section] = STATE(1480),
    [sym_rendering_section] = STATE(1480),
    [sym_elements_section] = STATE(1480),
    [sym_schema_section] = STATE(1480),
    [sym_assembly_declaration] = STATE(1480),
    [sym_event_declaration] = STATE(1480),
    [sym_procedure] = STATE(1480),
    [sym_preproc_split_procedure] = STATE(1480),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1480),
    [sym_var_section] = STATE(1480),
    [sym_attribute_item] = STATE(1480),
    [sym_preproc_conditional] = STATE(1480),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1480),
    [sym_preproc_conditional_layout_mixed] = STATE(1480),
    [aux_sym_group_section_repeat1] = STATE(1480),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4068),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1476)] = {
    [sym__body_element] = STATE(1481),
    [sym_empty_statement] = STATE(1481),
    [sym_property] = STATE(1481),
    [sym_fields_section] = STATE(1481),
    [sym_keys_section] = STATE(1481),
    [sym_fieldgroups_section] = STATE(1481),
    [sym_enum_value_declaration] = STATE(1481),
    [sym_labels_section] = STATE(1481),
    [sym_layout_section] = STATE(1481),
    [sym__layout_element] = STATE(1481),
    [sym_area_section] = STATE(1481),
    [sym_group_section] = STATE(1481),
    [sym_repeater_section] = STATE(1481),
    [sym_cuegroup_section] = STATE(1481),
    [sym_fixed_section] = STATE(1481),
    [sym_grid_section] = STATE(1481),
    [sym_page_field] = STATE(1481),
    [sym_part_section] = STATE(1481),
    [sym_systempart_section] = STATE(1481),
    [sym_usercontrol_section] = STATE(1481),
    [sym_preproc_split_field] = STATE(1481),
    [sym_label_section] = STATE(1481),
    [sym_addfirst_modification] = STATE(1481),
    [sym_addlast_modification] = STATE(1481),
    [sym_addafter_modification] = STATE(1481),
    [sym_addbefore_modification] = STATE(1481),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1481),
    [sym_movelast_modification] = STATE(1481),
    [sym_moveafter_modification] = STATE(1481),
    [sym_movebefore_modification] = STATE(1481),
    [sym_actions_section] = STATE(1481),
    [sym_views_section] = STATE(1481),
    [sym_dataset_section] = STATE(1481),
    [sym_requestpage_section] = STATE(1481),
    [sym_rendering_section] = STATE(1481),
    [sym_elements_section] = STATE(1481),
    [sym_schema_section] = STATE(1481),
    [sym_assembly_declaration] = STATE(1481),
    [sym_event_declaration] = STATE(1481),
    [sym_procedure] = STATE(1481),
    [sym_preproc_split_procedure] = STATE(1481),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1481),
    [sym_var_section] = STATE(1481),
    [sym_attribute_item] = STATE(1481),
    [sym_preproc_conditional] = STATE(1481),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1481),
    [sym_preproc_conditional_layout_mixed] = STATE(1481),
    [aux_sym_group_section_repeat1] = STATE(1481),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4070),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1477)] = {
    [sym__body_element] = STATE(1482),
    [sym_empty_statement] = STATE(1482),
    [sym_property] = STATE(1482),
    [sym_fields_section] = STATE(1482),
    [sym_keys_section] = STATE(1482),
    [sym_fieldgroups_section] = STATE(1482),
    [sym_enum_value_declaration] = STATE(1482),
    [sym_labels_section] = STATE(1482),
    [sym_layout_section] = STATE(1482),
    [sym__layout_element] = STATE(1482),
    [sym_area_section] = STATE(1482),
    [sym_group_section] = STATE(1482),
    [sym_repeater_section] = STATE(1482),
    [sym_cuegroup_section] = STATE(1482),
    [sym_fixed_section] = STATE(1482),
    [sym_grid_section] = STATE(1482),
    [sym_page_field] = STATE(1482),
    [sym_part_section] = STATE(1482),
    [sym_systempart_section] = STATE(1482),
    [sym_usercontrol_section] = STATE(1482),
    [sym_preproc_split_field] = STATE(1482),
    [sym_label_section] = STATE(1482),
    [sym_addfirst_modification] = STATE(1482),
    [sym_addlast_modification] = STATE(1482),
    [sym_addafter_modification] = STATE(1482),
    [sym_addbefore_modification] = STATE(1482),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1482),
    [sym_movelast_modification] = STATE(1482),
    [sym_moveafter_modification] = STATE(1482),
    [sym_movebefore_modification] = STATE(1482),
    [sym_actions_section] = STATE(1482),
    [sym_views_section] = STATE(1482),
    [sym_dataset_section] = STATE(1482),
    [sym_requestpage_section] = STATE(1482),
    [sym_rendering_section] = STATE(1482),
    [sym_elements_section] = STATE(1482),
    [sym_schema_section] = STATE(1482),
    [sym_assembly_declaration] = STATE(1482),
    [sym_event_declaration] = STATE(1482),
    [sym_procedure] = STATE(1482),
    [sym_preproc_split_procedure] = STATE(1482),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1482),
    [sym_var_section] = STATE(1482),
    [sym_attribute_item] = STATE(1482),
    [sym_preproc_conditional] = STATE(1482),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1482),
    [sym_preproc_conditional_layout_mixed] = STATE(1482),
    [aux_sym_group_section_repeat1] = STATE(1482),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4072),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1478)] = {
    [sym__body_element] = STATE(1483),
    [sym_empty_statement] = STATE(1483),
    [sym_property] = STATE(1483),
    [sym_fields_section] = STATE(1483),
    [sym_keys_section] = STATE(1483),
    [sym_fieldgroups_section] = STATE(1483),
    [sym_enum_value_declaration] = STATE(1483),
    [sym_labels_section] = STATE(1483),
    [sym_layout_section] = STATE(1483),
    [sym__layout_element] = STATE(1483),
    [sym_area_section] = STATE(1483),
    [sym_group_section] = STATE(1483),
    [sym_repeater_section] = STATE(1483),
    [sym_cuegroup_section] = STATE(1483),
    [sym_fixed_section] = STATE(1483),
    [sym_grid_section] = STATE(1483),
    [sym_page_field] = STATE(1483),
    [sym_part_section] = STATE(1483),
    [sym_systempart_section] = STATE(1483),
    [sym_usercontrol_section] = STATE(1483),
    [sym_preproc_split_field] = STATE(1483),
    [sym_label_section] = STATE(1483),
    [sym_addfirst_modification] = STATE(1483),
    [sym_addlast_modification] = STATE(1483),
    [sym_addafter_modification] = STATE(1483),
    [sym_addbefore_modification] = STATE(1483),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1483),
    [sym_movelast_modification] = STATE(1483),
    [sym_moveafter_modification] = STATE(1483),
    [sym_movebefore_modification] = STATE(1483),
    [sym_actions_section] = STATE(1483),
    [sym_views_section] = STATE(1483),
    [sym_dataset_section] = STATE(1483),
    [sym_requestpage_section] = STATE(1483),
    [sym_rendering_section] = STATE(1483),
    [sym_elements_section] = STATE(1483),
    [sym_schema_section] = STATE(1483),
    [sym_assembly_declaration] = STATE(1483),
    [sym_event_declaration] = STATE(1483),
    [sym_procedure] = STATE(1483),
    [sym_preproc_split_procedure] = STATE(1483),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1483),
    [sym_var_section] = STATE(1483),
    [sym_attribute_item] = STATE(1483),
    [sym_preproc_conditional] = STATE(1483),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1483),
    [sym_preproc_conditional_layout_mixed] = STATE(1483),
    [aux_sym_group_section_repeat1] = STATE(1483),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4074),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1479)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4076),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1480)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4078),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1481)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4080),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1482)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4082),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1483)] = {
    [sym__body_element] = STATE(1453),
    [sym_empty_statement] = STATE(1453),
    [sym_property] = STATE(1453),
    [sym_fields_section] = STATE(1453),
    [sym_keys_section] = STATE(1453),
    [sym_fieldgroups_section] = STATE(1453),
    [sym_enum_value_declaration] = STATE(1453),
    [sym_labels_section] = STATE(1453),
    [sym_layout_section] = STATE(1453),
    [sym__layout_element] = STATE(1453),
    [sym_area_section] = STATE(1453),
    [sym_group_section] = STATE(1453),
    [sym_repeater_section] = STATE(1453),
    [sym_cuegroup_section] = STATE(1453),
    [sym_fixed_section] = STATE(1453),
    [sym_grid_section] = STATE(1453),
    [sym_page_field] = STATE(1453),
    [sym_part_section] = STATE(1453),
    [sym_systempart_section] = STATE(1453),
    [sym_usercontrol_section] = STATE(1453),
    [sym_preproc_split_field] = STATE(1453),
    [sym_label_section] = STATE(1453),
    [sym_addfirst_modification] = STATE(1453),
    [sym_addlast_modification] = STATE(1453),
    [sym_addafter_modification] = STATE(1453),
    [sym_addbefore_modification] = STATE(1453),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1453),
    [sym_movelast_modification] = STATE(1453),
    [sym_moveafter_modification] = STATE(1453),
    [sym_movebefore_modification] = STATE(1453),
    [sym_actions_section] = STATE(1453),
    [sym_views_section] = STATE(1453),
    [sym_dataset_section] = STATE(1453),
    [sym_requestpage_section] = STATE(1453),
    [sym_rendering_section] = STATE(1453),
    [sym_elements_section] = STATE(1453),
    [sym_schema_section] = STATE(1453),
    [sym_assembly_declaration] = STATE(1453),
    [sym_event_declaration] = STATE(1453),
    [sym_procedure] = STATE(1453),
    [sym_preproc_split_procedure] = STATE(1453),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1453),
    [sym_var_section] = STATE(1453),
    [sym_attribute_item] = STATE(1453),
    [sym_preproc_conditional] = STATE(1453),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1453),
    [sym_preproc_conditional_layout_mixed] = STATE(1453),
    [aux_sym_group_section_repeat1] = STATE(1453),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4084),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1484)] = {
    [sym_identifier] = ACTIONS(2434),
    [anon_sym_SEMI] = ACTIONS(2436),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_COMMA] = ACTIONS(2436),
    [anon_sym_COLON] = ACTIONS(2434),
    [anon_sym_DASH] = ACTIONS(2434),
    [aux_sym_boolean_token1] = ACTIONS(2434),
    [aux_sym_boolean_token2] = ACTIONS(2434),
    [sym_decimal] = ACTIONS(2434),
    [anon_sym_LPAREN] = ACTIONS(2436),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2434),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [aux_sym_record_type_token1] = ACTIONS(2434),
    [aux_sym_basic_type_token21] = ACTIONS(2434),
    [aux_sym_basic_type_token22] = ACTIONS(2434),
    [aux_sym_basic_type_token48] = ACTIONS(2434),
    [anon_sym_COLON_COLON] = ACTIONS(3762),
    [anon_sym_POUNDif] = ACTIONS(2436),
    [anon_sym_POUNDIF] = ACTIONS(2436),
    [anon_sym_POUNDIf] = ACTIONS(2436),
    [anon_sym_not] = ACTIONS(2434),
    [anon_sym_NOT] = ACTIONS(2434),
    [anon_sym_Not] = ACTIONS(2434),
    [anon_sym_POUNDelif] = ACTIONS(2436),
    [anon_sym_POUNDELIF] = ACTIONS(2436),
    [anon_sym_POUNDElif] = ACTIONS(2436),
    [anon_sym_POUNDelse] = ACTIONS(2436),
    [anon_sym_POUNDELSE] = ACTIONS(2436),
    [anon_sym_POUNDElse] = ACTIONS(2436),
    [anon_sym_POUNDendif] = ACTIONS(2436),
    [anon_sym_POUNDENDIF] = ACTIONS(2436),
    [anon_sym_POUNDEndif] = ACTIONS(2436),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2434),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(2434),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(2436),
    [sym_date_literal] = ACTIONS(2434),
    [sym_time_literal] = ACTIONS(2434),
    [sym_biginteger_literal] = ACTIONS(2436),
    [anon_sym_else] = ACTIONS(2434),
    [anon_sym_ELSE] = ACTIONS(2434),
    [anon_sym_Else] = ACTIONS(2434),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(2434),
    [anon_sym_codeunit] = ACTIONS(2434),
    [anon_sym_CODEUNIT] = ACTIONS(2434),
    [anon_sym_Codeunit] = ACTIONS(2434),
    [anon_sym_CodeUnit] = ACTIONS(2434),
    [anon_sym_COdeunit] = ACTIONS(2434),
    [anon_sym_codeUnit] = ACTIONS(2434),
    [sym_report_keyword] = ACTIONS(2434),
    [sym_query_keyword] = ACTIONS(2434),
    [anon_sym_xmlport] = ACTIONS(2434),
    [anon_sym_XMLPORT] = ACTIONS(2434),
    [anon_sym_Xmlport] = ACTIONS(2434),
    [anon_sym_XMLport] = ACTIONS(2434),
    [anon_sym_XMLPort] = ACTIONS(2434),
    [anon_sym_XmlPort] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2434),
    [anon_sym_ENUM] = ACTIONS(2434),
    [anon_sym_Enum] = ACTIONS(2434),
    [anon_sym_eNUM] = ACTIONS(2434),
    [anon_sym_eNum] = ACTIONS(2434),
    [anon_sym_ENum] = ACTIONS(2434),
    [sym_quoted_identifier] = ACTIONS(2436),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2436),
    [sym_integer] = ACTIONS(2434),
    [sym_continue_as_identifier] = ACTIONS(2436),
    [sym_preproc_open] = ACTIONS(2436),
    [sym_preproc_close] = ACTIONS(2436),
  },
  [STATE(1485)] = {
    [sym_boolean] = STATE(4795),
    [sym_option_member] = STATE(4829),
    [sym_keyword_identifier] = STATE(4795),
    [sym_codeunit_keyword] = STATE(4642),
    [sym_xmlport_keyword] = STATE(4642),
    [sym_enum_keyword] = STATE(4642),
    [sym_keyword_as_identifier] = STATE(4795),
    [sym_identifier] = ACTIONS(2239),
    [anon_sym_SEMI] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(391),
    [anon_sym_EQ] = ACTIONS(389),
    [anon_sym_COMMA] = ACTIONS(389),
    [anon_sym_COLON] = ACTIONS(391),
    [anon_sym_DASH] = ACTIONS(4086),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [anon_sym_RPAREN] = ACTIONS(389),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_DOT_DOT] = ACTIONS(389),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_STAR] = ACTIONS(391),
    [anon_sym_LBRACK] = ACTIONS(389),
    [anon_sym_RBRACK] = ACTIONS(389),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(2221),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(389),
    [aux_sym__expression_token1] = ACTIONS(389),
    [aux_sym__expression_token2] = ACTIONS(389),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(917),
    [anon_sym_SLASH] = ACTIONS(391),
    [anon_sym_div] = ACTIONS(391),
    [anon_sym_DIV] = ACTIONS(391),
    [anon_sym_Div] = ACTIONS(391),
    [anon_sym_mod] = ACTIONS(391),
    [anon_sym_MOD] = ACTIONS(391),
    [anon_sym_Mod] = ACTIONS(391),
    [anon_sym_PLUS] = ACTIONS(391),
    [anon_sym_GT_EQ] = ACTIONS(389),
    [anon_sym_LT_EQ] = ACTIONS(389),
    [anon_sym_GT] = ACTIONS(391),
    [anon_sym_LT] = ACTIONS(391),
    [anon_sym_LT_GT] = ACTIONS(389),
    [anon_sym_and] = ACTIONS(391),
    [anon_sym_AND] = ACTIONS(391),
    [anon_sym_And] = ACTIONS(391),
    [anon_sym_or] = ACTIONS(391),
    [anon_sym_OR] = ACTIONS(391),
    [anon_sym_Or] = ACTIONS(391),
    [anon_sym_xor] = ACTIONS(391),
    [anon_sym_XOR] = ACTIONS(391),
    [anon_sym_Xor] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(389),
    [anon_sym_then] = ACTIONS(391),
    [anon_sym_THEN] = ACTIONS(391),
    [anon_sym_Then] = ACTIONS(391),
    [anon_sym_of] = ACTIONS(391),
    [anon_sym_OF] = ACTIONS(391),
    [anon_sym_Of] = ACTIONS(391),
    [anon_sym_do] = ACTIONS(391),
    [anon_sym_DO] = ACTIONS(391),
    [anon_sym_Do] = ACTIONS(391),
    [anon_sym_in] = ACTIONS(391),
    [anon_sym_IN] = ACTIONS(391),
    [anon_sym_In] = ACTIONS(391),
    [sym_page_keyword] = ACTIONS(917),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(917),
    [sym_query_keyword] = ACTIONS(917),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(2239),
    [sym_internal_keyword] = ACTIONS(2239),
    [sym_protected_keyword] = ACTIONS(2239),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_quoted_identifier] = ACTIONS(3706),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3706),
    [sym_integer] = ACTIONS(3706),
  },
  [STATE(1486)] = {
    [sym__body_element] = STATE(1444),
    [sym_empty_statement] = STATE(1444),
    [sym_property] = STATE(1444),
    [sym_fields_section] = STATE(1444),
    [sym_keys_section] = STATE(1444),
    [sym_fieldgroups_section] = STATE(1444),
    [sym_enum_value_declaration] = STATE(1444),
    [sym_labels_section] = STATE(1444),
    [sym_layout_section] = STATE(1444),
    [sym__layout_element] = STATE(1444),
    [sym_area_section] = STATE(1444),
    [sym_group_section] = STATE(1444),
    [sym_repeater_section] = STATE(1444),
    [sym_cuegroup_section] = STATE(1444),
    [sym_fixed_section] = STATE(1444),
    [sym_grid_section] = STATE(1444),
    [sym_page_field] = STATE(1444),
    [sym_part_section] = STATE(1444),
    [sym_systempart_section] = STATE(1444),
    [sym_usercontrol_section] = STATE(1444),
    [sym_preproc_split_field] = STATE(1444),
    [sym_label_section] = STATE(1444),
    [sym_addfirst_modification] = STATE(1444),
    [sym_addlast_modification] = STATE(1444),
    [sym_addafter_modification] = STATE(1444),
    [sym_addbefore_modification] = STATE(1444),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1444),
    [sym_movelast_modification] = STATE(1444),
    [sym_moveafter_modification] = STATE(1444),
    [sym_movebefore_modification] = STATE(1444),
    [sym_actions_section] = STATE(1444),
    [sym_views_section] = STATE(1444),
    [sym_dataset_section] = STATE(1444),
    [sym_requestpage_section] = STATE(1444),
    [sym_rendering_section] = STATE(1444),
    [sym_elements_section] = STATE(1444),
    [sym_schema_section] = STATE(1444),
    [sym_assembly_declaration] = STATE(1444),
    [sym_event_declaration] = STATE(1444),
    [sym_procedure] = STATE(1444),
    [sym_preproc_split_procedure] = STATE(1444),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1444),
    [sym_var_section] = STATE(1444),
    [sym_attribute_item] = STATE(1444),
    [sym_preproc_conditional] = STATE(1444),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1444),
    [sym_preproc_conditional_layout_mixed] = STATE(1444),
    [aux_sym_group_section_repeat1] = STATE(1444),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4089),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1487)] = {
    [sym__body_element] = STATE(1457),
    [sym_empty_statement] = STATE(1457),
    [sym_property] = STATE(1457),
    [sym_fields_section] = STATE(1457),
    [sym_keys_section] = STATE(1457),
    [sym_fieldgroups_section] = STATE(1457),
    [sym_enum_value_declaration] = STATE(1457),
    [sym_labels_section] = STATE(1457),
    [sym_layout_section] = STATE(1457),
    [sym__layout_element] = STATE(1457),
    [sym_area_section] = STATE(1457),
    [sym_group_section] = STATE(1457),
    [sym_repeater_section] = STATE(1457),
    [sym_cuegroup_section] = STATE(1457),
    [sym_fixed_section] = STATE(1457),
    [sym_grid_section] = STATE(1457),
    [sym_page_field] = STATE(1457),
    [sym_part_section] = STATE(1457),
    [sym_systempart_section] = STATE(1457),
    [sym_usercontrol_section] = STATE(1457),
    [sym_preproc_split_field] = STATE(1457),
    [sym_label_section] = STATE(1457),
    [sym_addfirst_modification] = STATE(1457),
    [sym_addlast_modification] = STATE(1457),
    [sym_addafter_modification] = STATE(1457),
    [sym_addbefore_modification] = STATE(1457),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1457),
    [sym_movelast_modification] = STATE(1457),
    [sym_moveafter_modification] = STATE(1457),
    [sym_movebefore_modification] = STATE(1457),
    [sym_actions_section] = STATE(1457),
    [sym_views_section] = STATE(1457),
    [sym_dataset_section] = STATE(1457),
    [sym_requestpage_section] = STATE(1457),
    [sym_rendering_section] = STATE(1457),
    [sym_elements_section] = STATE(1457),
    [sym_schema_section] = STATE(1457),
    [sym_assembly_declaration] = STATE(1457),
    [sym_event_declaration] = STATE(1457),
    [sym_procedure] = STATE(1457),
    [sym_preproc_split_procedure] = STATE(1457),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1457),
    [sym_var_section] = STATE(1457),
    [sym_attribute_item] = STATE(1457),
    [sym_preproc_conditional] = STATE(1457),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1457),
    [sym_preproc_conditional_layout_mixed] = STATE(1457),
    [aux_sym_group_section_repeat1] = STATE(1457),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4091),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1488)] = {
    [sym__body_element] = STATE(1451),
    [sym_empty_statement] = STATE(1451),
    [sym_property] = STATE(1451),
    [sym_fields_section] = STATE(1451),
    [sym_keys_section] = STATE(1451),
    [sym_fieldgroups_section] = STATE(1451),
    [sym_enum_value_declaration] = STATE(1451),
    [sym_labels_section] = STATE(1451),
    [sym_layout_section] = STATE(1451),
    [sym__layout_element] = STATE(1451),
    [sym_area_section] = STATE(1451),
    [sym_group_section] = STATE(1451),
    [sym_repeater_section] = STATE(1451),
    [sym_cuegroup_section] = STATE(1451),
    [sym_fixed_section] = STATE(1451),
    [sym_grid_section] = STATE(1451),
    [sym_page_field] = STATE(1451),
    [sym_part_section] = STATE(1451),
    [sym_systempart_section] = STATE(1451),
    [sym_usercontrol_section] = STATE(1451),
    [sym_preproc_split_field] = STATE(1451),
    [sym_label_section] = STATE(1451),
    [sym_addfirst_modification] = STATE(1451),
    [sym_addlast_modification] = STATE(1451),
    [sym_addafter_modification] = STATE(1451),
    [sym_addbefore_modification] = STATE(1451),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1451),
    [sym_movelast_modification] = STATE(1451),
    [sym_moveafter_modification] = STATE(1451),
    [sym_movebefore_modification] = STATE(1451),
    [sym_actions_section] = STATE(1451),
    [sym_views_section] = STATE(1451),
    [sym_dataset_section] = STATE(1451),
    [sym_requestpage_section] = STATE(1451),
    [sym_rendering_section] = STATE(1451),
    [sym_elements_section] = STATE(1451),
    [sym_schema_section] = STATE(1451),
    [sym_assembly_declaration] = STATE(1451),
    [sym_event_declaration] = STATE(1451),
    [sym_procedure] = STATE(1451),
    [sym_preproc_split_procedure] = STATE(1451),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1451),
    [sym_var_section] = STATE(1451),
    [sym_attribute_item] = STATE(1451),
    [sym_preproc_conditional] = STATE(1451),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1451),
    [sym_preproc_conditional_layout_mixed] = STATE(1451),
    [aux_sym_group_section_repeat1] = STATE(1451),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4093),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1489)] = {
    [sym__body_element] = STATE(1430),
    [sym_empty_statement] = STATE(1430),
    [sym_property] = STATE(1430),
    [sym_fields_section] = STATE(1430),
    [sym_keys_section] = STATE(1430),
    [sym_fieldgroups_section] = STATE(1430),
    [sym_enum_value_declaration] = STATE(1430),
    [sym_labels_section] = STATE(1430),
    [sym_layout_section] = STATE(1430),
    [sym__layout_element] = STATE(1430),
    [sym_area_section] = STATE(1430),
    [sym_group_section] = STATE(1430),
    [sym_repeater_section] = STATE(1430),
    [sym_cuegroup_section] = STATE(1430),
    [sym_fixed_section] = STATE(1430),
    [sym_grid_section] = STATE(1430),
    [sym_page_field] = STATE(1430),
    [sym_part_section] = STATE(1430),
    [sym_systempart_section] = STATE(1430),
    [sym_usercontrol_section] = STATE(1430),
    [sym_preproc_split_field] = STATE(1430),
    [sym_label_section] = STATE(1430),
    [sym_addfirst_modification] = STATE(1430),
    [sym_addlast_modification] = STATE(1430),
    [sym_addafter_modification] = STATE(1430),
    [sym_addbefore_modification] = STATE(1430),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1430),
    [sym_movelast_modification] = STATE(1430),
    [sym_moveafter_modification] = STATE(1430),
    [sym_movebefore_modification] = STATE(1430),
    [sym_actions_section] = STATE(1430),
    [sym_views_section] = STATE(1430),
    [sym_dataset_section] = STATE(1430),
    [sym_requestpage_section] = STATE(1430),
    [sym_rendering_section] = STATE(1430),
    [sym_elements_section] = STATE(1430),
    [sym_schema_section] = STATE(1430),
    [sym_assembly_declaration] = STATE(1430),
    [sym_event_declaration] = STATE(1430),
    [sym_procedure] = STATE(1430),
    [sym_preproc_split_procedure] = STATE(1430),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1430),
    [sym_var_section] = STATE(1430),
    [sym_attribute_item] = STATE(1430),
    [sym_preproc_conditional] = STATE(1430),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1430),
    [sym_preproc_conditional_layout_mixed] = STATE(1430),
    [aux_sym_group_section_repeat1] = STATE(1430),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4095),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1490)] = {
    [sym__body_element] = STATE(1431),
    [sym_empty_statement] = STATE(1431),
    [sym_property] = STATE(1431),
    [sym_fields_section] = STATE(1431),
    [sym_keys_section] = STATE(1431),
    [sym_fieldgroups_section] = STATE(1431),
    [sym_enum_value_declaration] = STATE(1431),
    [sym_labels_section] = STATE(1431),
    [sym_layout_section] = STATE(1431),
    [sym__layout_element] = STATE(1431),
    [sym_area_section] = STATE(1431),
    [sym_group_section] = STATE(1431),
    [sym_repeater_section] = STATE(1431),
    [sym_cuegroup_section] = STATE(1431),
    [sym_fixed_section] = STATE(1431),
    [sym_grid_section] = STATE(1431),
    [sym_page_field] = STATE(1431),
    [sym_part_section] = STATE(1431),
    [sym_systempart_section] = STATE(1431),
    [sym_usercontrol_section] = STATE(1431),
    [sym_preproc_split_field] = STATE(1431),
    [sym_label_section] = STATE(1431),
    [sym_addfirst_modification] = STATE(1431),
    [sym_addlast_modification] = STATE(1431),
    [sym_addafter_modification] = STATE(1431),
    [sym_addbefore_modification] = STATE(1431),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1431),
    [sym_movelast_modification] = STATE(1431),
    [sym_moveafter_modification] = STATE(1431),
    [sym_movebefore_modification] = STATE(1431),
    [sym_actions_section] = STATE(1431),
    [sym_views_section] = STATE(1431),
    [sym_dataset_section] = STATE(1431),
    [sym_requestpage_section] = STATE(1431),
    [sym_rendering_section] = STATE(1431),
    [sym_elements_section] = STATE(1431),
    [sym_schema_section] = STATE(1431),
    [sym_assembly_declaration] = STATE(1431),
    [sym_event_declaration] = STATE(1431),
    [sym_procedure] = STATE(1431),
    [sym_preproc_split_procedure] = STATE(1431),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1431),
    [sym_var_section] = STATE(1431),
    [sym_attribute_item] = STATE(1431),
    [sym_preproc_conditional] = STATE(1431),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1431),
    [sym_preproc_conditional_layout_mixed] = STATE(1431),
    [aux_sym_group_section_repeat1] = STATE(1431),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4097),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1491)] = {
    [sym__body_element] = STATE(1462),
    [sym_empty_statement] = STATE(1462),
    [sym_property] = STATE(1462),
    [sym_fields_section] = STATE(1462),
    [sym_keys_section] = STATE(1462),
    [sym_fieldgroups_section] = STATE(1462),
    [sym_enum_value_declaration] = STATE(1462),
    [sym_labels_section] = STATE(1462),
    [sym_layout_section] = STATE(1462),
    [sym__layout_element] = STATE(1462),
    [sym_area_section] = STATE(1462),
    [sym_group_section] = STATE(1462),
    [sym_repeater_section] = STATE(1462),
    [sym_cuegroup_section] = STATE(1462),
    [sym_fixed_section] = STATE(1462),
    [sym_grid_section] = STATE(1462),
    [sym_page_field] = STATE(1462),
    [sym_part_section] = STATE(1462),
    [sym_systempart_section] = STATE(1462),
    [sym_usercontrol_section] = STATE(1462),
    [sym_preproc_split_field] = STATE(1462),
    [sym_label_section] = STATE(1462),
    [sym_addfirst_modification] = STATE(1462),
    [sym_addlast_modification] = STATE(1462),
    [sym_addafter_modification] = STATE(1462),
    [sym_addbefore_modification] = STATE(1462),
    [sym_modify_modification] = STATE(4984),
    [sym_movefirst_modification] = STATE(1462),
    [sym_movelast_modification] = STATE(1462),
    [sym_moveafter_modification] = STATE(1462),
    [sym_movebefore_modification] = STATE(1462),
    [sym_actions_section] = STATE(1462),
    [sym_views_section] = STATE(1462),
    [sym_dataset_section] = STATE(1462),
    [sym_requestpage_section] = STATE(1462),
    [sym_rendering_section] = STATE(1462),
    [sym_elements_section] = STATE(1462),
    [sym_schema_section] = STATE(1462),
    [sym_assembly_declaration] = STATE(1462),
    [sym_event_declaration] = STATE(1462),
    [sym_procedure] = STATE(1462),
    [sym_preproc_split_procedure] = STATE(1462),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(1462),
    [sym_var_section] = STATE(1462),
    [sym_attribute_item] = STATE(1462),
    [sym_preproc_conditional] = STATE(1462),
    [sym_preproc_if] = STATE(1245),
    [sym_preproc_conditional_layout] = STATE(1462),
    [sym_preproc_conditional_layout_mixed] = STATE(1462),
    [aux_sym_group_section_repeat1] = STATE(1462),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(4099),
    [aux_sym_where_condition_token1] = ACTIONS(3797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3799),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token6] = ACTIONS(3805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(3809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3811),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3815),
    [aux_sym_movelast_modification_token1] = ACTIONS(3817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(3845),
    [sym_group_keyword] = ACTIONS(3847),
    [sym_repeater_keyword] = ACTIONS(3849),
    [sym_cuegroup_keyword] = ACTIONS(3851),
    [sym_fixed_keyword] = ACTIONS(3853),
    [sym_grid_keyword] = ACTIONS(3855),
    [sym_part_keyword] = ACTIONS(3857),
    [sym_systempart_keyword] = ACTIONS(3859),
    [sym_usercontrol_keyword] = ACTIONS(3861),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(1492)] = {
    [sym_identifier] = ACTIONS(2629),
    [anon_sym_SEMI] = ACTIONS(2631),
    [anon_sym_DOT] = ACTIONS(2629),
    [anon_sym_EQ] = ACTIONS(2631),
    [anon_sym_COMMA] = ACTIONS(2631),
    [anon_sym_COLON] = ACTIONS(2629),
    [anon_sym_DASH] = ACTIONS(2629),
    [aux_sym_boolean_token1] = ACTIONS(2629),
    [aux_sym_boolean_token2] = ACTIONS(2629),
    [sym_decimal] = ACTIONS(2629),
    [anon_sym_LPAREN] = ACTIONS(2631),
    [anon_sym_DOT_DOT] = ACTIONS(2631),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2629),
    [anon_sym_STAR] = ACTIONS(2629),
    [anon_sym_LBRACK] = ACTIONS(2631),
    [aux_sym_record_type_token1] = ACTIONS(2629),
    [aux_sym_basic_type_token21] = ACTIONS(2629),
    [aux_sym_basic_type_token22] = ACTIONS(2629),
    [aux_sym_basic_type_token48] = ACTIONS(2629),
    [anon_sym_POUNDif] = ACTIONS(2631),
    [anon_sym_POUNDIF] = ACTIONS(2631),
    [anon_sym_POUNDIf] = ACTIONS(2631),
    [anon_sym_not] = ACTIONS(2629),
    [anon_sym_NOT] = ACTIONS(2629),
    [anon_sym_Not] = ACTIONS(2629),
    [anon_sym_POUNDelif] = ACTIONS(2631),
    [anon_sym_POUNDELIF] = ACTIONS(2631),
    [anon_sym_POUNDElif] = ACTIONS(2631),
    [anon_sym_POUNDelse] = ACTIONS(2631),
    [anon_sym_POUNDELSE] = ACTIONS(2631),
    [anon_sym_POUNDElse] = ACTIONS(2631),
    [anon_sym_POUNDendif] = ACTIONS(2631),
    [anon_sym_POUNDENDIF] = ACTIONS(2631),
    [anon_sym_POUNDEndif] = ACTIONS(2631),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2631),
    [aux_sym__expression_token1] = ACTIONS(2631),
    [aux_sym__expression_token2] = ACTIONS(2631),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2629),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2629),
    [anon_sym_SLASH] = ACTIONS(2629),
    [anon_sym_div] = ACTIONS(2629),
    [anon_sym_DIV] = ACTIONS(2629),
    [anon_sym_Div] = ACTIONS(2629),
    [anon_sym_mod] = ACTIONS(2629),
    [anon_sym_MOD] = ACTIONS(2629),
    [anon_sym_Mod] = ACTIONS(2629),
    [anon_sym_PLUS] = ACTIONS(2629),
    [anon_sym_GT_EQ] = ACTIONS(2631),
    [anon_sym_LT_EQ] = ACTIONS(2631),
    [anon_sym_GT] = ACTIONS(2629),
    [anon_sym_LT] = ACTIONS(2629),
    [anon_sym_LT_GT] = ACTIONS(2631),
    [anon_sym_and] = ACTIONS(2629),
    [anon_sym_AND] = ACTIONS(2629),
    [anon_sym_And] = ACTIONS(2629),
    [anon_sym_or] = ACTIONS(2629),
    [anon_sym_OR] = ACTIONS(2629),
    [anon_sym_Or] = ACTIONS(2629),
    [anon_sym_xor] = ACTIONS(2629),
    [anon_sym_XOR] = ACTIONS(2629),
    [anon_sym_Xor] = ACTIONS(2629),
    [anon_sym_QMARK] = ACTIONS(2631),
    [sym_datetime_literal] = ACTIONS(2631),
    [sym_date_literal] = ACTIONS(2629),
    [sym_time_literal] = ACTIONS(2629),
    [sym_biginteger_literal] = ACTIONS(2631),
    [anon_sym_else] = ACTIONS(2629),
    [anon_sym_ELSE] = ACTIONS(2629),
    [anon_sym_Else] = ACTIONS(2629),
    [anon_sym_in] = ACTIONS(2629),
    [anon_sym_IN] = ACTIONS(2629),
    [anon_sym_In] = ACTIONS(2629),
    [sym_page_keyword] = ACTIONS(2629),
    [anon_sym_codeunit] = ACTIONS(2629),
    [anon_sym_CODEUNIT] = ACTIONS(2629),
    [anon_sym_Codeunit] = ACTIONS(2629),
    [anon_sym_CodeUnit] = ACTIONS(2629),
    [anon_sym_COdeunit] = ACTIONS(2629),
    [anon_sym_codeUnit] = ACTIONS(2629),
    [sym_report_keyword] = ACTIONS(2629),
    [sym_query_keyword] = ACTIONS(2629),
    [anon_sym_xmlport] = ACTIONS(2629),
    [anon_sym_XMLPORT] = ACTIONS(2629),
    [anon_sym_Xmlport] = ACTIONS(2629),
    [anon_sym_XMLport] = ACTIONS(2629),
    [anon_sym_XMLPort] = ACTIONS(2629),
    [anon_sym_XmlPort] = ACTIONS(2629),
    [anon_sym_enum] = ACTIONS(2629),
    [anon_sym_ENUM] = ACTIONS(2629),
    [anon_sym_Enum] = ACTIONS(2629),
    [anon_sym_eNUM] = ACTIONS(2629),
    [anon_sym_eNum] = ACTIONS(2629),
    [anon_sym_ENum] = ACTIONS(2629),
    [sym_quoted_identifier] = ACTIONS(2631),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2631),
    [sym_integer] = ACTIONS(2629),
    [sym_continue_as_identifier] = ACTIONS(2631),
    [sym_preproc_open] = ACTIONS(2631),
    [sym_preproc_close] = ACTIONS(2631),
  },
  [STATE(1493)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_SEMI] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_COMMA] = ACTIONS(2595),
    [anon_sym_COLON] = ACTIONS(2593),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [anon_sym_POUNDif] = ACTIONS(2595),
    [anon_sym_POUNDIF] = ACTIONS(2595),
    [anon_sym_POUNDIf] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [anon_sym_POUNDelif] = ACTIONS(2595),
    [anon_sym_POUNDELIF] = ACTIONS(2595),
    [anon_sym_POUNDElif] = ACTIONS(2595),
    [anon_sym_POUNDelse] = ACTIONS(2595),
    [anon_sym_POUNDELSE] = ACTIONS(2595),
    [anon_sym_POUNDElse] = ACTIONS(2595),
    [anon_sym_POUNDendif] = ACTIONS(2595),
    [anon_sym_POUNDENDIF] = ACTIONS(2595),
    [anon_sym_POUNDEndif] = ACTIONS(2595),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2595),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_else] = ACTIONS(2593),
    [anon_sym_ELSE] = ACTIONS(2593),
    [anon_sym_Else] = ACTIONS(2593),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_open] = ACTIONS(2595),
    [sym_preproc_close] = ACTIONS(2595),
  },
  [STATE(1494)] = {
    [sym_identifier] = ACTIONS(2605),
    [anon_sym_SEMI] = ACTIONS(2607),
    [anon_sym_DOT] = ACTIONS(2605),
    [anon_sym_EQ] = ACTIONS(2607),
    [anon_sym_COMMA] = ACTIONS(2607),
    [anon_sym_COLON] = ACTIONS(2605),
    [anon_sym_DASH] = ACTIONS(2605),
    [aux_sym_boolean_token1] = ACTIONS(2605),
    [aux_sym_boolean_token2] = ACTIONS(2605),
    [sym_decimal] = ACTIONS(2605),
    [anon_sym_LPAREN] = ACTIONS(2607),
    [anon_sym_DOT_DOT] = ACTIONS(2607),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2605),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_LBRACK] = ACTIONS(2607),
    [aux_sym_record_type_token1] = ACTIONS(2605),
    [aux_sym_basic_type_token21] = ACTIONS(2605),
    [aux_sym_basic_type_token22] = ACTIONS(2605),
    [aux_sym_basic_type_token48] = ACTIONS(2605),
    [anon_sym_POUNDif] = ACTIONS(2607),
    [anon_sym_POUNDIF] = ACTIONS(2607),
    [anon_sym_POUNDIf] = ACTIONS(2607),
    [anon_sym_not] = ACTIONS(2605),
    [anon_sym_NOT] = ACTIONS(2605),
    [anon_sym_Not] = ACTIONS(2605),
    [anon_sym_POUNDelif] = ACTIONS(2607),
    [anon_sym_POUNDELIF] = ACTIONS(2607),
    [anon_sym_POUNDElif] = ACTIONS(2607),
    [anon_sym_POUNDelse] = ACTIONS(2607),
    [anon_sym_POUNDELSE] = ACTIONS(2607),
    [anon_sym_POUNDElse] = ACTIONS(2607),
    [anon_sym_POUNDendif] = ACTIONS(2607),
    [anon_sym_POUNDENDIF] = ACTIONS(2607),
    [anon_sym_POUNDEndif] = ACTIONS(2607),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2607),
    [aux_sym__expression_token1] = ACTIONS(2607),
    [aux_sym__expression_token2] = ACTIONS(2607),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2605),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2605),
    [anon_sym_SLASH] = ACTIONS(2605),
    [anon_sym_div] = ACTIONS(2605),
    [anon_sym_DIV] = ACTIONS(2605),
    [anon_sym_Div] = ACTIONS(2605),
    [anon_sym_mod] = ACTIONS(2605),
    [anon_sym_MOD] = ACTIONS(2605),
    [anon_sym_Mod] = ACTIONS(2605),
    [anon_sym_PLUS] = ACTIONS(2605),
    [anon_sym_GT_EQ] = ACTIONS(2607),
    [anon_sym_LT_EQ] = ACTIONS(2607),
    [anon_sym_GT] = ACTIONS(2605),
    [anon_sym_LT] = ACTIONS(2605),
    [anon_sym_LT_GT] = ACTIONS(2607),
    [anon_sym_and] = ACTIONS(2605),
    [anon_sym_AND] = ACTIONS(2605),
    [anon_sym_And] = ACTIONS(2605),
    [anon_sym_or] = ACTIONS(2605),
    [anon_sym_OR] = ACTIONS(2605),
    [anon_sym_Or] = ACTIONS(2605),
    [anon_sym_xor] = ACTIONS(2605),
    [anon_sym_XOR] = ACTIONS(2605),
    [anon_sym_Xor] = ACTIONS(2605),
    [anon_sym_QMARK] = ACTIONS(2607),
    [sym_datetime_literal] = ACTIONS(2607),
    [sym_date_literal] = ACTIONS(2605),
    [sym_time_literal] = ACTIONS(2605),
    [sym_biginteger_literal] = ACTIONS(2607),
    [anon_sym_else] = ACTIONS(2605),
    [anon_sym_ELSE] = ACTIONS(2605),
    [anon_sym_Else] = ACTIONS(2605),
    [anon_sym_in] = ACTIONS(2605),
    [anon_sym_IN] = ACTIONS(2605),
    [anon_sym_In] = ACTIONS(2605),
    [sym_page_keyword] = ACTIONS(2605),
    [anon_sym_codeunit] = ACTIONS(2605),
    [anon_sym_CODEUNIT] = ACTIONS(2605),
    [anon_sym_Codeunit] = ACTIONS(2605),
    [anon_sym_CodeUnit] = ACTIONS(2605),
    [anon_sym_COdeunit] = ACTIONS(2605),
    [anon_sym_codeUnit] = ACTIONS(2605),
    [sym_report_keyword] = ACTIONS(2605),
    [sym_query_keyword] = ACTIONS(2605),
    [anon_sym_xmlport] = ACTIONS(2605),
    [anon_sym_XMLPORT] = ACTIONS(2605),
    [anon_sym_Xmlport] = ACTIONS(2605),
    [anon_sym_XMLport] = ACTIONS(2605),
    [anon_sym_XMLPort] = ACTIONS(2605),
    [anon_sym_XmlPort] = ACTIONS(2605),
    [anon_sym_enum] = ACTIONS(2605),
    [anon_sym_ENUM] = ACTIONS(2605),
    [anon_sym_Enum] = ACTIONS(2605),
    [anon_sym_eNUM] = ACTIONS(2605),
    [anon_sym_eNum] = ACTIONS(2605),
    [anon_sym_ENum] = ACTIONS(2605),
    [sym_quoted_identifier] = ACTIONS(2607),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2607),
    [sym_integer] = ACTIONS(2605),
    [sym_continue_as_identifier] = ACTIONS(2607),
    [sym_preproc_open] = ACTIONS(2607),
    [sym_preproc_close] = ACTIONS(2607),
  },
  [STATE(1495)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2382),
    [anon_sym_SEMI] = ACTIONS(2385),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(3710),
    [aux_sym_boolean_token1] = ACTIONS(2382),
    [aux_sym_boolean_token2] = ACTIONS(2382),
    [sym_decimal] = ACTIONS(2382),
    [anon_sym_LPAREN] = ACTIONS(2385),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2382),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2382),
    [aux_sym_basic_type_token21] = ACTIONS(2382),
    [aux_sym_basic_type_token22] = ACTIONS(2382),
    [aux_sym_basic_type_token48] = ACTIONS(2382),
    [anon_sym_POUNDif] = ACTIONS(2385),
    [anon_sym_POUNDIF] = ACTIONS(2385),
    [anon_sym_POUNDIf] = ACTIONS(2385),
    [anon_sym_not] = ACTIONS(2382),
    [anon_sym_NOT] = ACTIONS(2382),
    [anon_sym_Not] = ACTIONS(2382),
    [anon_sym_POUNDelif] = ACTIONS(2385),
    [anon_sym_POUNDELIF] = ACTIONS(2385),
    [anon_sym_POUNDElif] = ACTIONS(2385),
    [anon_sym_POUNDelse] = ACTIONS(2385),
    [anon_sym_POUNDELSE] = ACTIONS(2385),
    [anon_sym_POUNDElse] = ACTIONS(2385),
    [anon_sym_POUNDendif] = ACTIONS(2385),
    [anon_sym_POUNDENDIF] = ACTIONS(2385),
    [anon_sym_POUNDEndif] = ACTIONS(2385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3764),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2382),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(3736),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3740),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(3766),
    [anon_sym_OR] = ACTIONS(3768),
    [anon_sym_Or] = ACTIONS(3770),
    [anon_sym_xor] = ACTIONS(3772),
    [anon_sym_XOR] = ACTIONS(3774),
    [anon_sym_Xor] = ACTIONS(3776),
    [anon_sym_QMARK] = ACTIONS(3778),
    [sym_datetime_literal] = ACTIONS(2385),
    [sym_date_literal] = ACTIONS(2382),
    [sym_time_literal] = ACTIONS(2382),
    [sym_biginteger_literal] = ACTIONS(2385),
    [anon_sym_else] = ACTIONS(2382),
    [anon_sym_ELSE] = ACTIONS(2382),
    [anon_sym_Else] = ACTIONS(2382),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2382),
    [anon_sym_codeunit] = ACTIONS(2382),
    [anon_sym_CODEUNIT] = ACTIONS(2382),
    [anon_sym_Codeunit] = ACTIONS(2382),
    [anon_sym_CodeUnit] = ACTIONS(2382),
    [anon_sym_COdeunit] = ACTIONS(2382),
    [anon_sym_codeUnit] = ACTIONS(2382),
    [sym_report_keyword] = ACTIONS(2382),
    [sym_query_keyword] = ACTIONS(2382),
    [anon_sym_xmlport] = ACTIONS(2382),
    [anon_sym_XMLPORT] = ACTIONS(2382),
    [anon_sym_Xmlport] = ACTIONS(2382),
    [anon_sym_XMLport] = ACTIONS(2382),
    [anon_sym_XMLPort] = ACTIONS(2382),
    [anon_sym_XmlPort] = ACTIONS(2382),
    [anon_sym_enum] = ACTIONS(2382),
    [anon_sym_ENUM] = ACTIONS(2382),
    [anon_sym_Enum] = ACTIONS(2382),
    [anon_sym_eNUM] = ACTIONS(2382),
    [anon_sym_eNum] = ACTIONS(2382),
    [anon_sym_ENum] = ACTIONS(2382),
    [sym_quoted_identifier] = ACTIONS(2385),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2385),
    [sym_integer] = ACTIONS(2382),
    [sym_continue_as_identifier] = ACTIONS(2385),
    [sym_preproc_open] = ACTIONS(2385),
    [sym_preproc_close] = ACTIONS(2385),
  },
  [STATE(1496)] = {
    [sym_identifier] = ACTIONS(2551),
    [anon_sym_SEMI] = ACTIONS(2553),
    [anon_sym_DOT] = ACTIONS(2551),
    [anon_sym_EQ] = ACTIONS(2553),
    [anon_sym_COMMA] = ACTIONS(2553),
    [anon_sym_COLON] = ACTIONS(2551),
    [anon_sym_DASH] = ACTIONS(2551),
    [aux_sym_boolean_token1] = ACTIONS(2551),
    [aux_sym_boolean_token2] = ACTIONS(2551),
    [sym_decimal] = ACTIONS(2551),
    [anon_sym_LPAREN] = ACTIONS(2553),
    [anon_sym_DOT_DOT] = ACTIONS(2553),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2551),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_LBRACK] = ACTIONS(2553),
    [aux_sym_record_type_token1] = ACTIONS(2551),
    [aux_sym_basic_type_token21] = ACTIONS(2551),
    [aux_sym_basic_type_token22] = ACTIONS(2551),
    [aux_sym_basic_type_token48] = ACTIONS(2551),
    [anon_sym_POUNDif] = ACTIONS(2553),
    [anon_sym_POUNDIF] = ACTIONS(2553),
    [anon_sym_POUNDIf] = ACTIONS(2553),
    [anon_sym_not] = ACTIONS(2551),
    [anon_sym_NOT] = ACTIONS(2551),
    [anon_sym_Not] = ACTIONS(2551),
    [anon_sym_POUNDelif] = ACTIONS(2553),
    [anon_sym_POUNDELIF] = ACTIONS(2553),
    [anon_sym_POUNDElif] = ACTIONS(2553),
    [anon_sym_POUNDelse] = ACTIONS(2553),
    [anon_sym_POUNDELSE] = ACTIONS(2553),
    [anon_sym_POUNDElse] = ACTIONS(2553),
    [anon_sym_POUNDendif] = ACTIONS(2553),
    [anon_sym_POUNDENDIF] = ACTIONS(2553),
    [anon_sym_POUNDEndif] = ACTIONS(2553),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2553),
    [aux_sym__expression_token1] = ACTIONS(2553),
    [aux_sym__expression_token2] = ACTIONS(2553),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2551),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2551),
    [anon_sym_SLASH] = ACTIONS(2551),
    [anon_sym_div] = ACTIONS(2551),
    [anon_sym_DIV] = ACTIONS(2551),
    [anon_sym_Div] = ACTIONS(2551),
    [anon_sym_mod] = ACTIONS(2551),
    [anon_sym_MOD] = ACTIONS(2551),
    [anon_sym_Mod] = ACTIONS(2551),
    [anon_sym_PLUS] = ACTIONS(2551),
    [anon_sym_GT_EQ] = ACTIONS(2553),
    [anon_sym_LT_EQ] = ACTIONS(2553),
    [anon_sym_GT] = ACTIONS(2551),
    [anon_sym_LT] = ACTIONS(2551),
    [anon_sym_LT_GT] = ACTIONS(2553),
    [anon_sym_and] = ACTIONS(2551),
    [anon_sym_AND] = ACTIONS(2551),
    [anon_sym_And] = ACTIONS(2551),
    [anon_sym_or] = ACTIONS(2551),
    [anon_sym_OR] = ACTIONS(2551),
    [anon_sym_Or] = ACTIONS(2551),
    [anon_sym_xor] = ACTIONS(2551),
    [anon_sym_XOR] = ACTIONS(2551),
    [anon_sym_Xor] = ACTIONS(2551),
    [anon_sym_QMARK] = ACTIONS(2553),
    [sym_datetime_literal] = ACTIONS(2553),
    [sym_date_literal] = ACTIONS(2551),
    [sym_time_literal] = ACTIONS(2551),
    [sym_biginteger_literal] = ACTIONS(2553),
    [anon_sym_else] = ACTIONS(2551),
    [anon_sym_ELSE] = ACTIONS(2551),
    [anon_sym_Else] = ACTIONS(2551),
    [anon_sym_in] = ACTIONS(2551),
    [anon_sym_IN] = ACTIONS(2551),
    [anon_sym_In] = ACTIONS(2551),
    [sym_page_keyword] = ACTIONS(2551),
    [anon_sym_codeunit] = ACTIONS(2551),
    [anon_sym_CODEUNIT] = ACTIONS(2551),
    [anon_sym_Codeunit] = ACTIONS(2551),
    [anon_sym_CodeUnit] = ACTIONS(2551),
    [anon_sym_COdeunit] = ACTIONS(2551),
    [anon_sym_codeUnit] = ACTIONS(2551),
    [sym_report_keyword] = ACTIONS(2551),
    [sym_query_keyword] = ACTIONS(2551),
    [anon_sym_xmlport] = ACTIONS(2551),
    [anon_sym_XMLPORT] = ACTIONS(2551),
    [anon_sym_Xmlport] = ACTIONS(2551),
    [anon_sym_XMLport] = ACTIONS(2551),
    [anon_sym_XMLPort] = ACTIONS(2551),
    [anon_sym_XmlPort] = ACTIONS(2551),
    [anon_sym_enum] = ACTIONS(2551),
    [anon_sym_ENUM] = ACTIONS(2551),
    [anon_sym_Enum] = ACTIONS(2551),
    [anon_sym_eNUM] = ACTIONS(2551),
    [anon_sym_eNum] = ACTIONS(2551),
    [anon_sym_ENum] = ACTIONS(2551),
    [sym_quoted_identifier] = ACTIONS(2553),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2553),
    [sym_integer] = ACTIONS(2551),
    [sym_continue_as_identifier] = ACTIONS(2553),
    [sym_preproc_open] = ACTIONS(2553),
    [sym_preproc_close] = ACTIONS(2553),
  },
  [STATE(1497)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2388),
    [anon_sym_SEMI] = ACTIONS(2390),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(3710),
    [aux_sym_boolean_token1] = ACTIONS(2388),
    [aux_sym_boolean_token2] = ACTIONS(2388),
    [sym_decimal] = ACTIONS(2388),
    [anon_sym_LPAREN] = ACTIONS(2390),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2388),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2388),
    [aux_sym_basic_type_token21] = ACTIONS(2388),
    [aux_sym_basic_type_token22] = ACTIONS(2388),
    [aux_sym_basic_type_token48] = ACTIONS(2388),
    [anon_sym_POUNDif] = ACTIONS(2390),
    [anon_sym_POUNDIF] = ACTIONS(2390),
    [anon_sym_POUNDIf] = ACTIONS(2390),
    [anon_sym_not] = ACTIONS(2388),
    [anon_sym_NOT] = ACTIONS(2388),
    [anon_sym_Not] = ACTIONS(2388),
    [anon_sym_POUNDelif] = ACTIONS(2390),
    [anon_sym_POUNDELIF] = ACTIONS(2390),
    [anon_sym_POUNDElif] = ACTIONS(2390),
    [anon_sym_POUNDelse] = ACTIONS(2390),
    [anon_sym_POUNDELSE] = ACTIONS(2390),
    [anon_sym_POUNDElse] = ACTIONS(2390),
    [anon_sym_POUNDendif] = ACTIONS(2390),
    [anon_sym_POUNDENDIF] = ACTIONS(2390),
    [anon_sym_POUNDEndif] = ACTIONS(2390),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3764),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2388),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2388),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(3736),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3740),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(3766),
    [anon_sym_OR] = ACTIONS(3768),
    [anon_sym_Or] = ACTIONS(3770),
    [anon_sym_xor] = ACTIONS(3772),
    [anon_sym_XOR] = ACTIONS(3774),
    [anon_sym_Xor] = ACTIONS(3776),
    [anon_sym_QMARK] = ACTIONS(3778),
    [sym_datetime_literal] = ACTIONS(2390),
    [sym_date_literal] = ACTIONS(2388),
    [sym_time_literal] = ACTIONS(2388),
    [sym_biginteger_literal] = ACTIONS(2390),
    [anon_sym_else] = ACTIONS(2388),
    [anon_sym_ELSE] = ACTIONS(2388),
    [anon_sym_Else] = ACTIONS(2388),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2388),
    [anon_sym_codeunit] = ACTIONS(2388),
    [anon_sym_CODEUNIT] = ACTIONS(2388),
    [anon_sym_Codeunit] = ACTIONS(2388),
    [anon_sym_CodeUnit] = ACTIONS(2388),
    [anon_sym_COdeunit] = ACTIONS(2388),
    [anon_sym_codeUnit] = ACTIONS(2388),
    [sym_report_keyword] = ACTIONS(2388),
    [sym_query_keyword] = ACTIONS(2388),
    [anon_sym_xmlport] = ACTIONS(2388),
    [anon_sym_XMLPORT] = ACTIONS(2388),
    [anon_sym_Xmlport] = ACTIONS(2388),
    [anon_sym_XMLport] = ACTIONS(2388),
    [anon_sym_XMLPort] = ACTIONS(2388),
    [anon_sym_XmlPort] = ACTIONS(2388),
    [anon_sym_enum] = ACTIONS(2388),
    [anon_sym_ENUM] = ACTIONS(2388),
    [anon_sym_Enum] = ACTIONS(2388),
    [anon_sym_eNUM] = ACTIONS(2388),
    [anon_sym_eNum] = ACTIONS(2388),
    [anon_sym_ENum] = ACTIONS(2388),
    [sym_quoted_identifier] = ACTIONS(2390),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2390),
    [sym_integer] = ACTIONS(2388),
    [sym_continue_as_identifier] = ACTIONS(2390),
    [sym_preproc_open] = ACTIONS(2390),
    [sym_preproc_close] = ACTIONS(2390),
  },
  [STATE(1498)] = {
    [sym_identifier] = ACTIONS(2539),
    [anon_sym_SEMI] = ACTIONS(2541),
    [anon_sym_DOT] = ACTIONS(2539),
    [anon_sym_EQ] = ACTIONS(2541),
    [anon_sym_COMMA] = ACTIONS(2541),
    [anon_sym_COLON] = ACTIONS(2539),
    [anon_sym_DASH] = ACTIONS(2539),
    [aux_sym_boolean_token1] = ACTIONS(2539),
    [aux_sym_boolean_token2] = ACTIONS(2539),
    [sym_decimal] = ACTIONS(2539),
    [anon_sym_LPAREN] = ACTIONS(2541),
    [anon_sym_DOT_DOT] = ACTIONS(2541),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2539),
    [anon_sym_STAR] = ACTIONS(2539),
    [anon_sym_LBRACK] = ACTIONS(2541),
    [aux_sym_record_type_token1] = ACTIONS(2539),
    [aux_sym_basic_type_token21] = ACTIONS(2539),
    [aux_sym_basic_type_token22] = ACTIONS(2539),
    [aux_sym_basic_type_token48] = ACTIONS(2539),
    [anon_sym_POUNDif] = ACTIONS(2541),
    [anon_sym_POUNDIF] = ACTIONS(2541),
    [anon_sym_POUNDIf] = ACTIONS(2541),
    [anon_sym_not] = ACTIONS(2539),
    [anon_sym_NOT] = ACTIONS(2539),
    [anon_sym_Not] = ACTIONS(2539),
    [anon_sym_POUNDelif] = ACTIONS(2541),
    [anon_sym_POUNDELIF] = ACTIONS(2541),
    [anon_sym_POUNDElif] = ACTIONS(2541),
    [anon_sym_POUNDelse] = ACTIONS(2541),
    [anon_sym_POUNDELSE] = ACTIONS(2541),
    [anon_sym_POUNDElse] = ACTIONS(2541),
    [anon_sym_POUNDendif] = ACTIONS(2541),
    [anon_sym_POUNDENDIF] = ACTIONS(2541),
    [anon_sym_POUNDEndif] = ACTIONS(2541),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2541),
    [aux_sym__expression_token1] = ACTIONS(2541),
    [aux_sym__expression_token2] = ACTIONS(2541),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2539),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2539),
    [anon_sym_SLASH] = ACTIONS(2539),
    [anon_sym_div] = ACTIONS(2539),
    [anon_sym_DIV] = ACTIONS(2539),
    [anon_sym_Div] = ACTIONS(2539),
    [anon_sym_mod] = ACTIONS(2539),
    [anon_sym_MOD] = ACTIONS(2539),
    [anon_sym_Mod] = ACTIONS(2539),
    [anon_sym_PLUS] = ACTIONS(2539),
    [anon_sym_GT_EQ] = ACTIONS(2541),
    [anon_sym_LT_EQ] = ACTIONS(2541),
    [anon_sym_GT] = ACTIONS(2539),
    [anon_sym_LT] = ACTIONS(2539),
    [anon_sym_LT_GT] = ACTIONS(2541),
    [anon_sym_and] = ACTIONS(2539),
    [anon_sym_AND] = ACTIONS(2539),
    [anon_sym_And] = ACTIONS(2539),
    [anon_sym_or] = ACTIONS(2539),
    [anon_sym_OR] = ACTIONS(2539),
    [anon_sym_Or] = ACTIONS(2539),
    [anon_sym_xor] = ACTIONS(2539),
    [anon_sym_XOR] = ACTIONS(2539),
    [anon_sym_Xor] = ACTIONS(2539),
    [anon_sym_QMARK] = ACTIONS(2541),
    [sym_datetime_literal] = ACTIONS(2541),
    [sym_date_literal] = ACTIONS(2539),
    [sym_time_literal] = ACTIONS(2539),
    [sym_biginteger_literal] = ACTIONS(2541),
    [anon_sym_else] = ACTIONS(2539),
    [anon_sym_ELSE] = ACTIONS(2539),
    [anon_sym_Else] = ACTIONS(2539),
    [anon_sym_in] = ACTIONS(2539),
    [anon_sym_IN] = ACTIONS(2539),
    [anon_sym_In] = ACTIONS(2539),
    [sym_page_keyword] = ACTIONS(2539),
    [anon_sym_codeunit] = ACTIONS(2539),
    [anon_sym_CODEUNIT] = ACTIONS(2539),
    [anon_sym_Codeunit] = ACTIONS(2539),
    [anon_sym_CodeUnit] = ACTIONS(2539),
    [anon_sym_COdeunit] = ACTIONS(2539),
    [anon_sym_codeUnit] = ACTIONS(2539),
    [sym_report_keyword] = ACTIONS(2539),
    [sym_query_keyword] = ACTIONS(2539),
    [anon_sym_xmlport] = ACTIONS(2539),
    [anon_sym_XMLPORT] = ACTIONS(2539),
    [anon_sym_Xmlport] = ACTIONS(2539),
    [anon_sym_XMLport] = ACTIONS(2539),
    [anon_sym_XMLPort] = ACTIONS(2539),
    [anon_sym_XmlPort] = ACTIONS(2539),
    [anon_sym_enum] = ACTIONS(2539),
    [anon_sym_ENUM] = ACTIONS(2539),
    [anon_sym_Enum] = ACTIONS(2539),
    [anon_sym_eNUM] = ACTIONS(2539),
    [anon_sym_eNum] = ACTIONS(2539),
    [anon_sym_ENum] = ACTIONS(2539),
    [sym_quoted_identifier] = ACTIONS(2541),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2541),
    [sym_integer] = ACTIONS(2539),
    [sym_continue_as_identifier] = ACTIONS(2541),
    [sym_preproc_open] = ACTIONS(2541),
    [sym_preproc_close] = ACTIONS(2541),
  },
  [STATE(1499)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2392),
    [anon_sym_SEMI] = ACTIONS(2394),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(3710),
    [aux_sym_boolean_token1] = ACTIONS(2392),
    [aux_sym_boolean_token2] = ACTIONS(2392),
    [sym_decimal] = ACTIONS(2392),
    [anon_sym_LPAREN] = ACTIONS(2394),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2392),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2392),
    [aux_sym_basic_type_token21] = ACTIONS(2392),
    [aux_sym_basic_type_token22] = ACTIONS(2392),
    [aux_sym_basic_type_token48] = ACTIONS(2392),
    [anon_sym_POUNDif] = ACTIONS(2394),
    [anon_sym_POUNDIF] = ACTIONS(2394),
    [anon_sym_POUNDIf] = ACTIONS(2394),
    [anon_sym_not] = ACTIONS(2392),
    [anon_sym_NOT] = ACTIONS(2392),
    [anon_sym_Not] = ACTIONS(2392),
    [anon_sym_POUNDelif] = ACTIONS(2394),
    [anon_sym_POUNDELIF] = ACTIONS(2394),
    [anon_sym_POUNDElif] = ACTIONS(2394),
    [anon_sym_POUNDelse] = ACTIONS(2394),
    [anon_sym_POUNDELSE] = ACTIONS(2394),
    [anon_sym_POUNDElse] = ACTIONS(2394),
    [anon_sym_POUNDendif] = ACTIONS(2394),
    [anon_sym_POUNDENDIF] = ACTIONS(2394),
    [anon_sym_POUNDEndif] = ACTIONS(2394),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3764),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2392),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2392),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(3736),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3740),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(3766),
    [anon_sym_OR] = ACTIONS(3768),
    [anon_sym_Or] = ACTIONS(3770),
    [anon_sym_xor] = ACTIONS(3772),
    [anon_sym_XOR] = ACTIONS(3774),
    [anon_sym_Xor] = ACTIONS(3776),
    [anon_sym_QMARK] = ACTIONS(3778),
    [sym_datetime_literal] = ACTIONS(2394),
    [sym_date_literal] = ACTIONS(2392),
    [sym_time_literal] = ACTIONS(2392),
    [sym_biginteger_literal] = ACTIONS(2394),
    [anon_sym_else] = ACTIONS(2392),
    [anon_sym_ELSE] = ACTIONS(2392),
    [anon_sym_Else] = ACTIONS(2392),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2392),
    [anon_sym_codeunit] = ACTIONS(2392),
    [anon_sym_CODEUNIT] = ACTIONS(2392),
    [anon_sym_Codeunit] = ACTIONS(2392),
    [anon_sym_CodeUnit] = ACTIONS(2392),
    [anon_sym_COdeunit] = ACTIONS(2392),
    [anon_sym_codeUnit] = ACTIONS(2392),
    [sym_report_keyword] = ACTIONS(2392),
    [sym_query_keyword] = ACTIONS(2392),
    [anon_sym_xmlport] = ACTIONS(2392),
    [anon_sym_XMLPORT] = ACTIONS(2392),
    [anon_sym_Xmlport] = ACTIONS(2392),
    [anon_sym_XMLport] = ACTIONS(2392),
    [anon_sym_XMLPort] = ACTIONS(2392),
    [anon_sym_XmlPort] = ACTIONS(2392),
    [anon_sym_enum] = ACTIONS(2392),
    [anon_sym_ENUM] = ACTIONS(2392),
    [anon_sym_Enum] = ACTIONS(2392),
    [anon_sym_eNUM] = ACTIONS(2392),
    [anon_sym_eNum] = ACTIONS(2392),
    [anon_sym_ENum] = ACTIONS(2392),
    [sym_quoted_identifier] = ACTIONS(2394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2394),
    [sym_integer] = ACTIONS(2392),
    [sym_continue_as_identifier] = ACTIONS(2394),
    [sym_preproc_open] = ACTIONS(2394),
    [sym_preproc_close] = ACTIONS(2394),
  },
  [STATE(1500)] = {
    [sym_identifier] = ACTIONS(2613),
    [anon_sym_SEMI] = ACTIONS(2615),
    [anon_sym_DOT] = ACTIONS(2613),
    [anon_sym_EQ] = ACTIONS(2615),
    [anon_sym_COMMA] = ACTIONS(2615),
    [anon_sym_COLON] = ACTIONS(2613),
    [anon_sym_DASH] = ACTIONS(2613),
    [aux_sym_boolean_token1] = ACTIONS(2613),
    [aux_sym_boolean_token2] = ACTIONS(2613),
    [sym_decimal] = ACTIONS(2613),
    [anon_sym_LPAREN] = ACTIONS(2615),
    [anon_sym_DOT_DOT] = ACTIONS(2615),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2613),
    [anon_sym_STAR] = ACTIONS(2613),
    [anon_sym_LBRACK] = ACTIONS(4101),
    [aux_sym_record_type_token1] = ACTIONS(2613),
    [aux_sym_basic_type_token21] = ACTIONS(2613),
    [aux_sym_basic_type_token22] = ACTIONS(2613),
    [aux_sym_basic_type_token48] = ACTIONS(2613),
    [anon_sym_POUNDif] = ACTIONS(2615),
    [anon_sym_POUNDIF] = ACTIONS(2615),
    [anon_sym_POUNDIf] = ACTIONS(2615),
    [anon_sym_not] = ACTIONS(2613),
    [anon_sym_NOT] = ACTIONS(2613),
    [anon_sym_Not] = ACTIONS(2613),
    [anon_sym_POUNDelif] = ACTIONS(2615),
    [anon_sym_POUNDELIF] = ACTIONS(2615),
    [anon_sym_POUNDElif] = ACTIONS(2615),
    [anon_sym_POUNDelse] = ACTIONS(2615),
    [anon_sym_POUNDELSE] = ACTIONS(2615),
    [anon_sym_POUNDElse] = ACTIONS(2615),
    [anon_sym_POUNDendif] = ACTIONS(2615),
    [anon_sym_POUNDENDIF] = ACTIONS(2615),
    [anon_sym_POUNDEndif] = ACTIONS(2615),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2615),
    [aux_sym__expression_token1] = ACTIONS(2615),
    [aux_sym__expression_token2] = ACTIONS(2615),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2613),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2613),
    [anon_sym_SLASH] = ACTIONS(2613),
    [anon_sym_div] = ACTIONS(2613),
    [anon_sym_DIV] = ACTIONS(2613),
    [anon_sym_Div] = ACTIONS(2613),
    [anon_sym_mod] = ACTIONS(2613),
    [anon_sym_MOD] = ACTIONS(2613),
    [anon_sym_Mod] = ACTIONS(2613),
    [anon_sym_PLUS] = ACTIONS(2613),
    [anon_sym_GT_EQ] = ACTIONS(2615),
    [anon_sym_LT_EQ] = ACTIONS(2615),
    [anon_sym_GT] = ACTIONS(2613),
    [anon_sym_LT] = ACTIONS(2613),
    [anon_sym_LT_GT] = ACTIONS(2615),
    [anon_sym_and] = ACTIONS(2613),
    [anon_sym_AND] = ACTIONS(2613),
    [anon_sym_And] = ACTIONS(2613),
    [anon_sym_or] = ACTIONS(2613),
    [anon_sym_OR] = ACTIONS(2613),
    [anon_sym_Or] = ACTIONS(2613),
    [anon_sym_xor] = ACTIONS(2613),
    [anon_sym_XOR] = ACTIONS(2613),
    [anon_sym_Xor] = ACTIONS(2613),
    [anon_sym_QMARK] = ACTIONS(2615),
    [sym_datetime_literal] = ACTIONS(2615),
    [sym_date_literal] = ACTIONS(2613),
    [sym_time_literal] = ACTIONS(2613),
    [sym_biginteger_literal] = ACTIONS(2615),
    [anon_sym_else] = ACTIONS(2613),
    [anon_sym_ELSE] = ACTIONS(2613),
    [anon_sym_Else] = ACTIONS(2613),
    [anon_sym_in] = ACTIONS(2613),
    [anon_sym_IN] = ACTIONS(2613),
    [anon_sym_In] = ACTIONS(2613),
    [sym_page_keyword] = ACTIONS(2613),
    [anon_sym_codeunit] = ACTIONS(2613),
    [anon_sym_CODEUNIT] = ACTIONS(2613),
    [anon_sym_Codeunit] = ACTIONS(2613),
    [anon_sym_CodeUnit] = ACTIONS(2613),
    [anon_sym_COdeunit] = ACTIONS(2613),
    [anon_sym_codeUnit] = ACTIONS(2613),
    [sym_report_keyword] = ACTIONS(2613),
    [sym_query_keyword] = ACTIONS(2613),
    [anon_sym_xmlport] = ACTIONS(2613),
    [anon_sym_XMLPORT] = ACTIONS(2613),
    [anon_sym_Xmlport] = ACTIONS(2613),
    [anon_sym_XMLport] = ACTIONS(2613),
    [anon_sym_XMLPort] = ACTIONS(2613),
    [anon_sym_XmlPort] = ACTIONS(2613),
    [anon_sym_enum] = ACTIONS(2613),
    [anon_sym_ENUM] = ACTIONS(2613),
    [anon_sym_Enum] = ACTIONS(2613),
    [anon_sym_eNUM] = ACTIONS(2613),
    [anon_sym_eNum] = ACTIONS(2613),
    [anon_sym_ENum] = ACTIONS(2613),
    [sym_quoted_identifier] = ACTIONS(2615),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2615),
    [sym_integer] = ACTIONS(2613),
    [sym_continue_as_identifier] = ACTIONS(2615),
    [sym_preproc_open] = ACTIONS(2615),
    [sym_preproc_close] = ACTIONS(2615),
  },
  [STATE(1501)] = {
    [sym_identifier] = ACTIONS(2619),
    [anon_sym_SEMI] = ACTIONS(2621),
    [anon_sym_DOT] = ACTIONS(2619),
    [anon_sym_EQ] = ACTIONS(2621),
    [anon_sym_COMMA] = ACTIONS(2621),
    [anon_sym_COLON] = ACTIONS(2619),
    [anon_sym_DASH] = ACTIONS(2619),
    [aux_sym_boolean_token1] = ACTIONS(2619),
    [aux_sym_boolean_token2] = ACTIONS(2619),
    [sym_decimal] = ACTIONS(2619),
    [anon_sym_LPAREN] = ACTIONS(2621),
    [anon_sym_DOT_DOT] = ACTIONS(2621),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2619),
    [anon_sym_STAR] = ACTIONS(2619),
    [anon_sym_LBRACK] = ACTIONS(4103),
    [aux_sym_record_type_token1] = ACTIONS(2619),
    [aux_sym_basic_type_token21] = ACTIONS(2619),
    [aux_sym_basic_type_token22] = ACTIONS(2619),
    [aux_sym_basic_type_token48] = ACTIONS(2619),
    [anon_sym_POUNDif] = ACTIONS(2621),
    [anon_sym_POUNDIF] = ACTIONS(2621),
    [anon_sym_POUNDIf] = ACTIONS(2621),
    [anon_sym_not] = ACTIONS(2619),
    [anon_sym_NOT] = ACTIONS(2619),
    [anon_sym_Not] = ACTIONS(2619),
    [anon_sym_POUNDelif] = ACTIONS(2621),
    [anon_sym_POUNDELIF] = ACTIONS(2621),
    [anon_sym_POUNDElif] = ACTIONS(2621),
    [anon_sym_POUNDelse] = ACTIONS(2621),
    [anon_sym_POUNDELSE] = ACTIONS(2621),
    [anon_sym_POUNDElse] = ACTIONS(2621),
    [anon_sym_POUNDendif] = ACTIONS(2621),
    [anon_sym_POUNDENDIF] = ACTIONS(2621),
    [anon_sym_POUNDEndif] = ACTIONS(2621),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2621),
    [aux_sym__expression_token1] = ACTIONS(2621),
    [aux_sym__expression_token2] = ACTIONS(2621),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2619),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2619),
    [anon_sym_SLASH] = ACTIONS(2619),
    [anon_sym_div] = ACTIONS(2619),
    [anon_sym_DIV] = ACTIONS(2619),
    [anon_sym_Div] = ACTIONS(2619),
    [anon_sym_mod] = ACTIONS(2619),
    [anon_sym_MOD] = ACTIONS(2619),
    [anon_sym_Mod] = ACTIONS(2619),
    [anon_sym_PLUS] = ACTIONS(2619),
    [anon_sym_GT_EQ] = ACTIONS(2621),
    [anon_sym_LT_EQ] = ACTIONS(2621),
    [anon_sym_GT] = ACTIONS(2619),
    [anon_sym_LT] = ACTIONS(2619),
    [anon_sym_LT_GT] = ACTIONS(2621),
    [anon_sym_and] = ACTIONS(2619),
    [anon_sym_AND] = ACTIONS(2619),
    [anon_sym_And] = ACTIONS(2619),
    [anon_sym_or] = ACTIONS(2619),
    [anon_sym_OR] = ACTIONS(2619),
    [anon_sym_Or] = ACTIONS(2619),
    [anon_sym_xor] = ACTIONS(2619),
    [anon_sym_XOR] = ACTIONS(2619),
    [anon_sym_Xor] = ACTIONS(2619),
    [anon_sym_QMARK] = ACTIONS(2621),
    [sym_datetime_literal] = ACTIONS(2621),
    [sym_date_literal] = ACTIONS(2619),
    [sym_time_literal] = ACTIONS(2619),
    [sym_biginteger_literal] = ACTIONS(2621),
    [anon_sym_else] = ACTIONS(2619),
    [anon_sym_ELSE] = ACTIONS(2619),
    [anon_sym_Else] = ACTIONS(2619),
    [anon_sym_in] = ACTIONS(2619),
    [anon_sym_IN] = ACTIONS(2619),
    [anon_sym_In] = ACTIONS(2619),
    [sym_page_keyword] = ACTIONS(2619),
    [anon_sym_codeunit] = ACTIONS(2619),
    [anon_sym_CODEUNIT] = ACTIONS(2619),
    [anon_sym_Codeunit] = ACTIONS(2619),
    [anon_sym_CodeUnit] = ACTIONS(2619),
    [anon_sym_COdeunit] = ACTIONS(2619),
    [anon_sym_codeUnit] = ACTIONS(2619),
    [sym_report_keyword] = ACTIONS(2619),
    [sym_query_keyword] = ACTIONS(2619),
    [anon_sym_xmlport] = ACTIONS(2619),
    [anon_sym_XMLPORT] = ACTIONS(2619),
    [anon_sym_Xmlport] = ACTIONS(2619),
    [anon_sym_XMLport] = ACTIONS(2619),
    [anon_sym_XMLPort] = ACTIONS(2619),
    [anon_sym_XmlPort] = ACTIONS(2619),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_ENUM] = ACTIONS(2619),
    [anon_sym_Enum] = ACTIONS(2619),
    [anon_sym_eNUM] = ACTIONS(2619),
    [anon_sym_eNum] = ACTIONS(2619),
    [anon_sym_ENum] = ACTIONS(2619),
    [sym_quoted_identifier] = ACTIONS(2621),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2621),
    [sym_integer] = ACTIONS(2619),
    [sym_continue_as_identifier] = ACTIONS(2621),
    [sym_preproc_open] = ACTIONS(2621),
    [sym_preproc_close] = ACTIONS(2621),
  },
  [STATE(1502)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_COMMA] = ACTIONS(2587),
    [anon_sym_COLON] = ACTIONS(2585),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [anon_sym_POUNDif] = ACTIONS(2587),
    [anon_sym_POUNDIF] = ACTIONS(2587),
    [anon_sym_POUNDIf] = ACTIONS(2587),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [anon_sym_POUNDelif] = ACTIONS(2587),
    [anon_sym_POUNDELIF] = ACTIONS(2587),
    [anon_sym_POUNDElif] = ACTIONS(2587),
    [anon_sym_POUNDelse] = ACTIONS(2587),
    [anon_sym_POUNDELSE] = ACTIONS(2587),
    [anon_sym_POUNDElse] = ACTIONS(2587),
    [anon_sym_POUNDendif] = ACTIONS(2587),
    [anon_sym_POUNDENDIF] = ACTIONS(2587),
    [anon_sym_POUNDEndif] = ACTIONS(2587),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2587),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_else] = ACTIONS(2585),
    [anon_sym_ELSE] = ACTIONS(2585),
    [anon_sym_Else] = ACTIONS(2585),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_open] = ACTIONS(2587),
    [sym_preproc_close] = ACTIONS(2587),
  },
  [STATE(1503)] = {
    [sym_boolean] = STATE(6346),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(8837),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1387),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7706),
    [sym_keyword_as_identifier] = STATE(7706),
    [sym_identifier] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDelif] = ACTIONS(4105),
    [anon_sym_POUNDELIF] = ACTIONS(4105),
    [anon_sym_POUNDElif] = ACTIONS(4105),
    [anon_sym_POUNDelse] = ACTIONS(4105),
    [anon_sym_POUNDELSE] = ACTIONS(4105),
    [anon_sym_POUNDElse] = ACTIONS(4105),
    [anon_sym_POUNDendif] = ACTIONS(4105),
    [anon_sym_POUNDENDIF] = ACTIONS(4105),
    [anon_sym_POUNDEndif] = ACTIONS(4105),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(4105),
  },
  [STATE(1504)] = {
    [sym_boolean] = STATE(6346),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(9300),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym_preproc_conditional_permissions] = STATE(6836),
    [sym_tabledata_permission] = STATE(6826),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1370),
    [sym_preproc_endif] = STATE(6843),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4852),
    [sym_xmlport_keyword] = STATE(4852),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7706),
    [sym_keyword_as_identifier] = STATE(7706),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(6836),
    [sym_identifier] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token1] = ACTIONS(3064),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3066),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDendif] = ACTIONS(3439),
    [anon_sym_POUNDENDIF] = ACTIONS(3439),
    [anon_sym_POUNDEndif] = ACTIONS(3439),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_table_keyword] = ACTIONS(3064),
    [sym_page_keyword] = ACTIONS(3080),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(3080),
    [sym_query_keyword] = ACTIONS(3080),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(3439),
  },
  [STATE(1505)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_COMMA] = ACTIONS(2587),
    [anon_sym_COLON] = ACTIONS(2585),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [anon_sym_POUNDif] = ACTIONS(2587),
    [anon_sym_POUNDIF] = ACTIONS(2587),
    [anon_sym_POUNDIf] = ACTIONS(2587),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [anon_sym_POUNDelif] = ACTIONS(2587),
    [anon_sym_POUNDELIF] = ACTIONS(2587),
    [anon_sym_POUNDElif] = ACTIONS(2587),
    [anon_sym_POUNDelse] = ACTIONS(2587),
    [anon_sym_POUNDELSE] = ACTIONS(2587),
    [anon_sym_POUNDElse] = ACTIONS(2587),
    [anon_sym_POUNDendif] = ACTIONS(2587),
    [anon_sym_POUNDENDIF] = ACTIONS(2587),
    [anon_sym_POUNDEndif] = ACTIONS(2587),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2587),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_else] = ACTIONS(2585),
    [anon_sym_ELSE] = ACTIONS(2585),
    [anon_sym_Else] = ACTIONS(2585),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_open] = ACTIONS(2587),
    [sym_preproc_close] = ACTIONS(2587),
  },
  [STATE(1506)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_COMMA] = ACTIONS(2587),
    [anon_sym_COLON] = ACTIONS(2585),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [anon_sym_POUNDif] = ACTIONS(2587),
    [anon_sym_POUNDIF] = ACTIONS(2587),
    [anon_sym_POUNDIf] = ACTIONS(2587),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [anon_sym_POUNDelif] = ACTIONS(2587),
    [anon_sym_POUNDELIF] = ACTIONS(2587),
    [anon_sym_POUNDElif] = ACTIONS(2587),
    [anon_sym_POUNDelse] = ACTIONS(2587),
    [anon_sym_POUNDELSE] = ACTIONS(2587),
    [anon_sym_POUNDElse] = ACTIONS(2587),
    [anon_sym_POUNDendif] = ACTIONS(2587),
    [anon_sym_POUNDENDIF] = ACTIONS(2587),
    [anon_sym_POUNDEndif] = ACTIONS(2587),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2587),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_else] = ACTIONS(2585),
    [anon_sym_ELSE] = ACTIONS(2585),
    [anon_sym_Else] = ACTIONS(2585),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_open] = ACTIONS(2587),
    [sym_preproc_close] = ACTIONS(2587),
  },
  [STATE(1507)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_SEMI] = ACTIONS(2591),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_COMMA] = ACTIONS(2591),
    [anon_sym_COLON] = ACTIONS(2589),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [anon_sym_POUNDif] = ACTIONS(2591),
    [anon_sym_POUNDIF] = ACTIONS(2591),
    [anon_sym_POUNDIf] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [anon_sym_POUNDelif] = ACTIONS(2591),
    [anon_sym_POUNDELIF] = ACTIONS(2591),
    [anon_sym_POUNDElif] = ACTIONS(2591),
    [anon_sym_POUNDelse] = ACTIONS(2591),
    [anon_sym_POUNDELSE] = ACTIONS(2591),
    [anon_sym_POUNDElse] = ACTIONS(2591),
    [anon_sym_POUNDendif] = ACTIONS(2591),
    [anon_sym_POUNDENDIF] = ACTIONS(2591),
    [anon_sym_POUNDEndif] = ACTIONS(2591),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2591),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_else] = ACTIONS(2589),
    [anon_sym_ELSE] = ACTIONS(2589),
    [anon_sym_Else] = ACTIONS(2589),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_open] = ACTIONS(2591),
    [sym_preproc_close] = ACTIONS(2591),
  },
  [STATE(1508)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_SEMI] = ACTIONS(2591),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_COMMA] = ACTIONS(2591),
    [anon_sym_COLON] = ACTIONS(2589),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [anon_sym_POUNDif] = ACTIONS(2591),
    [anon_sym_POUNDIF] = ACTIONS(2591),
    [anon_sym_POUNDIf] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [anon_sym_POUNDelif] = ACTIONS(2591),
    [anon_sym_POUNDELIF] = ACTIONS(2591),
    [anon_sym_POUNDElif] = ACTIONS(2591),
    [anon_sym_POUNDelse] = ACTIONS(2591),
    [anon_sym_POUNDELSE] = ACTIONS(2591),
    [anon_sym_POUNDElse] = ACTIONS(2591),
    [anon_sym_POUNDendif] = ACTIONS(2591),
    [anon_sym_POUNDENDIF] = ACTIONS(2591),
    [anon_sym_POUNDEndif] = ACTIONS(2591),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2591),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_else] = ACTIONS(2589),
    [anon_sym_ELSE] = ACTIONS(2589),
    [anon_sym_Else] = ACTIONS(2589),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_open] = ACTIONS(2591),
    [sym_preproc_close] = ACTIONS(2591),
  },
  [STATE(1509)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_SEMI] = ACTIONS(2591),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_COMMA] = ACTIONS(2591),
    [anon_sym_COLON] = ACTIONS(2589),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [anon_sym_POUNDif] = ACTIONS(2591),
    [anon_sym_POUNDIF] = ACTIONS(2591),
    [anon_sym_POUNDIf] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [anon_sym_POUNDelif] = ACTIONS(2591),
    [anon_sym_POUNDELIF] = ACTIONS(2591),
    [anon_sym_POUNDElif] = ACTIONS(2591),
    [anon_sym_POUNDelse] = ACTIONS(2591),
    [anon_sym_POUNDELSE] = ACTIONS(2591),
    [anon_sym_POUNDElse] = ACTIONS(2591),
    [anon_sym_POUNDendif] = ACTIONS(2591),
    [anon_sym_POUNDENDIF] = ACTIONS(2591),
    [anon_sym_POUNDEndif] = ACTIONS(2591),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2591),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_else] = ACTIONS(2589),
    [anon_sym_ELSE] = ACTIONS(2589),
    [anon_sym_Else] = ACTIONS(2589),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_open] = ACTIONS(2591),
    [sym_preproc_close] = ACTIONS(2591),
  },
  [STATE(1510)] = {
    [sym_identifier] = ACTIONS(2403),
    [anon_sym_SEMI] = ACTIONS(2405),
    [anon_sym_DOT] = ACTIONS(2403),
    [anon_sym_EQ] = ACTIONS(2405),
    [anon_sym_COMMA] = ACTIONS(2405),
    [anon_sym_COLON] = ACTIONS(2403),
    [anon_sym_DASH] = ACTIONS(2403),
    [aux_sym_boolean_token1] = ACTIONS(2403),
    [aux_sym_boolean_token2] = ACTIONS(2403),
    [sym_decimal] = ACTIONS(2403),
    [anon_sym_LPAREN] = ACTIONS(2405),
    [anon_sym_DOT_DOT] = ACTIONS(2405),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2403),
    [anon_sym_STAR] = ACTIONS(2403),
    [anon_sym_LBRACK] = ACTIONS(2405),
    [aux_sym_record_type_token1] = ACTIONS(2403),
    [aux_sym_basic_type_token21] = ACTIONS(2403),
    [aux_sym_basic_type_token22] = ACTIONS(2403),
    [aux_sym_basic_type_token48] = ACTIONS(2403),
    [anon_sym_POUNDif] = ACTIONS(2405),
    [anon_sym_POUNDIF] = ACTIONS(2405),
    [anon_sym_POUNDIf] = ACTIONS(2405),
    [anon_sym_not] = ACTIONS(2403),
    [anon_sym_NOT] = ACTIONS(2403),
    [anon_sym_Not] = ACTIONS(2403),
    [anon_sym_POUNDelif] = ACTIONS(2405),
    [anon_sym_POUNDELIF] = ACTIONS(2405),
    [anon_sym_POUNDElif] = ACTIONS(2405),
    [anon_sym_POUNDelse] = ACTIONS(2405),
    [anon_sym_POUNDELSE] = ACTIONS(2405),
    [anon_sym_POUNDElse] = ACTIONS(2405),
    [anon_sym_POUNDendif] = ACTIONS(2405),
    [anon_sym_POUNDENDIF] = ACTIONS(2405),
    [anon_sym_POUNDEndif] = ACTIONS(2405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2405),
    [aux_sym__expression_token1] = ACTIONS(2405),
    [aux_sym__expression_token2] = ACTIONS(2405),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2403),
    [anon_sym_SLASH] = ACTIONS(2403),
    [anon_sym_div] = ACTIONS(2403),
    [anon_sym_DIV] = ACTIONS(2403),
    [anon_sym_Div] = ACTIONS(2403),
    [anon_sym_mod] = ACTIONS(2403),
    [anon_sym_MOD] = ACTIONS(2403),
    [anon_sym_Mod] = ACTIONS(2403),
    [anon_sym_PLUS] = ACTIONS(2403),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_LT_GT] = ACTIONS(2405),
    [anon_sym_and] = ACTIONS(2403),
    [anon_sym_AND] = ACTIONS(2403),
    [anon_sym_And] = ACTIONS(2403),
    [anon_sym_or] = ACTIONS(2403),
    [anon_sym_OR] = ACTIONS(2403),
    [anon_sym_Or] = ACTIONS(2403),
    [anon_sym_xor] = ACTIONS(2403),
    [anon_sym_XOR] = ACTIONS(2403),
    [anon_sym_Xor] = ACTIONS(2403),
    [anon_sym_QMARK] = ACTIONS(2405),
    [sym_datetime_literal] = ACTIONS(2405),
    [sym_date_literal] = ACTIONS(2403),
    [sym_time_literal] = ACTIONS(2403),
    [sym_biginteger_literal] = ACTIONS(2405),
    [anon_sym_else] = ACTIONS(2403),
    [anon_sym_ELSE] = ACTIONS(2403),
    [anon_sym_Else] = ACTIONS(2403),
    [anon_sym_in] = ACTIONS(2403),
    [anon_sym_IN] = ACTIONS(2403),
    [anon_sym_In] = ACTIONS(2403),
    [sym_page_keyword] = ACTIONS(2403),
    [anon_sym_codeunit] = ACTIONS(2403),
    [anon_sym_CODEUNIT] = ACTIONS(2403),
    [anon_sym_Codeunit] = ACTIONS(2403),
    [anon_sym_CodeUnit] = ACTIONS(2403),
    [anon_sym_COdeunit] = ACTIONS(2403),
    [anon_sym_codeUnit] = ACTIONS(2403),
    [sym_report_keyword] = ACTIONS(2403),
    [sym_query_keyword] = ACTIONS(2403),
    [anon_sym_xmlport] = ACTIONS(2403),
    [anon_sym_XMLPORT] = ACTIONS(2403),
    [anon_sym_Xmlport] = ACTIONS(2403),
    [anon_sym_XMLport] = ACTIONS(2403),
    [anon_sym_XMLPort] = ACTIONS(2403),
    [anon_sym_XmlPort] = ACTIONS(2403),
    [anon_sym_enum] = ACTIONS(2403),
    [anon_sym_ENUM] = ACTIONS(2403),
    [anon_sym_Enum] = ACTIONS(2403),
    [anon_sym_eNUM] = ACTIONS(2403),
    [anon_sym_eNum] = ACTIONS(2403),
    [anon_sym_ENum] = ACTIONS(2403),
    [sym_quoted_identifier] = ACTIONS(2405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2405),
    [sym_integer] = ACTIONS(2403),
    [sym_continue_as_identifier] = ACTIONS(2405),
    [sym_preproc_open] = ACTIONS(2405),
    [sym_preproc_close] = ACTIONS(2405),
  },
  [STATE(1511)] = {
    [sym_identifier] = ACTIONS(2529),
    [anon_sym_SEMI] = ACTIONS(2531),
    [anon_sym_DOT] = ACTIONS(2529),
    [anon_sym_EQ] = ACTIONS(2531),
    [anon_sym_COMMA] = ACTIONS(2531),
    [anon_sym_COLON] = ACTIONS(2529),
    [anon_sym_DASH] = ACTIONS(2529),
    [aux_sym_boolean_token1] = ACTIONS(2529),
    [aux_sym_boolean_token2] = ACTIONS(2529),
    [sym_decimal] = ACTIONS(2529),
    [anon_sym_LPAREN] = ACTIONS(2531),
    [anon_sym_DOT_DOT] = ACTIONS(2531),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2529),
    [anon_sym_STAR] = ACTIONS(2529),
    [anon_sym_LBRACK] = ACTIONS(2531),
    [aux_sym_record_type_token1] = ACTIONS(2529),
    [aux_sym_basic_type_token21] = ACTIONS(2529),
    [aux_sym_basic_type_token22] = ACTIONS(2529),
    [aux_sym_basic_type_token48] = ACTIONS(2529),
    [anon_sym_POUNDif] = ACTIONS(2531),
    [anon_sym_POUNDIF] = ACTIONS(2531),
    [anon_sym_POUNDIf] = ACTIONS(2531),
    [anon_sym_not] = ACTIONS(2529),
    [anon_sym_NOT] = ACTIONS(2529),
    [anon_sym_Not] = ACTIONS(2529),
    [anon_sym_POUNDelif] = ACTIONS(2531),
    [anon_sym_POUNDELIF] = ACTIONS(2531),
    [anon_sym_POUNDElif] = ACTIONS(2531),
    [anon_sym_POUNDelse] = ACTIONS(2531),
    [anon_sym_POUNDELSE] = ACTIONS(2531),
    [anon_sym_POUNDElse] = ACTIONS(2531),
    [anon_sym_POUNDendif] = ACTIONS(2531),
    [anon_sym_POUNDENDIF] = ACTIONS(2531),
    [anon_sym_POUNDEndif] = ACTIONS(2531),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2531),
    [aux_sym__expression_token1] = ACTIONS(2531),
    [aux_sym__expression_token2] = ACTIONS(2531),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2529),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2529),
    [anon_sym_SLASH] = ACTIONS(2529),
    [anon_sym_div] = ACTIONS(2529),
    [anon_sym_DIV] = ACTIONS(2529),
    [anon_sym_Div] = ACTIONS(2529),
    [anon_sym_mod] = ACTIONS(2529),
    [anon_sym_MOD] = ACTIONS(2529),
    [anon_sym_Mod] = ACTIONS(2529),
    [anon_sym_PLUS] = ACTIONS(2529),
    [anon_sym_GT_EQ] = ACTIONS(2531),
    [anon_sym_LT_EQ] = ACTIONS(2531),
    [anon_sym_GT] = ACTIONS(2529),
    [anon_sym_LT] = ACTIONS(2529),
    [anon_sym_LT_GT] = ACTIONS(2531),
    [anon_sym_and] = ACTIONS(2529),
    [anon_sym_AND] = ACTIONS(2529),
    [anon_sym_And] = ACTIONS(2529),
    [anon_sym_or] = ACTIONS(2529),
    [anon_sym_OR] = ACTIONS(2529),
    [anon_sym_Or] = ACTIONS(2529),
    [anon_sym_xor] = ACTIONS(2529),
    [anon_sym_XOR] = ACTIONS(2529),
    [anon_sym_Xor] = ACTIONS(2529),
    [anon_sym_QMARK] = ACTIONS(2531),
    [sym_datetime_literal] = ACTIONS(2531),
    [sym_date_literal] = ACTIONS(2529),
    [sym_time_literal] = ACTIONS(2529),
    [sym_biginteger_literal] = ACTIONS(2531),
    [anon_sym_else] = ACTIONS(2529),
    [anon_sym_ELSE] = ACTIONS(2529),
    [anon_sym_Else] = ACTIONS(2529),
    [anon_sym_in] = ACTIONS(2529),
    [anon_sym_IN] = ACTIONS(2529),
    [anon_sym_In] = ACTIONS(2529),
    [sym_page_keyword] = ACTIONS(2529),
    [anon_sym_codeunit] = ACTIONS(2529),
    [anon_sym_CODEUNIT] = ACTIONS(2529),
    [anon_sym_Codeunit] = ACTIONS(2529),
    [anon_sym_CodeUnit] = ACTIONS(2529),
    [anon_sym_COdeunit] = ACTIONS(2529),
    [anon_sym_codeUnit] = ACTIONS(2529),
    [sym_report_keyword] = ACTIONS(2529),
    [sym_query_keyword] = ACTIONS(2529),
    [anon_sym_xmlport] = ACTIONS(2529),
    [anon_sym_XMLPORT] = ACTIONS(2529),
    [anon_sym_Xmlport] = ACTIONS(2529),
    [anon_sym_XMLport] = ACTIONS(2529),
    [anon_sym_XMLPort] = ACTIONS(2529),
    [anon_sym_XmlPort] = ACTIONS(2529),
    [anon_sym_enum] = ACTIONS(2529),
    [anon_sym_ENUM] = ACTIONS(2529),
    [anon_sym_Enum] = ACTIONS(2529),
    [anon_sym_eNUM] = ACTIONS(2529),
    [anon_sym_eNum] = ACTIONS(2529),
    [anon_sym_ENum] = ACTIONS(2529),
    [sym_quoted_identifier] = ACTIONS(2531),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2531),
    [sym_integer] = ACTIONS(2529),
    [sym_continue_as_identifier] = ACTIONS(2531),
    [sym_preproc_open] = ACTIONS(2531),
    [sym_preproc_close] = ACTIONS(2531),
  },
  [STATE(1512)] = {
    [sym_identifier] = ACTIONS(2649),
    [anon_sym_SEMI] = ACTIONS(2651),
    [anon_sym_DOT] = ACTIONS(2649),
    [anon_sym_EQ] = ACTIONS(2651),
    [anon_sym_COMMA] = ACTIONS(2651),
    [anon_sym_COLON] = ACTIONS(2649),
    [anon_sym_DASH] = ACTIONS(2649),
    [aux_sym_boolean_token1] = ACTIONS(2649),
    [aux_sym_boolean_token2] = ACTIONS(2649),
    [sym_decimal] = ACTIONS(2649),
    [anon_sym_LPAREN] = ACTIONS(2651),
    [anon_sym_DOT_DOT] = ACTIONS(2651),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2649),
    [anon_sym_STAR] = ACTIONS(2649),
    [anon_sym_LBRACK] = ACTIONS(2651),
    [aux_sym_record_type_token1] = ACTIONS(2649),
    [aux_sym_basic_type_token21] = ACTIONS(2649),
    [aux_sym_basic_type_token22] = ACTIONS(2649),
    [aux_sym_basic_type_token48] = ACTIONS(2649),
    [anon_sym_POUNDif] = ACTIONS(2651),
    [anon_sym_POUNDIF] = ACTIONS(2651),
    [anon_sym_POUNDIf] = ACTIONS(2651),
    [anon_sym_not] = ACTIONS(2649),
    [anon_sym_NOT] = ACTIONS(2649),
    [anon_sym_Not] = ACTIONS(2649),
    [anon_sym_POUNDelif] = ACTIONS(2651),
    [anon_sym_POUNDELIF] = ACTIONS(2651),
    [anon_sym_POUNDElif] = ACTIONS(2651),
    [anon_sym_POUNDelse] = ACTIONS(2651),
    [anon_sym_POUNDELSE] = ACTIONS(2651),
    [anon_sym_POUNDElse] = ACTIONS(2651),
    [anon_sym_POUNDendif] = ACTIONS(2651),
    [anon_sym_POUNDENDIF] = ACTIONS(2651),
    [anon_sym_POUNDEndif] = ACTIONS(2651),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2651),
    [aux_sym__expression_token1] = ACTIONS(2651),
    [aux_sym__expression_token2] = ACTIONS(2651),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2649),
    [anon_sym_SLASH] = ACTIONS(2649),
    [anon_sym_div] = ACTIONS(2649),
    [anon_sym_DIV] = ACTIONS(2649),
    [anon_sym_Div] = ACTIONS(2649),
    [anon_sym_mod] = ACTIONS(2649),
    [anon_sym_MOD] = ACTIONS(2649),
    [anon_sym_Mod] = ACTIONS(2649),
    [anon_sym_PLUS] = ACTIONS(2649),
    [anon_sym_GT_EQ] = ACTIONS(2651),
    [anon_sym_LT_EQ] = ACTIONS(2651),
    [anon_sym_GT] = ACTIONS(2649),
    [anon_sym_LT] = ACTIONS(2649),
    [anon_sym_LT_GT] = ACTIONS(2651),
    [anon_sym_and] = ACTIONS(2649),
    [anon_sym_AND] = ACTIONS(2649),
    [anon_sym_And] = ACTIONS(2649),
    [anon_sym_or] = ACTIONS(2649),
    [anon_sym_OR] = ACTIONS(2649),
    [anon_sym_Or] = ACTIONS(2649),
    [anon_sym_xor] = ACTIONS(2649),
    [anon_sym_XOR] = ACTIONS(2649),
    [anon_sym_Xor] = ACTIONS(2649),
    [anon_sym_QMARK] = ACTIONS(2651),
    [sym_datetime_literal] = ACTIONS(2651),
    [sym_date_literal] = ACTIONS(2649),
    [sym_time_literal] = ACTIONS(2649),
    [sym_biginteger_literal] = ACTIONS(2651),
    [anon_sym_else] = ACTIONS(2649),
    [anon_sym_ELSE] = ACTIONS(2649),
    [anon_sym_Else] = ACTIONS(2649),
    [anon_sym_in] = ACTIONS(2649),
    [anon_sym_IN] = ACTIONS(2649),
    [anon_sym_In] = ACTIONS(2649),
    [sym_page_keyword] = ACTIONS(2649),
    [anon_sym_codeunit] = ACTIONS(2649),
    [anon_sym_CODEUNIT] = ACTIONS(2649),
    [anon_sym_Codeunit] = ACTIONS(2649),
    [anon_sym_CodeUnit] = ACTIONS(2649),
    [anon_sym_COdeunit] = ACTIONS(2649),
    [anon_sym_codeUnit] = ACTIONS(2649),
    [sym_report_keyword] = ACTIONS(2649),
    [sym_query_keyword] = ACTIONS(2649),
    [anon_sym_xmlport] = ACTIONS(2649),
    [anon_sym_XMLPORT] = ACTIONS(2649),
    [anon_sym_Xmlport] = ACTIONS(2649),
    [anon_sym_XMLport] = ACTIONS(2649),
    [anon_sym_XMLPort] = ACTIONS(2649),
    [anon_sym_XmlPort] = ACTIONS(2649),
    [anon_sym_enum] = ACTIONS(2649),
    [anon_sym_ENUM] = ACTIONS(2649),
    [anon_sym_Enum] = ACTIONS(2649),
    [anon_sym_eNUM] = ACTIONS(2649),
    [anon_sym_eNum] = ACTIONS(2649),
    [anon_sym_ENum] = ACTIONS(2649),
    [sym_quoted_identifier] = ACTIONS(2651),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2651),
    [sym_integer] = ACTIONS(2649),
    [sym_continue_as_identifier] = ACTIONS(2651),
    [sym_preproc_open] = ACTIONS(2651),
    [sym_preproc_close] = ACTIONS(2651),
  },
  [STATE(1513)] = {
    [sym_identifier] = ACTIONS(2609),
    [anon_sym_SEMI] = ACTIONS(2611),
    [anon_sym_DOT] = ACTIONS(2609),
    [anon_sym_EQ] = ACTIONS(2611),
    [anon_sym_COMMA] = ACTIONS(2611),
    [anon_sym_COLON] = ACTIONS(2609),
    [anon_sym_DASH] = ACTIONS(2609),
    [aux_sym_boolean_token1] = ACTIONS(2609),
    [aux_sym_boolean_token2] = ACTIONS(2609),
    [sym_decimal] = ACTIONS(2609),
    [anon_sym_LPAREN] = ACTIONS(2611),
    [anon_sym_DOT_DOT] = ACTIONS(2611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2609),
    [anon_sym_STAR] = ACTIONS(2609),
    [anon_sym_LBRACK] = ACTIONS(2611),
    [aux_sym_record_type_token1] = ACTIONS(2609),
    [aux_sym_basic_type_token21] = ACTIONS(2609),
    [aux_sym_basic_type_token22] = ACTIONS(2609),
    [aux_sym_basic_type_token48] = ACTIONS(2609),
    [anon_sym_POUNDif] = ACTIONS(2611),
    [anon_sym_POUNDIF] = ACTIONS(2611),
    [anon_sym_POUNDIf] = ACTIONS(2611),
    [anon_sym_not] = ACTIONS(2609),
    [anon_sym_NOT] = ACTIONS(2609),
    [anon_sym_Not] = ACTIONS(2609),
    [anon_sym_POUNDelif] = ACTIONS(2611),
    [anon_sym_POUNDELIF] = ACTIONS(2611),
    [anon_sym_POUNDElif] = ACTIONS(2611),
    [anon_sym_POUNDelse] = ACTIONS(2611),
    [anon_sym_POUNDELSE] = ACTIONS(2611),
    [anon_sym_POUNDElse] = ACTIONS(2611),
    [anon_sym_POUNDendif] = ACTIONS(2611),
    [anon_sym_POUNDENDIF] = ACTIONS(2611),
    [anon_sym_POUNDEndif] = ACTIONS(2611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2611),
    [aux_sym__expression_token1] = ACTIONS(2611),
    [aux_sym__expression_token2] = ACTIONS(2611),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2609),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2609),
    [anon_sym_SLASH] = ACTIONS(2609),
    [anon_sym_div] = ACTIONS(2609),
    [anon_sym_DIV] = ACTIONS(2609),
    [anon_sym_Div] = ACTIONS(2609),
    [anon_sym_mod] = ACTIONS(2609),
    [anon_sym_MOD] = ACTIONS(2609),
    [anon_sym_Mod] = ACTIONS(2609),
    [anon_sym_PLUS] = ACTIONS(2609),
    [anon_sym_GT_EQ] = ACTIONS(2611),
    [anon_sym_LT_EQ] = ACTIONS(2611),
    [anon_sym_GT] = ACTIONS(2609),
    [anon_sym_LT] = ACTIONS(2609),
    [anon_sym_LT_GT] = ACTIONS(2611),
    [anon_sym_and] = ACTIONS(2609),
    [anon_sym_AND] = ACTIONS(2609),
    [anon_sym_And] = ACTIONS(2609),
    [anon_sym_or] = ACTIONS(2609),
    [anon_sym_OR] = ACTIONS(2609),
    [anon_sym_Or] = ACTIONS(2609),
    [anon_sym_xor] = ACTIONS(2609),
    [anon_sym_XOR] = ACTIONS(2609),
    [anon_sym_Xor] = ACTIONS(2609),
    [anon_sym_QMARK] = ACTIONS(2611),
    [sym_datetime_literal] = ACTIONS(2611),
    [sym_date_literal] = ACTIONS(2609),
    [sym_time_literal] = ACTIONS(2609),
    [sym_biginteger_literal] = ACTIONS(2611),
    [anon_sym_else] = ACTIONS(2609),
    [anon_sym_ELSE] = ACTIONS(2609),
    [anon_sym_Else] = ACTIONS(2609),
    [anon_sym_in] = ACTIONS(2609),
    [anon_sym_IN] = ACTIONS(2609),
    [anon_sym_In] = ACTIONS(2609),
    [sym_page_keyword] = ACTIONS(2609),
    [anon_sym_codeunit] = ACTIONS(2609),
    [anon_sym_CODEUNIT] = ACTIONS(2609),
    [anon_sym_Codeunit] = ACTIONS(2609),
    [anon_sym_CodeUnit] = ACTIONS(2609),
    [anon_sym_COdeunit] = ACTIONS(2609),
    [anon_sym_codeUnit] = ACTIONS(2609),
    [sym_report_keyword] = ACTIONS(2609),
    [sym_query_keyword] = ACTIONS(2609),
    [anon_sym_xmlport] = ACTIONS(2609),
    [anon_sym_XMLPORT] = ACTIONS(2609),
    [anon_sym_Xmlport] = ACTIONS(2609),
    [anon_sym_XMLport] = ACTIONS(2609),
    [anon_sym_XMLPort] = ACTIONS(2609),
    [anon_sym_XmlPort] = ACTIONS(2609),
    [anon_sym_enum] = ACTIONS(2609),
    [anon_sym_ENUM] = ACTIONS(2609),
    [anon_sym_Enum] = ACTIONS(2609),
    [anon_sym_eNUM] = ACTIONS(2609),
    [anon_sym_eNum] = ACTIONS(2609),
    [anon_sym_ENum] = ACTIONS(2609),
    [sym_quoted_identifier] = ACTIONS(2611),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2611),
    [sym_integer] = ACTIONS(2609),
    [sym_continue_as_identifier] = ACTIONS(2611),
    [sym_preproc_open] = ACTIONS(2611),
    [sym_preproc_close] = ACTIONS(2611),
  },
  [STATE(1514)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_SEMI] = ACTIONS(2428),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_COMMA] = ACTIONS(2428),
    [anon_sym_COLON] = ACTIONS(2426),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [anon_sym_POUNDif] = ACTIONS(2428),
    [anon_sym_POUNDIF] = ACTIONS(2428),
    [anon_sym_POUNDIf] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [anon_sym_POUNDelif] = ACTIONS(2428),
    [anon_sym_POUNDELIF] = ACTIONS(2428),
    [anon_sym_POUNDElif] = ACTIONS(2428),
    [anon_sym_POUNDelse] = ACTIONS(2428),
    [anon_sym_POUNDELSE] = ACTIONS(2428),
    [anon_sym_POUNDElse] = ACTIONS(2428),
    [anon_sym_POUNDendif] = ACTIONS(2428),
    [anon_sym_POUNDENDIF] = ACTIONS(2428),
    [anon_sym_POUNDEndif] = ACTIONS(2428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2428),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_else] = ACTIONS(2426),
    [anon_sym_ELSE] = ACTIONS(2426),
    [anon_sym_Else] = ACTIONS(2426),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_open] = ACTIONS(2428),
    [sym_preproc_close] = ACTIONS(2428),
  },
  [STATE(1515)] = {
    [sym_identifier] = ACTIONS(2633),
    [anon_sym_SEMI] = ACTIONS(2635),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_EQ] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [anon_sym_COLON] = ACTIONS(2633),
    [anon_sym_DASH] = ACTIONS(2633),
    [aux_sym_boolean_token1] = ACTIONS(2633),
    [aux_sym_boolean_token2] = ACTIONS(2633),
    [sym_decimal] = ACTIONS(2633),
    [anon_sym_LPAREN] = ACTIONS(2635),
    [anon_sym_DOT_DOT] = ACTIONS(2635),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2633),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [aux_sym_record_type_token1] = ACTIONS(2633),
    [aux_sym_basic_type_token21] = ACTIONS(2633),
    [aux_sym_basic_type_token22] = ACTIONS(2633),
    [aux_sym_basic_type_token48] = ACTIONS(2633),
    [anon_sym_POUNDif] = ACTIONS(2635),
    [anon_sym_POUNDIF] = ACTIONS(2635),
    [anon_sym_POUNDIf] = ACTIONS(2635),
    [anon_sym_not] = ACTIONS(2633),
    [anon_sym_NOT] = ACTIONS(2633),
    [anon_sym_Not] = ACTIONS(2633),
    [anon_sym_POUNDelif] = ACTIONS(2635),
    [anon_sym_POUNDELIF] = ACTIONS(2635),
    [anon_sym_POUNDElif] = ACTIONS(2635),
    [anon_sym_POUNDelse] = ACTIONS(2635),
    [anon_sym_POUNDELSE] = ACTIONS(2635),
    [anon_sym_POUNDElse] = ACTIONS(2635),
    [anon_sym_POUNDendif] = ACTIONS(2635),
    [anon_sym_POUNDENDIF] = ACTIONS(2635),
    [anon_sym_POUNDEndif] = ACTIONS(2635),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2635),
    [aux_sym__expression_token1] = ACTIONS(2635),
    [aux_sym__expression_token2] = ACTIONS(2635),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2633),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2633),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_div] = ACTIONS(2633),
    [anon_sym_DIV] = ACTIONS(2633),
    [anon_sym_Div] = ACTIONS(2633),
    [anon_sym_mod] = ACTIONS(2633),
    [anon_sym_MOD] = ACTIONS(2633),
    [anon_sym_Mod] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_GT] = ACTIONS(2635),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_AND] = ACTIONS(2633),
    [anon_sym_And] = ACTIONS(2633),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_OR] = ACTIONS(2633),
    [anon_sym_Or] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_XOR] = ACTIONS(2633),
    [anon_sym_Xor] = ACTIONS(2633),
    [anon_sym_QMARK] = ACTIONS(2635),
    [sym_datetime_literal] = ACTIONS(2635),
    [sym_date_literal] = ACTIONS(2633),
    [sym_time_literal] = ACTIONS(2633),
    [sym_biginteger_literal] = ACTIONS(2635),
    [anon_sym_else] = ACTIONS(2633),
    [anon_sym_ELSE] = ACTIONS(2633),
    [anon_sym_Else] = ACTIONS(2633),
    [anon_sym_in] = ACTIONS(2633),
    [anon_sym_IN] = ACTIONS(2633),
    [anon_sym_In] = ACTIONS(2633),
    [sym_page_keyword] = ACTIONS(2633),
    [anon_sym_codeunit] = ACTIONS(2633),
    [anon_sym_CODEUNIT] = ACTIONS(2633),
    [anon_sym_Codeunit] = ACTIONS(2633),
    [anon_sym_CodeUnit] = ACTIONS(2633),
    [anon_sym_COdeunit] = ACTIONS(2633),
    [anon_sym_codeUnit] = ACTIONS(2633),
    [sym_report_keyword] = ACTIONS(2633),
    [sym_query_keyword] = ACTIONS(2633),
    [anon_sym_xmlport] = ACTIONS(2633),
    [anon_sym_XMLPORT] = ACTIONS(2633),
    [anon_sym_Xmlport] = ACTIONS(2633),
    [anon_sym_XMLport] = ACTIONS(2633),
    [anon_sym_XMLPort] = ACTIONS(2633),
    [anon_sym_XmlPort] = ACTIONS(2633),
    [anon_sym_enum] = ACTIONS(2633),
    [anon_sym_ENUM] = ACTIONS(2633),
    [anon_sym_Enum] = ACTIONS(2633),
    [anon_sym_eNUM] = ACTIONS(2633),
    [anon_sym_eNum] = ACTIONS(2633),
    [anon_sym_ENum] = ACTIONS(2633),
    [sym_quoted_identifier] = ACTIONS(2635),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2635),
    [sym_integer] = ACTIONS(2633),
    [sym_continue_as_identifier] = ACTIONS(2635),
    [sym_preproc_open] = ACTIONS(2635),
    [sym_preproc_close] = ACTIONS(2635),
  },
  [STATE(1516)] = {
    [sym_identifier] = ACTIONS(2641),
    [anon_sym_SEMI] = ACTIONS(2643),
    [anon_sym_DOT] = ACTIONS(2641),
    [anon_sym_EQ] = ACTIONS(2643),
    [anon_sym_COMMA] = ACTIONS(2643),
    [anon_sym_COLON] = ACTIONS(2641),
    [anon_sym_DASH] = ACTIONS(2641),
    [aux_sym_boolean_token1] = ACTIONS(2641),
    [aux_sym_boolean_token2] = ACTIONS(2641),
    [sym_decimal] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_DOT_DOT] = ACTIONS(2643),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2641),
    [anon_sym_STAR] = ACTIONS(2641),
    [anon_sym_LBRACK] = ACTIONS(2643),
    [aux_sym_record_type_token1] = ACTIONS(2641),
    [aux_sym_basic_type_token21] = ACTIONS(2641),
    [aux_sym_basic_type_token22] = ACTIONS(2641),
    [aux_sym_basic_type_token48] = ACTIONS(2641),
    [anon_sym_POUNDif] = ACTIONS(2643),
    [anon_sym_POUNDIF] = ACTIONS(2643),
    [anon_sym_POUNDIf] = ACTIONS(2643),
    [anon_sym_not] = ACTIONS(2641),
    [anon_sym_NOT] = ACTIONS(2641),
    [anon_sym_Not] = ACTIONS(2641),
    [anon_sym_POUNDelif] = ACTIONS(2643),
    [anon_sym_POUNDELIF] = ACTIONS(2643),
    [anon_sym_POUNDElif] = ACTIONS(2643),
    [anon_sym_POUNDelse] = ACTIONS(2643),
    [anon_sym_POUNDELSE] = ACTIONS(2643),
    [anon_sym_POUNDElse] = ACTIONS(2643),
    [anon_sym_POUNDendif] = ACTIONS(2643),
    [anon_sym_POUNDENDIF] = ACTIONS(2643),
    [anon_sym_POUNDEndif] = ACTIONS(2643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2643),
    [aux_sym__expression_token1] = ACTIONS(2643),
    [aux_sym__expression_token2] = ACTIONS(2643),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2641),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2641),
    [anon_sym_SLASH] = ACTIONS(2641),
    [anon_sym_div] = ACTIONS(2641),
    [anon_sym_DIV] = ACTIONS(2641),
    [anon_sym_Div] = ACTIONS(2641),
    [anon_sym_mod] = ACTIONS(2641),
    [anon_sym_MOD] = ACTIONS(2641),
    [anon_sym_Mod] = ACTIONS(2641),
    [anon_sym_PLUS] = ACTIONS(2641),
    [anon_sym_GT_EQ] = ACTIONS(2643),
    [anon_sym_LT_EQ] = ACTIONS(2643),
    [anon_sym_GT] = ACTIONS(2641),
    [anon_sym_LT] = ACTIONS(2641),
    [anon_sym_LT_GT] = ACTIONS(2643),
    [anon_sym_and] = ACTIONS(2641),
    [anon_sym_AND] = ACTIONS(2641),
    [anon_sym_And] = ACTIONS(2641),
    [anon_sym_or] = ACTIONS(2641),
    [anon_sym_OR] = ACTIONS(2641),
    [anon_sym_Or] = ACTIONS(2641),
    [anon_sym_xor] = ACTIONS(2641),
    [anon_sym_XOR] = ACTIONS(2641),
    [anon_sym_Xor] = ACTIONS(2641),
    [anon_sym_QMARK] = ACTIONS(2643),
    [sym_datetime_literal] = ACTIONS(2643),
    [sym_date_literal] = ACTIONS(2641),
    [sym_time_literal] = ACTIONS(2641),
    [sym_biginteger_literal] = ACTIONS(2643),
    [anon_sym_else] = ACTIONS(2641),
    [anon_sym_ELSE] = ACTIONS(2641),
    [anon_sym_Else] = ACTIONS(2641),
    [anon_sym_in] = ACTIONS(2641),
    [anon_sym_IN] = ACTIONS(2641),
    [anon_sym_In] = ACTIONS(2641),
    [sym_page_keyword] = ACTIONS(2641),
    [anon_sym_codeunit] = ACTIONS(2641),
    [anon_sym_CODEUNIT] = ACTIONS(2641),
    [anon_sym_Codeunit] = ACTIONS(2641),
    [anon_sym_CodeUnit] = ACTIONS(2641),
    [anon_sym_COdeunit] = ACTIONS(2641),
    [anon_sym_codeUnit] = ACTIONS(2641),
    [sym_report_keyword] = ACTIONS(2641),
    [sym_query_keyword] = ACTIONS(2641),
    [anon_sym_xmlport] = ACTIONS(2641),
    [anon_sym_XMLPORT] = ACTIONS(2641),
    [anon_sym_Xmlport] = ACTIONS(2641),
    [anon_sym_XMLport] = ACTIONS(2641),
    [anon_sym_XMLPort] = ACTIONS(2641),
    [anon_sym_XmlPort] = ACTIONS(2641),
    [anon_sym_enum] = ACTIONS(2641),
    [anon_sym_ENUM] = ACTIONS(2641),
    [anon_sym_Enum] = ACTIONS(2641),
    [anon_sym_eNUM] = ACTIONS(2641),
    [anon_sym_eNum] = ACTIONS(2641),
    [anon_sym_ENum] = ACTIONS(2641),
    [sym_quoted_identifier] = ACTIONS(2643),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2643),
    [sym_integer] = ACTIONS(2641),
    [sym_continue_as_identifier] = ACTIONS(2643),
    [sym_preproc_open] = ACTIONS(2643),
    [sym_preproc_close] = ACTIONS(2643),
  },
  [STATE(1517)] = {
    [sym_identifier] = ACTIONS(2645),
    [anon_sym_SEMI] = ACTIONS(2647),
    [anon_sym_DOT] = ACTIONS(2645),
    [anon_sym_EQ] = ACTIONS(2647),
    [anon_sym_COMMA] = ACTIONS(2647),
    [anon_sym_COLON] = ACTIONS(2645),
    [anon_sym_DASH] = ACTIONS(2645),
    [aux_sym_boolean_token1] = ACTIONS(2645),
    [aux_sym_boolean_token2] = ACTIONS(2645),
    [sym_decimal] = ACTIONS(2645),
    [anon_sym_LPAREN] = ACTIONS(2647),
    [anon_sym_DOT_DOT] = ACTIONS(2647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2645),
    [anon_sym_STAR] = ACTIONS(2645),
    [anon_sym_LBRACK] = ACTIONS(2647),
    [aux_sym_record_type_token1] = ACTIONS(2645),
    [aux_sym_basic_type_token21] = ACTIONS(2645),
    [aux_sym_basic_type_token22] = ACTIONS(2645),
    [aux_sym_basic_type_token48] = ACTIONS(2645),
    [anon_sym_POUNDif] = ACTIONS(2647),
    [anon_sym_POUNDIF] = ACTIONS(2647),
    [anon_sym_POUNDIf] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2645),
    [anon_sym_NOT] = ACTIONS(2645),
    [anon_sym_Not] = ACTIONS(2645),
    [anon_sym_POUNDelif] = ACTIONS(2647),
    [anon_sym_POUNDELIF] = ACTIONS(2647),
    [anon_sym_POUNDElif] = ACTIONS(2647),
    [anon_sym_POUNDelse] = ACTIONS(2647),
    [anon_sym_POUNDELSE] = ACTIONS(2647),
    [anon_sym_POUNDElse] = ACTIONS(2647),
    [anon_sym_POUNDendif] = ACTIONS(2647),
    [anon_sym_POUNDENDIF] = ACTIONS(2647),
    [anon_sym_POUNDEndif] = ACTIONS(2647),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2647),
    [aux_sym__expression_token1] = ACTIONS(2647),
    [aux_sym__expression_token2] = ACTIONS(2647),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2645),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2645),
    [anon_sym_SLASH] = ACTIONS(2645),
    [anon_sym_div] = ACTIONS(2645),
    [anon_sym_DIV] = ACTIONS(2645),
    [anon_sym_Div] = ACTIONS(2645),
    [anon_sym_mod] = ACTIONS(2645),
    [anon_sym_MOD] = ACTIONS(2645),
    [anon_sym_Mod] = ACTIONS(2645),
    [anon_sym_PLUS] = ACTIONS(2645),
    [anon_sym_GT_EQ] = ACTIONS(2647),
    [anon_sym_LT_EQ] = ACTIONS(2647),
    [anon_sym_GT] = ACTIONS(2645),
    [anon_sym_LT] = ACTIONS(2645),
    [anon_sym_LT_GT] = ACTIONS(2647),
    [anon_sym_and] = ACTIONS(2645),
    [anon_sym_AND] = ACTIONS(2645),
    [anon_sym_And] = ACTIONS(2645),
    [anon_sym_or] = ACTIONS(2645),
    [anon_sym_OR] = ACTIONS(2645),
    [anon_sym_Or] = ACTIONS(2645),
    [anon_sym_xor] = ACTIONS(2645),
    [anon_sym_XOR] = ACTIONS(2645),
    [anon_sym_Xor] = ACTIONS(2645),
    [anon_sym_QMARK] = ACTIONS(2647),
    [sym_datetime_literal] = ACTIONS(2647),
    [sym_date_literal] = ACTIONS(2645),
    [sym_time_literal] = ACTIONS(2645),
    [sym_biginteger_literal] = ACTIONS(2647),
    [anon_sym_else] = ACTIONS(2645),
    [anon_sym_ELSE] = ACTIONS(2645),
    [anon_sym_Else] = ACTIONS(2645),
    [anon_sym_in] = ACTIONS(2645),
    [anon_sym_IN] = ACTIONS(2645),
    [anon_sym_In] = ACTIONS(2645),
    [sym_page_keyword] = ACTIONS(2645),
    [anon_sym_codeunit] = ACTIONS(2645),
    [anon_sym_CODEUNIT] = ACTIONS(2645),
    [anon_sym_Codeunit] = ACTIONS(2645),
    [anon_sym_CodeUnit] = ACTIONS(2645),
    [anon_sym_COdeunit] = ACTIONS(2645),
    [anon_sym_codeUnit] = ACTIONS(2645),
    [sym_report_keyword] = ACTIONS(2645),
    [sym_query_keyword] = ACTIONS(2645),
    [anon_sym_xmlport] = ACTIONS(2645),
    [anon_sym_XMLPORT] = ACTIONS(2645),
    [anon_sym_Xmlport] = ACTIONS(2645),
    [anon_sym_XMLport] = ACTIONS(2645),
    [anon_sym_XMLPort] = ACTIONS(2645),
    [anon_sym_XmlPort] = ACTIONS(2645),
    [anon_sym_enum] = ACTIONS(2645),
    [anon_sym_ENUM] = ACTIONS(2645),
    [anon_sym_Enum] = ACTIONS(2645),
    [anon_sym_eNUM] = ACTIONS(2645),
    [anon_sym_eNum] = ACTIONS(2645),
    [anon_sym_ENum] = ACTIONS(2645),
    [sym_quoted_identifier] = ACTIONS(2647),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2647),
    [sym_integer] = ACTIONS(2645),
    [sym_continue_as_identifier] = ACTIONS(2647),
    [sym_preproc_open] = ACTIONS(2647),
    [sym_preproc_close] = ACTIONS(2647),
  },
  [STATE(1518)] = {
    [sym_identifier] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym_DOT] = ACTIONS(2573),
    [anon_sym_EQ] = ACTIONS(2575),
    [anon_sym_COMMA] = ACTIONS(2575),
    [anon_sym_COLON] = ACTIONS(2573),
    [anon_sym_DASH] = ACTIONS(2573),
    [aux_sym_boolean_token1] = ACTIONS(2573),
    [aux_sym_boolean_token2] = ACTIONS(2573),
    [sym_decimal] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2575),
    [anon_sym_DOT_DOT] = ACTIONS(2575),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2575),
    [aux_sym_record_type_token1] = ACTIONS(2573),
    [aux_sym_basic_type_token21] = ACTIONS(2573),
    [aux_sym_basic_type_token22] = ACTIONS(2573),
    [aux_sym_basic_type_token48] = ACTIONS(2573),
    [anon_sym_POUNDif] = ACTIONS(2575),
    [anon_sym_POUNDIF] = ACTIONS(2575),
    [anon_sym_POUNDIf] = ACTIONS(2575),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_NOT] = ACTIONS(2573),
    [anon_sym_Not] = ACTIONS(2573),
    [anon_sym_POUNDelif] = ACTIONS(2575),
    [anon_sym_POUNDELIF] = ACTIONS(2575),
    [anon_sym_POUNDElif] = ACTIONS(2575),
    [anon_sym_POUNDelse] = ACTIONS(2575),
    [anon_sym_POUNDELSE] = ACTIONS(2575),
    [anon_sym_POUNDElse] = ACTIONS(2575),
    [anon_sym_POUNDendif] = ACTIONS(2575),
    [anon_sym_POUNDENDIF] = ACTIONS(2575),
    [anon_sym_POUNDEndif] = ACTIONS(2575),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2575),
    [aux_sym__expression_token1] = ACTIONS(2575),
    [aux_sym__expression_token2] = ACTIONS(2575),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2573),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2573),
    [anon_sym_SLASH] = ACTIONS(2573),
    [anon_sym_div] = ACTIONS(2573),
    [anon_sym_DIV] = ACTIONS(2573),
    [anon_sym_Div] = ACTIONS(2573),
    [anon_sym_mod] = ACTIONS(2573),
    [anon_sym_MOD] = ACTIONS(2573),
    [anon_sym_Mod] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_GT_EQ] = ACTIONS(2575),
    [anon_sym_LT_EQ] = ACTIONS(2575),
    [anon_sym_GT] = ACTIONS(2573),
    [anon_sym_LT] = ACTIONS(2573),
    [anon_sym_LT_GT] = ACTIONS(2575),
    [anon_sym_and] = ACTIONS(2573),
    [anon_sym_AND] = ACTIONS(2573),
    [anon_sym_And] = ACTIONS(2573),
    [anon_sym_or] = ACTIONS(2573),
    [anon_sym_OR] = ACTIONS(2573),
    [anon_sym_Or] = ACTIONS(2573),
    [anon_sym_xor] = ACTIONS(2573),
    [anon_sym_XOR] = ACTIONS(2573),
    [anon_sym_Xor] = ACTIONS(2573),
    [anon_sym_QMARK] = ACTIONS(2575),
    [sym_datetime_literal] = ACTIONS(2575),
    [sym_date_literal] = ACTIONS(2573),
    [sym_time_literal] = ACTIONS(2573),
    [sym_biginteger_literal] = ACTIONS(2575),
    [anon_sym_else] = ACTIONS(2573),
    [anon_sym_ELSE] = ACTIONS(2573),
    [anon_sym_Else] = ACTIONS(2573),
    [anon_sym_in] = ACTIONS(2573),
    [anon_sym_IN] = ACTIONS(2573),
    [anon_sym_In] = ACTIONS(2573),
    [sym_page_keyword] = ACTIONS(2573),
    [anon_sym_codeunit] = ACTIONS(2573),
    [anon_sym_CODEUNIT] = ACTIONS(2573),
    [anon_sym_Codeunit] = ACTIONS(2573),
    [anon_sym_CodeUnit] = ACTIONS(2573),
    [anon_sym_COdeunit] = ACTIONS(2573),
    [anon_sym_codeUnit] = ACTIONS(2573),
    [sym_report_keyword] = ACTIONS(2573),
    [sym_query_keyword] = ACTIONS(2573),
    [anon_sym_xmlport] = ACTIONS(2573),
    [anon_sym_XMLPORT] = ACTIONS(2573),
    [anon_sym_Xmlport] = ACTIONS(2573),
    [anon_sym_XMLport] = ACTIONS(2573),
    [anon_sym_XMLPort] = ACTIONS(2573),
    [anon_sym_XmlPort] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_ENUM] = ACTIONS(2573),
    [anon_sym_Enum] = ACTIONS(2573),
    [anon_sym_eNUM] = ACTIONS(2573),
    [anon_sym_eNum] = ACTIONS(2573),
    [anon_sym_ENum] = ACTIONS(2573),
    [sym_quoted_identifier] = ACTIONS(2575),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2575),
    [sym_integer] = ACTIONS(2573),
    [sym_continue_as_identifier] = ACTIONS(2575),
    [sym_preproc_open] = ACTIONS(2575),
    [sym_preproc_close] = ACTIONS(2575),
  },
  [STATE(1519)] = {
    [sym_identifier] = ACTIONS(2577),
    [anon_sym_SEMI] = ACTIONS(2579),
    [anon_sym_DOT] = ACTIONS(2577),
    [anon_sym_EQ] = ACTIONS(2579),
    [anon_sym_COMMA] = ACTIONS(2579),
    [anon_sym_COLON] = ACTIONS(2577),
    [anon_sym_DASH] = ACTIONS(2577),
    [aux_sym_boolean_token1] = ACTIONS(2577),
    [aux_sym_boolean_token2] = ACTIONS(2577),
    [sym_decimal] = ACTIONS(2577),
    [anon_sym_LPAREN] = ACTIONS(2579),
    [anon_sym_DOT_DOT] = ACTIONS(2579),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2577),
    [anon_sym_STAR] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [aux_sym_record_type_token1] = ACTIONS(2577),
    [aux_sym_basic_type_token21] = ACTIONS(2577),
    [aux_sym_basic_type_token22] = ACTIONS(2577),
    [aux_sym_basic_type_token48] = ACTIONS(2577),
    [anon_sym_POUNDif] = ACTIONS(2579),
    [anon_sym_POUNDIF] = ACTIONS(2579),
    [anon_sym_POUNDIf] = ACTIONS(2579),
    [anon_sym_not] = ACTIONS(2577),
    [anon_sym_NOT] = ACTIONS(2577),
    [anon_sym_Not] = ACTIONS(2577),
    [anon_sym_POUNDelif] = ACTIONS(2579),
    [anon_sym_POUNDELIF] = ACTIONS(2579),
    [anon_sym_POUNDElif] = ACTIONS(2579),
    [anon_sym_POUNDelse] = ACTIONS(2579),
    [anon_sym_POUNDELSE] = ACTIONS(2579),
    [anon_sym_POUNDElse] = ACTIONS(2579),
    [anon_sym_POUNDendif] = ACTIONS(2579),
    [anon_sym_POUNDENDIF] = ACTIONS(2579),
    [anon_sym_POUNDEndif] = ACTIONS(2579),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2579),
    [aux_sym__expression_token1] = ACTIONS(2579),
    [aux_sym__expression_token2] = ACTIONS(2579),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2577),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2577),
    [anon_sym_SLASH] = ACTIONS(2577),
    [anon_sym_div] = ACTIONS(2577),
    [anon_sym_DIV] = ACTIONS(2577),
    [anon_sym_Div] = ACTIONS(2577),
    [anon_sym_mod] = ACTIONS(2577),
    [anon_sym_MOD] = ACTIONS(2577),
    [anon_sym_Mod] = ACTIONS(2577),
    [anon_sym_PLUS] = ACTIONS(2577),
    [anon_sym_GT_EQ] = ACTIONS(2579),
    [anon_sym_LT_EQ] = ACTIONS(2579),
    [anon_sym_GT] = ACTIONS(2577),
    [anon_sym_LT] = ACTIONS(2577),
    [anon_sym_LT_GT] = ACTIONS(2579),
    [anon_sym_and] = ACTIONS(2577),
    [anon_sym_AND] = ACTIONS(2577),
    [anon_sym_And] = ACTIONS(2577),
    [anon_sym_or] = ACTIONS(2577),
    [anon_sym_OR] = ACTIONS(2577),
    [anon_sym_Or] = ACTIONS(2577),
    [anon_sym_xor] = ACTIONS(2577),
    [anon_sym_XOR] = ACTIONS(2577),
    [anon_sym_Xor] = ACTIONS(2577),
    [anon_sym_QMARK] = ACTIONS(2579),
    [sym_datetime_literal] = ACTIONS(2579),
    [sym_date_literal] = ACTIONS(2577),
    [sym_time_literal] = ACTIONS(2577),
    [sym_biginteger_literal] = ACTIONS(2579),
    [anon_sym_else] = ACTIONS(2577),
    [anon_sym_ELSE] = ACTIONS(2577),
    [anon_sym_Else] = ACTIONS(2577),
    [anon_sym_in] = ACTIONS(2577),
    [anon_sym_IN] = ACTIONS(2577),
    [anon_sym_In] = ACTIONS(2577),
    [sym_page_keyword] = ACTIONS(2577),
    [anon_sym_codeunit] = ACTIONS(2577),
    [anon_sym_CODEUNIT] = ACTIONS(2577),
    [anon_sym_Codeunit] = ACTIONS(2577),
    [anon_sym_CodeUnit] = ACTIONS(2577),
    [anon_sym_COdeunit] = ACTIONS(2577),
    [anon_sym_codeUnit] = ACTIONS(2577),
    [sym_report_keyword] = ACTIONS(2577),
    [sym_query_keyword] = ACTIONS(2577),
    [anon_sym_xmlport] = ACTIONS(2577),
    [anon_sym_XMLPORT] = ACTIONS(2577),
    [anon_sym_Xmlport] = ACTIONS(2577),
    [anon_sym_XMLport] = ACTIONS(2577),
    [anon_sym_XMLPort] = ACTIONS(2577),
    [anon_sym_XmlPort] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_ENUM] = ACTIONS(2577),
    [anon_sym_Enum] = ACTIONS(2577),
    [anon_sym_eNUM] = ACTIONS(2577),
    [anon_sym_eNum] = ACTIONS(2577),
    [anon_sym_ENum] = ACTIONS(2577),
    [sym_quoted_identifier] = ACTIONS(2579),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2579),
    [sym_integer] = ACTIONS(2577),
    [sym_continue_as_identifier] = ACTIONS(2579),
    [sym_preproc_open] = ACTIONS(2579),
    [sym_preproc_close] = ACTIONS(2579),
  },
  [STATE(1520)] = {
    [sym_identifier] = ACTIONS(2581),
    [anon_sym_SEMI] = ACTIONS(2583),
    [anon_sym_DOT] = ACTIONS(2581),
    [anon_sym_EQ] = ACTIONS(2583),
    [anon_sym_COMMA] = ACTIONS(2583),
    [anon_sym_COLON] = ACTIONS(2581),
    [anon_sym_DASH] = ACTIONS(2581),
    [aux_sym_boolean_token1] = ACTIONS(2581),
    [aux_sym_boolean_token2] = ACTIONS(2581),
    [sym_decimal] = ACTIONS(2581),
    [anon_sym_LPAREN] = ACTIONS(2583),
    [anon_sym_DOT_DOT] = ACTIONS(2583),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2581),
    [anon_sym_STAR] = ACTIONS(2581),
    [anon_sym_LBRACK] = ACTIONS(2583),
    [aux_sym_record_type_token1] = ACTIONS(2581),
    [aux_sym_basic_type_token21] = ACTIONS(2581),
    [aux_sym_basic_type_token22] = ACTIONS(2581),
    [aux_sym_basic_type_token48] = ACTIONS(2581),
    [anon_sym_POUNDif] = ACTIONS(2583),
    [anon_sym_POUNDIF] = ACTIONS(2583),
    [anon_sym_POUNDIf] = ACTIONS(2583),
    [anon_sym_not] = ACTIONS(2581),
    [anon_sym_NOT] = ACTIONS(2581),
    [anon_sym_Not] = ACTIONS(2581),
    [anon_sym_POUNDelif] = ACTIONS(2583),
    [anon_sym_POUNDELIF] = ACTIONS(2583),
    [anon_sym_POUNDElif] = ACTIONS(2583),
    [anon_sym_POUNDelse] = ACTIONS(2583),
    [anon_sym_POUNDELSE] = ACTIONS(2583),
    [anon_sym_POUNDElse] = ACTIONS(2583),
    [anon_sym_POUNDendif] = ACTIONS(2583),
    [anon_sym_POUNDENDIF] = ACTIONS(2583),
    [anon_sym_POUNDEndif] = ACTIONS(2583),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2583),
    [aux_sym__expression_token1] = ACTIONS(2583),
    [aux_sym__expression_token2] = ACTIONS(2583),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2581),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2581),
    [anon_sym_SLASH] = ACTIONS(2581),
    [anon_sym_div] = ACTIONS(2581),
    [anon_sym_DIV] = ACTIONS(2581),
    [anon_sym_Div] = ACTIONS(2581),
    [anon_sym_mod] = ACTIONS(2581),
    [anon_sym_MOD] = ACTIONS(2581),
    [anon_sym_Mod] = ACTIONS(2581),
    [anon_sym_PLUS] = ACTIONS(2581),
    [anon_sym_GT_EQ] = ACTIONS(2583),
    [anon_sym_LT_EQ] = ACTIONS(2583),
    [anon_sym_GT] = ACTIONS(2581),
    [anon_sym_LT] = ACTIONS(2581),
    [anon_sym_LT_GT] = ACTIONS(2583),
    [anon_sym_and] = ACTIONS(2581),
    [anon_sym_AND] = ACTIONS(2581),
    [anon_sym_And] = ACTIONS(2581),
    [anon_sym_or] = ACTIONS(2581),
    [anon_sym_OR] = ACTIONS(2581),
    [anon_sym_Or] = ACTIONS(2581),
    [anon_sym_xor] = ACTIONS(2581),
    [anon_sym_XOR] = ACTIONS(2581),
    [anon_sym_Xor] = ACTIONS(2581),
    [anon_sym_QMARK] = ACTIONS(2583),
    [sym_datetime_literal] = ACTIONS(2583),
    [sym_date_literal] = ACTIONS(2581),
    [sym_time_literal] = ACTIONS(2581),
    [sym_biginteger_literal] = ACTIONS(2583),
    [anon_sym_else] = ACTIONS(2581),
    [anon_sym_ELSE] = ACTIONS(2581),
    [anon_sym_Else] = ACTIONS(2581),
    [anon_sym_in] = ACTIONS(2581),
    [anon_sym_IN] = ACTIONS(2581),
    [anon_sym_In] = ACTIONS(2581),
    [sym_page_keyword] = ACTIONS(2581),
    [anon_sym_codeunit] = ACTIONS(2581),
    [anon_sym_CODEUNIT] = ACTIONS(2581),
    [anon_sym_Codeunit] = ACTIONS(2581),
    [anon_sym_CodeUnit] = ACTIONS(2581),
    [anon_sym_COdeunit] = ACTIONS(2581),
    [anon_sym_codeUnit] = ACTIONS(2581),
    [sym_report_keyword] = ACTIONS(2581),
    [sym_query_keyword] = ACTIONS(2581),
    [anon_sym_xmlport] = ACTIONS(2581),
    [anon_sym_XMLPORT] = ACTIONS(2581),
    [anon_sym_Xmlport] = ACTIONS(2581),
    [anon_sym_XMLport] = ACTIONS(2581),
    [anon_sym_XMLPort] = ACTIONS(2581),
    [anon_sym_XmlPort] = ACTIONS(2581),
    [anon_sym_enum] = ACTIONS(2581),
    [anon_sym_ENUM] = ACTIONS(2581),
    [anon_sym_Enum] = ACTIONS(2581),
    [anon_sym_eNUM] = ACTIONS(2581),
    [anon_sym_eNum] = ACTIONS(2581),
    [anon_sym_ENum] = ACTIONS(2581),
    [sym_quoted_identifier] = ACTIONS(2583),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2583),
    [sym_integer] = ACTIONS(2581),
    [sym_continue_as_identifier] = ACTIONS(2583),
    [sym_preproc_open] = ACTIONS(2583),
    [sym_preproc_close] = ACTIONS(2583),
  },
  [STATE(1521)] = {
    [sym_identifier] = ACTIONS(2569),
    [anon_sym_SEMI] = ACTIONS(2571),
    [anon_sym_DOT] = ACTIONS(2569),
    [anon_sym_EQ] = ACTIONS(2571),
    [anon_sym_COMMA] = ACTIONS(2571),
    [anon_sym_COLON] = ACTIONS(2569),
    [anon_sym_DASH] = ACTIONS(2569),
    [aux_sym_boolean_token1] = ACTIONS(2569),
    [aux_sym_boolean_token2] = ACTIONS(2569),
    [sym_decimal] = ACTIONS(2569),
    [anon_sym_LPAREN] = ACTIONS(2571),
    [anon_sym_DOT_DOT] = ACTIONS(2571),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2569),
    [anon_sym_STAR] = ACTIONS(2569),
    [anon_sym_LBRACK] = ACTIONS(2571),
    [aux_sym_record_type_token1] = ACTIONS(2569),
    [aux_sym_basic_type_token21] = ACTIONS(2569),
    [aux_sym_basic_type_token22] = ACTIONS(2569),
    [aux_sym_basic_type_token48] = ACTIONS(2569),
    [anon_sym_POUNDif] = ACTIONS(2571),
    [anon_sym_POUNDIF] = ACTIONS(2571),
    [anon_sym_POUNDIf] = ACTIONS(2571),
    [anon_sym_not] = ACTIONS(2569),
    [anon_sym_NOT] = ACTIONS(2569),
    [anon_sym_Not] = ACTIONS(2569),
    [anon_sym_POUNDelif] = ACTIONS(2571),
    [anon_sym_POUNDELIF] = ACTIONS(2571),
    [anon_sym_POUNDElif] = ACTIONS(2571),
    [anon_sym_POUNDelse] = ACTIONS(2571),
    [anon_sym_POUNDELSE] = ACTIONS(2571),
    [anon_sym_POUNDElse] = ACTIONS(2571),
    [anon_sym_POUNDendif] = ACTIONS(2571),
    [anon_sym_POUNDENDIF] = ACTIONS(2571),
    [anon_sym_POUNDEndif] = ACTIONS(2571),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2571),
    [aux_sym__expression_token1] = ACTIONS(2571),
    [aux_sym__expression_token2] = ACTIONS(2571),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2569),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2569),
    [anon_sym_SLASH] = ACTIONS(2569),
    [anon_sym_div] = ACTIONS(2569),
    [anon_sym_DIV] = ACTIONS(2569),
    [anon_sym_Div] = ACTIONS(2569),
    [anon_sym_mod] = ACTIONS(2569),
    [anon_sym_MOD] = ACTIONS(2569),
    [anon_sym_Mod] = ACTIONS(2569),
    [anon_sym_PLUS] = ACTIONS(2569),
    [anon_sym_GT_EQ] = ACTIONS(2571),
    [anon_sym_LT_EQ] = ACTIONS(2571),
    [anon_sym_GT] = ACTIONS(2569),
    [anon_sym_LT] = ACTIONS(2569),
    [anon_sym_LT_GT] = ACTIONS(2571),
    [anon_sym_and] = ACTIONS(2569),
    [anon_sym_AND] = ACTIONS(2569),
    [anon_sym_And] = ACTIONS(2569),
    [anon_sym_or] = ACTIONS(2569),
    [anon_sym_OR] = ACTIONS(2569),
    [anon_sym_Or] = ACTIONS(2569),
    [anon_sym_xor] = ACTIONS(2569),
    [anon_sym_XOR] = ACTIONS(2569),
    [anon_sym_Xor] = ACTIONS(2569),
    [anon_sym_QMARK] = ACTIONS(2571),
    [sym_datetime_literal] = ACTIONS(2571),
    [sym_date_literal] = ACTIONS(2569),
    [sym_time_literal] = ACTIONS(2569),
    [sym_biginteger_literal] = ACTIONS(2571),
    [anon_sym_else] = ACTIONS(2569),
    [anon_sym_ELSE] = ACTIONS(2569),
    [anon_sym_Else] = ACTIONS(2569),
    [anon_sym_in] = ACTIONS(2569),
    [anon_sym_IN] = ACTIONS(2569),
    [anon_sym_In] = ACTIONS(2569),
    [sym_page_keyword] = ACTIONS(2569),
    [anon_sym_codeunit] = ACTIONS(2569),
    [anon_sym_CODEUNIT] = ACTIONS(2569),
    [anon_sym_Codeunit] = ACTIONS(2569),
    [anon_sym_CodeUnit] = ACTIONS(2569),
    [anon_sym_COdeunit] = ACTIONS(2569),
    [anon_sym_codeUnit] = ACTIONS(2569),
    [sym_report_keyword] = ACTIONS(2569),
    [sym_query_keyword] = ACTIONS(2569),
    [anon_sym_xmlport] = ACTIONS(2569),
    [anon_sym_XMLPORT] = ACTIONS(2569),
    [anon_sym_Xmlport] = ACTIONS(2569),
    [anon_sym_XMLport] = ACTIONS(2569),
    [anon_sym_XMLPort] = ACTIONS(2569),
    [anon_sym_XmlPort] = ACTIONS(2569),
    [anon_sym_enum] = ACTIONS(2569),
    [anon_sym_ENUM] = ACTIONS(2569),
    [anon_sym_Enum] = ACTIONS(2569),
    [anon_sym_eNUM] = ACTIONS(2569),
    [anon_sym_eNum] = ACTIONS(2569),
    [anon_sym_ENum] = ACTIONS(2569),
    [sym_quoted_identifier] = ACTIONS(2571),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2571),
    [sym_integer] = ACTIONS(2569),
    [sym_continue_as_identifier] = ACTIONS(2571),
    [sym_preproc_open] = ACTIONS(2571),
    [sym_preproc_close] = ACTIONS(2571),
  },
  [STATE(1522)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2441),
    [sym_preproc_elif] = STATE(1740),
    [sym_preproc_else] = STATE(2175),
    [sym_preproc_endif] = STATE(4641),
    [sym_assignment_expression] = STATE(6338),
    [sym_case_branch] = STATE(1939),
    [sym_preproc_split_case_branch] = STATE(3395),
    [aux_sym__case_pattern] = STATE(2579),
    [sym_preproc_conditional_case_patterns] = STATE(2579),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(8082),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(87),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(1939),
    [aux_sym_preproc_conditional_case_repeat2] = STATE(8081),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(3754),
    [anon_sym_ELSE] = ACTIONS(3754),
    [anon_sym_Else] = ACTIONS(3754),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(1523)] = {
    [sym_identifier] = ACTIONS(2637),
    [anon_sym_SEMI] = ACTIONS(2639),
    [anon_sym_DOT] = ACTIONS(2637),
    [anon_sym_EQ] = ACTIONS(2639),
    [anon_sym_COMMA] = ACTIONS(2639),
    [anon_sym_COLON] = ACTIONS(2637),
    [anon_sym_DASH] = ACTIONS(2637),
    [aux_sym_boolean_token1] = ACTIONS(2637),
    [aux_sym_boolean_token2] = ACTIONS(2637),
    [sym_decimal] = ACTIONS(2637),
    [anon_sym_LPAREN] = ACTIONS(2639),
    [anon_sym_DOT_DOT] = ACTIONS(2639),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(2637),
    [anon_sym_LBRACK] = ACTIONS(2639),
    [aux_sym_record_type_token1] = ACTIONS(2637),
    [aux_sym_basic_type_token21] = ACTIONS(2637),
    [aux_sym_basic_type_token22] = ACTIONS(2637),
    [aux_sym_basic_type_token48] = ACTIONS(2637),
    [anon_sym_POUNDif] = ACTIONS(2639),
    [anon_sym_POUNDIF] = ACTIONS(2639),
    [anon_sym_POUNDIf] = ACTIONS(2639),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_NOT] = ACTIONS(2637),
    [anon_sym_Not] = ACTIONS(2637),
    [anon_sym_POUNDelif] = ACTIONS(2639),
    [anon_sym_POUNDELIF] = ACTIONS(2639),
    [anon_sym_POUNDElif] = ACTIONS(2639),
    [anon_sym_POUNDelse] = ACTIONS(2639),
    [anon_sym_POUNDELSE] = ACTIONS(2639),
    [anon_sym_POUNDElse] = ACTIONS(2639),
    [anon_sym_POUNDendif] = ACTIONS(2639),
    [anon_sym_POUNDENDIF] = ACTIONS(2639),
    [anon_sym_POUNDEndif] = ACTIONS(2639),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2639),
    [aux_sym__expression_token1] = ACTIONS(2639),
    [aux_sym__expression_token2] = ACTIONS(2639),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2637),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2637),
    [anon_sym_SLASH] = ACTIONS(2637),
    [anon_sym_div] = ACTIONS(2637),
    [anon_sym_DIV] = ACTIONS(2637),
    [anon_sym_Div] = ACTIONS(2637),
    [anon_sym_mod] = ACTIONS(2637),
    [anon_sym_MOD] = ACTIONS(2637),
    [anon_sym_Mod] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_GT_EQ] = ACTIONS(2639),
    [anon_sym_LT_EQ] = ACTIONS(2639),
    [anon_sym_GT] = ACTIONS(2637),
    [anon_sym_LT] = ACTIONS(2637),
    [anon_sym_LT_GT] = ACTIONS(2639),
    [anon_sym_and] = ACTIONS(2637),
    [anon_sym_AND] = ACTIONS(2637),
    [anon_sym_And] = ACTIONS(2637),
    [anon_sym_or] = ACTIONS(2637),
    [anon_sym_OR] = ACTIONS(2637),
    [anon_sym_Or] = ACTIONS(2637),
    [anon_sym_xor] = ACTIONS(2637),
    [anon_sym_XOR] = ACTIONS(2637),
    [anon_sym_Xor] = ACTIONS(2637),
    [anon_sym_QMARK] = ACTIONS(2639),
    [sym_datetime_literal] = ACTIONS(2639),
    [sym_date_literal] = ACTIONS(2637),
    [sym_time_literal] = ACTIONS(2637),
    [sym_biginteger_literal] = ACTIONS(2639),
    [anon_sym_else] = ACTIONS(2637),
    [anon_sym_ELSE] = ACTIONS(2637),
    [anon_sym_Else] = ACTIONS(2637),
    [anon_sym_in] = ACTIONS(2637),
    [anon_sym_IN] = ACTIONS(2637),
    [anon_sym_In] = ACTIONS(2637),
    [sym_page_keyword] = ACTIONS(2637),
    [anon_sym_codeunit] = ACTIONS(2637),
    [anon_sym_CODEUNIT] = ACTIONS(2637),
    [anon_sym_Codeunit] = ACTIONS(2637),
    [anon_sym_CodeUnit] = ACTIONS(2637),
    [anon_sym_COdeunit] = ACTIONS(2637),
    [anon_sym_codeUnit] = ACTIONS(2637),
    [sym_report_keyword] = ACTIONS(2637),
    [sym_query_keyword] = ACTIONS(2637),
    [anon_sym_xmlport] = ACTIONS(2637),
    [anon_sym_XMLPORT] = ACTIONS(2637),
    [anon_sym_Xmlport] = ACTIONS(2637),
    [anon_sym_XMLport] = ACTIONS(2637),
    [anon_sym_XMLPort] = ACTIONS(2637),
    [anon_sym_XmlPort] = ACTIONS(2637),
    [anon_sym_enum] = ACTIONS(2637),
    [anon_sym_ENUM] = ACTIONS(2637),
    [anon_sym_Enum] = ACTIONS(2637),
    [anon_sym_eNUM] = ACTIONS(2637),
    [anon_sym_eNum] = ACTIONS(2637),
    [anon_sym_ENum] = ACTIONS(2637),
    [sym_quoted_identifier] = ACTIONS(2639),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2639),
    [sym_integer] = ACTIONS(2637),
    [sym_continue_as_identifier] = ACTIONS(2639),
    [sym_preproc_open] = ACTIONS(2639),
    [sym_preproc_close] = ACTIONS(2639),
  },
  [STATE(1524)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2372),
    [anon_sym_SEMI] = ACTIONS(2374),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(3710),
    [aux_sym_boolean_token1] = ACTIONS(2372),
    [aux_sym_boolean_token2] = ACTIONS(2372),
    [sym_decimal] = ACTIONS(2372),
    [anon_sym_LPAREN] = ACTIONS(2374),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2372),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(3716),
    [aux_sym_record_type_token1] = ACTIONS(2372),
    [aux_sym_basic_type_token21] = ACTIONS(2372),
    [aux_sym_basic_type_token22] = ACTIONS(2372),
    [aux_sym_basic_type_token48] = ACTIONS(2372),
    [anon_sym_POUNDif] = ACTIONS(2374),
    [anon_sym_POUNDIF] = ACTIONS(2374),
    [anon_sym_POUNDIf] = ACTIONS(2374),
    [anon_sym_not] = ACTIONS(2372),
    [anon_sym_NOT] = ACTIONS(2372),
    [anon_sym_Not] = ACTIONS(2372),
    [anon_sym_POUNDelif] = ACTIONS(2374),
    [anon_sym_POUNDELIF] = ACTIONS(2374),
    [anon_sym_POUNDElif] = ACTIONS(2374),
    [anon_sym_POUNDelse] = ACTIONS(2374),
    [anon_sym_POUNDELSE] = ACTIONS(2374),
    [anon_sym_POUNDElse] = ACTIONS(2374),
    [anon_sym_POUNDendif] = ACTIONS(2374),
    [anon_sym_POUNDENDIF] = ACTIONS(2374),
    [anon_sym_POUNDEndif] = ACTIONS(2374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(4117),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2372),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2372),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(3736),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3740),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(3766),
    [anon_sym_OR] = ACTIONS(3768),
    [anon_sym_Or] = ACTIONS(3770),
    [anon_sym_xor] = ACTIONS(3772),
    [anon_sym_XOR] = ACTIONS(3774),
    [anon_sym_Xor] = ACTIONS(3776),
    [anon_sym_QMARK] = ACTIONS(3778),
    [sym_datetime_literal] = ACTIONS(2374),
    [sym_date_literal] = ACTIONS(2372),
    [sym_time_literal] = ACTIONS(2372),
    [sym_biginteger_literal] = ACTIONS(2374),
    [anon_sym_else] = ACTIONS(2372),
    [anon_sym_ELSE] = ACTIONS(2372),
    [anon_sym_Else] = ACTIONS(2372),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2372),
    [anon_sym_codeunit] = ACTIONS(2372),
    [anon_sym_CODEUNIT] = ACTIONS(2372),
    [anon_sym_Codeunit] = ACTIONS(2372),
    [anon_sym_CodeUnit] = ACTIONS(2372),
    [anon_sym_COdeunit] = ACTIONS(2372),
    [anon_sym_codeUnit] = ACTIONS(2372),
    [sym_report_keyword] = ACTIONS(2372),
    [sym_query_keyword] = ACTIONS(2372),
    [anon_sym_xmlport] = ACTIONS(2372),
    [anon_sym_XMLPORT] = ACTIONS(2372),
    [anon_sym_Xmlport] = ACTIONS(2372),
    [anon_sym_XMLport] = ACTIONS(2372),
    [anon_sym_XMLPort] = ACTIONS(2372),
    [anon_sym_XmlPort] = ACTIONS(2372),
    [anon_sym_enum] = ACTIONS(2372),
    [anon_sym_ENUM] = ACTIONS(2372),
    [anon_sym_Enum] = ACTIONS(2372),
    [anon_sym_eNUM] = ACTIONS(2372),
    [anon_sym_eNum] = ACTIONS(2372),
    [anon_sym_ENum] = ACTIONS(2372),
    [sym_quoted_identifier] = ACTIONS(2374),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2374),
    [sym_integer] = ACTIONS(2372),
    [sym_continue_as_identifier] = ACTIONS(2374),
    [sym_preproc_open] = ACTIONS(2374),
    [sym_preproc_close] = ACTIONS(2374),
  },
  [STATE(1525)] = {
    [sym_identifier] = ACTIONS(2597),
    [anon_sym_SEMI] = ACTIONS(2599),
    [anon_sym_DOT] = ACTIONS(2597),
    [anon_sym_EQ] = ACTIONS(2599),
    [anon_sym_COMMA] = ACTIONS(2599),
    [anon_sym_COLON] = ACTIONS(2597),
    [anon_sym_DASH] = ACTIONS(2597),
    [aux_sym_boolean_token1] = ACTIONS(2597),
    [aux_sym_boolean_token2] = ACTIONS(2597),
    [sym_decimal] = ACTIONS(2597),
    [anon_sym_LPAREN] = ACTIONS(2599),
    [anon_sym_DOT_DOT] = ACTIONS(2599),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2597),
    [anon_sym_STAR] = ACTIONS(2597),
    [anon_sym_LBRACK] = ACTIONS(2599),
    [aux_sym_record_type_token1] = ACTIONS(2597),
    [aux_sym_basic_type_token21] = ACTIONS(2597),
    [aux_sym_basic_type_token22] = ACTIONS(2597),
    [aux_sym_basic_type_token48] = ACTIONS(2597),
    [anon_sym_POUNDif] = ACTIONS(2599),
    [anon_sym_POUNDIF] = ACTIONS(2599),
    [anon_sym_POUNDIf] = ACTIONS(2599),
    [anon_sym_not] = ACTIONS(2597),
    [anon_sym_NOT] = ACTIONS(2597),
    [anon_sym_Not] = ACTIONS(2597),
    [anon_sym_POUNDelif] = ACTIONS(2599),
    [anon_sym_POUNDELIF] = ACTIONS(2599),
    [anon_sym_POUNDElif] = ACTIONS(2599),
    [anon_sym_POUNDelse] = ACTIONS(2599),
    [anon_sym_POUNDELSE] = ACTIONS(2599),
    [anon_sym_POUNDElse] = ACTIONS(2599),
    [anon_sym_POUNDendif] = ACTIONS(2599),
    [anon_sym_POUNDENDIF] = ACTIONS(2599),
    [anon_sym_POUNDEndif] = ACTIONS(2599),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2599),
    [aux_sym__expression_token1] = ACTIONS(2599),
    [aux_sym__expression_token2] = ACTIONS(2599),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2597),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2597),
    [anon_sym_SLASH] = ACTIONS(2597),
    [anon_sym_div] = ACTIONS(2597),
    [anon_sym_DIV] = ACTIONS(2597),
    [anon_sym_Div] = ACTIONS(2597),
    [anon_sym_mod] = ACTIONS(2597),
    [anon_sym_MOD] = ACTIONS(2597),
    [anon_sym_Mod] = ACTIONS(2597),
    [anon_sym_PLUS] = ACTIONS(2597),
    [anon_sym_GT_EQ] = ACTIONS(2599),
    [anon_sym_LT_EQ] = ACTIONS(2599),
    [anon_sym_GT] = ACTIONS(2597),
    [anon_sym_LT] = ACTIONS(2597),
    [anon_sym_LT_GT] = ACTIONS(2599),
    [anon_sym_and] = ACTIONS(2597),
    [anon_sym_AND] = ACTIONS(2597),
    [anon_sym_And] = ACTIONS(2597),
    [anon_sym_or] = ACTIONS(2597),
    [anon_sym_OR] = ACTIONS(2597),
    [anon_sym_Or] = ACTIONS(2597),
    [anon_sym_xor] = ACTIONS(2597),
    [anon_sym_XOR] = ACTIONS(2597),
    [anon_sym_Xor] = ACTIONS(2597),
    [anon_sym_QMARK] = ACTIONS(2599),
    [sym_datetime_literal] = ACTIONS(2599),
    [sym_date_literal] = ACTIONS(2597),
    [sym_time_literal] = ACTIONS(2597),
    [sym_biginteger_literal] = ACTIONS(2599),
    [anon_sym_else] = ACTIONS(2597),
    [anon_sym_ELSE] = ACTIONS(2597),
    [anon_sym_Else] = ACTIONS(2597),
    [anon_sym_in] = ACTIONS(2597),
    [anon_sym_IN] = ACTIONS(2597),
    [anon_sym_In] = ACTIONS(2597),
    [sym_page_keyword] = ACTIONS(2597),
    [anon_sym_codeunit] = ACTIONS(2597),
    [anon_sym_CODEUNIT] = ACTIONS(2597),
    [anon_sym_Codeunit] = ACTIONS(2597),
    [anon_sym_CodeUnit] = ACTIONS(2597),
    [anon_sym_COdeunit] = ACTIONS(2597),
    [anon_sym_codeUnit] = ACTIONS(2597),
    [sym_report_keyword] = ACTIONS(2597),
    [sym_query_keyword] = ACTIONS(2597),
    [anon_sym_xmlport] = ACTIONS(2597),
    [anon_sym_XMLPORT] = ACTIONS(2597),
    [anon_sym_Xmlport] = ACTIONS(2597),
    [anon_sym_XMLport] = ACTIONS(2597),
    [anon_sym_XMLPort] = ACTIONS(2597),
    [anon_sym_XmlPort] = ACTIONS(2597),
    [anon_sym_enum] = ACTIONS(2597),
    [anon_sym_ENUM] = ACTIONS(2597),
    [anon_sym_Enum] = ACTIONS(2597),
    [anon_sym_eNUM] = ACTIONS(2597),
    [anon_sym_eNum] = ACTIONS(2597),
    [anon_sym_ENum] = ACTIONS(2597),
    [sym_quoted_identifier] = ACTIONS(2599),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2599),
    [sym_integer] = ACTIONS(2597),
    [sym_continue_as_identifier] = ACTIONS(2599),
    [sym_preproc_open] = ACTIONS(2599),
    [sym_preproc_close] = ACTIONS(2599),
  },
  [STATE(1526)] = {
    [sym_identifier] = ACTIONS(2601),
    [anon_sym_SEMI] = ACTIONS(2603),
    [anon_sym_DOT] = ACTIONS(2601),
    [anon_sym_EQ] = ACTIONS(2603),
    [anon_sym_COMMA] = ACTIONS(2603),
    [anon_sym_COLON] = ACTIONS(2601),
    [anon_sym_DASH] = ACTIONS(2601),
    [aux_sym_boolean_token1] = ACTIONS(2601),
    [aux_sym_boolean_token2] = ACTIONS(2601),
    [sym_decimal] = ACTIONS(2601),
    [anon_sym_LPAREN] = ACTIONS(2603),
    [anon_sym_DOT_DOT] = ACTIONS(2603),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2601),
    [anon_sym_STAR] = ACTIONS(2601),
    [anon_sym_LBRACK] = ACTIONS(2603),
    [aux_sym_record_type_token1] = ACTIONS(2601),
    [aux_sym_basic_type_token21] = ACTIONS(2601),
    [aux_sym_basic_type_token22] = ACTIONS(2601),
    [aux_sym_basic_type_token48] = ACTIONS(2601),
    [anon_sym_POUNDif] = ACTIONS(2603),
    [anon_sym_POUNDIF] = ACTIONS(2603),
    [anon_sym_POUNDIf] = ACTIONS(2603),
    [anon_sym_not] = ACTIONS(2601),
    [anon_sym_NOT] = ACTIONS(2601),
    [anon_sym_Not] = ACTIONS(2601),
    [anon_sym_POUNDelif] = ACTIONS(2603),
    [anon_sym_POUNDELIF] = ACTIONS(2603),
    [anon_sym_POUNDElif] = ACTIONS(2603),
    [anon_sym_POUNDelse] = ACTIONS(2603),
    [anon_sym_POUNDELSE] = ACTIONS(2603),
    [anon_sym_POUNDElse] = ACTIONS(2603),
    [anon_sym_POUNDendif] = ACTIONS(2603),
    [anon_sym_POUNDENDIF] = ACTIONS(2603),
    [anon_sym_POUNDEndif] = ACTIONS(2603),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2603),
    [aux_sym__expression_token1] = ACTIONS(2603),
    [aux_sym__expression_token2] = ACTIONS(2603),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2601),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2601),
    [anon_sym_SLASH] = ACTIONS(2601),
    [anon_sym_div] = ACTIONS(2601),
    [anon_sym_DIV] = ACTIONS(2601),
    [anon_sym_Div] = ACTIONS(2601),
    [anon_sym_mod] = ACTIONS(2601),
    [anon_sym_MOD] = ACTIONS(2601),
    [anon_sym_Mod] = ACTIONS(2601),
    [anon_sym_PLUS] = ACTIONS(2601),
    [anon_sym_GT_EQ] = ACTIONS(2603),
    [anon_sym_LT_EQ] = ACTIONS(2603),
    [anon_sym_GT] = ACTIONS(2601),
    [anon_sym_LT] = ACTIONS(2601),
    [anon_sym_LT_GT] = ACTIONS(2603),
    [anon_sym_and] = ACTIONS(2601),
    [anon_sym_AND] = ACTIONS(2601),
    [anon_sym_And] = ACTIONS(2601),
    [anon_sym_or] = ACTIONS(2601),
    [anon_sym_OR] = ACTIONS(2601),
    [anon_sym_Or] = ACTIONS(2601),
    [anon_sym_xor] = ACTIONS(2601),
    [anon_sym_XOR] = ACTIONS(2601),
    [anon_sym_Xor] = ACTIONS(2601),
    [anon_sym_QMARK] = ACTIONS(2603),
    [sym_datetime_literal] = ACTIONS(2603),
    [sym_date_literal] = ACTIONS(2601),
    [sym_time_literal] = ACTIONS(2601),
    [sym_biginteger_literal] = ACTIONS(2603),
    [anon_sym_else] = ACTIONS(2601),
    [anon_sym_ELSE] = ACTIONS(2601),
    [anon_sym_Else] = ACTIONS(2601),
    [anon_sym_in] = ACTIONS(2601),
    [anon_sym_IN] = ACTIONS(2601),
    [anon_sym_In] = ACTIONS(2601),
    [sym_page_keyword] = ACTIONS(2601),
    [anon_sym_codeunit] = ACTIONS(2601),
    [anon_sym_CODEUNIT] = ACTIONS(2601),
    [anon_sym_Codeunit] = ACTIONS(2601),
    [anon_sym_CodeUnit] = ACTIONS(2601),
    [anon_sym_COdeunit] = ACTIONS(2601),
    [anon_sym_codeUnit] = ACTIONS(2601),
    [sym_report_keyword] = ACTIONS(2601),
    [sym_query_keyword] = ACTIONS(2601),
    [anon_sym_xmlport] = ACTIONS(2601),
    [anon_sym_XMLPORT] = ACTIONS(2601),
    [anon_sym_Xmlport] = ACTIONS(2601),
    [anon_sym_XMLport] = ACTIONS(2601),
    [anon_sym_XMLPort] = ACTIONS(2601),
    [anon_sym_XmlPort] = ACTIONS(2601),
    [anon_sym_enum] = ACTIONS(2601),
    [anon_sym_ENUM] = ACTIONS(2601),
    [anon_sym_Enum] = ACTIONS(2601),
    [anon_sym_eNUM] = ACTIONS(2601),
    [anon_sym_eNum] = ACTIONS(2601),
    [anon_sym_ENum] = ACTIONS(2601),
    [sym_quoted_identifier] = ACTIONS(2603),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2603),
    [sym_integer] = ACTIONS(2601),
    [sym_continue_as_identifier] = ACTIONS(2603),
    [sym_preproc_open] = ACTIONS(2603),
    [sym_preproc_close] = ACTIONS(2603),
  },
  [STATE(1527)] = {
    [sym_comparison_operator] = STATE(3047),
    [sym_in_keyword] = STATE(11227),
    [sym_identifier] = ACTIONS(2378),
    [anon_sym_SEMI] = ACTIONS(2380),
    [anon_sym_DOT] = ACTIONS(3708),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2378),
    [aux_sym_boolean_token1] = ACTIONS(2378),
    [aux_sym_boolean_token2] = ACTIONS(2378),
    [sym_decimal] = ACTIONS(2378),
    [anon_sym_LPAREN] = ACTIONS(2380),
    [anon_sym_DOT_DOT] = ACTIONS(3712),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2378),
    [anon_sym_STAR] = ACTIONS(3714),
    [anon_sym_LBRACK] = ACTIONS(2380),
    [aux_sym_record_type_token1] = ACTIONS(2378),
    [aux_sym_basic_type_token21] = ACTIONS(2378),
    [aux_sym_basic_type_token22] = ACTIONS(2378),
    [aux_sym_basic_type_token48] = ACTIONS(2378),
    [anon_sym_POUNDif] = ACTIONS(2380),
    [anon_sym_POUNDIF] = ACTIONS(2380),
    [anon_sym_POUNDIf] = ACTIONS(2380),
    [anon_sym_not] = ACTIONS(2378),
    [anon_sym_NOT] = ACTIONS(2378),
    [anon_sym_Not] = ACTIONS(2378),
    [anon_sym_POUNDelif] = ACTIONS(2380),
    [anon_sym_POUNDELIF] = ACTIONS(2380),
    [anon_sym_POUNDElif] = ACTIONS(2380),
    [anon_sym_POUNDelse] = ACTIONS(2380),
    [anon_sym_POUNDELSE] = ACTIONS(2380),
    [anon_sym_POUNDElse] = ACTIONS(2380),
    [anon_sym_POUNDendif] = ACTIONS(2380),
    [anon_sym_POUNDENDIF] = ACTIONS(2380),
    [anon_sym_POUNDEndif] = ACTIONS(2380),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3764),
    [aux_sym__expression_token1] = ACTIONS(3718),
    [aux_sym__expression_token2] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2378),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2378),
    [anon_sym_SLASH] = ACTIONS(3722),
    [anon_sym_div] = ACTIONS(3724),
    [anon_sym_DIV] = ACTIONS(3726),
    [anon_sym_Div] = ACTIONS(3728),
    [anon_sym_mod] = ACTIONS(3730),
    [anon_sym_MOD] = ACTIONS(3732),
    [anon_sym_Mod] = ACTIONS(3734),
    [anon_sym_PLUS] = ACTIONS(2378),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3740),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(3766),
    [anon_sym_OR] = ACTIONS(3768),
    [anon_sym_Or] = ACTIONS(3770),
    [anon_sym_xor] = ACTIONS(3772),
    [anon_sym_XOR] = ACTIONS(3774),
    [anon_sym_Xor] = ACTIONS(3776),
    [anon_sym_QMARK] = ACTIONS(3778),
    [sym_datetime_literal] = ACTIONS(2380),
    [sym_date_literal] = ACTIONS(2378),
    [sym_time_literal] = ACTIONS(2378),
    [sym_biginteger_literal] = ACTIONS(2380),
    [anon_sym_else] = ACTIONS(2378),
    [anon_sym_ELSE] = ACTIONS(2378),
    [anon_sym_Else] = ACTIONS(2378),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2378),
    [anon_sym_codeunit] = ACTIONS(2378),
    [anon_sym_CODEUNIT] = ACTIONS(2378),
    [anon_sym_Codeunit] = ACTIONS(2378),
    [anon_sym_CodeUnit] = ACTIONS(2378),
    [anon_sym_COdeunit] = ACTIONS(2378),
    [anon_sym_codeUnit] = ACTIONS(2378),
    [sym_report_keyword] = ACTIONS(2378),
    [sym_query_keyword] = ACTIONS(2378),
    [anon_sym_xmlport] = ACTIONS(2378),
    [anon_sym_XMLPORT] = ACTIONS(2378),
    [anon_sym_Xmlport] = ACTIONS(2378),
    [anon_sym_XMLport] = ACTIONS(2378),
    [anon_sym_XMLPort] = ACTIONS(2378),
    [anon_sym_XmlPort] = ACTIONS(2378),
    [anon_sym_enum] = ACTIONS(2378),
    [anon_sym_ENUM] = ACTIONS(2378),
    [anon_sym_Enum] = ACTIONS(2378),
    [anon_sym_eNUM] = ACTIONS(2378),
    [anon_sym_eNum] = ACTIONS(2378),
    [anon_sym_ENum] = ACTIONS(2378),
    [sym_quoted_identifier] = ACTIONS(2380),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2380),
    [sym_integer] = ACTIONS(2378),
    [sym_continue_as_identifier] = ACTIONS(2380),
    [sym_preproc_open] = ACTIONS(2380),
    [sym_preproc_close] = ACTIONS(2380),
  },
  [STATE(1528)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_SEMI] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_COMMA] = ACTIONS(2595),
    [anon_sym_COLON] = ACTIONS(2593),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [anon_sym_POUNDif] = ACTIONS(2595),
    [anon_sym_POUNDIF] = ACTIONS(2595),
    [anon_sym_POUNDIf] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [anon_sym_POUNDelif] = ACTIONS(2595),
    [anon_sym_POUNDELIF] = ACTIONS(2595),
    [anon_sym_POUNDElif] = ACTIONS(2595),
    [anon_sym_POUNDelse] = ACTIONS(2595),
    [anon_sym_POUNDELSE] = ACTIONS(2595),
    [anon_sym_POUNDElse] = ACTIONS(2595),
    [anon_sym_POUNDendif] = ACTIONS(2595),
    [anon_sym_POUNDENDIF] = ACTIONS(2595),
    [anon_sym_POUNDEndif] = ACTIONS(2595),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2595),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_else] = ACTIONS(2593),
    [anon_sym_ELSE] = ACTIONS(2593),
    [anon_sym_Else] = ACTIONS(2593),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_open] = ACTIONS(2595),
    [sym_preproc_close] = ACTIONS(2595),
  },
  [STATE(1529)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_SEMI] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_COMMA] = ACTIONS(2595),
    [anon_sym_COLON] = ACTIONS(2593),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [anon_sym_POUNDif] = ACTIONS(2595),
    [anon_sym_POUNDIF] = ACTIONS(2595),
    [anon_sym_POUNDIf] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [anon_sym_POUNDelif] = ACTIONS(2595),
    [anon_sym_POUNDELIF] = ACTIONS(2595),
    [anon_sym_POUNDElif] = ACTIONS(2595),
    [anon_sym_POUNDelse] = ACTIONS(2595),
    [anon_sym_POUNDELSE] = ACTIONS(2595),
    [anon_sym_POUNDElse] = ACTIONS(2595),
    [anon_sym_POUNDendif] = ACTIONS(2595),
    [anon_sym_POUNDENDIF] = ACTIONS(2595),
    [anon_sym_POUNDEndif] = ACTIONS(2595),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2595),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_else] = ACTIONS(2593),
    [anon_sym_ELSE] = ACTIONS(2593),
    [anon_sym_Else] = ACTIONS(2593),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_open] = ACTIONS(2595),
    [sym_preproc_close] = ACTIONS(2595),
  },
  [STATE(1530)] = {
    [sym_identifier] = ACTIONS(2625),
    [anon_sym_SEMI] = ACTIONS(2627),
    [anon_sym_DOT] = ACTIONS(2625),
    [anon_sym_EQ] = ACTIONS(2627),
    [anon_sym_COMMA] = ACTIONS(2627),
    [anon_sym_COLON] = ACTIONS(2625),
    [anon_sym_DASH] = ACTIONS(2625),
    [aux_sym_boolean_token1] = ACTIONS(2625),
    [aux_sym_boolean_token2] = ACTIONS(2625),
    [sym_decimal] = ACTIONS(2625),
    [anon_sym_LPAREN] = ACTIONS(2627),
    [anon_sym_DOT_DOT] = ACTIONS(2627),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2625),
    [anon_sym_STAR] = ACTIONS(2625),
    [anon_sym_LBRACK] = ACTIONS(2627),
    [aux_sym_record_type_token1] = ACTIONS(2625),
    [aux_sym_basic_type_token21] = ACTIONS(2625),
    [aux_sym_basic_type_token22] = ACTIONS(2625),
    [aux_sym_basic_type_token48] = ACTIONS(2625),
    [anon_sym_POUNDif] = ACTIONS(2627),
    [anon_sym_POUNDIF] = ACTIONS(2627),
    [anon_sym_POUNDIf] = ACTIONS(2627),
    [anon_sym_not] = ACTIONS(2625),
    [anon_sym_NOT] = ACTIONS(2625),
    [anon_sym_Not] = ACTIONS(2625),
    [anon_sym_POUNDelif] = ACTIONS(2627),
    [anon_sym_POUNDELIF] = ACTIONS(2627),
    [anon_sym_POUNDElif] = ACTIONS(2627),
    [anon_sym_POUNDelse] = ACTIONS(2627),
    [anon_sym_POUNDELSE] = ACTIONS(2627),
    [anon_sym_POUNDElse] = ACTIONS(2627),
    [anon_sym_POUNDendif] = ACTIONS(2627),
    [anon_sym_POUNDENDIF] = ACTIONS(2627),
    [anon_sym_POUNDEndif] = ACTIONS(2627),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2627),
    [aux_sym__expression_token1] = ACTIONS(2627),
    [aux_sym__expression_token2] = ACTIONS(2627),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2625),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2625),
    [anon_sym_SLASH] = ACTIONS(2625),
    [anon_sym_div] = ACTIONS(2625),
    [anon_sym_DIV] = ACTIONS(2625),
    [anon_sym_Div] = ACTIONS(2625),
    [anon_sym_mod] = ACTIONS(2625),
    [anon_sym_MOD] = ACTIONS(2625),
    [anon_sym_Mod] = ACTIONS(2625),
    [anon_sym_PLUS] = ACTIONS(2625),
    [anon_sym_GT_EQ] = ACTIONS(2627),
    [anon_sym_LT_EQ] = ACTIONS(2627),
    [anon_sym_GT] = ACTIONS(2625),
    [anon_sym_LT] = ACTIONS(2625),
    [anon_sym_LT_GT] = ACTIONS(2627),
    [anon_sym_and] = ACTIONS(2625),
    [anon_sym_AND] = ACTIONS(2625),
    [anon_sym_And] = ACTIONS(2625),
    [anon_sym_or] = ACTIONS(2625),
    [anon_sym_OR] = ACTIONS(2625),
    [anon_sym_Or] = ACTIONS(2625),
    [anon_sym_xor] = ACTIONS(2625),
    [anon_sym_XOR] = ACTIONS(2625),
    [anon_sym_Xor] = ACTIONS(2625),
    [anon_sym_QMARK] = ACTIONS(2627),
    [sym_datetime_literal] = ACTIONS(2627),
    [sym_date_literal] = ACTIONS(2625),
    [sym_time_literal] = ACTIONS(2625),
    [sym_biginteger_literal] = ACTIONS(2627),
    [anon_sym_else] = ACTIONS(2625),
    [anon_sym_ELSE] = ACTIONS(2625),
    [anon_sym_Else] = ACTIONS(2625),
    [anon_sym_in] = ACTIONS(2625),
    [anon_sym_IN] = ACTIONS(2625),
    [anon_sym_In] = ACTIONS(2625),
    [sym_page_keyword] = ACTIONS(2625),
    [anon_sym_codeunit] = ACTIONS(2625),
    [anon_sym_CODEUNIT] = ACTIONS(2625),
    [anon_sym_Codeunit] = ACTIONS(2625),
    [anon_sym_CodeUnit] = ACTIONS(2625),
    [anon_sym_COdeunit] = ACTIONS(2625),
    [anon_sym_codeUnit] = ACTIONS(2625),
    [sym_report_keyword] = ACTIONS(2625),
    [sym_query_keyword] = ACTIONS(2625),
    [anon_sym_xmlport] = ACTIONS(2625),
    [anon_sym_XMLPORT] = ACTIONS(2625),
    [anon_sym_Xmlport] = ACTIONS(2625),
    [anon_sym_XMLport] = ACTIONS(2625),
    [anon_sym_XMLPort] = ACTIONS(2625),
    [anon_sym_XmlPort] = ACTIONS(2625),
    [anon_sym_enum] = ACTIONS(2625),
    [anon_sym_ENUM] = ACTIONS(2625),
    [anon_sym_Enum] = ACTIONS(2625),
    [anon_sym_eNUM] = ACTIONS(2625),
    [anon_sym_eNum] = ACTIONS(2625),
    [anon_sym_ENum] = ACTIONS(2625),
    [sym_quoted_identifier] = ACTIONS(2627),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2627),
    [sym_integer] = ACTIONS(2625),
    [sym_continue_as_identifier] = ACTIONS(2627),
    [sym_preproc_open] = ACTIONS(2627),
    [sym_preproc_close] = ACTIONS(2627),
  },
  [STATE(1531)] = {
    [sym_else_keyword] = STATE(13),
    [sym_identifier] = ACTIONS(4119),
    [anon_sym_SEMI] = ACTIONS(4121),
    [anon_sym_DASH] = ACTIONS(4121),
    [aux_sym_boolean_token1] = ACTIONS(4119),
    [aux_sym_boolean_token2] = ACTIONS(4119),
    [sym_decimal] = ACTIONS(4119),
    [anon_sym_LPAREN] = ACTIONS(4121),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4119),
    [anon_sym_LBRACK] = ACTIONS(4121),
    [aux_sym_record_type_token1] = ACTIONS(4119),
    [aux_sym_basic_type_token21] = ACTIONS(4119),
    [aux_sym_basic_type_token22] = ACTIONS(4119),
    [aux_sym_basic_type_token48] = ACTIONS(4119),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4119),
    [anon_sym_POUNDif] = ACTIONS(4121),
    [anon_sym_POUNDIF] = ACTIONS(4121),
    [anon_sym_POUNDIf] = ACTIONS(4121),
    [anon_sym_not] = ACTIONS(4119),
    [anon_sym_NOT] = ACTIONS(4119),
    [anon_sym_Not] = ACTIONS(4119),
    [anon_sym_POUNDelif] = ACTIONS(4121),
    [anon_sym_POUNDELIF] = ACTIONS(4121),
    [anon_sym_POUNDElif] = ACTIONS(4121),
    [anon_sym_POUNDelse] = ACTIONS(4121),
    [anon_sym_POUNDELSE] = ACTIONS(4121),
    [anon_sym_POUNDElse] = ACTIONS(4121),
    [anon_sym_POUNDendif] = ACTIONS(4121),
    [anon_sym_POUNDENDIF] = ACTIONS(4121),
    [anon_sym_POUNDEndif] = ACTIONS(4121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4119),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4119),
    [anon_sym_PLUS] = ACTIONS(4121),
    [sym_datetime_literal] = ACTIONS(4121),
    [sym_date_literal] = ACTIONS(4119),
    [sym_time_literal] = ACTIONS(4119),
    [sym_biginteger_literal] = ACTIONS(4121),
    [anon_sym_if] = ACTIONS(4119),
    [anon_sym_IF] = ACTIONS(4119),
    [anon_sym_If] = ACTIONS(4119),
    [anon_sym_else] = ACTIONS(4123),
    [anon_sym_ELSE] = ACTIONS(4123),
    [anon_sym_Else] = ACTIONS(4123),
    [anon_sym_case] = ACTIONS(4119),
    [anon_sym_CASE] = ACTIONS(4119),
    [anon_sym_Case] = ACTIONS(4119),
    [anon_sym_for] = ACTIONS(4119),
    [anon_sym_FOR] = ACTIONS(4119),
    [anon_sym_For] = ACTIONS(4119),
    [anon_sym_foreach] = ACTIONS(4119),
    [anon_sym_FOREACH] = ACTIONS(4119),
    [anon_sym_Foreach] = ACTIONS(4119),
    [anon_sym_while] = ACTIONS(4119),
    [anon_sym_WHILE] = ACTIONS(4119),
    [anon_sym_While] = ACTIONS(4119),
    [anon_sym_repeat] = ACTIONS(4119),
    [anon_sym_REPEAT] = ACTIONS(4119),
    [anon_sym_Repeat] = ACTIONS(4119),
    [anon_sym_exit] = ACTIONS(4119),
    [anon_sym_EXIT] = ACTIONS(4119),
    [anon_sym_Exit] = ACTIONS(4119),
    [anon_sym_continue] = ACTIONS(4119),
    [anon_sym_CONTINUE] = ACTIONS(4119),
    [anon_sym_Continue] = ACTIONS(4119),
    [anon_sym_break] = ACTIONS(4119),
    [anon_sym_BREAK] = ACTIONS(4119),
    [anon_sym_Break] = ACTIONS(4119),
    [anon_sym_with] = ACTIONS(4119),
    [anon_sym_WITH] = ACTIONS(4119),
    [anon_sym_With] = ACTIONS(4119),
    [sym_asserterror_keyword] = ACTIONS(4121),
    [sym_page_keyword] = ACTIONS(4119),
    [anon_sym_codeunit] = ACTIONS(4119),
    [anon_sym_CODEUNIT] = ACTIONS(4119),
    [anon_sym_Codeunit] = ACTIONS(4119),
    [anon_sym_CodeUnit] = ACTIONS(4119),
    [anon_sym_COdeunit] = ACTIONS(4119),
    [anon_sym_codeUnit] = ACTIONS(4119),
    [sym_report_keyword] = ACTIONS(4119),
    [sym_query_keyword] = ACTIONS(4119),
    [anon_sym_xmlport] = ACTIONS(4119),
    [anon_sym_XMLPORT] = ACTIONS(4119),
    [anon_sym_Xmlport] = ACTIONS(4119),
    [anon_sym_XMLport] = ACTIONS(4119),
    [anon_sym_XMLPort] = ACTIONS(4119),
    [anon_sym_XmlPort] = ACTIONS(4119),
    [anon_sym_enum] = ACTIONS(4119),
    [anon_sym_ENUM] = ACTIONS(4119),
    [anon_sym_Enum] = ACTIONS(4119),
    [anon_sym_eNUM] = ACTIONS(4119),
    [anon_sym_eNum] = ACTIONS(4119),
    [anon_sym_ENum] = ACTIONS(4119),
    [sym_quoted_identifier] = ACTIONS(4121),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4121),
    [sym_integer] = ACTIONS(4119),
    [sym_continue_as_identifier] = ACTIONS(4121),
    [sym_preproc_open] = ACTIONS(4121),
    [sym_preproc_close] = ACTIONS(4121),
  },
  [STATE(1532)] = {
    [sym_else_keyword] = STATE(14),
    [sym_identifier] = ACTIONS(4125),
    [anon_sym_SEMI] = ACTIONS(4127),
    [anon_sym_DASH] = ACTIONS(4127),
    [aux_sym_boolean_token1] = ACTIONS(4125),
    [aux_sym_boolean_token2] = ACTIONS(4125),
    [sym_decimal] = ACTIONS(4125),
    [anon_sym_LPAREN] = ACTIONS(4127),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4125),
    [anon_sym_LBRACK] = ACTIONS(4127),
    [aux_sym_record_type_token1] = ACTIONS(4125),
    [aux_sym_basic_type_token21] = ACTIONS(4125),
    [aux_sym_basic_type_token22] = ACTIONS(4125),
    [aux_sym_basic_type_token48] = ACTIONS(4125),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4125),
    [anon_sym_POUNDif] = ACTIONS(4127),
    [anon_sym_POUNDIF] = ACTIONS(4127),
    [anon_sym_POUNDIf] = ACTIONS(4127),
    [anon_sym_not] = ACTIONS(4125),
    [anon_sym_NOT] = ACTIONS(4125),
    [anon_sym_Not] = ACTIONS(4125),
    [anon_sym_POUNDelif] = ACTIONS(4127),
    [anon_sym_POUNDELIF] = ACTIONS(4127),
    [anon_sym_POUNDElif] = ACTIONS(4127),
    [anon_sym_POUNDelse] = ACTIONS(4127),
    [anon_sym_POUNDELSE] = ACTIONS(4127),
    [anon_sym_POUNDElse] = ACTIONS(4127),
    [anon_sym_POUNDendif] = ACTIONS(4127),
    [anon_sym_POUNDENDIF] = ACTIONS(4127),
    [anon_sym_POUNDEndif] = ACTIONS(4127),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4125),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4125),
    [anon_sym_PLUS] = ACTIONS(4127),
    [sym_datetime_literal] = ACTIONS(4127),
    [sym_date_literal] = ACTIONS(4125),
    [sym_time_literal] = ACTIONS(4125),
    [sym_biginteger_literal] = ACTIONS(4127),
    [anon_sym_if] = ACTIONS(4125),
    [anon_sym_IF] = ACTIONS(4125),
    [anon_sym_If] = ACTIONS(4125),
    [anon_sym_else] = ACTIONS(4123),
    [anon_sym_ELSE] = ACTIONS(4123),
    [anon_sym_Else] = ACTIONS(4123),
    [anon_sym_case] = ACTIONS(4125),
    [anon_sym_CASE] = ACTIONS(4125),
    [anon_sym_Case] = ACTIONS(4125),
    [anon_sym_for] = ACTIONS(4125),
    [anon_sym_FOR] = ACTIONS(4125),
    [anon_sym_For] = ACTIONS(4125),
    [anon_sym_foreach] = ACTIONS(4125),
    [anon_sym_FOREACH] = ACTIONS(4125),
    [anon_sym_Foreach] = ACTIONS(4125),
    [anon_sym_while] = ACTIONS(4125),
    [anon_sym_WHILE] = ACTIONS(4125),
    [anon_sym_While] = ACTIONS(4125),
    [anon_sym_repeat] = ACTIONS(4125),
    [anon_sym_REPEAT] = ACTIONS(4125),
    [anon_sym_Repeat] = ACTIONS(4125),
    [anon_sym_exit] = ACTIONS(4125),
    [anon_sym_EXIT] = ACTIONS(4125),
    [anon_sym_Exit] = ACTIONS(4125),
    [anon_sym_continue] = ACTIONS(4125),
    [anon_sym_CONTINUE] = ACTIONS(4125),
    [anon_sym_Continue] = ACTIONS(4125),
    [anon_sym_break] = ACTIONS(4125),
    [anon_sym_BREAK] = ACTIONS(4125),
    [anon_sym_Break] = ACTIONS(4125),
    [anon_sym_with] = ACTIONS(4125),
    [anon_sym_WITH] = ACTIONS(4125),
    [anon_sym_With] = ACTIONS(4125),
    [sym_asserterror_keyword] = ACTIONS(4127),
    [sym_page_keyword] = ACTIONS(4125),
    [anon_sym_codeunit] = ACTIONS(4125),
    [anon_sym_CODEUNIT] = ACTIONS(4125),
    [anon_sym_Codeunit] = ACTIONS(4125),
    [anon_sym_CodeUnit] = ACTIONS(4125),
    [anon_sym_COdeunit] = ACTIONS(4125),
    [anon_sym_codeUnit] = ACTIONS(4125),
    [sym_report_keyword] = ACTIONS(4125),
    [sym_query_keyword] = ACTIONS(4125),
    [anon_sym_xmlport] = ACTIONS(4125),
    [anon_sym_XMLPORT] = ACTIONS(4125),
    [anon_sym_Xmlport] = ACTIONS(4125),
    [anon_sym_XMLport] = ACTIONS(4125),
    [anon_sym_XMLPort] = ACTIONS(4125),
    [anon_sym_XmlPort] = ACTIONS(4125),
    [anon_sym_enum] = ACTIONS(4125),
    [anon_sym_ENUM] = ACTIONS(4125),
    [anon_sym_Enum] = ACTIONS(4125),
    [anon_sym_eNUM] = ACTIONS(4125),
    [anon_sym_eNum] = ACTIONS(4125),
    [anon_sym_ENum] = ACTIONS(4125),
    [sym_quoted_identifier] = ACTIONS(4127),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4127),
    [sym_integer] = ACTIONS(4125),
    [sym_continue_as_identifier] = ACTIONS(4127),
    [sym_preproc_open] = ACTIONS(4127),
    [sym_preproc_close] = ACTIONS(4127),
  },
  [STATE(1533)] = {
    [sym_else_keyword] = STATE(281),
    [sym_identifier] = ACTIONS(4119),
    [anon_sym_SEMI] = ACTIONS(4121),
    [anon_sym_DASH] = ACTIONS(4121),
    [aux_sym_boolean_token1] = ACTIONS(4119),
    [aux_sym_boolean_token2] = ACTIONS(4119),
    [sym_decimal] = ACTIONS(4119),
    [anon_sym_LPAREN] = ACTIONS(4121),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4119),
    [anon_sym_LBRACK] = ACTIONS(4121),
    [aux_sym_record_type_token1] = ACTIONS(4119),
    [aux_sym_basic_type_token21] = ACTIONS(4119),
    [aux_sym_basic_type_token22] = ACTIONS(4119),
    [aux_sym_basic_type_token48] = ACTIONS(4119),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4119),
    [anon_sym_POUNDif] = ACTIONS(4121),
    [anon_sym_POUNDIF] = ACTIONS(4121),
    [anon_sym_POUNDIf] = ACTIONS(4121),
    [anon_sym_not] = ACTIONS(4119),
    [anon_sym_NOT] = ACTIONS(4119),
    [anon_sym_Not] = ACTIONS(4119),
    [anon_sym_POUNDelif] = ACTIONS(4121),
    [anon_sym_POUNDELIF] = ACTIONS(4121),
    [anon_sym_POUNDElif] = ACTIONS(4121),
    [anon_sym_POUNDelse] = ACTIONS(4121),
    [anon_sym_POUNDELSE] = ACTIONS(4121),
    [anon_sym_POUNDElse] = ACTIONS(4121),
    [anon_sym_POUNDendif] = ACTIONS(4121),
    [anon_sym_POUNDENDIF] = ACTIONS(4121),
    [anon_sym_POUNDEndif] = ACTIONS(4121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4119),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4119),
    [anon_sym_PLUS] = ACTIONS(4121),
    [sym_datetime_literal] = ACTIONS(4121),
    [sym_date_literal] = ACTIONS(4119),
    [sym_time_literal] = ACTIONS(4119),
    [sym_biginteger_literal] = ACTIONS(4121),
    [anon_sym_if] = ACTIONS(4119),
    [anon_sym_IF] = ACTIONS(4119),
    [anon_sym_If] = ACTIONS(4119),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4119),
    [anon_sym_CASE] = ACTIONS(4119),
    [anon_sym_Case] = ACTIONS(4119),
    [anon_sym_for] = ACTIONS(4119),
    [anon_sym_FOR] = ACTIONS(4119),
    [anon_sym_For] = ACTIONS(4119),
    [anon_sym_foreach] = ACTIONS(4119),
    [anon_sym_FOREACH] = ACTIONS(4119),
    [anon_sym_Foreach] = ACTIONS(4119),
    [anon_sym_while] = ACTIONS(4119),
    [anon_sym_WHILE] = ACTIONS(4119),
    [anon_sym_While] = ACTIONS(4119),
    [anon_sym_repeat] = ACTIONS(4119),
    [anon_sym_REPEAT] = ACTIONS(4119),
    [anon_sym_Repeat] = ACTIONS(4119),
    [anon_sym_exit] = ACTIONS(4119),
    [anon_sym_EXIT] = ACTIONS(4119),
    [anon_sym_Exit] = ACTIONS(4119),
    [anon_sym_continue] = ACTIONS(4119),
    [anon_sym_CONTINUE] = ACTIONS(4119),
    [anon_sym_Continue] = ACTIONS(4119),
    [anon_sym_break] = ACTIONS(4119),
    [anon_sym_BREAK] = ACTIONS(4119),
    [anon_sym_Break] = ACTIONS(4119),
    [anon_sym_with] = ACTIONS(4119),
    [anon_sym_WITH] = ACTIONS(4119),
    [anon_sym_With] = ACTIONS(4119),
    [sym_asserterror_keyword] = ACTIONS(4121),
    [sym_page_keyword] = ACTIONS(4119),
    [anon_sym_codeunit] = ACTIONS(4119),
    [anon_sym_CODEUNIT] = ACTIONS(4119),
    [anon_sym_Codeunit] = ACTIONS(4119),
    [anon_sym_CodeUnit] = ACTIONS(4119),
    [anon_sym_COdeunit] = ACTIONS(4119),
    [anon_sym_codeUnit] = ACTIONS(4119),
    [sym_report_keyword] = ACTIONS(4119),
    [sym_query_keyword] = ACTIONS(4119),
    [anon_sym_xmlport] = ACTIONS(4119),
    [anon_sym_XMLPORT] = ACTIONS(4119),
    [anon_sym_Xmlport] = ACTIONS(4119),
    [anon_sym_XMLport] = ACTIONS(4119),
    [anon_sym_XMLPort] = ACTIONS(4119),
    [anon_sym_XmlPort] = ACTIONS(4119),
    [anon_sym_enum] = ACTIONS(4119),
    [anon_sym_ENUM] = ACTIONS(4119),
    [anon_sym_Enum] = ACTIONS(4119),
    [anon_sym_eNUM] = ACTIONS(4119),
    [anon_sym_eNum] = ACTIONS(4119),
    [anon_sym_ENum] = ACTIONS(4119),
    [sym_quoted_identifier] = ACTIONS(4121),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4121),
    [sym_integer] = ACTIONS(4119),
    [sym_continue_as_identifier] = ACTIONS(4121),
    [sym_preproc_open] = ACTIONS(4121),
    [sym_preproc_close] = ACTIONS(4121),
  },
  [STATE(1534)] = {
    [sym_else_keyword] = STATE(261),
    [sym_identifier] = ACTIONS(4131),
    [anon_sym_SEMI] = ACTIONS(4133),
    [anon_sym_DASH] = ACTIONS(4133),
    [aux_sym_boolean_token1] = ACTIONS(4131),
    [aux_sym_boolean_token2] = ACTIONS(4131),
    [sym_decimal] = ACTIONS(4131),
    [anon_sym_LPAREN] = ACTIONS(4133),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4131),
    [anon_sym_LBRACK] = ACTIONS(4133),
    [aux_sym_record_type_token1] = ACTIONS(4131),
    [aux_sym_basic_type_token21] = ACTIONS(4131),
    [aux_sym_basic_type_token22] = ACTIONS(4131),
    [aux_sym_basic_type_token48] = ACTIONS(4131),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4131),
    [anon_sym_POUNDif] = ACTIONS(4133),
    [anon_sym_POUNDIF] = ACTIONS(4133),
    [anon_sym_POUNDIf] = ACTIONS(4133),
    [anon_sym_not] = ACTIONS(4131),
    [anon_sym_NOT] = ACTIONS(4131),
    [anon_sym_Not] = ACTIONS(4131),
    [anon_sym_POUNDelif] = ACTIONS(4133),
    [anon_sym_POUNDELIF] = ACTIONS(4133),
    [anon_sym_POUNDElif] = ACTIONS(4133),
    [anon_sym_POUNDelse] = ACTIONS(4133),
    [anon_sym_POUNDELSE] = ACTIONS(4133),
    [anon_sym_POUNDElse] = ACTIONS(4133),
    [anon_sym_POUNDendif] = ACTIONS(4133),
    [anon_sym_POUNDENDIF] = ACTIONS(4133),
    [anon_sym_POUNDEndif] = ACTIONS(4133),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4131),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4131),
    [anon_sym_PLUS] = ACTIONS(4133),
    [sym_datetime_literal] = ACTIONS(4133),
    [sym_date_literal] = ACTIONS(4131),
    [sym_time_literal] = ACTIONS(4131),
    [sym_biginteger_literal] = ACTIONS(4133),
    [anon_sym_if] = ACTIONS(4131),
    [anon_sym_IF] = ACTIONS(4131),
    [anon_sym_If] = ACTIONS(4131),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4131),
    [anon_sym_CASE] = ACTIONS(4131),
    [anon_sym_Case] = ACTIONS(4131),
    [anon_sym_for] = ACTIONS(4131),
    [anon_sym_FOR] = ACTIONS(4131),
    [anon_sym_For] = ACTIONS(4131),
    [anon_sym_foreach] = ACTIONS(4131),
    [anon_sym_FOREACH] = ACTIONS(4131),
    [anon_sym_Foreach] = ACTIONS(4131),
    [anon_sym_while] = ACTIONS(4131),
    [anon_sym_WHILE] = ACTIONS(4131),
    [anon_sym_While] = ACTIONS(4131),
    [anon_sym_repeat] = ACTIONS(4131),
    [anon_sym_REPEAT] = ACTIONS(4131),
    [anon_sym_Repeat] = ACTIONS(4131),
    [anon_sym_exit] = ACTIONS(4131),
    [anon_sym_EXIT] = ACTIONS(4131),
    [anon_sym_Exit] = ACTIONS(4131),
    [anon_sym_continue] = ACTIONS(4131),
    [anon_sym_CONTINUE] = ACTIONS(4131),
    [anon_sym_Continue] = ACTIONS(4131),
    [anon_sym_break] = ACTIONS(4131),
    [anon_sym_BREAK] = ACTIONS(4131),
    [anon_sym_Break] = ACTIONS(4131),
    [anon_sym_with] = ACTIONS(4131),
    [anon_sym_WITH] = ACTIONS(4131),
    [anon_sym_With] = ACTIONS(4131),
    [sym_asserterror_keyword] = ACTIONS(4133),
    [sym_page_keyword] = ACTIONS(4131),
    [anon_sym_codeunit] = ACTIONS(4131),
    [anon_sym_CODEUNIT] = ACTIONS(4131),
    [anon_sym_Codeunit] = ACTIONS(4131),
    [anon_sym_CodeUnit] = ACTIONS(4131),
    [anon_sym_COdeunit] = ACTIONS(4131),
    [anon_sym_codeUnit] = ACTIONS(4131),
    [sym_report_keyword] = ACTIONS(4131),
    [sym_query_keyword] = ACTIONS(4131),
    [anon_sym_xmlport] = ACTIONS(4131),
    [anon_sym_XMLPORT] = ACTIONS(4131),
    [anon_sym_Xmlport] = ACTIONS(4131),
    [anon_sym_XMLport] = ACTIONS(4131),
    [anon_sym_XMLPort] = ACTIONS(4131),
    [anon_sym_XmlPort] = ACTIONS(4131),
    [anon_sym_enum] = ACTIONS(4131),
    [anon_sym_ENUM] = ACTIONS(4131),
    [anon_sym_Enum] = ACTIONS(4131),
    [anon_sym_eNUM] = ACTIONS(4131),
    [anon_sym_eNum] = ACTIONS(4131),
    [anon_sym_ENum] = ACTIONS(4131),
    [sym_quoted_identifier] = ACTIONS(4133),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4133),
    [sym_integer] = ACTIONS(4131),
    [sym_continue_as_identifier] = ACTIONS(4133),
    [sym_preproc_open] = ACTIONS(4133),
    [sym_preproc_close] = ACTIONS(4133),
  },
  [STATE(1535)] = {
    [sym_else_keyword] = STATE(282),
    [sym_identifier] = ACTIONS(4125),
    [anon_sym_SEMI] = ACTIONS(4127),
    [anon_sym_DASH] = ACTIONS(4127),
    [aux_sym_boolean_token1] = ACTIONS(4125),
    [aux_sym_boolean_token2] = ACTIONS(4125),
    [sym_decimal] = ACTIONS(4125),
    [anon_sym_LPAREN] = ACTIONS(4127),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4125),
    [anon_sym_LBRACK] = ACTIONS(4127),
    [aux_sym_record_type_token1] = ACTIONS(4125),
    [aux_sym_basic_type_token21] = ACTIONS(4125),
    [aux_sym_basic_type_token22] = ACTIONS(4125),
    [aux_sym_basic_type_token48] = ACTIONS(4125),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4125),
    [anon_sym_POUNDif] = ACTIONS(4127),
    [anon_sym_POUNDIF] = ACTIONS(4127),
    [anon_sym_POUNDIf] = ACTIONS(4127),
    [anon_sym_not] = ACTIONS(4125),
    [anon_sym_NOT] = ACTIONS(4125),
    [anon_sym_Not] = ACTIONS(4125),
    [anon_sym_POUNDelif] = ACTIONS(4127),
    [anon_sym_POUNDELIF] = ACTIONS(4127),
    [anon_sym_POUNDElif] = ACTIONS(4127),
    [anon_sym_POUNDelse] = ACTIONS(4127),
    [anon_sym_POUNDELSE] = ACTIONS(4127),
    [anon_sym_POUNDElse] = ACTIONS(4127),
    [anon_sym_POUNDendif] = ACTIONS(4127),
    [anon_sym_POUNDENDIF] = ACTIONS(4127),
    [anon_sym_POUNDEndif] = ACTIONS(4127),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4125),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4125),
    [anon_sym_PLUS] = ACTIONS(4127),
    [sym_datetime_literal] = ACTIONS(4127),
    [sym_date_literal] = ACTIONS(4125),
    [sym_time_literal] = ACTIONS(4125),
    [sym_biginteger_literal] = ACTIONS(4127),
    [anon_sym_if] = ACTIONS(4125),
    [anon_sym_IF] = ACTIONS(4125),
    [anon_sym_If] = ACTIONS(4125),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4125),
    [anon_sym_CASE] = ACTIONS(4125),
    [anon_sym_Case] = ACTIONS(4125),
    [anon_sym_for] = ACTIONS(4125),
    [anon_sym_FOR] = ACTIONS(4125),
    [anon_sym_For] = ACTIONS(4125),
    [anon_sym_foreach] = ACTIONS(4125),
    [anon_sym_FOREACH] = ACTIONS(4125),
    [anon_sym_Foreach] = ACTIONS(4125),
    [anon_sym_while] = ACTIONS(4125),
    [anon_sym_WHILE] = ACTIONS(4125),
    [anon_sym_While] = ACTIONS(4125),
    [anon_sym_repeat] = ACTIONS(4125),
    [anon_sym_REPEAT] = ACTIONS(4125),
    [anon_sym_Repeat] = ACTIONS(4125),
    [anon_sym_exit] = ACTIONS(4125),
    [anon_sym_EXIT] = ACTIONS(4125),
    [anon_sym_Exit] = ACTIONS(4125),
    [anon_sym_continue] = ACTIONS(4125),
    [anon_sym_CONTINUE] = ACTIONS(4125),
    [anon_sym_Continue] = ACTIONS(4125),
    [anon_sym_break] = ACTIONS(4125),
    [anon_sym_BREAK] = ACTIONS(4125),
    [anon_sym_Break] = ACTIONS(4125),
    [anon_sym_with] = ACTIONS(4125),
    [anon_sym_WITH] = ACTIONS(4125),
    [anon_sym_With] = ACTIONS(4125),
    [sym_asserterror_keyword] = ACTIONS(4127),
    [sym_page_keyword] = ACTIONS(4125),
    [anon_sym_codeunit] = ACTIONS(4125),
    [anon_sym_CODEUNIT] = ACTIONS(4125),
    [anon_sym_Codeunit] = ACTIONS(4125),
    [anon_sym_CodeUnit] = ACTIONS(4125),
    [anon_sym_COdeunit] = ACTIONS(4125),
    [anon_sym_codeUnit] = ACTIONS(4125),
    [sym_report_keyword] = ACTIONS(4125),
    [sym_query_keyword] = ACTIONS(4125),
    [anon_sym_xmlport] = ACTIONS(4125),
    [anon_sym_XMLPORT] = ACTIONS(4125),
    [anon_sym_Xmlport] = ACTIONS(4125),
    [anon_sym_XMLport] = ACTIONS(4125),
    [anon_sym_XMLPort] = ACTIONS(4125),
    [anon_sym_XmlPort] = ACTIONS(4125),
    [anon_sym_enum] = ACTIONS(4125),
    [anon_sym_ENUM] = ACTIONS(4125),
    [anon_sym_Enum] = ACTIONS(4125),
    [anon_sym_eNUM] = ACTIONS(4125),
    [anon_sym_eNum] = ACTIONS(4125),
    [anon_sym_ENum] = ACTIONS(4125),
    [sym_quoted_identifier] = ACTIONS(4127),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4127),
    [sym_integer] = ACTIONS(4125),
    [sym_continue_as_identifier] = ACTIONS(4127),
    [sym_preproc_open] = ACTIONS(4127),
    [sym_preproc_close] = ACTIONS(4127),
  },
  [STATE(1536)] = {
    [sym_identifier] = ACTIONS(4135),
    [anon_sym_SEMI] = ACTIONS(4137),
    [anon_sym_DASH] = ACTIONS(4137),
    [aux_sym_boolean_token1] = ACTIONS(4135),
    [aux_sym_boolean_token2] = ACTIONS(4135),
    [sym_decimal] = ACTIONS(4135),
    [anon_sym_LPAREN] = ACTIONS(4135),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4135),
    [anon_sym_LBRACK] = ACTIONS(4137),
    [aux_sym_record_type_token1] = ACTIONS(4135),
    [aux_sym_basic_type_token21] = ACTIONS(4135),
    [aux_sym_basic_type_token22] = ACTIONS(4135),
    [aux_sym_basic_type_token48] = ACTIONS(4135),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4135),
    [anon_sym_POUNDif] = ACTIONS(4137),
    [anon_sym_POUNDIF] = ACTIONS(4137),
    [anon_sym_POUNDIf] = ACTIONS(4137),
    [anon_sym_not] = ACTIONS(4135),
    [anon_sym_NOT] = ACTIONS(4135),
    [anon_sym_Not] = ACTIONS(4135),
    [anon_sym_POUNDelif] = ACTIONS(4137),
    [anon_sym_POUNDELIF] = ACTIONS(4137),
    [anon_sym_POUNDElif] = ACTIONS(4137),
    [anon_sym_POUNDelse] = ACTIONS(4137),
    [anon_sym_POUNDELSE] = ACTIONS(4137),
    [anon_sym_POUNDElse] = ACTIONS(4137),
    [anon_sym_POUNDendif] = ACTIONS(4137),
    [anon_sym_POUNDENDIF] = ACTIONS(4137),
    [anon_sym_POUNDEndif] = ACTIONS(4137),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_LPAREN2] = ACTIONS(4137),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4135),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [sym_datetime_literal] = ACTIONS(4137),
    [sym_date_literal] = ACTIONS(4135),
    [sym_time_literal] = ACTIONS(4135),
    [sym_biginteger_literal] = ACTIONS(4137),
    [anon_sym_if] = ACTIONS(4135),
    [anon_sym_IF] = ACTIONS(4135),
    [anon_sym_If] = ACTIONS(4135),
    [anon_sym_else] = ACTIONS(4135),
    [anon_sym_ELSE] = ACTIONS(4135),
    [anon_sym_Else] = ACTIONS(4135),
    [anon_sym_case] = ACTIONS(4135),
    [anon_sym_CASE] = ACTIONS(4135),
    [anon_sym_Case] = ACTIONS(4135),
    [anon_sym_for] = ACTIONS(4135),
    [anon_sym_FOR] = ACTIONS(4135),
    [anon_sym_For] = ACTIONS(4135),
    [anon_sym_foreach] = ACTIONS(4135),
    [anon_sym_FOREACH] = ACTIONS(4135),
    [anon_sym_Foreach] = ACTIONS(4135),
    [anon_sym_while] = ACTIONS(4135),
    [anon_sym_WHILE] = ACTIONS(4135),
    [anon_sym_While] = ACTIONS(4135),
    [anon_sym_repeat] = ACTIONS(4135),
    [anon_sym_REPEAT] = ACTIONS(4135),
    [anon_sym_Repeat] = ACTIONS(4135),
    [anon_sym_exit] = ACTIONS(4135),
    [anon_sym_EXIT] = ACTIONS(4135),
    [anon_sym_Exit] = ACTIONS(4135),
    [anon_sym_continue] = ACTIONS(4135),
    [anon_sym_CONTINUE] = ACTIONS(4135),
    [anon_sym_Continue] = ACTIONS(4135),
    [anon_sym_break] = ACTIONS(4135),
    [anon_sym_BREAK] = ACTIONS(4135),
    [anon_sym_Break] = ACTIONS(4135),
    [anon_sym_with] = ACTIONS(4135),
    [anon_sym_WITH] = ACTIONS(4135),
    [anon_sym_With] = ACTIONS(4135),
    [sym_asserterror_keyword] = ACTIONS(4137),
    [sym_page_keyword] = ACTIONS(4135),
    [anon_sym_codeunit] = ACTIONS(4135),
    [anon_sym_CODEUNIT] = ACTIONS(4135),
    [anon_sym_Codeunit] = ACTIONS(4135),
    [anon_sym_CodeUnit] = ACTIONS(4135),
    [anon_sym_COdeunit] = ACTIONS(4135),
    [anon_sym_codeUnit] = ACTIONS(4135),
    [sym_report_keyword] = ACTIONS(4135),
    [sym_query_keyword] = ACTIONS(4135),
    [anon_sym_xmlport] = ACTIONS(4135),
    [anon_sym_XMLPORT] = ACTIONS(4135),
    [anon_sym_Xmlport] = ACTIONS(4135),
    [anon_sym_XMLport] = ACTIONS(4135),
    [anon_sym_XMLPort] = ACTIONS(4135),
    [anon_sym_XmlPort] = ACTIONS(4135),
    [anon_sym_enum] = ACTIONS(4135),
    [anon_sym_ENUM] = ACTIONS(4135),
    [anon_sym_Enum] = ACTIONS(4135),
    [anon_sym_eNUM] = ACTIONS(4135),
    [anon_sym_eNum] = ACTIONS(4135),
    [anon_sym_ENum] = ACTIONS(4135),
    [sym_quoted_identifier] = ACTIONS(4137),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4137),
    [sym_integer] = ACTIONS(4135),
    [sym_continue_as_identifier] = ACTIONS(4137),
    [sym_preproc_open] = ACTIONS(4137),
    [sym_preproc_close] = ACTIONS(4137),
  },
  [STATE(1537)] = {
    [sym_identifier] = ACTIONS(4139),
    [anon_sym_SEMI] = ACTIONS(4141),
    [anon_sym_DASH] = ACTIONS(4141),
    [aux_sym_boolean_token1] = ACTIONS(4139),
    [aux_sym_boolean_token2] = ACTIONS(4139),
    [sym_decimal] = ACTIONS(4139),
    [anon_sym_LPAREN] = ACTIONS(4139),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4139),
    [anon_sym_LBRACK] = ACTIONS(4141),
    [aux_sym_record_type_token1] = ACTIONS(4139),
    [aux_sym_basic_type_token21] = ACTIONS(4139),
    [aux_sym_basic_type_token22] = ACTIONS(4139),
    [aux_sym_basic_type_token48] = ACTIONS(4139),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4139),
    [anon_sym_POUNDif] = ACTIONS(4141),
    [anon_sym_POUNDIF] = ACTIONS(4141),
    [anon_sym_POUNDIf] = ACTIONS(4141),
    [anon_sym_not] = ACTIONS(4139),
    [anon_sym_NOT] = ACTIONS(4139),
    [anon_sym_Not] = ACTIONS(4139),
    [anon_sym_POUNDelif] = ACTIONS(4141),
    [anon_sym_POUNDELIF] = ACTIONS(4141),
    [anon_sym_POUNDElif] = ACTIONS(4141),
    [anon_sym_POUNDelse] = ACTIONS(4141),
    [anon_sym_POUNDELSE] = ACTIONS(4141),
    [anon_sym_POUNDElse] = ACTIONS(4141),
    [anon_sym_POUNDendif] = ACTIONS(4141),
    [anon_sym_POUNDENDIF] = ACTIONS(4141),
    [anon_sym_POUNDEndif] = ACTIONS(4141),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_LPAREN2] = ACTIONS(4143),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4139),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4139),
    [anon_sym_PLUS] = ACTIONS(4141),
    [sym_datetime_literal] = ACTIONS(4141),
    [sym_date_literal] = ACTIONS(4139),
    [sym_time_literal] = ACTIONS(4139),
    [sym_biginteger_literal] = ACTIONS(4141),
    [anon_sym_if] = ACTIONS(4139),
    [anon_sym_IF] = ACTIONS(4139),
    [anon_sym_If] = ACTIONS(4139),
    [anon_sym_else] = ACTIONS(4139),
    [anon_sym_ELSE] = ACTIONS(4139),
    [anon_sym_Else] = ACTIONS(4139),
    [anon_sym_case] = ACTIONS(4139),
    [anon_sym_CASE] = ACTIONS(4139),
    [anon_sym_Case] = ACTIONS(4139),
    [anon_sym_for] = ACTIONS(4139),
    [anon_sym_FOR] = ACTIONS(4139),
    [anon_sym_For] = ACTIONS(4139),
    [anon_sym_foreach] = ACTIONS(4139),
    [anon_sym_FOREACH] = ACTIONS(4139),
    [anon_sym_Foreach] = ACTIONS(4139),
    [anon_sym_while] = ACTIONS(4139),
    [anon_sym_WHILE] = ACTIONS(4139),
    [anon_sym_While] = ACTIONS(4139),
    [anon_sym_repeat] = ACTIONS(4139),
    [anon_sym_REPEAT] = ACTIONS(4139),
    [anon_sym_Repeat] = ACTIONS(4139),
    [anon_sym_exit] = ACTIONS(4139),
    [anon_sym_EXIT] = ACTIONS(4139),
    [anon_sym_Exit] = ACTIONS(4139),
    [anon_sym_continue] = ACTIONS(4139),
    [anon_sym_CONTINUE] = ACTIONS(4139),
    [anon_sym_Continue] = ACTIONS(4139),
    [anon_sym_break] = ACTIONS(4139),
    [anon_sym_BREAK] = ACTIONS(4139),
    [anon_sym_Break] = ACTIONS(4139),
    [anon_sym_with] = ACTIONS(4139),
    [anon_sym_WITH] = ACTIONS(4139),
    [anon_sym_With] = ACTIONS(4139),
    [sym_asserterror_keyword] = ACTIONS(4141),
    [sym_page_keyword] = ACTIONS(4139),
    [anon_sym_codeunit] = ACTIONS(4139),
    [anon_sym_CODEUNIT] = ACTIONS(4139),
    [anon_sym_Codeunit] = ACTIONS(4139),
    [anon_sym_CodeUnit] = ACTIONS(4139),
    [anon_sym_COdeunit] = ACTIONS(4139),
    [anon_sym_codeUnit] = ACTIONS(4139),
    [sym_report_keyword] = ACTIONS(4139),
    [sym_query_keyword] = ACTIONS(4139),
    [anon_sym_xmlport] = ACTIONS(4139),
    [anon_sym_XMLPORT] = ACTIONS(4139),
    [anon_sym_Xmlport] = ACTIONS(4139),
    [anon_sym_XMLport] = ACTIONS(4139),
    [anon_sym_XMLPort] = ACTIONS(4139),
    [anon_sym_XmlPort] = ACTIONS(4139),
    [anon_sym_enum] = ACTIONS(4139),
    [anon_sym_ENUM] = ACTIONS(4139),
    [anon_sym_Enum] = ACTIONS(4139),
    [anon_sym_eNUM] = ACTIONS(4139),
    [anon_sym_eNum] = ACTIONS(4139),
    [anon_sym_ENum] = ACTIONS(4139),
    [sym_quoted_identifier] = ACTIONS(4141),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4141),
    [sym_integer] = ACTIONS(4139),
    [sym_continue_as_identifier] = ACTIONS(4141),
    [sym_preproc_open] = ACTIONS(4141),
    [sym_preproc_close] = ACTIONS(4141),
  },
  [STATE(1538)] = {
    [sym_else_keyword] = STATE(245),
    [sym_identifier] = ACTIONS(4145),
    [anon_sym_SEMI] = ACTIONS(4147),
    [anon_sym_DASH] = ACTIONS(4147),
    [aux_sym_boolean_token1] = ACTIONS(4145),
    [aux_sym_boolean_token2] = ACTIONS(4145),
    [sym_decimal] = ACTIONS(4145),
    [anon_sym_LPAREN] = ACTIONS(4147),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4145),
    [anon_sym_LBRACK] = ACTIONS(4147),
    [aux_sym_record_type_token1] = ACTIONS(4145),
    [aux_sym_basic_type_token21] = ACTIONS(4145),
    [aux_sym_basic_type_token22] = ACTIONS(4145),
    [aux_sym_basic_type_token48] = ACTIONS(4145),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4145),
    [anon_sym_POUNDif] = ACTIONS(4147),
    [anon_sym_POUNDIF] = ACTIONS(4147),
    [anon_sym_POUNDIf] = ACTIONS(4147),
    [anon_sym_not] = ACTIONS(4145),
    [anon_sym_NOT] = ACTIONS(4145),
    [anon_sym_Not] = ACTIONS(4145),
    [anon_sym_POUNDelif] = ACTIONS(4147),
    [anon_sym_POUNDELIF] = ACTIONS(4147),
    [anon_sym_POUNDElif] = ACTIONS(4147),
    [anon_sym_POUNDelse] = ACTIONS(4147),
    [anon_sym_POUNDELSE] = ACTIONS(4147),
    [anon_sym_POUNDElse] = ACTIONS(4147),
    [anon_sym_POUNDendif] = ACTIONS(4147),
    [anon_sym_POUNDENDIF] = ACTIONS(4147),
    [anon_sym_POUNDEndif] = ACTIONS(4147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4145),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4145),
    [anon_sym_PLUS] = ACTIONS(4147),
    [sym_datetime_literal] = ACTIONS(4147),
    [sym_date_literal] = ACTIONS(4145),
    [sym_time_literal] = ACTIONS(4145),
    [sym_biginteger_literal] = ACTIONS(4147),
    [anon_sym_if] = ACTIONS(4145),
    [anon_sym_IF] = ACTIONS(4145),
    [anon_sym_If] = ACTIONS(4145),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4145),
    [anon_sym_CASE] = ACTIONS(4145),
    [anon_sym_Case] = ACTIONS(4145),
    [anon_sym_for] = ACTIONS(4145),
    [anon_sym_FOR] = ACTIONS(4145),
    [anon_sym_For] = ACTIONS(4145),
    [anon_sym_foreach] = ACTIONS(4145),
    [anon_sym_FOREACH] = ACTIONS(4145),
    [anon_sym_Foreach] = ACTIONS(4145),
    [anon_sym_while] = ACTIONS(4145),
    [anon_sym_WHILE] = ACTIONS(4145),
    [anon_sym_While] = ACTIONS(4145),
    [anon_sym_repeat] = ACTIONS(4145),
    [anon_sym_REPEAT] = ACTIONS(4145),
    [anon_sym_Repeat] = ACTIONS(4145),
    [anon_sym_exit] = ACTIONS(4145),
    [anon_sym_EXIT] = ACTIONS(4145),
    [anon_sym_Exit] = ACTIONS(4145),
    [anon_sym_continue] = ACTIONS(4145),
    [anon_sym_CONTINUE] = ACTIONS(4145),
    [anon_sym_Continue] = ACTIONS(4145),
    [anon_sym_break] = ACTIONS(4145),
    [anon_sym_BREAK] = ACTIONS(4145),
    [anon_sym_Break] = ACTIONS(4145),
    [anon_sym_with] = ACTIONS(4145),
    [anon_sym_WITH] = ACTIONS(4145),
    [anon_sym_With] = ACTIONS(4145),
    [sym_asserterror_keyword] = ACTIONS(4147),
    [sym_page_keyword] = ACTIONS(4145),
    [anon_sym_codeunit] = ACTIONS(4145),
    [anon_sym_CODEUNIT] = ACTIONS(4145),
    [anon_sym_Codeunit] = ACTIONS(4145),
    [anon_sym_CodeUnit] = ACTIONS(4145),
    [anon_sym_COdeunit] = ACTIONS(4145),
    [anon_sym_codeUnit] = ACTIONS(4145),
    [sym_report_keyword] = ACTIONS(4145),
    [sym_query_keyword] = ACTIONS(4145),
    [anon_sym_xmlport] = ACTIONS(4145),
    [anon_sym_XMLPORT] = ACTIONS(4145),
    [anon_sym_Xmlport] = ACTIONS(4145),
    [anon_sym_XMLport] = ACTIONS(4145),
    [anon_sym_XMLPort] = ACTIONS(4145),
    [anon_sym_XmlPort] = ACTIONS(4145),
    [anon_sym_enum] = ACTIONS(4145),
    [anon_sym_ENUM] = ACTIONS(4145),
    [anon_sym_Enum] = ACTIONS(4145),
    [anon_sym_eNUM] = ACTIONS(4145),
    [anon_sym_eNum] = ACTIONS(4145),
    [anon_sym_ENum] = ACTIONS(4145),
    [sym_quoted_identifier] = ACTIONS(4147),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4147),
    [sym_integer] = ACTIONS(4145),
    [sym_continue_as_identifier] = ACTIONS(4147),
    [sym_preproc_open] = ACTIONS(4147),
    [sym_preproc_close] = ACTIONS(4147),
  },
  [STATE(1539)] = {
    [sym_else_keyword] = STATE(246),
    [sym_identifier] = ACTIONS(4149),
    [anon_sym_SEMI] = ACTIONS(4151),
    [anon_sym_DASH] = ACTIONS(4151),
    [aux_sym_boolean_token1] = ACTIONS(4149),
    [aux_sym_boolean_token2] = ACTIONS(4149),
    [sym_decimal] = ACTIONS(4149),
    [anon_sym_LPAREN] = ACTIONS(4151),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4149),
    [anon_sym_LBRACK] = ACTIONS(4151),
    [aux_sym_record_type_token1] = ACTIONS(4149),
    [aux_sym_basic_type_token21] = ACTIONS(4149),
    [aux_sym_basic_type_token22] = ACTIONS(4149),
    [aux_sym_basic_type_token48] = ACTIONS(4149),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4149),
    [anon_sym_POUNDif] = ACTIONS(4151),
    [anon_sym_POUNDIF] = ACTIONS(4151),
    [anon_sym_POUNDIf] = ACTIONS(4151),
    [anon_sym_not] = ACTIONS(4149),
    [anon_sym_NOT] = ACTIONS(4149),
    [anon_sym_Not] = ACTIONS(4149),
    [anon_sym_POUNDelif] = ACTIONS(4151),
    [anon_sym_POUNDELIF] = ACTIONS(4151),
    [anon_sym_POUNDElif] = ACTIONS(4151),
    [anon_sym_POUNDelse] = ACTIONS(4151),
    [anon_sym_POUNDELSE] = ACTIONS(4151),
    [anon_sym_POUNDElse] = ACTIONS(4151),
    [anon_sym_POUNDendif] = ACTIONS(4151),
    [anon_sym_POUNDENDIF] = ACTIONS(4151),
    [anon_sym_POUNDEndif] = ACTIONS(4151),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4149),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4149),
    [anon_sym_PLUS] = ACTIONS(4151),
    [sym_datetime_literal] = ACTIONS(4151),
    [sym_date_literal] = ACTIONS(4149),
    [sym_time_literal] = ACTIONS(4149),
    [sym_biginteger_literal] = ACTIONS(4151),
    [anon_sym_if] = ACTIONS(4149),
    [anon_sym_IF] = ACTIONS(4149),
    [anon_sym_If] = ACTIONS(4149),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4149),
    [anon_sym_CASE] = ACTIONS(4149),
    [anon_sym_Case] = ACTIONS(4149),
    [anon_sym_for] = ACTIONS(4149),
    [anon_sym_FOR] = ACTIONS(4149),
    [anon_sym_For] = ACTIONS(4149),
    [anon_sym_foreach] = ACTIONS(4149),
    [anon_sym_FOREACH] = ACTIONS(4149),
    [anon_sym_Foreach] = ACTIONS(4149),
    [anon_sym_while] = ACTIONS(4149),
    [anon_sym_WHILE] = ACTIONS(4149),
    [anon_sym_While] = ACTIONS(4149),
    [anon_sym_repeat] = ACTIONS(4149),
    [anon_sym_REPEAT] = ACTIONS(4149),
    [anon_sym_Repeat] = ACTIONS(4149),
    [anon_sym_exit] = ACTIONS(4149),
    [anon_sym_EXIT] = ACTIONS(4149),
    [anon_sym_Exit] = ACTIONS(4149),
    [anon_sym_continue] = ACTIONS(4149),
    [anon_sym_CONTINUE] = ACTIONS(4149),
    [anon_sym_Continue] = ACTIONS(4149),
    [anon_sym_break] = ACTIONS(4149),
    [anon_sym_BREAK] = ACTIONS(4149),
    [anon_sym_Break] = ACTIONS(4149),
    [anon_sym_with] = ACTIONS(4149),
    [anon_sym_WITH] = ACTIONS(4149),
    [anon_sym_With] = ACTIONS(4149),
    [sym_asserterror_keyword] = ACTIONS(4151),
    [sym_page_keyword] = ACTIONS(4149),
    [anon_sym_codeunit] = ACTIONS(4149),
    [anon_sym_CODEUNIT] = ACTIONS(4149),
    [anon_sym_Codeunit] = ACTIONS(4149),
    [anon_sym_CodeUnit] = ACTIONS(4149),
    [anon_sym_COdeunit] = ACTIONS(4149),
    [anon_sym_codeUnit] = ACTIONS(4149),
    [sym_report_keyword] = ACTIONS(4149),
    [sym_query_keyword] = ACTIONS(4149),
    [anon_sym_xmlport] = ACTIONS(4149),
    [anon_sym_XMLPORT] = ACTIONS(4149),
    [anon_sym_Xmlport] = ACTIONS(4149),
    [anon_sym_XMLport] = ACTIONS(4149),
    [anon_sym_XMLPort] = ACTIONS(4149),
    [anon_sym_XmlPort] = ACTIONS(4149),
    [anon_sym_enum] = ACTIONS(4149),
    [anon_sym_ENUM] = ACTIONS(4149),
    [anon_sym_Enum] = ACTIONS(4149),
    [anon_sym_eNUM] = ACTIONS(4149),
    [anon_sym_eNum] = ACTIONS(4149),
    [anon_sym_ENum] = ACTIONS(4149),
    [sym_quoted_identifier] = ACTIONS(4151),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4151),
    [sym_integer] = ACTIONS(4149),
    [sym_continue_as_identifier] = ACTIONS(4151),
    [sym_preproc_open] = ACTIONS(4151),
    [sym_preproc_close] = ACTIONS(4151),
  },
  [STATE(1540)] = {
    [sym_else_keyword] = STATE(252),
    [sym_identifier] = ACTIONS(4153),
    [anon_sym_SEMI] = ACTIONS(4155),
    [anon_sym_DASH] = ACTIONS(4155),
    [aux_sym_boolean_token1] = ACTIONS(4153),
    [aux_sym_boolean_token2] = ACTIONS(4153),
    [sym_decimal] = ACTIONS(4153),
    [anon_sym_LPAREN] = ACTIONS(4155),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4153),
    [anon_sym_LBRACK] = ACTIONS(4155),
    [aux_sym_record_type_token1] = ACTIONS(4153),
    [aux_sym_basic_type_token21] = ACTIONS(4153),
    [aux_sym_basic_type_token22] = ACTIONS(4153),
    [aux_sym_basic_type_token48] = ACTIONS(4153),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4153),
    [anon_sym_POUNDif] = ACTIONS(4155),
    [anon_sym_POUNDIF] = ACTIONS(4155),
    [anon_sym_POUNDIf] = ACTIONS(4155),
    [anon_sym_not] = ACTIONS(4153),
    [anon_sym_NOT] = ACTIONS(4153),
    [anon_sym_Not] = ACTIONS(4153),
    [anon_sym_POUNDelif] = ACTIONS(4155),
    [anon_sym_POUNDELIF] = ACTIONS(4155),
    [anon_sym_POUNDElif] = ACTIONS(4155),
    [anon_sym_POUNDelse] = ACTIONS(4155),
    [anon_sym_POUNDELSE] = ACTIONS(4155),
    [anon_sym_POUNDElse] = ACTIONS(4155),
    [anon_sym_POUNDendif] = ACTIONS(4155),
    [anon_sym_POUNDENDIF] = ACTIONS(4155),
    [anon_sym_POUNDEndif] = ACTIONS(4155),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4153),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4153),
    [anon_sym_PLUS] = ACTIONS(4155),
    [sym_datetime_literal] = ACTIONS(4155),
    [sym_date_literal] = ACTIONS(4153),
    [sym_time_literal] = ACTIONS(4153),
    [sym_biginteger_literal] = ACTIONS(4155),
    [anon_sym_if] = ACTIONS(4153),
    [anon_sym_IF] = ACTIONS(4153),
    [anon_sym_If] = ACTIONS(4153),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4153),
    [anon_sym_CASE] = ACTIONS(4153),
    [anon_sym_Case] = ACTIONS(4153),
    [anon_sym_for] = ACTIONS(4153),
    [anon_sym_FOR] = ACTIONS(4153),
    [anon_sym_For] = ACTIONS(4153),
    [anon_sym_foreach] = ACTIONS(4153),
    [anon_sym_FOREACH] = ACTIONS(4153),
    [anon_sym_Foreach] = ACTIONS(4153),
    [anon_sym_while] = ACTIONS(4153),
    [anon_sym_WHILE] = ACTIONS(4153),
    [anon_sym_While] = ACTIONS(4153),
    [anon_sym_repeat] = ACTIONS(4153),
    [anon_sym_REPEAT] = ACTIONS(4153),
    [anon_sym_Repeat] = ACTIONS(4153),
    [anon_sym_exit] = ACTIONS(4153),
    [anon_sym_EXIT] = ACTIONS(4153),
    [anon_sym_Exit] = ACTIONS(4153),
    [anon_sym_continue] = ACTIONS(4153),
    [anon_sym_CONTINUE] = ACTIONS(4153),
    [anon_sym_Continue] = ACTIONS(4153),
    [anon_sym_break] = ACTIONS(4153),
    [anon_sym_BREAK] = ACTIONS(4153),
    [anon_sym_Break] = ACTIONS(4153),
    [anon_sym_with] = ACTIONS(4153),
    [anon_sym_WITH] = ACTIONS(4153),
    [anon_sym_With] = ACTIONS(4153),
    [sym_asserterror_keyword] = ACTIONS(4155),
    [sym_page_keyword] = ACTIONS(4153),
    [anon_sym_codeunit] = ACTIONS(4153),
    [anon_sym_CODEUNIT] = ACTIONS(4153),
    [anon_sym_Codeunit] = ACTIONS(4153),
    [anon_sym_CodeUnit] = ACTIONS(4153),
    [anon_sym_COdeunit] = ACTIONS(4153),
    [anon_sym_codeUnit] = ACTIONS(4153),
    [sym_report_keyword] = ACTIONS(4153),
    [sym_query_keyword] = ACTIONS(4153),
    [anon_sym_xmlport] = ACTIONS(4153),
    [anon_sym_XMLPORT] = ACTIONS(4153),
    [anon_sym_Xmlport] = ACTIONS(4153),
    [anon_sym_XMLport] = ACTIONS(4153),
    [anon_sym_XMLPort] = ACTIONS(4153),
    [anon_sym_XmlPort] = ACTIONS(4153),
    [anon_sym_enum] = ACTIONS(4153),
    [anon_sym_ENUM] = ACTIONS(4153),
    [anon_sym_Enum] = ACTIONS(4153),
    [anon_sym_eNUM] = ACTIONS(4153),
    [anon_sym_eNum] = ACTIONS(4153),
    [anon_sym_ENum] = ACTIONS(4153),
    [sym_quoted_identifier] = ACTIONS(4155),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4155),
    [sym_integer] = ACTIONS(4153),
    [sym_continue_as_identifier] = ACTIONS(4155),
    [sym_preproc_open] = ACTIONS(4155),
    [sym_preproc_close] = ACTIONS(4155),
  },
  [STATE(1541)] = {
    [sym_else_keyword] = STATE(253),
    [sym_identifier] = ACTIONS(4157),
    [anon_sym_SEMI] = ACTIONS(4159),
    [anon_sym_DASH] = ACTIONS(4159),
    [aux_sym_boolean_token1] = ACTIONS(4157),
    [aux_sym_boolean_token2] = ACTIONS(4157),
    [sym_decimal] = ACTIONS(4157),
    [anon_sym_LPAREN] = ACTIONS(4159),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4157),
    [anon_sym_LBRACK] = ACTIONS(4159),
    [aux_sym_record_type_token1] = ACTIONS(4157),
    [aux_sym_basic_type_token21] = ACTIONS(4157),
    [aux_sym_basic_type_token22] = ACTIONS(4157),
    [aux_sym_basic_type_token48] = ACTIONS(4157),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4157),
    [anon_sym_POUNDif] = ACTIONS(4159),
    [anon_sym_POUNDIF] = ACTIONS(4159),
    [anon_sym_POUNDIf] = ACTIONS(4159),
    [anon_sym_not] = ACTIONS(4157),
    [anon_sym_NOT] = ACTIONS(4157),
    [anon_sym_Not] = ACTIONS(4157),
    [anon_sym_POUNDelif] = ACTIONS(4159),
    [anon_sym_POUNDELIF] = ACTIONS(4159),
    [anon_sym_POUNDElif] = ACTIONS(4159),
    [anon_sym_POUNDelse] = ACTIONS(4159),
    [anon_sym_POUNDELSE] = ACTIONS(4159),
    [anon_sym_POUNDElse] = ACTIONS(4159),
    [anon_sym_POUNDendif] = ACTIONS(4159),
    [anon_sym_POUNDENDIF] = ACTIONS(4159),
    [anon_sym_POUNDEndif] = ACTIONS(4159),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4157),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4157),
    [anon_sym_PLUS] = ACTIONS(4159),
    [sym_datetime_literal] = ACTIONS(4159),
    [sym_date_literal] = ACTIONS(4157),
    [sym_time_literal] = ACTIONS(4157),
    [sym_biginteger_literal] = ACTIONS(4159),
    [anon_sym_if] = ACTIONS(4157),
    [anon_sym_IF] = ACTIONS(4157),
    [anon_sym_If] = ACTIONS(4157),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4157),
    [anon_sym_CASE] = ACTIONS(4157),
    [anon_sym_Case] = ACTIONS(4157),
    [anon_sym_for] = ACTIONS(4157),
    [anon_sym_FOR] = ACTIONS(4157),
    [anon_sym_For] = ACTIONS(4157),
    [anon_sym_foreach] = ACTIONS(4157),
    [anon_sym_FOREACH] = ACTIONS(4157),
    [anon_sym_Foreach] = ACTIONS(4157),
    [anon_sym_while] = ACTIONS(4157),
    [anon_sym_WHILE] = ACTIONS(4157),
    [anon_sym_While] = ACTIONS(4157),
    [anon_sym_repeat] = ACTIONS(4157),
    [anon_sym_REPEAT] = ACTIONS(4157),
    [anon_sym_Repeat] = ACTIONS(4157),
    [anon_sym_exit] = ACTIONS(4157),
    [anon_sym_EXIT] = ACTIONS(4157),
    [anon_sym_Exit] = ACTIONS(4157),
    [anon_sym_continue] = ACTIONS(4157),
    [anon_sym_CONTINUE] = ACTIONS(4157),
    [anon_sym_Continue] = ACTIONS(4157),
    [anon_sym_break] = ACTIONS(4157),
    [anon_sym_BREAK] = ACTIONS(4157),
    [anon_sym_Break] = ACTIONS(4157),
    [anon_sym_with] = ACTIONS(4157),
    [anon_sym_WITH] = ACTIONS(4157),
    [anon_sym_With] = ACTIONS(4157),
    [sym_asserterror_keyword] = ACTIONS(4159),
    [sym_page_keyword] = ACTIONS(4157),
    [anon_sym_codeunit] = ACTIONS(4157),
    [anon_sym_CODEUNIT] = ACTIONS(4157),
    [anon_sym_Codeunit] = ACTIONS(4157),
    [anon_sym_CodeUnit] = ACTIONS(4157),
    [anon_sym_COdeunit] = ACTIONS(4157),
    [anon_sym_codeUnit] = ACTIONS(4157),
    [sym_report_keyword] = ACTIONS(4157),
    [sym_query_keyword] = ACTIONS(4157),
    [anon_sym_xmlport] = ACTIONS(4157),
    [anon_sym_XMLPORT] = ACTIONS(4157),
    [anon_sym_Xmlport] = ACTIONS(4157),
    [anon_sym_XMLport] = ACTIONS(4157),
    [anon_sym_XMLPort] = ACTIONS(4157),
    [anon_sym_XmlPort] = ACTIONS(4157),
    [anon_sym_enum] = ACTIONS(4157),
    [anon_sym_ENUM] = ACTIONS(4157),
    [anon_sym_Enum] = ACTIONS(4157),
    [anon_sym_eNUM] = ACTIONS(4157),
    [anon_sym_eNum] = ACTIONS(4157),
    [anon_sym_ENum] = ACTIONS(4157),
    [sym_quoted_identifier] = ACTIONS(4159),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4159),
    [sym_integer] = ACTIONS(4157),
    [sym_continue_as_identifier] = ACTIONS(4159),
    [sym_preproc_open] = ACTIONS(4159),
    [sym_preproc_close] = ACTIONS(4159),
  },
  [STATE(1542)] = {
    [sym_else_keyword] = STATE(254),
    [sym_identifier] = ACTIONS(4161),
    [anon_sym_SEMI] = ACTIONS(4163),
    [anon_sym_DASH] = ACTIONS(4163),
    [aux_sym_boolean_token1] = ACTIONS(4161),
    [aux_sym_boolean_token2] = ACTIONS(4161),
    [sym_decimal] = ACTIONS(4161),
    [anon_sym_LPAREN] = ACTIONS(4163),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4161),
    [anon_sym_LBRACK] = ACTIONS(4163),
    [aux_sym_record_type_token1] = ACTIONS(4161),
    [aux_sym_basic_type_token21] = ACTIONS(4161),
    [aux_sym_basic_type_token22] = ACTIONS(4161),
    [aux_sym_basic_type_token48] = ACTIONS(4161),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4161),
    [anon_sym_POUNDif] = ACTIONS(4163),
    [anon_sym_POUNDIF] = ACTIONS(4163),
    [anon_sym_POUNDIf] = ACTIONS(4163),
    [anon_sym_not] = ACTIONS(4161),
    [anon_sym_NOT] = ACTIONS(4161),
    [anon_sym_Not] = ACTIONS(4161),
    [anon_sym_POUNDelif] = ACTIONS(4163),
    [anon_sym_POUNDELIF] = ACTIONS(4163),
    [anon_sym_POUNDElif] = ACTIONS(4163),
    [anon_sym_POUNDelse] = ACTIONS(4163),
    [anon_sym_POUNDELSE] = ACTIONS(4163),
    [anon_sym_POUNDElse] = ACTIONS(4163),
    [anon_sym_POUNDendif] = ACTIONS(4163),
    [anon_sym_POUNDENDIF] = ACTIONS(4163),
    [anon_sym_POUNDEndif] = ACTIONS(4163),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4161),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4161),
    [anon_sym_PLUS] = ACTIONS(4163),
    [sym_datetime_literal] = ACTIONS(4163),
    [sym_date_literal] = ACTIONS(4161),
    [sym_time_literal] = ACTIONS(4161),
    [sym_biginteger_literal] = ACTIONS(4163),
    [anon_sym_if] = ACTIONS(4161),
    [anon_sym_IF] = ACTIONS(4161),
    [anon_sym_If] = ACTIONS(4161),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4161),
    [anon_sym_CASE] = ACTIONS(4161),
    [anon_sym_Case] = ACTIONS(4161),
    [anon_sym_for] = ACTIONS(4161),
    [anon_sym_FOR] = ACTIONS(4161),
    [anon_sym_For] = ACTIONS(4161),
    [anon_sym_foreach] = ACTIONS(4161),
    [anon_sym_FOREACH] = ACTIONS(4161),
    [anon_sym_Foreach] = ACTIONS(4161),
    [anon_sym_while] = ACTIONS(4161),
    [anon_sym_WHILE] = ACTIONS(4161),
    [anon_sym_While] = ACTIONS(4161),
    [anon_sym_repeat] = ACTIONS(4161),
    [anon_sym_REPEAT] = ACTIONS(4161),
    [anon_sym_Repeat] = ACTIONS(4161),
    [anon_sym_exit] = ACTIONS(4161),
    [anon_sym_EXIT] = ACTIONS(4161),
    [anon_sym_Exit] = ACTIONS(4161),
    [anon_sym_continue] = ACTIONS(4161),
    [anon_sym_CONTINUE] = ACTIONS(4161),
    [anon_sym_Continue] = ACTIONS(4161),
    [anon_sym_break] = ACTIONS(4161),
    [anon_sym_BREAK] = ACTIONS(4161),
    [anon_sym_Break] = ACTIONS(4161),
    [anon_sym_with] = ACTIONS(4161),
    [anon_sym_WITH] = ACTIONS(4161),
    [anon_sym_With] = ACTIONS(4161),
    [sym_asserterror_keyword] = ACTIONS(4163),
    [sym_page_keyword] = ACTIONS(4161),
    [anon_sym_codeunit] = ACTIONS(4161),
    [anon_sym_CODEUNIT] = ACTIONS(4161),
    [anon_sym_Codeunit] = ACTIONS(4161),
    [anon_sym_CodeUnit] = ACTIONS(4161),
    [anon_sym_COdeunit] = ACTIONS(4161),
    [anon_sym_codeUnit] = ACTIONS(4161),
    [sym_report_keyword] = ACTIONS(4161),
    [sym_query_keyword] = ACTIONS(4161),
    [anon_sym_xmlport] = ACTIONS(4161),
    [anon_sym_XMLPORT] = ACTIONS(4161),
    [anon_sym_Xmlport] = ACTIONS(4161),
    [anon_sym_XMLport] = ACTIONS(4161),
    [anon_sym_XMLPort] = ACTIONS(4161),
    [anon_sym_XmlPort] = ACTIONS(4161),
    [anon_sym_enum] = ACTIONS(4161),
    [anon_sym_ENUM] = ACTIONS(4161),
    [anon_sym_Enum] = ACTIONS(4161),
    [anon_sym_eNUM] = ACTIONS(4161),
    [anon_sym_eNum] = ACTIONS(4161),
    [anon_sym_ENum] = ACTIONS(4161),
    [sym_quoted_identifier] = ACTIONS(4163),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4163),
    [sym_integer] = ACTIONS(4161),
    [sym_continue_as_identifier] = ACTIONS(4163),
    [sym_preproc_open] = ACTIONS(4163),
    [sym_preproc_close] = ACTIONS(4163),
  },
  [STATE(1543)] = {
    [sym_else_keyword] = STATE(255),
    [sym_identifier] = ACTIONS(4165),
    [anon_sym_SEMI] = ACTIONS(4167),
    [anon_sym_DASH] = ACTIONS(4167),
    [aux_sym_boolean_token1] = ACTIONS(4165),
    [aux_sym_boolean_token2] = ACTIONS(4165),
    [sym_decimal] = ACTIONS(4165),
    [anon_sym_LPAREN] = ACTIONS(4167),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4165),
    [anon_sym_LBRACK] = ACTIONS(4167),
    [aux_sym_record_type_token1] = ACTIONS(4165),
    [aux_sym_basic_type_token21] = ACTIONS(4165),
    [aux_sym_basic_type_token22] = ACTIONS(4165),
    [aux_sym_basic_type_token48] = ACTIONS(4165),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4165),
    [anon_sym_POUNDif] = ACTIONS(4167),
    [anon_sym_POUNDIF] = ACTIONS(4167),
    [anon_sym_POUNDIf] = ACTIONS(4167),
    [anon_sym_not] = ACTIONS(4165),
    [anon_sym_NOT] = ACTIONS(4165),
    [anon_sym_Not] = ACTIONS(4165),
    [anon_sym_POUNDelif] = ACTIONS(4167),
    [anon_sym_POUNDELIF] = ACTIONS(4167),
    [anon_sym_POUNDElif] = ACTIONS(4167),
    [anon_sym_POUNDelse] = ACTIONS(4167),
    [anon_sym_POUNDELSE] = ACTIONS(4167),
    [anon_sym_POUNDElse] = ACTIONS(4167),
    [anon_sym_POUNDendif] = ACTIONS(4167),
    [anon_sym_POUNDENDIF] = ACTIONS(4167),
    [anon_sym_POUNDEndif] = ACTIONS(4167),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4165),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4165),
    [anon_sym_PLUS] = ACTIONS(4167),
    [sym_datetime_literal] = ACTIONS(4167),
    [sym_date_literal] = ACTIONS(4165),
    [sym_time_literal] = ACTIONS(4165),
    [sym_biginteger_literal] = ACTIONS(4167),
    [anon_sym_if] = ACTIONS(4165),
    [anon_sym_IF] = ACTIONS(4165),
    [anon_sym_If] = ACTIONS(4165),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4165),
    [anon_sym_CASE] = ACTIONS(4165),
    [anon_sym_Case] = ACTIONS(4165),
    [anon_sym_for] = ACTIONS(4165),
    [anon_sym_FOR] = ACTIONS(4165),
    [anon_sym_For] = ACTIONS(4165),
    [anon_sym_foreach] = ACTIONS(4165),
    [anon_sym_FOREACH] = ACTIONS(4165),
    [anon_sym_Foreach] = ACTIONS(4165),
    [anon_sym_while] = ACTIONS(4165),
    [anon_sym_WHILE] = ACTIONS(4165),
    [anon_sym_While] = ACTIONS(4165),
    [anon_sym_repeat] = ACTIONS(4165),
    [anon_sym_REPEAT] = ACTIONS(4165),
    [anon_sym_Repeat] = ACTIONS(4165),
    [anon_sym_exit] = ACTIONS(4165),
    [anon_sym_EXIT] = ACTIONS(4165),
    [anon_sym_Exit] = ACTIONS(4165),
    [anon_sym_continue] = ACTIONS(4165),
    [anon_sym_CONTINUE] = ACTIONS(4165),
    [anon_sym_Continue] = ACTIONS(4165),
    [anon_sym_break] = ACTIONS(4165),
    [anon_sym_BREAK] = ACTIONS(4165),
    [anon_sym_Break] = ACTIONS(4165),
    [anon_sym_with] = ACTIONS(4165),
    [anon_sym_WITH] = ACTIONS(4165),
    [anon_sym_With] = ACTIONS(4165),
    [sym_asserterror_keyword] = ACTIONS(4167),
    [sym_page_keyword] = ACTIONS(4165),
    [anon_sym_codeunit] = ACTIONS(4165),
    [anon_sym_CODEUNIT] = ACTIONS(4165),
    [anon_sym_Codeunit] = ACTIONS(4165),
    [anon_sym_CodeUnit] = ACTIONS(4165),
    [anon_sym_COdeunit] = ACTIONS(4165),
    [anon_sym_codeUnit] = ACTIONS(4165),
    [sym_report_keyword] = ACTIONS(4165),
    [sym_query_keyword] = ACTIONS(4165),
    [anon_sym_xmlport] = ACTIONS(4165),
    [anon_sym_XMLPORT] = ACTIONS(4165),
    [anon_sym_Xmlport] = ACTIONS(4165),
    [anon_sym_XMLport] = ACTIONS(4165),
    [anon_sym_XMLPort] = ACTIONS(4165),
    [anon_sym_XmlPort] = ACTIONS(4165),
    [anon_sym_enum] = ACTIONS(4165),
    [anon_sym_ENUM] = ACTIONS(4165),
    [anon_sym_Enum] = ACTIONS(4165),
    [anon_sym_eNUM] = ACTIONS(4165),
    [anon_sym_eNum] = ACTIONS(4165),
    [anon_sym_ENum] = ACTIONS(4165),
    [sym_quoted_identifier] = ACTIONS(4167),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4167),
    [sym_integer] = ACTIONS(4165),
    [sym_continue_as_identifier] = ACTIONS(4167),
    [sym_preproc_open] = ACTIONS(4167),
    [sym_preproc_close] = ACTIONS(4167),
  },
  [STATE(1544)] = {
    [sym_else_keyword] = STATE(260),
    [sym_identifier] = ACTIONS(4169),
    [anon_sym_SEMI] = ACTIONS(4171),
    [anon_sym_DASH] = ACTIONS(4171),
    [aux_sym_boolean_token1] = ACTIONS(4169),
    [aux_sym_boolean_token2] = ACTIONS(4169),
    [sym_decimal] = ACTIONS(4169),
    [anon_sym_LPAREN] = ACTIONS(4171),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4169),
    [anon_sym_LBRACK] = ACTIONS(4171),
    [aux_sym_record_type_token1] = ACTIONS(4169),
    [aux_sym_basic_type_token21] = ACTIONS(4169),
    [aux_sym_basic_type_token22] = ACTIONS(4169),
    [aux_sym_basic_type_token48] = ACTIONS(4169),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4169),
    [anon_sym_POUNDif] = ACTIONS(4171),
    [anon_sym_POUNDIF] = ACTIONS(4171),
    [anon_sym_POUNDIf] = ACTIONS(4171),
    [anon_sym_not] = ACTIONS(4169),
    [anon_sym_NOT] = ACTIONS(4169),
    [anon_sym_Not] = ACTIONS(4169),
    [anon_sym_POUNDelif] = ACTIONS(4171),
    [anon_sym_POUNDELIF] = ACTIONS(4171),
    [anon_sym_POUNDElif] = ACTIONS(4171),
    [anon_sym_POUNDelse] = ACTIONS(4171),
    [anon_sym_POUNDELSE] = ACTIONS(4171),
    [anon_sym_POUNDElse] = ACTIONS(4171),
    [anon_sym_POUNDendif] = ACTIONS(4171),
    [anon_sym_POUNDENDIF] = ACTIONS(4171),
    [anon_sym_POUNDEndif] = ACTIONS(4171),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4169),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4169),
    [anon_sym_PLUS] = ACTIONS(4171),
    [sym_datetime_literal] = ACTIONS(4171),
    [sym_date_literal] = ACTIONS(4169),
    [sym_time_literal] = ACTIONS(4169),
    [sym_biginteger_literal] = ACTIONS(4171),
    [anon_sym_if] = ACTIONS(4169),
    [anon_sym_IF] = ACTIONS(4169),
    [anon_sym_If] = ACTIONS(4169),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4169),
    [anon_sym_CASE] = ACTIONS(4169),
    [anon_sym_Case] = ACTIONS(4169),
    [anon_sym_for] = ACTIONS(4169),
    [anon_sym_FOR] = ACTIONS(4169),
    [anon_sym_For] = ACTIONS(4169),
    [anon_sym_foreach] = ACTIONS(4169),
    [anon_sym_FOREACH] = ACTIONS(4169),
    [anon_sym_Foreach] = ACTIONS(4169),
    [anon_sym_while] = ACTIONS(4169),
    [anon_sym_WHILE] = ACTIONS(4169),
    [anon_sym_While] = ACTIONS(4169),
    [anon_sym_repeat] = ACTIONS(4169),
    [anon_sym_REPEAT] = ACTIONS(4169),
    [anon_sym_Repeat] = ACTIONS(4169),
    [anon_sym_exit] = ACTIONS(4169),
    [anon_sym_EXIT] = ACTIONS(4169),
    [anon_sym_Exit] = ACTIONS(4169),
    [anon_sym_continue] = ACTIONS(4169),
    [anon_sym_CONTINUE] = ACTIONS(4169),
    [anon_sym_Continue] = ACTIONS(4169),
    [anon_sym_break] = ACTIONS(4169),
    [anon_sym_BREAK] = ACTIONS(4169),
    [anon_sym_Break] = ACTIONS(4169),
    [anon_sym_with] = ACTIONS(4169),
    [anon_sym_WITH] = ACTIONS(4169),
    [anon_sym_With] = ACTIONS(4169),
    [sym_asserterror_keyword] = ACTIONS(4171),
    [sym_page_keyword] = ACTIONS(4169),
    [anon_sym_codeunit] = ACTIONS(4169),
    [anon_sym_CODEUNIT] = ACTIONS(4169),
    [anon_sym_Codeunit] = ACTIONS(4169),
    [anon_sym_CodeUnit] = ACTIONS(4169),
    [anon_sym_COdeunit] = ACTIONS(4169),
    [anon_sym_codeUnit] = ACTIONS(4169),
    [sym_report_keyword] = ACTIONS(4169),
    [sym_query_keyword] = ACTIONS(4169),
    [anon_sym_xmlport] = ACTIONS(4169),
    [anon_sym_XMLPORT] = ACTIONS(4169),
    [anon_sym_Xmlport] = ACTIONS(4169),
    [anon_sym_XMLport] = ACTIONS(4169),
    [anon_sym_XMLPort] = ACTIONS(4169),
    [anon_sym_XmlPort] = ACTIONS(4169),
    [anon_sym_enum] = ACTIONS(4169),
    [anon_sym_ENUM] = ACTIONS(4169),
    [anon_sym_Enum] = ACTIONS(4169),
    [anon_sym_eNUM] = ACTIONS(4169),
    [anon_sym_eNum] = ACTIONS(4169),
    [anon_sym_ENum] = ACTIONS(4169),
    [sym_quoted_identifier] = ACTIONS(4171),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4171),
    [sym_integer] = ACTIONS(4169),
    [sym_continue_as_identifier] = ACTIONS(4171),
    [sym_preproc_open] = ACTIONS(4171),
    [sym_preproc_close] = ACTIONS(4171),
  },
  [STATE(1545)] = {
    [sym_identifier] = ACTIONS(4173),
    [anon_sym_SEMI] = ACTIONS(4175),
    [anon_sym_DASH] = ACTIONS(4175),
    [aux_sym_boolean_token1] = ACTIONS(4173),
    [aux_sym_boolean_token2] = ACTIONS(4173),
    [sym_decimal] = ACTIONS(4173),
    [anon_sym_LPAREN] = ACTIONS(4175),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4173),
    [anon_sym_LBRACK] = ACTIONS(4175),
    [aux_sym_record_type_token1] = ACTIONS(4173),
    [aux_sym_basic_type_token21] = ACTIONS(4173),
    [aux_sym_basic_type_token22] = ACTIONS(4173),
    [aux_sym_basic_type_token48] = ACTIONS(4173),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4173),
    [anon_sym_POUNDif] = ACTIONS(4175),
    [anon_sym_POUNDIF] = ACTIONS(4175),
    [anon_sym_POUNDIf] = ACTIONS(4175),
    [anon_sym_not] = ACTIONS(4173),
    [anon_sym_NOT] = ACTIONS(4173),
    [anon_sym_Not] = ACTIONS(4173),
    [anon_sym_POUNDelif] = ACTIONS(4175),
    [anon_sym_POUNDELIF] = ACTIONS(4175),
    [anon_sym_POUNDElif] = ACTIONS(4175),
    [anon_sym_POUNDelse] = ACTIONS(4175),
    [anon_sym_POUNDELSE] = ACTIONS(4175),
    [anon_sym_POUNDElse] = ACTIONS(4175),
    [anon_sym_POUNDendif] = ACTIONS(4175),
    [anon_sym_POUNDENDIF] = ACTIONS(4175),
    [anon_sym_POUNDEndif] = ACTIONS(4175),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4173),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4173),
    [anon_sym_PLUS] = ACTIONS(4175),
    [sym_datetime_literal] = ACTIONS(4175),
    [sym_date_literal] = ACTIONS(4173),
    [sym_time_literal] = ACTIONS(4173),
    [sym_biginteger_literal] = ACTIONS(4175),
    [anon_sym_if] = ACTIONS(4173),
    [anon_sym_IF] = ACTIONS(4173),
    [anon_sym_If] = ACTIONS(4173),
    [anon_sym_else] = ACTIONS(4173),
    [anon_sym_ELSE] = ACTIONS(4173),
    [anon_sym_Else] = ACTIONS(4173),
    [anon_sym_case] = ACTIONS(4173),
    [anon_sym_CASE] = ACTIONS(4173),
    [anon_sym_Case] = ACTIONS(4173),
    [anon_sym_for] = ACTIONS(4173),
    [anon_sym_FOR] = ACTIONS(4173),
    [anon_sym_For] = ACTIONS(4173),
    [anon_sym_foreach] = ACTIONS(4173),
    [anon_sym_FOREACH] = ACTIONS(4173),
    [anon_sym_Foreach] = ACTIONS(4173),
    [anon_sym_while] = ACTIONS(4173),
    [anon_sym_WHILE] = ACTIONS(4173),
    [anon_sym_While] = ACTIONS(4173),
    [anon_sym_repeat] = ACTIONS(4173),
    [anon_sym_REPEAT] = ACTIONS(4173),
    [anon_sym_Repeat] = ACTIONS(4173),
    [anon_sym_exit] = ACTIONS(4173),
    [anon_sym_EXIT] = ACTIONS(4173),
    [anon_sym_Exit] = ACTIONS(4173),
    [anon_sym_continue] = ACTIONS(4173),
    [anon_sym_CONTINUE] = ACTIONS(4173),
    [anon_sym_Continue] = ACTIONS(4173),
    [anon_sym_break] = ACTIONS(4173),
    [anon_sym_BREAK] = ACTIONS(4173),
    [anon_sym_Break] = ACTIONS(4173),
    [anon_sym_with] = ACTIONS(4173),
    [anon_sym_WITH] = ACTIONS(4173),
    [anon_sym_With] = ACTIONS(4173),
    [sym_asserterror_keyword] = ACTIONS(4175),
    [sym_page_keyword] = ACTIONS(4173),
    [anon_sym_codeunit] = ACTIONS(4173),
    [anon_sym_CODEUNIT] = ACTIONS(4173),
    [anon_sym_Codeunit] = ACTIONS(4173),
    [anon_sym_CodeUnit] = ACTIONS(4173),
    [anon_sym_COdeunit] = ACTIONS(4173),
    [anon_sym_codeUnit] = ACTIONS(4173),
    [sym_report_keyword] = ACTIONS(4173),
    [sym_query_keyword] = ACTIONS(4173),
    [anon_sym_xmlport] = ACTIONS(4173),
    [anon_sym_XMLPORT] = ACTIONS(4173),
    [anon_sym_Xmlport] = ACTIONS(4173),
    [anon_sym_XMLport] = ACTIONS(4173),
    [anon_sym_XMLPort] = ACTIONS(4173),
    [anon_sym_XmlPort] = ACTIONS(4173),
    [anon_sym_enum] = ACTIONS(4173),
    [anon_sym_ENUM] = ACTIONS(4173),
    [anon_sym_Enum] = ACTIONS(4173),
    [anon_sym_eNUM] = ACTIONS(4173),
    [anon_sym_eNum] = ACTIONS(4173),
    [anon_sym_ENum] = ACTIONS(4173),
    [sym_quoted_identifier] = ACTIONS(4175),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4175),
    [sym_integer] = ACTIONS(4173),
    [sym_continue_as_identifier] = ACTIONS(4175),
    [sym_preproc_open] = ACTIONS(4175),
    [sym_preproc_close] = ACTIONS(4175),
  },
  [STATE(1546)] = {
    [sym_identifier] = ACTIONS(4177),
    [anon_sym_SEMI] = ACTIONS(4179),
    [anon_sym_DASH] = ACTIONS(4179),
    [aux_sym_boolean_token1] = ACTIONS(4177),
    [aux_sym_boolean_token2] = ACTIONS(4177),
    [sym_decimal] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4179),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4177),
    [anon_sym_LBRACK] = ACTIONS(4179),
    [aux_sym_record_type_token1] = ACTIONS(4177),
    [aux_sym_basic_type_token21] = ACTIONS(4177),
    [aux_sym_basic_type_token22] = ACTIONS(4177),
    [aux_sym_basic_type_token48] = ACTIONS(4177),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4177),
    [anon_sym_POUNDif] = ACTIONS(4179),
    [anon_sym_POUNDIF] = ACTIONS(4179),
    [anon_sym_POUNDIf] = ACTIONS(4179),
    [anon_sym_not] = ACTIONS(4177),
    [anon_sym_NOT] = ACTIONS(4177),
    [anon_sym_Not] = ACTIONS(4177),
    [anon_sym_POUNDelif] = ACTIONS(4179),
    [anon_sym_POUNDELIF] = ACTIONS(4179),
    [anon_sym_POUNDElif] = ACTIONS(4179),
    [anon_sym_POUNDelse] = ACTIONS(4179),
    [anon_sym_POUNDELSE] = ACTIONS(4179),
    [anon_sym_POUNDElse] = ACTIONS(4179),
    [anon_sym_POUNDendif] = ACTIONS(4179),
    [anon_sym_POUNDENDIF] = ACTIONS(4179),
    [anon_sym_POUNDEndif] = ACTIONS(4179),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4177),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4179),
    [sym_datetime_literal] = ACTIONS(4179),
    [sym_date_literal] = ACTIONS(4177),
    [sym_time_literal] = ACTIONS(4177),
    [sym_biginteger_literal] = ACTIONS(4179),
    [anon_sym_if] = ACTIONS(4177),
    [anon_sym_IF] = ACTIONS(4177),
    [anon_sym_If] = ACTIONS(4177),
    [anon_sym_else] = ACTIONS(4177),
    [anon_sym_ELSE] = ACTIONS(4177),
    [anon_sym_Else] = ACTIONS(4177),
    [anon_sym_case] = ACTIONS(4177),
    [anon_sym_CASE] = ACTIONS(4177),
    [anon_sym_Case] = ACTIONS(4177),
    [anon_sym_for] = ACTIONS(4177),
    [anon_sym_FOR] = ACTIONS(4177),
    [anon_sym_For] = ACTIONS(4177),
    [anon_sym_foreach] = ACTIONS(4177),
    [anon_sym_FOREACH] = ACTIONS(4177),
    [anon_sym_Foreach] = ACTIONS(4177),
    [anon_sym_while] = ACTIONS(4177),
    [anon_sym_WHILE] = ACTIONS(4177),
    [anon_sym_While] = ACTIONS(4177),
    [anon_sym_repeat] = ACTIONS(4177),
    [anon_sym_REPEAT] = ACTIONS(4177),
    [anon_sym_Repeat] = ACTIONS(4177),
    [anon_sym_exit] = ACTIONS(4177),
    [anon_sym_EXIT] = ACTIONS(4177),
    [anon_sym_Exit] = ACTIONS(4177),
    [anon_sym_continue] = ACTIONS(4177),
    [anon_sym_CONTINUE] = ACTIONS(4177),
    [anon_sym_Continue] = ACTIONS(4177),
    [anon_sym_break] = ACTIONS(4177),
    [anon_sym_BREAK] = ACTIONS(4177),
    [anon_sym_Break] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4177),
    [anon_sym_WITH] = ACTIONS(4177),
    [anon_sym_With] = ACTIONS(4177),
    [sym_asserterror_keyword] = ACTIONS(4179),
    [sym_page_keyword] = ACTIONS(4177),
    [anon_sym_codeunit] = ACTIONS(4177),
    [anon_sym_CODEUNIT] = ACTIONS(4177),
    [anon_sym_Codeunit] = ACTIONS(4177),
    [anon_sym_CodeUnit] = ACTIONS(4177),
    [anon_sym_COdeunit] = ACTIONS(4177),
    [anon_sym_codeUnit] = ACTIONS(4177),
    [sym_report_keyword] = ACTIONS(4177),
    [sym_query_keyword] = ACTIONS(4177),
    [anon_sym_xmlport] = ACTIONS(4177),
    [anon_sym_XMLPORT] = ACTIONS(4177),
    [anon_sym_Xmlport] = ACTIONS(4177),
    [anon_sym_XMLport] = ACTIONS(4177),
    [anon_sym_XMLPort] = ACTIONS(4177),
    [anon_sym_XmlPort] = ACTIONS(4177),
    [anon_sym_enum] = ACTIONS(4177),
    [anon_sym_ENUM] = ACTIONS(4177),
    [anon_sym_Enum] = ACTIONS(4177),
    [anon_sym_eNUM] = ACTIONS(4177),
    [anon_sym_eNum] = ACTIONS(4177),
    [anon_sym_ENum] = ACTIONS(4177),
    [sym_quoted_identifier] = ACTIONS(4179),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4179),
    [sym_integer] = ACTIONS(4177),
    [sym_continue_as_identifier] = ACTIONS(4179),
    [sym_preproc_open] = ACTIONS(4179),
    [sym_preproc_close] = ACTIONS(4179),
  },
  [STATE(1547)] = {
    [sym_identifier] = ACTIONS(4181),
    [anon_sym_SEMI] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [aux_sym_boolean_token1] = ACTIONS(4181),
    [aux_sym_boolean_token2] = ACTIONS(4181),
    [sym_decimal] = ACTIONS(4181),
    [anon_sym_LPAREN] = ACTIONS(4183),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4181),
    [anon_sym_LBRACK] = ACTIONS(4183),
    [aux_sym_record_type_token1] = ACTIONS(4181),
    [aux_sym_basic_type_token21] = ACTIONS(4181),
    [aux_sym_basic_type_token22] = ACTIONS(4181),
    [aux_sym_basic_type_token48] = ACTIONS(4181),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4181),
    [anon_sym_POUNDif] = ACTIONS(4183),
    [anon_sym_POUNDIF] = ACTIONS(4183),
    [anon_sym_POUNDIf] = ACTIONS(4183),
    [anon_sym_not] = ACTIONS(4181),
    [anon_sym_NOT] = ACTIONS(4181),
    [anon_sym_Not] = ACTIONS(4181),
    [anon_sym_POUNDelif] = ACTIONS(4183),
    [anon_sym_POUNDELIF] = ACTIONS(4183),
    [anon_sym_POUNDElif] = ACTIONS(4183),
    [anon_sym_POUNDelse] = ACTIONS(4183),
    [anon_sym_POUNDELSE] = ACTIONS(4183),
    [anon_sym_POUNDElse] = ACTIONS(4183),
    [anon_sym_POUNDendif] = ACTIONS(4183),
    [anon_sym_POUNDENDIF] = ACTIONS(4183),
    [anon_sym_POUNDEndif] = ACTIONS(4183),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4181),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4181),
    [anon_sym_PLUS] = ACTIONS(4183),
    [sym_datetime_literal] = ACTIONS(4183),
    [sym_date_literal] = ACTIONS(4181),
    [sym_time_literal] = ACTIONS(4181),
    [sym_biginteger_literal] = ACTIONS(4183),
    [anon_sym_if] = ACTIONS(4181),
    [anon_sym_IF] = ACTIONS(4181),
    [anon_sym_If] = ACTIONS(4181),
    [anon_sym_else] = ACTIONS(4181),
    [anon_sym_ELSE] = ACTIONS(4181),
    [anon_sym_Else] = ACTIONS(4181),
    [anon_sym_case] = ACTIONS(4181),
    [anon_sym_CASE] = ACTIONS(4181),
    [anon_sym_Case] = ACTIONS(4181),
    [anon_sym_for] = ACTIONS(4181),
    [anon_sym_FOR] = ACTIONS(4181),
    [anon_sym_For] = ACTIONS(4181),
    [anon_sym_foreach] = ACTIONS(4181),
    [anon_sym_FOREACH] = ACTIONS(4181),
    [anon_sym_Foreach] = ACTIONS(4181),
    [anon_sym_while] = ACTIONS(4181),
    [anon_sym_WHILE] = ACTIONS(4181),
    [anon_sym_While] = ACTIONS(4181),
    [anon_sym_repeat] = ACTIONS(4181),
    [anon_sym_REPEAT] = ACTIONS(4181),
    [anon_sym_Repeat] = ACTIONS(4181),
    [anon_sym_exit] = ACTIONS(4181),
    [anon_sym_EXIT] = ACTIONS(4181),
    [anon_sym_Exit] = ACTIONS(4181),
    [anon_sym_continue] = ACTIONS(4181),
    [anon_sym_CONTINUE] = ACTIONS(4181),
    [anon_sym_Continue] = ACTIONS(4181),
    [anon_sym_break] = ACTIONS(4181),
    [anon_sym_BREAK] = ACTIONS(4181),
    [anon_sym_Break] = ACTIONS(4181),
    [anon_sym_with] = ACTIONS(4181),
    [anon_sym_WITH] = ACTIONS(4181),
    [anon_sym_With] = ACTIONS(4181),
    [sym_asserterror_keyword] = ACTIONS(4183),
    [sym_page_keyword] = ACTIONS(4181),
    [anon_sym_codeunit] = ACTIONS(4181),
    [anon_sym_CODEUNIT] = ACTIONS(4181),
    [anon_sym_Codeunit] = ACTIONS(4181),
    [anon_sym_CodeUnit] = ACTIONS(4181),
    [anon_sym_COdeunit] = ACTIONS(4181),
    [anon_sym_codeUnit] = ACTIONS(4181),
    [sym_report_keyword] = ACTIONS(4181),
    [sym_query_keyword] = ACTIONS(4181),
    [anon_sym_xmlport] = ACTIONS(4181),
    [anon_sym_XMLPORT] = ACTIONS(4181),
    [anon_sym_Xmlport] = ACTIONS(4181),
    [anon_sym_XMLport] = ACTIONS(4181),
    [anon_sym_XMLPort] = ACTIONS(4181),
    [anon_sym_XmlPort] = ACTIONS(4181),
    [anon_sym_enum] = ACTIONS(4181),
    [anon_sym_ENUM] = ACTIONS(4181),
    [anon_sym_Enum] = ACTIONS(4181),
    [anon_sym_eNUM] = ACTIONS(4181),
    [anon_sym_eNum] = ACTIONS(4181),
    [anon_sym_ENum] = ACTIONS(4181),
    [sym_quoted_identifier] = ACTIONS(4183),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4183),
    [sym_integer] = ACTIONS(4181),
    [sym_continue_as_identifier] = ACTIONS(4183),
    [sym_preproc_open] = ACTIONS(4183),
    [sym_preproc_close] = ACTIONS(4183),
  },
  [STATE(1548)] = {
    [sym_identifier] = ACTIONS(4185),
    [anon_sym_SEMI] = ACTIONS(4187),
    [anon_sym_DASH] = ACTIONS(4187),
    [aux_sym_boolean_token1] = ACTIONS(4185),
    [aux_sym_boolean_token2] = ACTIONS(4185),
    [sym_decimal] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4187),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4185),
    [anon_sym_LBRACK] = ACTIONS(4187),
    [aux_sym_record_type_token1] = ACTIONS(4185),
    [aux_sym_basic_type_token21] = ACTIONS(4185),
    [aux_sym_basic_type_token22] = ACTIONS(4185),
    [aux_sym_basic_type_token48] = ACTIONS(4185),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4185),
    [anon_sym_POUNDif] = ACTIONS(4187),
    [anon_sym_POUNDIF] = ACTIONS(4187),
    [anon_sym_POUNDIf] = ACTIONS(4187),
    [anon_sym_not] = ACTIONS(4185),
    [anon_sym_NOT] = ACTIONS(4185),
    [anon_sym_Not] = ACTIONS(4185),
    [anon_sym_POUNDelif] = ACTIONS(4187),
    [anon_sym_POUNDELIF] = ACTIONS(4187),
    [anon_sym_POUNDElif] = ACTIONS(4187),
    [anon_sym_POUNDelse] = ACTIONS(4187),
    [anon_sym_POUNDELSE] = ACTIONS(4187),
    [anon_sym_POUNDElse] = ACTIONS(4187),
    [anon_sym_POUNDendif] = ACTIONS(4187),
    [anon_sym_POUNDENDIF] = ACTIONS(4187),
    [anon_sym_POUNDEndif] = ACTIONS(4187),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4185),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4187),
    [sym_datetime_literal] = ACTIONS(4187),
    [sym_date_literal] = ACTIONS(4185),
    [sym_time_literal] = ACTIONS(4185),
    [sym_biginteger_literal] = ACTIONS(4187),
    [anon_sym_if] = ACTIONS(4185),
    [anon_sym_IF] = ACTIONS(4185),
    [anon_sym_If] = ACTIONS(4185),
    [anon_sym_else] = ACTIONS(4185),
    [anon_sym_ELSE] = ACTIONS(4185),
    [anon_sym_Else] = ACTIONS(4185),
    [anon_sym_case] = ACTIONS(4185),
    [anon_sym_CASE] = ACTIONS(4185),
    [anon_sym_Case] = ACTIONS(4185),
    [anon_sym_for] = ACTIONS(4185),
    [anon_sym_FOR] = ACTIONS(4185),
    [anon_sym_For] = ACTIONS(4185),
    [anon_sym_foreach] = ACTIONS(4185),
    [anon_sym_FOREACH] = ACTIONS(4185),
    [anon_sym_Foreach] = ACTIONS(4185),
    [anon_sym_while] = ACTIONS(4185),
    [anon_sym_WHILE] = ACTIONS(4185),
    [anon_sym_While] = ACTIONS(4185),
    [anon_sym_repeat] = ACTIONS(4185),
    [anon_sym_REPEAT] = ACTIONS(4185),
    [anon_sym_Repeat] = ACTIONS(4185),
    [anon_sym_exit] = ACTIONS(4185),
    [anon_sym_EXIT] = ACTIONS(4185),
    [anon_sym_Exit] = ACTIONS(4185),
    [anon_sym_continue] = ACTIONS(4185),
    [anon_sym_CONTINUE] = ACTIONS(4185),
    [anon_sym_Continue] = ACTIONS(4185),
    [anon_sym_break] = ACTIONS(4185),
    [anon_sym_BREAK] = ACTIONS(4185),
    [anon_sym_Break] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4185),
    [anon_sym_WITH] = ACTIONS(4185),
    [anon_sym_With] = ACTIONS(4185),
    [sym_asserterror_keyword] = ACTIONS(4187),
    [sym_page_keyword] = ACTIONS(4185),
    [anon_sym_codeunit] = ACTIONS(4185),
    [anon_sym_CODEUNIT] = ACTIONS(4185),
    [anon_sym_Codeunit] = ACTIONS(4185),
    [anon_sym_CodeUnit] = ACTIONS(4185),
    [anon_sym_COdeunit] = ACTIONS(4185),
    [anon_sym_codeUnit] = ACTIONS(4185),
    [sym_report_keyword] = ACTIONS(4185),
    [sym_query_keyword] = ACTIONS(4185),
    [anon_sym_xmlport] = ACTIONS(4185),
    [anon_sym_XMLPORT] = ACTIONS(4185),
    [anon_sym_Xmlport] = ACTIONS(4185),
    [anon_sym_XMLport] = ACTIONS(4185),
    [anon_sym_XMLPort] = ACTIONS(4185),
    [anon_sym_XmlPort] = ACTIONS(4185),
    [anon_sym_enum] = ACTIONS(4185),
    [anon_sym_ENUM] = ACTIONS(4185),
    [anon_sym_Enum] = ACTIONS(4185),
    [anon_sym_eNUM] = ACTIONS(4185),
    [anon_sym_eNum] = ACTIONS(4185),
    [anon_sym_ENum] = ACTIONS(4185),
    [sym_quoted_identifier] = ACTIONS(4187),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4187),
    [sym_integer] = ACTIONS(4185),
    [sym_continue_as_identifier] = ACTIONS(4187),
    [sym_preproc_open] = ACTIONS(4187),
    [sym_preproc_close] = ACTIONS(4187),
  },
  [STATE(1549)] = {
    [sym_else_keyword] = STATE(3),
    [sym_identifier] = ACTIONS(4119),
    [anon_sym_SEMI] = ACTIONS(4121),
    [anon_sym_DASH] = ACTIONS(4121),
    [aux_sym_boolean_token1] = ACTIONS(4119),
    [aux_sym_boolean_token2] = ACTIONS(4119),
    [sym_decimal] = ACTIONS(4119),
    [anon_sym_LPAREN] = ACTIONS(4121),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4119),
    [anon_sym_LBRACK] = ACTIONS(4121),
    [aux_sym_record_type_token1] = ACTIONS(4119),
    [aux_sym_basic_type_token21] = ACTIONS(4119),
    [aux_sym_basic_type_token22] = ACTIONS(4119),
    [aux_sym_basic_type_token48] = ACTIONS(4119),
    [anon_sym_POUNDif] = ACTIONS(4121),
    [anon_sym_POUNDIF] = ACTIONS(4121),
    [anon_sym_POUNDIf] = ACTIONS(4121),
    [anon_sym_not] = ACTIONS(4119),
    [anon_sym_NOT] = ACTIONS(4119),
    [anon_sym_Not] = ACTIONS(4119),
    [anon_sym_POUNDelif] = ACTIONS(4121),
    [anon_sym_POUNDELIF] = ACTIONS(4121),
    [anon_sym_POUNDElif] = ACTIONS(4121),
    [anon_sym_POUNDelse] = ACTIONS(4121),
    [anon_sym_POUNDELSE] = ACTIONS(4121),
    [anon_sym_POUNDElse] = ACTIONS(4121),
    [anon_sym_POUNDendif] = ACTIONS(4121),
    [anon_sym_POUNDENDIF] = ACTIONS(4121),
    [anon_sym_POUNDEndif] = ACTIONS(4121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4119),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4119),
    [anon_sym_PLUS] = ACTIONS(4121),
    [sym_datetime_literal] = ACTIONS(4121),
    [sym_date_literal] = ACTIONS(4119),
    [sym_time_literal] = ACTIONS(4119),
    [sym_biginteger_literal] = ACTIONS(4121),
    [anon_sym_if] = ACTIONS(4119),
    [anon_sym_IF] = ACTIONS(4119),
    [anon_sym_If] = ACTIONS(4119),
    [anon_sym_else] = ACTIONS(4123),
    [anon_sym_ELSE] = ACTIONS(4123),
    [anon_sym_Else] = ACTIONS(4123),
    [anon_sym_case] = ACTIONS(4119),
    [anon_sym_CASE] = ACTIONS(4119),
    [anon_sym_Case] = ACTIONS(4119),
    [anon_sym_for] = ACTIONS(4119),
    [anon_sym_FOR] = ACTIONS(4119),
    [anon_sym_For] = ACTIONS(4119),
    [anon_sym_foreach] = ACTIONS(4119),
    [anon_sym_FOREACH] = ACTIONS(4119),
    [anon_sym_Foreach] = ACTIONS(4119),
    [anon_sym_while] = ACTIONS(4119),
    [anon_sym_WHILE] = ACTIONS(4119),
    [anon_sym_While] = ACTIONS(4119),
    [anon_sym_repeat] = ACTIONS(4119),
    [anon_sym_REPEAT] = ACTIONS(4119),
    [anon_sym_Repeat] = ACTIONS(4119),
    [anon_sym_exit] = ACTIONS(4119),
    [anon_sym_EXIT] = ACTIONS(4119),
    [anon_sym_Exit] = ACTIONS(4119),
    [anon_sym_continue] = ACTIONS(4119),
    [anon_sym_CONTINUE] = ACTIONS(4119),
    [anon_sym_Continue] = ACTIONS(4119),
    [anon_sym_break] = ACTIONS(4119),
    [anon_sym_BREAK] = ACTIONS(4119),
    [anon_sym_Break] = ACTIONS(4119),
    [anon_sym_with] = ACTIONS(4119),
    [anon_sym_WITH] = ACTIONS(4119),
    [anon_sym_With] = ACTIONS(4119),
    [sym_asserterror_keyword] = ACTIONS(4121),
    [sym_page_keyword] = ACTIONS(4119),
    [anon_sym_codeunit] = ACTIONS(4119),
    [anon_sym_CODEUNIT] = ACTIONS(4119),
    [anon_sym_Codeunit] = ACTIONS(4119),
    [anon_sym_CodeUnit] = ACTIONS(4119),
    [anon_sym_COdeunit] = ACTIONS(4119),
    [anon_sym_codeUnit] = ACTIONS(4119),
    [sym_report_keyword] = ACTIONS(4119),
    [sym_query_keyword] = ACTIONS(4119),
    [anon_sym_xmlport] = ACTIONS(4119),
    [anon_sym_XMLPORT] = ACTIONS(4119),
    [anon_sym_Xmlport] = ACTIONS(4119),
    [anon_sym_XMLport] = ACTIONS(4119),
    [anon_sym_XMLPort] = ACTIONS(4119),
    [anon_sym_XmlPort] = ACTIONS(4119),
    [anon_sym_enum] = ACTIONS(4119),
    [anon_sym_ENUM] = ACTIONS(4119),
    [anon_sym_Enum] = ACTIONS(4119),
    [anon_sym_eNUM] = ACTIONS(4119),
    [anon_sym_eNum] = ACTIONS(4119),
    [anon_sym_ENum] = ACTIONS(4119),
    [sym_quoted_identifier] = ACTIONS(4121),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4121),
    [sym_integer] = ACTIONS(4119),
    [sym_continue_as_identifier] = ACTIONS(4121),
    [sym_preproc_open] = ACTIONS(4121),
    [sym_preproc_close] = ACTIONS(4121),
  },
  [STATE(1550)] = {
    [sym_else_keyword] = STATE(4),
    [sym_identifier] = ACTIONS(4125),
    [anon_sym_SEMI] = ACTIONS(4127),
    [anon_sym_DASH] = ACTIONS(4127),
    [aux_sym_boolean_token1] = ACTIONS(4125),
    [aux_sym_boolean_token2] = ACTIONS(4125),
    [sym_decimal] = ACTIONS(4125),
    [anon_sym_LPAREN] = ACTIONS(4127),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4125),
    [anon_sym_LBRACK] = ACTIONS(4127),
    [aux_sym_record_type_token1] = ACTIONS(4125),
    [aux_sym_basic_type_token21] = ACTIONS(4125),
    [aux_sym_basic_type_token22] = ACTIONS(4125),
    [aux_sym_basic_type_token48] = ACTIONS(4125),
    [anon_sym_POUNDif] = ACTIONS(4127),
    [anon_sym_POUNDIF] = ACTIONS(4127),
    [anon_sym_POUNDIf] = ACTIONS(4127),
    [anon_sym_not] = ACTIONS(4125),
    [anon_sym_NOT] = ACTIONS(4125),
    [anon_sym_Not] = ACTIONS(4125),
    [anon_sym_POUNDelif] = ACTIONS(4127),
    [anon_sym_POUNDELIF] = ACTIONS(4127),
    [anon_sym_POUNDElif] = ACTIONS(4127),
    [anon_sym_POUNDelse] = ACTIONS(4127),
    [anon_sym_POUNDELSE] = ACTIONS(4127),
    [anon_sym_POUNDElse] = ACTIONS(4127),
    [anon_sym_POUNDendif] = ACTIONS(4127),
    [anon_sym_POUNDENDIF] = ACTIONS(4127),
    [anon_sym_POUNDEndif] = ACTIONS(4127),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4125),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4125),
    [anon_sym_PLUS] = ACTIONS(4127),
    [sym_datetime_literal] = ACTIONS(4127),
    [sym_date_literal] = ACTIONS(4125),
    [sym_time_literal] = ACTIONS(4125),
    [sym_biginteger_literal] = ACTIONS(4127),
    [anon_sym_if] = ACTIONS(4125),
    [anon_sym_IF] = ACTIONS(4125),
    [anon_sym_If] = ACTIONS(4125),
    [anon_sym_else] = ACTIONS(4123),
    [anon_sym_ELSE] = ACTIONS(4123),
    [anon_sym_Else] = ACTIONS(4123),
    [anon_sym_case] = ACTIONS(4125),
    [anon_sym_CASE] = ACTIONS(4125),
    [anon_sym_Case] = ACTIONS(4125),
    [anon_sym_for] = ACTIONS(4125),
    [anon_sym_FOR] = ACTIONS(4125),
    [anon_sym_For] = ACTIONS(4125),
    [anon_sym_foreach] = ACTIONS(4125),
    [anon_sym_FOREACH] = ACTIONS(4125),
    [anon_sym_Foreach] = ACTIONS(4125),
    [anon_sym_while] = ACTIONS(4125),
    [anon_sym_WHILE] = ACTIONS(4125),
    [anon_sym_While] = ACTIONS(4125),
    [anon_sym_repeat] = ACTIONS(4125),
    [anon_sym_REPEAT] = ACTIONS(4125),
    [anon_sym_Repeat] = ACTIONS(4125),
    [anon_sym_exit] = ACTIONS(4125),
    [anon_sym_EXIT] = ACTIONS(4125),
    [anon_sym_Exit] = ACTIONS(4125),
    [anon_sym_continue] = ACTIONS(4125),
    [anon_sym_CONTINUE] = ACTIONS(4125),
    [anon_sym_Continue] = ACTIONS(4125),
    [anon_sym_break] = ACTIONS(4125),
    [anon_sym_BREAK] = ACTIONS(4125),
    [anon_sym_Break] = ACTIONS(4125),
    [anon_sym_with] = ACTIONS(4125),
    [anon_sym_WITH] = ACTIONS(4125),
    [anon_sym_With] = ACTIONS(4125),
    [sym_asserterror_keyword] = ACTIONS(4127),
    [sym_page_keyword] = ACTIONS(4125),
    [anon_sym_codeunit] = ACTIONS(4125),
    [anon_sym_CODEUNIT] = ACTIONS(4125),
    [anon_sym_Codeunit] = ACTIONS(4125),
    [anon_sym_CodeUnit] = ACTIONS(4125),
    [anon_sym_COdeunit] = ACTIONS(4125),
    [anon_sym_codeUnit] = ACTIONS(4125),
    [sym_report_keyword] = ACTIONS(4125),
    [sym_query_keyword] = ACTIONS(4125),
    [anon_sym_xmlport] = ACTIONS(4125),
    [anon_sym_XMLPORT] = ACTIONS(4125),
    [anon_sym_Xmlport] = ACTIONS(4125),
    [anon_sym_XMLport] = ACTIONS(4125),
    [anon_sym_XMLPort] = ACTIONS(4125),
    [anon_sym_XmlPort] = ACTIONS(4125),
    [anon_sym_enum] = ACTIONS(4125),
    [anon_sym_ENUM] = ACTIONS(4125),
    [anon_sym_Enum] = ACTIONS(4125),
    [anon_sym_eNUM] = ACTIONS(4125),
    [anon_sym_eNum] = ACTIONS(4125),
    [anon_sym_ENum] = ACTIONS(4125),
    [sym_quoted_identifier] = ACTIONS(4127),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4127),
    [sym_integer] = ACTIONS(4125),
    [sym_continue_as_identifier] = ACTIONS(4127),
    [sym_preproc_open] = ACTIONS(4127),
    [sym_preproc_close] = ACTIONS(4127),
  },
  [STATE(1551)] = {
    [sym_identifier] = ACTIONS(4189),
    [anon_sym_SEMI] = ACTIONS(4191),
    [anon_sym_DASH] = ACTIONS(4191),
    [aux_sym_boolean_token1] = ACTIONS(4189),
    [aux_sym_boolean_token2] = ACTIONS(4189),
    [sym_decimal] = ACTIONS(4189),
    [anon_sym_LPAREN] = ACTIONS(4191),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4189),
    [anon_sym_LBRACK] = ACTIONS(4191),
    [aux_sym_record_type_token1] = ACTIONS(4189),
    [aux_sym_basic_type_token21] = ACTIONS(4189),
    [aux_sym_basic_type_token22] = ACTIONS(4189),
    [aux_sym_basic_type_token48] = ACTIONS(4189),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4189),
    [anon_sym_POUNDif] = ACTIONS(4191),
    [anon_sym_POUNDIF] = ACTIONS(4191),
    [anon_sym_POUNDIf] = ACTIONS(4191),
    [anon_sym_not] = ACTIONS(4189),
    [anon_sym_NOT] = ACTIONS(4189),
    [anon_sym_Not] = ACTIONS(4189),
    [anon_sym_POUNDelif] = ACTIONS(4191),
    [anon_sym_POUNDELIF] = ACTIONS(4191),
    [anon_sym_POUNDElif] = ACTIONS(4191),
    [anon_sym_POUNDelse] = ACTIONS(4191),
    [anon_sym_POUNDELSE] = ACTIONS(4191),
    [anon_sym_POUNDElse] = ACTIONS(4191),
    [anon_sym_POUNDendif] = ACTIONS(4191),
    [anon_sym_POUNDENDIF] = ACTIONS(4191),
    [anon_sym_POUNDEndif] = ACTIONS(4191),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4189),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4189),
    [anon_sym_PLUS] = ACTIONS(4191),
    [sym_datetime_literal] = ACTIONS(4191),
    [sym_date_literal] = ACTIONS(4189),
    [sym_time_literal] = ACTIONS(4189),
    [sym_biginteger_literal] = ACTIONS(4191),
    [anon_sym_if] = ACTIONS(4189),
    [anon_sym_IF] = ACTIONS(4189),
    [anon_sym_If] = ACTIONS(4189),
    [anon_sym_else] = ACTIONS(4189),
    [anon_sym_ELSE] = ACTIONS(4189),
    [anon_sym_Else] = ACTIONS(4189),
    [anon_sym_case] = ACTIONS(4189),
    [anon_sym_CASE] = ACTIONS(4189),
    [anon_sym_Case] = ACTIONS(4189),
    [anon_sym_for] = ACTIONS(4189),
    [anon_sym_FOR] = ACTIONS(4189),
    [anon_sym_For] = ACTIONS(4189),
    [anon_sym_foreach] = ACTIONS(4189),
    [anon_sym_FOREACH] = ACTIONS(4189),
    [anon_sym_Foreach] = ACTIONS(4189),
    [anon_sym_while] = ACTIONS(4189),
    [anon_sym_WHILE] = ACTIONS(4189),
    [anon_sym_While] = ACTIONS(4189),
    [anon_sym_repeat] = ACTIONS(4189),
    [anon_sym_REPEAT] = ACTIONS(4189),
    [anon_sym_Repeat] = ACTIONS(4189),
    [anon_sym_exit] = ACTIONS(4189),
    [anon_sym_EXIT] = ACTIONS(4189),
    [anon_sym_Exit] = ACTIONS(4189),
    [anon_sym_continue] = ACTIONS(4189),
    [anon_sym_CONTINUE] = ACTIONS(4189),
    [anon_sym_Continue] = ACTIONS(4189),
    [anon_sym_break] = ACTIONS(4189),
    [anon_sym_BREAK] = ACTIONS(4189),
    [anon_sym_Break] = ACTIONS(4189),
    [anon_sym_with] = ACTIONS(4189),
    [anon_sym_WITH] = ACTIONS(4189),
    [anon_sym_With] = ACTIONS(4189),
    [sym_asserterror_keyword] = ACTIONS(4191),
    [sym_page_keyword] = ACTIONS(4189),
    [anon_sym_codeunit] = ACTIONS(4189),
    [anon_sym_CODEUNIT] = ACTIONS(4189),
    [anon_sym_Codeunit] = ACTIONS(4189),
    [anon_sym_CodeUnit] = ACTIONS(4189),
    [anon_sym_COdeunit] = ACTIONS(4189),
    [anon_sym_codeUnit] = ACTIONS(4189),
    [sym_report_keyword] = ACTIONS(4189),
    [sym_query_keyword] = ACTIONS(4189),
    [anon_sym_xmlport] = ACTIONS(4189),
    [anon_sym_XMLPORT] = ACTIONS(4189),
    [anon_sym_Xmlport] = ACTIONS(4189),
    [anon_sym_XMLport] = ACTIONS(4189),
    [anon_sym_XMLPort] = ACTIONS(4189),
    [anon_sym_XmlPort] = ACTIONS(4189),
    [anon_sym_enum] = ACTIONS(4189),
    [anon_sym_ENUM] = ACTIONS(4189),
    [anon_sym_Enum] = ACTIONS(4189),
    [anon_sym_eNUM] = ACTIONS(4189),
    [anon_sym_eNum] = ACTIONS(4189),
    [anon_sym_ENum] = ACTIONS(4189),
    [sym_quoted_identifier] = ACTIONS(4191),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4191),
    [sym_integer] = ACTIONS(4189),
    [sym_continue_as_identifier] = ACTIONS(4191),
    [sym_preproc_open] = ACTIONS(4191),
    [sym_preproc_close] = ACTIONS(4191),
  },
  [STATE(1552)] = {
    [sym_identifier] = ACTIONS(4193),
    [anon_sym_SEMI] = ACTIONS(4195),
    [anon_sym_DASH] = ACTIONS(4195),
    [aux_sym_boolean_token1] = ACTIONS(4193),
    [aux_sym_boolean_token2] = ACTIONS(4193),
    [sym_decimal] = ACTIONS(4193),
    [anon_sym_LPAREN] = ACTIONS(4195),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4193),
    [anon_sym_LBRACK] = ACTIONS(4195),
    [aux_sym_record_type_token1] = ACTIONS(4193),
    [aux_sym_basic_type_token21] = ACTIONS(4193),
    [aux_sym_basic_type_token22] = ACTIONS(4193),
    [aux_sym_basic_type_token48] = ACTIONS(4193),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4193),
    [anon_sym_POUNDif] = ACTIONS(4195),
    [anon_sym_POUNDIF] = ACTIONS(4195),
    [anon_sym_POUNDIf] = ACTIONS(4195),
    [anon_sym_not] = ACTIONS(4193),
    [anon_sym_NOT] = ACTIONS(4193),
    [anon_sym_Not] = ACTIONS(4193),
    [anon_sym_POUNDelif] = ACTIONS(4195),
    [anon_sym_POUNDELIF] = ACTIONS(4195),
    [anon_sym_POUNDElif] = ACTIONS(4195),
    [anon_sym_POUNDelse] = ACTIONS(4195),
    [anon_sym_POUNDELSE] = ACTIONS(4195),
    [anon_sym_POUNDElse] = ACTIONS(4195),
    [anon_sym_POUNDendif] = ACTIONS(4195),
    [anon_sym_POUNDENDIF] = ACTIONS(4195),
    [anon_sym_POUNDEndif] = ACTIONS(4195),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4193),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4193),
    [anon_sym_PLUS] = ACTIONS(4195),
    [sym_datetime_literal] = ACTIONS(4195),
    [sym_date_literal] = ACTIONS(4193),
    [sym_time_literal] = ACTIONS(4193),
    [sym_biginteger_literal] = ACTIONS(4195),
    [anon_sym_if] = ACTIONS(4193),
    [anon_sym_IF] = ACTIONS(4193),
    [anon_sym_If] = ACTIONS(4193),
    [anon_sym_else] = ACTIONS(4193),
    [anon_sym_ELSE] = ACTIONS(4193),
    [anon_sym_Else] = ACTIONS(4193),
    [anon_sym_case] = ACTIONS(4193),
    [anon_sym_CASE] = ACTIONS(4193),
    [anon_sym_Case] = ACTIONS(4193),
    [anon_sym_for] = ACTIONS(4193),
    [anon_sym_FOR] = ACTIONS(4193),
    [anon_sym_For] = ACTIONS(4193),
    [anon_sym_foreach] = ACTIONS(4193),
    [anon_sym_FOREACH] = ACTIONS(4193),
    [anon_sym_Foreach] = ACTIONS(4193),
    [anon_sym_while] = ACTIONS(4193),
    [anon_sym_WHILE] = ACTIONS(4193),
    [anon_sym_While] = ACTIONS(4193),
    [anon_sym_repeat] = ACTIONS(4193),
    [anon_sym_REPEAT] = ACTIONS(4193),
    [anon_sym_Repeat] = ACTIONS(4193),
    [anon_sym_exit] = ACTIONS(4193),
    [anon_sym_EXIT] = ACTIONS(4193),
    [anon_sym_Exit] = ACTIONS(4193),
    [anon_sym_continue] = ACTIONS(4193),
    [anon_sym_CONTINUE] = ACTIONS(4193),
    [anon_sym_Continue] = ACTIONS(4193),
    [anon_sym_break] = ACTIONS(4193),
    [anon_sym_BREAK] = ACTIONS(4193),
    [anon_sym_Break] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4193),
    [anon_sym_WITH] = ACTIONS(4193),
    [anon_sym_With] = ACTIONS(4193),
    [sym_asserterror_keyword] = ACTIONS(4195),
    [sym_page_keyword] = ACTIONS(4193),
    [anon_sym_codeunit] = ACTIONS(4193),
    [anon_sym_CODEUNIT] = ACTIONS(4193),
    [anon_sym_Codeunit] = ACTIONS(4193),
    [anon_sym_CodeUnit] = ACTIONS(4193),
    [anon_sym_COdeunit] = ACTIONS(4193),
    [anon_sym_codeUnit] = ACTIONS(4193),
    [sym_report_keyword] = ACTIONS(4193),
    [sym_query_keyword] = ACTIONS(4193),
    [anon_sym_xmlport] = ACTIONS(4193),
    [anon_sym_XMLPORT] = ACTIONS(4193),
    [anon_sym_Xmlport] = ACTIONS(4193),
    [anon_sym_XMLport] = ACTIONS(4193),
    [anon_sym_XMLPort] = ACTIONS(4193),
    [anon_sym_XmlPort] = ACTIONS(4193),
    [anon_sym_enum] = ACTIONS(4193),
    [anon_sym_ENUM] = ACTIONS(4193),
    [anon_sym_Enum] = ACTIONS(4193),
    [anon_sym_eNUM] = ACTIONS(4193),
    [anon_sym_eNum] = ACTIONS(4193),
    [anon_sym_ENum] = ACTIONS(4193),
    [sym_quoted_identifier] = ACTIONS(4195),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4195),
    [sym_integer] = ACTIONS(4193),
    [sym_continue_as_identifier] = ACTIONS(4195),
    [sym_preproc_open] = ACTIONS(4195),
    [sym_preproc_close] = ACTIONS(4195),
  },
  [STATE(1553)] = {
    [sym_identifier] = ACTIONS(4197),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_DASH] = ACTIONS(4199),
    [aux_sym_boolean_token1] = ACTIONS(4197),
    [aux_sym_boolean_token2] = ACTIONS(4197),
    [sym_decimal] = ACTIONS(4197),
    [anon_sym_LPAREN] = ACTIONS(4199),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4197),
    [anon_sym_LBRACK] = ACTIONS(4199),
    [aux_sym_record_type_token1] = ACTIONS(4197),
    [aux_sym_basic_type_token21] = ACTIONS(4197),
    [aux_sym_basic_type_token22] = ACTIONS(4197),
    [aux_sym_basic_type_token48] = ACTIONS(4197),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4197),
    [anon_sym_POUNDif] = ACTIONS(4199),
    [anon_sym_POUNDIF] = ACTIONS(4199),
    [anon_sym_POUNDIf] = ACTIONS(4199),
    [anon_sym_not] = ACTIONS(4197),
    [anon_sym_NOT] = ACTIONS(4197),
    [anon_sym_Not] = ACTIONS(4197),
    [anon_sym_POUNDelif] = ACTIONS(4199),
    [anon_sym_POUNDELIF] = ACTIONS(4199),
    [anon_sym_POUNDElif] = ACTIONS(4199),
    [anon_sym_POUNDelse] = ACTIONS(4199),
    [anon_sym_POUNDELSE] = ACTIONS(4199),
    [anon_sym_POUNDElse] = ACTIONS(4199),
    [anon_sym_POUNDendif] = ACTIONS(4199),
    [anon_sym_POUNDENDIF] = ACTIONS(4199),
    [anon_sym_POUNDEndif] = ACTIONS(4199),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4197),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4197),
    [anon_sym_PLUS] = ACTIONS(4199),
    [sym_datetime_literal] = ACTIONS(4199),
    [sym_date_literal] = ACTIONS(4197),
    [sym_time_literal] = ACTIONS(4197),
    [sym_biginteger_literal] = ACTIONS(4199),
    [anon_sym_if] = ACTIONS(4197),
    [anon_sym_IF] = ACTIONS(4197),
    [anon_sym_If] = ACTIONS(4197),
    [anon_sym_else] = ACTIONS(4197),
    [anon_sym_ELSE] = ACTIONS(4197),
    [anon_sym_Else] = ACTIONS(4197),
    [anon_sym_case] = ACTIONS(4197),
    [anon_sym_CASE] = ACTIONS(4197),
    [anon_sym_Case] = ACTIONS(4197),
    [anon_sym_for] = ACTIONS(4197),
    [anon_sym_FOR] = ACTIONS(4197),
    [anon_sym_For] = ACTIONS(4197),
    [anon_sym_foreach] = ACTIONS(4197),
    [anon_sym_FOREACH] = ACTIONS(4197),
    [anon_sym_Foreach] = ACTIONS(4197),
    [anon_sym_while] = ACTIONS(4197),
    [anon_sym_WHILE] = ACTIONS(4197),
    [anon_sym_While] = ACTIONS(4197),
    [anon_sym_repeat] = ACTIONS(4197),
    [anon_sym_REPEAT] = ACTIONS(4197),
    [anon_sym_Repeat] = ACTIONS(4197),
    [anon_sym_exit] = ACTIONS(4197),
    [anon_sym_EXIT] = ACTIONS(4197),
    [anon_sym_Exit] = ACTIONS(4197),
    [anon_sym_continue] = ACTIONS(4197),
    [anon_sym_CONTINUE] = ACTIONS(4197),
    [anon_sym_Continue] = ACTIONS(4197),
    [anon_sym_break] = ACTIONS(4197),
    [anon_sym_BREAK] = ACTIONS(4197),
    [anon_sym_Break] = ACTIONS(4197),
    [anon_sym_with] = ACTIONS(4197),
    [anon_sym_WITH] = ACTIONS(4197),
    [anon_sym_With] = ACTIONS(4197),
    [sym_asserterror_keyword] = ACTIONS(4199),
    [sym_page_keyword] = ACTIONS(4197),
    [anon_sym_codeunit] = ACTIONS(4197),
    [anon_sym_CODEUNIT] = ACTIONS(4197),
    [anon_sym_Codeunit] = ACTIONS(4197),
    [anon_sym_CodeUnit] = ACTIONS(4197),
    [anon_sym_COdeunit] = ACTIONS(4197),
    [anon_sym_codeUnit] = ACTIONS(4197),
    [sym_report_keyword] = ACTIONS(4197),
    [sym_query_keyword] = ACTIONS(4197),
    [anon_sym_xmlport] = ACTIONS(4197),
    [anon_sym_XMLPORT] = ACTIONS(4197),
    [anon_sym_Xmlport] = ACTIONS(4197),
    [anon_sym_XMLport] = ACTIONS(4197),
    [anon_sym_XMLPort] = ACTIONS(4197),
    [anon_sym_XmlPort] = ACTIONS(4197),
    [anon_sym_enum] = ACTIONS(4197),
    [anon_sym_ENUM] = ACTIONS(4197),
    [anon_sym_Enum] = ACTIONS(4197),
    [anon_sym_eNUM] = ACTIONS(4197),
    [anon_sym_eNum] = ACTIONS(4197),
    [anon_sym_ENum] = ACTIONS(4197),
    [sym_quoted_identifier] = ACTIONS(4199),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4199),
    [sym_integer] = ACTIONS(4197),
    [sym_continue_as_identifier] = ACTIONS(4199),
    [sym_preproc_open] = ACTIONS(4199),
    [sym_preproc_close] = ACTIONS(4199),
  },
  [STATE(1554)] = {
    [sym_identifier] = ACTIONS(4201),
    [anon_sym_SEMI] = ACTIONS(4203),
    [anon_sym_DASH] = ACTIONS(4203),
    [aux_sym_boolean_token1] = ACTIONS(4201),
    [aux_sym_boolean_token2] = ACTIONS(4201),
    [sym_decimal] = ACTIONS(4201),
    [anon_sym_LPAREN] = ACTIONS(4203),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4201),
    [anon_sym_LBRACK] = ACTIONS(4203),
    [aux_sym_record_type_token1] = ACTIONS(4201),
    [aux_sym_basic_type_token21] = ACTIONS(4201),
    [aux_sym_basic_type_token22] = ACTIONS(4201),
    [aux_sym_basic_type_token48] = ACTIONS(4201),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4201),
    [anon_sym_POUNDif] = ACTIONS(4203),
    [anon_sym_POUNDIF] = ACTIONS(4203),
    [anon_sym_POUNDIf] = ACTIONS(4203),
    [anon_sym_not] = ACTIONS(4201),
    [anon_sym_NOT] = ACTIONS(4201),
    [anon_sym_Not] = ACTIONS(4201),
    [anon_sym_POUNDelif] = ACTIONS(4203),
    [anon_sym_POUNDELIF] = ACTIONS(4203),
    [anon_sym_POUNDElif] = ACTIONS(4203),
    [anon_sym_POUNDelse] = ACTIONS(4203),
    [anon_sym_POUNDELSE] = ACTIONS(4203),
    [anon_sym_POUNDElse] = ACTIONS(4203),
    [anon_sym_POUNDendif] = ACTIONS(4203),
    [anon_sym_POUNDENDIF] = ACTIONS(4203),
    [anon_sym_POUNDEndif] = ACTIONS(4203),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4201),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4201),
    [anon_sym_PLUS] = ACTIONS(4203),
    [sym_datetime_literal] = ACTIONS(4203),
    [sym_date_literal] = ACTIONS(4201),
    [sym_time_literal] = ACTIONS(4201),
    [sym_biginteger_literal] = ACTIONS(4203),
    [anon_sym_if] = ACTIONS(4201),
    [anon_sym_IF] = ACTIONS(4201),
    [anon_sym_If] = ACTIONS(4201),
    [anon_sym_else] = ACTIONS(4201),
    [anon_sym_ELSE] = ACTIONS(4201),
    [anon_sym_Else] = ACTIONS(4201),
    [anon_sym_case] = ACTIONS(4201),
    [anon_sym_CASE] = ACTIONS(4201),
    [anon_sym_Case] = ACTIONS(4201),
    [anon_sym_for] = ACTIONS(4201),
    [anon_sym_FOR] = ACTIONS(4201),
    [anon_sym_For] = ACTIONS(4201),
    [anon_sym_foreach] = ACTIONS(4201),
    [anon_sym_FOREACH] = ACTIONS(4201),
    [anon_sym_Foreach] = ACTIONS(4201),
    [anon_sym_while] = ACTIONS(4201),
    [anon_sym_WHILE] = ACTIONS(4201),
    [anon_sym_While] = ACTIONS(4201),
    [anon_sym_repeat] = ACTIONS(4201),
    [anon_sym_REPEAT] = ACTIONS(4201),
    [anon_sym_Repeat] = ACTIONS(4201),
    [anon_sym_exit] = ACTIONS(4201),
    [anon_sym_EXIT] = ACTIONS(4201),
    [anon_sym_Exit] = ACTIONS(4201),
    [anon_sym_continue] = ACTIONS(4201),
    [anon_sym_CONTINUE] = ACTIONS(4201),
    [anon_sym_Continue] = ACTIONS(4201),
    [anon_sym_break] = ACTIONS(4201),
    [anon_sym_BREAK] = ACTIONS(4201),
    [anon_sym_Break] = ACTIONS(4201),
    [anon_sym_with] = ACTIONS(4201),
    [anon_sym_WITH] = ACTIONS(4201),
    [anon_sym_With] = ACTIONS(4201),
    [sym_asserterror_keyword] = ACTIONS(4203),
    [sym_page_keyword] = ACTIONS(4201),
    [anon_sym_codeunit] = ACTIONS(4201),
    [anon_sym_CODEUNIT] = ACTIONS(4201),
    [anon_sym_Codeunit] = ACTIONS(4201),
    [anon_sym_CodeUnit] = ACTIONS(4201),
    [anon_sym_COdeunit] = ACTIONS(4201),
    [anon_sym_codeUnit] = ACTIONS(4201),
    [sym_report_keyword] = ACTIONS(4201),
    [sym_query_keyword] = ACTIONS(4201),
    [anon_sym_xmlport] = ACTIONS(4201),
    [anon_sym_XMLPORT] = ACTIONS(4201),
    [anon_sym_Xmlport] = ACTIONS(4201),
    [anon_sym_XMLport] = ACTIONS(4201),
    [anon_sym_XMLPort] = ACTIONS(4201),
    [anon_sym_XmlPort] = ACTIONS(4201),
    [anon_sym_enum] = ACTIONS(4201),
    [anon_sym_ENUM] = ACTIONS(4201),
    [anon_sym_Enum] = ACTIONS(4201),
    [anon_sym_eNUM] = ACTIONS(4201),
    [anon_sym_eNum] = ACTIONS(4201),
    [anon_sym_ENum] = ACTIONS(4201),
    [sym_quoted_identifier] = ACTIONS(4203),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4203),
    [sym_integer] = ACTIONS(4201),
    [sym_continue_as_identifier] = ACTIONS(4203),
    [sym_preproc_open] = ACTIONS(4203),
    [sym_preproc_close] = ACTIONS(4203),
  },
  [STATE(1555)] = {
    [sym_identifier] = ACTIONS(4205),
    [anon_sym_SEMI] = ACTIONS(4207),
    [anon_sym_DASH] = ACTIONS(4207),
    [aux_sym_boolean_token1] = ACTIONS(4205),
    [aux_sym_boolean_token2] = ACTIONS(4205),
    [sym_decimal] = ACTIONS(4205),
    [anon_sym_LPAREN] = ACTIONS(4207),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4205),
    [anon_sym_LBRACK] = ACTIONS(4207),
    [aux_sym_record_type_token1] = ACTIONS(4205),
    [aux_sym_basic_type_token21] = ACTIONS(4205),
    [aux_sym_basic_type_token22] = ACTIONS(4205),
    [aux_sym_basic_type_token48] = ACTIONS(4205),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4205),
    [anon_sym_POUNDif] = ACTIONS(4207),
    [anon_sym_POUNDIF] = ACTIONS(4207),
    [anon_sym_POUNDIf] = ACTIONS(4207),
    [anon_sym_not] = ACTIONS(4205),
    [anon_sym_NOT] = ACTIONS(4205),
    [anon_sym_Not] = ACTIONS(4205),
    [anon_sym_POUNDelif] = ACTIONS(4207),
    [anon_sym_POUNDELIF] = ACTIONS(4207),
    [anon_sym_POUNDElif] = ACTIONS(4207),
    [anon_sym_POUNDelse] = ACTIONS(4207),
    [anon_sym_POUNDELSE] = ACTIONS(4207),
    [anon_sym_POUNDElse] = ACTIONS(4207),
    [anon_sym_POUNDendif] = ACTIONS(4207),
    [anon_sym_POUNDENDIF] = ACTIONS(4207),
    [anon_sym_POUNDEndif] = ACTIONS(4207),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4205),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4205),
    [anon_sym_PLUS] = ACTIONS(4207),
    [sym_datetime_literal] = ACTIONS(4207),
    [sym_date_literal] = ACTIONS(4205),
    [sym_time_literal] = ACTIONS(4205),
    [sym_biginteger_literal] = ACTIONS(4207),
    [anon_sym_if] = ACTIONS(4205),
    [anon_sym_IF] = ACTIONS(4205),
    [anon_sym_If] = ACTIONS(4205),
    [anon_sym_else] = ACTIONS(4205),
    [anon_sym_ELSE] = ACTIONS(4205),
    [anon_sym_Else] = ACTIONS(4205),
    [anon_sym_case] = ACTIONS(4205),
    [anon_sym_CASE] = ACTIONS(4205),
    [anon_sym_Case] = ACTIONS(4205),
    [anon_sym_for] = ACTIONS(4205),
    [anon_sym_FOR] = ACTIONS(4205),
    [anon_sym_For] = ACTIONS(4205),
    [anon_sym_foreach] = ACTIONS(4205),
    [anon_sym_FOREACH] = ACTIONS(4205),
    [anon_sym_Foreach] = ACTIONS(4205),
    [anon_sym_while] = ACTIONS(4205),
    [anon_sym_WHILE] = ACTIONS(4205),
    [anon_sym_While] = ACTIONS(4205),
    [anon_sym_repeat] = ACTIONS(4205),
    [anon_sym_REPEAT] = ACTIONS(4205),
    [anon_sym_Repeat] = ACTIONS(4205),
    [anon_sym_exit] = ACTIONS(4205),
    [anon_sym_EXIT] = ACTIONS(4205),
    [anon_sym_Exit] = ACTIONS(4205),
    [anon_sym_continue] = ACTIONS(4205),
    [anon_sym_CONTINUE] = ACTIONS(4205),
    [anon_sym_Continue] = ACTIONS(4205),
    [anon_sym_break] = ACTIONS(4205),
    [anon_sym_BREAK] = ACTIONS(4205),
    [anon_sym_Break] = ACTIONS(4205),
    [anon_sym_with] = ACTIONS(4205),
    [anon_sym_WITH] = ACTIONS(4205),
    [anon_sym_With] = ACTIONS(4205),
    [sym_asserterror_keyword] = ACTIONS(4207),
    [sym_page_keyword] = ACTIONS(4205),
    [anon_sym_codeunit] = ACTIONS(4205),
    [anon_sym_CODEUNIT] = ACTIONS(4205),
    [anon_sym_Codeunit] = ACTIONS(4205),
    [anon_sym_CodeUnit] = ACTIONS(4205),
    [anon_sym_COdeunit] = ACTIONS(4205),
    [anon_sym_codeUnit] = ACTIONS(4205),
    [sym_report_keyword] = ACTIONS(4205),
    [sym_query_keyword] = ACTIONS(4205),
    [anon_sym_xmlport] = ACTIONS(4205),
    [anon_sym_XMLPORT] = ACTIONS(4205),
    [anon_sym_Xmlport] = ACTIONS(4205),
    [anon_sym_XMLport] = ACTIONS(4205),
    [anon_sym_XMLPort] = ACTIONS(4205),
    [anon_sym_XmlPort] = ACTIONS(4205),
    [anon_sym_enum] = ACTIONS(4205),
    [anon_sym_ENUM] = ACTIONS(4205),
    [anon_sym_Enum] = ACTIONS(4205),
    [anon_sym_eNUM] = ACTIONS(4205),
    [anon_sym_eNum] = ACTIONS(4205),
    [anon_sym_ENum] = ACTIONS(4205),
    [sym_quoted_identifier] = ACTIONS(4207),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4207),
    [sym_integer] = ACTIONS(4205),
    [sym_continue_as_identifier] = ACTIONS(4207),
    [sym_preproc_open] = ACTIONS(4207),
    [sym_preproc_close] = ACTIONS(4207),
  },
  [STATE(1556)] = {
    [sym_identifier] = ACTIONS(4209),
    [anon_sym_SEMI] = ACTIONS(4211),
    [anon_sym_DASH] = ACTIONS(4211),
    [aux_sym_boolean_token1] = ACTIONS(4209),
    [aux_sym_boolean_token2] = ACTIONS(4209),
    [sym_decimal] = ACTIONS(4209),
    [anon_sym_LPAREN] = ACTIONS(4211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4209),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [aux_sym_record_type_token1] = ACTIONS(4209),
    [aux_sym_basic_type_token21] = ACTIONS(4209),
    [aux_sym_basic_type_token22] = ACTIONS(4209),
    [aux_sym_basic_type_token48] = ACTIONS(4209),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4209),
    [anon_sym_POUNDif] = ACTIONS(4211),
    [anon_sym_POUNDIF] = ACTIONS(4211),
    [anon_sym_POUNDIf] = ACTIONS(4211),
    [anon_sym_not] = ACTIONS(4209),
    [anon_sym_NOT] = ACTIONS(4209),
    [anon_sym_Not] = ACTIONS(4209),
    [anon_sym_POUNDelif] = ACTIONS(4211),
    [anon_sym_POUNDELIF] = ACTIONS(4211),
    [anon_sym_POUNDElif] = ACTIONS(4211),
    [anon_sym_POUNDelse] = ACTIONS(4211),
    [anon_sym_POUNDELSE] = ACTIONS(4211),
    [anon_sym_POUNDElse] = ACTIONS(4211),
    [anon_sym_POUNDendif] = ACTIONS(4211),
    [anon_sym_POUNDENDIF] = ACTIONS(4211),
    [anon_sym_POUNDEndif] = ACTIONS(4211),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4209),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4209),
    [anon_sym_PLUS] = ACTIONS(4211),
    [sym_datetime_literal] = ACTIONS(4211),
    [sym_date_literal] = ACTIONS(4209),
    [sym_time_literal] = ACTIONS(4209),
    [sym_biginteger_literal] = ACTIONS(4211),
    [anon_sym_if] = ACTIONS(4209),
    [anon_sym_IF] = ACTIONS(4209),
    [anon_sym_If] = ACTIONS(4209),
    [anon_sym_else] = ACTIONS(4209),
    [anon_sym_ELSE] = ACTIONS(4209),
    [anon_sym_Else] = ACTIONS(4209),
    [anon_sym_case] = ACTIONS(4209),
    [anon_sym_CASE] = ACTIONS(4209),
    [anon_sym_Case] = ACTIONS(4209),
    [anon_sym_for] = ACTIONS(4209),
    [anon_sym_FOR] = ACTIONS(4209),
    [anon_sym_For] = ACTIONS(4209),
    [anon_sym_foreach] = ACTIONS(4209),
    [anon_sym_FOREACH] = ACTIONS(4209),
    [anon_sym_Foreach] = ACTIONS(4209),
    [anon_sym_while] = ACTIONS(4209),
    [anon_sym_WHILE] = ACTIONS(4209),
    [anon_sym_While] = ACTIONS(4209),
    [anon_sym_repeat] = ACTIONS(4209),
    [anon_sym_REPEAT] = ACTIONS(4209),
    [anon_sym_Repeat] = ACTIONS(4209),
    [anon_sym_exit] = ACTIONS(4209),
    [anon_sym_EXIT] = ACTIONS(4209),
    [anon_sym_Exit] = ACTIONS(4209),
    [anon_sym_continue] = ACTIONS(4209),
    [anon_sym_CONTINUE] = ACTIONS(4209),
    [anon_sym_Continue] = ACTIONS(4209),
    [anon_sym_break] = ACTIONS(4209),
    [anon_sym_BREAK] = ACTIONS(4209),
    [anon_sym_Break] = ACTIONS(4209),
    [anon_sym_with] = ACTIONS(4209),
    [anon_sym_WITH] = ACTIONS(4209),
    [anon_sym_With] = ACTIONS(4209),
    [sym_asserterror_keyword] = ACTIONS(4211),
    [sym_page_keyword] = ACTIONS(4209),
    [anon_sym_codeunit] = ACTIONS(4209),
    [anon_sym_CODEUNIT] = ACTIONS(4209),
    [anon_sym_Codeunit] = ACTIONS(4209),
    [anon_sym_CodeUnit] = ACTIONS(4209),
    [anon_sym_COdeunit] = ACTIONS(4209),
    [anon_sym_codeUnit] = ACTIONS(4209),
    [sym_report_keyword] = ACTIONS(4209),
    [sym_query_keyword] = ACTIONS(4209),
    [anon_sym_xmlport] = ACTIONS(4209),
    [anon_sym_XMLPORT] = ACTIONS(4209),
    [anon_sym_Xmlport] = ACTIONS(4209),
    [anon_sym_XMLport] = ACTIONS(4209),
    [anon_sym_XMLPort] = ACTIONS(4209),
    [anon_sym_XmlPort] = ACTIONS(4209),
    [anon_sym_enum] = ACTIONS(4209),
    [anon_sym_ENUM] = ACTIONS(4209),
    [anon_sym_Enum] = ACTIONS(4209),
    [anon_sym_eNUM] = ACTIONS(4209),
    [anon_sym_eNum] = ACTIONS(4209),
    [anon_sym_ENum] = ACTIONS(4209),
    [sym_quoted_identifier] = ACTIONS(4211),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4211),
    [sym_integer] = ACTIONS(4209),
    [sym_continue_as_identifier] = ACTIONS(4211),
    [sym_preproc_open] = ACTIONS(4211),
    [sym_preproc_close] = ACTIONS(4211),
  },
  [STATE(1557)] = {
    [sym_identifier] = ACTIONS(4213),
    [anon_sym_SEMI] = ACTIONS(4215),
    [anon_sym_DASH] = ACTIONS(4215),
    [aux_sym_boolean_token1] = ACTIONS(4213),
    [aux_sym_boolean_token2] = ACTIONS(4213),
    [sym_decimal] = ACTIONS(4213),
    [anon_sym_LPAREN] = ACTIONS(4215),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4213),
    [anon_sym_LBRACK] = ACTIONS(4215),
    [aux_sym_record_type_token1] = ACTIONS(4213),
    [aux_sym_basic_type_token21] = ACTIONS(4213),
    [aux_sym_basic_type_token22] = ACTIONS(4213),
    [aux_sym_basic_type_token48] = ACTIONS(4213),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4213),
    [anon_sym_POUNDif] = ACTIONS(4215),
    [anon_sym_POUNDIF] = ACTIONS(4215),
    [anon_sym_POUNDIf] = ACTIONS(4215),
    [anon_sym_not] = ACTIONS(4213),
    [anon_sym_NOT] = ACTIONS(4213),
    [anon_sym_Not] = ACTIONS(4213),
    [anon_sym_POUNDelif] = ACTIONS(4215),
    [anon_sym_POUNDELIF] = ACTIONS(4215),
    [anon_sym_POUNDElif] = ACTIONS(4215),
    [anon_sym_POUNDelse] = ACTIONS(4215),
    [anon_sym_POUNDELSE] = ACTIONS(4215),
    [anon_sym_POUNDElse] = ACTIONS(4215),
    [anon_sym_POUNDendif] = ACTIONS(4215),
    [anon_sym_POUNDENDIF] = ACTIONS(4215),
    [anon_sym_POUNDEndif] = ACTIONS(4215),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4213),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4213),
    [anon_sym_PLUS] = ACTIONS(4215),
    [sym_datetime_literal] = ACTIONS(4215),
    [sym_date_literal] = ACTIONS(4213),
    [sym_time_literal] = ACTIONS(4213),
    [sym_biginteger_literal] = ACTIONS(4215),
    [anon_sym_if] = ACTIONS(4213),
    [anon_sym_IF] = ACTIONS(4213),
    [anon_sym_If] = ACTIONS(4213),
    [anon_sym_else] = ACTIONS(4213),
    [anon_sym_ELSE] = ACTIONS(4213),
    [anon_sym_Else] = ACTIONS(4213),
    [anon_sym_case] = ACTIONS(4213),
    [anon_sym_CASE] = ACTIONS(4213),
    [anon_sym_Case] = ACTIONS(4213),
    [anon_sym_for] = ACTIONS(4213),
    [anon_sym_FOR] = ACTIONS(4213),
    [anon_sym_For] = ACTIONS(4213),
    [anon_sym_foreach] = ACTIONS(4213),
    [anon_sym_FOREACH] = ACTIONS(4213),
    [anon_sym_Foreach] = ACTIONS(4213),
    [anon_sym_while] = ACTIONS(4213),
    [anon_sym_WHILE] = ACTIONS(4213),
    [anon_sym_While] = ACTIONS(4213),
    [anon_sym_repeat] = ACTIONS(4213),
    [anon_sym_REPEAT] = ACTIONS(4213),
    [anon_sym_Repeat] = ACTIONS(4213),
    [anon_sym_exit] = ACTIONS(4213),
    [anon_sym_EXIT] = ACTIONS(4213),
    [anon_sym_Exit] = ACTIONS(4213),
    [anon_sym_continue] = ACTIONS(4213),
    [anon_sym_CONTINUE] = ACTIONS(4213),
    [anon_sym_Continue] = ACTIONS(4213),
    [anon_sym_break] = ACTIONS(4213),
    [anon_sym_BREAK] = ACTIONS(4213),
    [anon_sym_Break] = ACTIONS(4213),
    [anon_sym_with] = ACTIONS(4213),
    [anon_sym_WITH] = ACTIONS(4213),
    [anon_sym_With] = ACTIONS(4213),
    [sym_asserterror_keyword] = ACTIONS(4215),
    [sym_page_keyword] = ACTIONS(4213),
    [anon_sym_codeunit] = ACTIONS(4213),
    [anon_sym_CODEUNIT] = ACTIONS(4213),
    [anon_sym_Codeunit] = ACTIONS(4213),
    [anon_sym_CodeUnit] = ACTIONS(4213),
    [anon_sym_COdeunit] = ACTIONS(4213),
    [anon_sym_codeUnit] = ACTIONS(4213),
    [sym_report_keyword] = ACTIONS(4213),
    [sym_query_keyword] = ACTIONS(4213),
    [anon_sym_xmlport] = ACTIONS(4213),
    [anon_sym_XMLPORT] = ACTIONS(4213),
    [anon_sym_Xmlport] = ACTIONS(4213),
    [anon_sym_XMLport] = ACTIONS(4213),
    [anon_sym_XMLPort] = ACTIONS(4213),
    [anon_sym_XmlPort] = ACTIONS(4213),
    [anon_sym_enum] = ACTIONS(4213),
    [anon_sym_ENUM] = ACTIONS(4213),
    [anon_sym_Enum] = ACTIONS(4213),
    [anon_sym_eNUM] = ACTIONS(4213),
    [anon_sym_eNum] = ACTIONS(4213),
    [anon_sym_ENum] = ACTIONS(4213),
    [sym_quoted_identifier] = ACTIONS(4215),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4215),
    [sym_integer] = ACTIONS(4213),
    [sym_continue_as_identifier] = ACTIONS(4215),
    [sym_preproc_open] = ACTIONS(4215),
    [sym_preproc_close] = ACTIONS(4215),
  },
  [STATE(1558)] = {
    [sym_identifier] = ACTIONS(4217),
    [anon_sym_SEMI] = ACTIONS(4219),
    [anon_sym_DASH] = ACTIONS(4219),
    [aux_sym_boolean_token1] = ACTIONS(4217),
    [aux_sym_boolean_token2] = ACTIONS(4217),
    [sym_decimal] = ACTIONS(4217),
    [anon_sym_LPAREN] = ACTIONS(4219),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4217),
    [anon_sym_LBRACK] = ACTIONS(4219),
    [aux_sym_record_type_token1] = ACTIONS(4217),
    [aux_sym_basic_type_token21] = ACTIONS(4217),
    [aux_sym_basic_type_token22] = ACTIONS(4217),
    [aux_sym_basic_type_token48] = ACTIONS(4217),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4217),
    [anon_sym_POUNDif] = ACTIONS(4219),
    [anon_sym_POUNDIF] = ACTIONS(4219),
    [anon_sym_POUNDIf] = ACTIONS(4219),
    [anon_sym_not] = ACTIONS(4217),
    [anon_sym_NOT] = ACTIONS(4217),
    [anon_sym_Not] = ACTIONS(4217),
    [anon_sym_POUNDelif] = ACTIONS(4219),
    [anon_sym_POUNDELIF] = ACTIONS(4219),
    [anon_sym_POUNDElif] = ACTIONS(4219),
    [anon_sym_POUNDelse] = ACTIONS(4219),
    [anon_sym_POUNDELSE] = ACTIONS(4219),
    [anon_sym_POUNDElse] = ACTIONS(4219),
    [anon_sym_POUNDendif] = ACTIONS(4219),
    [anon_sym_POUNDENDIF] = ACTIONS(4219),
    [anon_sym_POUNDEndif] = ACTIONS(4219),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4217),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4217),
    [anon_sym_PLUS] = ACTIONS(4219),
    [sym_datetime_literal] = ACTIONS(4219),
    [sym_date_literal] = ACTIONS(4217),
    [sym_time_literal] = ACTIONS(4217),
    [sym_biginteger_literal] = ACTIONS(4219),
    [anon_sym_if] = ACTIONS(4217),
    [anon_sym_IF] = ACTIONS(4217),
    [anon_sym_If] = ACTIONS(4217),
    [anon_sym_else] = ACTIONS(4217),
    [anon_sym_ELSE] = ACTIONS(4217),
    [anon_sym_Else] = ACTIONS(4217),
    [anon_sym_case] = ACTIONS(4217),
    [anon_sym_CASE] = ACTIONS(4217),
    [anon_sym_Case] = ACTIONS(4217),
    [anon_sym_for] = ACTIONS(4217),
    [anon_sym_FOR] = ACTIONS(4217),
    [anon_sym_For] = ACTIONS(4217),
    [anon_sym_foreach] = ACTIONS(4217),
    [anon_sym_FOREACH] = ACTIONS(4217),
    [anon_sym_Foreach] = ACTIONS(4217),
    [anon_sym_while] = ACTIONS(4217),
    [anon_sym_WHILE] = ACTIONS(4217),
    [anon_sym_While] = ACTIONS(4217),
    [anon_sym_repeat] = ACTIONS(4217),
    [anon_sym_REPEAT] = ACTIONS(4217),
    [anon_sym_Repeat] = ACTIONS(4217),
    [anon_sym_exit] = ACTIONS(4217),
    [anon_sym_EXIT] = ACTIONS(4217),
    [anon_sym_Exit] = ACTIONS(4217),
    [anon_sym_continue] = ACTIONS(4217),
    [anon_sym_CONTINUE] = ACTIONS(4217),
    [anon_sym_Continue] = ACTIONS(4217),
    [anon_sym_break] = ACTIONS(4217),
    [anon_sym_BREAK] = ACTIONS(4217),
    [anon_sym_Break] = ACTIONS(4217),
    [anon_sym_with] = ACTIONS(4217),
    [anon_sym_WITH] = ACTIONS(4217),
    [anon_sym_With] = ACTIONS(4217),
    [sym_asserterror_keyword] = ACTIONS(4219),
    [sym_page_keyword] = ACTIONS(4217),
    [anon_sym_codeunit] = ACTIONS(4217),
    [anon_sym_CODEUNIT] = ACTIONS(4217),
    [anon_sym_Codeunit] = ACTIONS(4217),
    [anon_sym_CodeUnit] = ACTIONS(4217),
    [anon_sym_COdeunit] = ACTIONS(4217),
    [anon_sym_codeUnit] = ACTIONS(4217),
    [sym_report_keyword] = ACTIONS(4217),
    [sym_query_keyword] = ACTIONS(4217),
    [anon_sym_xmlport] = ACTIONS(4217),
    [anon_sym_XMLPORT] = ACTIONS(4217),
    [anon_sym_Xmlport] = ACTIONS(4217),
    [anon_sym_XMLport] = ACTIONS(4217),
    [anon_sym_XMLPort] = ACTIONS(4217),
    [anon_sym_XmlPort] = ACTIONS(4217),
    [anon_sym_enum] = ACTIONS(4217),
    [anon_sym_ENUM] = ACTIONS(4217),
    [anon_sym_Enum] = ACTIONS(4217),
    [anon_sym_eNUM] = ACTIONS(4217),
    [anon_sym_eNum] = ACTIONS(4217),
    [anon_sym_ENum] = ACTIONS(4217),
    [sym_quoted_identifier] = ACTIONS(4219),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4219),
    [sym_integer] = ACTIONS(4217),
    [sym_continue_as_identifier] = ACTIONS(4219),
    [sym_preproc_open] = ACTIONS(4219),
    [sym_preproc_close] = ACTIONS(4219),
  },
  [STATE(1559)] = {
    [sym_identifier] = ACTIONS(4221),
    [anon_sym_SEMI] = ACTIONS(4223),
    [anon_sym_DASH] = ACTIONS(4223),
    [aux_sym_boolean_token1] = ACTIONS(4221),
    [aux_sym_boolean_token2] = ACTIONS(4221),
    [sym_decimal] = ACTIONS(4221),
    [anon_sym_LPAREN] = ACTIONS(4223),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4221),
    [anon_sym_LBRACK] = ACTIONS(4223),
    [aux_sym_record_type_token1] = ACTIONS(4221),
    [aux_sym_basic_type_token21] = ACTIONS(4221),
    [aux_sym_basic_type_token22] = ACTIONS(4221),
    [aux_sym_basic_type_token48] = ACTIONS(4221),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4221),
    [anon_sym_POUNDif] = ACTIONS(4223),
    [anon_sym_POUNDIF] = ACTIONS(4223),
    [anon_sym_POUNDIf] = ACTIONS(4223),
    [anon_sym_not] = ACTIONS(4221),
    [anon_sym_NOT] = ACTIONS(4221),
    [anon_sym_Not] = ACTIONS(4221),
    [anon_sym_POUNDelif] = ACTIONS(4223),
    [anon_sym_POUNDELIF] = ACTIONS(4223),
    [anon_sym_POUNDElif] = ACTIONS(4223),
    [anon_sym_POUNDelse] = ACTIONS(4223),
    [anon_sym_POUNDELSE] = ACTIONS(4223),
    [anon_sym_POUNDElse] = ACTIONS(4223),
    [anon_sym_POUNDendif] = ACTIONS(4223),
    [anon_sym_POUNDENDIF] = ACTIONS(4223),
    [anon_sym_POUNDEndif] = ACTIONS(4223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4221),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4221),
    [anon_sym_PLUS] = ACTIONS(4223),
    [sym_datetime_literal] = ACTIONS(4223),
    [sym_date_literal] = ACTIONS(4221),
    [sym_time_literal] = ACTIONS(4221),
    [sym_biginteger_literal] = ACTIONS(4223),
    [anon_sym_if] = ACTIONS(4221),
    [anon_sym_IF] = ACTIONS(4221),
    [anon_sym_If] = ACTIONS(4221),
    [anon_sym_else] = ACTIONS(4221),
    [anon_sym_ELSE] = ACTIONS(4221),
    [anon_sym_Else] = ACTIONS(4221),
    [anon_sym_case] = ACTIONS(4221),
    [anon_sym_CASE] = ACTIONS(4221),
    [anon_sym_Case] = ACTIONS(4221),
    [anon_sym_for] = ACTIONS(4221),
    [anon_sym_FOR] = ACTIONS(4221),
    [anon_sym_For] = ACTIONS(4221),
    [anon_sym_foreach] = ACTIONS(4221),
    [anon_sym_FOREACH] = ACTIONS(4221),
    [anon_sym_Foreach] = ACTIONS(4221),
    [anon_sym_while] = ACTIONS(4221),
    [anon_sym_WHILE] = ACTIONS(4221),
    [anon_sym_While] = ACTIONS(4221),
    [anon_sym_repeat] = ACTIONS(4221),
    [anon_sym_REPEAT] = ACTIONS(4221),
    [anon_sym_Repeat] = ACTIONS(4221),
    [anon_sym_exit] = ACTIONS(4221),
    [anon_sym_EXIT] = ACTIONS(4221),
    [anon_sym_Exit] = ACTIONS(4221),
    [anon_sym_continue] = ACTIONS(4221),
    [anon_sym_CONTINUE] = ACTIONS(4221),
    [anon_sym_Continue] = ACTIONS(4221),
    [anon_sym_break] = ACTIONS(4221),
    [anon_sym_BREAK] = ACTIONS(4221),
    [anon_sym_Break] = ACTIONS(4221),
    [anon_sym_with] = ACTIONS(4221),
    [anon_sym_WITH] = ACTIONS(4221),
    [anon_sym_With] = ACTIONS(4221),
    [sym_asserterror_keyword] = ACTIONS(4223),
    [sym_page_keyword] = ACTIONS(4221),
    [anon_sym_codeunit] = ACTIONS(4221),
    [anon_sym_CODEUNIT] = ACTIONS(4221),
    [anon_sym_Codeunit] = ACTIONS(4221),
    [anon_sym_CodeUnit] = ACTIONS(4221),
    [anon_sym_COdeunit] = ACTIONS(4221),
    [anon_sym_codeUnit] = ACTIONS(4221),
    [sym_report_keyword] = ACTIONS(4221),
    [sym_query_keyword] = ACTIONS(4221),
    [anon_sym_xmlport] = ACTIONS(4221),
    [anon_sym_XMLPORT] = ACTIONS(4221),
    [anon_sym_Xmlport] = ACTIONS(4221),
    [anon_sym_XMLport] = ACTIONS(4221),
    [anon_sym_XMLPort] = ACTIONS(4221),
    [anon_sym_XmlPort] = ACTIONS(4221),
    [anon_sym_enum] = ACTIONS(4221),
    [anon_sym_ENUM] = ACTIONS(4221),
    [anon_sym_Enum] = ACTIONS(4221),
    [anon_sym_eNUM] = ACTIONS(4221),
    [anon_sym_eNum] = ACTIONS(4221),
    [anon_sym_ENum] = ACTIONS(4221),
    [sym_quoted_identifier] = ACTIONS(4223),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4223),
    [sym_integer] = ACTIONS(4221),
    [sym_continue_as_identifier] = ACTIONS(4223),
    [sym_preproc_open] = ACTIONS(4223),
    [sym_preproc_close] = ACTIONS(4223),
  },
  [STATE(1560)] = {
    [sym_identifier] = ACTIONS(4225),
    [anon_sym_SEMI] = ACTIONS(4227),
    [anon_sym_DASH] = ACTIONS(4227),
    [aux_sym_boolean_token1] = ACTIONS(4225),
    [aux_sym_boolean_token2] = ACTIONS(4225),
    [sym_decimal] = ACTIONS(4225),
    [anon_sym_LPAREN] = ACTIONS(4227),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4225),
    [anon_sym_LBRACK] = ACTIONS(4227),
    [aux_sym_record_type_token1] = ACTIONS(4225),
    [aux_sym_basic_type_token21] = ACTIONS(4225),
    [aux_sym_basic_type_token22] = ACTIONS(4225),
    [aux_sym_basic_type_token48] = ACTIONS(4225),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4225),
    [anon_sym_POUNDif] = ACTIONS(4227),
    [anon_sym_POUNDIF] = ACTIONS(4227),
    [anon_sym_POUNDIf] = ACTIONS(4227),
    [anon_sym_not] = ACTIONS(4225),
    [anon_sym_NOT] = ACTIONS(4225),
    [anon_sym_Not] = ACTIONS(4225),
    [anon_sym_POUNDelif] = ACTIONS(4227),
    [anon_sym_POUNDELIF] = ACTIONS(4227),
    [anon_sym_POUNDElif] = ACTIONS(4227),
    [anon_sym_POUNDelse] = ACTIONS(4227),
    [anon_sym_POUNDELSE] = ACTIONS(4227),
    [anon_sym_POUNDElse] = ACTIONS(4227),
    [anon_sym_POUNDendif] = ACTIONS(4227),
    [anon_sym_POUNDENDIF] = ACTIONS(4227),
    [anon_sym_POUNDEndif] = ACTIONS(4227),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4225),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4225),
    [anon_sym_PLUS] = ACTIONS(4227),
    [sym_datetime_literal] = ACTIONS(4227),
    [sym_date_literal] = ACTIONS(4225),
    [sym_time_literal] = ACTIONS(4225),
    [sym_biginteger_literal] = ACTIONS(4227),
    [anon_sym_if] = ACTIONS(4225),
    [anon_sym_IF] = ACTIONS(4225),
    [anon_sym_If] = ACTIONS(4225),
    [anon_sym_else] = ACTIONS(4225),
    [anon_sym_ELSE] = ACTIONS(4225),
    [anon_sym_Else] = ACTIONS(4225),
    [anon_sym_case] = ACTIONS(4225),
    [anon_sym_CASE] = ACTIONS(4225),
    [anon_sym_Case] = ACTIONS(4225),
    [anon_sym_for] = ACTIONS(4225),
    [anon_sym_FOR] = ACTIONS(4225),
    [anon_sym_For] = ACTIONS(4225),
    [anon_sym_foreach] = ACTIONS(4225),
    [anon_sym_FOREACH] = ACTIONS(4225),
    [anon_sym_Foreach] = ACTIONS(4225),
    [anon_sym_while] = ACTIONS(4225),
    [anon_sym_WHILE] = ACTIONS(4225),
    [anon_sym_While] = ACTIONS(4225),
    [anon_sym_repeat] = ACTIONS(4225),
    [anon_sym_REPEAT] = ACTIONS(4225),
    [anon_sym_Repeat] = ACTIONS(4225),
    [anon_sym_exit] = ACTIONS(4225),
    [anon_sym_EXIT] = ACTIONS(4225),
    [anon_sym_Exit] = ACTIONS(4225),
    [anon_sym_continue] = ACTIONS(4225),
    [anon_sym_CONTINUE] = ACTIONS(4225),
    [anon_sym_Continue] = ACTIONS(4225),
    [anon_sym_break] = ACTIONS(4225),
    [anon_sym_BREAK] = ACTIONS(4225),
    [anon_sym_Break] = ACTIONS(4225),
    [anon_sym_with] = ACTIONS(4225),
    [anon_sym_WITH] = ACTIONS(4225),
    [anon_sym_With] = ACTIONS(4225),
    [sym_asserterror_keyword] = ACTIONS(4227),
    [sym_page_keyword] = ACTIONS(4225),
    [anon_sym_codeunit] = ACTIONS(4225),
    [anon_sym_CODEUNIT] = ACTIONS(4225),
    [anon_sym_Codeunit] = ACTIONS(4225),
    [anon_sym_CodeUnit] = ACTIONS(4225),
    [anon_sym_COdeunit] = ACTIONS(4225),
    [anon_sym_codeUnit] = ACTIONS(4225),
    [sym_report_keyword] = ACTIONS(4225),
    [sym_query_keyword] = ACTIONS(4225),
    [anon_sym_xmlport] = ACTIONS(4225),
    [anon_sym_XMLPORT] = ACTIONS(4225),
    [anon_sym_Xmlport] = ACTIONS(4225),
    [anon_sym_XMLport] = ACTIONS(4225),
    [anon_sym_XMLPort] = ACTIONS(4225),
    [anon_sym_XmlPort] = ACTIONS(4225),
    [anon_sym_enum] = ACTIONS(4225),
    [anon_sym_ENUM] = ACTIONS(4225),
    [anon_sym_Enum] = ACTIONS(4225),
    [anon_sym_eNUM] = ACTIONS(4225),
    [anon_sym_eNum] = ACTIONS(4225),
    [anon_sym_ENum] = ACTIONS(4225),
    [sym_quoted_identifier] = ACTIONS(4227),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4227),
    [sym_integer] = ACTIONS(4225),
    [sym_continue_as_identifier] = ACTIONS(4227),
    [sym_preproc_open] = ACTIONS(4227),
    [sym_preproc_close] = ACTIONS(4227),
  },
  [STATE(1561)] = {
    [sym_identifier] = ACTIONS(4229),
    [anon_sym_SEMI] = ACTIONS(4231),
    [anon_sym_DASH] = ACTIONS(4231),
    [aux_sym_boolean_token1] = ACTIONS(4229),
    [aux_sym_boolean_token2] = ACTIONS(4229),
    [sym_decimal] = ACTIONS(4229),
    [anon_sym_LPAREN] = ACTIONS(4231),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4229),
    [anon_sym_LBRACK] = ACTIONS(4231),
    [aux_sym_record_type_token1] = ACTIONS(4229),
    [aux_sym_basic_type_token21] = ACTIONS(4229),
    [aux_sym_basic_type_token22] = ACTIONS(4229),
    [aux_sym_basic_type_token48] = ACTIONS(4229),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4229),
    [anon_sym_POUNDif] = ACTIONS(4231),
    [anon_sym_POUNDIF] = ACTIONS(4231),
    [anon_sym_POUNDIf] = ACTIONS(4231),
    [anon_sym_not] = ACTIONS(4229),
    [anon_sym_NOT] = ACTIONS(4229),
    [anon_sym_Not] = ACTIONS(4229),
    [anon_sym_POUNDelif] = ACTIONS(4231),
    [anon_sym_POUNDELIF] = ACTIONS(4231),
    [anon_sym_POUNDElif] = ACTIONS(4231),
    [anon_sym_POUNDelse] = ACTIONS(4231),
    [anon_sym_POUNDELSE] = ACTIONS(4231),
    [anon_sym_POUNDElse] = ACTIONS(4231),
    [anon_sym_POUNDendif] = ACTIONS(4231),
    [anon_sym_POUNDENDIF] = ACTIONS(4231),
    [anon_sym_POUNDEndif] = ACTIONS(4231),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4229),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4229),
    [anon_sym_PLUS] = ACTIONS(4231),
    [sym_datetime_literal] = ACTIONS(4231),
    [sym_date_literal] = ACTIONS(4229),
    [sym_time_literal] = ACTIONS(4229),
    [sym_biginteger_literal] = ACTIONS(4231),
    [anon_sym_if] = ACTIONS(4229),
    [anon_sym_IF] = ACTIONS(4229),
    [anon_sym_If] = ACTIONS(4229),
    [anon_sym_else] = ACTIONS(4229),
    [anon_sym_ELSE] = ACTIONS(4229),
    [anon_sym_Else] = ACTIONS(4229),
    [anon_sym_case] = ACTIONS(4229),
    [anon_sym_CASE] = ACTIONS(4229),
    [anon_sym_Case] = ACTIONS(4229),
    [anon_sym_for] = ACTIONS(4229),
    [anon_sym_FOR] = ACTIONS(4229),
    [anon_sym_For] = ACTIONS(4229),
    [anon_sym_foreach] = ACTIONS(4229),
    [anon_sym_FOREACH] = ACTIONS(4229),
    [anon_sym_Foreach] = ACTIONS(4229),
    [anon_sym_while] = ACTIONS(4229),
    [anon_sym_WHILE] = ACTIONS(4229),
    [anon_sym_While] = ACTIONS(4229),
    [anon_sym_repeat] = ACTIONS(4229),
    [anon_sym_REPEAT] = ACTIONS(4229),
    [anon_sym_Repeat] = ACTIONS(4229),
    [anon_sym_exit] = ACTIONS(4229),
    [anon_sym_EXIT] = ACTIONS(4229),
    [anon_sym_Exit] = ACTIONS(4229),
    [anon_sym_continue] = ACTIONS(4229),
    [anon_sym_CONTINUE] = ACTIONS(4229),
    [anon_sym_Continue] = ACTIONS(4229),
    [anon_sym_break] = ACTIONS(4229),
    [anon_sym_BREAK] = ACTIONS(4229),
    [anon_sym_Break] = ACTIONS(4229),
    [anon_sym_with] = ACTIONS(4229),
    [anon_sym_WITH] = ACTIONS(4229),
    [anon_sym_With] = ACTIONS(4229),
    [sym_asserterror_keyword] = ACTIONS(4231),
    [sym_page_keyword] = ACTIONS(4229),
    [anon_sym_codeunit] = ACTIONS(4229),
    [anon_sym_CODEUNIT] = ACTIONS(4229),
    [anon_sym_Codeunit] = ACTIONS(4229),
    [anon_sym_CodeUnit] = ACTIONS(4229),
    [anon_sym_COdeunit] = ACTIONS(4229),
    [anon_sym_codeUnit] = ACTIONS(4229),
    [sym_report_keyword] = ACTIONS(4229),
    [sym_query_keyword] = ACTIONS(4229),
    [anon_sym_xmlport] = ACTIONS(4229),
    [anon_sym_XMLPORT] = ACTIONS(4229),
    [anon_sym_Xmlport] = ACTIONS(4229),
    [anon_sym_XMLport] = ACTIONS(4229),
    [anon_sym_XMLPort] = ACTIONS(4229),
    [anon_sym_XmlPort] = ACTIONS(4229),
    [anon_sym_enum] = ACTIONS(4229),
    [anon_sym_ENUM] = ACTIONS(4229),
    [anon_sym_Enum] = ACTIONS(4229),
    [anon_sym_eNUM] = ACTIONS(4229),
    [anon_sym_eNum] = ACTIONS(4229),
    [anon_sym_ENum] = ACTIONS(4229),
    [sym_quoted_identifier] = ACTIONS(4231),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4231),
    [sym_integer] = ACTIONS(4229),
    [sym_continue_as_identifier] = ACTIONS(4231),
    [sym_preproc_open] = ACTIONS(4231),
    [sym_preproc_close] = ACTIONS(4231),
  },
  [STATE(1562)] = {
    [sym_identifier] = ACTIONS(4233),
    [anon_sym_SEMI] = ACTIONS(4235),
    [anon_sym_DASH] = ACTIONS(4235),
    [aux_sym_boolean_token1] = ACTIONS(4233),
    [aux_sym_boolean_token2] = ACTIONS(4233),
    [sym_decimal] = ACTIONS(4233),
    [anon_sym_LPAREN] = ACTIONS(4235),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4233),
    [anon_sym_LBRACK] = ACTIONS(4235),
    [aux_sym_record_type_token1] = ACTIONS(4233),
    [aux_sym_basic_type_token21] = ACTIONS(4233),
    [aux_sym_basic_type_token22] = ACTIONS(4233),
    [aux_sym_basic_type_token48] = ACTIONS(4233),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4233),
    [anon_sym_POUNDif] = ACTIONS(4235),
    [anon_sym_POUNDIF] = ACTIONS(4235),
    [anon_sym_POUNDIf] = ACTIONS(4235),
    [anon_sym_not] = ACTIONS(4233),
    [anon_sym_NOT] = ACTIONS(4233),
    [anon_sym_Not] = ACTIONS(4233),
    [anon_sym_POUNDelif] = ACTIONS(4235),
    [anon_sym_POUNDELIF] = ACTIONS(4235),
    [anon_sym_POUNDElif] = ACTIONS(4235),
    [anon_sym_POUNDelse] = ACTIONS(4235),
    [anon_sym_POUNDELSE] = ACTIONS(4235),
    [anon_sym_POUNDElse] = ACTIONS(4235),
    [anon_sym_POUNDendif] = ACTIONS(4235),
    [anon_sym_POUNDENDIF] = ACTIONS(4235),
    [anon_sym_POUNDEndif] = ACTIONS(4235),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4233),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4233),
    [anon_sym_PLUS] = ACTIONS(4235),
    [sym_datetime_literal] = ACTIONS(4235),
    [sym_date_literal] = ACTIONS(4233),
    [sym_time_literal] = ACTIONS(4233),
    [sym_biginteger_literal] = ACTIONS(4235),
    [anon_sym_if] = ACTIONS(4233),
    [anon_sym_IF] = ACTIONS(4233),
    [anon_sym_If] = ACTIONS(4233),
    [anon_sym_else] = ACTIONS(4233),
    [anon_sym_ELSE] = ACTIONS(4233),
    [anon_sym_Else] = ACTIONS(4233),
    [anon_sym_case] = ACTIONS(4233),
    [anon_sym_CASE] = ACTIONS(4233),
    [anon_sym_Case] = ACTIONS(4233),
    [anon_sym_for] = ACTIONS(4233),
    [anon_sym_FOR] = ACTIONS(4233),
    [anon_sym_For] = ACTIONS(4233),
    [anon_sym_foreach] = ACTIONS(4233),
    [anon_sym_FOREACH] = ACTIONS(4233),
    [anon_sym_Foreach] = ACTIONS(4233),
    [anon_sym_while] = ACTIONS(4233),
    [anon_sym_WHILE] = ACTIONS(4233),
    [anon_sym_While] = ACTIONS(4233),
    [anon_sym_repeat] = ACTIONS(4233),
    [anon_sym_REPEAT] = ACTIONS(4233),
    [anon_sym_Repeat] = ACTIONS(4233),
    [anon_sym_exit] = ACTIONS(4233),
    [anon_sym_EXIT] = ACTIONS(4233),
    [anon_sym_Exit] = ACTIONS(4233),
    [anon_sym_continue] = ACTIONS(4233),
    [anon_sym_CONTINUE] = ACTIONS(4233),
    [anon_sym_Continue] = ACTIONS(4233),
    [anon_sym_break] = ACTIONS(4233),
    [anon_sym_BREAK] = ACTIONS(4233),
    [anon_sym_Break] = ACTIONS(4233),
    [anon_sym_with] = ACTIONS(4233),
    [anon_sym_WITH] = ACTIONS(4233),
    [anon_sym_With] = ACTIONS(4233),
    [sym_asserterror_keyword] = ACTIONS(4235),
    [sym_page_keyword] = ACTIONS(4233),
    [anon_sym_codeunit] = ACTIONS(4233),
    [anon_sym_CODEUNIT] = ACTIONS(4233),
    [anon_sym_Codeunit] = ACTIONS(4233),
    [anon_sym_CodeUnit] = ACTIONS(4233),
    [anon_sym_COdeunit] = ACTIONS(4233),
    [anon_sym_codeUnit] = ACTIONS(4233),
    [sym_report_keyword] = ACTIONS(4233),
    [sym_query_keyword] = ACTIONS(4233),
    [anon_sym_xmlport] = ACTIONS(4233),
    [anon_sym_XMLPORT] = ACTIONS(4233),
    [anon_sym_Xmlport] = ACTIONS(4233),
    [anon_sym_XMLport] = ACTIONS(4233),
    [anon_sym_XMLPort] = ACTIONS(4233),
    [anon_sym_XmlPort] = ACTIONS(4233),
    [anon_sym_enum] = ACTIONS(4233),
    [anon_sym_ENUM] = ACTIONS(4233),
    [anon_sym_Enum] = ACTIONS(4233),
    [anon_sym_eNUM] = ACTIONS(4233),
    [anon_sym_eNum] = ACTIONS(4233),
    [anon_sym_ENum] = ACTIONS(4233),
    [sym_quoted_identifier] = ACTIONS(4235),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4235),
    [sym_integer] = ACTIONS(4233),
    [sym_continue_as_identifier] = ACTIONS(4235),
    [sym_preproc_open] = ACTIONS(4235),
    [sym_preproc_close] = ACTIONS(4235),
  },
  [STATE(1563)] = {
    [sym_identifier] = ACTIONS(4237),
    [anon_sym_SEMI] = ACTIONS(4239),
    [anon_sym_DASH] = ACTIONS(4239),
    [aux_sym_boolean_token1] = ACTIONS(4237),
    [aux_sym_boolean_token2] = ACTIONS(4237),
    [sym_decimal] = ACTIONS(4237),
    [anon_sym_LPAREN] = ACTIONS(4239),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4237),
    [anon_sym_LBRACK] = ACTIONS(4239),
    [aux_sym_record_type_token1] = ACTIONS(4237),
    [aux_sym_basic_type_token21] = ACTIONS(4237),
    [aux_sym_basic_type_token22] = ACTIONS(4237),
    [aux_sym_basic_type_token48] = ACTIONS(4237),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4237),
    [anon_sym_POUNDif] = ACTIONS(4239),
    [anon_sym_POUNDIF] = ACTIONS(4239),
    [anon_sym_POUNDIf] = ACTIONS(4239),
    [anon_sym_not] = ACTIONS(4237),
    [anon_sym_NOT] = ACTIONS(4237),
    [anon_sym_Not] = ACTIONS(4237),
    [anon_sym_POUNDelif] = ACTIONS(4239),
    [anon_sym_POUNDELIF] = ACTIONS(4239),
    [anon_sym_POUNDElif] = ACTIONS(4239),
    [anon_sym_POUNDelse] = ACTIONS(4239),
    [anon_sym_POUNDELSE] = ACTIONS(4239),
    [anon_sym_POUNDElse] = ACTIONS(4239),
    [anon_sym_POUNDendif] = ACTIONS(4239),
    [anon_sym_POUNDENDIF] = ACTIONS(4239),
    [anon_sym_POUNDEndif] = ACTIONS(4239),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4237),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4237),
    [anon_sym_PLUS] = ACTIONS(4239),
    [sym_datetime_literal] = ACTIONS(4239),
    [sym_date_literal] = ACTIONS(4237),
    [sym_time_literal] = ACTIONS(4237),
    [sym_biginteger_literal] = ACTIONS(4239),
    [anon_sym_if] = ACTIONS(4237),
    [anon_sym_IF] = ACTIONS(4237),
    [anon_sym_If] = ACTIONS(4237),
    [anon_sym_else] = ACTIONS(4237),
    [anon_sym_ELSE] = ACTIONS(4237),
    [anon_sym_Else] = ACTIONS(4237),
    [anon_sym_case] = ACTIONS(4237),
    [anon_sym_CASE] = ACTIONS(4237),
    [anon_sym_Case] = ACTIONS(4237),
    [anon_sym_for] = ACTIONS(4237),
    [anon_sym_FOR] = ACTIONS(4237),
    [anon_sym_For] = ACTIONS(4237),
    [anon_sym_foreach] = ACTIONS(4237),
    [anon_sym_FOREACH] = ACTIONS(4237),
    [anon_sym_Foreach] = ACTIONS(4237),
    [anon_sym_while] = ACTIONS(4237),
    [anon_sym_WHILE] = ACTIONS(4237),
    [anon_sym_While] = ACTIONS(4237),
    [anon_sym_repeat] = ACTIONS(4237),
    [anon_sym_REPEAT] = ACTIONS(4237),
    [anon_sym_Repeat] = ACTIONS(4237),
    [anon_sym_exit] = ACTIONS(4237),
    [anon_sym_EXIT] = ACTIONS(4237),
    [anon_sym_Exit] = ACTIONS(4237),
    [anon_sym_continue] = ACTIONS(4237),
    [anon_sym_CONTINUE] = ACTIONS(4237),
    [anon_sym_Continue] = ACTIONS(4237),
    [anon_sym_break] = ACTIONS(4237),
    [anon_sym_BREAK] = ACTIONS(4237),
    [anon_sym_Break] = ACTIONS(4237),
    [anon_sym_with] = ACTIONS(4237),
    [anon_sym_WITH] = ACTIONS(4237),
    [anon_sym_With] = ACTIONS(4237),
    [sym_asserterror_keyword] = ACTIONS(4239),
    [sym_page_keyword] = ACTIONS(4237),
    [anon_sym_codeunit] = ACTIONS(4237),
    [anon_sym_CODEUNIT] = ACTIONS(4237),
    [anon_sym_Codeunit] = ACTIONS(4237),
    [anon_sym_CodeUnit] = ACTIONS(4237),
    [anon_sym_COdeunit] = ACTIONS(4237),
    [anon_sym_codeUnit] = ACTIONS(4237),
    [sym_report_keyword] = ACTIONS(4237),
    [sym_query_keyword] = ACTIONS(4237),
    [anon_sym_xmlport] = ACTIONS(4237),
    [anon_sym_XMLPORT] = ACTIONS(4237),
    [anon_sym_Xmlport] = ACTIONS(4237),
    [anon_sym_XMLport] = ACTIONS(4237),
    [anon_sym_XMLPort] = ACTIONS(4237),
    [anon_sym_XmlPort] = ACTIONS(4237),
    [anon_sym_enum] = ACTIONS(4237),
    [anon_sym_ENUM] = ACTIONS(4237),
    [anon_sym_Enum] = ACTIONS(4237),
    [anon_sym_eNUM] = ACTIONS(4237),
    [anon_sym_eNum] = ACTIONS(4237),
    [anon_sym_ENum] = ACTIONS(4237),
    [sym_quoted_identifier] = ACTIONS(4239),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4239),
    [sym_integer] = ACTIONS(4237),
    [sym_continue_as_identifier] = ACTIONS(4239),
    [sym_preproc_open] = ACTIONS(4239),
    [sym_preproc_close] = ACTIONS(4239),
  },
  [STATE(1564)] = {
    [sym_identifier] = ACTIONS(4241),
    [anon_sym_SEMI] = ACTIONS(4243),
    [anon_sym_DASH] = ACTIONS(4243),
    [aux_sym_boolean_token1] = ACTIONS(4241),
    [aux_sym_boolean_token2] = ACTIONS(4241),
    [sym_decimal] = ACTIONS(4241),
    [anon_sym_LPAREN] = ACTIONS(4243),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4241),
    [anon_sym_LBRACK] = ACTIONS(4243),
    [aux_sym_record_type_token1] = ACTIONS(4241),
    [aux_sym_basic_type_token21] = ACTIONS(4241),
    [aux_sym_basic_type_token22] = ACTIONS(4241),
    [aux_sym_basic_type_token48] = ACTIONS(4241),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4241),
    [anon_sym_POUNDif] = ACTIONS(4243),
    [anon_sym_POUNDIF] = ACTIONS(4243),
    [anon_sym_POUNDIf] = ACTIONS(4243),
    [anon_sym_not] = ACTIONS(4241),
    [anon_sym_NOT] = ACTIONS(4241),
    [anon_sym_Not] = ACTIONS(4241),
    [anon_sym_POUNDelif] = ACTIONS(4243),
    [anon_sym_POUNDELIF] = ACTIONS(4243),
    [anon_sym_POUNDElif] = ACTIONS(4243),
    [anon_sym_POUNDelse] = ACTIONS(4243),
    [anon_sym_POUNDELSE] = ACTIONS(4243),
    [anon_sym_POUNDElse] = ACTIONS(4243),
    [anon_sym_POUNDendif] = ACTIONS(4243),
    [anon_sym_POUNDENDIF] = ACTIONS(4243),
    [anon_sym_POUNDEndif] = ACTIONS(4243),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4241),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4241),
    [anon_sym_PLUS] = ACTIONS(4243),
    [sym_datetime_literal] = ACTIONS(4243),
    [sym_date_literal] = ACTIONS(4241),
    [sym_time_literal] = ACTIONS(4241),
    [sym_biginteger_literal] = ACTIONS(4243),
    [anon_sym_if] = ACTIONS(4241),
    [anon_sym_IF] = ACTIONS(4241),
    [anon_sym_If] = ACTIONS(4241),
    [anon_sym_else] = ACTIONS(4241),
    [anon_sym_ELSE] = ACTIONS(4241),
    [anon_sym_Else] = ACTIONS(4241),
    [anon_sym_case] = ACTIONS(4241),
    [anon_sym_CASE] = ACTIONS(4241),
    [anon_sym_Case] = ACTIONS(4241),
    [anon_sym_for] = ACTIONS(4241),
    [anon_sym_FOR] = ACTIONS(4241),
    [anon_sym_For] = ACTIONS(4241),
    [anon_sym_foreach] = ACTIONS(4241),
    [anon_sym_FOREACH] = ACTIONS(4241),
    [anon_sym_Foreach] = ACTIONS(4241),
    [anon_sym_while] = ACTIONS(4241),
    [anon_sym_WHILE] = ACTIONS(4241),
    [anon_sym_While] = ACTIONS(4241),
    [anon_sym_repeat] = ACTIONS(4241),
    [anon_sym_REPEAT] = ACTIONS(4241),
    [anon_sym_Repeat] = ACTIONS(4241),
    [anon_sym_exit] = ACTIONS(4241),
    [anon_sym_EXIT] = ACTIONS(4241),
    [anon_sym_Exit] = ACTIONS(4241),
    [anon_sym_continue] = ACTIONS(4241),
    [anon_sym_CONTINUE] = ACTIONS(4241),
    [anon_sym_Continue] = ACTIONS(4241),
    [anon_sym_break] = ACTIONS(4241),
    [anon_sym_BREAK] = ACTIONS(4241),
    [anon_sym_Break] = ACTIONS(4241),
    [anon_sym_with] = ACTIONS(4241),
    [anon_sym_WITH] = ACTIONS(4241),
    [anon_sym_With] = ACTIONS(4241),
    [sym_asserterror_keyword] = ACTIONS(4243),
    [sym_page_keyword] = ACTIONS(4241),
    [anon_sym_codeunit] = ACTIONS(4241),
    [anon_sym_CODEUNIT] = ACTIONS(4241),
    [anon_sym_Codeunit] = ACTIONS(4241),
    [anon_sym_CodeUnit] = ACTIONS(4241),
    [anon_sym_COdeunit] = ACTIONS(4241),
    [anon_sym_codeUnit] = ACTIONS(4241),
    [sym_report_keyword] = ACTIONS(4241),
    [sym_query_keyword] = ACTIONS(4241),
    [anon_sym_xmlport] = ACTIONS(4241),
    [anon_sym_XMLPORT] = ACTIONS(4241),
    [anon_sym_Xmlport] = ACTIONS(4241),
    [anon_sym_XMLport] = ACTIONS(4241),
    [anon_sym_XMLPort] = ACTIONS(4241),
    [anon_sym_XmlPort] = ACTIONS(4241),
    [anon_sym_enum] = ACTIONS(4241),
    [anon_sym_ENUM] = ACTIONS(4241),
    [anon_sym_Enum] = ACTIONS(4241),
    [anon_sym_eNUM] = ACTIONS(4241),
    [anon_sym_eNum] = ACTIONS(4241),
    [anon_sym_ENum] = ACTIONS(4241),
    [sym_quoted_identifier] = ACTIONS(4243),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4243),
    [sym_integer] = ACTIONS(4241),
    [sym_continue_as_identifier] = ACTIONS(4243),
    [sym_preproc_open] = ACTIONS(4243),
    [sym_preproc_close] = ACTIONS(4243),
  },
  [STATE(1565)] = {
    [sym_identifier] = ACTIONS(4245),
    [anon_sym_SEMI] = ACTIONS(4247),
    [anon_sym_DASH] = ACTIONS(4247),
    [aux_sym_boolean_token1] = ACTIONS(4245),
    [aux_sym_boolean_token2] = ACTIONS(4245),
    [sym_decimal] = ACTIONS(4245),
    [anon_sym_LPAREN] = ACTIONS(4247),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4245),
    [anon_sym_LBRACK] = ACTIONS(4247),
    [aux_sym_record_type_token1] = ACTIONS(4245),
    [aux_sym_basic_type_token21] = ACTIONS(4245),
    [aux_sym_basic_type_token22] = ACTIONS(4245),
    [aux_sym_basic_type_token48] = ACTIONS(4245),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4245),
    [anon_sym_POUNDif] = ACTIONS(4247),
    [anon_sym_POUNDIF] = ACTIONS(4247),
    [anon_sym_POUNDIf] = ACTIONS(4247),
    [anon_sym_not] = ACTIONS(4245),
    [anon_sym_NOT] = ACTIONS(4245),
    [anon_sym_Not] = ACTIONS(4245),
    [anon_sym_POUNDelif] = ACTIONS(4247),
    [anon_sym_POUNDELIF] = ACTIONS(4247),
    [anon_sym_POUNDElif] = ACTIONS(4247),
    [anon_sym_POUNDelse] = ACTIONS(4247),
    [anon_sym_POUNDELSE] = ACTIONS(4247),
    [anon_sym_POUNDElse] = ACTIONS(4247),
    [anon_sym_POUNDendif] = ACTIONS(4247),
    [anon_sym_POUNDENDIF] = ACTIONS(4247),
    [anon_sym_POUNDEndif] = ACTIONS(4247),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4245),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4245),
    [anon_sym_PLUS] = ACTIONS(4247),
    [sym_datetime_literal] = ACTIONS(4247),
    [sym_date_literal] = ACTIONS(4245),
    [sym_time_literal] = ACTIONS(4245),
    [sym_biginteger_literal] = ACTIONS(4247),
    [anon_sym_if] = ACTIONS(4245),
    [anon_sym_IF] = ACTIONS(4245),
    [anon_sym_If] = ACTIONS(4245),
    [anon_sym_else] = ACTIONS(4245),
    [anon_sym_ELSE] = ACTIONS(4245),
    [anon_sym_Else] = ACTIONS(4245),
    [anon_sym_case] = ACTIONS(4245),
    [anon_sym_CASE] = ACTIONS(4245),
    [anon_sym_Case] = ACTIONS(4245),
    [anon_sym_for] = ACTIONS(4245),
    [anon_sym_FOR] = ACTIONS(4245),
    [anon_sym_For] = ACTIONS(4245),
    [anon_sym_foreach] = ACTIONS(4245),
    [anon_sym_FOREACH] = ACTIONS(4245),
    [anon_sym_Foreach] = ACTIONS(4245),
    [anon_sym_while] = ACTIONS(4245),
    [anon_sym_WHILE] = ACTIONS(4245),
    [anon_sym_While] = ACTIONS(4245),
    [anon_sym_repeat] = ACTIONS(4245),
    [anon_sym_REPEAT] = ACTIONS(4245),
    [anon_sym_Repeat] = ACTIONS(4245),
    [anon_sym_exit] = ACTIONS(4245),
    [anon_sym_EXIT] = ACTIONS(4245),
    [anon_sym_Exit] = ACTIONS(4245),
    [anon_sym_continue] = ACTIONS(4245),
    [anon_sym_CONTINUE] = ACTIONS(4245),
    [anon_sym_Continue] = ACTIONS(4245),
    [anon_sym_break] = ACTIONS(4245),
    [anon_sym_BREAK] = ACTIONS(4245),
    [anon_sym_Break] = ACTIONS(4245),
    [anon_sym_with] = ACTIONS(4245),
    [anon_sym_WITH] = ACTIONS(4245),
    [anon_sym_With] = ACTIONS(4245),
    [sym_asserterror_keyword] = ACTIONS(4247),
    [sym_page_keyword] = ACTIONS(4245),
    [anon_sym_codeunit] = ACTIONS(4245),
    [anon_sym_CODEUNIT] = ACTIONS(4245),
    [anon_sym_Codeunit] = ACTIONS(4245),
    [anon_sym_CodeUnit] = ACTIONS(4245),
    [anon_sym_COdeunit] = ACTIONS(4245),
    [anon_sym_codeUnit] = ACTIONS(4245),
    [sym_report_keyword] = ACTIONS(4245),
    [sym_query_keyword] = ACTIONS(4245),
    [anon_sym_xmlport] = ACTIONS(4245),
    [anon_sym_XMLPORT] = ACTIONS(4245),
    [anon_sym_Xmlport] = ACTIONS(4245),
    [anon_sym_XMLport] = ACTIONS(4245),
    [anon_sym_XMLPort] = ACTIONS(4245),
    [anon_sym_XmlPort] = ACTIONS(4245),
    [anon_sym_enum] = ACTIONS(4245),
    [anon_sym_ENUM] = ACTIONS(4245),
    [anon_sym_Enum] = ACTIONS(4245),
    [anon_sym_eNUM] = ACTIONS(4245),
    [anon_sym_eNum] = ACTIONS(4245),
    [anon_sym_ENum] = ACTIONS(4245),
    [sym_quoted_identifier] = ACTIONS(4247),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4247),
    [sym_integer] = ACTIONS(4245),
    [sym_continue_as_identifier] = ACTIONS(4247),
    [sym_preproc_open] = ACTIONS(4247),
    [sym_preproc_close] = ACTIONS(4247),
  },
  [STATE(1566)] = {
    [sym_identifier] = ACTIONS(4249),
    [anon_sym_SEMI] = ACTIONS(4251),
    [anon_sym_DASH] = ACTIONS(4251),
    [aux_sym_boolean_token1] = ACTIONS(4249),
    [aux_sym_boolean_token2] = ACTIONS(4249),
    [sym_decimal] = ACTIONS(4249),
    [anon_sym_LPAREN] = ACTIONS(4251),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4249),
    [anon_sym_LBRACK] = ACTIONS(4251),
    [aux_sym_record_type_token1] = ACTIONS(4249),
    [aux_sym_basic_type_token21] = ACTIONS(4249),
    [aux_sym_basic_type_token22] = ACTIONS(4249),
    [aux_sym_basic_type_token48] = ACTIONS(4249),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4249),
    [anon_sym_POUNDif] = ACTIONS(4251),
    [anon_sym_POUNDIF] = ACTIONS(4251),
    [anon_sym_POUNDIf] = ACTIONS(4251),
    [anon_sym_not] = ACTIONS(4249),
    [anon_sym_NOT] = ACTIONS(4249),
    [anon_sym_Not] = ACTIONS(4249),
    [anon_sym_POUNDelif] = ACTIONS(4251),
    [anon_sym_POUNDELIF] = ACTIONS(4251),
    [anon_sym_POUNDElif] = ACTIONS(4251),
    [anon_sym_POUNDelse] = ACTIONS(4251),
    [anon_sym_POUNDELSE] = ACTIONS(4251),
    [anon_sym_POUNDElse] = ACTIONS(4251),
    [anon_sym_POUNDendif] = ACTIONS(4251),
    [anon_sym_POUNDENDIF] = ACTIONS(4251),
    [anon_sym_POUNDEndif] = ACTIONS(4251),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4249),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4249),
    [anon_sym_PLUS] = ACTIONS(4251),
    [sym_datetime_literal] = ACTIONS(4251),
    [sym_date_literal] = ACTIONS(4249),
    [sym_time_literal] = ACTIONS(4249),
    [sym_biginteger_literal] = ACTIONS(4251),
    [anon_sym_if] = ACTIONS(4249),
    [anon_sym_IF] = ACTIONS(4249),
    [anon_sym_If] = ACTIONS(4249),
    [anon_sym_else] = ACTIONS(4249),
    [anon_sym_ELSE] = ACTIONS(4249),
    [anon_sym_Else] = ACTIONS(4249),
    [anon_sym_case] = ACTIONS(4249),
    [anon_sym_CASE] = ACTIONS(4249),
    [anon_sym_Case] = ACTIONS(4249),
    [anon_sym_for] = ACTIONS(4249),
    [anon_sym_FOR] = ACTIONS(4249),
    [anon_sym_For] = ACTIONS(4249),
    [anon_sym_foreach] = ACTIONS(4249),
    [anon_sym_FOREACH] = ACTIONS(4249),
    [anon_sym_Foreach] = ACTIONS(4249),
    [anon_sym_while] = ACTIONS(4249),
    [anon_sym_WHILE] = ACTIONS(4249),
    [anon_sym_While] = ACTIONS(4249),
    [anon_sym_repeat] = ACTIONS(4249),
    [anon_sym_REPEAT] = ACTIONS(4249),
    [anon_sym_Repeat] = ACTIONS(4249),
    [anon_sym_exit] = ACTIONS(4249),
    [anon_sym_EXIT] = ACTIONS(4249),
    [anon_sym_Exit] = ACTIONS(4249),
    [anon_sym_continue] = ACTIONS(4249),
    [anon_sym_CONTINUE] = ACTIONS(4249),
    [anon_sym_Continue] = ACTIONS(4249),
    [anon_sym_break] = ACTIONS(4249),
    [anon_sym_BREAK] = ACTIONS(4249),
    [anon_sym_Break] = ACTIONS(4249),
    [anon_sym_with] = ACTIONS(4249),
    [anon_sym_WITH] = ACTIONS(4249),
    [anon_sym_With] = ACTIONS(4249),
    [sym_asserterror_keyword] = ACTIONS(4251),
    [sym_page_keyword] = ACTIONS(4249),
    [anon_sym_codeunit] = ACTIONS(4249),
    [anon_sym_CODEUNIT] = ACTIONS(4249),
    [anon_sym_Codeunit] = ACTIONS(4249),
    [anon_sym_CodeUnit] = ACTIONS(4249),
    [anon_sym_COdeunit] = ACTIONS(4249),
    [anon_sym_codeUnit] = ACTIONS(4249),
    [sym_report_keyword] = ACTIONS(4249),
    [sym_query_keyword] = ACTIONS(4249),
    [anon_sym_xmlport] = ACTIONS(4249),
    [anon_sym_XMLPORT] = ACTIONS(4249),
    [anon_sym_Xmlport] = ACTIONS(4249),
    [anon_sym_XMLport] = ACTIONS(4249),
    [anon_sym_XMLPort] = ACTIONS(4249),
    [anon_sym_XmlPort] = ACTIONS(4249),
    [anon_sym_enum] = ACTIONS(4249),
    [anon_sym_ENUM] = ACTIONS(4249),
    [anon_sym_Enum] = ACTIONS(4249),
    [anon_sym_eNUM] = ACTIONS(4249),
    [anon_sym_eNum] = ACTIONS(4249),
    [anon_sym_ENum] = ACTIONS(4249),
    [sym_quoted_identifier] = ACTIONS(4251),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4251),
    [sym_integer] = ACTIONS(4249),
    [sym_continue_as_identifier] = ACTIONS(4251),
    [sym_preproc_open] = ACTIONS(4251),
    [sym_preproc_close] = ACTIONS(4251),
  },
  [STATE(1567)] = {
    [sym_identifier] = ACTIONS(4253),
    [anon_sym_SEMI] = ACTIONS(4255),
    [anon_sym_DASH] = ACTIONS(4255),
    [aux_sym_boolean_token1] = ACTIONS(4253),
    [aux_sym_boolean_token2] = ACTIONS(4253),
    [sym_decimal] = ACTIONS(4253),
    [anon_sym_LPAREN] = ACTIONS(4255),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4253),
    [anon_sym_LBRACK] = ACTIONS(4255),
    [aux_sym_record_type_token1] = ACTIONS(4253),
    [aux_sym_basic_type_token21] = ACTIONS(4253),
    [aux_sym_basic_type_token22] = ACTIONS(4253),
    [aux_sym_basic_type_token48] = ACTIONS(4253),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4253),
    [anon_sym_POUNDif] = ACTIONS(4255),
    [anon_sym_POUNDIF] = ACTIONS(4255),
    [anon_sym_POUNDIf] = ACTIONS(4255),
    [anon_sym_not] = ACTIONS(4253),
    [anon_sym_NOT] = ACTIONS(4253),
    [anon_sym_Not] = ACTIONS(4253),
    [anon_sym_POUNDelif] = ACTIONS(4255),
    [anon_sym_POUNDELIF] = ACTIONS(4255),
    [anon_sym_POUNDElif] = ACTIONS(4255),
    [anon_sym_POUNDelse] = ACTIONS(4255),
    [anon_sym_POUNDELSE] = ACTIONS(4255),
    [anon_sym_POUNDElse] = ACTIONS(4255),
    [anon_sym_POUNDendif] = ACTIONS(4255),
    [anon_sym_POUNDENDIF] = ACTIONS(4255),
    [anon_sym_POUNDEndif] = ACTIONS(4255),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4253),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4253),
    [anon_sym_PLUS] = ACTIONS(4255),
    [sym_datetime_literal] = ACTIONS(4255),
    [sym_date_literal] = ACTIONS(4253),
    [sym_time_literal] = ACTIONS(4253),
    [sym_biginteger_literal] = ACTIONS(4255),
    [anon_sym_if] = ACTIONS(4253),
    [anon_sym_IF] = ACTIONS(4253),
    [anon_sym_If] = ACTIONS(4253),
    [anon_sym_else] = ACTIONS(4253),
    [anon_sym_ELSE] = ACTIONS(4253),
    [anon_sym_Else] = ACTIONS(4253),
    [anon_sym_case] = ACTIONS(4253),
    [anon_sym_CASE] = ACTIONS(4253),
    [anon_sym_Case] = ACTIONS(4253),
    [anon_sym_for] = ACTIONS(4253),
    [anon_sym_FOR] = ACTIONS(4253),
    [anon_sym_For] = ACTIONS(4253),
    [anon_sym_foreach] = ACTIONS(4253),
    [anon_sym_FOREACH] = ACTIONS(4253),
    [anon_sym_Foreach] = ACTIONS(4253),
    [anon_sym_while] = ACTIONS(4253),
    [anon_sym_WHILE] = ACTIONS(4253),
    [anon_sym_While] = ACTIONS(4253),
    [anon_sym_repeat] = ACTIONS(4253),
    [anon_sym_REPEAT] = ACTIONS(4253),
    [anon_sym_Repeat] = ACTIONS(4253),
    [anon_sym_exit] = ACTIONS(4253),
    [anon_sym_EXIT] = ACTIONS(4253),
    [anon_sym_Exit] = ACTIONS(4253),
    [anon_sym_continue] = ACTIONS(4253),
    [anon_sym_CONTINUE] = ACTIONS(4253),
    [anon_sym_Continue] = ACTIONS(4253),
    [anon_sym_break] = ACTIONS(4253),
    [anon_sym_BREAK] = ACTIONS(4253),
    [anon_sym_Break] = ACTIONS(4253),
    [anon_sym_with] = ACTIONS(4253),
    [anon_sym_WITH] = ACTIONS(4253),
    [anon_sym_With] = ACTIONS(4253),
    [sym_asserterror_keyword] = ACTIONS(4255),
    [sym_page_keyword] = ACTIONS(4253),
    [anon_sym_codeunit] = ACTIONS(4253),
    [anon_sym_CODEUNIT] = ACTIONS(4253),
    [anon_sym_Codeunit] = ACTIONS(4253),
    [anon_sym_CodeUnit] = ACTIONS(4253),
    [anon_sym_COdeunit] = ACTIONS(4253),
    [anon_sym_codeUnit] = ACTIONS(4253),
    [sym_report_keyword] = ACTIONS(4253),
    [sym_query_keyword] = ACTIONS(4253),
    [anon_sym_xmlport] = ACTIONS(4253),
    [anon_sym_XMLPORT] = ACTIONS(4253),
    [anon_sym_Xmlport] = ACTIONS(4253),
    [anon_sym_XMLport] = ACTIONS(4253),
    [anon_sym_XMLPort] = ACTIONS(4253),
    [anon_sym_XmlPort] = ACTIONS(4253),
    [anon_sym_enum] = ACTIONS(4253),
    [anon_sym_ENUM] = ACTIONS(4253),
    [anon_sym_Enum] = ACTIONS(4253),
    [anon_sym_eNUM] = ACTIONS(4253),
    [anon_sym_eNum] = ACTIONS(4253),
    [anon_sym_ENum] = ACTIONS(4253),
    [sym_quoted_identifier] = ACTIONS(4255),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4255),
    [sym_integer] = ACTIONS(4253),
    [sym_continue_as_identifier] = ACTIONS(4255),
    [sym_preproc_open] = ACTIONS(4255),
    [sym_preproc_close] = ACTIONS(4255),
  },
  [STATE(1568)] = {
    [sym_identifier] = ACTIONS(4257),
    [anon_sym_SEMI] = ACTIONS(4259),
    [anon_sym_DASH] = ACTIONS(4259),
    [aux_sym_boolean_token1] = ACTIONS(4257),
    [aux_sym_boolean_token2] = ACTIONS(4257),
    [sym_decimal] = ACTIONS(4257),
    [anon_sym_LPAREN] = ACTIONS(4259),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4257),
    [anon_sym_LBRACK] = ACTIONS(4259),
    [aux_sym_record_type_token1] = ACTIONS(4257),
    [aux_sym_basic_type_token21] = ACTIONS(4257),
    [aux_sym_basic_type_token22] = ACTIONS(4257),
    [aux_sym_basic_type_token48] = ACTIONS(4257),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4257),
    [anon_sym_POUNDif] = ACTIONS(4259),
    [anon_sym_POUNDIF] = ACTIONS(4259),
    [anon_sym_POUNDIf] = ACTIONS(4259),
    [anon_sym_not] = ACTIONS(4257),
    [anon_sym_NOT] = ACTIONS(4257),
    [anon_sym_Not] = ACTIONS(4257),
    [anon_sym_POUNDelif] = ACTIONS(4259),
    [anon_sym_POUNDELIF] = ACTIONS(4259),
    [anon_sym_POUNDElif] = ACTIONS(4259),
    [anon_sym_POUNDelse] = ACTIONS(4259),
    [anon_sym_POUNDELSE] = ACTIONS(4259),
    [anon_sym_POUNDElse] = ACTIONS(4259),
    [anon_sym_POUNDendif] = ACTIONS(4259),
    [anon_sym_POUNDENDIF] = ACTIONS(4259),
    [anon_sym_POUNDEndif] = ACTIONS(4259),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4257),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4257),
    [anon_sym_PLUS] = ACTIONS(4259),
    [sym_datetime_literal] = ACTIONS(4259),
    [sym_date_literal] = ACTIONS(4257),
    [sym_time_literal] = ACTIONS(4257),
    [sym_biginteger_literal] = ACTIONS(4259),
    [anon_sym_if] = ACTIONS(4257),
    [anon_sym_IF] = ACTIONS(4257),
    [anon_sym_If] = ACTIONS(4257),
    [anon_sym_else] = ACTIONS(4257),
    [anon_sym_ELSE] = ACTIONS(4257),
    [anon_sym_Else] = ACTIONS(4257),
    [anon_sym_case] = ACTIONS(4257),
    [anon_sym_CASE] = ACTIONS(4257),
    [anon_sym_Case] = ACTIONS(4257),
    [anon_sym_for] = ACTIONS(4257),
    [anon_sym_FOR] = ACTIONS(4257),
    [anon_sym_For] = ACTIONS(4257),
    [anon_sym_foreach] = ACTIONS(4257),
    [anon_sym_FOREACH] = ACTIONS(4257),
    [anon_sym_Foreach] = ACTIONS(4257),
    [anon_sym_while] = ACTIONS(4257),
    [anon_sym_WHILE] = ACTIONS(4257),
    [anon_sym_While] = ACTIONS(4257),
    [anon_sym_repeat] = ACTIONS(4257),
    [anon_sym_REPEAT] = ACTIONS(4257),
    [anon_sym_Repeat] = ACTIONS(4257),
    [anon_sym_exit] = ACTIONS(4257),
    [anon_sym_EXIT] = ACTIONS(4257),
    [anon_sym_Exit] = ACTIONS(4257),
    [anon_sym_continue] = ACTIONS(4257),
    [anon_sym_CONTINUE] = ACTIONS(4257),
    [anon_sym_Continue] = ACTIONS(4257),
    [anon_sym_break] = ACTIONS(4257),
    [anon_sym_BREAK] = ACTIONS(4257),
    [anon_sym_Break] = ACTIONS(4257),
    [anon_sym_with] = ACTIONS(4257),
    [anon_sym_WITH] = ACTIONS(4257),
    [anon_sym_With] = ACTIONS(4257),
    [sym_asserterror_keyword] = ACTIONS(4259),
    [sym_page_keyword] = ACTIONS(4257),
    [anon_sym_codeunit] = ACTIONS(4257),
    [anon_sym_CODEUNIT] = ACTIONS(4257),
    [anon_sym_Codeunit] = ACTIONS(4257),
    [anon_sym_CodeUnit] = ACTIONS(4257),
    [anon_sym_COdeunit] = ACTIONS(4257),
    [anon_sym_codeUnit] = ACTIONS(4257),
    [sym_report_keyword] = ACTIONS(4257),
    [sym_query_keyword] = ACTIONS(4257),
    [anon_sym_xmlport] = ACTIONS(4257),
    [anon_sym_XMLPORT] = ACTIONS(4257),
    [anon_sym_Xmlport] = ACTIONS(4257),
    [anon_sym_XMLport] = ACTIONS(4257),
    [anon_sym_XMLPort] = ACTIONS(4257),
    [anon_sym_XmlPort] = ACTIONS(4257),
    [anon_sym_enum] = ACTIONS(4257),
    [anon_sym_ENUM] = ACTIONS(4257),
    [anon_sym_Enum] = ACTIONS(4257),
    [anon_sym_eNUM] = ACTIONS(4257),
    [anon_sym_eNum] = ACTIONS(4257),
    [anon_sym_ENum] = ACTIONS(4257),
    [sym_quoted_identifier] = ACTIONS(4259),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4259),
    [sym_integer] = ACTIONS(4257),
    [sym_continue_as_identifier] = ACTIONS(4259),
    [sym_preproc_open] = ACTIONS(4259),
    [sym_preproc_close] = ACTIONS(4259),
  },
  [STATE(1569)] = {
    [sym_identifier] = ACTIONS(4261),
    [anon_sym_SEMI] = ACTIONS(4263),
    [anon_sym_DASH] = ACTIONS(4263),
    [aux_sym_boolean_token1] = ACTIONS(4261),
    [aux_sym_boolean_token2] = ACTIONS(4261),
    [sym_decimal] = ACTIONS(4261),
    [anon_sym_LPAREN] = ACTIONS(4263),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4261),
    [anon_sym_LBRACK] = ACTIONS(4263),
    [aux_sym_record_type_token1] = ACTIONS(4261),
    [aux_sym_basic_type_token21] = ACTIONS(4261),
    [aux_sym_basic_type_token22] = ACTIONS(4261),
    [aux_sym_basic_type_token48] = ACTIONS(4261),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4261),
    [anon_sym_POUNDif] = ACTIONS(4263),
    [anon_sym_POUNDIF] = ACTIONS(4263),
    [anon_sym_POUNDIf] = ACTIONS(4263),
    [anon_sym_not] = ACTIONS(4261),
    [anon_sym_NOT] = ACTIONS(4261),
    [anon_sym_Not] = ACTIONS(4261),
    [anon_sym_POUNDelif] = ACTIONS(4263),
    [anon_sym_POUNDELIF] = ACTIONS(4263),
    [anon_sym_POUNDElif] = ACTIONS(4263),
    [anon_sym_POUNDelse] = ACTIONS(4263),
    [anon_sym_POUNDELSE] = ACTIONS(4263),
    [anon_sym_POUNDElse] = ACTIONS(4263),
    [anon_sym_POUNDendif] = ACTIONS(4263),
    [anon_sym_POUNDENDIF] = ACTIONS(4263),
    [anon_sym_POUNDEndif] = ACTIONS(4263),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4261),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4261),
    [anon_sym_PLUS] = ACTIONS(4263),
    [sym_datetime_literal] = ACTIONS(4263),
    [sym_date_literal] = ACTIONS(4261),
    [sym_time_literal] = ACTIONS(4261),
    [sym_biginteger_literal] = ACTIONS(4263),
    [anon_sym_if] = ACTIONS(4261),
    [anon_sym_IF] = ACTIONS(4261),
    [anon_sym_If] = ACTIONS(4261),
    [anon_sym_else] = ACTIONS(4261),
    [anon_sym_ELSE] = ACTIONS(4261),
    [anon_sym_Else] = ACTIONS(4261),
    [anon_sym_case] = ACTIONS(4261),
    [anon_sym_CASE] = ACTIONS(4261),
    [anon_sym_Case] = ACTIONS(4261),
    [anon_sym_for] = ACTIONS(4261),
    [anon_sym_FOR] = ACTIONS(4261),
    [anon_sym_For] = ACTIONS(4261),
    [anon_sym_foreach] = ACTIONS(4261),
    [anon_sym_FOREACH] = ACTIONS(4261),
    [anon_sym_Foreach] = ACTIONS(4261),
    [anon_sym_while] = ACTIONS(4261),
    [anon_sym_WHILE] = ACTIONS(4261),
    [anon_sym_While] = ACTIONS(4261),
    [anon_sym_repeat] = ACTIONS(4261),
    [anon_sym_REPEAT] = ACTIONS(4261),
    [anon_sym_Repeat] = ACTIONS(4261),
    [anon_sym_exit] = ACTIONS(4261),
    [anon_sym_EXIT] = ACTIONS(4261),
    [anon_sym_Exit] = ACTIONS(4261),
    [anon_sym_continue] = ACTIONS(4261),
    [anon_sym_CONTINUE] = ACTIONS(4261),
    [anon_sym_Continue] = ACTIONS(4261),
    [anon_sym_break] = ACTIONS(4261),
    [anon_sym_BREAK] = ACTIONS(4261),
    [anon_sym_Break] = ACTIONS(4261),
    [anon_sym_with] = ACTIONS(4261),
    [anon_sym_WITH] = ACTIONS(4261),
    [anon_sym_With] = ACTIONS(4261),
    [sym_asserterror_keyword] = ACTIONS(4263),
    [sym_page_keyword] = ACTIONS(4261),
    [anon_sym_codeunit] = ACTIONS(4261),
    [anon_sym_CODEUNIT] = ACTIONS(4261),
    [anon_sym_Codeunit] = ACTIONS(4261),
    [anon_sym_CodeUnit] = ACTIONS(4261),
    [anon_sym_COdeunit] = ACTIONS(4261),
    [anon_sym_codeUnit] = ACTIONS(4261),
    [sym_report_keyword] = ACTIONS(4261),
    [sym_query_keyword] = ACTIONS(4261),
    [anon_sym_xmlport] = ACTIONS(4261),
    [anon_sym_XMLPORT] = ACTIONS(4261),
    [anon_sym_Xmlport] = ACTIONS(4261),
    [anon_sym_XMLport] = ACTIONS(4261),
    [anon_sym_XMLPort] = ACTIONS(4261),
    [anon_sym_XmlPort] = ACTIONS(4261),
    [anon_sym_enum] = ACTIONS(4261),
    [anon_sym_ENUM] = ACTIONS(4261),
    [anon_sym_Enum] = ACTIONS(4261),
    [anon_sym_eNUM] = ACTIONS(4261),
    [anon_sym_eNum] = ACTIONS(4261),
    [anon_sym_ENum] = ACTIONS(4261),
    [sym_quoted_identifier] = ACTIONS(4263),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4263),
    [sym_integer] = ACTIONS(4261),
    [sym_continue_as_identifier] = ACTIONS(4263),
    [sym_preproc_open] = ACTIONS(4263),
    [sym_preproc_close] = ACTIONS(4263),
  },
  [STATE(1570)] = {
    [sym_identifier] = ACTIONS(4265),
    [anon_sym_SEMI] = ACTIONS(4267),
    [anon_sym_DASH] = ACTIONS(4267),
    [aux_sym_boolean_token1] = ACTIONS(4265),
    [aux_sym_boolean_token2] = ACTIONS(4265),
    [sym_decimal] = ACTIONS(4265),
    [anon_sym_LPAREN] = ACTIONS(4267),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4265),
    [anon_sym_LBRACK] = ACTIONS(4267),
    [aux_sym_record_type_token1] = ACTIONS(4265),
    [aux_sym_basic_type_token21] = ACTIONS(4265),
    [aux_sym_basic_type_token22] = ACTIONS(4265),
    [aux_sym_basic_type_token48] = ACTIONS(4265),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4265),
    [anon_sym_POUNDif] = ACTIONS(4267),
    [anon_sym_POUNDIF] = ACTIONS(4267),
    [anon_sym_POUNDIf] = ACTIONS(4267),
    [anon_sym_not] = ACTIONS(4265),
    [anon_sym_NOT] = ACTIONS(4265),
    [anon_sym_Not] = ACTIONS(4265),
    [anon_sym_POUNDelif] = ACTIONS(4267),
    [anon_sym_POUNDELIF] = ACTIONS(4267),
    [anon_sym_POUNDElif] = ACTIONS(4267),
    [anon_sym_POUNDelse] = ACTIONS(4267),
    [anon_sym_POUNDELSE] = ACTIONS(4267),
    [anon_sym_POUNDElse] = ACTIONS(4267),
    [anon_sym_POUNDendif] = ACTIONS(4267),
    [anon_sym_POUNDENDIF] = ACTIONS(4267),
    [anon_sym_POUNDEndif] = ACTIONS(4267),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4265),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4265),
    [anon_sym_PLUS] = ACTIONS(4267),
    [sym_datetime_literal] = ACTIONS(4267),
    [sym_date_literal] = ACTIONS(4265),
    [sym_time_literal] = ACTIONS(4265),
    [sym_biginteger_literal] = ACTIONS(4267),
    [anon_sym_if] = ACTIONS(4265),
    [anon_sym_IF] = ACTIONS(4265),
    [anon_sym_If] = ACTIONS(4265),
    [anon_sym_else] = ACTIONS(4265),
    [anon_sym_ELSE] = ACTIONS(4265),
    [anon_sym_Else] = ACTIONS(4265),
    [anon_sym_case] = ACTIONS(4265),
    [anon_sym_CASE] = ACTIONS(4265),
    [anon_sym_Case] = ACTIONS(4265),
    [anon_sym_for] = ACTIONS(4265),
    [anon_sym_FOR] = ACTIONS(4265),
    [anon_sym_For] = ACTIONS(4265),
    [anon_sym_foreach] = ACTIONS(4265),
    [anon_sym_FOREACH] = ACTIONS(4265),
    [anon_sym_Foreach] = ACTIONS(4265),
    [anon_sym_while] = ACTIONS(4265),
    [anon_sym_WHILE] = ACTIONS(4265),
    [anon_sym_While] = ACTIONS(4265),
    [anon_sym_repeat] = ACTIONS(4265),
    [anon_sym_REPEAT] = ACTIONS(4265),
    [anon_sym_Repeat] = ACTIONS(4265),
    [anon_sym_exit] = ACTIONS(4265),
    [anon_sym_EXIT] = ACTIONS(4265),
    [anon_sym_Exit] = ACTIONS(4265),
    [anon_sym_continue] = ACTIONS(4265),
    [anon_sym_CONTINUE] = ACTIONS(4265),
    [anon_sym_Continue] = ACTIONS(4265),
    [anon_sym_break] = ACTIONS(4265),
    [anon_sym_BREAK] = ACTIONS(4265),
    [anon_sym_Break] = ACTIONS(4265),
    [anon_sym_with] = ACTIONS(4265),
    [anon_sym_WITH] = ACTIONS(4265),
    [anon_sym_With] = ACTIONS(4265),
    [sym_asserterror_keyword] = ACTIONS(4267),
    [sym_page_keyword] = ACTIONS(4265),
    [anon_sym_codeunit] = ACTIONS(4265),
    [anon_sym_CODEUNIT] = ACTIONS(4265),
    [anon_sym_Codeunit] = ACTIONS(4265),
    [anon_sym_CodeUnit] = ACTIONS(4265),
    [anon_sym_COdeunit] = ACTIONS(4265),
    [anon_sym_codeUnit] = ACTIONS(4265),
    [sym_report_keyword] = ACTIONS(4265),
    [sym_query_keyword] = ACTIONS(4265),
    [anon_sym_xmlport] = ACTIONS(4265),
    [anon_sym_XMLPORT] = ACTIONS(4265),
    [anon_sym_Xmlport] = ACTIONS(4265),
    [anon_sym_XMLport] = ACTIONS(4265),
    [anon_sym_XMLPort] = ACTIONS(4265),
    [anon_sym_XmlPort] = ACTIONS(4265),
    [anon_sym_enum] = ACTIONS(4265),
    [anon_sym_ENUM] = ACTIONS(4265),
    [anon_sym_Enum] = ACTIONS(4265),
    [anon_sym_eNUM] = ACTIONS(4265),
    [anon_sym_eNum] = ACTIONS(4265),
    [anon_sym_ENum] = ACTIONS(4265),
    [sym_quoted_identifier] = ACTIONS(4267),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4267),
    [sym_integer] = ACTIONS(4265),
    [sym_continue_as_identifier] = ACTIONS(4267),
    [sym_preproc_open] = ACTIONS(4267),
    [sym_preproc_close] = ACTIONS(4267),
  },
  [STATE(1571)] = {
    [sym_identifier] = ACTIONS(4269),
    [anon_sym_SEMI] = ACTIONS(4271),
    [anon_sym_DASH] = ACTIONS(4271),
    [aux_sym_boolean_token1] = ACTIONS(4269),
    [aux_sym_boolean_token2] = ACTIONS(4269),
    [sym_decimal] = ACTIONS(4269),
    [anon_sym_LPAREN] = ACTIONS(4271),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4269),
    [anon_sym_LBRACK] = ACTIONS(4271),
    [aux_sym_record_type_token1] = ACTIONS(4269),
    [aux_sym_basic_type_token21] = ACTIONS(4269),
    [aux_sym_basic_type_token22] = ACTIONS(4269),
    [aux_sym_basic_type_token48] = ACTIONS(4269),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4269),
    [anon_sym_POUNDif] = ACTIONS(4271),
    [anon_sym_POUNDIF] = ACTIONS(4271),
    [anon_sym_POUNDIf] = ACTIONS(4271),
    [anon_sym_not] = ACTIONS(4269),
    [anon_sym_NOT] = ACTIONS(4269),
    [anon_sym_Not] = ACTIONS(4269),
    [anon_sym_POUNDelif] = ACTIONS(4271),
    [anon_sym_POUNDELIF] = ACTIONS(4271),
    [anon_sym_POUNDElif] = ACTIONS(4271),
    [anon_sym_POUNDelse] = ACTIONS(4271),
    [anon_sym_POUNDELSE] = ACTIONS(4271),
    [anon_sym_POUNDElse] = ACTIONS(4271),
    [anon_sym_POUNDendif] = ACTIONS(4271),
    [anon_sym_POUNDENDIF] = ACTIONS(4271),
    [anon_sym_POUNDEndif] = ACTIONS(4271),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4269),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4269),
    [anon_sym_PLUS] = ACTIONS(4271),
    [sym_datetime_literal] = ACTIONS(4271),
    [sym_date_literal] = ACTIONS(4269),
    [sym_time_literal] = ACTIONS(4269),
    [sym_biginteger_literal] = ACTIONS(4271),
    [anon_sym_if] = ACTIONS(4269),
    [anon_sym_IF] = ACTIONS(4269),
    [anon_sym_If] = ACTIONS(4269),
    [anon_sym_else] = ACTIONS(4269),
    [anon_sym_ELSE] = ACTIONS(4269),
    [anon_sym_Else] = ACTIONS(4269),
    [anon_sym_case] = ACTIONS(4269),
    [anon_sym_CASE] = ACTIONS(4269),
    [anon_sym_Case] = ACTIONS(4269),
    [anon_sym_for] = ACTIONS(4269),
    [anon_sym_FOR] = ACTIONS(4269),
    [anon_sym_For] = ACTIONS(4269),
    [anon_sym_foreach] = ACTIONS(4269),
    [anon_sym_FOREACH] = ACTIONS(4269),
    [anon_sym_Foreach] = ACTIONS(4269),
    [anon_sym_while] = ACTIONS(4269),
    [anon_sym_WHILE] = ACTIONS(4269),
    [anon_sym_While] = ACTIONS(4269),
    [anon_sym_repeat] = ACTIONS(4269),
    [anon_sym_REPEAT] = ACTIONS(4269),
    [anon_sym_Repeat] = ACTIONS(4269),
    [anon_sym_exit] = ACTIONS(4269),
    [anon_sym_EXIT] = ACTIONS(4269),
    [anon_sym_Exit] = ACTIONS(4269),
    [anon_sym_continue] = ACTIONS(4269),
    [anon_sym_CONTINUE] = ACTIONS(4269),
    [anon_sym_Continue] = ACTIONS(4269),
    [anon_sym_break] = ACTIONS(4269),
    [anon_sym_BREAK] = ACTIONS(4269),
    [anon_sym_Break] = ACTIONS(4269),
    [anon_sym_with] = ACTIONS(4269),
    [anon_sym_WITH] = ACTIONS(4269),
    [anon_sym_With] = ACTIONS(4269),
    [sym_asserterror_keyword] = ACTIONS(4271),
    [sym_page_keyword] = ACTIONS(4269),
    [anon_sym_codeunit] = ACTIONS(4269),
    [anon_sym_CODEUNIT] = ACTIONS(4269),
    [anon_sym_Codeunit] = ACTIONS(4269),
    [anon_sym_CodeUnit] = ACTIONS(4269),
    [anon_sym_COdeunit] = ACTIONS(4269),
    [anon_sym_codeUnit] = ACTIONS(4269),
    [sym_report_keyword] = ACTIONS(4269),
    [sym_query_keyword] = ACTIONS(4269),
    [anon_sym_xmlport] = ACTIONS(4269),
    [anon_sym_XMLPORT] = ACTIONS(4269),
    [anon_sym_Xmlport] = ACTIONS(4269),
    [anon_sym_XMLport] = ACTIONS(4269),
    [anon_sym_XMLPort] = ACTIONS(4269),
    [anon_sym_XmlPort] = ACTIONS(4269),
    [anon_sym_enum] = ACTIONS(4269),
    [anon_sym_ENUM] = ACTIONS(4269),
    [anon_sym_Enum] = ACTIONS(4269),
    [anon_sym_eNUM] = ACTIONS(4269),
    [anon_sym_eNum] = ACTIONS(4269),
    [anon_sym_ENum] = ACTIONS(4269),
    [sym_quoted_identifier] = ACTIONS(4271),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4271),
    [sym_integer] = ACTIONS(4269),
    [sym_continue_as_identifier] = ACTIONS(4271),
    [sym_preproc_open] = ACTIONS(4271),
    [sym_preproc_close] = ACTIONS(4271),
  },
  [STATE(1572)] = {
    [sym_identifier] = ACTIONS(4273),
    [anon_sym_SEMI] = ACTIONS(4275),
    [anon_sym_DASH] = ACTIONS(4275),
    [aux_sym_boolean_token1] = ACTIONS(4273),
    [aux_sym_boolean_token2] = ACTIONS(4273),
    [sym_decimal] = ACTIONS(4273),
    [anon_sym_LPAREN] = ACTIONS(4275),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4273),
    [anon_sym_LBRACK] = ACTIONS(4275),
    [aux_sym_record_type_token1] = ACTIONS(4273),
    [aux_sym_basic_type_token21] = ACTIONS(4273),
    [aux_sym_basic_type_token22] = ACTIONS(4273),
    [aux_sym_basic_type_token48] = ACTIONS(4273),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4273),
    [anon_sym_POUNDif] = ACTIONS(4275),
    [anon_sym_POUNDIF] = ACTIONS(4275),
    [anon_sym_POUNDIf] = ACTIONS(4275),
    [anon_sym_not] = ACTIONS(4273),
    [anon_sym_NOT] = ACTIONS(4273),
    [anon_sym_Not] = ACTIONS(4273),
    [anon_sym_POUNDelif] = ACTIONS(4275),
    [anon_sym_POUNDELIF] = ACTIONS(4275),
    [anon_sym_POUNDElif] = ACTIONS(4275),
    [anon_sym_POUNDelse] = ACTIONS(4275),
    [anon_sym_POUNDELSE] = ACTIONS(4275),
    [anon_sym_POUNDElse] = ACTIONS(4275),
    [anon_sym_POUNDendif] = ACTIONS(4275),
    [anon_sym_POUNDENDIF] = ACTIONS(4275),
    [anon_sym_POUNDEndif] = ACTIONS(4275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4273),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4273),
    [anon_sym_PLUS] = ACTIONS(4275),
    [sym_datetime_literal] = ACTIONS(4275),
    [sym_date_literal] = ACTIONS(4273),
    [sym_time_literal] = ACTIONS(4273),
    [sym_biginteger_literal] = ACTIONS(4275),
    [anon_sym_if] = ACTIONS(4273),
    [anon_sym_IF] = ACTIONS(4273),
    [anon_sym_If] = ACTIONS(4273),
    [anon_sym_else] = ACTIONS(4273),
    [anon_sym_ELSE] = ACTIONS(4273),
    [anon_sym_Else] = ACTIONS(4273),
    [anon_sym_case] = ACTIONS(4273),
    [anon_sym_CASE] = ACTIONS(4273),
    [anon_sym_Case] = ACTIONS(4273),
    [anon_sym_for] = ACTIONS(4273),
    [anon_sym_FOR] = ACTIONS(4273),
    [anon_sym_For] = ACTIONS(4273),
    [anon_sym_foreach] = ACTIONS(4273),
    [anon_sym_FOREACH] = ACTIONS(4273),
    [anon_sym_Foreach] = ACTIONS(4273),
    [anon_sym_while] = ACTIONS(4273),
    [anon_sym_WHILE] = ACTIONS(4273),
    [anon_sym_While] = ACTIONS(4273),
    [anon_sym_repeat] = ACTIONS(4273),
    [anon_sym_REPEAT] = ACTIONS(4273),
    [anon_sym_Repeat] = ACTIONS(4273),
    [anon_sym_exit] = ACTIONS(4273),
    [anon_sym_EXIT] = ACTIONS(4273),
    [anon_sym_Exit] = ACTIONS(4273),
    [anon_sym_continue] = ACTIONS(4273),
    [anon_sym_CONTINUE] = ACTIONS(4273),
    [anon_sym_Continue] = ACTIONS(4273),
    [anon_sym_break] = ACTIONS(4273),
    [anon_sym_BREAK] = ACTIONS(4273),
    [anon_sym_Break] = ACTIONS(4273),
    [anon_sym_with] = ACTIONS(4273),
    [anon_sym_WITH] = ACTIONS(4273),
    [anon_sym_With] = ACTIONS(4273),
    [sym_asserterror_keyword] = ACTIONS(4275),
    [sym_page_keyword] = ACTIONS(4273),
    [anon_sym_codeunit] = ACTIONS(4273),
    [anon_sym_CODEUNIT] = ACTIONS(4273),
    [anon_sym_Codeunit] = ACTIONS(4273),
    [anon_sym_CodeUnit] = ACTIONS(4273),
    [anon_sym_COdeunit] = ACTIONS(4273),
    [anon_sym_codeUnit] = ACTIONS(4273),
    [sym_report_keyword] = ACTIONS(4273),
    [sym_query_keyword] = ACTIONS(4273),
    [anon_sym_xmlport] = ACTIONS(4273),
    [anon_sym_XMLPORT] = ACTIONS(4273),
    [anon_sym_Xmlport] = ACTIONS(4273),
    [anon_sym_XMLport] = ACTIONS(4273),
    [anon_sym_XMLPort] = ACTIONS(4273),
    [anon_sym_XmlPort] = ACTIONS(4273),
    [anon_sym_enum] = ACTIONS(4273),
    [anon_sym_ENUM] = ACTIONS(4273),
    [anon_sym_Enum] = ACTIONS(4273),
    [anon_sym_eNUM] = ACTIONS(4273),
    [anon_sym_eNum] = ACTIONS(4273),
    [anon_sym_ENum] = ACTIONS(4273),
    [sym_quoted_identifier] = ACTIONS(4275),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4275),
    [sym_integer] = ACTIONS(4273),
    [sym_continue_as_identifier] = ACTIONS(4275),
    [sym_preproc_open] = ACTIONS(4275),
    [sym_preproc_close] = ACTIONS(4275),
  },
  [STATE(1573)] = {
    [sym_identifier] = ACTIONS(4277),
    [anon_sym_SEMI] = ACTIONS(4279),
    [anon_sym_DASH] = ACTIONS(4279),
    [aux_sym_boolean_token1] = ACTIONS(4277),
    [aux_sym_boolean_token2] = ACTIONS(4277),
    [sym_decimal] = ACTIONS(4277),
    [anon_sym_LPAREN] = ACTIONS(4279),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4277),
    [anon_sym_LBRACK] = ACTIONS(4279),
    [aux_sym_record_type_token1] = ACTIONS(4277),
    [aux_sym_basic_type_token21] = ACTIONS(4277),
    [aux_sym_basic_type_token22] = ACTIONS(4277),
    [aux_sym_basic_type_token48] = ACTIONS(4277),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4277),
    [anon_sym_POUNDif] = ACTIONS(4279),
    [anon_sym_POUNDIF] = ACTIONS(4279),
    [anon_sym_POUNDIf] = ACTIONS(4279),
    [anon_sym_not] = ACTIONS(4277),
    [anon_sym_NOT] = ACTIONS(4277),
    [anon_sym_Not] = ACTIONS(4277),
    [anon_sym_POUNDelif] = ACTIONS(4279),
    [anon_sym_POUNDELIF] = ACTIONS(4279),
    [anon_sym_POUNDElif] = ACTIONS(4279),
    [anon_sym_POUNDelse] = ACTIONS(4279),
    [anon_sym_POUNDELSE] = ACTIONS(4279),
    [anon_sym_POUNDElse] = ACTIONS(4279),
    [anon_sym_POUNDendif] = ACTIONS(4279),
    [anon_sym_POUNDENDIF] = ACTIONS(4279),
    [anon_sym_POUNDEndif] = ACTIONS(4279),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4277),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4277),
    [anon_sym_PLUS] = ACTIONS(4279),
    [sym_datetime_literal] = ACTIONS(4279),
    [sym_date_literal] = ACTIONS(4277),
    [sym_time_literal] = ACTIONS(4277),
    [sym_biginteger_literal] = ACTIONS(4279),
    [anon_sym_if] = ACTIONS(4277),
    [anon_sym_IF] = ACTIONS(4277),
    [anon_sym_If] = ACTIONS(4277),
    [anon_sym_else] = ACTIONS(4277),
    [anon_sym_ELSE] = ACTIONS(4277),
    [anon_sym_Else] = ACTIONS(4277),
    [anon_sym_case] = ACTIONS(4277),
    [anon_sym_CASE] = ACTIONS(4277),
    [anon_sym_Case] = ACTIONS(4277),
    [anon_sym_for] = ACTIONS(4277),
    [anon_sym_FOR] = ACTIONS(4277),
    [anon_sym_For] = ACTIONS(4277),
    [anon_sym_foreach] = ACTIONS(4277),
    [anon_sym_FOREACH] = ACTIONS(4277),
    [anon_sym_Foreach] = ACTIONS(4277),
    [anon_sym_while] = ACTIONS(4277),
    [anon_sym_WHILE] = ACTIONS(4277),
    [anon_sym_While] = ACTIONS(4277),
    [anon_sym_repeat] = ACTIONS(4277),
    [anon_sym_REPEAT] = ACTIONS(4277),
    [anon_sym_Repeat] = ACTIONS(4277),
    [anon_sym_exit] = ACTIONS(4277),
    [anon_sym_EXIT] = ACTIONS(4277),
    [anon_sym_Exit] = ACTIONS(4277),
    [anon_sym_continue] = ACTIONS(4277),
    [anon_sym_CONTINUE] = ACTIONS(4277),
    [anon_sym_Continue] = ACTIONS(4277),
    [anon_sym_break] = ACTIONS(4277),
    [anon_sym_BREAK] = ACTIONS(4277),
    [anon_sym_Break] = ACTIONS(4277),
    [anon_sym_with] = ACTIONS(4277),
    [anon_sym_WITH] = ACTIONS(4277),
    [anon_sym_With] = ACTIONS(4277),
    [sym_asserterror_keyword] = ACTIONS(4279),
    [sym_page_keyword] = ACTIONS(4277),
    [anon_sym_codeunit] = ACTIONS(4277),
    [anon_sym_CODEUNIT] = ACTIONS(4277),
    [anon_sym_Codeunit] = ACTIONS(4277),
    [anon_sym_CodeUnit] = ACTIONS(4277),
    [anon_sym_COdeunit] = ACTIONS(4277),
    [anon_sym_codeUnit] = ACTIONS(4277),
    [sym_report_keyword] = ACTIONS(4277),
    [sym_query_keyword] = ACTIONS(4277),
    [anon_sym_xmlport] = ACTIONS(4277),
    [anon_sym_XMLPORT] = ACTIONS(4277),
    [anon_sym_Xmlport] = ACTIONS(4277),
    [anon_sym_XMLport] = ACTIONS(4277),
    [anon_sym_XMLPort] = ACTIONS(4277),
    [anon_sym_XmlPort] = ACTIONS(4277),
    [anon_sym_enum] = ACTIONS(4277),
    [anon_sym_ENUM] = ACTIONS(4277),
    [anon_sym_Enum] = ACTIONS(4277),
    [anon_sym_eNUM] = ACTIONS(4277),
    [anon_sym_eNum] = ACTIONS(4277),
    [anon_sym_ENum] = ACTIONS(4277),
    [sym_quoted_identifier] = ACTIONS(4279),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4279),
    [sym_integer] = ACTIONS(4277),
    [sym_continue_as_identifier] = ACTIONS(4279),
    [sym_preproc_open] = ACTIONS(4279),
    [sym_preproc_close] = ACTIONS(4279),
  },
  [STATE(1574)] = {
    [sym_identifier] = ACTIONS(4281),
    [anon_sym_SEMI] = ACTIONS(4283),
    [anon_sym_DASH] = ACTIONS(4283),
    [aux_sym_boolean_token1] = ACTIONS(4281),
    [aux_sym_boolean_token2] = ACTIONS(4281),
    [sym_decimal] = ACTIONS(4281),
    [anon_sym_LPAREN] = ACTIONS(4283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4281),
    [anon_sym_LBRACK] = ACTIONS(4283),
    [aux_sym_record_type_token1] = ACTIONS(4281),
    [aux_sym_basic_type_token21] = ACTIONS(4281),
    [aux_sym_basic_type_token22] = ACTIONS(4281),
    [aux_sym_basic_type_token48] = ACTIONS(4281),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4281),
    [anon_sym_POUNDif] = ACTIONS(4283),
    [anon_sym_POUNDIF] = ACTIONS(4283),
    [anon_sym_POUNDIf] = ACTIONS(4283),
    [anon_sym_not] = ACTIONS(4281),
    [anon_sym_NOT] = ACTIONS(4281),
    [anon_sym_Not] = ACTIONS(4281),
    [anon_sym_POUNDelif] = ACTIONS(4283),
    [anon_sym_POUNDELIF] = ACTIONS(4283),
    [anon_sym_POUNDElif] = ACTIONS(4283),
    [anon_sym_POUNDelse] = ACTIONS(4283),
    [anon_sym_POUNDELSE] = ACTIONS(4283),
    [anon_sym_POUNDElse] = ACTIONS(4283),
    [anon_sym_POUNDendif] = ACTIONS(4283),
    [anon_sym_POUNDENDIF] = ACTIONS(4283),
    [anon_sym_POUNDEndif] = ACTIONS(4283),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4281),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4281),
    [anon_sym_PLUS] = ACTIONS(4283),
    [sym_datetime_literal] = ACTIONS(4283),
    [sym_date_literal] = ACTIONS(4281),
    [sym_time_literal] = ACTIONS(4281),
    [sym_biginteger_literal] = ACTIONS(4283),
    [anon_sym_if] = ACTIONS(4281),
    [anon_sym_IF] = ACTIONS(4281),
    [anon_sym_If] = ACTIONS(4281),
    [anon_sym_else] = ACTIONS(4281),
    [anon_sym_ELSE] = ACTIONS(4281),
    [anon_sym_Else] = ACTIONS(4281),
    [anon_sym_case] = ACTIONS(4281),
    [anon_sym_CASE] = ACTIONS(4281),
    [anon_sym_Case] = ACTIONS(4281),
    [anon_sym_for] = ACTIONS(4281),
    [anon_sym_FOR] = ACTIONS(4281),
    [anon_sym_For] = ACTIONS(4281),
    [anon_sym_foreach] = ACTIONS(4281),
    [anon_sym_FOREACH] = ACTIONS(4281),
    [anon_sym_Foreach] = ACTIONS(4281),
    [anon_sym_while] = ACTIONS(4281),
    [anon_sym_WHILE] = ACTIONS(4281),
    [anon_sym_While] = ACTIONS(4281),
    [anon_sym_repeat] = ACTIONS(4281),
    [anon_sym_REPEAT] = ACTIONS(4281),
    [anon_sym_Repeat] = ACTIONS(4281),
    [anon_sym_exit] = ACTIONS(4281),
    [anon_sym_EXIT] = ACTIONS(4281),
    [anon_sym_Exit] = ACTIONS(4281),
    [anon_sym_continue] = ACTIONS(4281),
    [anon_sym_CONTINUE] = ACTIONS(4281),
    [anon_sym_Continue] = ACTIONS(4281),
    [anon_sym_break] = ACTIONS(4281),
    [anon_sym_BREAK] = ACTIONS(4281),
    [anon_sym_Break] = ACTIONS(4281),
    [anon_sym_with] = ACTIONS(4281),
    [anon_sym_WITH] = ACTIONS(4281),
    [anon_sym_With] = ACTIONS(4281),
    [sym_asserterror_keyword] = ACTIONS(4283),
    [sym_page_keyword] = ACTIONS(4281),
    [anon_sym_codeunit] = ACTIONS(4281),
    [anon_sym_CODEUNIT] = ACTIONS(4281),
    [anon_sym_Codeunit] = ACTIONS(4281),
    [anon_sym_CodeUnit] = ACTIONS(4281),
    [anon_sym_COdeunit] = ACTIONS(4281),
    [anon_sym_codeUnit] = ACTIONS(4281),
    [sym_report_keyword] = ACTIONS(4281),
    [sym_query_keyword] = ACTIONS(4281),
    [anon_sym_xmlport] = ACTIONS(4281),
    [anon_sym_XMLPORT] = ACTIONS(4281),
    [anon_sym_Xmlport] = ACTIONS(4281),
    [anon_sym_XMLport] = ACTIONS(4281),
    [anon_sym_XMLPort] = ACTIONS(4281),
    [anon_sym_XmlPort] = ACTIONS(4281),
    [anon_sym_enum] = ACTIONS(4281),
    [anon_sym_ENUM] = ACTIONS(4281),
    [anon_sym_Enum] = ACTIONS(4281),
    [anon_sym_eNUM] = ACTIONS(4281),
    [anon_sym_eNum] = ACTIONS(4281),
    [anon_sym_ENum] = ACTIONS(4281),
    [sym_quoted_identifier] = ACTIONS(4283),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4283),
    [sym_integer] = ACTIONS(4281),
    [sym_continue_as_identifier] = ACTIONS(4283),
    [sym_preproc_open] = ACTIONS(4283),
    [sym_preproc_close] = ACTIONS(4283),
  },
  [STATE(1575)] = {
    [sym_identifier] = ACTIONS(4285),
    [anon_sym_SEMI] = ACTIONS(4287),
    [anon_sym_DASH] = ACTIONS(4287),
    [aux_sym_boolean_token1] = ACTIONS(4285),
    [aux_sym_boolean_token2] = ACTIONS(4285),
    [sym_decimal] = ACTIONS(4285),
    [anon_sym_LPAREN] = ACTIONS(4287),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4285),
    [anon_sym_LBRACK] = ACTIONS(4287),
    [aux_sym_record_type_token1] = ACTIONS(4285),
    [aux_sym_basic_type_token21] = ACTIONS(4285),
    [aux_sym_basic_type_token22] = ACTIONS(4285),
    [aux_sym_basic_type_token48] = ACTIONS(4285),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4285),
    [anon_sym_POUNDif] = ACTIONS(4287),
    [anon_sym_POUNDIF] = ACTIONS(4287),
    [anon_sym_POUNDIf] = ACTIONS(4287),
    [anon_sym_not] = ACTIONS(4285),
    [anon_sym_NOT] = ACTIONS(4285),
    [anon_sym_Not] = ACTIONS(4285),
    [anon_sym_POUNDelif] = ACTIONS(4287),
    [anon_sym_POUNDELIF] = ACTIONS(4287),
    [anon_sym_POUNDElif] = ACTIONS(4287),
    [anon_sym_POUNDelse] = ACTIONS(4287),
    [anon_sym_POUNDELSE] = ACTIONS(4287),
    [anon_sym_POUNDElse] = ACTIONS(4287),
    [anon_sym_POUNDendif] = ACTIONS(4287),
    [anon_sym_POUNDENDIF] = ACTIONS(4287),
    [anon_sym_POUNDEndif] = ACTIONS(4287),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4285),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4285),
    [anon_sym_PLUS] = ACTIONS(4287),
    [sym_datetime_literal] = ACTIONS(4287),
    [sym_date_literal] = ACTIONS(4285),
    [sym_time_literal] = ACTIONS(4285),
    [sym_biginteger_literal] = ACTIONS(4287),
    [anon_sym_if] = ACTIONS(4285),
    [anon_sym_IF] = ACTIONS(4285),
    [anon_sym_If] = ACTIONS(4285),
    [anon_sym_else] = ACTIONS(4285),
    [anon_sym_ELSE] = ACTIONS(4285),
    [anon_sym_Else] = ACTIONS(4285),
    [anon_sym_case] = ACTIONS(4285),
    [anon_sym_CASE] = ACTIONS(4285),
    [anon_sym_Case] = ACTIONS(4285),
    [anon_sym_for] = ACTIONS(4285),
    [anon_sym_FOR] = ACTIONS(4285),
    [anon_sym_For] = ACTIONS(4285),
    [anon_sym_foreach] = ACTIONS(4285),
    [anon_sym_FOREACH] = ACTIONS(4285),
    [anon_sym_Foreach] = ACTIONS(4285),
    [anon_sym_while] = ACTIONS(4285),
    [anon_sym_WHILE] = ACTIONS(4285),
    [anon_sym_While] = ACTIONS(4285),
    [anon_sym_repeat] = ACTIONS(4285),
    [anon_sym_REPEAT] = ACTIONS(4285),
    [anon_sym_Repeat] = ACTIONS(4285),
    [anon_sym_exit] = ACTIONS(4285),
    [anon_sym_EXIT] = ACTIONS(4285),
    [anon_sym_Exit] = ACTIONS(4285),
    [anon_sym_continue] = ACTIONS(4285),
    [anon_sym_CONTINUE] = ACTIONS(4285),
    [anon_sym_Continue] = ACTIONS(4285),
    [anon_sym_break] = ACTIONS(4285),
    [anon_sym_BREAK] = ACTIONS(4285),
    [anon_sym_Break] = ACTIONS(4285),
    [anon_sym_with] = ACTIONS(4285),
    [anon_sym_WITH] = ACTIONS(4285),
    [anon_sym_With] = ACTIONS(4285),
    [sym_asserterror_keyword] = ACTIONS(4287),
    [sym_page_keyword] = ACTIONS(4285),
    [anon_sym_codeunit] = ACTIONS(4285),
    [anon_sym_CODEUNIT] = ACTIONS(4285),
    [anon_sym_Codeunit] = ACTIONS(4285),
    [anon_sym_CodeUnit] = ACTIONS(4285),
    [anon_sym_COdeunit] = ACTIONS(4285),
    [anon_sym_codeUnit] = ACTIONS(4285),
    [sym_report_keyword] = ACTIONS(4285),
    [sym_query_keyword] = ACTIONS(4285),
    [anon_sym_xmlport] = ACTIONS(4285),
    [anon_sym_XMLPORT] = ACTIONS(4285),
    [anon_sym_Xmlport] = ACTIONS(4285),
    [anon_sym_XMLport] = ACTIONS(4285),
    [anon_sym_XMLPort] = ACTIONS(4285),
    [anon_sym_XmlPort] = ACTIONS(4285),
    [anon_sym_enum] = ACTIONS(4285),
    [anon_sym_ENUM] = ACTIONS(4285),
    [anon_sym_Enum] = ACTIONS(4285),
    [anon_sym_eNUM] = ACTIONS(4285),
    [anon_sym_eNum] = ACTIONS(4285),
    [anon_sym_ENum] = ACTIONS(4285),
    [sym_quoted_identifier] = ACTIONS(4287),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4287),
    [sym_integer] = ACTIONS(4285),
    [sym_continue_as_identifier] = ACTIONS(4287),
    [sym_preproc_open] = ACTIONS(4287),
    [sym_preproc_close] = ACTIONS(4287),
  },
  [STATE(1576)] = {
    [sym_identifier] = ACTIONS(4289),
    [anon_sym_SEMI] = ACTIONS(4291),
    [anon_sym_DASH] = ACTIONS(4291),
    [aux_sym_boolean_token1] = ACTIONS(4289),
    [aux_sym_boolean_token2] = ACTIONS(4289),
    [sym_decimal] = ACTIONS(4289),
    [anon_sym_LPAREN] = ACTIONS(4291),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4289),
    [anon_sym_LBRACK] = ACTIONS(4291),
    [aux_sym_record_type_token1] = ACTIONS(4289),
    [aux_sym_basic_type_token21] = ACTIONS(4289),
    [aux_sym_basic_type_token22] = ACTIONS(4289),
    [aux_sym_basic_type_token48] = ACTIONS(4289),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4289),
    [anon_sym_POUNDif] = ACTIONS(4291),
    [anon_sym_POUNDIF] = ACTIONS(4291),
    [anon_sym_POUNDIf] = ACTIONS(4291),
    [anon_sym_not] = ACTIONS(4289),
    [anon_sym_NOT] = ACTIONS(4289),
    [anon_sym_Not] = ACTIONS(4289),
    [anon_sym_POUNDelif] = ACTIONS(4291),
    [anon_sym_POUNDELIF] = ACTIONS(4291),
    [anon_sym_POUNDElif] = ACTIONS(4291),
    [anon_sym_POUNDelse] = ACTIONS(4291),
    [anon_sym_POUNDELSE] = ACTIONS(4291),
    [anon_sym_POUNDElse] = ACTIONS(4291),
    [anon_sym_POUNDendif] = ACTIONS(4291),
    [anon_sym_POUNDENDIF] = ACTIONS(4291),
    [anon_sym_POUNDEndif] = ACTIONS(4291),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4289),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4289),
    [anon_sym_PLUS] = ACTIONS(4291),
    [sym_datetime_literal] = ACTIONS(4291),
    [sym_date_literal] = ACTIONS(4289),
    [sym_time_literal] = ACTIONS(4289),
    [sym_biginteger_literal] = ACTIONS(4291),
    [anon_sym_if] = ACTIONS(4289),
    [anon_sym_IF] = ACTIONS(4289),
    [anon_sym_If] = ACTIONS(4289),
    [anon_sym_else] = ACTIONS(4289),
    [anon_sym_ELSE] = ACTIONS(4289),
    [anon_sym_Else] = ACTIONS(4289),
    [anon_sym_case] = ACTIONS(4289),
    [anon_sym_CASE] = ACTIONS(4289),
    [anon_sym_Case] = ACTIONS(4289),
    [anon_sym_for] = ACTIONS(4289),
    [anon_sym_FOR] = ACTIONS(4289),
    [anon_sym_For] = ACTIONS(4289),
    [anon_sym_foreach] = ACTIONS(4289),
    [anon_sym_FOREACH] = ACTIONS(4289),
    [anon_sym_Foreach] = ACTIONS(4289),
    [anon_sym_while] = ACTIONS(4289),
    [anon_sym_WHILE] = ACTIONS(4289),
    [anon_sym_While] = ACTIONS(4289),
    [anon_sym_repeat] = ACTIONS(4289),
    [anon_sym_REPEAT] = ACTIONS(4289),
    [anon_sym_Repeat] = ACTIONS(4289),
    [anon_sym_exit] = ACTIONS(4289),
    [anon_sym_EXIT] = ACTIONS(4289),
    [anon_sym_Exit] = ACTIONS(4289),
    [anon_sym_continue] = ACTIONS(4289),
    [anon_sym_CONTINUE] = ACTIONS(4289),
    [anon_sym_Continue] = ACTIONS(4289),
    [anon_sym_break] = ACTIONS(4289),
    [anon_sym_BREAK] = ACTIONS(4289),
    [anon_sym_Break] = ACTIONS(4289),
    [anon_sym_with] = ACTIONS(4289),
    [anon_sym_WITH] = ACTIONS(4289),
    [anon_sym_With] = ACTIONS(4289),
    [sym_asserterror_keyword] = ACTIONS(4291),
    [sym_page_keyword] = ACTIONS(4289),
    [anon_sym_codeunit] = ACTIONS(4289),
    [anon_sym_CODEUNIT] = ACTIONS(4289),
    [anon_sym_Codeunit] = ACTIONS(4289),
    [anon_sym_CodeUnit] = ACTIONS(4289),
    [anon_sym_COdeunit] = ACTIONS(4289),
    [anon_sym_codeUnit] = ACTIONS(4289),
    [sym_report_keyword] = ACTIONS(4289),
    [sym_query_keyword] = ACTIONS(4289),
    [anon_sym_xmlport] = ACTIONS(4289),
    [anon_sym_XMLPORT] = ACTIONS(4289),
    [anon_sym_Xmlport] = ACTIONS(4289),
    [anon_sym_XMLport] = ACTIONS(4289),
    [anon_sym_XMLPort] = ACTIONS(4289),
    [anon_sym_XmlPort] = ACTIONS(4289),
    [anon_sym_enum] = ACTIONS(4289),
    [anon_sym_ENUM] = ACTIONS(4289),
    [anon_sym_Enum] = ACTIONS(4289),
    [anon_sym_eNUM] = ACTIONS(4289),
    [anon_sym_eNum] = ACTIONS(4289),
    [anon_sym_ENum] = ACTIONS(4289),
    [sym_quoted_identifier] = ACTIONS(4291),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4291),
    [sym_integer] = ACTIONS(4289),
    [sym_continue_as_identifier] = ACTIONS(4291),
    [sym_preproc_open] = ACTIONS(4291),
    [sym_preproc_close] = ACTIONS(4291),
  },
  [STATE(1577)] = {
    [sym_identifier] = ACTIONS(4293),
    [anon_sym_SEMI] = ACTIONS(4295),
    [anon_sym_DASH] = ACTIONS(4295),
    [aux_sym_boolean_token1] = ACTIONS(4293),
    [aux_sym_boolean_token2] = ACTIONS(4293),
    [sym_decimal] = ACTIONS(4293),
    [anon_sym_LPAREN] = ACTIONS(4295),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4293),
    [anon_sym_LBRACK] = ACTIONS(4295),
    [aux_sym_record_type_token1] = ACTIONS(4293),
    [aux_sym_basic_type_token21] = ACTIONS(4293),
    [aux_sym_basic_type_token22] = ACTIONS(4293),
    [aux_sym_basic_type_token48] = ACTIONS(4293),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4293),
    [anon_sym_POUNDif] = ACTIONS(4295),
    [anon_sym_POUNDIF] = ACTIONS(4295),
    [anon_sym_POUNDIf] = ACTIONS(4295),
    [anon_sym_not] = ACTIONS(4293),
    [anon_sym_NOT] = ACTIONS(4293),
    [anon_sym_Not] = ACTIONS(4293),
    [anon_sym_POUNDelif] = ACTIONS(4295),
    [anon_sym_POUNDELIF] = ACTIONS(4295),
    [anon_sym_POUNDElif] = ACTIONS(4295),
    [anon_sym_POUNDelse] = ACTIONS(4295),
    [anon_sym_POUNDELSE] = ACTIONS(4295),
    [anon_sym_POUNDElse] = ACTIONS(4295),
    [anon_sym_POUNDendif] = ACTIONS(4295),
    [anon_sym_POUNDENDIF] = ACTIONS(4295),
    [anon_sym_POUNDEndif] = ACTIONS(4295),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4293),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4293),
    [anon_sym_PLUS] = ACTIONS(4295),
    [sym_datetime_literal] = ACTIONS(4295),
    [sym_date_literal] = ACTIONS(4293),
    [sym_time_literal] = ACTIONS(4293),
    [sym_biginteger_literal] = ACTIONS(4295),
    [anon_sym_if] = ACTIONS(4293),
    [anon_sym_IF] = ACTIONS(4293),
    [anon_sym_If] = ACTIONS(4293),
    [anon_sym_else] = ACTIONS(4293),
    [anon_sym_ELSE] = ACTIONS(4293),
    [anon_sym_Else] = ACTIONS(4293),
    [anon_sym_case] = ACTIONS(4293),
    [anon_sym_CASE] = ACTIONS(4293),
    [anon_sym_Case] = ACTIONS(4293),
    [anon_sym_for] = ACTIONS(4293),
    [anon_sym_FOR] = ACTIONS(4293),
    [anon_sym_For] = ACTIONS(4293),
    [anon_sym_foreach] = ACTIONS(4293),
    [anon_sym_FOREACH] = ACTIONS(4293),
    [anon_sym_Foreach] = ACTIONS(4293),
    [anon_sym_while] = ACTIONS(4293),
    [anon_sym_WHILE] = ACTIONS(4293),
    [anon_sym_While] = ACTIONS(4293),
    [anon_sym_repeat] = ACTIONS(4293),
    [anon_sym_REPEAT] = ACTIONS(4293),
    [anon_sym_Repeat] = ACTIONS(4293),
    [anon_sym_exit] = ACTIONS(4293),
    [anon_sym_EXIT] = ACTIONS(4293),
    [anon_sym_Exit] = ACTIONS(4293),
    [anon_sym_continue] = ACTIONS(4293),
    [anon_sym_CONTINUE] = ACTIONS(4293),
    [anon_sym_Continue] = ACTIONS(4293),
    [anon_sym_break] = ACTIONS(4293),
    [anon_sym_BREAK] = ACTIONS(4293),
    [anon_sym_Break] = ACTIONS(4293),
    [anon_sym_with] = ACTIONS(4293),
    [anon_sym_WITH] = ACTIONS(4293),
    [anon_sym_With] = ACTIONS(4293),
    [sym_asserterror_keyword] = ACTIONS(4295),
    [sym_page_keyword] = ACTIONS(4293),
    [anon_sym_codeunit] = ACTIONS(4293),
    [anon_sym_CODEUNIT] = ACTIONS(4293),
    [anon_sym_Codeunit] = ACTIONS(4293),
    [anon_sym_CodeUnit] = ACTIONS(4293),
    [anon_sym_COdeunit] = ACTIONS(4293),
    [anon_sym_codeUnit] = ACTIONS(4293),
    [sym_report_keyword] = ACTIONS(4293),
    [sym_query_keyword] = ACTIONS(4293),
    [anon_sym_xmlport] = ACTIONS(4293),
    [anon_sym_XMLPORT] = ACTIONS(4293),
    [anon_sym_Xmlport] = ACTIONS(4293),
    [anon_sym_XMLport] = ACTIONS(4293),
    [anon_sym_XMLPort] = ACTIONS(4293),
    [anon_sym_XmlPort] = ACTIONS(4293),
    [anon_sym_enum] = ACTIONS(4293),
    [anon_sym_ENUM] = ACTIONS(4293),
    [anon_sym_Enum] = ACTIONS(4293),
    [anon_sym_eNUM] = ACTIONS(4293),
    [anon_sym_eNum] = ACTIONS(4293),
    [anon_sym_ENum] = ACTIONS(4293),
    [sym_quoted_identifier] = ACTIONS(4295),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4295),
    [sym_integer] = ACTIONS(4293),
    [sym_continue_as_identifier] = ACTIONS(4295),
    [sym_preproc_open] = ACTIONS(4295),
    [sym_preproc_close] = ACTIONS(4295),
  },
  [STATE(1578)] = {
    [sym_identifier] = ACTIONS(4297),
    [anon_sym_SEMI] = ACTIONS(4299),
    [anon_sym_DASH] = ACTIONS(4299),
    [aux_sym_boolean_token1] = ACTIONS(4297),
    [aux_sym_boolean_token2] = ACTIONS(4297),
    [sym_decimal] = ACTIONS(4297),
    [anon_sym_LPAREN] = ACTIONS(4299),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4297),
    [anon_sym_LBRACK] = ACTIONS(4299),
    [aux_sym_record_type_token1] = ACTIONS(4297),
    [aux_sym_basic_type_token21] = ACTIONS(4297),
    [aux_sym_basic_type_token22] = ACTIONS(4297),
    [aux_sym_basic_type_token48] = ACTIONS(4297),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4297),
    [anon_sym_POUNDif] = ACTIONS(4299),
    [anon_sym_POUNDIF] = ACTIONS(4299),
    [anon_sym_POUNDIf] = ACTIONS(4299),
    [anon_sym_not] = ACTIONS(4297),
    [anon_sym_NOT] = ACTIONS(4297),
    [anon_sym_Not] = ACTIONS(4297),
    [anon_sym_POUNDelif] = ACTIONS(4299),
    [anon_sym_POUNDELIF] = ACTIONS(4299),
    [anon_sym_POUNDElif] = ACTIONS(4299),
    [anon_sym_POUNDelse] = ACTIONS(4299),
    [anon_sym_POUNDELSE] = ACTIONS(4299),
    [anon_sym_POUNDElse] = ACTIONS(4299),
    [anon_sym_POUNDendif] = ACTIONS(4299),
    [anon_sym_POUNDENDIF] = ACTIONS(4299),
    [anon_sym_POUNDEndif] = ACTIONS(4299),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4297),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4297),
    [anon_sym_PLUS] = ACTIONS(4299),
    [sym_datetime_literal] = ACTIONS(4299),
    [sym_date_literal] = ACTIONS(4297),
    [sym_time_literal] = ACTIONS(4297),
    [sym_biginteger_literal] = ACTIONS(4299),
    [anon_sym_if] = ACTIONS(4297),
    [anon_sym_IF] = ACTIONS(4297),
    [anon_sym_If] = ACTIONS(4297),
    [anon_sym_else] = ACTIONS(4297),
    [anon_sym_ELSE] = ACTIONS(4297),
    [anon_sym_Else] = ACTIONS(4297),
    [anon_sym_case] = ACTIONS(4297),
    [anon_sym_CASE] = ACTIONS(4297),
    [anon_sym_Case] = ACTIONS(4297),
    [anon_sym_for] = ACTIONS(4297),
    [anon_sym_FOR] = ACTIONS(4297),
    [anon_sym_For] = ACTIONS(4297),
    [anon_sym_foreach] = ACTIONS(4297),
    [anon_sym_FOREACH] = ACTIONS(4297),
    [anon_sym_Foreach] = ACTIONS(4297),
    [anon_sym_while] = ACTIONS(4297),
    [anon_sym_WHILE] = ACTIONS(4297),
    [anon_sym_While] = ACTIONS(4297),
    [anon_sym_repeat] = ACTIONS(4297),
    [anon_sym_REPEAT] = ACTIONS(4297),
    [anon_sym_Repeat] = ACTIONS(4297),
    [anon_sym_exit] = ACTIONS(4297),
    [anon_sym_EXIT] = ACTIONS(4297),
    [anon_sym_Exit] = ACTIONS(4297),
    [anon_sym_continue] = ACTIONS(4297),
    [anon_sym_CONTINUE] = ACTIONS(4297),
    [anon_sym_Continue] = ACTIONS(4297),
    [anon_sym_break] = ACTIONS(4297),
    [anon_sym_BREAK] = ACTIONS(4297),
    [anon_sym_Break] = ACTIONS(4297),
    [anon_sym_with] = ACTIONS(4297),
    [anon_sym_WITH] = ACTIONS(4297),
    [anon_sym_With] = ACTIONS(4297),
    [sym_asserterror_keyword] = ACTIONS(4299),
    [sym_page_keyword] = ACTIONS(4297),
    [anon_sym_codeunit] = ACTIONS(4297),
    [anon_sym_CODEUNIT] = ACTIONS(4297),
    [anon_sym_Codeunit] = ACTIONS(4297),
    [anon_sym_CodeUnit] = ACTIONS(4297),
    [anon_sym_COdeunit] = ACTIONS(4297),
    [anon_sym_codeUnit] = ACTIONS(4297),
    [sym_report_keyword] = ACTIONS(4297),
    [sym_query_keyword] = ACTIONS(4297),
    [anon_sym_xmlport] = ACTIONS(4297),
    [anon_sym_XMLPORT] = ACTIONS(4297),
    [anon_sym_Xmlport] = ACTIONS(4297),
    [anon_sym_XMLport] = ACTIONS(4297),
    [anon_sym_XMLPort] = ACTIONS(4297),
    [anon_sym_XmlPort] = ACTIONS(4297),
    [anon_sym_enum] = ACTIONS(4297),
    [anon_sym_ENUM] = ACTIONS(4297),
    [anon_sym_Enum] = ACTIONS(4297),
    [anon_sym_eNUM] = ACTIONS(4297),
    [anon_sym_eNum] = ACTIONS(4297),
    [anon_sym_ENum] = ACTIONS(4297),
    [sym_quoted_identifier] = ACTIONS(4299),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4299),
    [sym_integer] = ACTIONS(4297),
    [sym_continue_as_identifier] = ACTIONS(4299),
    [sym_preproc_open] = ACTIONS(4299),
    [sym_preproc_close] = ACTIONS(4299),
  },
  [STATE(1579)] = {
    [sym_identifier] = ACTIONS(4301),
    [anon_sym_SEMI] = ACTIONS(4303),
    [anon_sym_DASH] = ACTIONS(4303),
    [aux_sym_boolean_token1] = ACTIONS(4301),
    [aux_sym_boolean_token2] = ACTIONS(4301),
    [sym_decimal] = ACTIONS(4301),
    [anon_sym_LPAREN] = ACTIONS(4303),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4301),
    [anon_sym_LBRACK] = ACTIONS(4303),
    [aux_sym_record_type_token1] = ACTIONS(4301),
    [aux_sym_basic_type_token21] = ACTIONS(4301),
    [aux_sym_basic_type_token22] = ACTIONS(4301),
    [aux_sym_basic_type_token48] = ACTIONS(4301),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4301),
    [anon_sym_POUNDif] = ACTIONS(4303),
    [anon_sym_POUNDIF] = ACTIONS(4303),
    [anon_sym_POUNDIf] = ACTIONS(4303),
    [anon_sym_not] = ACTIONS(4301),
    [anon_sym_NOT] = ACTIONS(4301),
    [anon_sym_Not] = ACTIONS(4301),
    [anon_sym_POUNDelif] = ACTIONS(4303),
    [anon_sym_POUNDELIF] = ACTIONS(4303),
    [anon_sym_POUNDElif] = ACTIONS(4303),
    [anon_sym_POUNDelse] = ACTIONS(4303),
    [anon_sym_POUNDELSE] = ACTIONS(4303),
    [anon_sym_POUNDElse] = ACTIONS(4303),
    [anon_sym_POUNDendif] = ACTIONS(4303),
    [anon_sym_POUNDENDIF] = ACTIONS(4303),
    [anon_sym_POUNDEndif] = ACTIONS(4303),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4301),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4301),
    [anon_sym_PLUS] = ACTIONS(4303),
    [sym_datetime_literal] = ACTIONS(4303),
    [sym_date_literal] = ACTIONS(4301),
    [sym_time_literal] = ACTIONS(4301),
    [sym_biginteger_literal] = ACTIONS(4303),
    [anon_sym_if] = ACTIONS(4301),
    [anon_sym_IF] = ACTIONS(4301),
    [anon_sym_If] = ACTIONS(4301),
    [anon_sym_else] = ACTIONS(4301),
    [anon_sym_ELSE] = ACTIONS(4301),
    [anon_sym_Else] = ACTIONS(4301),
    [anon_sym_case] = ACTIONS(4301),
    [anon_sym_CASE] = ACTIONS(4301),
    [anon_sym_Case] = ACTIONS(4301),
    [anon_sym_for] = ACTIONS(4301),
    [anon_sym_FOR] = ACTIONS(4301),
    [anon_sym_For] = ACTIONS(4301),
    [anon_sym_foreach] = ACTIONS(4301),
    [anon_sym_FOREACH] = ACTIONS(4301),
    [anon_sym_Foreach] = ACTIONS(4301),
    [anon_sym_while] = ACTIONS(4301),
    [anon_sym_WHILE] = ACTIONS(4301),
    [anon_sym_While] = ACTIONS(4301),
    [anon_sym_repeat] = ACTIONS(4301),
    [anon_sym_REPEAT] = ACTIONS(4301),
    [anon_sym_Repeat] = ACTIONS(4301),
    [anon_sym_exit] = ACTIONS(4301),
    [anon_sym_EXIT] = ACTIONS(4301),
    [anon_sym_Exit] = ACTIONS(4301),
    [anon_sym_continue] = ACTIONS(4301),
    [anon_sym_CONTINUE] = ACTIONS(4301),
    [anon_sym_Continue] = ACTIONS(4301),
    [anon_sym_break] = ACTIONS(4301),
    [anon_sym_BREAK] = ACTIONS(4301),
    [anon_sym_Break] = ACTIONS(4301),
    [anon_sym_with] = ACTIONS(4301),
    [anon_sym_WITH] = ACTIONS(4301),
    [anon_sym_With] = ACTIONS(4301),
    [sym_asserterror_keyword] = ACTIONS(4303),
    [sym_page_keyword] = ACTIONS(4301),
    [anon_sym_codeunit] = ACTIONS(4301),
    [anon_sym_CODEUNIT] = ACTIONS(4301),
    [anon_sym_Codeunit] = ACTIONS(4301),
    [anon_sym_CodeUnit] = ACTIONS(4301),
    [anon_sym_COdeunit] = ACTIONS(4301),
    [anon_sym_codeUnit] = ACTIONS(4301),
    [sym_report_keyword] = ACTIONS(4301),
    [sym_query_keyword] = ACTIONS(4301),
    [anon_sym_xmlport] = ACTIONS(4301),
    [anon_sym_XMLPORT] = ACTIONS(4301),
    [anon_sym_Xmlport] = ACTIONS(4301),
    [anon_sym_XMLport] = ACTIONS(4301),
    [anon_sym_XMLPort] = ACTIONS(4301),
    [anon_sym_XmlPort] = ACTIONS(4301),
    [anon_sym_enum] = ACTIONS(4301),
    [anon_sym_ENUM] = ACTIONS(4301),
    [anon_sym_Enum] = ACTIONS(4301),
    [anon_sym_eNUM] = ACTIONS(4301),
    [anon_sym_eNum] = ACTIONS(4301),
    [anon_sym_ENum] = ACTIONS(4301),
    [sym_quoted_identifier] = ACTIONS(4303),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4303),
    [sym_integer] = ACTIONS(4301),
    [sym_continue_as_identifier] = ACTIONS(4303),
    [sym_preproc_open] = ACTIONS(4303),
    [sym_preproc_close] = ACTIONS(4303),
  },
  [STATE(1580)] = {
    [sym_identifier] = ACTIONS(4305),
    [anon_sym_SEMI] = ACTIONS(4307),
    [anon_sym_DASH] = ACTIONS(4307),
    [aux_sym_boolean_token1] = ACTIONS(4305),
    [aux_sym_boolean_token2] = ACTIONS(4305),
    [sym_decimal] = ACTIONS(4305),
    [anon_sym_LPAREN] = ACTIONS(4307),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4305),
    [anon_sym_LBRACK] = ACTIONS(4307),
    [aux_sym_record_type_token1] = ACTIONS(4305),
    [aux_sym_basic_type_token21] = ACTIONS(4305),
    [aux_sym_basic_type_token22] = ACTIONS(4305),
    [aux_sym_basic_type_token48] = ACTIONS(4305),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4305),
    [anon_sym_POUNDif] = ACTIONS(4307),
    [anon_sym_POUNDIF] = ACTIONS(4307),
    [anon_sym_POUNDIf] = ACTIONS(4307),
    [anon_sym_not] = ACTIONS(4305),
    [anon_sym_NOT] = ACTIONS(4305),
    [anon_sym_Not] = ACTIONS(4305),
    [anon_sym_POUNDelif] = ACTIONS(4307),
    [anon_sym_POUNDELIF] = ACTIONS(4307),
    [anon_sym_POUNDElif] = ACTIONS(4307),
    [anon_sym_POUNDelse] = ACTIONS(4307),
    [anon_sym_POUNDELSE] = ACTIONS(4307),
    [anon_sym_POUNDElse] = ACTIONS(4307),
    [anon_sym_POUNDendif] = ACTIONS(4307),
    [anon_sym_POUNDENDIF] = ACTIONS(4307),
    [anon_sym_POUNDEndif] = ACTIONS(4307),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4305),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4305),
    [anon_sym_PLUS] = ACTIONS(4307),
    [sym_datetime_literal] = ACTIONS(4307),
    [sym_date_literal] = ACTIONS(4305),
    [sym_time_literal] = ACTIONS(4305),
    [sym_biginteger_literal] = ACTIONS(4307),
    [anon_sym_if] = ACTIONS(4305),
    [anon_sym_IF] = ACTIONS(4305),
    [anon_sym_If] = ACTIONS(4305),
    [anon_sym_else] = ACTIONS(4305),
    [anon_sym_ELSE] = ACTIONS(4305),
    [anon_sym_Else] = ACTIONS(4305),
    [anon_sym_case] = ACTIONS(4305),
    [anon_sym_CASE] = ACTIONS(4305),
    [anon_sym_Case] = ACTIONS(4305),
    [anon_sym_for] = ACTIONS(4305),
    [anon_sym_FOR] = ACTIONS(4305),
    [anon_sym_For] = ACTIONS(4305),
    [anon_sym_foreach] = ACTIONS(4305),
    [anon_sym_FOREACH] = ACTIONS(4305),
    [anon_sym_Foreach] = ACTIONS(4305),
    [anon_sym_while] = ACTIONS(4305),
    [anon_sym_WHILE] = ACTIONS(4305),
    [anon_sym_While] = ACTIONS(4305),
    [anon_sym_repeat] = ACTIONS(4305),
    [anon_sym_REPEAT] = ACTIONS(4305),
    [anon_sym_Repeat] = ACTIONS(4305),
    [anon_sym_exit] = ACTIONS(4305),
    [anon_sym_EXIT] = ACTIONS(4305),
    [anon_sym_Exit] = ACTIONS(4305),
    [anon_sym_continue] = ACTIONS(4305),
    [anon_sym_CONTINUE] = ACTIONS(4305),
    [anon_sym_Continue] = ACTIONS(4305),
    [anon_sym_break] = ACTIONS(4305),
    [anon_sym_BREAK] = ACTIONS(4305),
    [anon_sym_Break] = ACTIONS(4305),
    [anon_sym_with] = ACTIONS(4305),
    [anon_sym_WITH] = ACTIONS(4305),
    [anon_sym_With] = ACTIONS(4305),
    [sym_asserterror_keyword] = ACTIONS(4307),
    [sym_page_keyword] = ACTIONS(4305),
    [anon_sym_codeunit] = ACTIONS(4305),
    [anon_sym_CODEUNIT] = ACTIONS(4305),
    [anon_sym_Codeunit] = ACTIONS(4305),
    [anon_sym_CodeUnit] = ACTIONS(4305),
    [anon_sym_COdeunit] = ACTIONS(4305),
    [anon_sym_codeUnit] = ACTIONS(4305),
    [sym_report_keyword] = ACTIONS(4305),
    [sym_query_keyword] = ACTIONS(4305),
    [anon_sym_xmlport] = ACTIONS(4305),
    [anon_sym_XMLPORT] = ACTIONS(4305),
    [anon_sym_Xmlport] = ACTIONS(4305),
    [anon_sym_XMLport] = ACTIONS(4305),
    [anon_sym_XMLPort] = ACTIONS(4305),
    [anon_sym_XmlPort] = ACTIONS(4305),
    [anon_sym_enum] = ACTIONS(4305),
    [anon_sym_ENUM] = ACTIONS(4305),
    [anon_sym_Enum] = ACTIONS(4305),
    [anon_sym_eNUM] = ACTIONS(4305),
    [anon_sym_eNum] = ACTIONS(4305),
    [anon_sym_ENum] = ACTIONS(4305),
    [sym_quoted_identifier] = ACTIONS(4307),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4307),
    [sym_integer] = ACTIONS(4305),
    [sym_continue_as_identifier] = ACTIONS(4307),
    [sym_preproc_open] = ACTIONS(4307),
    [sym_preproc_close] = ACTIONS(4307),
  },
  [STATE(1581)] = {
    [sym_identifier] = ACTIONS(4309),
    [anon_sym_SEMI] = ACTIONS(4311),
    [anon_sym_DASH] = ACTIONS(4311),
    [aux_sym_boolean_token1] = ACTIONS(4309),
    [aux_sym_boolean_token2] = ACTIONS(4309),
    [sym_decimal] = ACTIONS(4309),
    [anon_sym_LPAREN] = ACTIONS(4311),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4309),
    [anon_sym_LBRACK] = ACTIONS(4311),
    [aux_sym_record_type_token1] = ACTIONS(4309),
    [aux_sym_basic_type_token21] = ACTIONS(4309),
    [aux_sym_basic_type_token22] = ACTIONS(4309),
    [aux_sym_basic_type_token48] = ACTIONS(4309),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4309),
    [anon_sym_POUNDif] = ACTIONS(4311),
    [anon_sym_POUNDIF] = ACTIONS(4311),
    [anon_sym_POUNDIf] = ACTIONS(4311),
    [anon_sym_not] = ACTIONS(4309),
    [anon_sym_NOT] = ACTIONS(4309),
    [anon_sym_Not] = ACTIONS(4309),
    [anon_sym_POUNDelif] = ACTIONS(4311),
    [anon_sym_POUNDELIF] = ACTIONS(4311),
    [anon_sym_POUNDElif] = ACTIONS(4311),
    [anon_sym_POUNDelse] = ACTIONS(4311),
    [anon_sym_POUNDELSE] = ACTIONS(4311),
    [anon_sym_POUNDElse] = ACTIONS(4311),
    [anon_sym_POUNDendif] = ACTIONS(4311),
    [anon_sym_POUNDENDIF] = ACTIONS(4311),
    [anon_sym_POUNDEndif] = ACTIONS(4311),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4309),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4309),
    [anon_sym_PLUS] = ACTIONS(4311),
    [sym_datetime_literal] = ACTIONS(4311),
    [sym_date_literal] = ACTIONS(4309),
    [sym_time_literal] = ACTIONS(4309),
    [sym_biginteger_literal] = ACTIONS(4311),
    [anon_sym_if] = ACTIONS(4309),
    [anon_sym_IF] = ACTIONS(4309),
    [anon_sym_If] = ACTIONS(4309),
    [anon_sym_else] = ACTIONS(4309),
    [anon_sym_ELSE] = ACTIONS(4309),
    [anon_sym_Else] = ACTIONS(4309),
    [anon_sym_case] = ACTIONS(4309),
    [anon_sym_CASE] = ACTIONS(4309),
    [anon_sym_Case] = ACTIONS(4309),
    [anon_sym_for] = ACTIONS(4309),
    [anon_sym_FOR] = ACTIONS(4309),
    [anon_sym_For] = ACTIONS(4309),
    [anon_sym_foreach] = ACTIONS(4309),
    [anon_sym_FOREACH] = ACTIONS(4309),
    [anon_sym_Foreach] = ACTIONS(4309),
    [anon_sym_while] = ACTIONS(4309),
    [anon_sym_WHILE] = ACTIONS(4309),
    [anon_sym_While] = ACTIONS(4309),
    [anon_sym_repeat] = ACTIONS(4309),
    [anon_sym_REPEAT] = ACTIONS(4309),
    [anon_sym_Repeat] = ACTIONS(4309),
    [anon_sym_exit] = ACTIONS(4309),
    [anon_sym_EXIT] = ACTIONS(4309),
    [anon_sym_Exit] = ACTIONS(4309),
    [anon_sym_continue] = ACTIONS(4309),
    [anon_sym_CONTINUE] = ACTIONS(4309),
    [anon_sym_Continue] = ACTIONS(4309),
    [anon_sym_break] = ACTIONS(4309),
    [anon_sym_BREAK] = ACTIONS(4309),
    [anon_sym_Break] = ACTIONS(4309),
    [anon_sym_with] = ACTIONS(4309),
    [anon_sym_WITH] = ACTIONS(4309),
    [anon_sym_With] = ACTIONS(4309),
    [sym_asserterror_keyword] = ACTIONS(4311),
    [sym_page_keyword] = ACTIONS(4309),
    [anon_sym_codeunit] = ACTIONS(4309),
    [anon_sym_CODEUNIT] = ACTIONS(4309),
    [anon_sym_Codeunit] = ACTIONS(4309),
    [anon_sym_CodeUnit] = ACTIONS(4309),
    [anon_sym_COdeunit] = ACTIONS(4309),
    [anon_sym_codeUnit] = ACTIONS(4309),
    [sym_report_keyword] = ACTIONS(4309),
    [sym_query_keyword] = ACTIONS(4309),
    [anon_sym_xmlport] = ACTIONS(4309),
    [anon_sym_XMLPORT] = ACTIONS(4309),
    [anon_sym_Xmlport] = ACTIONS(4309),
    [anon_sym_XMLport] = ACTIONS(4309),
    [anon_sym_XMLPort] = ACTIONS(4309),
    [anon_sym_XmlPort] = ACTIONS(4309),
    [anon_sym_enum] = ACTIONS(4309),
    [anon_sym_ENUM] = ACTIONS(4309),
    [anon_sym_Enum] = ACTIONS(4309),
    [anon_sym_eNUM] = ACTIONS(4309),
    [anon_sym_eNum] = ACTIONS(4309),
    [anon_sym_ENum] = ACTIONS(4309),
    [sym_quoted_identifier] = ACTIONS(4311),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4311),
    [sym_integer] = ACTIONS(4309),
    [sym_continue_as_identifier] = ACTIONS(4311),
    [sym_preproc_open] = ACTIONS(4311),
    [sym_preproc_close] = ACTIONS(4311),
  },
  [STATE(1582)] = {
    [sym_identifier] = ACTIONS(4313),
    [anon_sym_SEMI] = ACTIONS(4315),
    [anon_sym_DASH] = ACTIONS(4315),
    [aux_sym_boolean_token1] = ACTIONS(4313),
    [aux_sym_boolean_token2] = ACTIONS(4313),
    [sym_decimal] = ACTIONS(4313),
    [anon_sym_LPAREN] = ACTIONS(4315),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4313),
    [anon_sym_LBRACK] = ACTIONS(4315),
    [aux_sym_record_type_token1] = ACTIONS(4313),
    [aux_sym_basic_type_token21] = ACTIONS(4313),
    [aux_sym_basic_type_token22] = ACTIONS(4313),
    [aux_sym_basic_type_token48] = ACTIONS(4313),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4313),
    [anon_sym_POUNDif] = ACTIONS(4315),
    [anon_sym_POUNDIF] = ACTIONS(4315),
    [anon_sym_POUNDIf] = ACTIONS(4315),
    [anon_sym_not] = ACTIONS(4313),
    [anon_sym_NOT] = ACTIONS(4313),
    [anon_sym_Not] = ACTIONS(4313),
    [anon_sym_POUNDelif] = ACTIONS(4315),
    [anon_sym_POUNDELIF] = ACTIONS(4315),
    [anon_sym_POUNDElif] = ACTIONS(4315),
    [anon_sym_POUNDelse] = ACTIONS(4315),
    [anon_sym_POUNDELSE] = ACTIONS(4315),
    [anon_sym_POUNDElse] = ACTIONS(4315),
    [anon_sym_POUNDendif] = ACTIONS(4315),
    [anon_sym_POUNDENDIF] = ACTIONS(4315),
    [anon_sym_POUNDEndif] = ACTIONS(4315),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4313),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4313),
    [anon_sym_PLUS] = ACTIONS(4315),
    [sym_datetime_literal] = ACTIONS(4315),
    [sym_date_literal] = ACTIONS(4313),
    [sym_time_literal] = ACTIONS(4313),
    [sym_biginteger_literal] = ACTIONS(4315),
    [anon_sym_if] = ACTIONS(4313),
    [anon_sym_IF] = ACTIONS(4313),
    [anon_sym_If] = ACTIONS(4313),
    [anon_sym_else] = ACTIONS(4313),
    [anon_sym_ELSE] = ACTIONS(4313),
    [anon_sym_Else] = ACTIONS(4313),
    [anon_sym_case] = ACTIONS(4313),
    [anon_sym_CASE] = ACTIONS(4313),
    [anon_sym_Case] = ACTIONS(4313),
    [anon_sym_for] = ACTIONS(4313),
    [anon_sym_FOR] = ACTIONS(4313),
    [anon_sym_For] = ACTIONS(4313),
    [anon_sym_foreach] = ACTIONS(4313),
    [anon_sym_FOREACH] = ACTIONS(4313),
    [anon_sym_Foreach] = ACTIONS(4313),
    [anon_sym_while] = ACTIONS(4313),
    [anon_sym_WHILE] = ACTIONS(4313),
    [anon_sym_While] = ACTIONS(4313),
    [anon_sym_repeat] = ACTIONS(4313),
    [anon_sym_REPEAT] = ACTIONS(4313),
    [anon_sym_Repeat] = ACTIONS(4313),
    [anon_sym_exit] = ACTIONS(4313),
    [anon_sym_EXIT] = ACTIONS(4313),
    [anon_sym_Exit] = ACTIONS(4313),
    [anon_sym_continue] = ACTIONS(4313),
    [anon_sym_CONTINUE] = ACTIONS(4313),
    [anon_sym_Continue] = ACTIONS(4313),
    [anon_sym_break] = ACTIONS(4313),
    [anon_sym_BREAK] = ACTIONS(4313),
    [anon_sym_Break] = ACTIONS(4313),
    [anon_sym_with] = ACTIONS(4313),
    [anon_sym_WITH] = ACTIONS(4313),
    [anon_sym_With] = ACTIONS(4313),
    [sym_asserterror_keyword] = ACTIONS(4315),
    [sym_page_keyword] = ACTIONS(4313),
    [anon_sym_codeunit] = ACTIONS(4313),
    [anon_sym_CODEUNIT] = ACTIONS(4313),
    [anon_sym_Codeunit] = ACTIONS(4313),
    [anon_sym_CodeUnit] = ACTIONS(4313),
    [anon_sym_COdeunit] = ACTIONS(4313),
    [anon_sym_codeUnit] = ACTIONS(4313),
    [sym_report_keyword] = ACTIONS(4313),
    [sym_query_keyword] = ACTIONS(4313),
    [anon_sym_xmlport] = ACTIONS(4313),
    [anon_sym_XMLPORT] = ACTIONS(4313),
    [anon_sym_Xmlport] = ACTIONS(4313),
    [anon_sym_XMLport] = ACTIONS(4313),
    [anon_sym_XMLPort] = ACTIONS(4313),
    [anon_sym_XmlPort] = ACTIONS(4313),
    [anon_sym_enum] = ACTIONS(4313),
    [anon_sym_ENUM] = ACTIONS(4313),
    [anon_sym_Enum] = ACTIONS(4313),
    [anon_sym_eNUM] = ACTIONS(4313),
    [anon_sym_eNum] = ACTIONS(4313),
    [anon_sym_ENum] = ACTIONS(4313),
    [sym_quoted_identifier] = ACTIONS(4315),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4315),
    [sym_integer] = ACTIONS(4313),
    [sym_continue_as_identifier] = ACTIONS(4315),
    [sym_preproc_open] = ACTIONS(4315),
    [sym_preproc_close] = ACTIONS(4315),
  },
  [STATE(1583)] = {
    [sym_identifier] = ACTIONS(4317),
    [anon_sym_SEMI] = ACTIONS(4319),
    [anon_sym_DASH] = ACTIONS(4319),
    [aux_sym_boolean_token1] = ACTIONS(4317),
    [aux_sym_boolean_token2] = ACTIONS(4317),
    [sym_decimal] = ACTIONS(4317),
    [anon_sym_LPAREN] = ACTIONS(4319),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4317),
    [anon_sym_LBRACK] = ACTIONS(4319),
    [aux_sym_record_type_token1] = ACTIONS(4317),
    [aux_sym_basic_type_token21] = ACTIONS(4317),
    [aux_sym_basic_type_token22] = ACTIONS(4317),
    [aux_sym_basic_type_token48] = ACTIONS(4317),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4317),
    [anon_sym_POUNDif] = ACTIONS(4319),
    [anon_sym_POUNDIF] = ACTIONS(4319),
    [anon_sym_POUNDIf] = ACTIONS(4319),
    [anon_sym_not] = ACTIONS(4317),
    [anon_sym_NOT] = ACTIONS(4317),
    [anon_sym_Not] = ACTIONS(4317),
    [anon_sym_POUNDelif] = ACTIONS(4319),
    [anon_sym_POUNDELIF] = ACTIONS(4319),
    [anon_sym_POUNDElif] = ACTIONS(4319),
    [anon_sym_POUNDelse] = ACTIONS(4319),
    [anon_sym_POUNDELSE] = ACTIONS(4319),
    [anon_sym_POUNDElse] = ACTIONS(4319),
    [anon_sym_POUNDendif] = ACTIONS(4319),
    [anon_sym_POUNDENDIF] = ACTIONS(4319),
    [anon_sym_POUNDEndif] = ACTIONS(4319),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4317),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4317),
    [anon_sym_PLUS] = ACTIONS(4319),
    [sym_datetime_literal] = ACTIONS(4319),
    [sym_date_literal] = ACTIONS(4317),
    [sym_time_literal] = ACTIONS(4317),
    [sym_biginteger_literal] = ACTIONS(4319),
    [anon_sym_if] = ACTIONS(4317),
    [anon_sym_IF] = ACTIONS(4317),
    [anon_sym_If] = ACTIONS(4317),
    [anon_sym_else] = ACTIONS(4317),
    [anon_sym_ELSE] = ACTIONS(4317),
    [anon_sym_Else] = ACTIONS(4317),
    [anon_sym_case] = ACTIONS(4317),
    [anon_sym_CASE] = ACTIONS(4317),
    [anon_sym_Case] = ACTIONS(4317),
    [anon_sym_for] = ACTIONS(4317),
    [anon_sym_FOR] = ACTIONS(4317),
    [anon_sym_For] = ACTIONS(4317),
    [anon_sym_foreach] = ACTIONS(4317),
    [anon_sym_FOREACH] = ACTIONS(4317),
    [anon_sym_Foreach] = ACTIONS(4317),
    [anon_sym_while] = ACTIONS(4317),
    [anon_sym_WHILE] = ACTIONS(4317),
    [anon_sym_While] = ACTIONS(4317),
    [anon_sym_repeat] = ACTIONS(4317),
    [anon_sym_REPEAT] = ACTIONS(4317),
    [anon_sym_Repeat] = ACTIONS(4317),
    [anon_sym_exit] = ACTIONS(4317),
    [anon_sym_EXIT] = ACTIONS(4317),
    [anon_sym_Exit] = ACTIONS(4317),
    [anon_sym_continue] = ACTIONS(4317),
    [anon_sym_CONTINUE] = ACTIONS(4317),
    [anon_sym_Continue] = ACTIONS(4317),
    [anon_sym_break] = ACTIONS(4317),
    [anon_sym_BREAK] = ACTIONS(4317),
    [anon_sym_Break] = ACTIONS(4317),
    [anon_sym_with] = ACTIONS(4317),
    [anon_sym_WITH] = ACTIONS(4317),
    [anon_sym_With] = ACTIONS(4317),
    [sym_asserterror_keyword] = ACTIONS(4319),
    [sym_page_keyword] = ACTIONS(4317),
    [anon_sym_codeunit] = ACTIONS(4317),
    [anon_sym_CODEUNIT] = ACTIONS(4317),
    [anon_sym_Codeunit] = ACTIONS(4317),
    [anon_sym_CodeUnit] = ACTIONS(4317),
    [anon_sym_COdeunit] = ACTIONS(4317),
    [anon_sym_codeUnit] = ACTIONS(4317),
    [sym_report_keyword] = ACTIONS(4317),
    [sym_query_keyword] = ACTIONS(4317),
    [anon_sym_xmlport] = ACTIONS(4317),
    [anon_sym_XMLPORT] = ACTIONS(4317),
    [anon_sym_Xmlport] = ACTIONS(4317),
    [anon_sym_XMLport] = ACTIONS(4317),
    [anon_sym_XMLPort] = ACTIONS(4317),
    [anon_sym_XmlPort] = ACTIONS(4317),
    [anon_sym_enum] = ACTIONS(4317),
    [anon_sym_ENUM] = ACTIONS(4317),
    [anon_sym_Enum] = ACTIONS(4317),
    [anon_sym_eNUM] = ACTIONS(4317),
    [anon_sym_eNum] = ACTIONS(4317),
    [anon_sym_ENum] = ACTIONS(4317),
    [sym_quoted_identifier] = ACTIONS(4319),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4319),
    [sym_integer] = ACTIONS(4317),
    [sym_continue_as_identifier] = ACTIONS(4319),
    [sym_preproc_open] = ACTIONS(4319),
    [sym_preproc_close] = ACTIONS(4319),
  },
  [STATE(1584)] = {
    [sym_identifier] = ACTIONS(4321),
    [anon_sym_SEMI] = ACTIONS(4323),
    [anon_sym_DASH] = ACTIONS(4323),
    [aux_sym_boolean_token1] = ACTIONS(4321),
    [aux_sym_boolean_token2] = ACTIONS(4321),
    [sym_decimal] = ACTIONS(4321),
    [anon_sym_LPAREN] = ACTIONS(4323),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4321),
    [anon_sym_LBRACK] = ACTIONS(4323),
    [aux_sym_record_type_token1] = ACTIONS(4321),
    [aux_sym_basic_type_token21] = ACTIONS(4321),
    [aux_sym_basic_type_token22] = ACTIONS(4321),
    [aux_sym_basic_type_token48] = ACTIONS(4321),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4321),
    [anon_sym_POUNDif] = ACTIONS(4323),
    [anon_sym_POUNDIF] = ACTIONS(4323),
    [anon_sym_POUNDIf] = ACTIONS(4323),
    [anon_sym_not] = ACTIONS(4321),
    [anon_sym_NOT] = ACTIONS(4321),
    [anon_sym_Not] = ACTIONS(4321),
    [anon_sym_POUNDelif] = ACTIONS(4323),
    [anon_sym_POUNDELIF] = ACTIONS(4323),
    [anon_sym_POUNDElif] = ACTIONS(4323),
    [anon_sym_POUNDelse] = ACTIONS(4323),
    [anon_sym_POUNDELSE] = ACTIONS(4323),
    [anon_sym_POUNDElse] = ACTIONS(4323),
    [anon_sym_POUNDendif] = ACTIONS(4323),
    [anon_sym_POUNDENDIF] = ACTIONS(4323),
    [anon_sym_POUNDEndif] = ACTIONS(4323),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4321),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4321),
    [anon_sym_PLUS] = ACTIONS(4323),
    [sym_datetime_literal] = ACTIONS(4323),
    [sym_date_literal] = ACTIONS(4321),
    [sym_time_literal] = ACTIONS(4321),
    [sym_biginteger_literal] = ACTIONS(4323),
    [anon_sym_if] = ACTIONS(4321),
    [anon_sym_IF] = ACTIONS(4321),
    [anon_sym_If] = ACTIONS(4321),
    [anon_sym_else] = ACTIONS(4321),
    [anon_sym_ELSE] = ACTIONS(4321),
    [anon_sym_Else] = ACTIONS(4321),
    [anon_sym_case] = ACTIONS(4321),
    [anon_sym_CASE] = ACTIONS(4321),
    [anon_sym_Case] = ACTIONS(4321),
    [anon_sym_for] = ACTIONS(4321),
    [anon_sym_FOR] = ACTIONS(4321),
    [anon_sym_For] = ACTIONS(4321),
    [anon_sym_foreach] = ACTIONS(4321),
    [anon_sym_FOREACH] = ACTIONS(4321),
    [anon_sym_Foreach] = ACTIONS(4321),
    [anon_sym_while] = ACTIONS(4321),
    [anon_sym_WHILE] = ACTIONS(4321),
    [anon_sym_While] = ACTIONS(4321),
    [anon_sym_repeat] = ACTIONS(4321),
    [anon_sym_REPEAT] = ACTIONS(4321),
    [anon_sym_Repeat] = ACTIONS(4321),
    [anon_sym_exit] = ACTIONS(4321),
    [anon_sym_EXIT] = ACTIONS(4321),
    [anon_sym_Exit] = ACTIONS(4321),
    [anon_sym_continue] = ACTIONS(4321),
    [anon_sym_CONTINUE] = ACTIONS(4321),
    [anon_sym_Continue] = ACTIONS(4321),
    [anon_sym_break] = ACTIONS(4321),
    [anon_sym_BREAK] = ACTIONS(4321),
    [anon_sym_Break] = ACTIONS(4321),
    [anon_sym_with] = ACTIONS(4321),
    [anon_sym_WITH] = ACTIONS(4321),
    [anon_sym_With] = ACTIONS(4321),
    [sym_asserterror_keyword] = ACTIONS(4323),
    [sym_page_keyword] = ACTIONS(4321),
    [anon_sym_codeunit] = ACTIONS(4321),
    [anon_sym_CODEUNIT] = ACTIONS(4321),
    [anon_sym_Codeunit] = ACTIONS(4321),
    [anon_sym_CodeUnit] = ACTIONS(4321),
    [anon_sym_COdeunit] = ACTIONS(4321),
    [anon_sym_codeUnit] = ACTIONS(4321),
    [sym_report_keyword] = ACTIONS(4321),
    [sym_query_keyword] = ACTIONS(4321),
    [anon_sym_xmlport] = ACTIONS(4321),
    [anon_sym_XMLPORT] = ACTIONS(4321),
    [anon_sym_Xmlport] = ACTIONS(4321),
    [anon_sym_XMLport] = ACTIONS(4321),
    [anon_sym_XMLPort] = ACTIONS(4321),
    [anon_sym_XmlPort] = ACTIONS(4321),
    [anon_sym_enum] = ACTIONS(4321),
    [anon_sym_ENUM] = ACTIONS(4321),
    [anon_sym_Enum] = ACTIONS(4321),
    [anon_sym_eNUM] = ACTIONS(4321),
    [anon_sym_eNum] = ACTIONS(4321),
    [anon_sym_ENum] = ACTIONS(4321),
    [sym_quoted_identifier] = ACTIONS(4323),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4323),
    [sym_integer] = ACTIONS(4321),
    [sym_continue_as_identifier] = ACTIONS(4323),
    [sym_preproc_open] = ACTIONS(4323),
    [sym_preproc_close] = ACTIONS(4323),
  },
  [STATE(1585)] = {
    [sym_identifier] = ACTIONS(4325),
    [anon_sym_SEMI] = ACTIONS(4327),
    [anon_sym_DASH] = ACTIONS(4327),
    [aux_sym_boolean_token1] = ACTIONS(4325),
    [aux_sym_boolean_token2] = ACTIONS(4325),
    [sym_decimal] = ACTIONS(4325),
    [anon_sym_LPAREN] = ACTIONS(4327),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4325),
    [anon_sym_LBRACK] = ACTIONS(4327),
    [aux_sym_record_type_token1] = ACTIONS(4325),
    [aux_sym_basic_type_token21] = ACTIONS(4325),
    [aux_sym_basic_type_token22] = ACTIONS(4325),
    [aux_sym_basic_type_token48] = ACTIONS(4325),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4325),
    [anon_sym_POUNDif] = ACTIONS(4327),
    [anon_sym_POUNDIF] = ACTIONS(4327),
    [anon_sym_POUNDIf] = ACTIONS(4327),
    [anon_sym_not] = ACTIONS(4325),
    [anon_sym_NOT] = ACTIONS(4325),
    [anon_sym_Not] = ACTIONS(4325),
    [anon_sym_POUNDelif] = ACTIONS(4327),
    [anon_sym_POUNDELIF] = ACTIONS(4327),
    [anon_sym_POUNDElif] = ACTIONS(4327),
    [anon_sym_POUNDelse] = ACTIONS(4327),
    [anon_sym_POUNDELSE] = ACTIONS(4327),
    [anon_sym_POUNDElse] = ACTIONS(4327),
    [anon_sym_POUNDendif] = ACTIONS(4327),
    [anon_sym_POUNDENDIF] = ACTIONS(4327),
    [anon_sym_POUNDEndif] = ACTIONS(4327),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4325),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4325),
    [anon_sym_PLUS] = ACTIONS(4327),
    [sym_datetime_literal] = ACTIONS(4327),
    [sym_date_literal] = ACTIONS(4325),
    [sym_time_literal] = ACTIONS(4325),
    [sym_biginteger_literal] = ACTIONS(4327),
    [anon_sym_if] = ACTIONS(4325),
    [anon_sym_IF] = ACTIONS(4325),
    [anon_sym_If] = ACTIONS(4325),
    [anon_sym_else] = ACTIONS(4325),
    [anon_sym_ELSE] = ACTIONS(4325),
    [anon_sym_Else] = ACTIONS(4325),
    [anon_sym_case] = ACTIONS(4325),
    [anon_sym_CASE] = ACTIONS(4325),
    [anon_sym_Case] = ACTIONS(4325),
    [anon_sym_for] = ACTIONS(4325),
    [anon_sym_FOR] = ACTIONS(4325),
    [anon_sym_For] = ACTIONS(4325),
    [anon_sym_foreach] = ACTIONS(4325),
    [anon_sym_FOREACH] = ACTIONS(4325),
    [anon_sym_Foreach] = ACTIONS(4325),
    [anon_sym_while] = ACTIONS(4325),
    [anon_sym_WHILE] = ACTIONS(4325),
    [anon_sym_While] = ACTIONS(4325),
    [anon_sym_repeat] = ACTIONS(4325),
    [anon_sym_REPEAT] = ACTIONS(4325),
    [anon_sym_Repeat] = ACTIONS(4325),
    [anon_sym_exit] = ACTIONS(4325),
    [anon_sym_EXIT] = ACTIONS(4325),
    [anon_sym_Exit] = ACTIONS(4325),
    [anon_sym_continue] = ACTIONS(4325),
    [anon_sym_CONTINUE] = ACTIONS(4325),
    [anon_sym_Continue] = ACTIONS(4325),
    [anon_sym_break] = ACTIONS(4325),
    [anon_sym_BREAK] = ACTIONS(4325),
    [anon_sym_Break] = ACTIONS(4325),
    [anon_sym_with] = ACTIONS(4325),
    [anon_sym_WITH] = ACTIONS(4325),
    [anon_sym_With] = ACTIONS(4325),
    [sym_asserterror_keyword] = ACTIONS(4327),
    [sym_page_keyword] = ACTIONS(4325),
    [anon_sym_codeunit] = ACTIONS(4325),
    [anon_sym_CODEUNIT] = ACTIONS(4325),
    [anon_sym_Codeunit] = ACTIONS(4325),
    [anon_sym_CodeUnit] = ACTIONS(4325),
    [anon_sym_COdeunit] = ACTIONS(4325),
    [anon_sym_codeUnit] = ACTIONS(4325),
    [sym_report_keyword] = ACTIONS(4325),
    [sym_query_keyword] = ACTIONS(4325),
    [anon_sym_xmlport] = ACTIONS(4325),
    [anon_sym_XMLPORT] = ACTIONS(4325),
    [anon_sym_Xmlport] = ACTIONS(4325),
    [anon_sym_XMLport] = ACTIONS(4325),
    [anon_sym_XMLPort] = ACTIONS(4325),
    [anon_sym_XmlPort] = ACTIONS(4325),
    [anon_sym_enum] = ACTIONS(4325),
    [anon_sym_ENUM] = ACTIONS(4325),
    [anon_sym_Enum] = ACTIONS(4325),
    [anon_sym_eNUM] = ACTIONS(4325),
    [anon_sym_eNum] = ACTIONS(4325),
    [anon_sym_ENum] = ACTIONS(4325),
    [sym_quoted_identifier] = ACTIONS(4327),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4327),
    [sym_integer] = ACTIONS(4325),
    [sym_continue_as_identifier] = ACTIONS(4327),
    [sym_preproc_open] = ACTIONS(4327),
    [sym_preproc_close] = ACTIONS(4327),
  },
  [STATE(1586)] = {
    [sym_identifier] = ACTIONS(4329),
    [anon_sym_SEMI] = ACTIONS(4331),
    [anon_sym_DASH] = ACTIONS(4331),
    [aux_sym_boolean_token1] = ACTIONS(4329),
    [aux_sym_boolean_token2] = ACTIONS(4329),
    [sym_decimal] = ACTIONS(4329),
    [anon_sym_LPAREN] = ACTIONS(4331),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4329),
    [anon_sym_LBRACK] = ACTIONS(4331),
    [aux_sym_record_type_token1] = ACTIONS(4329),
    [aux_sym_basic_type_token21] = ACTIONS(4329),
    [aux_sym_basic_type_token22] = ACTIONS(4329),
    [aux_sym_basic_type_token48] = ACTIONS(4329),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4329),
    [anon_sym_POUNDif] = ACTIONS(4331),
    [anon_sym_POUNDIF] = ACTIONS(4331),
    [anon_sym_POUNDIf] = ACTIONS(4331),
    [anon_sym_not] = ACTIONS(4329),
    [anon_sym_NOT] = ACTIONS(4329),
    [anon_sym_Not] = ACTIONS(4329),
    [anon_sym_POUNDelif] = ACTIONS(4331),
    [anon_sym_POUNDELIF] = ACTIONS(4331),
    [anon_sym_POUNDElif] = ACTIONS(4331),
    [anon_sym_POUNDelse] = ACTIONS(4331),
    [anon_sym_POUNDELSE] = ACTIONS(4331),
    [anon_sym_POUNDElse] = ACTIONS(4331),
    [anon_sym_POUNDendif] = ACTIONS(4331),
    [anon_sym_POUNDENDIF] = ACTIONS(4331),
    [anon_sym_POUNDEndif] = ACTIONS(4331),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4329),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4329),
    [anon_sym_PLUS] = ACTIONS(4331),
    [sym_datetime_literal] = ACTIONS(4331),
    [sym_date_literal] = ACTIONS(4329),
    [sym_time_literal] = ACTIONS(4329),
    [sym_biginteger_literal] = ACTIONS(4331),
    [anon_sym_if] = ACTIONS(4329),
    [anon_sym_IF] = ACTIONS(4329),
    [anon_sym_If] = ACTIONS(4329),
    [anon_sym_else] = ACTIONS(4329),
    [anon_sym_ELSE] = ACTIONS(4329),
    [anon_sym_Else] = ACTIONS(4329),
    [anon_sym_case] = ACTIONS(4329),
    [anon_sym_CASE] = ACTIONS(4329),
    [anon_sym_Case] = ACTIONS(4329),
    [anon_sym_for] = ACTIONS(4329),
    [anon_sym_FOR] = ACTIONS(4329),
    [anon_sym_For] = ACTIONS(4329),
    [anon_sym_foreach] = ACTIONS(4329),
    [anon_sym_FOREACH] = ACTIONS(4329),
    [anon_sym_Foreach] = ACTIONS(4329),
    [anon_sym_while] = ACTIONS(4329),
    [anon_sym_WHILE] = ACTIONS(4329),
    [anon_sym_While] = ACTIONS(4329),
    [anon_sym_repeat] = ACTIONS(4329),
    [anon_sym_REPEAT] = ACTIONS(4329),
    [anon_sym_Repeat] = ACTIONS(4329),
    [anon_sym_exit] = ACTIONS(4329),
    [anon_sym_EXIT] = ACTIONS(4329),
    [anon_sym_Exit] = ACTIONS(4329),
    [anon_sym_continue] = ACTIONS(4329),
    [anon_sym_CONTINUE] = ACTIONS(4329),
    [anon_sym_Continue] = ACTIONS(4329),
    [anon_sym_break] = ACTIONS(4329),
    [anon_sym_BREAK] = ACTIONS(4329),
    [anon_sym_Break] = ACTIONS(4329),
    [anon_sym_with] = ACTIONS(4329),
    [anon_sym_WITH] = ACTIONS(4329),
    [anon_sym_With] = ACTIONS(4329),
    [sym_asserterror_keyword] = ACTIONS(4331),
    [sym_page_keyword] = ACTIONS(4329),
    [anon_sym_codeunit] = ACTIONS(4329),
    [anon_sym_CODEUNIT] = ACTIONS(4329),
    [anon_sym_Codeunit] = ACTIONS(4329),
    [anon_sym_CodeUnit] = ACTIONS(4329),
    [anon_sym_COdeunit] = ACTIONS(4329),
    [anon_sym_codeUnit] = ACTIONS(4329),
    [sym_report_keyword] = ACTIONS(4329),
    [sym_query_keyword] = ACTIONS(4329),
    [anon_sym_xmlport] = ACTIONS(4329),
    [anon_sym_XMLPORT] = ACTIONS(4329),
    [anon_sym_Xmlport] = ACTIONS(4329),
    [anon_sym_XMLport] = ACTIONS(4329),
    [anon_sym_XMLPort] = ACTIONS(4329),
    [anon_sym_XmlPort] = ACTIONS(4329),
    [anon_sym_enum] = ACTIONS(4329),
    [anon_sym_ENUM] = ACTIONS(4329),
    [anon_sym_Enum] = ACTIONS(4329),
    [anon_sym_eNUM] = ACTIONS(4329),
    [anon_sym_eNum] = ACTIONS(4329),
    [anon_sym_ENum] = ACTIONS(4329),
    [sym_quoted_identifier] = ACTIONS(4331),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4331),
    [sym_integer] = ACTIONS(4329),
    [sym_continue_as_identifier] = ACTIONS(4331),
    [sym_preproc_open] = ACTIONS(4331),
    [sym_preproc_close] = ACTIONS(4331),
  },
  [STATE(1587)] = {
    [sym_identifier] = ACTIONS(4333),
    [anon_sym_SEMI] = ACTIONS(4335),
    [anon_sym_DASH] = ACTIONS(4335),
    [aux_sym_boolean_token1] = ACTIONS(4333),
    [aux_sym_boolean_token2] = ACTIONS(4333),
    [sym_decimal] = ACTIONS(4333),
    [anon_sym_LPAREN] = ACTIONS(4335),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4333),
    [anon_sym_LBRACK] = ACTIONS(4335),
    [aux_sym_record_type_token1] = ACTIONS(4333),
    [aux_sym_basic_type_token21] = ACTIONS(4333),
    [aux_sym_basic_type_token22] = ACTIONS(4333),
    [aux_sym_basic_type_token48] = ACTIONS(4333),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4333),
    [anon_sym_POUNDif] = ACTIONS(4335),
    [anon_sym_POUNDIF] = ACTIONS(4335),
    [anon_sym_POUNDIf] = ACTIONS(4335),
    [anon_sym_not] = ACTIONS(4333),
    [anon_sym_NOT] = ACTIONS(4333),
    [anon_sym_Not] = ACTIONS(4333),
    [anon_sym_POUNDelif] = ACTIONS(4335),
    [anon_sym_POUNDELIF] = ACTIONS(4335),
    [anon_sym_POUNDElif] = ACTIONS(4335),
    [anon_sym_POUNDelse] = ACTIONS(4335),
    [anon_sym_POUNDELSE] = ACTIONS(4335),
    [anon_sym_POUNDElse] = ACTIONS(4335),
    [anon_sym_POUNDendif] = ACTIONS(4335),
    [anon_sym_POUNDENDIF] = ACTIONS(4335),
    [anon_sym_POUNDEndif] = ACTIONS(4335),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4333),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4333),
    [anon_sym_PLUS] = ACTIONS(4335),
    [sym_datetime_literal] = ACTIONS(4335),
    [sym_date_literal] = ACTIONS(4333),
    [sym_time_literal] = ACTIONS(4333),
    [sym_biginteger_literal] = ACTIONS(4335),
    [anon_sym_if] = ACTIONS(4333),
    [anon_sym_IF] = ACTIONS(4333),
    [anon_sym_If] = ACTIONS(4333),
    [anon_sym_else] = ACTIONS(4333),
    [anon_sym_ELSE] = ACTIONS(4333),
    [anon_sym_Else] = ACTIONS(4333),
    [anon_sym_case] = ACTIONS(4333),
    [anon_sym_CASE] = ACTIONS(4333),
    [anon_sym_Case] = ACTIONS(4333),
    [anon_sym_for] = ACTIONS(4333),
    [anon_sym_FOR] = ACTIONS(4333),
    [anon_sym_For] = ACTIONS(4333),
    [anon_sym_foreach] = ACTIONS(4333),
    [anon_sym_FOREACH] = ACTIONS(4333),
    [anon_sym_Foreach] = ACTIONS(4333),
    [anon_sym_while] = ACTIONS(4333),
    [anon_sym_WHILE] = ACTIONS(4333),
    [anon_sym_While] = ACTIONS(4333),
    [anon_sym_repeat] = ACTIONS(4333),
    [anon_sym_REPEAT] = ACTIONS(4333),
    [anon_sym_Repeat] = ACTIONS(4333),
    [anon_sym_exit] = ACTIONS(4333),
    [anon_sym_EXIT] = ACTIONS(4333),
    [anon_sym_Exit] = ACTIONS(4333),
    [anon_sym_continue] = ACTIONS(4333),
    [anon_sym_CONTINUE] = ACTIONS(4333),
    [anon_sym_Continue] = ACTIONS(4333),
    [anon_sym_break] = ACTIONS(4333),
    [anon_sym_BREAK] = ACTIONS(4333),
    [anon_sym_Break] = ACTIONS(4333),
    [anon_sym_with] = ACTIONS(4333),
    [anon_sym_WITH] = ACTIONS(4333),
    [anon_sym_With] = ACTIONS(4333),
    [sym_asserterror_keyword] = ACTIONS(4335),
    [sym_page_keyword] = ACTIONS(4333),
    [anon_sym_codeunit] = ACTIONS(4333),
    [anon_sym_CODEUNIT] = ACTIONS(4333),
    [anon_sym_Codeunit] = ACTIONS(4333),
    [anon_sym_CodeUnit] = ACTIONS(4333),
    [anon_sym_COdeunit] = ACTIONS(4333),
    [anon_sym_codeUnit] = ACTIONS(4333),
    [sym_report_keyword] = ACTIONS(4333),
    [sym_query_keyword] = ACTIONS(4333),
    [anon_sym_xmlport] = ACTIONS(4333),
    [anon_sym_XMLPORT] = ACTIONS(4333),
    [anon_sym_Xmlport] = ACTIONS(4333),
    [anon_sym_XMLport] = ACTIONS(4333),
    [anon_sym_XMLPort] = ACTIONS(4333),
    [anon_sym_XmlPort] = ACTIONS(4333),
    [anon_sym_enum] = ACTIONS(4333),
    [anon_sym_ENUM] = ACTIONS(4333),
    [anon_sym_Enum] = ACTIONS(4333),
    [anon_sym_eNUM] = ACTIONS(4333),
    [anon_sym_eNum] = ACTIONS(4333),
    [anon_sym_ENum] = ACTIONS(4333),
    [sym_quoted_identifier] = ACTIONS(4335),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4335),
    [sym_integer] = ACTIONS(4333),
    [sym_continue_as_identifier] = ACTIONS(4335),
    [sym_preproc_open] = ACTIONS(4335),
    [sym_preproc_close] = ACTIONS(4335),
  },
  [STATE(1588)] = {
    [sym_identifier] = ACTIONS(4337),
    [anon_sym_SEMI] = ACTIONS(4339),
    [anon_sym_DASH] = ACTIONS(4339),
    [aux_sym_boolean_token1] = ACTIONS(4337),
    [aux_sym_boolean_token2] = ACTIONS(4337),
    [sym_decimal] = ACTIONS(4337),
    [anon_sym_LPAREN] = ACTIONS(4339),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4337),
    [anon_sym_LBRACK] = ACTIONS(4339),
    [aux_sym_record_type_token1] = ACTIONS(4337),
    [aux_sym_basic_type_token21] = ACTIONS(4337),
    [aux_sym_basic_type_token22] = ACTIONS(4337),
    [aux_sym_basic_type_token48] = ACTIONS(4337),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4337),
    [anon_sym_POUNDif] = ACTIONS(4339),
    [anon_sym_POUNDIF] = ACTIONS(4339),
    [anon_sym_POUNDIf] = ACTIONS(4339),
    [anon_sym_not] = ACTIONS(4337),
    [anon_sym_NOT] = ACTIONS(4337),
    [anon_sym_Not] = ACTIONS(4337),
    [anon_sym_POUNDelif] = ACTIONS(4339),
    [anon_sym_POUNDELIF] = ACTIONS(4339),
    [anon_sym_POUNDElif] = ACTIONS(4339),
    [anon_sym_POUNDelse] = ACTIONS(4339),
    [anon_sym_POUNDELSE] = ACTIONS(4339),
    [anon_sym_POUNDElse] = ACTIONS(4339),
    [anon_sym_POUNDendif] = ACTIONS(4339),
    [anon_sym_POUNDENDIF] = ACTIONS(4339),
    [anon_sym_POUNDEndif] = ACTIONS(4339),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4337),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4337),
    [anon_sym_PLUS] = ACTIONS(4339),
    [sym_datetime_literal] = ACTIONS(4339),
    [sym_date_literal] = ACTIONS(4337),
    [sym_time_literal] = ACTIONS(4337),
    [sym_biginteger_literal] = ACTIONS(4339),
    [anon_sym_if] = ACTIONS(4337),
    [anon_sym_IF] = ACTIONS(4337),
    [anon_sym_If] = ACTIONS(4337),
    [anon_sym_else] = ACTIONS(4337),
    [anon_sym_ELSE] = ACTIONS(4337),
    [anon_sym_Else] = ACTIONS(4337),
    [anon_sym_case] = ACTIONS(4337),
    [anon_sym_CASE] = ACTIONS(4337),
    [anon_sym_Case] = ACTIONS(4337),
    [anon_sym_for] = ACTIONS(4337),
    [anon_sym_FOR] = ACTIONS(4337),
    [anon_sym_For] = ACTIONS(4337),
    [anon_sym_foreach] = ACTIONS(4337),
    [anon_sym_FOREACH] = ACTIONS(4337),
    [anon_sym_Foreach] = ACTIONS(4337),
    [anon_sym_while] = ACTIONS(4337),
    [anon_sym_WHILE] = ACTIONS(4337),
    [anon_sym_While] = ACTIONS(4337),
    [anon_sym_repeat] = ACTIONS(4337),
    [anon_sym_REPEAT] = ACTIONS(4337),
    [anon_sym_Repeat] = ACTIONS(4337),
    [anon_sym_exit] = ACTIONS(4337),
    [anon_sym_EXIT] = ACTIONS(4337),
    [anon_sym_Exit] = ACTIONS(4337),
    [anon_sym_continue] = ACTIONS(4337),
    [anon_sym_CONTINUE] = ACTIONS(4337),
    [anon_sym_Continue] = ACTIONS(4337),
    [anon_sym_break] = ACTIONS(4337),
    [anon_sym_BREAK] = ACTIONS(4337),
    [anon_sym_Break] = ACTIONS(4337),
    [anon_sym_with] = ACTIONS(4337),
    [anon_sym_WITH] = ACTIONS(4337),
    [anon_sym_With] = ACTIONS(4337),
    [sym_asserterror_keyword] = ACTIONS(4339),
    [sym_page_keyword] = ACTIONS(4337),
    [anon_sym_codeunit] = ACTIONS(4337),
    [anon_sym_CODEUNIT] = ACTIONS(4337),
    [anon_sym_Codeunit] = ACTIONS(4337),
    [anon_sym_CodeUnit] = ACTIONS(4337),
    [anon_sym_COdeunit] = ACTIONS(4337),
    [anon_sym_codeUnit] = ACTIONS(4337),
    [sym_report_keyword] = ACTIONS(4337),
    [sym_query_keyword] = ACTIONS(4337),
    [anon_sym_xmlport] = ACTIONS(4337),
    [anon_sym_XMLPORT] = ACTIONS(4337),
    [anon_sym_Xmlport] = ACTIONS(4337),
    [anon_sym_XMLport] = ACTIONS(4337),
    [anon_sym_XMLPort] = ACTIONS(4337),
    [anon_sym_XmlPort] = ACTIONS(4337),
    [anon_sym_enum] = ACTIONS(4337),
    [anon_sym_ENUM] = ACTIONS(4337),
    [anon_sym_Enum] = ACTIONS(4337),
    [anon_sym_eNUM] = ACTIONS(4337),
    [anon_sym_eNum] = ACTIONS(4337),
    [anon_sym_ENum] = ACTIONS(4337),
    [sym_quoted_identifier] = ACTIONS(4339),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4339),
    [sym_integer] = ACTIONS(4337),
    [sym_continue_as_identifier] = ACTIONS(4339),
    [sym_preproc_open] = ACTIONS(4339),
    [sym_preproc_close] = ACTIONS(4339),
  },
  [STATE(1589)] = {
    [sym_identifier] = ACTIONS(4341),
    [anon_sym_SEMI] = ACTIONS(4343),
    [anon_sym_DASH] = ACTIONS(4343),
    [aux_sym_boolean_token1] = ACTIONS(4341),
    [aux_sym_boolean_token2] = ACTIONS(4341),
    [sym_decimal] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4343),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4341),
    [anon_sym_LBRACK] = ACTIONS(4343),
    [aux_sym_record_type_token1] = ACTIONS(4341),
    [aux_sym_basic_type_token21] = ACTIONS(4341),
    [aux_sym_basic_type_token22] = ACTIONS(4341),
    [aux_sym_basic_type_token48] = ACTIONS(4341),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4341),
    [anon_sym_POUNDif] = ACTIONS(4343),
    [anon_sym_POUNDIF] = ACTIONS(4343),
    [anon_sym_POUNDIf] = ACTIONS(4343),
    [anon_sym_not] = ACTIONS(4341),
    [anon_sym_NOT] = ACTIONS(4341),
    [anon_sym_Not] = ACTIONS(4341),
    [anon_sym_POUNDelif] = ACTIONS(4343),
    [anon_sym_POUNDELIF] = ACTIONS(4343),
    [anon_sym_POUNDElif] = ACTIONS(4343),
    [anon_sym_POUNDelse] = ACTIONS(4343),
    [anon_sym_POUNDELSE] = ACTIONS(4343),
    [anon_sym_POUNDElse] = ACTIONS(4343),
    [anon_sym_POUNDendif] = ACTIONS(4343),
    [anon_sym_POUNDENDIF] = ACTIONS(4343),
    [anon_sym_POUNDEndif] = ACTIONS(4343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4341),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4343),
    [sym_datetime_literal] = ACTIONS(4343),
    [sym_date_literal] = ACTIONS(4341),
    [sym_time_literal] = ACTIONS(4341),
    [sym_biginteger_literal] = ACTIONS(4343),
    [anon_sym_if] = ACTIONS(4341),
    [anon_sym_IF] = ACTIONS(4341),
    [anon_sym_If] = ACTIONS(4341),
    [anon_sym_else] = ACTIONS(4341),
    [anon_sym_ELSE] = ACTIONS(4341),
    [anon_sym_Else] = ACTIONS(4341),
    [anon_sym_case] = ACTIONS(4341),
    [anon_sym_CASE] = ACTIONS(4341),
    [anon_sym_Case] = ACTIONS(4341),
    [anon_sym_for] = ACTIONS(4341),
    [anon_sym_FOR] = ACTIONS(4341),
    [anon_sym_For] = ACTIONS(4341),
    [anon_sym_foreach] = ACTIONS(4341),
    [anon_sym_FOREACH] = ACTIONS(4341),
    [anon_sym_Foreach] = ACTIONS(4341),
    [anon_sym_while] = ACTIONS(4341),
    [anon_sym_WHILE] = ACTIONS(4341),
    [anon_sym_While] = ACTIONS(4341),
    [anon_sym_repeat] = ACTIONS(4341),
    [anon_sym_REPEAT] = ACTIONS(4341),
    [anon_sym_Repeat] = ACTIONS(4341),
    [anon_sym_exit] = ACTIONS(4341),
    [anon_sym_EXIT] = ACTIONS(4341),
    [anon_sym_Exit] = ACTIONS(4341),
    [anon_sym_continue] = ACTIONS(4341),
    [anon_sym_CONTINUE] = ACTIONS(4341),
    [anon_sym_Continue] = ACTIONS(4341),
    [anon_sym_break] = ACTIONS(4341),
    [anon_sym_BREAK] = ACTIONS(4341),
    [anon_sym_Break] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4341),
    [anon_sym_WITH] = ACTIONS(4341),
    [anon_sym_With] = ACTIONS(4341),
    [sym_asserterror_keyword] = ACTIONS(4343),
    [sym_page_keyword] = ACTIONS(4341),
    [anon_sym_codeunit] = ACTIONS(4341),
    [anon_sym_CODEUNIT] = ACTIONS(4341),
    [anon_sym_Codeunit] = ACTIONS(4341),
    [anon_sym_CodeUnit] = ACTIONS(4341),
    [anon_sym_COdeunit] = ACTIONS(4341),
    [anon_sym_codeUnit] = ACTIONS(4341),
    [sym_report_keyword] = ACTIONS(4341),
    [sym_query_keyword] = ACTIONS(4341),
    [anon_sym_xmlport] = ACTIONS(4341),
    [anon_sym_XMLPORT] = ACTIONS(4341),
    [anon_sym_Xmlport] = ACTIONS(4341),
    [anon_sym_XMLport] = ACTIONS(4341),
    [anon_sym_XMLPort] = ACTIONS(4341),
    [anon_sym_XmlPort] = ACTIONS(4341),
    [anon_sym_enum] = ACTIONS(4341),
    [anon_sym_ENUM] = ACTIONS(4341),
    [anon_sym_Enum] = ACTIONS(4341),
    [anon_sym_eNUM] = ACTIONS(4341),
    [anon_sym_eNum] = ACTIONS(4341),
    [anon_sym_ENum] = ACTIONS(4341),
    [sym_quoted_identifier] = ACTIONS(4343),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4343),
    [sym_integer] = ACTIONS(4341),
    [sym_continue_as_identifier] = ACTIONS(4343),
    [sym_preproc_open] = ACTIONS(4343),
    [sym_preproc_close] = ACTIONS(4343),
  },
  [STATE(1590)] = {
    [sym_identifier] = ACTIONS(4345),
    [anon_sym_SEMI] = ACTIONS(4347),
    [anon_sym_DASH] = ACTIONS(4347),
    [aux_sym_boolean_token1] = ACTIONS(4345),
    [aux_sym_boolean_token2] = ACTIONS(4345),
    [sym_decimal] = ACTIONS(4345),
    [anon_sym_LPAREN] = ACTIONS(4347),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4345),
    [anon_sym_LBRACK] = ACTIONS(4347),
    [aux_sym_record_type_token1] = ACTIONS(4345),
    [aux_sym_basic_type_token21] = ACTIONS(4345),
    [aux_sym_basic_type_token22] = ACTIONS(4345),
    [aux_sym_basic_type_token48] = ACTIONS(4345),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4345),
    [anon_sym_POUNDif] = ACTIONS(4347),
    [anon_sym_POUNDIF] = ACTIONS(4347),
    [anon_sym_POUNDIf] = ACTIONS(4347),
    [anon_sym_not] = ACTIONS(4345),
    [anon_sym_NOT] = ACTIONS(4345),
    [anon_sym_Not] = ACTIONS(4345),
    [anon_sym_POUNDelif] = ACTIONS(4347),
    [anon_sym_POUNDELIF] = ACTIONS(4347),
    [anon_sym_POUNDElif] = ACTIONS(4347),
    [anon_sym_POUNDelse] = ACTIONS(4347),
    [anon_sym_POUNDELSE] = ACTIONS(4347),
    [anon_sym_POUNDElse] = ACTIONS(4347),
    [anon_sym_POUNDendif] = ACTIONS(4347),
    [anon_sym_POUNDENDIF] = ACTIONS(4347),
    [anon_sym_POUNDEndif] = ACTIONS(4347),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4345),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4345),
    [anon_sym_PLUS] = ACTIONS(4347),
    [sym_datetime_literal] = ACTIONS(4347),
    [sym_date_literal] = ACTIONS(4345),
    [sym_time_literal] = ACTIONS(4345),
    [sym_biginteger_literal] = ACTIONS(4347),
    [anon_sym_if] = ACTIONS(4345),
    [anon_sym_IF] = ACTIONS(4345),
    [anon_sym_If] = ACTIONS(4345),
    [anon_sym_else] = ACTIONS(4345),
    [anon_sym_ELSE] = ACTIONS(4345),
    [anon_sym_Else] = ACTIONS(4345),
    [anon_sym_case] = ACTIONS(4345),
    [anon_sym_CASE] = ACTIONS(4345),
    [anon_sym_Case] = ACTIONS(4345),
    [anon_sym_for] = ACTIONS(4345),
    [anon_sym_FOR] = ACTIONS(4345),
    [anon_sym_For] = ACTIONS(4345),
    [anon_sym_foreach] = ACTIONS(4345),
    [anon_sym_FOREACH] = ACTIONS(4345),
    [anon_sym_Foreach] = ACTIONS(4345),
    [anon_sym_while] = ACTIONS(4345),
    [anon_sym_WHILE] = ACTIONS(4345),
    [anon_sym_While] = ACTIONS(4345),
    [anon_sym_repeat] = ACTIONS(4345),
    [anon_sym_REPEAT] = ACTIONS(4345),
    [anon_sym_Repeat] = ACTIONS(4345),
    [anon_sym_exit] = ACTIONS(4345),
    [anon_sym_EXIT] = ACTIONS(4345),
    [anon_sym_Exit] = ACTIONS(4345),
    [anon_sym_continue] = ACTIONS(4345),
    [anon_sym_CONTINUE] = ACTIONS(4345),
    [anon_sym_Continue] = ACTIONS(4345),
    [anon_sym_break] = ACTIONS(4345),
    [anon_sym_BREAK] = ACTIONS(4345),
    [anon_sym_Break] = ACTIONS(4345),
    [anon_sym_with] = ACTIONS(4345),
    [anon_sym_WITH] = ACTIONS(4345),
    [anon_sym_With] = ACTIONS(4345),
    [sym_asserterror_keyword] = ACTIONS(4347),
    [sym_page_keyword] = ACTIONS(4345),
    [anon_sym_codeunit] = ACTIONS(4345),
    [anon_sym_CODEUNIT] = ACTIONS(4345),
    [anon_sym_Codeunit] = ACTIONS(4345),
    [anon_sym_CodeUnit] = ACTIONS(4345),
    [anon_sym_COdeunit] = ACTIONS(4345),
    [anon_sym_codeUnit] = ACTIONS(4345),
    [sym_report_keyword] = ACTIONS(4345),
    [sym_query_keyword] = ACTIONS(4345),
    [anon_sym_xmlport] = ACTIONS(4345),
    [anon_sym_XMLPORT] = ACTIONS(4345),
    [anon_sym_Xmlport] = ACTIONS(4345),
    [anon_sym_XMLport] = ACTIONS(4345),
    [anon_sym_XMLPort] = ACTIONS(4345),
    [anon_sym_XmlPort] = ACTIONS(4345),
    [anon_sym_enum] = ACTIONS(4345),
    [anon_sym_ENUM] = ACTIONS(4345),
    [anon_sym_Enum] = ACTIONS(4345),
    [anon_sym_eNUM] = ACTIONS(4345),
    [anon_sym_eNum] = ACTIONS(4345),
    [anon_sym_ENum] = ACTIONS(4345),
    [sym_quoted_identifier] = ACTIONS(4347),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4347),
    [sym_integer] = ACTIONS(4345),
    [sym_continue_as_identifier] = ACTIONS(4347),
    [sym_preproc_open] = ACTIONS(4347),
    [sym_preproc_close] = ACTIONS(4347),
  },
  [STATE(1591)] = {
    [sym_identifier] = ACTIONS(4349),
    [anon_sym_SEMI] = ACTIONS(4351),
    [anon_sym_DASH] = ACTIONS(4351),
    [aux_sym_boolean_token1] = ACTIONS(4349),
    [aux_sym_boolean_token2] = ACTIONS(4349),
    [sym_decimal] = ACTIONS(4349),
    [anon_sym_LPAREN] = ACTIONS(4351),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4349),
    [anon_sym_LBRACK] = ACTIONS(4351),
    [aux_sym_record_type_token1] = ACTIONS(4349),
    [aux_sym_basic_type_token21] = ACTIONS(4349),
    [aux_sym_basic_type_token22] = ACTIONS(4349),
    [aux_sym_basic_type_token48] = ACTIONS(4349),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4349),
    [anon_sym_POUNDif] = ACTIONS(4351),
    [anon_sym_POUNDIF] = ACTIONS(4351),
    [anon_sym_POUNDIf] = ACTIONS(4351),
    [anon_sym_not] = ACTIONS(4349),
    [anon_sym_NOT] = ACTIONS(4349),
    [anon_sym_Not] = ACTIONS(4349),
    [anon_sym_POUNDelif] = ACTIONS(4351),
    [anon_sym_POUNDELIF] = ACTIONS(4351),
    [anon_sym_POUNDElif] = ACTIONS(4351),
    [anon_sym_POUNDelse] = ACTIONS(4351),
    [anon_sym_POUNDELSE] = ACTIONS(4351),
    [anon_sym_POUNDElse] = ACTIONS(4351),
    [anon_sym_POUNDendif] = ACTIONS(4351),
    [anon_sym_POUNDENDIF] = ACTIONS(4351),
    [anon_sym_POUNDEndif] = ACTIONS(4351),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4349),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4349),
    [anon_sym_PLUS] = ACTIONS(4351),
    [sym_datetime_literal] = ACTIONS(4351),
    [sym_date_literal] = ACTIONS(4349),
    [sym_time_literal] = ACTIONS(4349),
    [sym_biginteger_literal] = ACTIONS(4351),
    [anon_sym_if] = ACTIONS(4349),
    [anon_sym_IF] = ACTIONS(4349),
    [anon_sym_If] = ACTIONS(4349),
    [anon_sym_else] = ACTIONS(4349),
    [anon_sym_ELSE] = ACTIONS(4349),
    [anon_sym_Else] = ACTIONS(4349),
    [anon_sym_case] = ACTIONS(4349),
    [anon_sym_CASE] = ACTIONS(4349),
    [anon_sym_Case] = ACTIONS(4349),
    [anon_sym_for] = ACTIONS(4349),
    [anon_sym_FOR] = ACTIONS(4349),
    [anon_sym_For] = ACTIONS(4349),
    [anon_sym_foreach] = ACTIONS(4349),
    [anon_sym_FOREACH] = ACTIONS(4349),
    [anon_sym_Foreach] = ACTIONS(4349),
    [anon_sym_while] = ACTIONS(4349),
    [anon_sym_WHILE] = ACTIONS(4349),
    [anon_sym_While] = ACTIONS(4349),
    [anon_sym_repeat] = ACTIONS(4349),
    [anon_sym_REPEAT] = ACTIONS(4349),
    [anon_sym_Repeat] = ACTIONS(4349),
    [anon_sym_exit] = ACTIONS(4349),
    [anon_sym_EXIT] = ACTIONS(4349),
    [anon_sym_Exit] = ACTIONS(4349),
    [anon_sym_continue] = ACTIONS(4349),
    [anon_sym_CONTINUE] = ACTIONS(4349),
    [anon_sym_Continue] = ACTIONS(4349),
    [anon_sym_break] = ACTIONS(4349),
    [anon_sym_BREAK] = ACTIONS(4349),
    [anon_sym_Break] = ACTIONS(4349),
    [anon_sym_with] = ACTIONS(4349),
    [anon_sym_WITH] = ACTIONS(4349),
    [anon_sym_With] = ACTIONS(4349),
    [sym_asserterror_keyword] = ACTIONS(4351),
    [sym_page_keyword] = ACTIONS(4349),
    [anon_sym_codeunit] = ACTIONS(4349),
    [anon_sym_CODEUNIT] = ACTIONS(4349),
    [anon_sym_Codeunit] = ACTIONS(4349),
    [anon_sym_CodeUnit] = ACTIONS(4349),
    [anon_sym_COdeunit] = ACTIONS(4349),
    [anon_sym_codeUnit] = ACTIONS(4349),
    [sym_report_keyword] = ACTIONS(4349),
    [sym_query_keyword] = ACTIONS(4349),
    [anon_sym_xmlport] = ACTIONS(4349),
    [anon_sym_XMLPORT] = ACTIONS(4349),
    [anon_sym_Xmlport] = ACTIONS(4349),
    [anon_sym_XMLport] = ACTIONS(4349),
    [anon_sym_XMLPort] = ACTIONS(4349),
    [anon_sym_XmlPort] = ACTIONS(4349),
    [anon_sym_enum] = ACTIONS(4349),
    [anon_sym_ENUM] = ACTIONS(4349),
    [anon_sym_Enum] = ACTIONS(4349),
    [anon_sym_eNUM] = ACTIONS(4349),
    [anon_sym_eNum] = ACTIONS(4349),
    [anon_sym_ENum] = ACTIONS(4349),
    [sym_quoted_identifier] = ACTIONS(4351),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4351),
    [sym_integer] = ACTIONS(4349),
    [sym_continue_as_identifier] = ACTIONS(4351),
    [sym_preproc_open] = ACTIONS(4351),
    [sym_preproc_close] = ACTIONS(4351),
  },
  [STATE(1592)] = {
    [sym_identifier] = ACTIONS(4353),
    [anon_sym_SEMI] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [aux_sym_boolean_token1] = ACTIONS(4353),
    [aux_sym_boolean_token2] = ACTIONS(4353),
    [sym_decimal] = ACTIONS(4353),
    [anon_sym_LPAREN] = ACTIONS(4355),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4353),
    [anon_sym_LBRACK] = ACTIONS(4355),
    [aux_sym_record_type_token1] = ACTIONS(4353),
    [aux_sym_basic_type_token21] = ACTIONS(4353),
    [aux_sym_basic_type_token22] = ACTIONS(4353),
    [aux_sym_basic_type_token48] = ACTIONS(4353),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4353),
    [anon_sym_POUNDif] = ACTIONS(4355),
    [anon_sym_POUNDIF] = ACTIONS(4355),
    [anon_sym_POUNDIf] = ACTIONS(4355),
    [anon_sym_not] = ACTIONS(4353),
    [anon_sym_NOT] = ACTIONS(4353),
    [anon_sym_Not] = ACTIONS(4353),
    [anon_sym_POUNDelif] = ACTIONS(4355),
    [anon_sym_POUNDELIF] = ACTIONS(4355),
    [anon_sym_POUNDElif] = ACTIONS(4355),
    [anon_sym_POUNDelse] = ACTIONS(4355),
    [anon_sym_POUNDELSE] = ACTIONS(4355),
    [anon_sym_POUNDElse] = ACTIONS(4355),
    [anon_sym_POUNDendif] = ACTIONS(4355),
    [anon_sym_POUNDENDIF] = ACTIONS(4355),
    [anon_sym_POUNDEndif] = ACTIONS(4355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4353),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4353),
    [anon_sym_PLUS] = ACTIONS(4355),
    [sym_datetime_literal] = ACTIONS(4355),
    [sym_date_literal] = ACTIONS(4353),
    [sym_time_literal] = ACTIONS(4353),
    [sym_biginteger_literal] = ACTIONS(4355),
    [anon_sym_if] = ACTIONS(4353),
    [anon_sym_IF] = ACTIONS(4353),
    [anon_sym_If] = ACTIONS(4353),
    [anon_sym_else] = ACTIONS(4353),
    [anon_sym_ELSE] = ACTIONS(4353),
    [anon_sym_Else] = ACTIONS(4353),
    [anon_sym_case] = ACTIONS(4353),
    [anon_sym_CASE] = ACTIONS(4353),
    [anon_sym_Case] = ACTIONS(4353),
    [anon_sym_for] = ACTIONS(4353),
    [anon_sym_FOR] = ACTIONS(4353),
    [anon_sym_For] = ACTIONS(4353),
    [anon_sym_foreach] = ACTIONS(4353),
    [anon_sym_FOREACH] = ACTIONS(4353),
    [anon_sym_Foreach] = ACTIONS(4353),
    [anon_sym_while] = ACTIONS(4353),
    [anon_sym_WHILE] = ACTIONS(4353),
    [anon_sym_While] = ACTIONS(4353),
    [anon_sym_repeat] = ACTIONS(4353),
    [anon_sym_REPEAT] = ACTIONS(4353),
    [anon_sym_Repeat] = ACTIONS(4353),
    [anon_sym_exit] = ACTIONS(4353),
    [anon_sym_EXIT] = ACTIONS(4353),
    [anon_sym_Exit] = ACTIONS(4353),
    [anon_sym_continue] = ACTIONS(4353),
    [anon_sym_CONTINUE] = ACTIONS(4353),
    [anon_sym_Continue] = ACTIONS(4353),
    [anon_sym_break] = ACTIONS(4353),
    [anon_sym_BREAK] = ACTIONS(4353),
    [anon_sym_Break] = ACTIONS(4353),
    [anon_sym_with] = ACTIONS(4353),
    [anon_sym_WITH] = ACTIONS(4353),
    [anon_sym_With] = ACTIONS(4353),
    [sym_asserterror_keyword] = ACTIONS(4355),
    [sym_page_keyword] = ACTIONS(4353),
    [anon_sym_codeunit] = ACTIONS(4353),
    [anon_sym_CODEUNIT] = ACTIONS(4353),
    [anon_sym_Codeunit] = ACTIONS(4353),
    [anon_sym_CodeUnit] = ACTIONS(4353),
    [anon_sym_COdeunit] = ACTIONS(4353),
    [anon_sym_codeUnit] = ACTIONS(4353),
    [sym_report_keyword] = ACTIONS(4353),
    [sym_query_keyword] = ACTIONS(4353),
    [anon_sym_xmlport] = ACTIONS(4353),
    [anon_sym_XMLPORT] = ACTIONS(4353),
    [anon_sym_Xmlport] = ACTIONS(4353),
    [anon_sym_XMLport] = ACTIONS(4353),
    [anon_sym_XMLPort] = ACTIONS(4353),
    [anon_sym_XmlPort] = ACTIONS(4353),
    [anon_sym_enum] = ACTIONS(4353),
    [anon_sym_ENUM] = ACTIONS(4353),
    [anon_sym_Enum] = ACTIONS(4353),
    [anon_sym_eNUM] = ACTIONS(4353),
    [anon_sym_eNum] = ACTIONS(4353),
    [anon_sym_ENum] = ACTIONS(4353),
    [sym_quoted_identifier] = ACTIONS(4355),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4355),
    [sym_integer] = ACTIONS(4353),
    [sym_continue_as_identifier] = ACTIONS(4355),
    [sym_preproc_open] = ACTIONS(4355),
    [sym_preproc_close] = ACTIONS(4355),
  },
  [STATE(1593)] = {
    [sym_identifier] = ACTIONS(4357),
    [anon_sym_SEMI] = ACTIONS(4359),
    [anon_sym_DASH] = ACTIONS(4359),
    [aux_sym_boolean_token1] = ACTIONS(4357),
    [aux_sym_boolean_token2] = ACTIONS(4357),
    [sym_decimal] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4359),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4357),
    [anon_sym_LBRACK] = ACTIONS(4359),
    [aux_sym_record_type_token1] = ACTIONS(4357),
    [aux_sym_basic_type_token21] = ACTIONS(4357),
    [aux_sym_basic_type_token22] = ACTIONS(4357),
    [aux_sym_basic_type_token48] = ACTIONS(4357),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4357),
    [anon_sym_POUNDif] = ACTIONS(4359),
    [anon_sym_POUNDIF] = ACTIONS(4359),
    [anon_sym_POUNDIf] = ACTIONS(4359),
    [anon_sym_not] = ACTIONS(4357),
    [anon_sym_NOT] = ACTIONS(4357),
    [anon_sym_Not] = ACTIONS(4357),
    [anon_sym_POUNDelif] = ACTIONS(4359),
    [anon_sym_POUNDELIF] = ACTIONS(4359),
    [anon_sym_POUNDElif] = ACTIONS(4359),
    [anon_sym_POUNDelse] = ACTIONS(4359),
    [anon_sym_POUNDELSE] = ACTIONS(4359),
    [anon_sym_POUNDElse] = ACTIONS(4359),
    [anon_sym_POUNDendif] = ACTIONS(4359),
    [anon_sym_POUNDENDIF] = ACTIONS(4359),
    [anon_sym_POUNDEndif] = ACTIONS(4359),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4357),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4359),
    [sym_datetime_literal] = ACTIONS(4359),
    [sym_date_literal] = ACTIONS(4357),
    [sym_time_literal] = ACTIONS(4357),
    [sym_biginteger_literal] = ACTIONS(4359),
    [anon_sym_if] = ACTIONS(4357),
    [anon_sym_IF] = ACTIONS(4357),
    [anon_sym_If] = ACTIONS(4357),
    [anon_sym_else] = ACTIONS(4357),
    [anon_sym_ELSE] = ACTIONS(4357),
    [anon_sym_Else] = ACTIONS(4357),
    [anon_sym_case] = ACTIONS(4357),
    [anon_sym_CASE] = ACTIONS(4357),
    [anon_sym_Case] = ACTIONS(4357),
    [anon_sym_for] = ACTIONS(4357),
    [anon_sym_FOR] = ACTIONS(4357),
    [anon_sym_For] = ACTIONS(4357),
    [anon_sym_foreach] = ACTIONS(4357),
    [anon_sym_FOREACH] = ACTIONS(4357),
    [anon_sym_Foreach] = ACTIONS(4357),
    [anon_sym_while] = ACTIONS(4357),
    [anon_sym_WHILE] = ACTIONS(4357),
    [anon_sym_While] = ACTIONS(4357),
    [anon_sym_repeat] = ACTIONS(4357),
    [anon_sym_REPEAT] = ACTIONS(4357),
    [anon_sym_Repeat] = ACTIONS(4357),
    [anon_sym_exit] = ACTIONS(4357),
    [anon_sym_EXIT] = ACTIONS(4357),
    [anon_sym_Exit] = ACTIONS(4357),
    [anon_sym_continue] = ACTIONS(4357),
    [anon_sym_CONTINUE] = ACTIONS(4357),
    [anon_sym_Continue] = ACTIONS(4357),
    [anon_sym_break] = ACTIONS(4357),
    [anon_sym_BREAK] = ACTIONS(4357),
    [anon_sym_Break] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4357),
    [anon_sym_WITH] = ACTIONS(4357),
    [anon_sym_With] = ACTIONS(4357),
    [sym_asserterror_keyword] = ACTIONS(4359),
    [sym_page_keyword] = ACTIONS(4357),
    [anon_sym_codeunit] = ACTIONS(4357),
    [anon_sym_CODEUNIT] = ACTIONS(4357),
    [anon_sym_Codeunit] = ACTIONS(4357),
    [anon_sym_CodeUnit] = ACTIONS(4357),
    [anon_sym_COdeunit] = ACTIONS(4357),
    [anon_sym_codeUnit] = ACTIONS(4357),
    [sym_report_keyword] = ACTIONS(4357),
    [sym_query_keyword] = ACTIONS(4357),
    [anon_sym_xmlport] = ACTIONS(4357),
    [anon_sym_XMLPORT] = ACTIONS(4357),
    [anon_sym_Xmlport] = ACTIONS(4357),
    [anon_sym_XMLport] = ACTIONS(4357),
    [anon_sym_XMLPort] = ACTIONS(4357),
    [anon_sym_XmlPort] = ACTIONS(4357),
    [anon_sym_enum] = ACTIONS(4357),
    [anon_sym_ENUM] = ACTIONS(4357),
    [anon_sym_Enum] = ACTIONS(4357),
    [anon_sym_eNUM] = ACTIONS(4357),
    [anon_sym_eNum] = ACTIONS(4357),
    [anon_sym_ENum] = ACTIONS(4357),
    [sym_quoted_identifier] = ACTIONS(4359),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4359),
    [sym_integer] = ACTIONS(4357),
    [sym_continue_as_identifier] = ACTIONS(4359),
    [sym_preproc_open] = ACTIONS(4359),
    [sym_preproc_close] = ACTIONS(4359),
  },
  [STATE(1594)] = {
    [sym_identifier] = ACTIONS(4361),
    [anon_sym_SEMI] = ACTIONS(4363),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(4361),
    [aux_sym_boolean_token2] = ACTIONS(4361),
    [sym_decimal] = ACTIONS(4361),
    [anon_sym_LPAREN] = ACTIONS(4363),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4361),
    [anon_sym_LBRACK] = ACTIONS(4363),
    [aux_sym_record_type_token1] = ACTIONS(4361),
    [aux_sym_basic_type_token21] = ACTIONS(4361),
    [aux_sym_basic_type_token22] = ACTIONS(4361),
    [aux_sym_basic_type_token48] = ACTIONS(4361),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4361),
    [anon_sym_POUNDif] = ACTIONS(4363),
    [anon_sym_POUNDIF] = ACTIONS(4363),
    [anon_sym_POUNDIf] = ACTIONS(4363),
    [anon_sym_not] = ACTIONS(4361),
    [anon_sym_NOT] = ACTIONS(4361),
    [anon_sym_Not] = ACTIONS(4361),
    [anon_sym_POUNDelif] = ACTIONS(4363),
    [anon_sym_POUNDELIF] = ACTIONS(4363),
    [anon_sym_POUNDElif] = ACTIONS(4363),
    [anon_sym_POUNDelse] = ACTIONS(4363),
    [anon_sym_POUNDELSE] = ACTIONS(4363),
    [anon_sym_POUNDElse] = ACTIONS(4363),
    [anon_sym_POUNDendif] = ACTIONS(4363),
    [anon_sym_POUNDENDIF] = ACTIONS(4363),
    [anon_sym_POUNDEndif] = ACTIONS(4363),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4361),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4361),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4363),
    [sym_date_literal] = ACTIONS(4361),
    [sym_time_literal] = ACTIONS(4361),
    [sym_biginteger_literal] = ACTIONS(4363),
    [anon_sym_if] = ACTIONS(4361),
    [anon_sym_IF] = ACTIONS(4361),
    [anon_sym_If] = ACTIONS(4361),
    [anon_sym_else] = ACTIONS(4361),
    [anon_sym_ELSE] = ACTIONS(4361),
    [anon_sym_Else] = ACTIONS(4361),
    [anon_sym_case] = ACTIONS(4361),
    [anon_sym_CASE] = ACTIONS(4361),
    [anon_sym_Case] = ACTIONS(4361),
    [anon_sym_for] = ACTIONS(4361),
    [anon_sym_FOR] = ACTIONS(4361),
    [anon_sym_For] = ACTIONS(4361),
    [anon_sym_foreach] = ACTIONS(4361),
    [anon_sym_FOREACH] = ACTIONS(4361),
    [anon_sym_Foreach] = ACTIONS(4361),
    [anon_sym_while] = ACTIONS(4361),
    [anon_sym_WHILE] = ACTIONS(4361),
    [anon_sym_While] = ACTIONS(4361),
    [anon_sym_repeat] = ACTIONS(4361),
    [anon_sym_REPEAT] = ACTIONS(4361),
    [anon_sym_Repeat] = ACTIONS(4361),
    [anon_sym_exit] = ACTIONS(4361),
    [anon_sym_EXIT] = ACTIONS(4361),
    [anon_sym_Exit] = ACTIONS(4361),
    [anon_sym_continue] = ACTIONS(4361),
    [anon_sym_CONTINUE] = ACTIONS(4361),
    [anon_sym_Continue] = ACTIONS(4361),
    [anon_sym_break] = ACTIONS(4361),
    [anon_sym_BREAK] = ACTIONS(4361),
    [anon_sym_Break] = ACTIONS(4361),
    [anon_sym_with] = ACTIONS(4361),
    [anon_sym_WITH] = ACTIONS(4361),
    [anon_sym_With] = ACTIONS(4361),
    [sym_asserterror_keyword] = ACTIONS(4363),
    [sym_page_keyword] = ACTIONS(4361),
    [anon_sym_codeunit] = ACTIONS(4361),
    [anon_sym_CODEUNIT] = ACTIONS(4361),
    [anon_sym_Codeunit] = ACTIONS(4361),
    [anon_sym_CodeUnit] = ACTIONS(4361),
    [anon_sym_COdeunit] = ACTIONS(4361),
    [anon_sym_codeUnit] = ACTIONS(4361),
    [sym_report_keyword] = ACTIONS(4361),
    [sym_query_keyword] = ACTIONS(4361),
    [anon_sym_xmlport] = ACTIONS(4361),
    [anon_sym_XMLPORT] = ACTIONS(4361),
    [anon_sym_Xmlport] = ACTIONS(4361),
    [anon_sym_XMLport] = ACTIONS(4361),
    [anon_sym_XMLPort] = ACTIONS(4361),
    [anon_sym_XmlPort] = ACTIONS(4361),
    [anon_sym_enum] = ACTIONS(4361),
    [anon_sym_ENUM] = ACTIONS(4361),
    [anon_sym_Enum] = ACTIONS(4361),
    [anon_sym_eNUM] = ACTIONS(4361),
    [anon_sym_eNum] = ACTIONS(4361),
    [anon_sym_ENum] = ACTIONS(4361),
    [sym_quoted_identifier] = ACTIONS(4363),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4363),
    [sym_integer] = ACTIONS(4361),
    [sym_continue_as_identifier] = ACTIONS(4363),
    [sym_preproc_open] = ACTIONS(4363),
    [sym_preproc_close] = ACTIONS(4363),
  },
  [STATE(1595)] = {
    [sym_identifier] = ACTIONS(4365),
    [anon_sym_SEMI] = ACTIONS(4367),
    [anon_sym_DASH] = ACTIONS(4367),
    [aux_sym_boolean_token1] = ACTIONS(4365),
    [aux_sym_boolean_token2] = ACTIONS(4365),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4365),
    [anon_sym_LBRACK] = ACTIONS(4367),
    [aux_sym_record_type_token1] = ACTIONS(4365),
    [aux_sym_basic_type_token21] = ACTIONS(4365),
    [aux_sym_basic_type_token22] = ACTIONS(4365),
    [aux_sym_basic_type_token48] = ACTIONS(4365),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4365),
    [anon_sym_POUNDif] = ACTIONS(4367),
    [anon_sym_POUNDIF] = ACTIONS(4367),
    [anon_sym_POUNDIf] = ACTIONS(4367),
    [anon_sym_not] = ACTIONS(4365),
    [anon_sym_NOT] = ACTIONS(4365),
    [anon_sym_Not] = ACTIONS(4365),
    [anon_sym_POUNDelif] = ACTIONS(4367),
    [anon_sym_POUNDELIF] = ACTIONS(4367),
    [anon_sym_POUNDElif] = ACTIONS(4367),
    [anon_sym_POUNDelse] = ACTIONS(4367),
    [anon_sym_POUNDELSE] = ACTIONS(4367),
    [anon_sym_POUNDElse] = ACTIONS(4367),
    [anon_sym_POUNDendif] = ACTIONS(4367),
    [anon_sym_POUNDENDIF] = ACTIONS(4367),
    [anon_sym_POUNDEndif] = ACTIONS(4367),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4365),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4365),
    [anon_sym_PLUS] = ACTIONS(4367),
    [sym_datetime_literal] = ACTIONS(4367),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4367),
    [anon_sym_if] = ACTIONS(4365),
    [anon_sym_IF] = ACTIONS(4365),
    [anon_sym_If] = ACTIONS(4365),
    [anon_sym_else] = ACTIONS(4365),
    [anon_sym_ELSE] = ACTIONS(4365),
    [anon_sym_Else] = ACTIONS(4365),
    [anon_sym_case] = ACTIONS(4365),
    [anon_sym_CASE] = ACTIONS(4365),
    [anon_sym_Case] = ACTIONS(4365),
    [anon_sym_for] = ACTIONS(4365),
    [anon_sym_FOR] = ACTIONS(4365),
    [anon_sym_For] = ACTIONS(4365),
    [anon_sym_foreach] = ACTIONS(4365),
    [anon_sym_FOREACH] = ACTIONS(4365),
    [anon_sym_Foreach] = ACTIONS(4365),
    [anon_sym_while] = ACTIONS(4365),
    [anon_sym_WHILE] = ACTIONS(4365),
    [anon_sym_While] = ACTIONS(4365),
    [anon_sym_repeat] = ACTIONS(4365),
    [anon_sym_REPEAT] = ACTIONS(4365),
    [anon_sym_Repeat] = ACTIONS(4365),
    [anon_sym_exit] = ACTIONS(4365),
    [anon_sym_EXIT] = ACTIONS(4365),
    [anon_sym_Exit] = ACTIONS(4365),
    [anon_sym_continue] = ACTIONS(4365),
    [anon_sym_CONTINUE] = ACTIONS(4365),
    [anon_sym_Continue] = ACTIONS(4365),
    [anon_sym_break] = ACTIONS(4365),
    [anon_sym_BREAK] = ACTIONS(4365),
    [anon_sym_Break] = ACTIONS(4365),
    [anon_sym_with] = ACTIONS(4365),
    [anon_sym_WITH] = ACTIONS(4365),
    [anon_sym_With] = ACTIONS(4365),
    [sym_asserterror_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(4365),
    [anon_sym_codeunit] = ACTIONS(4365),
    [anon_sym_CODEUNIT] = ACTIONS(4365),
    [anon_sym_Codeunit] = ACTIONS(4365),
    [anon_sym_CodeUnit] = ACTIONS(4365),
    [anon_sym_COdeunit] = ACTIONS(4365),
    [anon_sym_codeUnit] = ACTIONS(4365),
    [sym_report_keyword] = ACTIONS(4365),
    [sym_query_keyword] = ACTIONS(4365),
    [anon_sym_xmlport] = ACTIONS(4365),
    [anon_sym_XMLPORT] = ACTIONS(4365),
    [anon_sym_Xmlport] = ACTIONS(4365),
    [anon_sym_XMLport] = ACTIONS(4365),
    [anon_sym_XMLPort] = ACTIONS(4365),
    [anon_sym_XmlPort] = ACTIONS(4365),
    [anon_sym_enum] = ACTIONS(4365),
    [anon_sym_ENUM] = ACTIONS(4365),
    [anon_sym_Enum] = ACTIONS(4365),
    [anon_sym_eNUM] = ACTIONS(4365),
    [anon_sym_eNum] = ACTIONS(4365),
    [anon_sym_ENum] = ACTIONS(4365),
    [sym_quoted_identifier] = ACTIONS(4367),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4367),
    [sym_integer] = ACTIONS(4365),
    [sym_continue_as_identifier] = ACTIONS(4367),
    [sym_preproc_open] = ACTIONS(4367),
    [sym_preproc_close] = ACTIONS(4367),
  },
  [STATE(1596)] = {
    [sym_identifier] = ACTIONS(4369),
    [anon_sym_SEMI] = ACTIONS(4371),
    [anon_sym_DASH] = ACTIONS(4371),
    [aux_sym_boolean_token1] = ACTIONS(4369),
    [aux_sym_boolean_token2] = ACTIONS(4369),
    [sym_decimal] = ACTIONS(4369),
    [anon_sym_LPAREN] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4369),
    [anon_sym_LBRACK] = ACTIONS(4371),
    [aux_sym_record_type_token1] = ACTIONS(4369),
    [aux_sym_basic_type_token21] = ACTIONS(4369),
    [aux_sym_basic_type_token22] = ACTIONS(4369),
    [aux_sym_basic_type_token48] = ACTIONS(4369),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4369),
    [anon_sym_POUNDif] = ACTIONS(4371),
    [anon_sym_POUNDIF] = ACTIONS(4371),
    [anon_sym_POUNDIf] = ACTIONS(4371),
    [anon_sym_not] = ACTIONS(4369),
    [anon_sym_NOT] = ACTIONS(4369),
    [anon_sym_Not] = ACTIONS(4369),
    [anon_sym_POUNDelif] = ACTIONS(4371),
    [anon_sym_POUNDELIF] = ACTIONS(4371),
    [anon_sym_POUNDElif] = ACTIONS(4371),
    [anon_sym_POUNDelse] = ACTIONS(4371),
    [anon_sym_POUNDELSE] = ACTIONS(4371),
    [anon_sym_POUNDElse] = ACTIONS(4371),
    [anon_sym_POUNDendif] = ACTIONS(4371),
    [anon_sym_POUNDENDIF] = ACTIONS(4371),
    [anon_sym_POUNDEndif] = ACTIONS(4371),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4369),
    [anon_sym_PLUS] = ACTIONS(4371),
    [sym_datetime_literal] = ACTIONS(4371),
    [sym_date_literal] = ACTIONS(4369),
    [sym_time_literal] = ACTIONS(4369),
    [sym_biginteger_literal] = ACTIONS(4371),
    [anon_sym_if] = ACTIONS(4369),
    [anon_sym_IF] = ACTIONS(4369),
    [anon_sym_If] = ACTIONS(4369),
    [anon_sym_else] = ACTIONS(4369),
    [anon_sym_ELSE] = ACTIONS(4369),
    [anon_sym_Else] = ACTIONS(4369),
    [anon_sym_case] = ACTIONS(4369),
    [anon_sym_CASE] = ACTIONS(4369),
    [anon_sym_Case] = ACTIONS(4369),
    [anon_sym_for] = ACTIONS(4369),
    [anon_sym_FOR] = ACTIONS(4369),
    [anon_sym_For] = ACTIONS(4369),
    [anon_sym_foreach] = ACTIONS(4369),
    [anon_sym_FOREACH] = ACTIONS(4369),
    [anon_sym_Foreach] = ACTIONS(4369),
    [anon_sym_while] = ACTIONS(4369),
    [anon_sym_WHILE] = ACTIONS(4369),
    [anon_sym_While] = ACTIONS(4369),
    [anon_sym_repeat] = ACTIONS(4369),
    [anon_sym_REPEAT] = ACTIONS(4369),
    [anon_sym_Repeat] = ACTIONS(4369),
    [anon_sym_exit] = ACTIONS(4369),
    [anon_sym_EXIT] = ACTIONS(4369),
    [anon_sym_Exit] = ACTIONS(4369),
    [anon_sym_continue] = ACTIONS(4369),
    [anon_sym_CONTINUE] = ACTIONS(4369),
    [anon_sym_Continue] = ACTIONS(4369),
    [anon_sym_break] = ACTIONS(4369),
    [anon_sym_BREAK] = ACTIONS(4369),
    [anon_sym_Break] = ACTIONS(4369),
    [anon_sym_with] = ACTIONS(4369),
    [anon_sym_WITH] = ACTIONS(4369),
    [anon_sym_With] = ACTIONS(4369),
    [sym_asserterror_keyword] = ACTIONS(4371),
    [sym_page_keyword] = ACTIONS(4369),
    [anon_sym_codeunit] = ACTIONS(4369),
    [anon_sym_CODEUNIT] = ACTIONS(4369),
    [anon_sym_Codeunit] = ACTIONS(4369),
    [anon_sym_CodeUnit] = ACTIONS(4369),
    [anon_sym_COdeunit] = ACTIONS(4369),
    [anon_sym_codeUnit] = ACTIONS(4369),
    [sym_report_keyword] = ACTIONS(4369),
    [sym_query_keyword] = ACTIONS(4369),
    [anon_sym_xmlport] = ACTIONS(4369),
    [anon_sym_XMLPORT] = ACTIONS(4369),
    [anon_sym_Xmlport] = ACTIONS(4369),
    [anon_sym_XMLport] = ACTIONS(4369),
    [anon_sym_XMLPort] = ACTIONS(4369),
    [anon_sym_XmlPort] = ACTIONS(4369),
    [anon_sym_enum] = ACTIONS(4369),
    [anon_sym_ENUM] = ACTIONS(4369),
    [anon_sym_Enum] = ACTIONS(4369),
    [anon_sym_eNUM] = ACTIONS(4369),
    [anon_sym_eNum] = ACTIONS(4369),
    [anon_sym_ENum] = ACTIONS(4369),
    [sym_quoted_identifier] = ACTIONS(4371),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4371),
    [sym_integer] = ACTIONS(4369),
    [sym_continue_as_identifier] = ACTIONS(4371),
    [sym_preproc_open] = ACTIONS(4371),
    [sym_preproc_close] = ACTIONS(4371),
  },
  [STATE(1597)] = {
    [sym_identifier] = ACTIONS(4373),
    [anon_sym_SEMI] = ACTIONS(4375),
    [anon_sym_DASH] = ACTIONS(4377),
    [aux_sym_boolean_token1] = ACTIONS(4373),
    [aux_sym_boolean_token2] = ACTIONS(4373),
    [sym_decimal] = ACTIONS(4373),
    [anon_sym_LPAREN] = ACTIONS(4377),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4373),
    [anon_sym_LBRACK] = ACTIONS(4377),
    [aux_sym_record_type_token1] = ACTIONS(4373),
    [aux_sym_basic_type_token21] = ACTIONS(4373),
    [aux_sym_basic_type_token22] = ACTIONS(4373),
    [aux_sym_basic_type_token48] = ACTIONS(4373),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4373),
    [anon_sym_POUNDif] = ACTIONS(4377),
    [anon_sym_POUNDIF] = ACTIONS(4377),
    [anon_sym_POUNDIf] = ACTIONS(4377),
    [anon_sym_not] = ACTIONS(4373),
    [anon_sym_NOT] = ACTIONS(4373),
    [anon_sym_Not] = ACTIONS(4373),
    [anon_sym_POUNDelif] = ACTIONS(4377),
    [anon_sym_POUNDELIF] = ACTIONS(4377),
    [anon_sym_POUNDElif] = ACTIONS(4377),
    [anon_sym_POUNDelse] = ACTIONS(4377),
    [anon_sym_POUNDELSE] = ACTIONS(4377),
    [anon_sym_POUNDElse] = ACTIONS(4377),
    [anon_sym_POUNDendif] = ACTIONS(4377),
    [anon_sym_POUNDENDIF] = ACTIONS(4377),
    [anon_sym_POUNDEndif] = ACTIONS(4377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4373),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4373),
    [anon_sym_PLUS] = ACTIONS(4377),
    [sym_datetime_literal] = ACTIONS(4377),
    [sym_date_literal] = ACTIONS(4373),
    [sym_time_literal] = ACTIONS(4373),
    [sym_biginteger_literal] = ACTIONS(4377),
    [anon_sym_if] = ACTIONS(4373),
    [anon_sym_IF] = ACTIONS(4373),
    [anon_sym_If] = ACTIONS(4373),
    [anon_sym_else] = ACTIONS(4373),
    [anon_sym_ELSE] = ACTIONS(4373),
    [anon_sym_Else] = ACTIONS(4373),
    [anon_sym_case] = ACTIONS(4373),
    [anon_sym_CASE] = ACTIONS(4373),
    [anon_sym_Case] = ACTIONS(4373),
    [anon_sym_for] = ACTIONS(4373),
    [anon_sym_FOR] = ACTIONS(4373),
    [anon_sym_For] = ACTIONS(4373),
    [anon_sym_foreach] = ACTIONS(4373),
    [anon_sym_FOREACH] = ACTIONS(4373),
    [anon_sym_Foreach] = ACTIONS(4373),
    [anon_sym_while] = ACTIONS(4373),
    [anon_sym_WHILE] = ACTIONS(4373),
    [anon_sym_While] = ACTIONS(4373),
    [anon_sym_repeat] = ACTIONS(4373),
    [anon_sym_REPEAT] = ACTIONS(4373),
    [anon_sym_Repeat] = ACTIONS(4373),
    [anon_sym_exit] = ACTIONS(4373),
    [anon_sym_EXIT] = ACTIONS(4373),
    [anon_sym_Exit] = ACTIONS(4373),
    [anon_sym_continue] = ACTIONS(4373),
    [anon_sym_CONTINUE] = ACTIONS(4373),
    [anon_sym_Continue] = ACTIONS(4373),
    [anon_sym_break] = ACTIONS(4373),
    [anon_sym_BREAK] = ACTIONS(4373),
    [anon_sym_Break] = ACTIONS(4373),
    [anon_sym_with] = ACTIONS(4373),
    [anon_sym_WITH] = ACTIONS(4373),
    [anon_sym_With] = ACTIONS(4373),
    [sym_asserterror_keyword] = ACTIONS(4377),
    [sym_page_keyword] = ACTIONS(4373),
    [anon_sym_codeunit] = ACTIONS(4373),
    [anon_sym_CODEUNIT] = ACTIONS(4373),
    [anon_sym_Codeunit] = ACTIONS(4373),
    [anon_sym_CodeUnit] = ACTIONS(4373),
    [anon_sym_COdeunit] = ACTIONS(4373),
    [anon_sym_codeUnit] = ACTIONS(4373),
    [sym_report_keyword] = ACTIONS(4373),
    [sym_query_keyword] = ACTIONS(4373),
    [anon_sym_xmlport] = ACTIONS(4373),
    [anon_sym_XMLPORT] = ACTIONS(4373),
    [anon_sym_Xmlport] = ACTIONS(4373),
    [anon_sym_XMLport] = ACTIONS(4373),
    [anon_sym_XMLPort] = ACTIONS(4373),
    [anon_sym_XmlPort] = ACTIONS(4373),
    [anon_sym_enum] = ACTIONS(4373),
    [anon_sym_ENUM] = ACTIONS(4373),
    [anon_sym_Enum] = ACTIONS(4373),
    [anon_sym_eNUM] = ACTIONS(4373),
    [anon_sym_eNum] = ACTIONS(4373),
    [anon_sym_ENum] = ACTIONS(4373),
    [sym_quoted_identifier] = ACTIONS(4377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4377),
    [sym_integer] = ACTIONS(4373),
    [sym_continue_as_identifier] = ACTIONS(4377),
    [sym_preproc_open] = ACTIONS(4377),
    [sym_preproc_close] = ACTIONS(4377),
  },
  [STATE(1598)] = {
    [sym_identifier] = ACTIONS(4373),
    [anon_sym_SEMI] = ACTIONS(4377),
    [anon_sym_DASH] = ACTIONS(4377),
    [aux_sym_boolean_token1] = ACTIONS(4373),
    [aux_sym_boolean_token2] = ACTIONS(4373),
    [sym_decimal] = ACTIONS(4373),
    [anon_sym_LPAREN] = ACTIONS(4377),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4373),
    [anon_sym_LBRACK] = ACTIONS(4377),
    [aux_sym_record_type_token1] = ACTIONS(4373),
    [aux_sym_basic_type_token21] = ACTIONS(4373),
    [aux_sym_basic_type_token22] = ACTIONS(4373),
    [aux_sym_basic_type_token48] = ACTIONS(4373),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4373),
    [anon_sym_POUNDif] = ACTIONS(4377),
    [anon_sym_POUNDIF] = ACTIONS(4377),
    [anon_sym_POUNDIf] = ACTIONS(4377),
    [anon_sym_not] = ACTIONS(4373),
    [anon_sym_NOT] = ACTIONS(4373),
    [anon_sym_Not] = ACTIONS(4373),
    [anon_sym_POUNDelif] = ACTIONS(4377),
    [anon_sym_POUNDELIF] = ACTIONS(4377),
    [anon_sym_POUNDElif] = ACTIONS(4377),
    [anon_sym_POUNDelse] = ACTIONS(4377),
    [anon_sym_POUNDELSE] = ACTIONS(4377),
    [anon_sym_POUNDElse] = ACTIONS(4377),
    [anon_sym_POUNDendif] = ACTIONS(4377),
    [anon_sym_POUNDENDIF] = ACTIONS(4377),
    [anon_sym_POUNDEndif] = ACTIONS(4377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4373),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4373),
    [anon_sym_PLUS] = ACTIONS(4377),
    [sym_datetime_literal] = ACTIONS(4377),
    [sym_date_literal] = ACTIONS(4373),
    [sym_time_literal] = ACTIONS(4373),
    [sym_biginteger_literal] = ACTIONS(4377),
    [anon_sym_if] = ACTIONS(4373),
    [anon_sym_IF] = ACTIONS(4373),
    [anon_sym_If] = ACTIONS(4373),
    [anon_sym_else] = ACTIONS(4373),
    [anon_sym_ELSE] = ACTIONS(4373),
    [anon_sym_Else] = ACTIONS(4373),
    [anon_sym_case] = ACTIONS(4373),
    [anon_sym_CASE] = ACTIONS(4373),
    [anon_sym_Case] = ACTIONS(4373),
    [anon_sym_for] = ACTIONS(4373),
    [anon_sym_FOR] = ACTIONS(4373),
    [anon_sym_For] = ACTIONS(4373),
    [anon_sym_foreach] = ACTIONS(4373),
    [anon_sym_FOREACH] = ACTIONS(4373),
    [anon_sym_Foreach] = ACTIONS(4373),
    [anon_sym_while] = ACTIONS(4373),
    [anon_sym_WHILE] = ACTIONS(4373),
    [anon_sym_While] = ACTIONS(4373),
    [anon_sym_repeat] = ACTIONS(4373),
    [anon_sym_REPEAT] = ACTIONS(4373),
    [anon_sym_Repeat] = ACTIONS(4373),
    [anon_sym_exit] = ACTIONS(4373),
    [anon_sym_EXIT] = ACTIONS(4373),
    [anon_sym_Exit] = ACTIONS(4373),
    [anon_sym_continue] = ACTIONS(4373),
    [anon_sym_CONTINUE] = ACTIONS(4373),
    [anon_sym_Continue] = ACTIONS(4373),
    [anon_sym_break] = ACTIONS(4373),
    [anon_sym_BREAK] = ACTIONS(4373),
    [anon_sym_Break] = ACTIONS(4373),
    [anon_sym_with] = ACTIONS(4373),
    [anon_sym_WITH] = ACTIONS(4373),
    [anon_sym_With] = ACTIONS(4373),
    [sym_asserterror_keyword] = ACTIONS(4377),
    [sym_page_keyword] = ACTIONS(4373),
    [anon_sym_codeunit] = ACTIONS(4373),
    [anon_sym_CODEUNIT] = ACTIONS(4373),
    [anon_sym_Codeunit] = ACTIONS(4373),
    [anon_sym_CodeUnit] = ACTIONS(4373),
    [anon_sym_COdeunit] = ACTIONS(4373),
    [anon_sym_codeUnit] = ACTIONS(4373),
    [sym_report_keyword] = ACTIONS(4373),
    [sym_query_keyword] = ACTIONS(4373),
    [anon_sym_xmlport] = ACTIONS(4373),
    [anon_sym_XMLPORT] = ACTIONS(4373),
    [anon_sym_Xmlport] = ACTIONS(4373),
    [anon_sym_XMLport] = ACTIONS(4373),
    [anon_sym_XMLPort] = ACTIONS(4373),
    [anon_sym_XmlPort] = ACTIONS(4373),
    [anon_sym_enum] = ACTIONS(4373),
    [anon_sym_ENUM] = ACTIONS(4373),
    [anon_sym_Enum] = ACTIONS(4373),
    [anon_sym_eNUM] = ACTIONS(4373),
    [anon_sym_eNum] = ACTIONS(4373),
    [anon_sym_ENum] = ACTIONS(4373),
    [sym_quoted_identifier] = ACTIONS(4377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4377),
    [sym_integer] = ACTIONS(4373),
    [sym_continue_as_identifier] = ACTIONS(4377),
    [sym_preproc_open] = ACTIONS(4377),
    [sym_preproc_close] = ACTIONS(4377),
  },
  [STATE(1599)] = {
    [sym_identifier] = ACTIONS(4379),
    [anon_sym_SEMI] = ACTIONS(4381),
    [anon_sym_DASH] = ACTIONS(4381),
    [aux_sym_boolean_token1] = ACTIONS(4379),
    [aux_sym_boolean_token2] = ACTIONS(4379),
    [sym_decimal] = ACTIONS(4379),
    [anon_sym_LPAREN] = ACTIONS(4381),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4379),
    [anon_sym_LBRACK] = ACTIONS(4381),
    [aux_sym_record_type_token1] = ACTIONS(4379),
    [aux_sym_basic_type_token21] = ACTIONS(4379),
    [aux_sym_basic_type_token22] = ACTIONS(4379),
    [aux_sym_basic_type_token48] = ACTIONS(4379),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4379),
    [anon_sym_POUNDif] = ACTIONS(4381),
    [anon_sym_POUNDIF] = ACTIONS(4381),
    [anon_sym_POUNDIf] = ACTIONS(4381),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4381),
    [anon_sym_POUNDELIF] = ACTIONS(4381),
    [anon_sym_POUNDElif] = ACTIONS(4381),
    [anon_sym_POUNDelse] = ACTIONS(4381),
    [anon_sym_POUNDELSE] = ACTIONS(4381),
    [anon_sym_POUNDElse] = ACTIONS(4381),
    [anon_sym_POUNDendif] = ACTIONS(4381),
    [anon_sym_POUNDENDIF] = ACTIONS(4381),
    [anon_sym_POUNDEndif] = ACTIONS(4381),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4379),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4379),
    [anon_sym_PLUS] = ACTIONS(4381),
    [sym_datetime_literal] = ACTIONS(4381),
    [sym_date_literal] = ACTIONS(4379),
    [sym_time_literal] = ACTIONS(4379),
    [sym_biginteger_literal] = ACTIONS(4381),
    [anon_sym_if] = ACTIONS(4379),
    [anon_sym_IF] = ACTIONS(4379),
    [anon_sym_If] = ACTIONS(4379),
    [anon_sym_else] = ACTIONS(4379),
    [anon_sym_ELSE] = ACTIONS(4379),
    [anon_sym_Else] = ACTIONS(4379),
    [anon_sym_case] = ACTIONS(4379),
    [anon_sym_CASE] = ACTIONS(4379),
    [anon_sym_Case] = ACTIONS(4379),
    [anon_sym_for] = ACTIONS(4379),
    [anon_sym_FOR] = ACTIONS(4379),
    [anon_sym_For] = ACTIONS(4379),
    [anon_sym_foreach] = ACTIONS(4379),
    [anon_sym_FOREACH] = ACTIONS(4379),
    [anon_sym_Foreach] = ACTIONS(4379),
    [anon_sym_while] = ACTIONS(4379),
    [anon_sym_WHILE] = ACTIONS(4379),
    [anon_sym_While] = ACTIONS(4379),
    [anon_sym_repeat] = ACTIONS(4379),
    [anon_sym_REPEAT] = ACTIONS(4379),
    [anon_sym_Repeat] = ACTIONS(4379),
    [anon_sym_exit] = ACTIONS(4379),
    [anon_sym_EXIT] = ACTIONS(4379),
    [anon_sym_Exit] = ACTIONS(4379),
    [anon_sym_continue] = ACTIONS(4379),
    [anon_sym_CONTINUE] = ACTIONS(4379),
    [anon_sym_Continue] = ACTIONS(4379),
    [anon_sym_break] = ACTIONS(4379),
    [anon_sym_BREAK] = ACTIONS(4379),
    [anon_sym_Break] = ACTIONS(4379),
    [anon_sym_with] = ACTIONS(4379),
    [anon_sym_WITH] = ACTIONS(4379),
    [anon_sym_With] = ACTIONS(4379),
    [sym_asserterror_keyword] = ACTIONS(4381),
    [sym_page_keyword] = ACTIONS(4379),
    [anon_sym_codeunit] = ACTIONS(4379),
    [anon_sym_CODEUNIT] = ACTIONS(4379),
    [anon_sym_Codeunit] = ACTIONS(4379),
    [anon_sym_CodeUnit] = ACTIONS(4379),
    [anon_sym_COdeunit] = ACTIONS(4379),
    [anon_sym_codeUnit] = ACTIONS(4379),
    [sym_report_keyword] = ACTIONS(4379),
    [sym_query_keyword] = ACTIONS(4379),
    [anon_sym_xmlport] = ACTIONS(4379),
    [anon_sym_XMLPORT] = ACTIONS(4379),
    [anon_sym_Xmlport] = ACTIONS(4379),
    [anon_sym_XMLport] = ACTIONS(4379),
    [anon_sym_XMLPort] = ACTIONS(4379),
    [anon_sym_XmlPort] = ACTIONS(4379),
    [anon_sym_enum] = ACTIONS(4379),
    [anon_sym_ENUM] = ACTIONS(4379),
    [anon_sym_Enum] = ACTIONS(4379),
    [anon_sym_eNUM] = ACTIONS(4379),
    [anon_sym_eNum] = ACTIONS(4379),
    [anon_sym_ENum] = ACTIONS(4379),
    [sym_quoted_identifier] = ACTIONS(4381),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4381),
    [sym_integer] = ACTIONS(4379),
    [sym_continue_as_identifier] = ACTIONS(4381),
    [sym_preproc_open] = ACTIONS(4381),
    [sym_preproc_close] = ACTIONS(4381),
  },
  [STATE(1600)] = {
    [sym_identifier] = ACTIONS(4383),
    [anon_sym_SEMI] = ACTIONS(4385),
    [anon_sym_DASH] = ACTIONS(4387),
    [aux_sym_boolean_token1] = ACTIONS(4383),
    [aux_sym_boolean_token2] = ACTIONS(4383),
    [sym_decimal] = ACTIONS(4383),
    [anon_sym_LPAREN] = ACTIONS(4387),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4383),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_record_type_token1] = ACTIONS(4383),
    [aux_sym_basic_type_token21] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_basic_type_token48] = ACTIONS(4383),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4383),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [anon_sym_not] = ACTIONS(4383),
    [anon_sym_NOT] = ACTIONS(4383),
    [anon_sym_Not] = ACTIONS(4383),
    [anon_sym_POUNDelif] = ACTIONS(4387),
    [anon_sym_POUNDELIF] = ACTIONS(4387),
    [anon_sym_POUNDElif] = ACTIONS(4387),
    [anon_sym_POUNDelse] = ACTIONS(4387),
    [anon_sym_POUNDELSE] = ACTIONS(4387),
    [anon_sym_POUNDElse] = ACTIONS(4387),
    [anon_sym_POUNDendif] = ACTIONS(4387),
    [anon_sym_POUNDENDIF] = ACTIONS(4387),
    [anon_sym_POUNDEndif] = ACTIONS(4387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4383),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4383),
    [anon_sym_PLUS] = ACTIONS(4387),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4383),
    [sym_time_literal] = ACTIONS(4383),
    [sym_biginteger_literal] = ACTIONS(4387),
    [anon_sym_if] = ACTIONS(4383),
    [anon_sym_IF] = ACTIONS(4383),
    [anon_sym_If] = ACTIONS(4383),
    [anon_sym_else] = ACTIONS(4383),
    [anon_sym_ELSE] = ACTIONS(4383),
    [anon_sym_Else] = ACTIONS(4383),
    [anon_sym_case] = ACTIONS(4383),
    [anon_sym_CASE] = ACTIONS(4383),
    [anon_sym_Case] = ACTIONS(4383),
    [anon_sym_for] = ACTIONS(4383),
    [anon_sym_FOR] = ACTIONS(4383),
    [anon_sym_For] = ACTIONS(4383),
    [anon_sym_foreach] = ACTIONS(4383),
    [anon_sym_FOREACH] = ACTIONS(4383),
    [anon_sym_Foreach] = ACTIONS(4383),
    [anon_sym_while] = ACTIONS(4383),
    [anon_sym_WHILE] = ACTIONS(4383),
    [anon_sym_While] = ACTIONS(4383),
    [anon_sym_repeat] = ACTIONS(4383),
    [anon_sym_REPEAT] = ACTIONS(4383),
    [anon_sym_Repeat] = ACTIONS(4383),
    [anon_sym_exit] = ACTIONS(4383),
    [anon_sym_EXIT] = ACTIONS(4383),
    [anon_sym_Exit] = ACTIONS(4383),
    [anon_sym_continue] = ACTIONS(4383),
    [anon_sym_CONTINUE] = ACTIONS(4383),
    [anon_sym_Continue] = ACTIONS(4383),
    [anon_sym_break] = ACTIONS(4383),
    [anon_sym_BREAK] = ACTIONS(4383),
    [anon_sym_Break] = ACTIONS(4383),
    [anon_sym_with] = ACTIONS(4383),
    [anon_sym_WITH] = ACTIONS(4383),
    [anon_sym_With] = ACTIONS(4383),
    [sym_asserterror_keyword] = ACTIONS(4387),
    [sym_page_keyword] = ACTIONS(4383),
    [anon_sym_codeunit] = ACTIONS(4383),
    [anon_sym_CODEUNIT] = ACTIONS(4383),
    [anon_sym_Codeunit] = ACTIONS(4383),
    [anon_sym_CodeUnit] = ACTIONS(4383),
    [anon_sym_COdeunit] = ACTIONS(4383),
    [anon_sym_codeUnit] = ACTIONS(4383),
    [sym_report_keyword] = ACTIONS(4383),
    [sym_query_keyword] = ACTIONS(4383),
    [anon_sym_xmlport] = ACTIONS(4383),
    [anon_sym_XMLPORT] = ACTIONS(4383),
    [anon_sym_Xmlport] = ACTIONS(4383),
    [anon_sym_XMLport] = ACTIONS(4383),
    [anon_sym_XMLPort] = ACTIONS(4383),
    [anon_sym_XmlPort] = ACTIONS(4383),
    [anon_sym_enum] = ACTIONS(4383),
    [anon_sym_ENUM] = ACTIONS(4383),
    [anon_sym_Enum] = ACTIONS(4383),
    [anon_sym_eNUM] = ACTIONS(4383),
    [anon_sym_eNum] = ACTIONS(4383),
    [anon_sym_ENum] = ACTIONS(4383),
    [sym_quoted_identifier] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4383),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
    [sym_preproc_close] = ACTIONS(4387),
  },
  [STATE(1601)] = {
    [sym_identifier] = ACTIONS(4383),
    [anon_sym_SEMI] = ACTIONS(4389),
    [anon_sym_DASH] = ACTIONS(4387),
    [aux_sym_boolean_token1] = ACTIONS(4383),
    [aux_sym_boolean_token2] = ACTIONS(4383),
    [sym_decimal] = ACTIONS(4383),
    [anon_sym_LPAREN] = ACTIONS(4387),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4383),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_record_type_token1] = ACTIONS(4383),
    [aux_sym_basic_type_token21] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_basic_type_token48] = ACTIONS(4383),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4383),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [anon_sym_not] = ACTIONS(4383),
    [anon_sym_NOT] = ACTIONS(4383),
    [anon_sym_Not] = ACTIONS(4383),
    [anon_sym_POUNDelif] = ACTIONS(4387),
    [anon_sym_POUNDELIF] = ACTIONS(4387),
    [anon_sym_POUNDElif] = ACTIONS(4387),
    [anon_sym_POUNDelse] = ACTIONS(4387),
    [anon_sym_POUNDELSE] = ACTIONS(4387),
    [anon_sym_POUNDElse] = ACTIONS(4387),
    [anon_sym_POUNDendif] = ACTIONS(4387),
    [anon_sym_POUNDENDIF] = ACTIONS(4387),
    [anon_sym_POUNDEndif] = ACTIONS(4387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4383),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4383),
    [anon_sym_PLUS] = ACTIONS(4387),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4383),
    [sym_time_literal] = ACTIONS(4383),
    [sym_biginteger_literal] = ACTIONS(4387),
    [anon_sym_if] = ACTIONS(4383),
    [anon_sym_IF] = ACTIONS(4383),
    [anon_sym_If] = ACTIONS(4383),
    [anon_sym_else] = ACTIONS(4383),
    [anon_sym_ELSE] = ACTIONS(4383),
    [anon_sym_Else] = ACTIONS(4383),
    [anon_sym_case] = ACTIONS(4383),
    [anon_sym_CASE] = ACTIONS(4383),
    [anon_sym_Case] = ACTIONS(4383),
    [anon_sym_for] = ACTIONS(4383),
    [anon_sym_FOR] = ACTIONS(4383),
    [anon_sym_For] = ACTIONS(4383),
    [anon_sym_foreach] = ACTIONS(4383),
    [anon_sym_FOREACH] = ACTIONS(4383),
    [anon_sym_Foreach] = ACTIONS(4383),
    [anon_sym_while] = ACTIONS(4383),
    [anon_sym_WHILE] = ACTIONS(4383),
    [anon_sym_While] = ACTIONS(4383),
    [anon_sym_repeat] = ACTIONS(4383),
    [anon_sym_REPEAT] = ACTIONS(4383),
    [anon_sym_Repeat] = ACTIONS(4383),
    [anon_sym_exit] = ACTIONS(4383),
    [anon_sym_EXIT] = ACTIONS(4383),
    [anon_sym_Exit] = ACTIONS(4383),
    [anon_sym_continue] = ACTIONS(4383),
    [anon_sym_CONTINUE] = ACTIONS(4383),
    [anon_sym_Continue] = ACTIONS(4383),
    [anon_sym_break] = ACTIONS(4383),
    [anon_sym_BREAK] = ACTIONS(4383),
    [anon_sym_Break] = ACTIONS(4383),
    [anon_sym_with] = ACTIONS(4383),
    [anon_sym_WITH] = ACTIONS(4383),
    [anon_sym_With] = ACTIONS(4383),
    [sym_asserterror_keyword] = ACTIONS(4387),
    [sym_page_keyword] = ACTIONS(4383),
    [anon_sym_codeunit] = ACTIONS(4383),
    [anon_sym_CODEUNIT] = ACTIONS(4383),
    [anon_sym_Codeunit] = ACTIONS(4383),
    [anon_sym_CodeUnit] = ACTIONS(4383),
    [anon_sym_COdeunit] = ACTIONS(4383),
    [anon_sym_codeUnit] = ACTIONS(4383),
    [sym_report_keyword] = ACTIONS(4383),
    [sym_query_keyword] = ACTIONS(4383),
    [anon_sym_xmlport] = ACTIONS(4383),
    [anon_sym_XMLPORT] = ACTIONS(4383),
    [anon_sym_Xmlport] = ACTIONS(4383),
    [anon_sym_XMLport] = ACTIONS(4383),
    [anon_sym_XMLPort] = ACTIONS(4383),
    [anon_sym_XmlPort] = ACTIONS(4383),
    [anon_sym_enum] = ACTIONS(4383),
    [anon_sym_ENUM] = ACTIONS(4383),
    [anon_sym_Enum] = ACTIONS(4383),
    [anon_sym_eNUM] = ACTIONS(4383),
    [anon_sym_eNum] = ACTIONS(4383),
    [anon_sym_ENum] = ACTIONS(4383),
    [sym_quoted_identifier] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4383),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
    [sym_preproc_close] = ACTIONS(4387),
  },
  [STATE(1602)] = {
    [sym_identifier] = ACTIONS(4383),
    [anon_sym_SEMI] = ACTIONS(4387),
    [anon_sym_DASH] = ACTIONS(4387),
    [aux_sym_boolean_token1] = ACTIONS(4383),
    [aux_sym_boolean_token2] = ACTIONS(4383),
    [sym_decimal] = ACTIONS(4383),
    [anon_sym_LPAREN] = ACTIONS(4387),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4383),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_record_type_token1] = ACTIONS(4383),
    [aux_sym_basic_type_token21] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_basic_type_token48] = ACTIONS(4383),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4383),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [anon_sym_not] = ACTIONS(4383),
    [anon_sym_NOT] = ACTIONS(4383),
    [anon_sym_Not] = ACTIONS(4383),
    [anon_sym_POUNDelif] = ACTIONS(4387),
    [anon_sym_POUNDELIF] = ACTIONS(4387),
    [anon_sym_POUNDElif] = ACTIONS(4387),
    [anon_sym_POUNDelse] = ACTIONS(4387),
    [anon_sym_POUNDELSE] = ACTIONS(4387),
    [anon_sym_POUNDElse] = ACTIONS(4387),
    [anon_sym_POUNDendif] = ACTIONS(4387),
    [anon_sym_POUNDENDIF] = ACTIONS(4387),
    [anon_sym_POUNDEndif] = ACTIONS(4387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4383),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4383),
    [anon_sym_PLUS] = ACTIONS(4387),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4383),
    [sym_time_literal] = ACTIONS(4383),
    [sym_biginteger_literal] = ACTIONS(4387),
    [anon_sym_if] = ACTIONS(4383),
    [anon_sym_IF] = ACTIONS(4383),
    [anon_sym_If] = ACTIONS(4383),
    [anon_sym_else] = ACTIONS(4383),
    [anon_sym_ELSE] = ACTIONS(4383),
    [anon_sym_Else] = ACTIONS(4383),
    [anon_sym_case] = ACTIONS(4383),
    [anon_sym_CASE] = ACTIONS(4383),
    [anon_sym_Case] = ACTIONS(4383),
    [anon_sym_for] = ACTIONS(4383),
    [anon_sym_FOR] = ACTIONS(4383),
    [anon_sym_For] = ACTIONS(4383),
    [anon_sym_foreach] = ACTIONS(4383),
    [anon_sym_FOREACH] = ACTIONS(4383),
    [anon_sym_Foreach] = ACTIONS(4383),
    [anon_sym_while] = ACTIONS(4383),
    [anon_sym_WHILE] = ACTIONS(4383),
    [anon_sym_While] = ACTIONS(4383),
    [anon_sym_repeat] = ACTIONS(4383),
    [anon_sym_REPEAT] = ACTIONS(4383),
    [anon_sym_Repeat] = ACTIONS(4383),
    [anon_sym_exit] = ACTIONS(4383),
    [anon_sym_EXIT] = ACTIONS(4383),
    [anon_sym_Exit] = ACTIONS(4383),
    [anon_sym_continue] = ACTIONS(4383),
    [anon_sym_CONTINUE] = ACTIONS(4383),
    [anon_sym_Continue] = ACTIONS(4383),
    [anon_sym_break] = ACTIONS(4383),
    [anon_sym_BREAK] = ACTIONS(4383),
    [anon_sym_Break] = ACTIONS(4383),
    [anon_sym_with] = ACTIONS(4383),
    [anon_sym_WITH] = ACTIONS(4383),
    [anon_sym_With] = ACTIONS(4383),
    [sym_asserterror_keyword] = ACTIONS(4387),
    [sym_page_keyword] = ACTIONS(4383),
    [anon_sym_codeunit] = ACTIONS(4383),
    [anon_sym_CODEUNIT] = ACTIONS(4383),
    [anon_sym_Codeunit] = ACTIONS(4383),
    [anon_sym_CodeUnit] = ACTIONS(4383),
    [anon_sym_COdeunit] = ACTIONS(4383),
    [anon_sym_codeUnit] = ACTIONS(4383),
    [sym_report_keyword] = ACTIONS(4383),
    [sym_query_keyword] = ACTIONS(4383),
    [anon_sym_xmlport] = ACTIONS(4383),
    [anon_sym_XMLPORT] = ACTIONS(4383),
    [anon_sym_Xmlport] = ACTIONS(4383),
    [anon_sym_XMLport] = ACTIONS(4383),
    [anon_sym_XMLPort] = ACTIONS(4383),
    [anon_sym_XmlPort] = ACTIONS(4383),
    [anon_sym_enum] = ACTIONS(4383),
    [anon_sym_ENUM] = ACTIONS(4383),
    [anon_sym_Enum] = ACTIONS(4383),
    [anon_sym_eNUM] = ACTIONS(4383),
    [anon_sym_eNum] = ACTIONS(4383),
    [anon_sym_ENum] = ACTIONS(4383),
    [sym_quoted_identifier] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4383),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
    [sym_preproc_close] = ACTIONS(4387),
  },
  [STATE(1603)] = {
    [sym_identifier] = ACTIONS(4391),
    [anon_sym_SEMI] = ACTIONS(4393),
    [anon_sym_DASH] = ACTIONS(4393),
    [aux_sym_boolean_token1] = ACTIONS(4391),
    [aux_sym_boolean_token2] = ACTIONS(4391),
    [sym_decimal] = ACTIONS(4391),
    [anon_sym_LPAREN] = ACTIONS(4393),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4391),
    [anon_sym_LBRACK] = ACTIONS(4393),
    [aux_sym_record_type_token1] = ACTIONS(4391),
    [aux_sym_basic_type_token21] = ACTIONS(4391),
    [aux_sym_basic_type_token22] = ACTIONS(4391),
    [aux_sym_basic_type_token48] = ACTIONS(4391),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4391),
    [anon_sym_POUNDif] = ACTIONS(4393),
    [anon_sym_POUNDIF] = ACTIONS(4393),
    [anon_sym_POUNDIf] = ACTIONS(4393),
    [anon_sym_not] = ACTIONS(4391),
    [anon_sym_NOT] = ACTIONS(4391),
    [anon_sym_Not] = ACTIONS(4391),
    [anon_sym_POUNDelif] = ACTIONS(4393),
    [anon_sym_POUNDELIF] = ACTIONS(4393),
    [anon_sym_POUNDElif] = ACTIONS(4393),
    [anon_sym_POUNDelse] = ACTIONS(4393),
    [anon_sym_POUNDELSE] = ACTIONS(4393),
    [anon_sym_POUNDElse] = ACTIONS(4393),
    [anon_sym_POUNDendif] = ACTIONS(4393),
    [anon_sym_POUNDENDIF] = ACTIONS(4393),
    [anon_sym_POUNDEndif] = ACTIONS(4393),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4391),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4391),
    [anon_sym_PLUS] = ACTIONS(4393),
    [sym_datetime_literal] = ACTIONS(4393),
    [sym_date_literal] = ACTIONS(4391),
    [sym_time_literal] = ACTIONS(4391),
    [sym_biginteger_literal] = ACTIONS(4393),
    [anon_sym_if] = ACTIONS(4391),
    [anon_sym_IF] = ACTIONS(4391),
    [anon_sym_If] = ACTIONS(4391),
    [anon_sym_else] = ACTIONS(4391),
    [anon_sym_ELSE] = ACTIONS(4391),
    [anon_sym_Else] = ACTIONS(4391),
    [anon_sym_case] = ACTIONS(4391),
    [anon_sym_CASE] = ACTIONS(4391),
    [anon_sym_Case] = ACTIONS(4391),
    [anon_sym_for] = ACTIONS(4391),
    [anon_sym_FOR] = ACTIONS(4391),
    [anon_sym_For] = ACTIONS(4391),
    [anon_sym_foreach] = ACTIONS(4391),
    [anon_sym_FOREACH] = ACTIONS(4391),
    [anon_sym_Foreach] = ACTIONS(4391),
    [anon_sym_while] = ACTIONS(4391),
    [anon_sym_WHILE] = ACTIONS(4391),
    [anon_sym_While] = ACTIONS(4391),
    [anon_sym_repeat] = ACTIONS(4391),
    [anon_sym_REPEAT] = ACTIONS(4391),
    [anon_sym_Repeat] = ACTIONS(4391),
    [anon_sym_exit] = ACTIONS(4391),
    [anon_sym_EXIT] = ACTIONS(4391),
    [anon_sym_Exit] = ACTIONS(4391),
    [anon_sym_continue] = ACTIONS(4391),
    [anon_sym_CONTINUE] = ACTIONS(4391),
    [anon_sym_Continue] = ACTIONS(4391),
    [anon_sym_break] = ACTIONS(4391),
    [anon_sym_BREAK] = ACTIONS(4391),
    [anon_sym_Break] = ACTIONS(4391),
    [anon_sym_with] = ACTIONS(4391),
    [anon_sym_WITH] = ACTIONS(4391),
    [anon_sym_With] = ACTIONS(4391),
    [sym_asserterror_keyword] = ACTIONS(4393),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(4391),
    [anon_sym_CODEUNIT] = ACTIONS(4391),
    [anon_sym_Codeunit] = ACTIONS(4391),
    [anon_sym_CodeUnit] = ACTIONS(4391),
    [anon_sym_COdeunit] = ACTIONS(4391),
    [anon_sym_codeUnit] = ACTIONS(4391),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(4391),
    [anon_sym_XMLPORT] = ACTIONS(4391),
    [anon_sym_Xmlport] = ACTIONS(4391),
    [anon_sym_XMLport] = ACTIONS(4391),
    [anon_sym_XMLPort] = ACTIONS(4391),
    [anon_sym_XmlPort] = ACTIONS(4391),
    [anon_sym_enum] = ACTIONS(4391),
    [anon_sym_ENUM] = ACTIONS(4391),
    [anon_sym_Enum] = ACTIONS(4391),
    [anon_sym_eNUM] = ACTIONS(4391),
    [anon_sym_eNum] = ACTIONS(4391),
    [anon_sym_ENum] = ACTIONS(4391),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4393),
    [sym_integer] = ACTIONS(4391),
    [sym_continue_as_identifier] = ACTIONS(4393),
    [sym_preproc_open] = ACTIONS(4393),
    [sym_preproc_close] = ACTIONS(4393),
  },
  [STATE(1604)] = {
    [sym_identifier] = ACTIONS(4395),
    [anon_sym_SEMI] = ACTIONS(4397),
    [anon_sym_DASH] = ACTIONS(4397),
    [aux_sym_boolean_token1] = ACTIONS(4395),
    [aux_sym_boolean_token2] = ACTIONS(4395),
    [sym_decimal] = ACTIONS(4395),
    [anon_sym_LPAREN] = ACTIONS(4397),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4395),
    [anon_sym_LBRACK] = ACTIONS(4397),
    [aux_sym_record_type_token1] = ACTIONS(4395),
    [aux_sym_basic_type_token21] = ACTIONS(4395),
    [aux_sym_basic_type_token22] = ACTIONS(4395),
    [aux_sym_basic_type_token48] = ACTIONS(4395),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4395),
    [anon_sym_POUNDif] = ACTIONS(4397),
    [anon_sym_POUNDIF] = ACTIONS(4397),
    [anon_sym_POUNDIf] = ACTIONS(4397),
    [anon_sym_not] = ACTIONS(4395),
    [anon_sym_NOT] = ACTIONS(4395),
    [anon_sym_Not] = ACTIONS(4395),
    [anon_sym_POUNDelif] = ACTIONS(4397),
    [anon_sym_POUNDELIF] = ACTIONS(4397),
    [anon_sym_POUNDElif] = ACTIONS(4397),
    [anon_sym_POUNDelse] = ACTIONS(4397),
    [anon_sym_POUNDELSE] = ACTIONS(4397),
    [anon_sym_POUNDElse] = ACTIONS(4397),
    [anon_sym_POUNDendif] = ACTIONS(4397),
    [anon_sym_POUNDENDIF] = ACTIONS(4397),
    [anon_sym_POUNDEndif] = ACTIONS(4397),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4395),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4395),
    [anon_sym_PLUS] = ACTIONS(4397),
    [sym_datetime_literal] = ACTIONS(4397),
    [sym_date_literal] = ACTIONS(4395),
    [sym_time_literal] = ACTIONS(4395),
    [sym_biginteger_literal] = ACTIONS(4397),
    [anon_sym_if] = ACTIONS(4395),
    [anon_sym_IF] = ACTIONS(4395),
    [anon_sym_If] = ACTIONS(4395),
    [anon_sym_else] = ACTIONS(4395),
    [anon_sym_ELSE] = ACTIONS(4395),
    [anon_sym_Else] = ACTIONS(4395),
    [anon_sym_case] = ACTIONS(4395),
    [anon_sym_CASE] = ACTIONS(4395),
    [anon_sym_Case] = ACTIONS(4395),
    [anon_sym_for] = ACTIONS(4395),
    [anon_sym_FOR] = ACTIONS(4395),
    [anon_sym_For] = ACTIONS(4395),
    [anon_sym_foreach] = ACTIONS(4395),
    [anon_sym_FOREACH] = ACTIONS(4395),
    [anon_sym_Foreach] = ACTIONS(4395),
    [anon_sym_while] = ACTIONS(4395),
    [anon_sym_WHILE] = ACTIONS(4395),
    [anon_sym_While] = ACTIONS(4395),
    [anon_sym_repeat] = ACTIONS(4395),
    [anon_sym_REPEAT] = ACTIONS(4395),
    [anon_sym_Repeat] = ACTIONS(4395),
    [anon_sym_exit] = ACTIONS(4395),
    [anon_sym_EXIT] = ACTIONS(4395),
    [anon_sym_Exit] = ACTIONS(4395),
    [anon_sym_continue] = ACTIONS(4395),
    [anon_sym_CONTINUE] = ACTIONS(4395),
    [anon_sym_Continue] = ACTIONS(4395),
    [anon_sym_break] = ACTIONS(4395),
    [anon_sym_BREAK] = ACTIONS(4395),
    [anon_sym_Break] = ACTIONS(4395),
    [anon_sym_with] = ACTIONS(4395),
    [anon_sym_WITH] = ACTIONS(4395),
    [anon_sym_With] = ACTIONS(4395),
    [sym_asserterror_keyword] = ACTIONS(4397),
    [sym_page_keyword] = ACTIONS(4395),
    [anon_sym_codeunit] = ACTIONS(4395),
    [anon_sym_CODEUNIT] = ACTIONS(4395),
    [anon_sym_Codeunit] = ACTIONS(4395),
    [anon_sym_CodeUnit] = ACTIONS(4395),
    [anon_sym_COdeunit] = ACTIONS(4395),
    [anon_sym_codeUnit] = ACTIONS(4395),
    [sym_report_keyword] = ACTIONS(4395),
    [sym_query_keyword] = ACTIONS(4395),
    [anon_sym_xmlport] = ACTIONS(4395),
    [anon_sym_XMLPORT] = ACTIONS(4395),
    [anon_sym_Xmlport] = ACTIONS(4395),
    [anon_sym_XMLport] = ACTIONS(4395),
    [anon_sym_XMLPort] = ACTIONS(4395),
    [anon_sym_XmlPort] = ACTIONS(4395),
    [anon_sym_enum] = ACTIONS(4395),
    [anon_sym_ENUM] = ACTIONS(4395),
    [anon_sym_Enum] = ACTIONS(4395),
    [anon_sym_eNUM] = ACTIONS(4395),
    [anon_sym_eNum] = ACTIONS(4395),
    [anon_sym_ENum] = ACTIONS(4395),
    [sym_quoted_identifier] = ACTIONS(4397),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4397),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4397),
    [sym_preproc_open] = ACTIONS(4397),
    [sym_preproc_close] = ACTIONS(4397),
  },
  [STATE(1605)] = {
    [sym_identifier] = ACTIONS(4395),
    [anon_sym_SEMI] = ACTIONS(4397),
    [anon_sym_DASH] = ACTIONS(4397),
    [aux_sym_boolean_token1] = ACTIONS(4395),
    [aux_sym_boolean_token2] = ACTIONS(4395),
    [sym_decimal] = ACTIONS(4395),
    [anon_sym_LPAREN] = ACTIONS(4397),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4395),
    [anon_sym_LBRACK] = ACTIONS(4397),
    [aux_sym_record_type_token1] = ACTIONS(4395),
    [aux_sym_basic_type_token21] = ACTIONS(4395),
    [aux_sym_basic_type_token22] = ACTIONS(4395),
    [aux_sym_basic_type_token48] = ACTIONS(4395),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4395),
    [anon_sym_POUNDif] = ACTIONS(4397),
    [anon_sym_POUNDIF] = ACTIONS(4397),
    [anon_sym_POUNDIf] = ACTIONS(4397),
    [anon_sym_not] = ACTIONS(4395),
    [anon_sym_NOT] = ACTIONS(4395),
    [anon_sym_Not] = ACTIONS(4395),
    [anon_sym_POUNDelif] = ACTIONS(4397),
    [anon_sym_POUNDELIF] = ACTIONS(4397),
    [anon_sym_POUNDElif] = ACTIONS(4397),
    [anon_sym_POUNDelse] = ACTIONS(4397),
    [anon_sym_POUNDELSE] = ACTIONS(4397),
    [anon_sym_POUNDElse] = ACTIONS(4397),
    [anon_sym_POUNDendif] = ACTIONS(4397),
    [anon_sym_POUNDENDIF] = ACTIONS(4397),
    [anon_sym_POUNDEndif] = ACTIONS(4397),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4395),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4395),
    [anon_sym_PLUS] = ACTIONS(4397),
    [sym_datetime_literal] = ACTIONS(4397),
    [sym_date_literal] = ACTIONS(4395),
    [sym_time_literal] = ACTIONS(4395),
    [sym_biginteger_literal] = ACTIONS(4397),
    [anon_sym_if] = ACTIONS(4395),
    [anon_sym_IF] = ACTIONS(4395),
    [anon_sym_If] = ACTIONS(4395),
    [anon_sym_else] = ACTIONS(4395),
    [anon_sym_ELSE] = ACTIONS(4395),
    [anon_sym_Else] = ACTIONS(4395),
    [anon_sym_case] = ACTIONS(4395),
    [anon_sym_CASE] = ACTIONS(4395),
    [anon_sym_Case] = ACTIONS(4395),
    [anon_sym_for] = ACTIONS(4395),
    [anon_sym_FOR] = ACTIONS(4395),
    [anon_sym_For] = ACTIONS(4395),
    [anon_sym_foreach] = ACTIONS(4395),
    [anon_sym_FOREACH] = ACTIONS(4395),
    [anon_sym_Foreach] = ACTIONS(4395),
    [anon_sym_while] = ACTIONS(4395),
    [anon_sym_WHILE] = ACTIONS(4395),
    [anon_sym_While] = ACTIONS(4395),
    [anon_sym_repeat] = ACTIONS(4395),
    [anon_sym_REPEAT] = ACTIONS(4395),
    [anon_sym_Repeat] = ACTIONS(4395),
    [anon_sym_exit] = ACTIONS(4395),
    [anon_sym_EXIT] = ACTIONS(4395),
    [anon_sym_Exit] = ACTIONS(4395),
    [anon_sym_continue] = ACTIONS(4395),
    [anon_sym_CONTINUE] = ACTIONS(4395),
    [anon_sym_Continue] = ACTIONS(4395),
    [anon_sym_break] = ACTIONS(4395),
    [anon_sym_BREAK] = ACTIONS(4395),
    [anon_sym_Break] = ACTIONS(4395),
    [anon_sym_with] = ACTIONS(4395),
    [anon_sym_WITH] = ACTIONS(4395),
    [anon_sym_With] = ACTIONS(4395),
    [sym_asserterror_keyword] = ACTIONS(4397),
    [sym_page_keyword] = ACTIONS(4395),
    [anon_sym_codeunit] = ACTIONS(4395),
    [anon_sym_CODEUNIT] = ACTIONS(4395),
    [anon_sym_Codeunit] = ACTIONS(4395),
    [anon_sym_CodeUnit] = ACTIONS(4395),
    [anon_sym_COdeunit] = ACTIONS(4395),
    [anon_sym_codeUnit] = ACTIONS(4395),
    [sym_report_keyword] = ACTIONS(4395),
    [sym_query_keyword] = ACTIONS(4395),
    [anon_sym_xmlport] = ACTIONS(4395),
    [anon_sym_XMLPORT] = ACTIONS(4395),
    [anon_sym_Xmlport] = ACTIONS(4395),
    [anon_sym_XMLport] = ACTIONS(4395),
    [anon_sym_XMLPort] = ACTIONS(4395),
    [anon_sym_XmlPort] = ACTIONS(4395),
    [anon_sym_enum] = ACTIONS(4395),
    [anon_sym_ENUM] = ACTIONS(4395),
    [anon_sym_Enum] = ACTIONS(4395),
    [anon_sym_eNUM] = ACTIONS(4395),
    [anon_sym_eNum] = ACTIONS(4395),
    [anon_sym_ENum] = ACTIONS(4395),
    [sym_quoted_identifier] = ACTIONS(4397),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4397),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4397),
    [sym_preproc_open] = ACTIONS(4397),
    [sym_preproc_close] = ACTIONS(4397),
  },
  [STATE(1606)] = {
    [sym_identifier] = ACTIONS(4399),
    [anon_sym_SEMI] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [aux_sym_boolean_token1] = ACTIONS(4399),
    [aux_sym_boolean_token2] = ACTIONS(4399),
    [sym_decimal] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4401),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4399),
    [anon_sym_LBRACK] = ACTIONS(4401),
    [aux_sym_record_type_token1] = ACTIONS(4399),
    [aux_sym_basic_type_token21] = ACTIONS(4399),
    [aux_sym_basic_type_token22] = ACTIONS(4399),
    [aux_sym_basic_type_token48] = ACTIONS(4399),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4399),
    [anon_sym_POUNDif] = ACTIONS(4401),
    [anon_sym_POUNDIF] = ACTIONS(4401),
    [anon_sym_POUNDIf] = ACTIONS(4401),
    [anon_sym_not] = ACTIONS(4399),
    [anon_sym_NOT] = ACTIONS(4399),
    [anon_sym_Not] = ACTIONS(4399),
    [anon_sym_POUNDelif] = ACTIONS(4401),
    [anon_sym_POUNDELIF] = ACTIONS(4401),
    [anon_sym_POUNDElif] = ACTIONS(4401),
    [anon_sym_POUNDelse] = ACTIONS(4401),
    [anon_sym_POUNDELSE] = ACTIONS(4401),
    [anon_sym_POUNDElse] = ACTIONS(4401),
    [anon_sym_POUNDendif] = ACTIONS(4401),
    [anon_sym_POUNDENDIF] = ACTIONS(4401),
    [anon_sym_POUNDEndif] = ACTIONS(4401),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4399),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [sym_datetime_literal] = ACTIONS(4401),
    [sym_date_literal] = ACTIONS(4399),
    [sym_time_literal] = ACTIONS(4399),
    [sym_biginteger_literal] = ACTIONS(4401),
    [anon_sym_if] = ACTIONS(4399),
    [anon_sym_IF] = ACTIONS(4399),
    [anon_sym_If] = ACTIONS(4399),
    [anon_sym_else] = ACTIONS(4399),
    [anon_sym_ELSE] = ACTIONS(4399),
    [anon_sym_Else] = ACTIONS(4399),
    [anon_sym_case] = ACTIONS(4399),
    [anon_sym_CASE] = ACTIONS(4399),
    [anon_sym_Case] = ACTIONS(4399),
    [anon_sym_for] = ACTIONS(4399),
    [anon_sym_FOR] = ACTIONS(4399),
    [anon_sym_For] = ACTIONS(4399),
    [anon_sym_foreach] = ACTIONS(4399),
    [anon_sym_FOREACH] = ACTIONS(4399),
    [anon_sym_Foreach] = ACTIONS(4399),
    [anon_sym_while] = ACTIONS(4399),
    [anon_sym_WHILE] = ACTIONS(4399),
    [anon_sym_While] = ACTIONS(4399),
    [anon_sym_repeat] = ACTIONS(4399),
    [anon_sym_REPEAT] = ACTIONS(4399),
    [anon_sym_Repeat] = ACTIONS(4399),
    [anon_sym_exit] = ACTIONS(4399),
    [anon_sym_EXIT] = ACTIONS(4399),
    [anon_sym_Exit] = ACTIONS(4399),
    [anon_sym_continue] = ACTIONS(4399),
    [anon_sym_CONTINUE] = ACTIONS(4399),
    [anon_sym_Continue] = ACTIONS(4399),
    [anon_sym_break] = ACTIONS(4399),
    [anon_sym_BREAK] = ACTIONS(4399),
    [anon_sym_Break] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4399),
    [anon_sym_WITH] = ACTIONS(4399),
    [anon_sym_With] = ACTIONS(4399),
    [sym_asserterror_keyword] = ACTIONS(4401),
    [sym_page_keyword] = ACTIONS(4399),
    [anon_sym_codeunit] = ACTIONS(4399),
    [anon_sym_CODEUNIT] = ACTIONS(4399),
    [anon_sym_Codeunit] = ACTIONS(4399),
    [anon_sym_CodeUnit] = ACTIONS(4399),
    [anon_sym_COdeunit] = ACTIONS(4399),
    [anon_sym_codeUnit] = ACTIONS(4399),
    [sym_report_keyword] = ACTIONS(4399),
    [sym_query_keyword] = ACTIONS(4399),
    [anon_sym_xmlport] = ACTIONS(4399),
    [anon_sym_XMLPORT] = ACTIONS(4399),
    [anon_sym_Xmlport] = ACTIONS(4399),
    [anon_sym_XMLport] = ACTIONS(4399),
    [anon_sym_XMLPort] = ACTIONS(4399),
    [anon_sym_XmlPort] = ACTIONS(4399),
    [anon_sym_enum] = ACTIONS(4399),
    [anon_sym_ENUM] = ACTIONS(4399),
    [anon_sym_Enum] = ACTIONS(4399),
    [anon_sym_eNUM] = ACTIONS(4399),
    [anon_sym_eNum] = ACTIONS(4399),
    [anon_sym_ENum] = ACTIONS(4399),
    [sym_quoted_identifier] = ACTIONS(4401),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4401),
    [sym_integer] = ACTIONS(4399),
    [sym_continue_as_identifier] = ACTIONS(4401),
    [sym_preproc_open] = ACTIONS(4401),
    [sym_preproc_close] = ACTIONS(4401),
  },
  [STATE(1607)] = {
    [sym_identifier] = ACTIONS(4403),
    [anon_sym_SEMI] = ACTIONS(4405),
    [anon_sym_DASH] = ACTIONS(4405),
    [aux_sym_boolean_token1] = ACTIONS(4403),
    [aux_sym_boolean_token2] = ACTIONS(4403),
    [sym_decimal] = ACTIONS(4403),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4403),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [aux_sym_record_type_token1] = ACTIONS(4403),
    [aux_sym_basic_type_token21] = ACTIONS(4403),
    [aux_sym_basic_type_token22] = ACTIONS(4403),
    [aux_sym_basic_type_token48] = ACTIONS(4403),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4403),
    [anon_sym_POUNDif] = ACTIONS(4405),
    [anon_sym_POUNDIF] = ACTIONS(4405),
    [anon_sym_POUNDIf] = ACTIONS(4405),
    [anon_sym_not] = ACTIONS(4403),
    [anon_sym_NOT] = ACTIONS(4403),
    [anon_sym_Not] = ACTIONS(4403),
    [anon_sym_POUNDelif] = ACTIONS(4405),
    [anon_sym_POUNDELIF] = ACTIONS(4405),
    [anon_sym_POUNDElif] = ACTIONS(4405),
    [anon_sym_POUNDelse] = ACTIONS(4405),
    [anon_sym_POUNDELSE] = ACTIONS(4405),
    [anon_sym_POUNDElse] = ACTIONS(4405),
    [anon_sym_POUNDendif] = ACTIONS(4405),
    [anon_sym_POUNDENDIF] = ACTIONS(4405),
    [anon_sym_POUNDEndif] = ACTIONS(4405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4403),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4403),
    [anon_sym_PLUS] = ACTIONS(4405),
    [sym_datetime_literal] = ACTIONS(4405),
    [sym_date_literal] = ACTIONS(4403),
    [sym_time_literal] = ACTIONS(4403),
    [sym_biginteger_literal] = ACTIONS(4405),
    [anon_sym_if] = ACTIONS(4403),
    [anon_sym_IF] = ACTIONS(4403),
    [anon_sym_If] = ACTIONS(4403),
    [anon_sym_else] = ACTIONS(4403),
    [anon_sym_ELSE] = ACTIONS(4403),
    [anon_sym_Else] = ACTIONS(4403),
    [anon_sym_case] = ACTIONS(4403),
    [anon_sym_CASE] = ACTIONS(4403),
    [anon_sym_Case] = ACTIONS(4403),
    [anon_sym_for] = ACTIONS(4403),
    [anon_sym_FOR] = ACTIONS(4403),
    [anon_sym_For] = ACTIONS(4403),
    [anon_sym_foreach] = ACTIONS(4403),
    [anon_sym_FOREACH] = ACTIONS(4403),
    [anon_sym_Foreach] = ACTIONS(4403),
    [anon_sym_while] = ACTIONS(4403),
    [anon_sym_WHILE] = ACTIONS(4403),
    [anon_sym_While] = ACTIONS(4403),
    [anon_sym_repeat] = ACTIONS(4403),
    [anon_sym_REPEAT] = ACTIONS(4403),
    [anon_sym_Repeat] = ACTIONS(4403),
    [anon_sym_exit] = ACTIONS(4403),
    [anon_sym_EXIT] = ACTIONS(4403),
    [anon_sym_Exit] = ACTIONS(4403),
    [anon_sym_continue] = ACTIONS(4403),
    [anon_sym_CONTINUE] = ACTIONS(4403),
    [anon_sym_Continue] = ACTIONS(4403),
    [anon_sym_break] = ACTIONS(4403),
    [anon_sym_BREAK] = ACTIONS(4403),
    [anon_sym_Break] = ACTIONS(4403),
    [anon_sym_with] = ACTIONS(4403),
    [anon_sym_WITH] = ACTIONS(4403),
    [anon_sym_With] = ACTIONS(4403),
    [sym_asserterror_keyword] = ACTIONS(4405),
    [sym_page_keyword] = ACTIONS(4403),
    [anon_sym_codeunit] = ACTIONS(4403),
    [anon_sym_CODEUNIT] = ACTIONS(4403),
    [anon_sym_Codeunit] = ACTIONS(4403),
    [anon_sym_CodeUnit] = ACTIONS(4403),
    [anon_sym_COdeunit] = ACTIONS(4403),
    [anon_sym_codeUnit] = ACTIONS(4403),
    [sym_report_keyword] = ACTIONS(4403),
    [sym_query_keyword] = ACTIONS(4403),
    [anon_sym_xmlport] = ACTIONS(4403),
    [anon_sym_XMLPORT] = ACTIONS(4403),
    [anon_sym_Xmlport] = ACTIONS(4403),
    [anon_sym_XMLport] = ACTIONS(4403),
    [anon_sym_XMLPort] = ACTIONS(4403),
    [anon_sym_XmlPort] = ACTIONS(4403),
    [anon_sym_enum] = ACTIONS(4403),
    [anon_sym_ENUM] = ACTIONS(4403),
    [anon_sym_Enum] = ACTIONS(4403),
    [anon_sym_eNUM] = ACTIONS(4403),
    [anon_sym_eNum] = ACTIONS(4403),
    [anon_sym_ENum] = ACTIONS(4403),
    [sym_quoted_identifier] = ACTIONS(4405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4405),
    [sym_integer] = ACTIONS(4403),
    [sym_continue_as_identifier] = ACTIONS(4405),
    [sym_preproc_open] = ACTIONS(4405),
    [sym_preproc_close] = ACTIONS(4405),
  },
  [STATE(1608)] = {
    [sym_identifier] = ACTIONS(4407),
    [anon_sym_SEMI] = ACTIONS(4409),
    [anon_sym_DASH] = ACTIONS(4409),
    [aux_sym_boolean_token1] = ACTIONS(4407),
    [aux_sym_boolean_token2] = ACTIONS(4407),
    [sym_decimal] = ACTIONS(4407),
    [anon_sym_LPAREN] = ACTIONS(4409),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4407),
    [anon_sym_LBRACK] = ACTIONS(4409),
    [aux_sym_record_type_token1] = ACTIONS(4407),
    [aux_sym_basic_type_token21] = ACTIONS(4407),
    [aux_sym_basic_type_token22] = ACTIONS(4407),
    [aux_sym_basic_type_token48] = ACTIONS(4407),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4407),
    [anon_sym_POUNDif] = ACTIONS(4409),
    [anon_sym_POUNDIF] = ACTIONS(4409),
    [anon_sym_POUNDIf] = ACTIONS(4409),
    [anon_sym_not] = ACTIONS(4407),
    [anon_sym_NOT] = ACTIONS(4407),
    [anon_sym_Not] = ACTIONS(4407),
    [anon_sym_POUNDelif] = ACTIONS(4409),
    [anon_sym_POUNDELIF] = ACTIONS(4409),
    [anon_sym_POUNDElif] = ACTIONS(4409),
    [anon_sym_POUNDelse] = ACTIONS(4409),
    [anon_sym_POUNDELSE] = ACTIONS(4409),
    [anon_sym_POUNDElse] = ACTIONS(4409),
    [anon_sym_POUNDendif] = ACTIONS(4409),
    [anon_sym_POUNDENDIF] = ACTIONS(4409),
    [anon_sym_POUNDEndif] = ACTIONS(4409),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4407),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4407),
    [anon_sym_PLUS] = ACTIONS(4409),
    [sym_datetime_literal] = ACTIONS(4409),
    [sym_date_literal] = ACTIONS(4407),
    [sym_time_literal] = ACTIONS(4407),
    [sym_biginteger_literal] = ACTIONS(4409),
    [anon_sym_if] = ACTIONS(4407),
    [anon_sym_IF] = ACTIONS(4407),
    [anon_sym_If] = ACTIONS(4407),
    [anon_sym_else] = ACTIONS(4407),
    [anon_sym_ELSE] = ACTIONS(4407),
    [anon_sym_Else] = ACTIONS(4407),
    [anon_sym_case] = ACTIONS(4407),
    [anon_sym_CASE] = ACTIONS(4407),
    [anon_sym_Case] = ACTIONS(4407),
    [anon_sym_for] = ACTIONS(4407),
    [anon_sym_FOR] = ACTIONS(4407),
    [anon_sym_For] = ACTIONS(4407),
    [anon_sym_foreach] = ACTIONS(4407),
    [anon_sym_FOREACH] = ACTIONS(4407),
    [anon_sym_Foreach] = ACTIONS(4407),
    [anon_sym_while] = ACTIONS(4407),
    [anon_sym_WHILE] = ACTIONS(4407),
    [anon_sym_While] = ACTIONS(4407),
    [anon_sym_repeat] = ACTIONS(4407),
    [anon_sym_REPEAT] = ACTIONS(4407),
    [anon_sym_Repeat] = ACTIONS(4407),
    [anon_sym_exit] = ACTIONS(4407),
    [anon_sym_EXIT] = ACTIONS(4407),
    [anon_sym_Exit] = ACTIONS(4407),
    [anon_sym_continue] = ACTIONS(4407),
    [anon_sym_CONTINUE] = ACTIONS(4407),
    [anon_sym_Continue] = ACTIONS(4407),
    [anon_sym_break] = ACTIONS(4407),
    [anon_sym_BREAK] = ACTIONS(4407),
    [anon_sym_Break] = ACTIONS(4407),
    [anon_sym_with] = ACTIONS(4407),
    [anon_sym_WITH] = ACTIONS(4407),
    [anon_sym_With] = ACTIONS(4407),
    [sym_asserterror_keyword] = ACTIONS(4409),
    [sym_page_keyword] = ACTIONS(4407),
    [anon_sym_codeunit] = ACTIONS(4407),
    [anon_sym_CODEUNIT] = ACTIONS(4407),
    [anon_sym_Codeunit] = ACTIONS(4407),
    [anon_sym_CodeUnit] = ACTIONS(4407),
    [anon_sym_COdeunit] = ACTIONS(4407),
    [anon_sym_codeUnit] = ACTIONS(4407),
    [sym_report_keyword] = ACTIONS(4407),
    [sym_query_keyword] = ACTIONS(4407),
    [anon_sym_xmlport] = ACTIONS(4407),
    [anon_sym_XMLPORT] = ACTIONS(4407),
    [anon_sym_Xmlport] = ACTIONS(4407),
    [anon_sym_XMLport] = ACTIONS(4407),
    [anon_sym_XMLPort] = ACTIONS(4407),
    [anon_sym_XmlPort] = ACTIONS(4407),
    [anon_sym_enum] = ACTIONS(4407),
    [anon_sym_ENUM] = ACTIONS(4407),
    [anon_sym_Enum] = ACTIONS(4407),
    [anon_sym_eNUM] = ACTIONS(4407),
    [anon_sym_eNum] = ACTIONS(4407),
    [anon_sym_ENum] = ACTIONS(4407),
    [sym_quoted_identifier] = ACTIONS(4409),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4409),
    [sym_integer] = ACTIONS(4407),
    [sym_continue_as_identifier] = ACTIONS(4409),
    [sym_preproc_open] = ACTIONS(4409),
    [sym_preproc_close] = ACTIONS(4409),
  },
  [STATE(1609)] = {
    [sym_identifier] = ACTIONS(4411),
    [anon_sym_SEMI] = ACTIONS(4413),
    [anon_sym_DASH] = ACTIONS(4413),
    [aux_sym_boolean_token1] = ACTIONS(4411),
    [aux_sym_boolean_token2] = ACTIONS(4411),
    [sym_decimal] = ACTIONS(4411),
    [anon_sym_LPAREN] = ACTIONS(4413),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4411),
    [anon_sym_LBRACK] = ACTIONS(4413),
    [aux_sym_record_type_token1] = ACTIONS(4411),
    [aux_sym_basic_type_token21] = ACTIONS(4411),
    [aux_sym_basic_type_token22] = ACTIONS(4411),
    [aux_sym_basic_type_token48] = ACTIONS(4411),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4411),
    [anon_sym_POUNDif] = ACTIONS(4413),
    [anon_sym_POUNDIF] = ACTIONS(4413),
    [anon_sym_POUNDIf] = ACTIONS(4413),
    [anon_sym_not] = ACTIONS(4411),
    [anon_sym_NOT] = ACTIONS(4411),
    [anon_sym_Not] = ACTIONS(4411),
    [anon_sym_POUNDelif] = ACTIONS(4413),
    [anon_sym_POUNDELIF] = ACTIONS(4413),
    [anon_sym_POUNDElif] = ACTIONS(4413),
    [anon_sym_POUNDelse] = ACTIONS(4413),
    [anon_sym_POUNDELSE] = ACTIONS(4413),
    [anon_sym_POUNDElse] = ACTIONS(4413),
    [anon_sym_POUNDendif] = ACTIONS(4413),
    [anon_sym_POUNDENDIF] = ACTIONS(4413),
    [anon_sym_POUNDEndif] = ACTIONS(4413),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4411),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4411),
    [anon_sym_PLUS] = ACTIONS(4413),
    [sym_datetime_literal] = ACTIONS(4413),
    [sym_date_literal] = ACTIONS(4411),
    [sym_time_literal] = ACTIONS(4411),
    [sym_biginteger_literal] = ACTIONS(4413),
    [anon_sym_if] = ACTIONS(4411),
    [anon_sym_IF] = ACTIONS(4411),
    [anon_sym_If] = ACTIONS(4411),
    [anon_sym_else] = ACTIONS(4411),
    [anon_sym_ELSE] = ACTIONS(4411),
    [anon_sym_Else] = ACTIONS(4411),
    [anon_sym_case] = ACTIONS(4411),
    [anon_sym_CASE] = ACTIONS(4411),
    [anon_sym_Case] = ACTIONS(4411),
    [anon_sym_for] = ACTIONS(4411),
    [anon_sym_FOR] = ACTIONS(4411),
    [anon_sym_For] = ACTIONS(4411),
    [anon_sym_foreach] = ACTIONS(4411),
    [anon_sym_FOREACH] = ACTIONS(4411),
    [anon_sym_Foreach] = ACTIONS(4411),
    [anon_sym_while] = ACTIONS(4411),
    [anon_sym_WHILE] = ACTIONS(4411),
    [anon_sym_While] = ACTIONS(4411),
    [anon_sym_repeat] = ACTIONS(4411),
    [anon_sym_REPEAT] = ACTIONS(4411),
    [anon_sym_Repeat] = ACTIONS(4411),
    [anon_sym_exit] = ACTIONS(4411),
    [anon_sym_EXIT] = ACTIONS(4411),
    [anon_sym_Exit] = ACTIONS(4411),
    [anon_sym_continue] = ACTIONS(4411),
    [anon_sym_CONTINUE] = ACTIONS(4411),
    [anon_sym_Continue] = ACTIONS(4411),
    [anon_sym_break] = ACTIONS(4411),
    [anon_sym_BREAK] = ACTIONS(4411),
    [anon_sym_Break] = ACTIONS(4411),
    [anon_sym_with] = ACTIONS(4411),
    [anon_sym_WITH] = ACTIONS(4411),
    [anon_sym_With] = ACTIONS(4411),
    [sym_asserterror_keyword] = ACTIONS(4413),
    [sym_page_keyword] = ACTIONS(4411),
    [anon_sym_codeunit] = ACTIONS(4411),
    [anon_sym_CODEUNIT] = ACTIONS(4411),
    [anon_sym_Codeunit] = ACTIONS(4411),
    [anon_sym_CodeUnit] = ACTIONS(4411),
    [anon_sym_COdeunit] = ACTIONS(4411),
    [anon_sym_codeUnit] = ACTIONS(4411),
    [sym_report_keyword] = ACTIONS(4411),
    [sym_query_keyword] = ACTIONS(4411),
    [anon_sym_xmlport] = ACTIONS(4411),
    [anon_sym_XMLPORT] = ACTIONS(4411),
    [anon_sym_Xmlport] = ACTIONS(4411),
    [anon_sym_XMLport] = ACTIONS(4411),
    [anon_sym_XMLPort] = ACTIONS(4411),
    [anon_sym_XmlPort] = ACTIONS(4411),
    [anon_sym_enum] = ACTIONS(4411),
    [anon_sym_ENUM] = ACTIONS(4411),
    [anon_sym_Enum] = ACTIONS(4411),
    [anon_sym_eNUM] = ACTIONS(4411),
    [anon_sym_eNum] = ACTIONS(4411),
    [anon_sym_ENum] = ACTIONS(4411),
    [sym_quoted_identifier] = ACTIONS(4413),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4413),
    [sym_integer] = ACTIONS(4411),
    [sym_continue_as_identifier] = ACTIONS(4413),
    [sym_preproc_open] = ACTIONS(4413),
    [sym_preproc_close] = ACTIONS(4413),
  },
  [STATE(1610)] = {
    [sym_identifier] = ACTIONS(4415),
    [anon_sym_SEMI] = ACTIONS(4417),
    [anon_sym_DASH] = ACTIONS(4417),
    [aux_sym_boolean_token1] = ACTIONS(4415),
    [aux_sym_boolean_token2] = ACTIONS(4415),
    [sym_decimal] = ACTIONS(4415),
    [anon_sym_LPAREN] = ACTIONS(4417),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4415),
    [anon_sym_LBRACK] = ACTIONS(4417),
    [aux_sym_record_type_token1] = ACTIONS(4415),
    [aux_sym_basic_type_token21] = ACTIONS(4415),
    [aux_sym_basic_type_token22] = ACTIONS(4415),
    [aux_sym_basic_type_token48] = ACTIONS(4415),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4415),
    [anon_sym_POUNDif] = ACTIONS(4417),
    [anon_sym_POUNDIF] = ACTIONS(4417),
    [anon_sym_POUNDIf] = ACTIONS(4417),
    [anon_sym_not] = ACTIONS(4415),
    [anon_sym_NOT] = ACTIONS(4415),
    [anon_sym_Not] = ACTIONS(4415),
    [anon_sym_POUNDelif] = ACTIONS(4417),
    [anon_sym_POUNDELIF] = ACTIONS(4417),
    [anon_sym_POUNDElif] = ACTIONS(4417),
    [anon_sym_POUNDelse] = ACTIONS(4417),
    [anon_sym_POUNDELSE] = ACTIONS(4417),
    [anon_sym_POUNDElse] = ACTIONS(4417),
    [anon_sym_POUNDendif] = ACTIONS(4417),
    [anon_sym_POUNDENDIF] = ACTIONS(4417),
    [anon_sym_POUNDEndif] = ACTIONS(4417),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4415),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4415),
    [anon_sym_PLUS] = ACTIONS(4417),
    [sym_datetime_literal] = ACTIONS(4417),
    [sym_date_literal] = ACTIONS(4415),
    [sym_time_literal] = ACTIONS(4415),
    [sym_biginteger_literal] = ACTIONS(4417),
    [anon_sym_if] = ACTIONS(4415),
    [anon_sym_IF] = ACTIONS(4415),
    [anon_sym_If] = ACTIONS(4415),
    [anon_sym_else] = ACTIONS(4415),
    [anon_sym_ELSE] = ACTIONS(4415),
    [anon_sym_Else] = ACTIONS(4415),
    [anon_sym_case] = ACTIONS(4415),
    [anon_sym_CASE] = ACTIONS(4415),
    [anon_sym_Case] = ACTIONS(4415),
    [anon_sym_for] = ACTIONS(4415),
    [anon_sym_FOR] = ACTIONS(4415),
    [anon_sym_For] = ACTIONS(4415),
    [anon_sym_foreach] = ACTIONS(4415),
    [anon_sym_FOREACH] = ACTIONS(4415),
    [anon_sym_Foreach] = ACTIONS(4415),
    [anon_sym_while] = ACTIONS(4415),
    [anon_sym_WHILE] = ACTIONS(4415),
    [anon_sym_While] = ACTIONS(4415),
    [anon_sym_repeat] = ACTIONS(4415),
    [anon_sym_REPEAT] = ACTIONS(4415),
    [anon_sym_Repeat] = ACTIONS(4415),
    [anon_sym_exit] = ACTIONS(4415),
    [anon_sym_EXIT] = ACTIONS(4415),
    [anon_sym_Exit] = ACTIONS(4415),
    [anon_sym_continue] = ACTIONS(4415),
    [anon_sym_CONTINUE] = ACTIONS(4415),
    [anon_sym_Continue] = ACTIONS(4415),
    [anon_sym_break] = ACTIONS(4415),
    [anon_sym_BREAK] = ACTIONS(4415),
    [anon_sym_Break] = ACTIONS(4415),
    [anon_sym_with] = ACTIONS(4415),
    [anon_sym_WITH] = ACTIONS(4415),
    [anon_sym_With] = ACTIONS(4415),
    [sym_asserterror_keyword] = ACTIONS(4417),
    [sym_page_keyword] = ACTIONS(4415),
    [anon_sym_codeunit] = ACTIONS(4415),
    [anon_sym_CODEUNIT] = ACTIONS(4415),
    [anon_sym_Codeunit] = ACTIONS(4415),
    [anon_sym_CodeUnit] = ACTIONS(4415),
    [anon_sym_COdeunit] = ACTIONS(4415),
    [anon_sym_codeUnit] = ACTIONS(4415),
    [sym_report_keyword] = ACTIONS(4415),
    [sym_query_keyword] = ACTIONS(4415),
    [anon_sym_xmlport] = ACTIONS(4415),
    [anon_sym_XMLPORT] = ACTIONS(4415),
    [anon_sym_Xmlport] = ACTIONS(4415),
    [anon_sym_XMLport] = ACTIONS(4415),
    [anon_sym_XMLPort] = ACTIONS(4415),
    [anon_sym_XmlPort] = ACTIONS(4415),
    [anon_sym_enum] = ACTIONS(4415),
    [anon_sym_ENUM] = ACTIONS(4415),
    [anon_sym_Enum] = ACTIONS(4415),
    [anon_sym_eNUM] = ACTIONS(4415),
    [anon_sym_eNum] = ACTIONS(4415),
    [anon_sym_ENum] = ACTIONS(4415),
    [sym_quoted_identifier] = ACTIONS(4417),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4417),
    [sym_integer] = ACTIONS(4415),
    [sym_continue_as_identifier] = ACTIONS(4417),
    [sym_preproc_open] = ACTIONS(4417),
    [sym_preproc_close] = ACTIONS(4417),
  },
  [STATE(1611)] = {
    [sym_identifier] = ACTIONS(4419),
    [anon_sym_SEMI] = ACTIONS(4421),
    [anon_sym_DASH] = ACTIONS(4421),
    [aux_sym_boolean_token1] = ACTIONS(4419),
    [aux_sym_boolean_token2] = ACTIONS(4419),
    [sym_decimal] = ACTIONS(4419),
    [anon_sym_LPAREN] = ACTIONS(4421),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4419),
    [anon_sym_LBRACK] = ACTIONS(4421),
    [aux_sym_record_type_token1] = ACTIONS(4419),
    [aux_sym_basic_type_token21] = ACTIONS(4419),
    [aux_sym_basic_type_token22] = ACTIONS(4419),
    [aux_sym_basic_type_token48] = ACTIONS(4419),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4419),
    [anon_sym_POUNDif] = ACTIONS(4421),
    [anon_sym_POUNDIF] = ACTIONS(4421),
    [anon_sym_POUNDIf] = ACTIONS(4421),
    [anon_sym_not] = ACTIONS(4419),
    [anon_sym_NOT] = ACTIONS(4419),
    [anon_sym_Not] = ACTIONS(4419),
    [anon_sym_POUNDelif] = ACTIONS(4421),
    [anon_sym_POUNDELIF] = ACTIONS(4421),
    [anon_sym_POUNDElif] = ACTIONS(4421),
    [anon_sym_POUNDelse] = ACTIONS(4421),
    [anon_sym_POUNDELSE] = ACTIONS(4421),
    [anon_sym_POUNDElse] = ACTIONS(4421),
    [anon_sym_POUNDendif] = ACTIONS(4421),
    [anon_sym_POUNDENDIF] = ACTIONS(4421),
    [anon_sym_POUNDEndif] = ACTIONS(4421),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4419),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4419),
    [anon_sym_PLUS] = ACTIONS(4421),
    [sym_datetime_literal] = ACTIONS(4421),
    [sym_date_literal] = ACTIONS(4419),
    [sym_time_literal] = ACTIONS(4419),
    [sym_biginteger_literal] = ACTIONS(4421),
    [anon_sym_if] = ACTIONS(4419),
    [anon_sym_IF] = ACTIONS(4419),
    [anon_sym_If] = ACTIONS(4419),
    [anon_sym_else] = ACTIONS(4419),
    [anon_sym_ELSE] = ACTIONS(4419),
    [anon_sym_Else] = ACTIONS(4419),
    [anon_sym_case] = ACTIONS(4419),
    [anon_sym_CASE] = ACTIONS(4419),
    [anon_sym_Case] = ACTIONS(4419),
    [anon_sym_for] = ACTIONS(4419),
    [anon_sym_FOR] = ACTIONS(4419),
    [anon_sym_For] = ACTIONS(4419),
    [anon_sym_foreach] = ACTIONS(4419),
    [anon_sym_FOREACH] = ACTIONS(4419),
    [anon_sym_Foreach] = ACTIONS(4419),
    [anon_sym_while] = ACTIONS(4419),
    [anon_sym_WHILE] = ACTIONS(4419),
    [anon_sym_While] = ACTIONS(4419),
    [anon_sym_repeat] = ACTIONS(4419),
    [anon_sym_REPEAT] = ACTIONS(4419),
    [anon_sym_Repeat] = ACTIONS(4419),
    [anon_sym_exit] = ACTIONS(4419),
    [anon_sym_EXIT] = ACTIONS(4419),
    [anon_sym_Exit] = ACTIONS(4419),
    [anon_sym_continue] = ACTIONS(4419),
    [anon_sym_CONTINUE] = ACTIONS(4419),
    [anon_sym_Continue] = ACTIONS(4419),
    [anon_sym_break] = ACTIONS(4419),
    [anon_sym_BREAK] = ACTIONS(4419),
    [anon_sym_Break] = ACTIONS(4419),
    [anon_sym_with] = ACTIONS(4419),
    [anon_sym_WITH] = ACTIONS(4419),
    [anon_sym_With] = ACTIONS(4419),
    [sym_asserterror_keyword] = ACTIONS(4421),
    [sym_page_keyword] = ACTIONS(4419),
    [anon_sym_codeunit] = ACTIONS(4419),
    [anon_sym_CODEUNIT] = ACTIONS(4419),
    [anon_sym_Codeunit] = ACTIONS(4419),
    [anon_sym_CodeUnit] = ACTIONS(4419),
    [anon_sym_COdeunit] = ACTIONS(4419),
    [anon_sym_codeUnit] = ACTIONS(4419),
    [sym_report_keyword] = ACTIONS(4419),
    [sym_query_keyword] = ACTIONS(4419),
    [anon_sym_xmlport] = ACTIONS(4419),
    [anon_sym_XMLPORT] = ACTIONS(4419),
    [anon_sym_Xmlport] = ACTIONS(4419),
    [anon_sym_XMLport] = ACTIONS(4419),
    [anon_sym_XMLPort] = ACTIONS(4419),
    [anon_sym_XmlPort] = ACTIONS(4419),
    [anon_sym_enum] = ACTIONS(4419),
    [anon_sym_ENUM] = ACTIONS(4419),
    [anon_sym_Enum] = ACTIONS(4419),
    [anon_sym_eNUM] = ACTIONS(4419),
    [anon_sym_eNum] = ACTIONS(4419),
    [anon_sym_ENum] = ACTIONS(4419),
    [sym_quoted_identifier] = ACTIONS(4421),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4421),
    [sym_integer] = ACTIONS(4419),
    [sym_continue_as_identifier] = ACTIONS(4421),
    [sym_preproc_open] = ACTIONS(4421),
    [sym_preproc_close] = ACTIONS(4421),
  },
  [STATE(1612)] = {
    [sym_identifier] = ACTIONS(4423),
    [anon_sym_SEMI] = ACTIONS(4425),
    [anon_sym_DASH] = ACTIONS(4425),
    [aux_sym_boolean_token1] = ACTIONS(4423),
    [aux_sym_boolean_token2] = ACTIONS(4423),
    [sym_decimal] = ACTIONS(4423),
    [anon_sym_LPAREN] = ACTIONS(4425),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4423),
    [anon_sym_LBRACK] = ACTIONS(4425),
    [aux_sym_record_type_token1] = ACTIONS(4423),
    [aux_sym_basic_type_token21] = ACTIONS(4423),
    [aux_sym_basic_type_token22] = ACTIONS(4423),
    [aux_sym_basic_type_token48] = ACTIONS(4423),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4423),
    [anon_sym_POUNDif] = ACTIONS(4425),
    [anon_sym_POUNDIF] = ACTIONS(4425),
    [anon_sym_POUNDIf] = ACTIONS(4425),
    [anon_sym_not] = ACTIONS(4423),
    [anon_sym_NOT] = ACTIONS(4423),
    [anon_sym_Not] = ACTIONS(4423),
    [anon_sym_POUNDelif] = ACTIONS(4425),
    [anon_sym_POUNDELIF] = ACTIONS(4425),
    [anon_sym_POUNDElif] = ACTIONS(4425),
    [anon_sym_POUNDelse] = ACTIONS(4425),
    [anon_sym_POUNDELSE] = ACTIONS(4425),
    [anon_sym_POUNDElse] = ACTIONS(4425),
    [anon_sym_POUNDendif] = ACTIONS(4425),
    [anon_sym_POUNDENDIF] = ACTIONS(4425),
    [anon_sym_POUNDEndif] = ACTIONS(4425),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4423),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4423),
    [anon_sym_PLUS] = ACTIONS(4425),
    [sym_datetime_literal] = ACTIONS(4425),
    [sym_date_literal] = ACTIONS(4423),
    [sym_time_literal] = ACTIONS(4423),
    [sym_biginteger_literal] = ACTIONS(4425),
    [anon_sym_if] = ACTIONS(4423),
    [anon_sym_IF] = ACTIONS(4423),
    [anon_sym_If] = ACTIONS(4423),
    [anon_sym_else] = ACTIONS(4423),
    [anon_sym_ELSE] = ACTIONS(4423),
    [anon_sym_Else] = ACTIONS(4423),
    [anon_sym_case] = ACTIONS(4423),
    [anon_sym_CASE] = ACTIONS(4423),
    [anon_sym_Case] = ACTIONS(4423),
    [anon_sym_for] = ACTIONS(4423),
    [anon_sym_FOR] = ACTIONS(4423),
    [anon_sym_For] = ACTIONS(4423),
    [anon_sym_foreach] = ACTIONS(4423),
    [anon_sym_FOREACH] = ACTIONS(4423),
    [anon_sym_Foreach] = ACTIONS(4423),
    [anon_sym_while] = ACTIONS(4423),
    [anon_sym_WHILE] = ACTIONS(4423),
    [anon_sym_While] = ACTIONS(4423),
    [anon_sym_repeat] = ACTIONS(4423),
    [anon_sym_REPEAT] = ACTIONS(4423),
    [anon_sym_Repeat] = ACTIONS(4423),
    [anon_sym_exit] = ACTIONS(4423),
    [anon_sym_EXIT] = ACTIONS(4423),
    [anon_sym_Exit] = ACTIONS(4423),
    [anon_sym_continue] = ACTIONS(4423),
    [anon_sym_CONTINUE] = ACTIONS(4423),
    [anon_sym_Continue] = ACTIONS(4423),
    [anon_sym_break] = ACTIONS(4423),
    [anon_sym_BREAK] = ACTIONS(4423),
    [anon_sym_Break] = ACTIONS(4423),
    [anon_sym_with] = ACTIONS(4423),
    [anon_sym_WITH] = ACTIONS(4423),
    [anon_sym_With] = ACTIONS(4423),
    [sym_asserterror_keyword] = ACTIONS(4425),
    [sym_page_keyword] = ACTIONS(4423),
    [anon_sym_codeunit] = ACTIONS(4423),
    [anon_sym_CODEUNIT] = ACTIONS(4423),
    [anon_sym_Codeunit] = ACTIONS(4423),
    [anon_sym_CodeUnit] = ACTIONS(4423),
    [anon_sym_COdeunit] = ACTIONS(4423),
    [anon_sym_codeUnit] = ACTIONS(4423),
    [sym_report_keyword] = ACTIONS(4423),
    [sym_query_keyword] = ACTIONS(4423),
    [anon_sym_xmlport] = ACTIONS(4423),
    [anon_sym_XMLPORT] = ACTIONS(4423),
    [anon_sym_Xmlport] = ACTIONS(4423),
    [anon_sym_XMLport] = ACTIONS(4423),
    [anon_sym_XMLPort] = ACTIONS(4423),
    [anon_sym_XmlPort] = ACTIONS(4423),
    [anon_sym_enum] = ACTIONS(4423),
    [anon_sym_ENUM] = ACTIONS(4423),
    [anon_sym_Enum] = ACTIONS(4423),
    [anon_sym_eNUM] = ACTIONS(4423),
    [anon_sym_eNum] = ACTIONS(4423),
    [anon_sym_ENum] = ACTIONS(4423),
    [sym_quoted_identifier] = ACTIONS(4425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4425),
    [sym_integer] = ACTIONS(4423),
    [sym_continue_as_identifier] = ACTIONS(4425),
    [sym_preproc_open] = ACTIONS(4425),
    [sym_preproc_close] = ACTIONS(4425),
  },
  [STATE(1613)] = {
    [sym_identifier] = ACTIONS(4427),
    [anon_sym_SEMI] = ACTIONS(4429),
    [anon_sym_DASH] = ACTIONS(4429),
    [aux_sym_boolean_token1] = ACTIONS(4427),
    [aux_sym_boolean_token2] = ACTIONS(4427),
    [sym_decimal] = ACTIONS(4427),
    [anon_sym_LPAREN] = ACTIONS(4429),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4427),
    [anon_sym_LBRACK] = ACTIONS(4429),
    [aux_sym_record_type_token1] = ACTIONS(4427),
    [aux_sym_basic_type_token21] = ACTIONS(4427),
    [aux_sym_basic_type_token22] = ACTIONS(4427),
    [aux_sym_basic_type_token48] = ACTIONS(4427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4427),
    [anon_sym_POUNDif] = ACTIONS(4429),
    [anon_sym_POUNDIF] = ACTIONS(4429),
    [anon_sym_POUNDIf] = ACTIONS(4429),
    [anon_sym_not] = ACTIONS(4427),
    [anon_sym_NOT] = ACTIONS(4427),
    [anon_sym_Not] = ACTIONS(4427),
    [anon_sym_POUNDelif] = ACTIONS(4429),
    [anon_sym_POUNDELIF] = ACTIONS(4429),
    [anon_sym_POUNDElif] = ACTIONS(4429),
    [anon_sym_POUNDelse] = ACTIONS(4429),
    [anon_sym_POUNDELSE] = ACTIONS(4429),
    [anon_sym_POUNDElse] = ACTIONS(4429),
    [anon_sym_POUNDendif] = ACTIONS(4429),
    [anon_sym_POUNDENDIF] = ACTIONS(4429),
    [anon_sym_POUNDEndif] = ACTIONS(4429),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4427),
    [anon_sym_PLUS] = ACTIONS(4429),
    [sym_datetime_literal] = ACTIONS(4429),
    [sym_date_literal] = ACTIONS(4427),
    [sym_time_literal] = ACTIONS(4427),
    [sym_biginteger_literal] = ACTIONS(4429),
    [anon_sym_if] = ACTIONS(4427),
    [anon_sym_IF] = ACTIONS(4427),
    [anon_sym_If] = ACTIONS(4427),
    [anon_sym_else] = ACTIONS(4427),
    [anon_sym_ELSE] = ACTIONS(4427),
    [anon_sym_Else] = ACTIONS(4427),
    [anon_sym_case] = ACTIONS(4427),
    [anon_sym_CASE] = ACTIONS(4427),
    [anon_sym_Case] = ACTIONS(4427),
    [anon_sym_for] = ACTIONS(4427),
    [anon_sym_FOR] = ACTIONS(4427),
    [anon_sym_For] = ACTIONS(4427),
    [anon_sym_foreach] = ACTIONS(4427),
    [anon_sym_FOREACH] = ACTIONS(4427),
    [anon_sym_Foreach] = ACTIONS(4427),
    [anon_sym_while] = ACTIONS(4427),
    [anon_sym_WHILE] = ACTIONS(4427),
    [anon_sym_While] = ACTIONS(4427),
    [anon_sym_repeat] = ACTIONS(4427),
    [anon_sym_REPEAT] = ACTIONS(4427),
    [anon_sym_Repeat] = ACTIONS(4427),
    [anon_sym_exit] = ACTIONS(4427),
    [anon_sym_EXIT] = ACTIONS(4427),
    [anon_sym_Exit] = ACTIONS(4427),
    [anon_sym_continue] = ACTIONS(4427),
    [anon_sym_CONTINUE] = ACTIONS(4427),
    [anon_sym_Continue] = ACTIONS(4427),
    [anon_sym_break] = ACTIONS(4427),
    [anon_sym_BREAK] = ACTIONS(4427),
    [anon_sym_Break] = ACTIONS(4427),
    [anon_sym_with] = ACTIONS(4427),
    [anon_sym_WITH] = ACTIONS(4427),
    [anon_sym_With] = ACTIONS(4427),
    [sym_asserterror_keyword] = ACTIONS(4429),
    [sym_page_keyword] = ACTIONS(4427),
    [anon_sym_codeunit] = ACTIONS(4427),
    [anon_sym_CODEUNIT] = ACTIONS(4427),
    [anon_sym_Codeunit] = ACTIONS(4427),
    [anon_sym_CodeUnit] = ACTIONS(4427),
    [anon_sym_COdeunit] = ACTIONS(4427),
    [anon_sym_codeUnit] = ACTIONS(4427),
    [sym_report_keyword] = ACTIONS(4427),
    [sym_query_keyword] = ACTIONS(4427),
    [anon_sym_xmlport] = ACTIONS(4427),
    [anon_sym_XMLPORT] = ACTIONS(4427),
    [anon_sym_Xmlport] = ACTIONS(4427),
    [anon_sym_XMLport] = ACTIONS(4427),
    [anon_sym_XMLPort] = ACTIONS(4427),
    [anon_sym_XmlPort] = ACTIONS(4427),
    [anon_sym_enum] = ACTIONS(4427),
    [anon_sym_ENUM] = ACTIONS(4427),
    [anon_sym_Enum] = ACTIONS(4427),
    [anon_sym_eNUM] = ACTIONS(4427),
    [anon_sym_eNum] = ACTIONS(4427),
    [anon_sym_ENum] = ACTIONS(4427),
    [sym_quoted_identifier] = ACTIONS(4429),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4429),
    [sym_integer] = ACTIONS(4427),
    [sym_continue_as_identifier] = ACTIONS(4429),
    [sym_preproc_open] = ACTIONS(4429),
    [sym_preproc_close] = ACTIONS(4429),
  },
  [STATE(1614)] = {
    [sym_identifier] = ACTIONS(4431),
    [anon_sym_SEMI] = ACTIONS(4433),
    [anon_sym_DASH] = ACTIONS(4433),
    [aux_sym_boolean_token1] = ACTIONS(4431),
    [aux_sym_boolean_token2] = ACTIONS(4431),
    [sym_decimal] = ACTIONS(4431),
    [anon_sym_LPAREN] = ACTIONS(4433),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4431),
    [anon_sym_LBRACK] = ACTIONS(4433),
    [aux_sym_record_type_token1] = ACTIONS(4431),
    [aux_sym_basic_type_token21] = ACTIONS(4431),
    [aux_sym_basic_type_token22] = ACTIONS(4431),
    [aux_sym_basic_type_token48] = ACTIONS(4431),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4431),
    [anon_sym_POUNDif] = ACTIONS(4433),
    [anon_sym_POUNDIF] = ACTIONS(4433),
    [anon_sym_POUNDIf] = ACTIONS(4433),
    [anon_sym_not] = ACTIONS(4431),
    [anon_sym_NOT] = ACTIONS(4431),
    [anon_sym_Not] = ACTIONS(4431),
    [anon_sym_POUNDelif] = ACTIONS(4433),
    [anon_sym_POUNDELIF] = ACTIONS(4433),
    [anon_sym_POUNDElif] = ACTIONS(4433),
    [anon_sym_POUNDelse] = ACTIONS(4433),
    [anon_sym_POUNDELSE] = ACTIONS(4433),
    [anon_sym_POUNDElse] = ACTIONS(4433),
    [anon_sym_POUNDendif] = ACTIONS(4433),
    [anon_sym_POUNDENDIF] = ACTIONS(4433),
    [anon_sym_POUNDEndif] = ACTIONS(4433),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4431),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4431),
    [anon_sym_PLUS] = ACTIONS(4433),
    [sym_datetime_literal] = ACTIONS(4433),
    [sym_date_literal] = ACTIONS(4431),
    [sym_time_literal] = ACTIONS(4431),
    [sym_biginteger_literal] = ACTIONS(4433),
    [anon_sym_if] = ACTIONS(4431),
    [anon_sym_IF] = ACTIONS(4431),
    [anon_sym_If] = ACTIONS(4431),
    [anon_sym_else] = ACTIONS(4431),
    [anon_sym_ELSE] = ACTIONS(4431),
    [anon_sym_Else] = ACTIONS(4431),
    [anon_sym_case] = ACTIONS(4431),
    [anon_sym_CASE] = ACTIONS(4431),
    [anon_sym_Case] = ACTIONS(4431),
    [anon_sym_for] = ACTIONS(4431),
    [anon_sym_FOR] = ACTIONS(4431),
    [anon_sym_For] = ACTIONS(4431),
    [anon_sym_foreach] = ACTIONS(4431),
    [anon_sym_FOREACH] = ACTIONS(4431),
    [anon_sym_Foreach] = ACTIONS(4431),
    [anon_sym_while] = ACTIONS(4431),
    [anon_sym_WHILE] = ACTIONS(4431),
    [anon_sym_While] = ACTIONS(4431),
    [anon_sym_repeat] = ACTIONS(4431),
    [anon_sym_REPEAT] = ACTIONS(4431),
    [anon_sym_Repeat] = ACTIONS(4431),
    [anon_sym_exit] = ACTIONS(4431),
    [anon_sym_EXIT] = ACTIONS(4431),
    [anon_sym_Exit] = ACTIONS(4431),
    [anon_sym_continue] = ACTIONS(4431),
    [anon_sym_CONTINUE] = ACTIONS(4431),
    [anon_sym_Continue] = ACTIONS(4431),
    [anon_sym_break] = ACTIONS(4431),
    [anon_sym_BREAK] = ACTIONS(4431),
    [anon_sym_Break] = ACTIONS(4431),
    [anon_sym_with] = ACTIONS(4431),
    [anon_sym_WITH] = ACTIONS(4431),
    [anon_sym_With] = ACTIONS(4431),
    [sym_asserterror_keyword] = ACTIONS(4433),
    [sym_page_keyword] = ACTIONS(4431),
    [anon_sym_codeunit] = ACTIONS(4431),
    [anon_sym_CODEUNIT] = ACTIONS(4431),
    [anon_sym_Codeunit] = ACTIONS(4431),
    [anon_sym_CodeUnit] = ACTIONS(4431),
    [anon_sym_COdeunit] = ACTIONS(4431),
    [anon_sym_codeUnit] = ACTIONS(4431),
    [sym_report_keyword] = ACTIONS(4431),
    [sym_query_keyword] = ACTIONS(4431),
    [anon_sym_xmlport] = ACTIONS(4431),
    [anon_sym_XMLPORT] = ACTIONS(4431),
    [anon_sym_Xmlport] = ACTIONS(4431),
    [anon_sym_XMLport] = ACTIONS(4431),
    [anon_sym_XMLPort] = ACTIONS(4431),
    [anon_sym_XmlPort] = ACTIONS(4431),
    [anon_sym_enum] = ACTIONS(4431),
    [anon_sym_ENUM] = ACTIONS(4431),
    [anon_sym_Enum] = ACTIONS(4431),
    [anon_sym_eNUM] = ACTIONS(4431),
    [anon_sym_eNum] = ACTIONS(4431),
    [anon_sym_ENum] = ACTIONS(4431),
    [sym_quoted_identifier] = ACTIONS(4433),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4433),
    [sym_integer] = ACTIONS(4431),
    [sym_continue_as_identifier] = ACTIONS(4433),
    [sym_preproc_open] = ACTIONS(4433),
    [sym_preproc_close] = ACTIONS(4433),
  },
  [STATE(1615)] = {
    [sym_identifier] = ACTIONS(4435),
    [anon_sym_SEMI] = ACTIONS(4437),
    [anon_sym_DASH] = ACTIONS(4437),
    [aux_sym_boolean_token1] = ACTIONS(4435),
    [aux_sym_boolean_token2] = ACTIONS(4435),
    [sym_decimal] = ACTIONS(4435),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4435),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [aux_sym_record_type_token1] = ACTIONS(4435),
    [aux_sym_basic_type_token21] = ACTIONS(4435),
    [aux_sym_basic_type_token22] = ACTIONS(4435),
    [aux_sym_basic_type_token48] = ACTIONS(4435),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4435),
    [anon_sym_POUNDif] = ACTIONS(4437),
    [anon_sym_POUNDIF] = ACTIONS(4437),
    [anon_sym_POUNDIf] = ACTIONS(4437),
    [anon_sym_not] = ACTIONS(4435),
    [anon_sym_NOT] = ACTIONS(4435),
    [anon_sym_Not] = ACTIONS(4435),
    [anon_sym_POUNDelif] = ACTIONS(4437),
    [anon_sym_POUNDELIF] = ACTIONS(4437),
    [anon_sym_POUNDElif] = ACTIONS(4437),
    [anon_sym_POUNDelse] = ACTIONS(4437),
    [anon_sym_POUNDELSE] = ACTIONS(4437),
    [anon_sym_POUNDElse] = ACTIONS(4437),
    [anon_sym_POUNDendif] = ACTIONS(4437),
    [anon_sym_POUNDENDIF] = ACTIONS(4437),
    [anon_sym_POUNDEndif] = ACTIONS(4437),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4435),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4435),
    [anon_sym_PLUS] = ACTIONS(4437),
    [sym_datetime_literal] = ACTIONS(4437),
    [sym_date_literal] = ACTIONS(4435),
    [sym_time_literal] = ACTIONS(4435),
    [sym_biginteger_literal] = ACTIONS(4437),
    [anon_sym_if] = ACTIONS(4435),
    [anon_sym_IF] = ACTIONS(4435),
    [anon_sym_If] = ACTIONS(4435),
    [anon_sym_else] = ACTIONS(4435),
    [anon_sym_ELSE] = ACTIONS(4435),
    [anon_sym_Else] = ACTIONS(4435),
    [anon_sym_case] = ACTIONS(4435),
    [anon_sym_CASE] = ACTIONS(4435),
    [anon_sym_Case] = ACTIONS(4435),
    [anon_sym_for] = ACTIONS(4435),
    [anon_sym_FOR] = ACTIONS(4435),
    [anon_sym_For] = ACTIONS(4435),
    [anon_sym_foreach] = ACTIONS(4435),
    [anon_sym_FOREACH] = ACTIONS(4435),
    [anon_sym_Foreach] = ACTIONS(4435),
    [anon_sym_while] = ACTIONS(4435),
    [anon_sym_WHILE] = ACTIONS(4435),
    [anon_sym_While] = ACTIONS(4435),
    [anon_sym_repeat] = ACTIONS(4435),
    [anon_sym_REPEAT] = ACTIONS(4435),
    [anon_sym_Repeat] = ACTIONS(4435),
    [anon_sym_exit] = ACTIONS(4435),
    [anon_sym_EXIT] = ACTIONS(4435),
    [anon_sym_Exit] = ACTIONS(4435),
    [anon_sym_continue] = ACTIONS(4435),
    [anon_sym_CONTINUE] = ACTIONS(4435),
    [anon_sym_Continue] = ACTIONS(4435),
    [anon_sym_break] = ACTIONS(4435),
    [anon_sym_BREAK] = ACTIONS(4435),
    [anon_sym_Break] = ACTIONS(4435),
    [anon_sym_with] = ACTIONS(4435),
    [anon_sym_WITH] = ACTIONS(4435),
    [anon_sym_With] = ACTIONS(4435),
    [sym_asserterror_keyword] = ACTIONS(4437),
    [sym_page_keyword] = ACTIONS(4435),
    [anon_sym_codeunit] = ACTIONS(4435),
    [anon_sym_CODEUNIT] = ACTIONS(4435),
    [anon_sym_Codeunit] = ACTIONS(4435),
    [anon_sym_CodeUnit] = ACTIONS(4435),
    [anon_sym_COdeunit] = ACTIONS(4435),
    [anon_sym_codeUnit] = ACTIONS(4435),
    [sym_report_keyword] = ACTIONS(4435),
    [sym_query_keyword] = ACTIONS(4435),
    [anon_sym_xmlport] = ACTIONS(4435),
    [anon_sym_XMLPORT] = ACTIONS(4435),
    [anon_sym_Xmlport] = ACTIONS(4435),
    [anon_sym_XMLport] = ACTIONS(4435),
    [anon_sym_XMLPort] = ACTIONS(4435),
    [anon_sym_XmlPort] = ACTIONS(4435),
    [anon_sym_enum] = ACTIONS(4435),
    [anon_sym_ENUM] = ACTIONS(4435),
    [anon_sym_Enum] = ACTIONS(4435),
    [anon_sym_eNUM] = ACTIONS(4435),
    [anon_sym_eNum] = ACTIONS(4435),
    [anon_sym_ENum] = ACTIONS(4435),
    [sym_quoted_identifier] = ACTIONS(4437),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4437),
    [sym_integer] = ACTIONS(4435),
    [sym_continue_as_identifier] = ACTIONS(4437),
    [sym_preproc_open] = ACTIONS(4437),
    [sym_preproc_close] = ACTIONS(4437),
  },
  [STATE(1616)] = {
    [sym_identifier] = ACTIONS(4439),
    [anon_sym_SEMI] = ACTIONS(4441),
    [anon_sym_DASH] = ACTIONS(4441),
    [aux_sym_boolean_token1] = ACTIONS(4439),
    [aux_sym_boolean_token2] = ACTIONS(4439),
    [sym_decimal] = ACTIONS(4439),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4439),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [aux_sym_record_type_token1] = ACTIONS(4439),
    [aux_sym_basic_type_token21] = ACTIONS(4439),
    [aux_sym_basic_type_token22] = ACTIONS(4439),
    [aux_sym_basic_type_token48] = ACTIONS(4439),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4439),
    [anon_sym_POUNDif] = ACTIONS(4441),
    [anon_sym_POUNDIF] = ACTIONS(4441),
    [anon_sym_POUNDIf] = ACTIONS(4441),
    [anon_sym_not] = ACTIONS(4439),
    [anon_sym_NOT] = ACTIONS(4439),
    [anon_sym_Not] = ACTIONS(4439),
    [anon_sym_POUNDelif] = ACTIONS(4441),
    [anon_sym_POUNDELIF] = ACTIONS(4441),
    [anon_sym_POUNDElif] = ACTIONS(4441),
    [anon_sym_POUNDelse] = ACTIONS(4441),
    [anon_sym_POUNDELSE] = ACTIONS(4441),
    [anon_sym_POUNDElse] = ACTIONS(4441),
    [anon_sym_POUNDendif] = ACTIONS(4441),
    [anon_sym_POUNDENDIF] = ACTIONS(4441),
    [anon_sym_POUNDEndif] = ACTIONS(4441),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4439),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4439),
    [anon_sym_PLUS] = ACTIONS(4441),
    [sym_datetime_literal] = ACTIONS(4441),
    [sym_date_literal] = ACTIONS(4439),
    [sym_time_literal] = ACTIONS(4439),
    [sym_biginteger_literal] = ACTIONS(4441),
    [anon_sym_if] = ACTIONS(4439),
    [anon_sym_IF] = ACTIONS(4439),
    [anon_sym_If] = ACTIONS(4439),
    [anon_sym_else] = ACTIONS(4439),
    [anon_sym_ELSE] = ACTIONS(4439),
    [anon_sym_Else] = ACTIONS(4439),
    [anon_sym_case] = ACTIONS(4439),
    [anon_sym_CASE] = ACTIONS(4439),
    [anon_sym_Case] = ACTIONS(4439),
    [anon_sym_for] = ACTIONS(4439),
    [anon_sym_FOR] = ACTIONS(4439),
    [anon_sym_For] = ACTIONS(4439),
    [anon_sym_foreach] = ACTIONS(4439),
    [anon_sym_FOREACH] = ACTIONS(4439),
    [anon_sym_Foreach] = ACTIONS(4439),
    [anon_sym_while] = ACTIONS(4439),
    [anon_sym_WHILE] = ACTIONS(4439),
    [anon_sym_While] = ACTIONS(4439),
    [anon_sym_repeat] = ACTIONS(4439),
    [anon_sym_REPEAT] = ACTIONS(4439),
    [anon_sym_Repeat] = ACTIONS(4439),
    [anon_sym_exit] = ACTIONS(4439),
    [anon_sym_EXIT] = ACTIONS(4439),
    [anon_sym_Exit] = ACTIONS(4439),
    [anon_sym_continue] = ACTIONS(4439),
    [anon_sym_CONTINUE] = ACTIONS(4439),
    [anon_sym_Continue] = ACTIONS(4439),
    [anon_sym_break] = ACTIONS(4439),
    [anon_sym_BREAK] = ACTIONS(4439),
    [anon_sym_Break] = ACTIONS(4439),
    [anon_sym_with] = ACTIONS(4439),
    [anon_sym_WITH] = ACTIONS(4439),
    [anon_sym_With] = ACTIONS(4439),
    [sym_asserterror_keyword] = ACTIONS(4441),
    [sym_page_keyword] = ACTIONS(4439),
    [anon_sym_codeunit] = ACTIONS(4439),
    [anon_sym_CODEUNIT] = ACTIONS(4439),
    [anon_sym_Codeunit] = ACTIONS(4439),
    [anon_sym_CodeUnit] = ACTIONS(4439),
    [anon_sym_COdeunit] = ACTIONS(4439),
    [anon_sym_codeUnit] = ACTIONS(4439),
    [sym_report_keyword] = ACTIONS(4439),
    [sym_query_keyword] = ACTIONS(4439),
    [anon_sym_xmlport] = ACTIONS(4439),
    [anon_sym_XMLPORT] = ACTIONS(4439),
    [anon_sym_Xmlport] = ACTIONS(4439),
    [anon_sym_XMLport] = ACTIONS(4439),
    [anon_sym_XMLPort] = ACTIONS(4439),
    [anon_sym_XmlPort] = ACTIONS(4439),
    [anon_sym_enum] = ACTIONS(4439),
    [anon_sym_ENUM] = ACTIONS(4439),
    [anon_sym_Enum] = ACTIONS(4439),
    [anon_sym_eNUM] = ACTIONS(4439),
    [anon_sym_eNum] = ACTIONS(4439),
    [anon_sym_ENum] = ACTIONS(4439),
    [sym_quoted_identifier] = ACTIONS(4441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4441),
    [sym_integer] = ACTIONS(4439),
    [sym_continue_as_identifier] = ACTIONS(4441),
    [sym_preproc_open] = ACTIONS(4441),
    [sym_preproc_close] = ACTIONS(4441),
  },
  [STATE(1617)] = {
    [sym_identifier] = ACTIONS(4443),
    [anon_sym_SEMI] = ACTIONS(4445),
    [anon_sym_DASH] = ACTIONS(4445),
    [aux_sym_boolean_token1] = ACTIONS(4443),
    [aux_sym_boolean_token2] = ACTIONS(4443),
    [sym_decimal] = ACTIONS(4443),
    [anon_sym_LPAREN] = ACTIONS(4445),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4443),
    [anon_sym_LBRACK] = ACTIONS(4445),
    [aux_sym_record_type_token1] = ACTIONS(4443),
    [aux_sym_basic_type_token21] = ACTIONS(4443),
    [aux_sym_basic_type_token22] = ACTIONS(4443),
    [aux_sym_basic_type_token48] = ACTIONS(4443),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4443),
    [anon_sym_POUNDif] = ACTIONS(4445),
    [anon_sym_POUNDIF] = ACTIONS(4445),
    [anon_sym_POUNDIf] = ACTIONS(4445),
    [anon_sym_not] = ACTIONS(4443),
    [anon_sym_NOT] = ACTIONS(4443),
    [anon_sym_Not] = ACTIONS(4443),
    [anon_sym_POUNDelif] = ACTIONS(4445),
    [anon_sym_POUNDELIF] = ACTIONS(4445),
    [anon_sym_POUNDElif] = ACTIONS(4445),
    [anon_sym_POUNDelse] = ACTIONS(4445),
    [anon_sym_POUNDELSE] = ACTIONS(4445),
    [anon_sym_POUNDElse] = ACTIONS(4445),
    [anon_sym_POUNDendif] = ACTIONS(4445),
    [anon_sym_POUNDENDIF] = ACTIONS(4445),
    [anon_sym_POUNDEndif] = ACTIONS(4445),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4443),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4443),
    [anon_sym_PLUS] = ACTIONS(4445),
    [sym_datetime_literal] = ACTIONS(4445),
    [sym_date_literal] = ACTIONS(4443),
    [sym_time_literal] = ACTIONS(4443),
    [sym_biginteger_literal] = ACTIONS(4445),
    [anon_sym_if] = ACTIONS(4443),
    [anon_sym_IF] = ACTIONS(4443),
    [anon_sym_If] = ACTIONS(4443),
    [anon_sym_else] = ACTIONS(4443),
    [anon_sym_ELSE] = ACTIONS(4443),
    [anon_sym_Else] = ACTIONS(4443),
    [anon_sym_case] = ACTIONS(4443),
    [anon_sym_CASE] = ACTIONS(4443),
    [anon_sym_Case] = ACTIONS(4443),
    [anon_sym_for] = ACTIONS(4443),
    [anon_sym_FOR] = ACTIONS(4443),
    [anon_sym_For] = ACTIONS(4443),
    [anon_sym_foreach] = ACTIONS(4443),
    [anon_sym_FOREACH] = ACTIONS(4443),
    [anon_sym_Foreach] = ACTIONS(4443),
    [anon_sym_while] = ACTIONS(4443),
    [anon_sym_WHILE] = ACTIONS(4443),
    [anon_sym_While] = ACTIONS(4443),
    [anon_sym_repeat] = ACTIONS(4443),
    [anon_sym_REPEAT] = ACTIONS(4443),
    [anon_sym_Repeat] = ACTIONS(4443),
    [anon_sym_exit] = ACTIONS(4443),
    [anon_sym_EXIT] = ACTIONS(4443),
    [anon_sym_Exit] = ACTIONS(4443),
    [anon_sym_continue] = ACTIONS(4443),
    [anon_sym_CONTINUE] = ACTIONS(4443),
    [anon_sym_Continue] = ACTIONS(4443),
    [anon_sym_break] = ACTIONS(4443),
    [anon_sym_BREAK] = ACTIONS(4443),
    [anon_sym_Break] = ACTIONS(4443),
    [anon_sym_with] = ACTIONS(4443),
    [anon_sym_WITH] = ACTIONS(4443),
    [anon_sym_With] = ACTIONS(4443),
    [sym_asserterror_keyword] = ACTIONS(4445),
    [sym_page_keyword] = ACTIONS(4443),
    [anon_sym_codeunit] = ACTIONS(4443),
    [anon_sym_CODEUNIT] = ACTIONS(4443),
    [anon_sym_Codeunit] = ACTIONS(4443),
    [anon_sym_CodeUnit] = ACTIONS(4443),
    [anon_sym_COdeunit] = ACTIONS(4443),
    [anon_sym_codeUnit] = ACTIONS(4443),
    [sym_report_keyword] = ACTIONS(4443),
    [sym_query_keyword] = ACTIONS(4443),
    [anon_sym_xmlport] = ACTIONS(4443),
    [anon_sym_XMLPORT] = ACTIONS(4443),
    [anon_sym_Xmlport] = ACTIONS(4443),
    [anon_sym_XMLport] = ACTIONS(4443),
    [anon_sym_XMLPort] = ACTIONS(4443),
    [anon_sym_XmlPort] = ACTIONS(4443),
    [anon_sym_enum] = ACTIONS(4443),
    [anon_sym_ENUM] = ACTIONS(4443),
    [anon_sym_Enum] = ACTIONS(4443),
    [anon_sym_eNUM] = ACTIONS(4443),
    [anon_sym_eNum] = ACTIONS(4443),
    [anon_sym_ENum] = ACTIONS(4443),
    [sym_quoted_identifier] = ACTIONS(4445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4445),
    [sym_integer] = ACTIONS(4443),
    [sym_continue_as_identifier] = ACTIONS(4445),
    [sym_preproc_open] = ACTIONS(4445),
    [sym_preproc_close] = ACTIONS(4445),
  },
  [STATE(1618)] = {
    [sym_identifier] = ACTIONS(4447),
    [anon_sym_SEMI] = ACTIONS(4449),
    [anon_sym_DASH] = ACTIONS(4449),
    [aux_sym_boolean_token1] = ACTIONS(4447),
    [aux_sym_boolean_token2] = ACTIONS(4447),
    [sym_decimal] = ACTIONS(4447),
    [anon_sym_LPAREN] = ACTIONS(4449),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4447),
    [anon_sym_LBRACK] = ACTIONS(4449),
    [aux_sym_record_type_token1] = ACTIONS(4447),
    [aux_sym_basic_type_token21] = ACTIONS(4447),
    [aux_sym_basic_type_token22] = ACTIONS(4447),
    [aux_sym_basic_type_token48] = ACTIONS(4447),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4447),
    [anon_sym_POUNDif] = ACTIONS(4449),
    [anon_sym_POUNDIF] = ACTIONS(4449),
    [anon_sym_POUNDIf] = ACTIONS(4449),
    [anon_sym_not] = ACTIONS(4447),
    [anon_sym_NOT] = ACTIONS(4447),
    [anon_sym_Not] = ACTIONS(4447),
    [anon_sym_POUNDelif] = ACTIONS(4449),
    [anon_sym_POUNDELIF] = ACTIONS(4449),
    [anon_sym_POUNDElif] = ACTIONS(4449),
    [anon_sym_POUNDelse] = ACTIONS(4449),
    [anon_sym_POUNDELSE] = ACTIONS(4449),
    [anon_sym_POUNDElse] = ACTIONS(4449),
    [anon_sym_POUNDendif] = ACTIONS(4449),
    [anon_sym_POUNDENDIF] = ACTIONS(4449),
    [anon_sym_POUNDEndif] = ACTIONS(4449),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4447),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4447),
    [anon_sym_PLUS] = ACTIONS(4449),
    [sym_datetime_literal] = ACTIONS(4449),
    [sym_date_literal] = ACTIONS(4447),
    [sym_time_literal] = ACTIONS(4447),
    [sym_biginteger_literal] = ACTIONS(4449),
    [anon_sym_if] = ACTIONS(4447),
    [anon_sym_IF] = ACTIONS(4447),
    [anon_sym_If] = ACTIONS(4447),
    [anon_sym_else] = ACTIONS(4447),
    [anon_sym_ELSE] = ACTIONS(4447),
    [anon_sym_Else] = ACTIONS(4447),
    [anon_sym_case] = ACTIONS(4447),
    [anon_sym_CASE] = ACTIONS(4447),
    [anon_sym_Case] = ACTIONS(4447),
    [anon_sym_for] = ACTIONS(4447),
    [anon_sym_FOR] = ACTIONS(4447),
    [anon_sym_For] = ACTIONS(4447),
    [anon_sym_foreach] = ACTIONS(4447),
    [anon_sym_FOREACH] = ACTIONS(4447),
    [anon_sym_Foreach] = ACTIONS(4447),
    [anon_sym_while] = ACTIONS(4447),
    [anon_sym_WHILE] = ACTIONS(4447),
    [anon_sym_While] = ACTIONS(4447),
    [anon_sym_repeat] = ACTIONS(4447),
    [anon_sym_REPEAT] = ACTIONS(4447),
    [anon_sym_Repeat] = ACTIONS(4447),
    [anon_sym_exit] = ACTIONS(4447),
    [anon_sym_EXIT] = ACTIONS(4447),
    [anon_sym_Exit] = ACTIONS(4447),
    [anon_sym_continue] = ACTIONS(4447),
    [anon_sym_CONTINUE] = ACTIONS(4447),
    [anon_sym_Continue] = ACTIONS(4447),
    [anon_sym_break] = ACTIONS(4447),
    [anon_sym_BREAK] = ACTIONS(4447),
    [anon_sym_Break] = ACTIONS(4447),
    [anon_sym_with] = ACTIONS(4447),
    [anon_sym_WITH] = ACTIONS(4447),
    [anon_sym_With] = ACTIONS(4447),
    [sym_asserterror_keyword] = ACTIONS(4449),
    [sym_page_keyword] = ACTIONS(4447),
    [anon_sym_codeunit] = ACTIONS(4447),
    [anon_sym_CODEUNIT] = ACTIONS(4447),
    [anon_sym_Codeunit] = ACTIONS(4447),
    [anon_sym_CodeUnit] = ACTIONS(4447),
    [anon_sym_COdeunit] = ACTIONS(4447),
    [anon_sym_codeUnit] = ACTIONS(4447),
    [sym_report_keyword] = ACTIONS(4447),
    [sym_query_keyword] = ACTIONS(4447),
    [anon_sym_xmlport] = ACTIONS(4447),
    [anon_sym_XMLPORT] = ACTIONS(4447),
    [anon_sym_Xmlport] = ACTIONS(4447),
    [anon_sym_XMLport] = ACTIONS(4447),
    [anon_sym_XMLPort] = ACTIONS(4447),
    [anon_sym_XmlPort] = ACTIONS(4447),
    [anon_sym_enum] = ACTIONS(4447),
    [anon_sym_ENUM] = ACTIONS(4447),
    [anon_sym_Enum] = ACTIONS(4447),
    [anon_sym_eNUM] = ACTIONS(4447),
    [anon_sym_eNum] = ACTIONS(4447),
    [anon_sym_ENum] = ACTIONS(4447),
    [sym_quoted_identifier] = ACTIONS(4449),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4449),
    [sym_integer] = ACTIONS(4447),
    [sym_continue_as_identifier] = ACTIONS(4449),
    [sym_preproc_open] = ACTIONS(4449),
    [sym_preproc_close] = ACTIONS(4449),
  },
  [STATE(1619)] = {
    [sym_identifier] = ACTIONS(4451),
    [anon_sym_SEMI] = ACTIONS(4453),
    [anon_sym_DASH] = ACTIONS(4453),
    [aux_sym_boolean_token1] = ACTIONS(4451),
    [aux_sym_boolean_token2] = ACTIONS(4451),
    [sym_decimal] = ACTIONS(4451),
    [anon_sym_LPAREN] = ACTIONS(4453),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4451),
    [anon_sym_LBRACK] = ACTIONS(4453),
    [aux_sym_record_type_token1] = ACTIONS(4451),
    [aux_sym_basic_type_token21] = ACTIONS(4451),
    [aux_sym_basic_type_token22] = ACTIONS(4451),
    [aux_sym_basic_type_token48] = ACTIONS(4451),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4451),
    [anon_sym_POUNDif] = ACTIONS(4453),
    [anon_sym_POUNDIF] = ACTIONS(4453),
    [anon_sym_POUNDIf] = ACTIONS(4453),
    [anon_sym_not] = ACTIONS(4451),
    [anon_sym_NOT] = ACTIONS(4451),
    [anon_sym_Not] = ACTIONS(4451),
    [anon_sym_POUNDelif] = ACTIONS(4453),
    [anon_sym_POUNDELIF] = ACTIONS(4453),
    [anon_sym_POUNDElif] = ACTIONS(4453),
    [anon_sym_POUNDelse] = ACTIONS(4453),
    [anon_sym_POUNDELSE] = ACTIONS(4453),
    [anon_sym_POUNDElse] = ACTIONS(4453),
    [anon_sym_POUNDendif] = ACTIONS(4453),
    [anon_sym_POUNDENDIF] = ACTIONS(4453),
    [anon_sym_POUNDEndif] = ACTIONS(4453),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4451),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4451),
    [anon_sym_PLUS] = ACTIONS(4453),
    [sym_datetime_literal] = ACTIONS(4453),
    [sym_date_literal] = ACTIONS(4451),
    [sym_time_literal] = ACTIONS(4451),
    [sym_biginteger_literal] = ACTIONS(4453),
    [anon_sym_if] = ACTIONS(4451),
    [anon_sym_IF] = ACTIONS(4451),
    [anon_sym_If] = ACTIONS(4451),
    [anon_sym_else] = ACTIONS(4451),
    [anon_sym_ELSE] = ACTIONS(4451),
    [anon_sym_Else] = ACTIONS(4451),
    [anon_sym_case] = ACTIONS(4451),
    [anon_sym_CASE] = ACTIONS(4451),
    [anon_sym_Case] = ACTIONS(4451),
    [anon_sym_for] = ACTIONS(4451),
    [anon_sym_FOR] = ACTIONS(4451),
    [anon_sym_For] = ACTIONS(4451),
    [anon_sym_foreach] = ACTIONS(4451),
    [anon_sym_FOREACH] = ACTIONS(4451),
    [anon_sym_Foreach] = ACTIONS(4451),
    [anon_sym_while] = ACTIONS(4451),
    [anon_sym_WHILE] = ACTIONS(4451),
    [anon_sym_While] = ACTIONS(4451),
    [anon_sym_repeat] = ACTIONS(4451),
    [anon_sym_REPEAT] = ACTIONS(4451),
    [anon_sym_Repeat] = ACTIONS(4451),
    [anon_sym_exit] = ACTIONS(4451),
    [anon_sym_EXIT] = ACTIONS(4451),
    [anon_sym_Exit] = ACTIONS(4451),
    [anon_sym_continue] = ACTIONS(4451),
    [anon_sym_CONTINUE] = ACTIONS(4451),
    [anon_sym_Continue] = ACTIONS(4451),
    [anon_sym_break] = ACTIONS(4451),
    [anon_sym_BREAK] = ACTIONS(4451),
    [anon_sym_Break] = ACTIONS(4451),
    [anon_sym_with] = ACTIONS(4451),
    [anon_sym_WITH] = ACTIONS(4451),
    [anon_sym_With] = ACTIONS(4451),
    [sym_asserterror_keyword] = ACTIONS(4453),
    [sym_page_keyword] = ACTIONS(4451),
    [anon_sym_codeunit] = ACTIONS(4451),
    [anon_sym_CODEUNIT] = ACTIONS(4451),
    [anon_sym_Codeunit] = ACTIONS(4451),
    [anon_sym_CodeUnit] = ACTIONS(4451),
    [anon_sym_COdeunit] = ACTIONS(4451),
    [anon_sym_codeUnit] = ACTIONS(4451),
    [sym_report_keyword] = ACTIONS(4451),
    [sym_query_keyword] = ACTIONS(4451),
    [anon_sym_xmlport] = ACTIONS(4451),
    [anon_sym_XMLPORT] = ACTIONS(4451),
    [anon_sym_Xmlport] = ACTIONS(4451),
    [anon_sym_XMLport] = ACTIONS(4451),
    [anon_sym_XMLPort] = ACTIONS(4451),
    [anon_sym_XmlPort] = ACTIONS(4451),
    [anon_sym_enum] = ACTIONS(4451),
    [anon_sym_ENUM] = ACTIONS(4451),
    [anon_sym_Enum] = ACTIONS(4451),
    [anon_sym_eNUM] = ACTIONS(4451),
    [anon_sym_eNum] = ACTIONS(4451),
    [anon_sym_ENum] = ACTIONS(4451),
    [sym_quoted_identifier] = ACTIONS(4453),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4453),
    [sym_integer] = ACTIONS(4451),
    [sym_continue_as_identifier] = ACTIONS(4453),
    [sym_preproc_open] = ACTIONS(4453),
    [sym_preproc_close] = ACTIONS(4453),
  },
  [STATE(1620)] = {
    [sym_identifier] = ACTIONS(4455),
    [anon_sym_SEMI] = ACTIONS(4457),
    [anon_sym_DASH] = ACTIONS(4457),
    [aux_sym_boolean_token1] = ACTIONS(4455),
    [aux_sym_boolean_token2] = ACTIONS(4455),
    [sym_decimal] = ACTIONS(4455),
    [anon_sym_LPAREN] = ACTIONS(4457),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4455),
    [anon_sym_LBRACK] = ACTIONS(4457),
    [aux_sym_record_type_token1] = ACTIONS(4455),
    [aux_sym_basic_type_token21] = ACTIONS(4455),
    [aux_sym_basic_type_token22] = ACTIONS(4455),
    [aux_sym_basic_type_token48] = ACTIONS(4455),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(4457),
    [anon_sym_POUNDIF] = ACTIONS(4457),
    [anon_sym_POUNDIf] = ACTIONS(4457),
    [anon_sym_not] = ACTIONS(4455),
    [anon_sym_NOT] = ACTIONS(4455),
    [anon_sym_Not] = ACTIONS(4455),
    [anon_sym_POUNDelif] = ACTIONS(4457),
    [anon_sym_POUNDELIF] = ACTIONS(4457),
    [anon_sym_POUNDElif] = ACTIONS(4457),
    [anon_sym_POUNDelse] = ACTIONS(4457),
    [anon_sym_POUNDELSE] = ACTIONS(4457),
    [anon_sym_POUNDElse] = ACTIONS(4457),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4455),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4455),
    [anon_sym_PLUS] = ACTIONS(4457),
    [sym_datetime_literal] = ACTIONS(4457),
    [sym_date_literal] = ACTIONS(4455),
    [sym_time_literal] = ACTIONS(4455),
    [sym_biginteger_literal] = ACTIONS(4457),
    [anon_sym_if] = ACTIONS(4455),
    [anon_sym_IF] = ACTIONS(4455),
    [anon_sym_If] = ACTIONS(4455),
    [anon_sym_else] = ACTIONS(4455),
    [anon_sym_ELSE] = ACTIONS(4455),
    [anon_sym_Else] = ACTIONS(4455),
    [anon_sym_case] = ACTIONS(4455),
    [anon_sym_CASE] = ACTIONS(4455),
    [anon_sym_Case] = ACTIONS(4455),
    [anon_sym_for] = ACTIONS(4455),
    [anon_sym_FOR] = ACTIONS(4455),
    [anon_sym_For] = ACTIONS(4455),
    [anon_sym_foreach] = ACTIONS(4455),
    [anon_sym_FOREACH] = ACTIONS(4455),
    [anon_sym_Foreach] = ACTIONS(4455),
    [anon_sym_while] = ACTIONS(4455),
    [anon_sym_WHILE] = ACTIONS(4455),
    [anon_sym_While] = ACTIONS(4455),
    [anon_sym_repeat] = ACTIONS(4455),
    [anon_sym_REPEAT] = ACTIONS(4455),
    [anon_sym_Repeat] = ACTIONS(4455),
    [anon_sym_exit] = ACTIONS(4455),
    [anon_sym_EXIT] = ACTIONS(4455),
    [anon_sym_Exit] = ACTIONS(4455),
    [anon_sym_continue] = ACTIONS(4455),
    [anon_sym_CONTINUE] = ACTIONS(4455),
    [anon_sym_Continue] = ACTIONS(4455),
    [anon_sym_break] = ACTIONS(4455),
    [anon_sym_BREAK] = ACTIONS(4455),
    [anon_sym_Break] = ACTIONS(4455),
    [anon_sym_with] = ACTIONS(4455),
    [anon_sym_WITH] = ACTIONS(4455),
    [anon_sym_With] = ACTIONS(4455),
    [sym_asserterror_keyword] = ACTIONS(4457),
    [sym_page_keyword] = ACTIONS(4455),
    [anon_sym_codeunit] = ACTIONS(4455),
    [anon_sym_CODEUNIT] = ACTIONS(4455),
    [anon_sym_Codeunit] = ACTIONS(4455),
    [anon_sym_CodeUnit] = ACTIONS(4455),
    [anon_sym_COdeunit] = ACTIONS(4455),
    [anon_sym_codeUnit] = ACTIONS(4455),
    [sym_report_keyword] = ACTIONS(4455),
    [sym_query_keyword] = ACTIONS(4455),
    [anon_sym_xmlport] = ACTIONS(4455),
    [anon_sym_XMLPORT] = ACTIONS(4455),
    [anon_sym_Xmlport] = ACTIONS(4455),
    [anon_sym_XMLport] = ACTIONS(4455),
    [anon_sym_XMLPort] = ACTIONS(4455),
    [anon_sym_XmlPort] = ACTIONS(4455),
    [anon_sym_enum] = ACTIONS(4455),
    [anon_sym_ENUM] = ACTIONS(4455),
    [anon_sym_Enum] = ACTIONS(4455),
    [anon_sym_eNUM] = ACTIONS(4455),
    [anon_sym_eNum] = ACTIONS(4455),
    [anon_sym_ENum] = ACTIONS(4455),
    [sym_quoted_identifier] = ACTIONS(4457),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4457),
    [sym_integer] = ACTIONS(4455),
    [sym_continue_as_identifier] = ACTIONS(4457),
    [sym_preproc_open] = ACTIONS(4457),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(1621)] = {
    [sym_identifier] = ACTIONS(4459),
    [anon_sym_SEMI] = ACTIONS(4461),
    [anon_sym_DASH] = ACTIONS(4461),
    [aux_sym_boolean_token1] = ACTIONS(4459),
    [aux_sym_boolean_token2] = ACTIONS(4459),
    [sym_decimal] = ACTIONS(4459),
    [anon_sym_LPAREN] = ACTIONS(4461),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4459),
    [anon_sym_LBRACK] = ACTIONS(4461),
    [aux_sym_record_type_token1] = ACTIONS(4459),
    [aux_sym_basic_type_token21] = ACTIONS(4459),
    [aux_sym_basic_type_token22] = ACTIONS(4459),
    [aux_sym_basic_type_token48] = ACTIONS(4459),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4459),
    [anon_sym_POUNDif] = ACTIONS(4461),
    [anon_sym_POUNDIF] = ACTIONS(4461),
    [anon_sym_POUNDIf] = ACTIONS(4461),
    [anon_sym_not] = ACTIONS(4459),
    [anon_sym_NOT] = ACTIONS(4459),
    [anon_sym_Not] = ACTIONS(4459),
    [anon_sym_POUNDelif] = ACTIONS(4461),
    [anon_sym_POUNDELIF] = ACTIONS(4461),
    [anon_sym_POUNDElif] = ACTIONS(4461),
    [anon_sym_POUNDelse] = ACTIONS(4461),
    [anon_sym_POUNDELSE] = ACTIONS(4461),
    [anon_sym_POUNDElse] = ACTIONS(4461),
    [anon_sym_POUNDendif] = ACTIONS(4461),
    [anon_sym_POUNDENDIF] = ACTIONS(4461),
    [anon_sym_POUNDEndif] = ACTIONS(4461),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4459),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4459),
    [anon_sym_PLUS] = ACTIONS(4461),
    [sym_datetime_literal] = ACTIONS(4461),
    [sym_date_literal] = ACTIONS(4459),
    [sym_time_literal] = ACTIONS(4459),
    [sym_biginteger_literal] = ACTIONS(4461),
    [anon_sym_if] = ACTIONS(4459),
    [anon_sym_IF] = ACTIONS(4459),
    [anon_sym_If] = ACTIONS(4459),
    [anon_sym_else] = ACTIONS(4459),
    [anon_sym_ELSE] = ACTIONS(4459),
    [anon_sym_Else] = ACTIONS(4459),
    [anon_sym_case] = ACTIONS(4459),
    [anon_sym_CASE] = ACTIONS(4459),
    [anon_sym_Case] = ACTIONS(4459),
    [anon_sym_for] = ACTIONS(4459),
    [anon_sym_FOR] = ACTIONS(4459),
    [anon_sym_For] = ACTIONS(4459),
    [anon_sym_foreach] = ACTIONS(4459),
    [anon_sym_FOREACH] = ACTIONS(4459),
    [anon_sym_Foreach] = ACTIONS(4459),
    [anon_sym_while] = ACTIONS(4459),
    [anon_sym_WHILE] = ACTIONS(4459),
    [anon_sym_While] = ACTIONS(4459),
    [anon_sym_repeat] = ACTIONS(4459),
    [anon_sym_REPEAT] = ACTIONS(4459),
    [anon_sym_Repeat] = ACTIONS(4459),
    [anon_sym_exit] = ACTIONS(4459),
    [anon_sym_EXIT] = ACTIONS(4459),
    [anon_sym_Exit] = ACTIONS(4459),
    [anon_sym_continue] = ACTIONS(4459),
    [anon_sym_CONTINUE] = ACTIONS(4459),
    [anon_sym_Continue] = ACTIONS(4459),
    [anon_sym_break] = ACTIONS(4459),
    [anon_sym_BREAK] = ACTIONS(4459),
    [anon_sym_Break] = ACTIONS(4459),
    [anon_sym_with] = ACTIONS(4459),
    [anon_sym_WITH] = ACTIONS(4459),
    [anon_sym_With] = ACTIONS(4459),
    [sym_asserterror_keyword] = ACTIONS(4461),
    [sym_page_keyword] = ACTIONS(4459),
    [anon_sym_codeunit] = ACTIONS(4459),
    [anon_sym_CODEUNIT] = ACTIONS(4459),
    [anon_sym_Codeunit] = ACTIONS(4459),
    [anon_sym_CodeUnit] = ACTIONS(4459),
    [anon_sym_COdeunit] = ACTIONS(4459),
    [anon_sym_codeUnit] = ACTIONS(4459),
    [sym_report_keyword] = ACTIONS(4459),
    [sym_query_keyword] = ACTIONS(4459),
    [anon_sym_xmlport] = ACTIONS(4459),
    [anon_sym_XMLPORT] = ACTIONS(4459),
    [anon_sym_Xmlport] = ACTIONS(4459),
    [anon_sym_XMLport] = ACTIONS(4459),
    [anon_sym_XMLPort] = ACTIONS(4459),
    [anon_sym_XmlPort] = ACTIONS(4459),
    [anon_sym_enum] = ACTIONS(4459),
    [anon_sym_ENUM] = ACTIONS(4459),
    [anon_sym_Enum] = ACTIONS(4459),
    [anon_sym_eNUM] = ACTIONS(4459),
    [anon_sym_eNum] = ACTIONS(4459),
    [anon_sym_ENum] = ACTIONS(4459),
    [sym_quoted_identifier] = ACTIONS(4461),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4461),
    [sym_integer] = ACTIONS(4459),
    [sym_continue_as_identifier] = ACTIONS(4461),
    [sym_preproc_open] = ACTIONS(4461),
    [sym_preproc_close] = ACTIONS(4461),
  },
  [STATE(1622)] = {
    [sym_identifier] = ACTIONS(4463),
    [anon_sym_SEMI] = ACTIONS(4465),
    [anon_sym_DASH] = ACTIONS(4465),
    [aux_sym_boolean_token1] = ACTIONS(4463),
    [aux_sym_boolean_token2] = ACTIONS(4463),
    [sym_decimal] = ACTIONS(4463),
    [anon_sym_LPAREN] = ACTIONS(4465),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4463),
    [anon_sym_LBRACK] = ACTIONS(4465),
    [aux_sym_record_type_token1] = ACTIONS(4463),
    [aux_sym_basic_type_token21] = ACTIONS(4463),
    [aux_sym_basic_type_token22] = ACTIONS(4463),
    [aux_sym_basic_type_token48] = ACTIONS(4463),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4463),
    [anon_sym_POUNDif] = ACTIONS(4465),
    [anon_sym_POUNDIF] = ACTIONS(4465),
    [anon_sym_POUNDIf] = ACTIONS(4465),
    [anon_sym_not] = ACTIONS(4463),
    [anon_sym_NOT] = ACTIONS(4463),
    [anon_sym_Not] = ACTIONS(4463),
    [anon_sym_POUNDelif] = ACTIONS(4465),
    [anon_sym_POUNDELIF] = ACTIONS(4465),
    [anon_sym_POUNDElif] = ACTIONS(4465),
    [anon_sym_POUNDelse] = ACTIONS(4465),
    [anon_sym_POUNDELSE] = ACTIONS(4465),
    [anon_sym_POUNDElse] = ACTIONS(4465),
    [anon_sym_POUNDendif] = ACTIONS(4465),
    [anon_sym_POUNDENDIF] = ACTIONS(4465),
    [anon_sym_POUNDEndif] = ACTIONS(4465),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4463),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4463),
    [anon_sym_PLUS] = ACTIONS(4465),
    [sym_datetime_literal] = ACTIONS(4465),
    [sym_date_literal] = ACTIONS(4463),
    [sym_time_literal] = ACTIONS(4463),
    [sym_biginteger_literal] = ACTIONS(4465),
    [anon_sym_if] = ACTIONS(4463),
    [anon_sym_IF] = ACTIONS(4463),
    [anon_sym_If] = ACTIONS(4463),
    [anon_sym_else] = ACTIONS(4463),
    [anon_sym_ELSE] = ACTIONS(4463),
    [anon_sym_Else] = ACTIONS(4463),
    [anon_sym_case] = ACTIONS(4463),
    [anon_sym_CASE] = ACTIONS(4463),
    [anon_sym_Case] = ACTIONS(4463),
    [anon_sym_for] = ACTIONS(4463),
    [anon_sym_FOR] = ACTIONS(4463),
    [anon_sym_For] = ACTIONS(4463),
    [anon_sym_foreach] = ACTIONS(4463),
    [anon_sym_FOREACH] = ACTIONS(4463),
    [anon_sym_Foreach] = ACTIONS(4463),
    [anon_sym_while] = ACTIONS(4463),
    [anon_sym_WHILE] = ACTIONS(4463),
    [anon_sym_While] = ACTIONS(4463),
    [anon_sym_repeat] = ACTIONS(4463),
    [anon_sym_REPEAT] = ACTIONS(4463),
    [anon_sym_Repeat] = ACTIONS(4463),
    [anon_sym_exit] = ACTIONS(4463),
    [anon_sym_EXIT] = ACTIONS(4463),
    [anon_sym_Exit] = ACTIONS(4463),
    [anon_sym_continue] = ACTIONS(4463),
    [anon_sym_CONTINUE] = ACTIONS(4463),
    [anon_sym_Continue] = ACTIONS(4463),
    [anon_sym_break] = ACTIONS(4463),
    [anon_sym_BREAK] = ACTIONS(4463),
    [anon_sym_Break] = ACTIONS(4463),
    [anon_sym_with] = ACTIONS(4463),
    [anon_sym_WITH] = ACTIONS(4463),
    [anon_sym_With] = ACTIONS(4463),
    [sym_asserterror_keyword] = ACTIONS(4465),
    [sym_page_keyword] = ACTIONS(4463),
    [anon_sym_codeunit] = ACTIONS(4463),
    [anon_sym_CODEUNIT] = ACTIONS(4463),
    [anon_sym_Codeunit] = ACTIONS(4463),
    [anon_sym_CodeUnit] = ACTIONS(4463),
    [anon_sym_COdeunit] = ACTIONS(4463),
    [anon_sym_codeUnit] = ACTIONS(4463),
    [sym_report_keyword] = ACTIONS(4463),
    [sym_query_keyword] = ACTIONS(4463),
    [anon_sym_xmlport] = ACTIONS(4463),
    [anon_sym_XMLPORT] = ACTIONS(4463),
    [anon_sym_Xmlport] = ACTIONS(4463),
    [anon_sym_XMLport] = ACTIONS(4463),
    [anon_sym_XMLPort] = ACTIONS(4463),
    [anon_sym_XmlPort] = ACTIONS(4463),
    [anon_sym_enum] = ACTIONS(4463),
    [anon_sym_ENUM] = ACTIONS(4463),
    [anon_sym_Enum] = ACTIONS(4463),
    [anon_sym_eNUM] = ACTIONS(4463),
    [anon_sym_eNum] = ACTIONS(4463),
    [anon_sym_ENum] = ACTIONS(4463),
    [sym_quoted_identifier] = ACTIONS(4465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4465),
    [sym_integer] = ACTIONS(4463),
    [sym_continue_as_identifier] = ACTIONS(4465),
    [sym_preproc_open] = ACTIONS(4465),
    [sym_preproc_close] = ACTIONS(4465),
  },
  [STATE(1623)] = {
    [sym_identifier] = ACTIONS(4467),
    [anon_sym_SEMI] = ACTIONS(4469),
    [anon_sym_DASH] = ACTIONS(4469),
    [aux_sym_boolean_token1] = ACTIONS(4467),
    [aux_sym_boolean_token2] = ACTIONS(4467),
    [sym_decimal] = ACTIONS(4467),
    [anon_sym_LPAREN] = ACTIONS(4469),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4467),
    [anon_sym_LBRACK] = ACTIONS(4469),
    [aux_sym_record_type_token1] = ACTIONS(4467),
    [aux_sym_basic_type_token21] = ACTIONS(4467),
    [aux_sym_basic_type_token22] = ACTIONS(4467),
    [aux_sym_basic_type_token48] = ACTIONS(4467),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4467),
    [anon_sym_POUNDif] = ACTIONS(4469),
    [anon_sym_POUNDIF] = ACTIONS(4469),
    [anon_sym_POUNDIf] = ACTIONS(4469),
    [anon_sym_not] = ACTIONS(4467),
    [anon_sym_NOT] = ACTIONS(4467),
    [anon_sym_Not] = ACTIONS(4467),
    [anon_sym_POUNDelif] = ACTIONS(4469),
    [anon_sym_POUNDELIF] = ACTIONS(4469),
    [anon_sym_POUNDElif] = ACTIONS(4469),
    [anon_sym_POUNDelse] = ACTIONS(4469),
    [anon_sym_POUNDELSE] = ACTIONS(4469),
    [anon_sym_POUNDElse] = ACTIONS(4469),
    [anon_sym_POUNDendif] = ACTIONS(4469),
    [anon_sym_POUNDENDIF] = ACTIONS(4469),
    [anon_sym_POUNDEndif] = ACTIONS(4469),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4467),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4467),
    [anon_sym_PLUS] = ACTIONS(4469),
    [sym_datetime_literal] = ACTIONS(4469),
    [sym_date_literal] = ACTIONS(4467),
    [sym_time_literal] = ACTIONS(4467),
    [sym_biginteger_literal] = ACTIONS(4469),
    [anon_sym_if] = ACTIONS(4467),
    [anon_sym_IF] = ACTIONS(4467),
    [anon_sym_If] = ACTIONS(4467),
    [anon_sym_else] = ACTIONS(4467),
    [anon_sym_ELSE] = ACTIONS(4467),
    [anon_sym_Else] = ACTIONS(4467),
    [anon_sym_case] = ACTIONS(4467),
    [anon_sym_CASE] = ACTIONS(4467),
    [anon_sym_Case] = ACTIONS(4467),
    [anon_sym_for] = ACTIONS(4467),
    [anon_sym_FOR] = ACTIONS(4467),
    [anon_sym_For] = ACTIONS(4467),
    [anon_sym_foreach] = ACTIONS(4467),
    [anon_sym_FOREACH] = ACTIONS(4467),
    [anon_sym_Foreach] = ACTIONS(4467),
    [anon_sym_while] = ACTIONS(4467),
    [anon_sym_WHILE] = ACTIONS(4467),
    [anon_sym_While] = ACTIONS(4467),
    [anon_sym_repeat] = ACTIONS(4467),
    [anon_sym_REPEAT] = ACTIONS(4467),
    [anon_sym_Repeat] = ACTIONS(4467),
    [anon_sym_exit] = ACTIONS(4467),
    [anon_sym_EXIT] = ACTIONS(4467),
    [anon_sym_Exit] = ACTIONS(4467),
    [anon_sym_continue] = ACTIONS(4467),
    [anon_sym_CONTINUE] = ACTIONS(4467),
    [anon_sym_Continue] = ACTIONS(4467),
    [anon_sym_break] = ACTIONS(4467),
    [anon_sym_BREAK] = ACTIONS(4467),
    [anon_sym_Break] = ACTIONS(4467),
    [anon_sym_with] = ACTIONS(4467),
    [anon_sym_WITH] = ACTIONS(4467),
    [anon_sym_With] = ACTIONS(4467),
    [sym_asserterror_keyword] = ACTIONS(4469),
    [sym_page_keyword] = ACTIONS(4467),
    [anon_sym_codeunit] = ACTIONS(4467),
    [anon_sym_CODEUNIT] = ACTIONS(4467),
    [anon_sym_Codeunit] = ACTIONS(4467),
    [anon_sym_CodeUnit] = ACTIONS(4467),
    [anon_sym_COdeunit] = ACTIONS(4467),
    [anon_sym_codeUnit] = ACTIONS(4467),
    [sym_report_keyword] = ACTIONS(4467),
    [sym_query_keyword] = ACTIONS(4467),
    [anon_sym_xmlport] = ACTIONS(4467),
    [anon_sym_XMLPORT] = ACTIONS(4467),
    [anon_sym_Xmlport] = ACTIONS(4467),
    [anon_sym_XMLport] = ACTIONS(4467),
    [anon_sym_XMLPort] = ACTIONS(4467),
    [anon_sym_XmlPort] = ACTIONS(4467),
    [anon_sym_enum] = ACTIONS(4467),
    [anon_sym_ENUM] = ACTIONS(4467),
    [anon_sym_Enum] = ACTIONS(4467),
    [anon_sym_eNUM] = ACTIONS(4467),
    [anon_sym_eNum] = ACTIONS(4467),
    [anon_sym_ENum] = ACTIONS(4467),
    [sym_quoted_identifier] = ACTIONS(4469),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4469),
    [sym_integer] = ACTIONS(4467),
    [sym_continue_as_identifier] = ACTIONS(4469),
    [sym_preproc_open] = ACTIONS(4469),
    [sym_preproc_close] = ACTIONS(4469),
  },
  [STATE(1624)] = {
    [sym_identifier] = ACTIONS(4471),
    [anon_sym_SEMI] = ACTIONS(4473),
    [anon_sym_DASH] = ACTIONS(4473),
    [aux_sym_boolean_token1] = ACTIONS(4471),
    [aux_sym_boolean_token2] = ACTIONS(4471),
    [sym_decimal] = ACTIONS(4471),
    [anon_sym_LPAREN] = ACTIONS(4473),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4471),
    [anon_sym_LBRACK] = ACTIONS(4473),
    [aux_sym_record_type_token1] = ACTIONS(4471),
    [aux_sym_basic_type_token21] = ACTIONS(4471),
    [aux_sym_basic_type_token22] = ACTIONS(4471),
    [aux_sym_basic_type_token48] = ACTIONS(4471),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4471),
    [anon_sym_POUNDif] = ACTIONS(4473),
    [anon_sym_POUNDIF] = ACTIONS(4473),
    [anon_sym_POUNDIf] = ACTIONS(4473),
    [anon_sym_not] = ACTIONS(4471),
    [anon_sym_NOT] = ACTIONS(4471),
    [anon_sym_Not] = ACTIONS(4471),
    [anon_sym_POUNDelif] = ACTIONS(4473),
    [anon_sym_POUNDELIF] = ACTIONS(4473),
    [anon_sym_POUNDElif] = ACTIONS(4473),
    [anon_sym_POUNDelse] = ACTIONS(4473),
    [anon_sym_POUNDELSE] = ACTIONS(4473),
    [anon_sym_POUNDElse] = ACTIONS(4473),
    [anon_sym_POUNDendif] = ACTIONS(4473),
    [anon_sym_POUNDENDIF] = ACTIONS(4473),
    [anon_sym_POUNDEndif] = ACTIONS(4473),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4471),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4471),
    [anon_sym_PLUS] = ACTIONS(4473),
    [sym_datetime_literal] = ACTIONS(4473),
    [sym_date_literal] = ACTIONS(4471),
    [sym_time_literal] = ACTIONS(4471),
    [sym_biginteger_literal] = ACTIONS(4473),
    [anon_sym_if] = ACTIONS(4471),
    [anon_sym_IF] = ACTIONS(4471),
    [anon_sym_If] = ACTIONS(4471),
    [anon_sym_else] = ACTIONS(4471),
    [anon_sym_ELSE] = ACTIONS(4471),
    [anon_sym_Else] = ACTIONS(4471),
    [anon_sym_case] = ACTIONS(4471),
    [anon_sym_CASE] = ACTIONS(4471),
    [anon_sym_Case] = ACTIONS(4471),
    [anon_sym_for] = ACTIONS(4471),
    [anon_sym_FOR] = ACTIONS(4471),
    [anon_sym_For] = ACTIONS(4471),
    [anon_sym_foreach] = ACTIONS(4471),
    [anon_sym_FOREACH] = ACTIONS(4471),
    [anon_sym_Foreach] = ACTIONS(4471),
    [anon_sym_while] = ACTIONS(4471),
    [anon_sym_WHILE] = ACTIONS(4471),
    [anon_sym_While] = ACTIONS(4471),
    [anon_sym_repeat] = ACTIONS(4471),
    [anon_sym_REPEAT] = ACTIONS(4471),
    [anon_sym_Repeat] = ACTIONS(4471),
    [anon_sym_exit] = ACTIONS(4471),
    [anon_sym_EXIT] = ACTIONS(4471),
    [anon_sym_Exit] = ACTIONS(4471),
    [anon_sym_continue] = ACTIONS(4471),
    [anon_sym_CONTINUE] = ACTIONS(4471),
    [anon_sym_Continue] = ACTIONS(4471),
    [anon_sym_break] = ACTIONS(4471),
    [anon_sym_BREAK] = ACTIONS(4471),
    [anon_sym_Break] = ACTIONS(4471),
    [anon_sym_with] = ACTIONS(4471),
    [anon_sym_WITH] = ACTIONS(4471),
    [anon_sym_With] = ACTIONS(4471),
    [sym_asserterror_keyword] = ACTIONS(4473),
    [sym_page_keyword] = ACTIONS(4471),
    [anon_sym_codeunit] = ACTIONS(4471),
    [anon_sym_CODEUNIT] = ACTIONS(4471),
    [anon_sym_Codeunit] = ACTIONS(4471),
    [anon_sym_CodeUnit] = ACTIONS(4471),
    [anon_sym_COdeunit] = ACTIONS(4471),
    [anon_sym_codeUnit] = ACTIONS(4471),
    [sym_report_keyword] = ACTIONS(4471),
    [sym_query_keyword] = ACTIONS(4471),
    [anon_sym_xmlport] = ACTIONS(4471),
    [anon_sym_XMLPORT] = ACTIONS(4471),
    [anon_sym_Xmlport] = ACTIONS(4471),
    [anon_sym_XMLport] = ACTIONS(4471),
    [anon_sym_XMLPort] = ACTIONS(4471),
    [anon_sym_XmlPort] = ACTIONS(4471),
    [anon_sym_enum] = ACTIONS(4471),
    [anon_sym_ENUM] = ACTIONS(4471),
    [anon_sym_Enum] = ACTIONS(4471),
    [anon_sym_eNUM] = ACTIONS(4471),
    [anon_sym_eNum] = ACTIONS(4471),
    [anon_sym_ENum] = ACTIONS(4471),
    [sym_quoted_identifier] = ACTIONS(4473),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4473),
    [sym_integer] = ACTIONS(4471),
    [sym_continue_as_identifier] = ACTIONS(4473),
    [sym_preproc_open] = ACTIONS(4473),
    [sym_preproc_close] = ACTIONS(4473),
  },
  [STATE(1625)] = {
    [sym_identifier] = ACTIONS(4475),
    [anon_sym_SEMI] = ACTIONS(4477),
    [anon_sym_DASH] = ACTIONS(4477),
    [aux_sym_boolean_token1] = ACTIONS(4475),
    [aux_sym_boolean_token2] = ACTIONS(4475),
    [sym_decimal] = ACTIONS(4475),
    [anon_sym_LPAREN] = ACTIONS(4477),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4475),
    [anon_sym_LBRACK] = ACTIONS(4477),
    [aux_sym_record_type_token1] = ACTIONS(4475),
    [aux_sym_basic_type_token21] = ACTIONS(4475),
    [aux_sym_basic_type_token22] = ACTIONS(4475),
    [aux_sym_basic_type_token48] = ACTIONS(4475),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4475),
    [anon_sym_POUNDif] = ACTIONS(4477),
    [anon_sym_POUNDIF] = ACTIONS(4477),
    [anon_sym_POUNDIf] = ACTIONS(4477),
    [anon_sym_not] = ACTIONS(4475),
    [anon_sym_NOT] = ACTIONS(4475),
    [anon_sym_Not] = ACTIONS(4475),
    [anon_sym_POUNDelif] = ACTIONS(4477),
    [anon_sym_POUNDELIF] = ACTIONS(4477),
    [anon_sym_POUNDElif] = ACTIONS(4477),
    [anon_sym_POUNDelse] = ACTIONS(4477),
    [anon_sym_POUNDELSE] = ACTIONS(4477),
    [anon_sym_POUNDElse] = ACTIONS(4477),
    [anon_sym_POUNDendif] = ACTIONS(4477),
    [anon_sym_POUNDENDIF] = ACTIONS(4477),
    [anon_sym_POUNDEndif] = ACTIONS(4477),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4475),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4475),
    [anon_sym_PLUS] = ACTIONS(4477),
    [sym_datetime_literal] = ACTIONS(4477),
    [sym_date_literal] = ACTIONS(4475),
    [sym_time_literal] = ACTIONS(4475),
    [sym_biginteger_literal] = ACTIONS(4477),
    [anon_sym_if] = ACTIONS(4475),
    [anon_sym_IF] = ACTIONS(4475),
    [anon_sym_If] = ACTIONS(4475),
    [anon_sym_else] = ACTIONS(4475),
    [anon_sym_ELSE] = ACTIONS(4475),
    [anon_sym_Else] = ACTIONS(4475),
    [anon_sym_case] = ACTIONS(4475),
    [anon_sym_CASE] = ACTIONS(4475),
    [anon_sym_Case] = ACTIONS(4475),
    [anon_sym_for] = ACTIONS(4475),
    [anon_sym_FOR] = ACTIONS(4475),
    [anon_sym_For] = ACTIONS(4475),
    [anon_sym_foreach] = ACTIONS(4475),
    [anon_sym_FOREACH] = ACTIONS(4475),
    [anon_sym_Foreach] = ACTIONS(4475),
    [anon_sym_while] = ACTIONS(4475),
    [anon_sym_WHILE] = ACTIONS(4475),
    [anon_sym_While] = ACTIONS(4475),
    [anon_sym_repeat] = ACTIONS(4475),
    [anon_sym_REPEAT] = ACTIONS(4475),
    [anon_sym_Repeat] = ACTIONS(4475),
    [anon_sym_exit] = ACTIONS(4475),
    [anon_sym_EXIT] = ACTIONS(4475),
    [anon_sym_Exit] = ACTIONS(4475),
    [anon_sym_continue] = ACTIONS(4475),
    [anon_sym_CONTINUE] = ACTIONS(4475),
    [anon_sym_Continue] = ACTIONS(4475),
    [anon_sym_break] = ACTIONS(4475),
    [anon_sym_BREAK] = ACTIONS(4475),
    [anon_sym_Break] = ACTIONS(4475),
    [anon_sym_with] = ACTIONS(4475),
    [anon_sym_WITH] = ACTIONS(4475),
    [anon_sym_With] = ACTIONS(4475),
    [sym_asserterror_keyword] = ACTIONS(4477),
    [sym_page_keyword] = ACTIONS(4475),
    [anon_sym_codeunit] = ACTIONS(4475),
    [anon_sym_CODEUNIT] = ACTIONS(4475),
    [anon_sym_Codeunit] = ACTIONS(4475),
    [anon_sym_CodeUnit] = ACTIONS(4475),
    [anon_sym_COdeunit] = ACTIONS(4475),
    [anon_sym_codeUnit] = ACTIONS(4475),
    [sym_report_keyword] = ACTIONS(4475),
    [sym_query_keyword] = ACTIONS(4475),
    [anon_sym_xmlport] = ACTIONS(4475),
    [anon_sym_XMLPORT] = ACTIONS(4475),
    [anon_sym_Xmlport] = ACTIONS(4475),
    [anon_sym_XMLport] = ACTIONS(4475),
    [anon_sym_XMLPort] = ACTIONS(4475),
    [anon_sym_XmlPort] = ACTIONS(4475),
    [anon_sym_enum] = ACTIONS(4475),
    [anon_sym_ENUM] = ACTIONS(4475),
    [anon_sym_Enum] = ACTIONS(4475),
    [anon_sym_eNUM] = ACTIONS(4475),
    [anon_sym_eNum] = ACTIONS(4475),
    [anon_sym_ENum] = ACTIONS(4475),
    [sym_quoted_identifier] = ACTIONS(4477),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4477),
    [sym_integer] = ACTIONS(4475),
    [sym_continue_as_identifier] = ACTIONS(4477),
    [sym_preproc_open] = ACTIONS(4477),
    [sym_preproc_close] = ACTIONS(4477),
  },
  [STATE(1626)] = {
    [sym_identifier] = ACTIONS(4479),
    [anon_sym_SEMI] = ACTIONS(4481),
    [anon_sym_DASH] = ACTIONS(4481),
    [aux_sym_boolean_token1] = ACTIONS(4479),
    [aux_sym_boolean_token2] = ACTIONS(4479),
    [sym_decimal] = ACTIONS(4479),
    [anon_sym_LPAREN] = ACTIONS(4481),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4479),
    [anon_sym_LBRACK] = ACTIONS(4481),
    [aux_sym_record_type_token1] = ACTIONS(4479),
    [aux_sym_basic_type_token21] = ACTIONS(4479),
    [aux_sym_basic_type_token22] = ACTIONS(4479),
    [aux_sym_basic_type_token48] = ACTIONS(4479),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4479),
    [anon_sym_POUNDif] = ACTIONS(4481),
    [anon_sym_POUNDIF] = ACTIONS(4481),
    [anon_sym_POUNDIf] = ACTIONS(4481),
    [anon_sym_not] = ACTIONS(4479),
    [anon_sym_NOT] = ACTIONS(4479),
    [anon_sym_Not] = ACTIONS(4479),
    [anon_sym_POUNDelif] = ACTIONS(4481),
    [anon_sym_POUNDELIF] = ACTIONS(4481),
    [anon_sym_POUNDElif] = ACTIONS(4481),
    [anon_sym_POUNDelse] = ACTIONS(4481),
    [anon_sym_POUNDELSE] = ACTIONS(4481),
    [anon_sym_POUNDElse] = ACTIONS(4481),
    [anon_sym_POUNDendif] = ACTIONS(4481),
    [anon_sym_POUNDENDIF] = ACTIONS(4481),
    [anon_sym_POUNDEndif] = ACTIONS(4481),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4479),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4479),
    [anon_sym_PLUS] = ACTIONS(4481),
    [sym_datetime_literal] = ACTIONS(4481),
    [sym_date_literal] = ACTIONS(4479),
    [sym_time_literal] = ACTIONS(4479),
    [sym_biginteger_literal] = ACTIONS(4481),
    [anon_sym_if] = ACTIONS(4479),
    [anon_sym_IF] = ACTIONS(4479),
    [anon_sym_If] = ACTIONS(4479),
    [anon_sym_else] = ACTIONS(4479),
    [anon_sym_ELSE] = ACTIONS(4479),
    [anon_sym_Else] = ACTIONS(4479),
    [anon_sym_case] = ACTIONS(4479),
    [anon_sym_CASE] = ACTIONS(4479),
    [anon_sym_Case] = ACTIONS(4479),
    [anon_sym_for] = ACTIONS(4479),
    [anon_sym_FOR] = ACTIONS(4479),
    [anon_sym_For] = ACTIONS(4479),
    [anon_sym_foreach] = ACTIONS(4479),
    [anon_sym_FOREACH] = ACTIONS(4479),
    [anon_sym_Foreach] = ACTIONS(4479),
    [anon_sym_while] = ACTIONS(4479),
    [anon_sym_WHILE] = ACTIONS(4479),
    [anon_sym_While] = ACTIONS(4479),
    [anon_sym_repeat] = ACTIONS(4479),
    [anon_sym_REPEAT] = ACTIONS(4479),
    [anon_sym_Repeat] = ACTIONS(4479),
    [anon_sym_exit] = ACTIONS(4479),
    [anon_sym_EXIT] = ACTIONS(4479),
    [anon_sym_Exit] = ACTIONS(4479),
    [anon_sym_continue] = ACTIONS(4479),
    [anon_sym_CONTINUE] = ACTIONS(4479),
    [anon_sym_Continue] = ACTIONS(4479),
    [anon_sym_break] = ACTIONS(4479),
    [anon_sym_BREAK] = ACTIONS(4479),
    [anon_sym_Break] = ACTIONS(4479),
    [anon_sym_with] = ACTIONS(4479),
    [anon_sym_WITH] = ACTIONS(4479),
    [anon_sym_With] = ACTIONS(4479),
    [sym_asserterror_keyword] = ACTIONS(4481),
    [sym_page_keyword] = ACTIONS(4479),
    [anon_sym_codeunit] = ACTIONS(4479),
    [anon_sym_CODEUNIT] = ACTIONS(4479),
    [anon_sym_Codeunit] = ACTIONS(4479),
    [anon_sym_CodeUnit] = ACTIONS(4479),
    [anon_sym_COdeunit] = ACTIONS(4479),
    [anon_sym_codeUnit] = ACTIONS(4479),
    [sym_report_keyword] = ACTIONS(4479),
    [sym_query_keyword] = ACTIONS(4479),
    [anon_sym_xmlport] = ACTIONS(4479),
    [anon_sym_XMLPORT] = ACTIONS(4479),
    [anon_sym_Xmlport] = ACTIONS(4479),
    [anon_sym_XMLport] = ACTIONS(4479),
    [anon_sym_XMLPort] = ACTIONS(4479),
    [anon_sym_XmlPort] = ACTIONS(4479),
    [anon_sym_enum] = ACTIONS(4479),
    [anon_sym_ENUM] = ACTIONS(4479),
    [anon_sym_Enum] = ACTIONS(4479),
    [anon_sym_eNUM] = ACTIONS(4479),
    [anon_sym_eNum] = ACTIONS(4479),
    [anon_sym_ENum] = ACTIONS(4479),
    [sym_quoted_identifier] = ACTIONS(4481),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4481),
    [sym_integer] = ACTIONS(4479),
    [sym_continue_as_identifier] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4481),
    [sym_preproc_close] = ACTIONS(4481),
  },
  [STATE(1627)] = {
    [sym_identifier] = ACTIONS(4483),
    [anon_sym_SEMI] = ACTIONS(4485),
    [anon_sym_DASH] = ACTIONS(4485),
    [aux_sym_boolean_token1] = ACTIONS(4483),
    [aux_sym_boolean_token2] = ACTIONS(4483),
    [sym_decimal] = ACTIONS(4483),
    [anon_sym_LPAREN] = ACTIONS(4485),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4483),
    [anon_sym_LBRACK] = ACTIONS(4485),
    [aux_sym_record_type_token1] = ACTIONS(4483),
    [aux_sym_basic_type_token21] = ACTIONS(4483),
    [aux_sym_basic_type_token22] = ACTIONS(4483),
    [aux_sym_basic_type_token48] = ACTIONS(4483),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4483),
    [anon_sym_POUNDif] = ACTIONS(4485),
    [anon_sym_POUNDIF] = ACTIONS(4485),
    [anon_sym_POUNDIf] = ACTIONS(4485),
    [anon_sym_not] = ACTIONS(4483),
    [anon_sym_NOT] = ACTIONS(4483),
    [anon_sym_Not] = ACTIONS(4483),
    [anon_sym_POUNDelif] = ACTIONS(4485),
    [anon_sym_POUNDELIF] = ACTIONS(4485),
    [anon_sym_POUNDElif] = ACTIONS(4485),
    [anon_sym_POUNDelse] = ACTIONS(4485),
    [anon_sym_POUNDELSE] = ACTIONS(4485),
    [anon_sym_POUNDElse] = ACTIONS(4485),
    [anon_sym_POUNDendif] = ACTIONS(4485),
    [anon_sym_POUNDENDIF] = ACTIONS(4485),
    [anon_sym_POUNDEndif] = ACTIONS(4485),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4483),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4483),
    [anon_sym_PLUS] = ACTIONS(4485),
    [sym_datetime_literal] = ACTIONS(4485),
    [sym_date_literal] = ACTIONS(4483),
    [sym_time_literal] = ACTIONS(4483),
    [sym_biginteger_literal] = ACTIONS(4485),
    [anon_sym_if] = ACTIONS(4483),
    [anon_sym_IF] = ACTIONS(4483),
    [anon_sym_If] = ACTIONS(4483),
    [anon_sym_else] = ACTIONS(4483),
    [anon_sym_ELSE] = ACTIONS(4483),
    [anon_sym_Else] = ACTIONS(4483),
    [anon_sym_case] = ACTIONS(4483),
    [anon_sym_CASE] = ACTIONS(4483),
    [anon_sym_Case] = ACTIONS(4483),
    [anon_sym_for] = ACTIONS(4483),
    [anon_sym_FOR] = ACTIONS(4483),
    [anon_sym_For] = ACTIONS(4483),
    [anon_sym_foreach] = ACTIONS(4483),
    [anon_sym_FOREACH] = ACTIONS(4483),
    [anon_sym_Foreach] = ACTIONS(4483),
    [anon_sym_while] = ACTIONS(4483),
    [anon_sym_WHILE] = ACTIONS(4483),
    [anon_sym_While] = ACTIONS(4483),
    [anon_sym_repeat] = ACTIONS(4483),
    [anon_sym_REPEAT] = ACTIONS(4483),
    [anon_sym_Repeat] = ACTIONS(4483),
    [anon_sym_exit] = ACTIONS(4483),
    [anon_sym_EXIT] = ACTIONS(4483),
    [anon_sym_Exit] = ACTIONS(4483),
    [anon_sym_continue] = ACTIONS(4483),
    [anon_sym_CONTINUE] = ACTIONS(4483),
    [anon_sym_Continue] = ACTIONS(4483),
    [anon_sym_break] = ACTIONS(4483),
    [anon_sym_BREAK] = ACTIONS(4483),
    [anon_sym_Break] = ACTIONS(4483),
    [anon_sym_with] = ACTIONS(4483),
    [anon_sym_WITH] = ACTIONS(4483),
    [anon_sym_With] = ACTIONS(4483),
    [sym_asserterror_keyword] = ACTIONS(4485),
    [sym_page_keyword] = ACTIONS(4483),
    [anon_sym_codeunit] = ACTIONS(4483),
    [anon_sym_CODEUNIT] = ACTIONS(4483),
    [anon_sym_Codeunit] = ACTIONS(4483),
    [anon_sym_CodeUnit] = ACTIONS(4483),
    [anon_sym_COdeunit] = ACTIONS(4483),
    [anon_sym_codeUnit] = ACTIONS(4483),
    [sym_report_keyword] = ACTIONS(4483),
    [sym_query_keyword] = ACTIONS(4483),
    [anon_sym_xmlport] = ACTIONS(4483),
    [anon_sym_XMLPORT] = ACTIONS(4483),
    [anon_sym_Xmlport] = ACTIONS(4483),
    [anon_sym_XMLport] = ACTIONS(4483),
    [anon_sym_XMLPort] = ACTIONS(4483),
    [anon_sym_XmlPort] = ACTIONS(4483),
    [anon_sym_enum] = ACTIONS(4483),
    [anon_sym_ENUM] = ACTIONS(4483),
    [anon_sym_Enum] = ACTIONS(4483),
    [anon_sym_eNUM] = ACTIONS(4483),
    [anon_sym_eNum] = ACTIONS(4483),
    [anon_sym_ENum] = ACTIONS(4483),
    [sym_quoted_identifier] = ACTIONS(4485),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4485),
    [sym_integer] = ACTIONS(4483),
    [sym_continue_as_identifier] = ACTIONS(4485),
    [sym_preproc_open] = ACTIONS(4485),
    [sym_preproc_close] = ACTIONS(4485),
  },
  [STATE(1628)] = {
    [sym_identifier] = ACTIONS(4487),
    [anon_sym_SEMI] = ACTIONS(4489),
    [anon_sym_DASH] = ACTIONS(4489),
    [aux_sym_boolean_token1] = ACTIONS(4487),
    [aux_sym_boolean_token2] = ACTIONS(4487),
    [sym_decimal] = ACTIONS(4487),
    [anon_sym_LPAREN] = ACTIONS(4489),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4487),
    [anon_sym_LBRACK] = ACTIONS(4489),
    [aux_sym_record_type_token1] = ACTIONS(4487),
    [aux_sym_basic_type_token21] = ACTIONS(4487),
    [aux_sym_basic_type_token22] = ACTIONS(4487),
    [aux_sym_basic_type_token48] = ACTIONS(4487),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4487),
    [anon_sym_POUNDif] = ACTIONS(4489),
    [anon_sym_POUNDIF] = ACTIONS(4489),
    [anon_sym_POUNDIf] = ACTIONS(4489),
    [anon_sym_not] = ACTIONS(4487),
    [anon_sym_NOT] = ACTIONS(4487),
    [anon_sym_Not] = ACTIONS(4487),
    [anon_sym_POUNDelif] = ACTIONS(4489),
    [anon_sym_POUNDELIF] = ACTIONS(4489),
    [anon_sym_POUNDElif] = ACTIONS(4489),
    [anon_sym_POUNDelse] = ACTIONS(4489),
    [anon_sym_POUNDELSE] = ACTIONS(4489),
    [anon_sym_POUNDElse] = ACTIONS(4489),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4487),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4487),
    [anon_sym_PLUS] = ACTIONS(4489),
    [sym_datetime_literal] = ACTIONS(4489),
    [sym_date_literal] = ACTIONS(4487),
    [sym_time_literal] = ACTIONS(4487),
    [sym_biginteger_literal] = ACTIONS(4489),
    [anon_sym_if] = ACTIONS(4487),
    [anon_sym_IF] = ACTIONS(4487),
    [anon_sym_If] = ACTIONS(4487),
    [anon_sym_else] = ACTIONS(4487),
    [anon_sym_ELSE] = ACTIONS(4487),
    [anon_sym_Else] = ACTIONS(4487),
    [anon_sym_case] = ACTIONS(4487),
    [anon_sym_CASE] = ACTIONS(4487),
    [anon_sym_Case] = ACTIONS(4487),
    [anon_sym_for] = ACTIONS(4487),
    [anon_sym_FOR] = ACTIONS(4487),
    [anon_sym_For] = ACTIONS(4487),
    [anon_sym_foreach] = ACTIONS(4487),
    [anon_sym_FOREACH] = ACTIONS(4487),
    [anon_sym_Foreach] = ACTIONS(4487),
    [anon_sym_while] = ACTIONS(4487),
    [anon_sym_WHILE] = ACTIONS(4487),
    [anon_sym_While] = ACTIONS(4487),
    [anon_sym_repeat] = ACTIONS(4487),
    [anon_sym_REPEAT] = ACTIONS(4487),
    [anon_sym_Repeat] = ACTIONS(4487),
    [anon_sym_exit] = ACTIONS(4487),
    [anon_sym_EXIT] = ACTIONS(4487),
    [anon_sym_Exit] = ACTIONS(4487),
    [anon_sym_continue] = ACTIONS(4487),
    [anon_sym_CONTINUE] = ACTIONS(4487),
    [anon_sym_Continue] = ACTIONS(4487),
    [anon_sym_break] = ACTIONS(4487),
    [anon_sym_BREAK] = ACTIONS(4487),
    [anon_sym_Break] = ACTIONS(4487),
    [anon_sym_with] = ACTIONS(4487),
    [anon_sym_WITH] = ACTIONS(4487),
    [anon_sym_With] = ACTIONS(4487),
    [sym_asserterror_keyword] = ACTIONS(4489),
    [sym_page_keyword] = ACTIONS(4487),
    [anon_sym_codeunit] = ACTIONS(4487),
    [anon_sym_CODEUNIT] = ACTIONS(4487),
    [anon_sym_Codeunit] = ACTIONS(4487),
    [anon_sym_CodeUnit] = ACTIONS(4487),
    [anon_sym_COdeunit] = ACTIONS(4487),
    [anon_sym_codeUnit] = ACTIONS(4487),
    [sym_report_keyword] = ACTIONS(4487),
    [sym_query_keyword] = ACTIONS(4487),
    [anon_sym_xmlport] = ACTIONS(4487),
    [anon_sym_XMLPORT] = ACTIONS(4487),
    [anon_sym_Xmlport] = ACTIONS(4487),
    [anon_sym_XMLport] = ACTIONS(4487),
    [anon_sym_XMLPort] = ACTIONS(4487),
    [anon_sym_XmlPort] = ACTIONS(4487),
    [anon_sym_enum] = ACTIONS(4487),
    [anon_sym_ENUM] = ACTIONS(4487),
    [anon_sym_Enum] = ACTIONS(4487),
    [anon_sym_eNUM] = ACTIONS(4487),
    [anon_sym_eNum] = ACTIONS(4487),
    [anon_sym_ENum] = ACTIONS(4487),
    [sym_quoted_identifier] = ACTIONS(4489),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4489),
    [sym_integer] = ACTIONS(4487),
    [sym_continue_as_identifier] = ACTIONS(4489),
    [sym_preproc_open] = ACTIONS(4489),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(1629)] = {
    [sym_identifier] = ACTIONS(4491),
    [anon_sym_SEMI] = ACTIONS(4493),
    [anon_sym_DASH] = ACTIONS(4493),
    [aux_sym_boolean_token1] = ACTIONS(4491),
    [aux_sym_boolean_token2] = ACTIONS(4491),
    [sym_decimal] = ACTIONS(4491),
    [anon_sym_LPAREN] = ACTIONS(4493),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4491),
    [anon_sym_LBRACK] = ACTIONS(4493),
    [aux_sym_record_type_token1] = ACTIONS(4491),
    [aux_sym_basic_type_token21] = ACTIONS(4491),
    [aux_sym_basic_type_token22] = ACTIONS(4491),
    [aux_sym_basic_type_token48] = ACTIONS(4491),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4491),
    [anon_sym_POUNDif] = ACTIONS(4493),
    [anon_sym_POUNDIF] = ACTIONS(4493),
    [anon_sym_POUNDIf] = ACTIONS(4493),
    [anon_sym_not] = ACTIONS(4491),
    [anon_sym_NOT] = ACTIONS(4491),
    [anon_sym_Not] = ACTIONS(4491),
    [anon_sym_POUNDelif] = ACTIONS(4493),
    [anon_sym_POUNDELIF] = ACTIONS(4493),
    [anon_sym_POUNDElif] = ACTIONS(4493),
    [anon_sym_POUNDelse] = ACTIONS(4493),
    [anon_sym_POUNDELSE] = ACTIONS(4493),
    [anon_sym_POUNDElse] = ACTIONS(4493),
    [anon_sym_POUNDendif] = ACTIONS(4493),
    [anon_sym_POUNDENDIF] = ACTIONS(4493),
    [anon_sym_POUNDEndif] = ACTIONS(4493),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4491),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4491),
    [anon_sym_PLUS] = ACTIONS(4493),
    [sym_datetime_literal] = ACTIONS(4493),
    [sym_date_literal] = ACTIONS(4491),
    [sym_time_literal] = ACTIONS(4491),
    [sym_biginteger_literal] = ACTIONS(4493),
    [anon_sym_if] = ACTIONS(4491),
    [anon_sym_IF] = ACTIONS(4491),
    [anon_sym_If] = ACTIONS(4491),
    [anon_sym_else] = ACTIONS(4491),
    [anon_sym_ELSE] = ACTIONS(4491),
    [anon_sym_Else] = ACTIONS(4491),
    [anon_sym_case] = ACTIONS(4491),
    [anon_sym_CASE] = ACTIONS(4491),
    [anon_sym_Case] = ACTIONS(4491),
    [anon_sym_for] = ACTIONS(4491),
    [anon_sym_FOR] = ACTIONS(4491),
    [anon_sym_For] = ACTIONS(4491),
    [anon_sym_foreach] = ACTIONS(4491),
    [anon_sym_FOREACH] = ACTIONS(4491),
    [anon_sym_Foreach] = ACTIONS(4491),
    [anon_sym_while] = ACTIONS(4491),
    [anon_sym_WHILE] = ACTIONS(4491),
    [anon_sym_While] = ACTIONS(4491),
    [anon_sym_repeat] = ACTIONS(4491),
    [anon_sym_REPEAT] = ACTIONS(4491),
    [anon_sym_Repeat] = ACTIONS(4491),
    [anon_sym_exit] = ACTIONS(4491),
    [anon_sym_EXIT] = ACTIONS(4491),
    [anon_sym_Exit] = ACTIONS(4491),
    [anon_sym_continue] = ACTIONS(4491),
    [anon_sym_CONTINUE] = ACTIONS(4491),
    [anon_sym_Continue] = ACTIONS(4491),
    [anon_sym_break] = ACTIONS(4491),
    [anon_sym_BREAK] = ACTIONS(4491),
    [anon_sym_Break] = ACTIONS(4491),
    [anon_sym_with] = ACTIONS(4491),
    [anon_sym_WITH] = ACTIONS(4491),
    [anon_sym_With] = ACTIONS(4491),
    [sym_asserterror_keyword] = ACTIONS(4493),
    [sym_page_keyword] = ACTIONS(4491),
    [anon_sym_codeunit] = ACTIONS(4491),
    [anon_sym_CODEUNIT] = ACTIONS(4491),
    [anon_sym_Codeunit] = ACTIONS(4491),
    [anon_sym_CodeUnit] = ACTIONS(4491),
    [anon_sym_COdeunit] = ACTIONS(4491),
    [anon_sym_codeUnit] = ACTIONS(4491),
    [sym_report_keyword] = ACTIONS(4491),
    [sym_query_keyword] = ACTIONS(4491),
    [anon_sym_xmlport] = ACTIONS(4491),
    [anon_sym_XMLPORT] = ACTIONS(4491),
    [anon_sym_Xmlport] = ACTIONS(4491),
    [anon_sym_XMLport] = ACTIONS(4491),
    [anon_sym_XMLPort] = ACTIONS(4491),
    [anon_sym_XmlPort] = ACTIONS(4491),
    [anon_sym_enum] = ACTIONS(4491),
    [anon_sym_ENUM] = ACTIONS(4491),
    [anon_sym_Enum] = ACTIONS(4491),
    [anon_sym_eNUM] = ACTIONS(4491),
    [anon_sym_eNum] = ACTIONS(4491),
    [anon_sym_ENum] = ACTIONS(4491),
    [sym_quoted_identifier] = ACTIONS(4493),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4493),
    [sym_integer] = ACTIONS(4491),
    [sym_continue_as_identifier] = ACTIONS(4493),
    [sym_preproc_open] = ACTIONS(4493),
    [sym_preproc_close] = ACTIONS(4493),
  },
  [STATE(1630)] = {
    [sym_identifier] = ACTIONS(4495),
    [anon_sym_SEMI] = ACTIONS(4497),
    [anon_sym_DASH] = ACTIONS(4497),
    [aux_sym_boolean_token1] = ACTIONS(4495),
    [aux_sym_boolean_token2] = ACTIONS(4495),
    [sym_decimal] = ACTIONS(4495),
    [anon_sym_LPAREN] = ACTIONS(4497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4495),
    [anon_sym_LBRACK] = ACTIONS(4497),
    [aux_sym_record_type_token1] = ACTIONS(4495),
    [aux_sym_basic_type_token21] = ACTIONS(4495),
    [aux_sym_basic_type_token22] = ACTIONS(4495),
    [aux_sym_basic_type_token48] = ACTIONS(4495),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4495),
    [anon_sym_POUNDif] = ACTIONS(4497),
    [anon_sym_POUNDIF] = ACTIONS(4497),
    [anon_sym_POUNDIf] = ACTIONS(4497),
    [anon_sym_not] = ACTIONS(4495),
    [anon_sym_NOT] = ACTIONS(4495),
    [anon_sym_Not] = ACTIONS(4495),
    [anon_sym_POUNDelif] = ACTIONS(4497),
    [anon_sym_POUNDELIF] = ACTIONS(4497),
    [anon_sym_POUNDElif] = ACTIONS(4497),
    [anon_sym_POUNDelse] = ACTIONS(4497),
    [anon_sym_POUNDELSE] = ACTIONS(4497),
    [anon_sym_POUNDElse] = ACTIONS(4497),
    [anon_sym_POUNDendif] = ACTIONS(4497),
    [anon_sym_POUNDENDIF] = ACTIONS(4497),
    [anon_sym_POUNDEndif] = ACTIONS(4497),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4495),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4495),
    [anon_sym_PLUS] = ACTIONS(4497),
    [sym_datetime_literal] = ACTIONS(4497),
    [sym_date_literal] = ACTIONS(4495),
    [sym_time_literal] = ACTIONS(4495),
    [sym_biginteger_literal] = ACTIONS(4497),
    [anon_sym_if] = ACTIONS(4495),
    [anon_sym_IF] = ACTIONS(4495),
    [anon_sym_If] = ACTIONS(4495),
    [anon_sym_else] = ACTIONS(4495),
    [anon_sym_ELSE] = ACTIONS(4495),
    [anon_sym_Else] = ACTIONS(4495),
    [anon_sym_case] = ACTIONS(4495),
    [anon_sym_CASE] = ACTIONS(4495),
    [anon_sym_Case] = ACTIONS(4495),
    [anon_sym_for] = ACTIONS(4495),
    [anon_sym_FOR] = ACTIONS(4495),
    [anon_sym_For] = ACTIONS(4495),
    [anon_sym_foreach] = ACTIONS(4495),
    [anon_sym_FOREACH] = ACTIONS(4495),
    [anon_sym_Foreach] = ACTIONS(4495),
    [anon_sym_while] = ACTIONS(4495),
    [anon_sym_WHILE] = ACTIONS(4495),
    [anon_sym_While] = ACTIONS(4495),
    [anon_sym_repeat] = ACTIONS(4495),
    [anon_sym_REPEAT] = ACTIONS(4495),
    [anon_sym_Repeat] = ACTIONS(4495),
    [anon_sym_exit] = ACTIONS(4495),
    [anon_sym_EXIT] = ACTIONS(4495),
    [anon_sym_Exit] = ACTIONS(4495),
    [anon_sym_continue] = ACTIONS(4495),
    [anon_sym_CONTINUE] = ACTIONS(4495),
    [anon_sym_Continue] = ACTIONS(4495),
    [anon_sym_break] = ACTIONS(4495),
    [anon_sym_BREAK] = ACTIONS(4495),
    [anon_sym_Break] = ACTIONS(4495),
    [anon_sym_with] = ACTIONS(4495),
    [anon_sym_WITH] = ACTIONS(4495),
    [anon_sym_With] = ACTIONS(4495),
    [sym_asserterror_keyword] = ACTIONS(4497),
    [sym_page_keyword] = ACTIONS(4495),
    [anon_sym_codeunit] = ACTIONS(4495),
    [anon_sym_CODEUNIT] = ACTIONS(4495),
    [anon_sym_Codeunit] = ACTIONS(4495),
    [anon_sym_CodeUnit] = ACTIONS(4495),
    [anon_sym_COdeunit] = ACTIONS(4495),
    [anon_sym_codeUnit] = ACTIONS(4495),
    [sym_report_keyword] = ACTIONS(4495),
    [sym_query_keyword] = ACTIONS(4495),
    [anon_sym_xmlport] = ACTIONS(4495),
    [anon_sym_XMLPORT] = ACTIONS(4495),
    [anon_sym_Xmlport] = ACTIONS(4495),
    [anon_sym_XMLport] = ACTIONS(4495),
    [anon_sym_XMLPort] = ACTIONS(4495),
    [anon_sym_XmlPort] = ACTIONS(4495),
    [anon_sym_enum] = ACTIONS(4495),
    [anon_sym_ENUM] = ACTIONS(4495),
    [anon_sym_Enum] = ACTIONS(4495),
    [anon_sym_eNUM] = ACTIONS(4495),
    [anon_sym_eNum] = ACTIONS(4495),
    [anon_sym_ENum] = ACTIONS(4495),
    [sym_quoted_identifier] = ACTIONS(4497),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4497),
    [sym_integer] = ACTIONS(4495),
    [sym_continue_as_identifier] = ACTIONS(4497),
    [sym_preproc_open] = ACTIONS(4497),
    [sym_preproc_close] = ACTIONS(4497),
  },
  [STATE(1631)] = {
    [sym_identifier] = ACTIONS(4499),
    [anon_sym_SEMI] = ACTIONS(4501),
    [anon_sym_DASH] = ACTIONS(4501),
    [aux_sym_boolean_token1] = ACTIONS(4499),
    [aux_sym_boolean_token2] = ACTIONS(4499),
    [sym_decimal] = ACTIONS(4499),
    [anon_sym_LPAREN] = ACTIONS(4501),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4499),
    [anon_sym_LBRACK] = ACTIONS(4501),
    [aux_sym_record_type_token1] = ACTIONS(4499),
    [aux_sym_basic_type_token21] = ACTIONS(4499),
    [aux_sym_basic_type_token22] = ACTIONS(4499),
    [aux_sym_basic_type_token48] = ACTIONS(4499),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4499),
    [anon_sym_POUNDif] = ACTIONS(4501),
    [anon_sym_POUNDIF] = ACTIONS(4501),
    [anon_sym_POUNDIf] = ACTIONS(4501),
    [anon_sym_not] = ACTIONS(4499),
    [anon_sym_NOT] = ACTIONS(4499),
    [anon_sym_Not] = ACTIONS(4499),
    [anon_sym_POUNDelif] = ACTIONS(4501),
    [anon_sym_POUNDELIF] = ACTIONS(4501),
    [anon_sym_POUNDElif] = ACTIONS(4501),
    [anon_sym_POUNDelse] = ACTIONS(4501),
    [anon_sym_POUNDELSE] = ACTIONS(4501),
    [anon_sym_POUNDElse] = ACTIONS(4501),
    [anon_sym_POUNDendif] = ACTIONS(4501),
    [anon_sym_POUNDENDIF] = ACTIONS(4501),
    [anon_sym_POUNDEndif] = ACTIONS(4501),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4499),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4499),
    [anon_sym_PLUS] = ACTIONS(4501),
    [sym_datetime_literal] = ACTIONS(4501),
    [sym_date_literal] = ACTIONS(4499),
    [sym_time_literal] = ACTIONS(4499),
    [sym_biginteger_literal] = ACTIONS(4501),
    [anon_sym_if] = ACTIONS(4499),
    [anon_sym_IF] = ACTIONS(4499),
    [anon_sym_If] = ACTIONS(4499),
    [anon_sym_else] = ACTIONS(4499),
    [anon_sym_ELSE] = ACTIONS(4499),
    [anon_sym_Else] = ACTIONS(4499),
    [anon_sym_case] = ACTIONS(4499),
    [anon_sym_CASE] = ACTIONS(4499),
    [anon_sym_Case] = ACTIONS(4499),
    [anon_sym_for] = ACTIONS(4499),
    [anon_sym_FOR] = ACTIONS(4499),
    [anon_sym_For] = ACTIONS(4499),
    [anon_sym_foreach] = ACTIONS(4499),
    [anon_sym_FOREACH] = ACTIONS(4499),
    [anon_sym_Foreach] = ACTIONS(4499),
    [anon_sym_while] = ACTIONS(4499),
    [anon_sym_WHILE] = ACTIONS(4499),
    [anon_sym_While] = ACTIONS(4499),
    [anon_sym_repeat] = ACTIONS(4499),
    [anon_sym_REPEAT] = ACTIONS(4499),
    [anon_sym_Repeat] = ACTIONS(4499),
    [anon_sym_exit] = ACTIONS(4499),
    [anon_sym_EXIT] = ACTIONS(4499),
    [anon_sym_Exit] = ACTIONS(4499),
    [anon_sym_continue] = ACTIONS(4499),
    [anon_sym_CONTINUE] = ACTIONS(4499),
    [anon_sym_Continue] = ACTIONS(4499),
    [anon_sym_break] = ACTIONS(4499),
    [anon_sym_BREAK] = ACTIONS(4499),
    [anon_sym_Break] = ACTIONS(4499),
    [anon_sym_with] = ACTIONS(4499),
    [anon_sym_WITH] = ACTIONS(4499),
    [anon_sym_With] = ACTIONS(4499),
    [sym_asserterror_keyword] = ACTIONS(4501),
    [sym_page_keyword] = ACTIONS(4499),
    [anon_sym_codeunit] = ACTIONS(4499),
    [anon_sym_CODEUNIT] = ACTIONS(4499),
    [anon_sym_Codeunit] = ACTIONS(4499),
    [anon_sym_CodeUnit] = ACTIONS(4499),
    [anon_sym_COdeunit] = ACTIONS(4499),
    [anon_sym_codeUnit] = ACTIONS(4499),
    [sym_report_keyword] = ACTIONS(4499),
    [sym_query_keyword] = ACTIONS(4499),
    [anon_sym_xmlport] = ACTIONS(4499),
    [anon_sym_XMLPORT] = ACTIONS(4499),
    [anon_sym_Xmlport] = ACTIONS(4499),
    [anon_sym_XMLport] = ACTIONS(4499),
    [anon_sym_XMLPort] = ACTIONS(4499),
    [anon_sym_XmlPort] = ACTIONS(4499),
    [anon_sym_enum] = ACTIONS(4499),
    [anon_sym_ENUM] = ACTIONS(4499),
    [anon_sym_Enum] = ACTIONS(4499),
    [anon_sym_eNUM] = ACTIONS(4499),
    [anon_sym_eNum] = ACTIONS(4499),
    [anon_sym_ENum] = ACTIONS(4499),
    [sym_quoted_identifier] = ACTIONS(4501),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4501),
    [sym_integer] = ACTIONS(4499),
    [sym_continue_as_identifier] = ACTIONS(4501),
    [sym_preproc_open] = ACTIONS(4501),
    [sym_preproc_close] = ACTIONS(4501),
  },
  [STATE(1632)] = {
    [sym_identifier] = ACTIONS(4503),
    [anon_sym_SEMI] = ACTIONS(4505),
    [anon_sym_DASH] = ACTIONS(4505),
    [aux_sym_boolean_token1] = ACTIONS(4503),
    [aux_sym_boolean_token2] = ACTIONS(4503),
    [sym_decimal] = ACTIONS(4503),
    [anon_sym_LPAREN] = ACTIONS(4505),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4503),
    [anon_sym_LBRACK] = ACTIONS(4505),
    [aux_sym_record_type_token1] = ACTIONS(4503),
    [aux_sym_basic_type_token21] = ACTIONS(4503),
    [aux_sym_basic_type_token22] = ACTIONS(4503),
    [aux_sym_basic_type_token48] = ACTIONS(4503),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4503),
    [anon_sym_POUNDif] = ACTIONS(4505),
    [anon_sym_POUNDIF] = ACTIONS(4505),
    [anon_sym_POUNDIf] = ACTIONS(4505),
    [anon_sym_not] = ACTIONS(4503),
    [anon_sym_NOT] = ACTIONS(4503),
    [anon_sym_Not] = ACTIONS(4503),
    [anon_sym_POUNDelif] = ACTIONS(4505),
    [anon_sym_POUNDELIF] = ACTIONS(4505),
    [anon_sym_POUNDElif] = ACTIONS(4505),
    [anon_sym_POUNDelse] = ACTIONS(4505),
    [anon_sym_POUNDELSE] = ACTIONS(4505),
    [anon_sym_POUNDElse] = ACTIONS(4505),
    [anon_sym_POUNDendif] = ACTIONS(4505),
    [anon_sym_POUNDENDIF] = ACTIONS(4505),
    [anon_sym_POUNDEndif] = ACTIONS(4505),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4503),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4503),
    [anon_sym_PLUS] = ACTIONS(4505),
    [sym_datetime_literal] = ACTIONS(4505),
    [sym_date_literal] = ACTIONS(4503),
    [sym_time_literal] = ACTIONS(4503),
    [sym_biginteger_literal] = ACTIONS(4505),
    [anon_sym_if] = ACTIONS(4503),
    [anon_sym_IF] = ACTIONS(4503),
    [anon_sym_If] = ACTIONS(4503),
    [anon_sym_else] = ACTIONS(4503),
    [anon_sym_ELSE] = ACTIONS(4503),
    [anon_sym_Else] = ACTIONS(4503),
    [anon_sym_case] = ACTIONS(4503),
    [anon_sym_CASE] = ACTIONS(4503),
    [anon_sym_Case] = ACTIONS(4503),
    [anon_sym_for] = ACTIONS(4503),
    [anon_sym_FOR] = ACTIONS(4503),
    [anon_sym_For] = ACTIONS(4503),
    [anon_sym_foreach] = ACTIONS(4503),
    [anon_sym_FOREACH] = ACTIONS(4503),
    [anon_sym_Foreach] = ACTIONS(4503),
    [anon_sym_while] = ACTIONS(4503),
    [anon_sym_WHILE] = ACTIONS(4503),
    [anon_sym_While] = ACTIONS(4503),
    [anon_sym_repeat] = ACTIONS(4503),
    [anon_sym_REPEAT] = ACTIONS(4503),
    [anon_sym_Repeat] = ACTIONS(4503),
    [anon_sym_exit] = ACTIONS(4503),
    [anon_sym_EXIT] = ACTIONS(4503),
    [anon_sym_Exit] = ACTIONS(4503),
    [anon_sym_continue] = ACTIONS(4503),
    [anon_sym_CONTINUE] = ACTIONS(4503),
    [anon_sym_Continue] = ACTIONS(4503),
    [anon_sym_break] = ACTIONS(4503),
    [anon_sym_BREAK] = ACTIONS(4503),
    [anon_sym_Break] = ACTIONS(4503),
    [anon_sym_with] = ACTIONS(4503),
    [anon_sym_WITH] = ACTIONS(4503),
    [anon_sym_With] = ACTIONS(4503),
    [sym_asserterror_keyword] = ACTIONS(4505),
    [sym_page_keyword] = ACTIONS(4503),
    [anon_sym_codeunit] = ACTIONS(4503),
    [anon_sym_CODEUNIT] = ACTIONS(4503),
    [anon_sym_Codeunit] = ACTIONS(4503),
    [anon_sym_CodeUnit] = ACTIONS(4503),
    [anon_sym_COdeunit] = ACTIONS(4503),
    [anon_sym_codeUnit] = ACTIONS(4503),
    [sym_report_keyword] = ACTIONS(4503),
    [sym_query_keyword] = ACTIONS(4503),
    [anon_sym_xmlport] = ACTIONS(4503),
    [anon_sym_XMLPORT] = ACTIONS(4503),
    [anon_sym_Xmlport] = ACTIONS(4503),
    [anon_sym_XMLport] = ACTIONS(4503),
    [anon_sym_XMLPort] = ACTIONS(4503),
    [anon_sym_XmlPort] = ACTIONS(4503),
    [anon_sym_enum] = ACTIONS(4503),
    [anon_sym_ENUM] = ACTIONS(4503),
    [anon_sym_Enum] = ACTIONS(4503),
    [anon_sym_eNUM] = ACTIONS(4503),
    [anon_sym_eNum] = ACTIONS(4503),
    [anon_sym_ENum] = ACTIONS(4503),
    [sym_quoted_identifier] = ACTIONS(4505),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4505),
    [sym_integer] = ACTIONS(4503),
    [sym_continue_as_identifier] = ACTIONS(4505),
    [sym_preproc_open] = ACTIONS(4505),
    [sym_preproc_close] = ACTIONS(4505),
  },
  [STATE(1633)] = {
    [sym_identifier] = ACTIONS(4507),
    [anon_sym_SEMI] = ACTIONS(4509),
    [anon_sym_DASH] = ACTIONS(4509),
    [aux_sym_boolean_token1] = ACTIONS(4507),
    [aux_sym_boolean_token2] = ACTIONS(4507),
    [sym_decimal] = ACTIONS(4507),
    [anon_sym_LPAREN] = ACTIONS(4509),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4507),
    [anon_sym_LBRACK] = ACTIONS(4509),
    [aux_sym_record_type_token1] = ACTIONS(4507),
    [aux_sym_basic_type_token21] = ACTIONS(4507),
    [aux_sym_basic_type_token22] = ACTIONS(4507),
    [aux_sym_basic_type_token48] = ACTIONS(4507),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4507),
    [anon_sym_POUNDif] = ACTIONS(4509),
    [anon_sym_POUNDIF] = ACTIONS(4509),
    [anon_sym_POUNDIf] = ACTIONS(4509),
    [anon_sym_not] = ACTIONS(4507),
    [anon_sym_NOT] = ACTIONS(4507),
    [anon_sym_Not] = ACTIONS(4507),
    [anon_sym_POUNDelif] = ACTIONS(4509),
    [anon_sym_POUNDELIF] = ACTIONS(4509),
    [anon_sym_POUNDElif] = ACTIONS(4509),
    [anon_sym_POUNDelse] = ACTIONS(4509),
    [anon_sym_POUNDELSE] = ACTIONS(4509),
    [anon_sym_POUNDElse] = ACTIONS(4509),
    [anon_sym_POUNDendif] = ACTIONS(4509),
    [anon_sym_POUNDENDIF] = ACTIONS(4509),
    [anon_sym_POUNDEndif] = ACTIONS(4509),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4507),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4507),
    [anon_sym_PLUS] = ACTIONS(4509),
    [sym_datetime_literal] = ACTIONS(4509),
    [sym_date_literal] = ACTIONS(4507),
    [sym_time_literal] = ACTIONS(4507),
    [sym_biginteger_literal] = ACTIONS(4509),
    [anon_sym_if] = ACTIONS(4507),
    [anon_sym_IF] = ACTIONS(4507),
    [anon_sym_If] = ACTIONS(4507),
    [anon_sym_else] = ACTIONS(4507),
    [anon_sym_ELSE] = ACTIONS(4507),
    [anon_sym_Else] = ACTIONS(4507),
    [anon_sym_case] = ACTIONS(4507),
    [anon_sym_CASE] = ACTIONS(4507),
    [anon_sym_Case] = ACTIONS(4507),
    [anon_sym_for] = ACTIONS(4507),
    [anon_sym_FOR] = ACTIONS(4507),
    [anon_sym_For] = ACTIONS(4507),
    [anon_sym_foreach] = ACTIONS(4507),
    [anon_sym_FOREACH] = ACTIONS(4507),
    [anon_sym_Foreach] = ACTIONS(4507),
    [anon_sym_while] = ACTIONS(4507),
    [anon_sym_WHILE] = ACTIONS(4507),
    [anon_sym_While] = ACTIONS(4507),
    [anon_sym_repeat] = ACTIONS(4507),
    [anon_sym_REPEAT] = ACTIONS(4507),
    [anon_sym_Repeat] = ACTIONS(4507),
    [anon_sym_exit] = ACTIONS(4507),
    [anon_sym_EXIT] = ACTIONS(4507),
    [anon_sym_Exit] = ACTIONS(4507),
    [anon_sym_continue] = ACTIONS(4507),
    [anon_sym_CONTINUE] = ACTIONS(4507),
    [anon_sym_Continue] = ACTIONS(4507),
    [anon_sym_break] = ACTIONS(4507),
    [anon_sym_BREAK] = ACTIONS(4507),
    [anon_sym_Break] = ACTIONS(4507),
    [anon_sym_with] = ACTIONS(4507),
    [anon_sym_WITH] = ACTIONS(4507),
    [anon_sym_With] = ACTIONS(4507),
    [sym_asserterror_keyword] = ACTIONS(4509),
    [sym_page_keyword] = ACTIONS(4507),
    [anon_sym_codeunit] = ACTIONS(4507),
    [anon_sym_CODEUNIT] = ACTIONS(4507),
    [anon_sym_Codeunit] = ACTIONS(4507),
    [anon_sym_CodeUnit] = ACTIONS(4507),
    [anon_sym_COdeunit] = ACTIONS(4507),
    [anon_sym_codeUnit] = ACTIONS(4507),
    [sym_report_keyword] = ACTIONS(4507),
    [sym_query_keyword] = ACTIONS(4507),
    [anon_sym_xmlport] = ACTIONS(4507),
    [anon_sym_XMLPORT] = ACTIONS(4507),
    [anon_sym_Xmlport] = ACTIONS(4507),
    [anon_sym_XMLport] = ACTIONS(4507),
    [anon_sym_XMLPort] = ACTIONS(4507),
    [anon_sym_XmlPort] = ACTIONS(4507),
    [anon_sym_enum] = ACTIONS(4507),
    [anon_sym_ENUM] = ACTIONS(4507),
    [anon_sym_Enum] = ACTIONS(4507),
    [anon_sym_eNUM] = ACTIONS(4507),
    [anon_sym_eNum] = ACTIONS(4507),
    [anon_sym_ENum] = ACTIONS(4507),
    [sym_quoted_identifier] = ACTIONS(4509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4509),
    [sym_integer] = ACTIONS(4507),
    [sym_continue_as_identifier] = ACTIONS(4509),
    [sym_preproc_open] = ACTIONS(4509),
    [sym_preproc_close] = ACTIONS(4509),
  },
  [STATE(1634)] = {
    [sym_identifier] = ACTIONS(4511),
    [anon_sym_SEMI] = ACTIONS(4513),
    [anon_sym_DASH] = ACTIONS(4513),
    [aux_sym_boolean_token1] = ACTIONS(4511),
    [aux_sym_boolean_token2] = ACTIONS(4511),
    [sym_decimal] = ACTIONS(4511),
    [anon_sym_LPAREN] = ACTIONS(4513),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4511),
    [anon_sym_LBRACK] = ACTIONS(4513),
    [aux_sym_record_type_token1] = ACTIONS(4511),
    [aux_sym_basic_type_token21] = ACTIONS(4511),
    [aux_sym_basic_type_token22] = ACTIONS(4511),
    [aux_sym_basic_type_token48] = ACTIONS(4511),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4511),
    [anon_sym_POUNDif] = ACTIONS(4513),
    [anon_sym_POUNDIF] = ACTIONS(4513),
    [anon_sym_POUNDIf] = ACTIONS(4513),
    [anon_sym_not] = ACTIONS(4511),
    [anon_sym_NOT] = ACTIONS(4511),
    [anon_sym_Not] = ACTIONS(4511),
    [anon_sym_POUNDelif] = ACTIONS(4513),
    [anon_sym_POUNDELIF] = ACTIONS(4513),
    [anon_sym_POUNDElif] = ACTIONS(4513),
    [anon_sym_POUNDelse] = ACTIONS(4513),
    [anon_sym_POUNDELSE] = ACTIONS(4513),
    [anon_sym_POUNDElse] = ACTIONS(4513),
    [anon_sym_POUNDendif] = ACTIONS(4513),
    [anon_sym_POUNDENDIF] = ACTIONS(4513),
    [anon_sym_POUNDEndif] = ACTIONS(4513),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4511),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4511),
    [anon_sym_PLUS] = ACTIONS(4513),
    [sym_datetime_literal] = ACTIONS(4513),
    [sym_date_literal] = ACTIONS(4511),
    [sym_time_literal] = ACTIONS(4511),
    [sym_biginteger_literal] = ACTIONS(4513),
    [anon_sym_if] = ACTIONS(4511),
    [anon_sym_IF] = ACTIONS(4511),
    [anon_sym_If] = ACTIONS(4511),
    [anon_sym_else] = ACTIONS(4511),
    [anon_sym_ELSE] = ACTIONS(4511),
    [anon_sym_Else] = ACTIONS(4511),
    [anon_sym_case] = ACTIONS(4511),
    [anon_sym_CASE] = ACTIONS(4511),
    [anon_sym_Case] = ACTIONS(4511),
    [anon_sym_for] = ACTIONS(4511),
    [anon_sym_FOR] = ACTIONS(4511),
    [anon_sym_For] = ACTIONS(4511),
    [anon_sym_foreach] = ACTIONS(4511),
    [anon_sym_FOREACH] = ACTIONS(4511),
    [anon_sym_Foreach] = ACTIONS(4511),
    [anon_sym_while] = ACTIONS(4511),
    [anon_sym_WHILE] = ACTIONS(4511),
    [anon_sym_While] = ACTIONS(4511),
    [anon_sym_repeat] = ACTIONS(4511),
    [anon_sym_REPEAT] = ACTIONS(4511),
    [anon_sym_Repeat] = ACTIONS(4511),
    [anon_sym_exit] = ACTIONS(4511),
    [anon_sym_EXIT] = ACTIONS(4511),
    [anon_sym_Exit] = ACTIONS(4511),
    [anon_sym_continue] = ACTIONS(4511),
    [anon_sym_CONTINUE] = ACTIONS(4511),
    [anon_sym_Continue] = ACTIONS(4511),
    [anon_sym_break] = ACTIONS(4511),
    [anon_sym_BREAK] = ACTIONS(4511),
    [anon_sym_Break] = ACTIONS(4511),
    [anon_sym_with] = ACTIONS(4511),
    [anon_sym_WITH] = ACTIONS(4511),
    [anon_sym_With] = ACTIONS(4511),
    [sym_asserterror_keyword] = ACTIONS(4513),
    [sym_page_keyword] = ACTIONS(4511),
    [anon_sym_codeunit] = ACTIONS(4511),
    [anon_sym_CODEUNIT] = ACTIONS(4511),
    [anon_sym_Codeunit] = ACTIONS(4511),
    [anon_sym_CodeUnit] = ACTIONS(4511),
    [anon_sym_COdeunit] = ACTIONS(4511),
    [anon_sym_codeUnit] = ACTIONS(4511),
    [sym_report_keyword] = ACTIONS(4511),
    [sym_query_keyword] = ACTIONS(4511),
    [anon_sym_xmlport] = ACTIONS(4511),
    [anon_sym_XMLPORT] = ACTIONS(4511),
    [anon_sym_Xmlport] = ACTIONS(4511),
    [anon_sym_XMLport] = ACTIONS(4511),
    [anon_sym_XMLPort] = ACTIONS(4511),
    [anon_sym_XmlPort] = ACTIONS(4511),
    [anon_sym_enum] = ACTIONS(4511),
    [anon_sym_ENUM] = ACTIONS(4511),
    [anon_sym_Enum] = ACTIONS(4511),
    [anon_sym_eNUM] = ACTIONS(4511),
    [anon_sym_eNum] = ACTIONS(4511),
    [anon_sym_ENum] = ACTIONS(4511),
    [sym_quoted_identifier] = ACTIONS(4513),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4513),
    [sym_integer] = ACTIONS(4511),
    [sym_continue_as_identifier] = ACTIONS(4513),
    [sym_preproc_open] = ACTIONS(4513),
    [sym_preproc_close] = ACTIONS(4513),
  },
  [STATE(1635)] = {
    [sym_identifier] = ACTIONS(4515),
    [anon_sym_SEMI] = ACTIONS(4517),
    [anon_sym_DASH] = ACTIONS(4517),
    [aux_sym_boolean_token1] = ACTIONS(4515),
    [aux_sym_boolean_token2] = ACTIONS(4515),
    [sym_decimal] = ACTIONS(4515),
    [anon_sym_LPAREN] = ACTIONS(4517),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4515),
    [anon_sym_LBRACK] = ACTIONS(4517),
    [aux_sym_record_type_token1] = ACTIONS(4515),
    [aux_sym_basic_type_token21] = ACTIONS(4515),
    [aux_sym_basic_type_token22] = ACTIONS(4515),
    [aux_sym_basic_type_token48] = ACTIONS(4515),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4515),
    [anon_sym_POUNDif] = ACTIONS(4517),
    [anon_sym_POUNDIF] = ACTIONS(4517),
    [anon_sym_POUNDIf] = ACTIONS(4517),
    [anon_sym_not] = ACTIONS(4515),
    [anon_sym_NOT] = ACTIONS(4515),
    [anon_sym_Not] = ACTIONS(4515),
    [anon_sym_POUNDelif] = ACTIONS(4517),
    [anon_sym_POUNDELIF] = ACTIONS(4517),
    [anon_sym_POUNDElif] = ACTIONS(4517),
    [anon_sym_POUNDelse] = ACTIONS(4517),
    [anon_sym_POUNDELSE] = ACTIONS(4517),
    [anon_sym_POUNDElse] = ACTIONS(4517),
    [anon_sym_POUNDendif] = ACTIONS(4517),
    [anon_sym_POUNDENDIF] = ACTIONS(4517),
    [anon_sym_POUNDEndif] = ACTIONS(4517),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4515),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4515),
    [anon_sym_PLUS] = ACTIONS(4517),
    [sym_datetime_literal] = ACTIONS(4517),
    [sym_date_literal] = ACTIONS(4515),
    [sym_time_literal] = ACTIONS(4515),
    [sym_biginteger_literal] = ACTIONS(4517),
    [anon_sym_if] = ACTIONS(4515),
    [anon_sym_IF] = ACTIONS(4515),
    [anon_sym_If] = ACTIONS(4515),
    [anon_sym_else] = ACTIONS(4515),
    [anon_sym_ELSE] = ACTIONS(4515),
    [anon_sym_Else] = ACTIONS(4515),
    [anon_sym_case] = ACTIONS(4515),
    [anon_sym_CASE] = ACTIONS(4515),
    [anon_sym_Case] = ACTIONS(4515),
    [anon_sym_for] = ACTIONS(4515),
    [anon_sym_FOR] = ACTIONS(4515),
    [anon_sym_For] = ACTIONS(4515),
    [anon_sym_foreach] = ACTIONS(4515),
    [anon_sym_FOREACH] = ACTIONS(4515),
    [anon_sym_Foreach] = ACTIONS(4515),
    [anon_sym_while] = ACTIONS(4515),
    [anon_sym_WHILE] = ACTIONS(4515),
    [anon_sym_While] = ACTIONS(4515),
    [anon_sym_repeat] = ACTIONS(4515),
    [anon_sym_REPEAT] = ACTIONS(4515),
    [anon_sym_Repeat] = ACTIONS(4515),
    [anon_sym_exit] = ACTIONS(4515),
    [anon_sym_EXIT] = ACTIONS(4515),
    [anon_sym_Exit] = ACTIONS(4515),
    [anon_sym_continue] = ACTIONS(4515),
    [anon_sym_CONTINUE] = ACTIONS(4515),
    [anon_sym_Continue] = ACTIONS(4515),
    [anon_sym_break] = ACTIONS(4515),
    [anon_sym_BREAK] = ACTIONS(4515),
    [anon_sym_Break] = ACTIONS(4515),
    [anon_sym_with] = ACTIONS(4515),
    [anon_sym_WITH] = ACTIONS(4515),
    [anon_sym_With] = ACTIONS(4515),
    [sym_asserterror_keyword] = ACTIONS(4517),
    [sym_page_keyword] = ACTIONS(4515),
    [anon_sym_codeunit] = ACTIONS(4515),
    [anon_sym_CODEUNIT] = ACTIONS(4515),
    [anon_sym_Codeunit] = ACTIONS(4515),
    [anon_sym_CodeUnit] = ACTIONS(4515),
    [anon_sym_COdeunit] = ACTIONS(4515),
    [anon_sym_codeUnit] = ACTIONS(4515),
    [sym_report_keyword] = ACTIONS(4515),
    [sym_query_keyword] = ACTIONS(4515),
    [anon_sym_xmlport] = ACTIONS(4515),
    [anon_sym_XMLPORT] = ACTIONS(4515),
    [anon_sym_Xmlport] = ACTIONS(4515),
    [anon_sym_XMLport] = ACTIONS(4515),
    [anon_sym_XMLPort] = ACTIONS(4515),
    [anon_sym_XmlPort] = ACTIONS(4515),
    [anon_sym_enum] = ACTIONS(4515),
    [anon_sym_ENUM] = ACTIONS(4515),
    [anon_sym_Enum] = ACTIONS(4515),
    [anon_sym_eNUM] = ACTIONS(4515),
    [anon_sym_eNum] = ACTIONS(4515),
    [anon_sym_ENum] = ACTIONS(4515),
    [sym_quoted_identifier] = ACTIONS(4517),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4517),
    [sym_integer] = ACTIONS(4515),
    [sym_continue_as_identifier] = ACTIONS(4517),
    [sym_preproc_open] = ACTIONS(4517),
    [sym_preproc_close] = ACTIONS(4517),
  },
  [STATE(1636)] = {
    [sym_identifier] = ACTIONS(4519),
    [anon_sym_SEMI] = ACTIONS(4521),
    [anon_sym_DASH] = ACTIONS(4521),
    [aux_sym_boolean_token1] = ACTIONS(4519),
    [aux_sym_boolean_token2] = ACTIONS(4519),
    [sym_decimal] = ACTIONS(4519),
    [anon_sym_LPAREN] = ACTIONS(4521),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4521),
    [aux_sym_record_type_token1] = ACTIONS(4519),
    [aux_sym_basic_type_token21] = ACTIONS(4519),
    [aux_sym_basic_type_token22] = ACTIONS(4519),
    [aux_sym_basic_type_token48] = ACTIONS(4519),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4519),
    [anon_sym_POUNDif] = ACTIONS(4521),
    [anon_sym_POUNDIF] = ACTIONS(4521),
    [anon_sym_POUNDIf] = ACTIONS(4521),
    [anon_sym_not] = ACTIONS(4519),
    [anon_sym_NOT] = ACTIONS(4519),
    [anon_sym_Not] = ACTIONS(4519),
    [anon_sym_POUNDelif] = ACTIONS(4521),
    [anon_sym_POUNDELIF] = ACTIONS(4521),
    [anon_sym_POUNDElif] = ACTIONS(4521),
    [anon_sym_POUNDelse] = ACTIONS(4521),
    [anon_sym_POUNDELSE] = ACTIONS(4521),
    [anon_sym_POUNDElse] = ACTIONS(4521),
    [anon_sym_POUNDendif] = ACTIONS(4521),
    [anon_sym_POUNDENDIF] = ACTIONS(4521),
    [anon_sym_POUNDEndif] = ACTIONS(4521),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4519),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4519),
    [anon_sym_PLUS] = ACTIONS(4521),
    [sym_datetime_literal] = ACTIONS(4521),
    [sym_date_literal] = ACTIONS(4519),
    [sym_time_literal] = ACTIONS(4519),
    [sym_biginteger_literal] = ACTIONS(4521),
    [anon_sym_if] = ACTIONS(4519),
    [anon_sym_IF] = ACTIONS(4519),
    [anon_sym_If] = ACTIONS(4519),
    [anon_sym_else] = ACTIONS(4519),
    [anon_sym_ELSE] = ACTIONS(4519),
    [anon_sym_Else] = ACTIONS(4519),
    [anon_sym_case] = ACTIONS(4519),
    [anon_sym_CASE] = ACTIONS(4519),
    [anon_sym_Case] = ACTIONS(4519),
    [anon_sym_for] = ACTIONS(4519),
    [anon_sym_FOR] = ACTIONS(4519),
    [anon_sym_For] = ACTIONS(4519),
    [anon_sym_foreach] = ACTIONS(4519),
    [anon_sym_FOREACH] = ACTIONS(4519),
    [anon_sym_Foreach] = ACTIONS(4519),
    [anon_sym_while] = ACTIONS(4519),
    [anon_sym_WHILE] = ACTIONS(4519),
    [anon_sym_While] = ACTIONS(4519),
    [anon_sym_repeat] = ACTIONS(4519),
    [anon_sym_REPEAT] = ACTIONS(4519),
    [anon_sym_Repeat] = ACTIONS(4519),
    [anon_sym_exit] = ACTIONS(4519),
    [anon_sym_EXIT] = ACTIONS(4519),
    [anon_sym_Exit] = ACTIONS(4519),
    [anon_sym_continue] = ACTIONS(4519),
    [anon_sym_CONTINUE] = ACTIONS(4519),
    [anon_sym_Continue] = ACTIONS(4519),
    [anon_sym_break] = ACTIONS(4519),
    [anon_sym_BREAK] = ACTIONS(4519),
    [anon_sym_Break] = ACTIONS(4519),
    [anon_sym_with] = ACTIONS(4519),
    [anon_sym_WITH] = ACTIONS(4519),
    [anon_sym_With] = ACTIONS(4519),
    [sym_asserterror_keyword] = ACTIONS(4521),
    [sym_page_keyword] = ACTIONS(4519),
    [anon_sym_codeunit] = ACTIONS(4519),
    [anon_sym_CODEUNIT] = ACTIONS(4519),
    [anon_sym_Codeunit] = ACTIONS(4519),
    [anon_sym_CodeUnit] = ACTIONS(4519),
    [anon_sym_COdeunit] = ACTIONS(4519),
    [anon_sym_codeUnit] = ACTIONS(4519),
    [sym_report_keyword] = ACTIONS(4519),
    [sym_query_keyword] = ACTIONS(4519),
    [anon_sym_xmlport] = ACTIONS(4519),
    [anon_sym_XMLPORT] = ACTIONS(4519),
    [anon_sym_Xmlport] = ACTIONS(4519),
    [anon_sym_XMLport] = ACTIONS(4519),
    [anon_sym_XMLPort] = ACTIONS(4519),
    [anon_sym_XmlPort] = ACTIONS(4519),
    [anon_sym_enum] = ACTIONS(4519),
    [anon_sym_ENUM] = ACTIONS(4519),
    [anon_sym_Enum] = ACTIONS(4519),
    [anon_sym_eNUM] = ACTIONS(4519),
    [anon_sym_eNum] = ACTIONS(4519),
    [anon_sym_ENum] = ACTIONS(4519),
    [sym_quoted_identifier] = ACTIONS(4521),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4521),
    [sym_integer] = ACTIONS(4519),
    [sym_continue_as_identifier] = ACTIONS(4521),
    [sym_preproc_open] = ACTIONS(4521),
    [sym_preproc_close] = ACTIONS(4521),
  },
  [STATE(1637)] = {
    [sym_identifier] = ACTIONS(4523),
    [anon_sym_SEMI] = ACTIONS(4525),
    [anon_sym_DASH] = ACTIONS(4525),
    [aux_sym_boolean_token1] = ACTIONS(4523),
    [aux_sym_boolean_token2] = ACTIONS(4523),
    [sym_decimal] = ACTIONS(4523),
    [anon_sym_LPAREN] = ACTIONS(4525),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4523),
    [anon_sym_LBRACK] = ACTIONS(4525),
    [aux_sym_record_type_token1] = ACTIONS(4523),
    [aux_sym_basic_type_token21] = ACTIONS(4523),
    [aux_sym_basic_type_token22] = ACTIONS(4523),
    [aux_sym_basic_type_token48] = ACTIONS(4523),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4523),
    [anon_sym_POUNDif] = ACTIONS(4525),
    [anon_sym_POUNDIF] = ACTIONS(4525),
    [anon_sym_POUNDIf] = ACTIONS(4525),
    [anon_sym_not] = ACTIONS(4523),
    [anon_sym_NOT] = ACTIONS(4523),
    [anon_sym_Not] = ACTIONS(4523),
    [anon_sym_POUNDelif] = ACTIONS(4525),
    [anon_sym_POUNDELIF] = ACTIONS(4525),
    [anon_sym_POUNDElif] = ACTIONS(4525),
    [anon_sym_POUNDelse] = ACTIONS(4525),
    [anon_sym_POUNDELSE] = ACTIONS(4525),
    [anon_sym_POUNDElse] = ACTIONS(4525),
    [anon_sym_POUNDendif] = ACTIONS(4525),
    [anon_sym_POUNDENDIF] = ACTIONS(4525),
    [anon_sym_POUNDEndif] = ACTIONS(4525),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4523),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4523),
    [anon_sym_PLUS] = ACTIONS(4525),
    [sym_datetime_literal] = ACTIONS(4525),
    [sym_date_literal] = ACTIONS(4523),
    [sym_time_literal] = ACTIONS(4523),
    [sym_biginteger_literal] = ACTIONS(4525),
    [anon_sym_if] = ACTIONS(4523),
    [anon_sym_IF] = ACTIONS(4523),
    [anon_sym_If] = ACTIONS(4523),
    [anon_sym_else] = ACTIONS(4523),
    [anon_sym_ELSE] = ACTIONS(4523),
    [anon_sym_Else] = ACTIONS(4523),
    [anon_sym_case] = ACTIONS(4523),
    [anon_sym_CASE] = ACTIONS(4523),
    [anon_sym_Case] = ACTIONS(4523),
    [anon_sym_for] = ACTIONS(4523),
    [anon_sym_FOR] = ACTIONS(4523),
    [anon_sym_For] = ACTIONS(4523),
    [anon_sym_foreach] = ACTIONS(4523),
    [anon_sym_FOREACH] = ACTIONS(4523),
    [anon_sym_Foreach] = ACTIONS(4523),
    [anon_sym_while] = ACTIONS(4523),
    [anon_sym_WHILE] = ACTIONS(4523),
    [anon_sym_While] = ACTIONS(4523),
    [anon_sym_repeat] = ACTIONS(4523),
    [anon_sym_REPEAT] = ACTIONS(4523),
    [anon_sym_Repeat] = ACTIONS(4523),
    [anon_sym_exit] = ACTIONS(4523),
    [anon_sym_EXIT] = ACTIONS(4523),
    [anon_sym_Exit] = ACTIONS(4523),
    [anon_sym_continue] = ACTIONS(4523),
    [anon_sym_CONTINUE] = ACTIONS(4523),
    [anon_sym_Continue] = ACTIONS(4523),
    [anon_sym_break] = ACTIONS(4523),
    [anon_sym_BREAK] = ACTIONS(4523),
    [anon_sym_Break] = ACTIONS(4523),
    [anon_sym_with] = ACTIONS(4523),
    [anon_sym_WITH] = ACTIONS(4523),
    [anon_sym_With] = ACTIONS(4523),
    [sym_asserterror_keyword] = ACTIONS(4525),
    [sym_page_keyword] = ACTIONS(4523),
    [anon_sym_codeunit] = ACTIONS(4523),
    [anon_sym_CODEUNIT] = ACTIONS(4523),
    [anon_sym_Codeunit] = ACTIONS(4523),
    [anon_sym_CodeUnit] = ACTIONS(4523),
    [anon_sym_COdeunit] = ACTIONS(4523),
    [anon_sym_codeUnit] = ACTIONS(4523),
    [sym_report_keyword] = ACTIONS(4523),
    [sym_query_keyword] = ACTIONS(4523),
    [anon_sym_xmlport] = ACTIONS(4523),
    [anon_sym_XMLPORT] = ACTIONS(4523),
    [anon_sym_Xmlport] = ACTIONS(4523),
    [anon_sym_XMLport] = ACTIONS(4523),
    [anon_sym_XMLPort] = ACTIONS(4523),
    [anon_sym_XmlPort] = ACTIONS(4523),
    [anon_sym_enum] = ACTIONS(4523),
    [anon_sym_ENUM] = ACTIONS(4523),
    [anon_sym_Enum] = ACTIONS(4523),
    [anon_sym_eNUM] = ACTIONS(4523),
    [anon_sym_eNum] = ACTIONS(4523),
    [anon_sym_ENum] = ACTIONS(4523),
    [sym_quoted_identifier] = ACTIONS(4525),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4525),
    [sym_integer] = ACTIONS(4523),
    [sym_continue_as_identifier] = ACTIONS(4525),
    [sym_preproc_open] = ACTIONS(4525),
    [sym_preproc_close] = ACTIONS(4525),
  },
  [STATE(1638)] = {
    [sym_identifier] = ACTIONS(4527),
    [anon_sym_SEMI] = ACTIONS(4529),
    [anon_sym_DASH] = ACTIONS(4529),
    [aux_sym_boolean_token1] = ACTIONS(4527),
    [aux_sym_boolean_token2] = ACTIONS(4527),
    [sym_decimal] = ACTIONS(4527),
    [anon_sym_LPAREN] = ACTIONS(4529),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4527),
    [anon_sym_LBRACK] = ACTIONS(4529),
    [aux_sym_record_type_token1] = ACTIONS(4527),
    [aux_sym_basic_type_token21] = ACTIONS(4527),
    [aux_sym_basic_type_token22] = ACTIONS(4527),
    [aux_sym_basic_type_token48] = ACTIONS(4527),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4527),
    [anon_sym_POUNDif] = ACTIONS(4529),
    [anon_sym_POUNDIF] = ACTIONS(4529),
    [anon_sym_POUNDIf] = ACTIONS(4529),
    [anon_sym_not] = ACTIONS(4527),
    [anon_sym_NOT] = ACTIONS(4527),
    [anon_sym_Not] = ACTIONS(4527),
    [anon_sym_POUNDelif] = ACTIONS(4529),
    [anon_sym_POUNDELIF] = ACTIONS(4529),
    [anon_sym_POUNDElif] = ACTIONS(4529),
    [anon_sym_POUNDelse] = ACTIONS(4529),
    [anon_sym_POUNDELSE] = ACTIONS(4529),
    [anon_sym_POUNDElse] = ACTIONS(4529),
    [anon_sym_POUNDendif] = ACTIONS(4529),
    [anon_sym_POUNDENDIF] = ACTIONS(4529),
    [anon_sym_POUNDEndif] = ACTIONS(4529),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4527),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4527),
    [anon_sym_PLUS] = ACTIONS(4529),
    [sym_datetime_literal] = ACTIONS(4529),
    [sym_date_literal] = ACTIONS(4527),
    [sym_time_literal] = ACTIONS(4527),
    [sym_biginteger_literal] = ACTIONS(4529),
    [anon_sym_if] = ACTIONS(4527),
    [anon_sym_IF] = ACTIONS(4527),
    [anon_sym_If] = ACTIONS(4527),
    [anon_sym_else] = ACTIONS(4527),
    [anon_sym_ELSE] = ACTIONS(4527),
    [anon_sym_Else] = ACTIONS(4527),
    [anon_sym_case] = ACTIONS(4527),
    [anon_sym_CASE] = ACTIONS(4527),
    [anon_sym_Case] = ACTIONS(4527),
    [anon_sym_for] = ACTIONS(4527),
    [anon_sym_FOR] = ACTIONS(4527),
    [anon_sym_For] = ACTIONS(4527),
    [anon_sym_foreach] = ACTIONS(4527),
    [anon_sym_FOREACH] = ACTIONS(4527),
    [anon_sym_Foreach] = ACTIONS(4527),
    [anon_sym_while] = ACTIONS(4527),
    [anon_sym_WHILE] = ACTIONS(4527),
    [anon_sym_While] = ACTIONS(4527),
    [anon_sym_repeat] = ACTIONS(4527),
    [anon_sym_REPEAT] = ACTIONS(4527),
    [anon_sym_Repeat] = ACTIONS(4527),
    [anon_sym_exit] = ACTIONS(4527),
    [anon_sym_EXIT] = ACTIONS(4527),
    [anon_sym_Exit] = ACTIONS(4527),
    [anon_sym_continue] = ACTIONS(4527),
    [anon_sym_CONTINUE] = ACTIONS(4527),
    [anon_sym_Continue] = ACTIONS(4527),
    [anon_sym_break] = ACTIONS(4527),
    [anon_sym_BREAK] = ACTIONS(4527),
    [anon_sym_Break] = ACTIONS(4527),
    [anon_sym_with] = ACTIONS(4527),
    [anon_sym_WITH] = ACTIONS(4527),
    [anon_sym_With] = ACTIONS(4527),
    [sym_asserterror_keyword] = ACTIONS(4529),
    [sym_page_keyword] = ACTIONS(4527),
    [anon_sym_codeunit] = ACTIONS(4527),
    [anon_sym_CODEUNIT] = ACTIONS(4527),
    [anon_sym_Codeunit] = ACTIONS(4527),
    [anon_sym_CodeUnit] = ACTIONS(4527),
    [anon_sym_COdeunit] = ACTIONS(4527),
    [anon_sym_codeUnit] = ACTIONS(4527),
    [sym_report_keyword] = ACTIONS(4527),
    [sym_query_keyword] = ACTIONS(4527),
    [anon_sym_xmlport] = ACTIONS(4527),
    [anon_sym_XMLPORT] = ACTIONS(4527),
    [anon_sym_Xmlport] = ACTIONS(4527),
    [anon_sym_XMLport] = ACTIONS(4527),
    [anon_sym_XMLPort] = ACTIONS(4527),
    [anon_sym_XmlPort] = ACTIONS(4527),
    [anon_sym_enum] = ACTIONS(4527),
    [anon_sym_ENUM] = ACTIONS(4527),
    [anon_sym_Enum] = ACTIONS(4527),
    [anon_sym_eNUM] = ACTIONS(4527),
    [anon_sym_eNum] = ACTIONS(4527),
    [anon_sym_ENum] = ACTIONS(4527),
    [sym_quoted_identifier] = ACTIONS(4529),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4529),
    [sym_integer] = ACTIONS(4527),
    [sym_continue_as_identifier] = ACTIONS(4529),
    [sym_preproc_open] = ACTIONS(4529),
    [sym_preproc_close] = ACTIONS(4529),
  },
  [STATE(1639)] = {
    [sym_identifier] = ACTIONS(4531),
    [anon_sym_SEMI] = ACTIONS(4533),
    [anon_sym_DASH] = ACTIONS(4533),
    [aux_sym_boolean_token1] = ACTIONS(4531),
    [aux_sym_boolean_token2] = ACTIONS(4531),
    [sym_decimal] = ACTIONS(4531),
    [anon_sym_LPAREN] = ACTIONS(4533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4531),
    [anon_sym_LBRACK] = ACTIONS(4533),
    [aux_sym_record_type_token1] = ACTIONS(4531),
    [aux_sym_basic_type_token21] = ACTIONS(4531),
    [aux_sym_basic_type_token22] = ACTIONS(4531),
    [aux_sym_basic_type_token48] = ACTIONS(4531),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4531),
    [anon_sym_POUNDif] = ACTIONS(4533),
    [anon_sym_POUNDIF] = ACTIONS(4533),
    [anon_sym_POUNDIf] = ACTIONS(4533),
    [anon_sym_not] = ACTIONS(4531),
    [anon_sym_NOT] = ACTIONS(4531),
    [anon_sym_Not] = ACTIONS(4531),
    [anon_sym_POUNDelif] = ACTIONS(4533),
    [anon_sym_POUNDELIF] = ACTIONS(4533),
    [anon_sym_POUNDElif] = ACTIONS(4533),
    [anon_sym_POUNDelse] = ACTIONS(4533),
    [anon_sym_POUNDELSE] = ACTIONS(4533),
    [anon_sym_POUNDElse] = ACTIONS(4533),
    [anon_sym_POUNDendif] = ACTIONS(4533),
    [anon_sym_POUNDENDIF] = ACTIONS(4533),
    [anon_sym_POUNDEndif] = ACTIONS(4533),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4531),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4531),
    [anon_sym_PLUS] = ACTIONS(4533),
    [sym_datetime_literal] = ACTIONS(4533),
    [sym_date_literal] = ACTIONS(4531),
    [sym_time_literal] = ACTIONS(4531),
    [sym_biginteger_literal] = ACTIONS(4533),
    [anon_sym_if] = ACTIONS(4531),
    [anon_sym_IF] = ACTIONS(4531),
    [anon_sym_If] = ACTIONS(4531),
    [anon_sym_else] = ACTIONS(4531),
    [anon_sym_ELSE] = ACTIONS(4531),
    [anon_sym_Else] = ACTIONS(4531),
    [anon_sym_case] = ACTIONS(4531),
    [anon_sym_CASE] = ACTIONS(4531),
    [anon_sym_Case] = ACTIONS(4531),
    [anon_sym_for] = ACTIONS(4531),
    [anon_sym_FOR] = ACTIONS(4531),
    [anon_sym_For] = ACTIONS(4531),
    [anon_sym_foreach] = ACTIONS(4531),
    [anon_sym_FOREACH] = ACTIONS(4531),
    [anon_sym_Foreach] = ACTIONS(4531),
    [anon_sym_while] = ACTIONS(4531),
    [anon_sym_WHILE] = ACTIONS(4531),
    [anon_sym_While] = ACTIONS(4531),
    [anon_sym_repeat] = ACTIONS(4531),
    [anon_sym_REPEAT] = ACTIONS(4531),
    [anon_sym_Repeat] = ACTIONS(4531),
    [anon_sym_exit] = ACTIONS(4531),
    [anon_sym_EXIT] = ACTIONS(4531),
    [anon_sym_Exit] = ACTIONS(4531),
    [anon_sym_continue] = ACTIONS(4531),
    [anon_sym_CONTINUE] = ACTIONS(4531),
    [anon_sym_Continue] = ACTIONS(4531),
    [anon_sym_break] = ACTIONS(4531),
    [anon_sym_BREAK] = ACTIONS(4531),
    [anon_sym_Break] = ACTIONS(4531),
    [anon_sym_with] = ACTIONS(4531),
    [anon_sym_WITH] = ACTIONS(4531),
    [anon_sym_With] = ACTIONS(4531),
    [sym_asserterror_keyword] = ACTIONS(4533),
    [sym_page_keyword] = ACTIONS(4531),
    [anon_sym_codeunit] = ACTIONS(4531),
    [anon_sym_CODEUNIT] = ACTIONS(4531),
    [anon_sym_Codeunit] = ACTIONS(4531),
    [anon_sym_CodeUnit] = ACTIONS(4531),
    [anon_sym_COdeunit] = ACTIONS(4531),
    [anon_sym_codeUnit] = ACTIONS(4531),
    [sym_report_keyword] = ACTIONS(4531),
    [sym_query_keyword] = ACTIONS(4531),
    [anon_sym_xmlport] = ACTIONS(4531),
    [anon_sym_XMLPORT] = ACTIONS(4531),
    [anon_sym_Xmlport] = ACTIONS(4531),
    [anon_sym_XMLport] = ACTIONS(4531),
    [anon_sym_XMLPort] = ACTIONS(4531),
    [anon_sym_XmlPort] = ACTIONS(4531),
    [anon_sym_enum] = ACTIONS(4531),
    [anon_sym_ENUM] = ACTIONS(4531),
    [anon_sym_Enum] = ACTIONS(4531),
    [anon_sym_eNUM] = ACTIONS(4531),
    [anon_sym_eNum] = ACTIONS(4531),
    [anon_sym_ENum] = ACTIONS(4531),
    [sym_quoted_identifier] = ACTIONS(4533),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4533),
    [sym_integer] = ACTIONS(4531),
    [sym_continue_as_identifier] = ACTIONS(4533),
    [sym_preproc_open] = ACTIONS(4533),
    [sym_preproc_close] = ACTIONS(4533),
  },
  [STATE(1640)] = {
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_SEMI] = ACTIONS(4537),
    [anon_sym_DASH] = ACTIONS(4537),
    [aux_sym_boolean_token1] = ACTIONS(4535),
    [aux_sym_boolean_token2] = ACTIONS(4535),
    [sym_decimal] = ACTIONS(4535),
    [anon_sym_LPAREN] = ACTIONS(4537),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4535),
    [anon_sym_LBRACK] = ACTIONS(4537),
    [aux_sym_record_type_token1] = ACTIONS(4535),
    [aux_sym_basic_type_token21] = ACTIONS(4535),
    [aux_sym_basic_type_token22] = ACTIONS(4535),
    [aux_sym_basic_type_token48] = ACTIONS(4535),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4535),
    [anon_sym_POUNDif] = ACTIONS(4537),
    [anon_sym_POUNDIF] = ACTIONS(4537),
    [anon_sym_POUNDIf] = ACTIONS(4537),
    [anon_sym_not] = ACTIONS(4535),
    [anon_sym_NOT] = ACTIONS(4535),
    [anon_sym_Not] = ACTIONS(4535),
    [anon_sym_POUNDelif] = ACTIONS(4537),
    [anon_sym_POUNDELIF] = ACTIONS(4537),
    [anon_sym_POUNDElif] = ACTIONS(4537),
    [anon_sym_POUNDelse] = ACTIONS(4537),
    [anon_sym_POUNDELSE] = ACTIONS(4537),
    [anon_sym_POUNDElse] = ACTIONS(4537),
    [anon_sym_POUNDendif] = ACTIONS(4537),
    [anon_sym_POUNDENDIF] = ACTIONS(4537),
    [anon_sym_POUNDEndif] = ACTIONS(4537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4535),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4535),
    [anon_sym_PLUS] = ACTIONS(4537),
    [sym_datetime_literal] = ACTIONS(4537),
    [sym_date_literal] = ACTIONS(4535),
    [sym_time_literal] = ACTIONS(4535),
    [sym_biginteger_literal] = ACTIONS(4537),
    [anon_sym_if] = ACTIONS(4535),
    [anon_sym_IF] = ACTIONS(4535),
    [anon_sym_If] = ACTIONS(4535),
    [anon_sym_else] = ACTIONS(4535),
    [anon_sym_ELSE] = ACTIONS(4535),
    [anon_sym_Else] = ACTIONS(4535),
    [anon_sym_case] = ACTIONS(4535),
    [anon_sym_CASE] = ACTIONS(4535),
    [anon_sym_Case] = ACTIONS(4535),
    [anon_sym_for] = ACTIONS(4535),
    [anon_sym_FOR] = ACTIONS(4535),
    [anon_sym_For] = ACTIONS(4535),
    [anon_sym_foreach] = ACTIONS(4535),
    [anon_sym_FOREACH] = ACTIONS(4535),
    [anon_sym_Foreach] = ACTIONS(4535),
    [anon_sym_while] = ACTIONS(4535),
    [anon_sym_WHILE] = ACTIONS(4535),
    [anon_sym_While] = ACTIONS(4535),
    [anon_sym_repeat] = ACTIONS(4535),
    [anon_sym_REPEAT] = ACTIONS(4535),
    [anon_sym_Repeat] = ACTIONS(4535),
    [anon_sym_exit] = ACTIONS(4535),
    [anon_sym_EXIT] = ACTIONS(4535),
    [anon_sym_Exit] = ACTIONS(4535),
    [anon_sym_continue] = ACTIONS(4535),
    [anon_sym_CONTINUE] = ACTIONS(4535),
    [anon_sym_Continue] = ACTIONS(4535),
    [anon_sym_break] = ACTIONS(4535),
    [anon_sym_BREAK] = ACTIONS(4535),
    [anon_sym_Break] = ACTIONS(4535),
    [anon_sym_with] = ACTIONS(4535),
    [anon_sym_WITH] = ACTIONS(4535),
    [anon_sym_With] = ACTIONS(4535),
    [sym_asserterror_keyword] = ACTIONS(4537),
    [sym_page_keyword] = ACTIONS(4535),
    [anon_sym_codeunit] = ACTIONS(4535),
    [anon_sym_CODEUNIT] = ACTIONS(4535),
    [anon_sym_Codeunit] = ACTIONS(4535),
    [anon_sym_CodeUnit] = ACTIONS(4535),
    [anon_sym_COdeunit] = ACTIONS(4535),
    [anon_sym_codeUnit] = ACTIONS(4535),
    [sym_report_keyword] = ACTIONS(4535),
    [sym_query_keyword] = ACTIONS(4535),
    [anon_sym_xmlport] = ACTIONS(4535),
    [anon_sym_XMLPORT] = ACTIONS(4535),
    [anon_sym_Xmlport] = ACTIONS(4535),
    [anon_sym_XMLport] = ACTIONS(4535),
    [anon_sym_XMLPort] = ACTIONS(4535),
    [anon_sym_XmlPort] = ACTIONS(4535),
    [anon_sym_enum] = ACTIONS(4535),
    [anon_sym_ENUM] = ACTIONS(4535),
    [anon_sym_Enum] = ACTIONS(4535),
    [anon_sym_eNUM] = ACTIONS(4535),
    [anon_sym_eNum] = ACTIONS(4535),
    [anon_sym_ENum] = ACTIONS(4535),
    [sym_quoted_identifier] = ACTIONS(4537),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4537),
    [sym_integer] = ACTIONS(4535),
    [sym_continue_as_identifier] = ACTIONS(4537),
    [sym_preproc_open] = ACTIONS(4537),
    [sym_preproc_close] = ACTIONS(4537),
  },
  [STATE(1641)] = {
    [sym_identifier] = ACTIONS(4539),
    [anon_sym_SEMI] = ACTIONS(4541),
    [anon_sym_DASH] = ACTIONS(4541),
    [aux_sym_boolean_token1] = ACTIONS(4539),
    [aux_sym_boolean_token2] = ACTIONS(4539),
    [sym_decimal] = ACTIONS(4539),
    [anon_sym_LPAREN] = ACTIONS(4541),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4539),
    [anon_sym_LBRACK] = ACTIONS(4541),
    [aux_sym_record_type_token1] = ACTIONS(4539),
    [aux_sym_basic_type_token21] = ACTIONS(4539),
    [aux_sym_basic_type_token22] = ACTIONS(4539),
    [aux_sym_basic_type_token48] = ACTIONS(4539),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4539),
    [anon_sym_POUNDif] = ACTIONS(4541),
    [anon_sym_POUNDIF] = ACTIONS(4541),
    [anon_sym_POUNDIf] = ACTIONS(4541),
    [anon_sym_not] = ACTIONS(4539),
    [anon_sym_NOT] = ACTIONS(4539),
    [anon_sym_Not] = ACTIONS(4539),
    [anon_sym_POUNDelif] = ACTIONS(4541),
    [anon_sym_POUNDELIF] = ACTIONS(4541),
    [anon_sym_POUNDElif] = ACTIONS(4541),
    [anon_sym_POUNDelse] = ACTIONS(4541),
    [anon_sym_POUNDELSE] = ACTIONS(4541),
    [anon_sym_POUNDElse] = ACTIONS(4541),
    [anon_sym_POUNDendif] = ACTIONS(4541),
    [anon_sym_POUNDENDIF] = ACTIONS(4541),
    [anon_sym_POUNDEndif] = ACTIONS(4541),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4539),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4539),
    [anon_sym_PLUS] = ACTIONS(4541),
    [sym_datetime_literal] = ACTIONS(4541),
    [sym_date_literal] = ACTIONS(4539),
    [sym_time_literal] = ACTIONS(4539),
    [sym_biginteger_literal] = ACTIONS(4541),
    [anon_sym_if] = ACTIONS(4539),
    [anon_sym_IF] = ACTIONS(4539),
    [anon_sym_If] = ACTIONS(4539),
    [anon_sym_else] = ACTIONS(4539),
    [anon_sym_ELSE] = ACTIONS(4539),
    [anon_sym_Else] = ACTIONS(4539),
    [anon_sym_case] = ACTIONS(4539),
    [anon_sym_CASE] = ACTIONS(4539),
    [anon_sym_Case] = ACTIONS(4539),
    [anon_sym_for] = ACTIONS(4539),
    [anon_sym_FOR] = ACTIONS(4539),
    [anon_sym_For] = ACTIONS(4539),
    [anon_sym_foreach] = ACTIONS(4539),
    [anon_sym_FOREACH] = ACTIONS(4539),
    [anon_sym_Foreach] = ACTIONS(4539),
    [anon_sym_while] = ACTIONS(4539),
    [anon_sym_WHILE] = ACTIONS(4539),
    [anon_sym_While] = ACTIONS(4539),
    [anon_sym_repeat] = ACTIONS(4539),
    [anon_sym_REPEAT] = ACTIONS(4539),
    [anon_sym_Repeat] = ACTIONS(4539),
    [anon_sym_exit] = ACTIONS(4539),
    [anon_sym_EXIT] = ACTIONS(4539),
    [anon_sym_Exit] = ACTIONS(4539),
    [anon_sym_continue] = ACTIONS(4539),
    [anon_sym_CONTINUE] = ACTIONS(4539),
    [anon_sym_Continue] = ACTIONS(4539),
    [anon_sym_break] = ACTIONS(4539),
    [anon_sym_BREAK] = ACTIONS(4539),
    [anon_sym_Break] = ACTIONS(4539),
    [anon_sym_with] = ACTIONS(4539),
    [anon_sym_WITH] = ACTIONS(4539),
    [anon_sym_With] = ACTIONS(4539),
    [sym_asserterror_keyword] = ACTIONS(4541),
    [sym_page_keyword] = ACTIONS(4539),
    [anon_sym_codeunit] = ACTIONS(4539),
    [anon_sym_CODEUNIT] = ACTIONS(4539),
    [anon_sym_Codeunit] = ACTIONS(4539),
    [anon_sym_CodeUnit] = ACTIONS(4539),
    [anon_sym_COdeunit] = ACTIONS(4539),
    [anon_sym_codeUnit] = ACTIONS(4539),
    [sym_report_keyword] = ACTIONS(4539),
    [sym_query_keyword] = ACTIONS(4539),
    [anon_sym_xmlport] = ACTIONS(4539),
    [anon_sym_XMLPORT] = ACTIONS(4539),
    [anon_sym_Xmlport] = ACTIONS(4539),
    [anon_sym_XMLport] = ACTIONS(4539),
    [anon_sym_XMLPort] = ACTIONS(4539),
    [anon_sym_XmlPort] = ACTIONS(4539),
    [anon_sym_enum] = ACTIONS(4539),
    [anon_sym_ENUM] = ACTIONS(4539),
    [anon_sym_Enum] = ACTIONS(4539),
    [anon_sym_eNUM] = ACTIONS(4539),
    [anon_sym_eNum] = ACTIONS(4539),
    [anon_sym_ENum] = ACTIONS(4539),
    [sym_quoted_identifier] = ACTIONS(4541),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4541),
    [sym_integer] = ACTIONS(4539),
    [sym_continue_as_identifier] = ACTIONS(4541),
    [sym_preproc_open] = ACTIONS(4541),
    [sym_preproc_close] = ACTIONS(4541),
  },
  [STATE(1642)] = {
    [sym_identifier] = ACTIONS(4543),
    [anon_sym_SEMI] = ACTIONS(4545),
    [anon_sym_DASH] = ACTIONS(4545),
    [aux_sym_boolean_token1] = ACTIONS(4543),
    [aux_sym_boolean_token2] = ACTIONS(4543),
    [sym_decimal] = ACTIONS(4543),
    [anon_sym_LPAREN] = ACTIONS(4545),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4543),
    [anon_sym_LBRACK] = ACTIONS(4545),
    [aux_sym_record_type_token1] = ACTIONS(4543),
    [aux_sym_basic_type_token21] = ACTIONS(4543),
    [aux_sym_basic_type_token22] = ACTIONS(4543),
    [aux_sym_basic_type_token48] = ACTIONS(4543),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4543),
    [anon_sym_POUNDif] = ACTIONS(4545),
    [anon_sym_POUNDIF] = ACTIONS(4545),
    [anon_sym_POUNDIf] = ACTIONS(4545),
    [anon_sym_not] = ACTIONS(4543),
    [anon_sym_NOT] = ACTIONS(4543),
    [anon_sym_Not] = ACTIONS(4543),
    [anon_sym_POUNDelif] = ACTIONS(4545),
    [anon_sym_POUNDELIF] = ACTIONS(4545),
    [anon_sym_POUNDElif] = ACTIONS(4545),
    [anon_sym_POUNDelse] = ACTIONS(4545),
    [anon_sym_POUNDELSE] = ACTIONS(4545),
    [anon_sym_POUNDElse] = ACTIONS(4545),
    [anon_sym_POUNDendif] = ACTIONS(4545),
    [anon_sym_POUNDENDIF] = ACTIONS(4545),
    [anon_sym_POUNDEndif] = ACTIONS(4545),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4543),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4543),
    [anon_sym_PLUS] = ACTIONS(4545),
    [sym_datetime_literal] = ACTIONS(4545),
    [sym_date_literal] = ACTIONS(4543),
    [sym_time_literal] = ACTIONS(4543),
    [sym_biginteger_literal] = ACTIONS(4545),
    [anon_sym_if] = ACTIONS(4543),
    [anon_sym_IF] = ACTIONS(4543),
    [anon_sym_If] = ACTIONS(4543),
    [anon_sym_else] = ACTIONS(4543),
    [anon_sym_ELSE] = ACTIONS(4543),
    [anon_sym_Else] = ACTIONS(4543),
    [anon_sym_case] = ACTIONS(4543),
    [anon_sym_CASE] = ACTIONS(4543),
    [anon_sym_Case] = ACTIONS(4543),
    [anon_sym_for] = ACTIONS(4543),
    [anon_sym_FOR] = ACTIONS(4543),
    [anon_sym_For] = ACTIONS(4543),
    [anon_sym_foreach] = ACTIONS(4543),
    [anon_sym_FOREACH] = ACTIONS(4543),
    [anon_sym_Foreach] = ACTIONS(4543),
    [anon_sym_while] = ACTIONS(4543),
    [anon_sym_WHILE] = ACTIONS(4543),
    [anon_sym_While] = ACTIONS(4543),
    [anon_sym_repeat] = ACTIONS(4543),
    [anon_sym_REPEAT] = ACTIONS(4543),
    [anon_sym_Repeat] = ACTIONS(4543),
    [anon_sym_exit] = ACTIONS(4543),
    [anon_sym_EXIT] = ACTIONS(4543),
    [anon_sym_Exit] = ACTIONS(4543),
    [anon_sym_continue] = ACTIONS(4543),
    [anon_sym_CONTINUE] = ACTIONS(4543),
    [anon_sym_Continue] = ACTIONS(4543),
    [anon_sym_break] = ACTIONS(4543),
    [anon_sym_BREAK] = ACTIONS(4543),
    [anon_sym_Break] = ACTIONS(4543),
    [anon_sym_with] = ACTIONS(4543),
    [anon_sym_WITH] = ACTIONS(4543),
    [anon_sym_With] = ACTIONS(4543),
    [sym_asserterror_keyword] = ACTIONS(4545),
    [sym_page_keyword] = ACTIONS(4543),
    [anon_sym_codeunit] = ACTIONS(4543),
    [anon_sym_CODEUNIT] = ACTIONS(4543),
    [anon_sym_Codeunit] = ACTIONS(4543),
    [anon_sym_CodeUnit] = ACTIONS(4543),
    [anon_sym_COdeunit] = ACTIONS(4543),
    [anon_sym_codeUnit] = ACTIONS(4543),
    [sym_report_keyword] = ACTIONS(4543),
    [sym_query_keyword] = ACTIONS(4543),
    [anon_sym_xmlport] = ACTIONS(4543),
    [anon_sym_XMLPORT] = ACTIONS(4543),
    [anon_sym_Xmlport] = ACTIONS(4543),
    [anon_sym_XMLport] = ACTIONS(4543),
    [anon_sym_XMLPort] = ACTIONS(4543),
    [anon_sym_XmlPort] = ACTIONS(4543),
    [anon_sym_enum] = ACTIONS(4543),
    [anon_sym_ENUM] = ACTIONS(4543),
    [anon_sym_Enum] = ACTIONS(4543),
    [anon_sym_eNUM] = ACTIONS(4543),
    [anon_sym_eNum] = ACTIONS(4543),
    [anon_sym_ENum] = ACTIONS(4543),
    [sym_quoted_identifier] = ACTIONS(4545),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4545),
    [sym_integer] = ACTIONS(4543),
    [sym_continue_as_identifier] = ACTIONS(4545),
    [sym_preproc_open] = ACTIONS(4545),
    [sym_preproc_close] = ACTIONS(4545),
  },
  [STATE(1643)] = {
    [sym_identifier] = ACTIONS(4547),
    [anon_sym_SEMI] = ACTIONS(4549),
    [anon_sym_DASH] = ACTIONS(4549),
    [aux_sym_boolean_token1] = ACTIONS(4547),
    [aux_sym_boolean_token2] = ACTIONS(4547),
    [sym_decimal] = ACTIONS(4547),
    [anon_sym_LPAREN] = ACTIONS(4549),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4547),
    [anon_sym_LBRACK] = ACTIONS(4549),
    [aux_sym_record_type_token1] = ACTIONS(4547),
    [aux_sym_basic_type_token21] = ACTIONS(4547),
    [aux_sym_basic_type_token22] = ACTIONS(4547),
    [aux_sym_basic_type_token48] = ACTIONS(4547),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4547),
    [anon_sym_POUNDif] = ACTIONS(4549),
    [anon_sym_POUNDIF] = ACTIONS(4549),
    [anon_sym_POUNDIf] = ACTIONS(4549),
    [anon_sym_not] = ACTIONS(4547),
    [anon_sym_NOT] = ACTIONS(4547),
    [anon_sym_Not] = ACTIONS(4547),
    [anon_sym_POUNDelif] = ACTIONS(4549),
    [anon_sym_POUNDELIF] = ACTIONS(4549),
    [anon_sym_POUNDElif] = ACTIONS(4549),
    [anon_sym_POUNDelse] = ACTIONS(4549),
    [anon_sym_POUNDELSE] = ACTIONS(4549),
    [anon_sym_POUNDElse] = ACTIONS(4549),
    [anon_sym_POUNDendif] = ACTIONS(4549),
    [anon_sym_POUNDENDIF] = ACTIONS(4549),
    [anon_sym_POUNDEndif] = ACTIONS(4549),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4547),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4547),
    [anon_sym_PLUS] = ACTIONS(4549),
    [sym_datetime_literal] = ACTIONS(4549),
    [sym_date_literal] = ACTIONS(4547),
    [sym_time_literal] = ACTIONS(4547),
    [sym_biginteger_literal] = ACTIONS(4549),
    [anon_sym_if] = ACTIONS(4547),
    [anon_sym_IF] = ACTIONS(4547),
    [anon_sym_If] = ACTIONS(4547),
    [anon_sym_else] = ACTIONS(4547),
    [anon_sym_ELSE] = ACTIONS(4547),
    [anon_sym_Else] = ACTIONS(4547),
    [anon_sym_case] = ACTIONS(4547),
    [anon_sym_CASE] = ACTIONS(4547),
    [anon_sym_Case] = ACTIONS(4547),
    [anon_sym_for] = ACTIONS(4547),
    [anon_sym_FOR] = ACTIONS(4547),
    [anon_sym_For] = ACTIONS(4547),
    [anon_sym_foreach] = ACTIONS(4547),
    [anon_sym_FOREACH] = ACTIONS(4547),
    [anon_sym_Foreach] = ACTIONS(4547),
    [anon_sym_while] = ACTIONS(4547),
    [anon_sym_WHILE] = ACTIONS(4547),
    [anon_sym_While] = ACTIONS(4547),
    [anon_sym_repeat] = ACTIONS(4547),
    [anon_sym_REPEAT] = ACTIONS(4547),
    [anon_sym_Repeat] = ACTIONS(4547),
    [anon_sym_exit] = ACTIONS(4547),
    [anon_sym_EXIT] = ACTIONS(4547),
    [anon_sym_Exit] = ACTIONS(4547),
    [anon_sym_continue] = ACTIONS(4547),
    [anon_sym_CONTINUE] = ACTIONS(4547),
    [anon_sym_Continue] = ACTIONS(4547),
    [anon_sym_break] = ACTIONS(4547),
    [anon_sym_BREAK] = ACTIONS(4547),
    [anon_sym_Break] = ACTIONS(4547),
    [anon_sym_with] = ACTIONS(4547),
    [anon_sym_WITH] = ACTIONS(4547),
    [anon_sym_With] = ACTIONS(4547),
    [sym_asserterror_keyword] = ACTIONS(4549),
    [sym_page_keyword] = ACTIONS(4547),
    [anon_sym_codeunit] = ACTIONS(4547),
    [anon_sym_CODEUNIT] = ACTIONS(4547),
    [anon_sym_Codeunit] = ACTIONS(4547),
    [anon_sym_CodeUnit] = ACTIONS(4547),
    [anon_sym_COdeunit] = ACTIONS(4547),
    [anon_sym_codeUnit] = ACTIONS(4547),
    [sym_report_keyword] = ACTIONS(4547),
    [sym_query_keyword] = ACTIONS(4547),
    [anon_sym_xmlport] = ACTIONS(4547),
    [anon_sym_XMLPORT] = ACTIONS(4547),
    [anon_sym_Xmlport] = ACTIONS(4547),
    [anon_sym_XMLport] = ACTIONS(4547),
    [anon_sym_XMLPort] = ACTIONS(4547),
    [anon_sym_XmlPort] = ACTIONS(4547),
    [anon_sym_enum] = ACTIONS(4547),
    [anon_sym_ENUM] = ACTIONS(4547),
    [anon_sym_Enum] = ACTIONS(4547),
    [anon_sym_eNUM] = ACTIONS(4547),
    [anon_sym_eNum] = ACTIONS(4547),
    [anon_sym_ENum] = ACTIONS(4547),
    [sym_quoted_identifier] = ACTIONS(4549),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4549),
    [sym_integer] = ACTIONS(4547),
    [sym_continue_as_identifier] = ACTIONS(4549),
    [sym_preproc_open] = ACTIONS(4549),
    [sym_preproc_close] = ACTIONS(4549),
  },
  [STATE(1644)] = {
    [sym_identifier] = ACTIONS(4551),
    [anon_sym_SEMI] = ACTIONS(4553),
    [anon_sym_DASH] = ACTIONS(4553),
    [aux_sym_boolean_token1] = ACTIONS(4551),
    [aux_sym_boolean_token2] = ACTIONS(4551),
    [sym_decimal] = ACTIONS(4551),
    [anon_sym_LPAREN] = ACTIONS(4553),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4551),
    [anon_sym_LBRACK] = ACTIONS(4553),
    [aux_sym_record_type_token1] = ACTIONS(4551),
    [aux_sym_basic_type_token21] = ACTIONS(4551),
    [aux_sym_basic_type_token22] = ACTIONS(4551),
    [aux_sym_basic_type_token48] = ACTIONS(4551),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4551),
    [anon_sym_POUNDif] = ACTIONS(4553),
    [anon_sym_POUNDIF] = ACTIONS(4553),
    [anon_sym_POUNDIf] = ACTIONS(4553),
    [anon_sym_not] = ACTIONS(4551),
    [anon_sym_NOT] = ACTIONS(4551),
    [anon_sym_Not] = ACTIONS(4551),
    [anon_sym_POUNDelif] = ACTIONS(4553),
    [anon_sym_POUNDELIF] = ACTIONS(4553),
    [anon_sym_POUNDElif] = ACTIONS(4553),
    [anon_sym_POUNDelse] = ACTIONS(4553),
    [anon_sym_POUNDELSE] = ACTIONS(4553),
    [anon_sym_POUNDElse] = ACTIONS(4553),
    [anon_sym_POUNDendif] = ACTIONS(4553),
    [anon_sym_POUNDENDIF] = ACTIONS(4553),
    [anon_sym_POUNDEndif] = ACTIONS(4553),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4551),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4551),
    [anon_sym_PLUS] = ACTIONS(4553),
    [sym_datetime_literal] = ACTIONS(4553),
    [sym_date_literal] = ACTIONS(4551),
    [sym_time_literal] = ACTIONS(4551),
    [sym_biginteger_literal] = ACTIONS(4553),
    [anon_sym_if] = ACTIONS(4551),
    [anon_sym_IF] = ACTIONS(4551),
    [anon_sym_If] = ACTIONS(4551),
    [anon_sym_else] = ACTIONS(4551),
    [anon_sym_ELSE] = ACTIONS(4551),
    [anon_sym_Else] = ACTIONS(4551),
    [anon_sym_case] = ACTIONS(4551),
    [anon_sym_CASE] = ACTIONS(4551),
    [anon_sym_Case] = ACTIONS(4551),
    [anon_sym_for] = ACTIONS(4551),
    [anon_sym_FOR] = ACTIONS(4551),
    [anon_sym_For] = ACTIONS(4551),
    [anon_sym_foreach] = ACTIONS(4551),
    [anon_sym_FOREACH] = ACTIONS(4551),
    [anon_sym_Foreach] = ACTIONS(4551),
    [anon_sym_while] = ACTIONS(4551),
    [anon_sym_WHILE] = ACTIONS(4551),
    [anon_sym_While] = ACTIONS(4551),
    [anon_sym_repeat] = ACTIONS(4551),
    [anon_sym_REPEAT] = ACTIONS(4551),
    [anon_sym_Repeat] = ACTIONS(4551),
    [anon_sym_exit] = ACTIONS(4551),
    [anon_sym_EXIT] = ACTIONS(4551),
    [anon_sym_Exit] = ACTIONS(4551),
    [anon_sym_continue] = ACTIONS(4551),
    [anon_sym_CONTINUE] = ACTIONS(4551),
    [anon_sym_Continue] = ACTIONS(4551),
    [anon_sym_break] = ACTIONS(4551),
    [anon_sym_BREAK] = ACTIONS(4551),
    [anon_sym_Break] = ACTIONS(4551),
    [anon_sym_with] = ACTIONS(4551),
    [anon_sym_WITH] = ACTIONS(4551),
    [anon_sym_With] = ACTIONS(4551),
    [sym_asserterror_keyword] = ACTIONS(4553),
    [sym_page_keyword] = ACTIONS(4551),
    [anon_sym_codeunit] = ACTIONS(4551),
    [anon_sym_CODEUNIT] = ACTIONS(4551),
    [anon_sym_Codeunit] = ACTIONS(4551),
    [anon_sym_CodeUnit] = ACTIONS(4551),
    [anon_sym_COdeunit] = ACTIONS(4551),
    [anon_sym_codeUnit] = ACTIONS(4551),
    [sym_report_keyword] = ACTIONS(4551),
    [sym_query_keyword] = ACTIONS(4551),
    [anon_sym_xmlport] = ACTIONS(4551),
    [anon_sym_XMLPORT] = ACTIONS(4551),
    [anon_sym_Xmlport] = ACTIONS(4551),
    [anon_sym_XMLport] = ACTIONS(4551),
    [anon_sym_XMLPort] = ACTIONS(4551),
    [anon_sym_XmlPort] = ACTIONS(4551),
    [anon_sym_enum] = ACTIONS(4551),
    [anon_sym_ENUM] = ACTIONS(4551),
    [anon_sym_Enum] = ACTIONS(4551),
    [anon_sym_eNUM] = ACTIONS(4551),
    [anon_sym_eNum] = ACTIONS(4551),
    [anon_sym_ENum] = ACTIONS(4551),
    [sym_quoted_identifier] = ACTIONS(4553),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4553),
    [sym_integer] = ACTIONS(4551),
    [sym_continue_as_identifier] = ACTIONS(4553),
    [sym_preproc_open] = ACTIONS(4553),
    [sym_preproc_close] = ACTIONS(4553),
  },
  [STATE(1645)] = {
    [sym_identifier] = ACTIONS(4555),
    [anon_sym_SEMI] = ACTIONS(4557),
    [anon_sym_DASH] = ACTIONS(4557),
    [aux_sym_boolean_token1] = ACTIONS(4555),
    [aux_sym_boolean_token2] = ACTIONS(4555),
    [sym_decimal] = ACTIONS(4555),
    [anon_sym_LPAREN] = ACTIONS(4557),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4555),
    [anon_sym_LBRACK] = ACTIONS(4557),
    [aux_sym_record_type_token1] = ACTIONS(4555),
    [aux_sym_basic_type_token21] = ACTIONS(4555),
    [aux_sym_basic_type_token22] = ACTIONS(4555),
    [aux_sym_basic_type_token48] = ACTIONS(4555),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4555),
    [anon_sym_POUNDif] = ACTIONS(4557),
    [anon_sym_POUNDIF] = ACTIONS(4557),
    [anon_sym_POUNDIf] = ACTIONS(4557),
    [anon_sym_not] = ACTIONS(4555),
    [anon_sym_NOT] = ACTIONS(4555),
    [anon_sym_Not] = ACTIONS(4555),
    [anon_sym_POUNDelif] = ACTIONS(4557),
    [anon_sym_POUNDELIF] = ACTIONS(4557),
    [anon_sym_POUNDElif] = ACTIONS(4557),
    [anon_sym_POUNDelse] = ACTIONS(4557),
    [anon_sym_POUNDELSE] = ACTIONS(4557),
    [anon_sym_POUNDElse] = ACTIONS(4557),
    [anon_sym_POUNDendif] = ACTIONS(4557),
    [anon_sym_POUNDENDIF] = ACTIONS(4557),
    [anon_sym_POUNDEndif] = ACTIONS(4557),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4555),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4555),
    [anon_sym_PLUS] = ACTIONS(4557),
    [sym_datetime_literal] = ACTIONS(4557),
    [sym_date_literal] = ACTIONS(4555),
    [sym_time_literal] = ACTIONS(4555),
    [sym_biginteger_literal] = ACTIONS(4557),
    [anon_sym_if] = ACTIONS(4555),
    [anon_sym_IF] = ACTIONS(4555),
    [anon_sym_If] = ACTIONS(4555),
    [anon_sym_else] = ACTIONS(4555),
    [anon_sym_ELSE] = ACTIONS(4555),
    [anon_sym_Else] = ACTIONS(4555),
    [anon_sym_case] = ACTIONS(4555),
    [anon_sym_CASE] = ACTIONS(4555),
    [anon_sym_Case] = ACTIONS(4555),
    [anon_sym_for] = ACTIONS(4555),
    [anon_sym_FOR] = ACTIONS(4555),
    [anon_sym_For] = ACTIONS(4555),
    [anon_sym_foreach] = ACTIONS(4555),
    [anon_sym_FOREACH] = ACTIONS(4555),
    [anon_sym_Foreach] = ACTIONS(4555),
    [anon_sym_while] = ACTIONS(4555),
    [anon_sym_WHILE] = ACTIONS(4555),
    [anon_sym_While] = ACTIONS(4555),
    [anon_sym_repeat] = ACTIONS(4555),
    [anon_sym_REPEAT] = ACTIONS(4555),
    [anon_sym_Repeat] = ACTIONS(4555),
    [anon_sym_exit] = ACTIONS(4555),
    [anon_sym_EXIT] = ACTIONS(4555),
    [anon_sym_Exit] = ACTIONS(4555),
    [anon_sym_continue] = ACTIONS(4555),
    [anon_sym_CONTINUE] = ACTIONS(4555),
    [anon_sym_Continue] = ACTIONS(4555),
    [anon_sym_break] = ACTIONS(4555),
    [anon_sym_BREAK] = ACTIONS(4555),
    [anon_sym_Break] = ACTIONS(4555),
    [anon_sym_with] = ACTIONS(4555),
    [anon_sym_WITH] = ACTIONS(4555),
    [anon_sym_With] = ACTIONS(4555),
    [sym_asserterror_keyword] = ACTIONS(4557),
    [sym_page_keyword] = ACTIONS(4555),
    [anon_sym_codeunit] = ACTIONS(4555),
    [anon_sym_CODEUNIT] = ACTIONS(4555),
    [anon_sym_Codeunit] = ACTIONS(4555),
    [anon_sym_CodeUnit] = ACTIONS(4555),
    [anon_sym_COdeunit] = ACTIONS(4555),
    [anon_sym_codeUnit] = ACTIONS(4555),
    [sym_report_keyword] = ACTIONS(4555),
    [sym_query_keyword] = ACTIONS(4555),
    [anon_sym_xmlport] = ACTIONS(4555),
    [anon_sym_XMLPORT] = ACTIONS(4555),
    [anon_sym_Xmlport] = ACTIONS(4555),
    [anon_sym_XMLport] = ACTIONS(4555),
    [anon_sym_XMLPort] = ACTIONS(4555),
    [anon_sym_XmlPort] = ACTIONS(4555),
    [anon_sym_enum] = ACTIONS(4555),
    [anon_sym_ENUM] = ACTIONS(4555),
    [anon_sym_Enum] = ACTIONS(4555),
    [anon_sym_eNUM] = ACTIONS(4555),
    [anon_sym_eNum] = ACTIONS(4555),
    [anon_sym_ENum] = ACTIONS(4555),
    [sym_quoted_identifier] = ACTIONS(4557),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4557),
    [sym_integer] = ACTIONS(4555),
    [sym_continue_as_identifier] = ACTIONS(4557),
    [sym_preproc_open] = ACTIONS(4557),
    [sym_preproc_close] = ACTIONS(4557),
  },
  [STATE(1646)] = {
    [sym_identifier] = ACTIONS(4185),
    [anon_sym_SEMI] = ACTIONS(4187),
    [anon_sym_DASH] = ACTIONS(4187),
    [aux_sym_boolean_token1] = ACTIONS(4185),
    [aux_sym_boolean_token2] = ACTIONS(4185),
    [sym_decimal] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4187),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4185),
    [anon_sym_LBRACK] = ACTIONS(4187),
    [aux_sym_record_type_token1] = ACTIONS(4185),
    [aux_sym_basic_type_token21] = ACTIONS(4185),
    [aux_sym_basic_type_token22] = ACTIONS(4185),
    [aux_sym_basic_type_token48] = ACTIONS(4185),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4185),
    [anon_sym_POUNDif] = ACTIONS(4187),
    [anon_sym_POUNDIF] = ACTIONS(4187),
    [anon_sym_POUNDIf] = ACTIONS(4187),
    [anon_sym_not] = ACTIONS(4185),
    [anon_sym_NOT] = ACTIONS(4185),
    [anon_sym_Not] = ACTIONS(4185),
    [anon_sym_POUNDelif] = ACTIONS(4187),
    [anon_sym_POUNDELIF] = ACTIONS(4187),
    [anon_sym_POUNDElif] = ACTIONS(4187),
    [anon_sym_POUNDelse] = ACTIONS(4187),
    [anon_sym_POUNDELSE] = ACTIONS(4187),
    [anon_sym_POUNDElse] = ACTIONS(4187),
    [anon_sym_POUNDendif] = ACTIONS(4187),
    [anon_sym_POUNDENDIF] = ACTIONS(4187),
    [anon_sym_POUNDEndif] = ACTIONS(4187),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4185),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4187),
    [sym_datetime_literal] = ACTIONS(4187),
    [sym_date_literal] = ACTIONS(4185),
    [sym_time_literal] = ACTIONS(4185),
    [sym_biginteger_literal] = ACTIONS(4187),
    [anon_sym_if] = ACTIONS(4185),
    [anon_sym_IF] = ACTIONS(4185),
    [anon_sym_If] = ACTIONS(4185),
    [anon_sym_else] = ACTIONS(4185),
    [anon_sym_ELSE] = ACTIONS(4185),
    [anon_sym_Else] = ACTIONS(4185),
    [anon_sym_case] = ACTIONS(4185),
    [anon_sym_CASE] = ACTIONS(4185),
    [anon_sym_Case] = ACTIONS(4185),
    [anon_sym_for] = ACTIONS(4185),
    [anon_sym_FOR] = ACTIONS(4185),
    [anon_sym_For] = ACTIONS(4185),
    [anon_sym_foreach] = ACTIONS(4185),
    [anon_sym_FOREACH] = ACTIONS(4185),
    [anon_sym_Foreach] = ACTIONS(4185),
    [anon_sym_while] = ACTIONS(4185),
    [anon_sym_WHILE] = ACTIONS(4185),
    [anon_sym_While] = ACTIONS(4185),
    [anon_sym_repeat] = ACTIONS(4185),
    [anon_sym_REPEAT] = ACTIONS(4185),
    [anon_sym_Repeat] = ACTIONS(4185),
    [anon_sym_exit] = ACTIONS(4185),
    [anon_sym_EXIT] = ACTIONS(4185),
    [anon_sym_Exit] = ACTIONS(4185),
    [anon_sym_continue] = ACTIONS(4185),
    [anon_sym_CONTINUE] = ACTIONS(4185),
    [anon_sym_Continue] = ACTIONS(4185),
    [anon_sym_break] = ACTIONS(4185),
    [anon_sym_BREAK] = ACTIONS(4185),
    [anon_sym_Break] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4185),
    [anon_sym_WITH] = ACTIONS(4185),
    [anon_sym_With] = ACTIONS(4185),
    [sym_asserterror_keyword] = ACTIONS(4187),
    [sym_page_keyword] = ACTIONS(4185),
    [anon_sym_codeunit] = ACTIONS(4185),
    [anon_sym_CODEUNIT] = ACTIONS(4185),
    [anon_sym_Codeunit] = ACTIONS(4185),
    [anon_sym_CodeUnit] = ACTIONS(4185),
    [anon_sym_COdeunit] = ACTIONS(4185),
    [anon_sym_codeUnit] = ACTIONS(4185),
    [sym_report_keyword] = ACTIONS(4185),
    [sym_query_keyword] = ACTIONS(4185),
    [anon_sym_xmlport] = ACTIONS(4185),
    [anon_sym_XMLPORT] = ACTIONS(4185),
    [anon_sym_Xmlport] = ACTIONS(4185),
    [anon_sym_XMLport] = ACTIONS(4185),
    [anon_sym_XMLPort] = ACTIONS(4185),
    [anon_sym_XmlPort] = ACTIONS(4185),
    [anon_sym_enum] = ACTIONS(4185),
    [anon_sym_ENUM] = ACTIONS(4185),
    [anon_sym_Enum] = ACTIONS(4185),
    [anon_sym_eNUM] = ACTIONS(4185),
    [anon_sym_eNum] = ACTIONS(4185),
    [anon_sym_ENum] = ACTIONS(4185),
    [sym_quoted_identifier] = ACTIONS(4187),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4187),
    [sym_integer] = ACTIONS(4185),
    [sym_continue_as_identifier] = ACTIONS(4187),
    [sym_preproc_open] = ACTIONS(4187),
    [sym_preproc_close] = ACTIONS(4187),
  },
  [STATE(1647)] = {
    [sym_identifier] = ACTIONS(4559),
    [anon_sym_SEMI] = ACTIONS(4561),
    [anon_sym_DASH] = ACTIONS(4561),
    [aux_sym_boolean_token1] = ACTIONS(4559),
    [aux_sym_boolean_token2] = ACTIONS(4559),
    [sym_decimal] = ACTIONS(4559),
    [anon_sym_LPAREN] = ACTIONS(4561),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4559),
    [anon_sym_LBRACK] = ACTIONS(4561),
    [aux_sym_record_type_token1] = ACTIONS(4559),
    [aux_sym_basic_type_token21] = ACTIONS(4559),
    [aux_sym_basic_type_token22] = ACTIONS(4559),
    [aux_sym_basic_type_token48] = ACTIONS(4559),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4559),
    [anon_sym_POUNDif] = ACTIONS(4561),
    [anon_sym_POUNDIF] = ACTIONS(4561),
    [anon_sym_POUNDIf] = ACTIONS(4561),
    [anon_sym_not] = ACTIONS(4559),
    [anon_sym_NOT] = ACTIONS(4559),
    [anon_sym_Not] = ACTIONS(4559),
    [anon_sym_POUNDelif] = ACTIONS(4561),
    [anon_sym_POUNDELIF] = ACTIONS(4561),
    [anon_sym_POUNDElif] = ACTIONS(4561),
    [anon_sym_POUNDelse] = ACTIONS(4561),
    [anon_sym_POUNDELSE] = ACTIONS(4561),
    [anon_sym_POUNDElse] = ACTIONS(4561),
    [anon_sym_POUNDendif] = ACTIONS(4561),
    [anon_sym_POUNDENDIF] = ACTIONS(4561),
    [anon_sym_POUNDEndif] = ACTIONS(4561),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4559),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4559),
    [anon_sym_PLUS] = ACTIONS(4561),
    [sym_datetime_literal] = ACTIONS(4561),
    [sym_date_literal] = ACTIONS(4559),
    [sym_time_literal] = ACTIONS(4559),
    [sym_biginteger_literal] = ACTIONS(4561),
    [anon_sym_if] = ACTIONS(4559),
    [anon_sym_IF] = ACTIONS(4559),
    [anon_sym_If] = ACTIONS(4559),
    [anon_sym_else] = ACTIONS(4559),
    [anon_sym_ELSE] = ACTIONS(4559),
    [anon_sym_Else] = ACTIONS(4559),
    [anon_sym_case] = ACTIONS(4559),
    [anon_sym_CASE] = ACTIONS(4559),
    [anon_sym_Case] = ACTIONS(4559),
    [anon_sym_for] = ACTIONS(4559),
    [anon_sym_FOR] = ACTIONS(4559),
    [anon_sym_For] = ACTIONS(4559),
    [anon_sym_foreach] = ACTIONS(4559),
    [anon_sym_FOREACH] = ACTIONS(4559),
    [anon_sym_Foreach] = ACTIONS(4559),
    [anon_sym_while] = ACTIONS(4559),
    [anon_sym_WHILE] = ACTIONS(4559),
    [anon_sym_While] = ACTIONS(4559),
    [anon_sym_repeat] = ACTIONS(4559),
    [anon_sym_REPEAT] = ACTIONS(4559),
    [anon_sym_Repeat] = ACTIONS(4559),
    [anon_sym_exit] = ACTIONS(4559),
    [anon_sym_EXIT] = ACTIONS(4559),
    [anon_sym_Exit] = ACTIONS(4559),
    [anon_sym_continue] = ACTIONS(4559),
    [anon_sym_CONTINUE] = ACTIONS(4559),
    [anon_sym_Continue] = ACTIONS(4559),
    [anon_sym_break] = ACTIONS(4559),
    [anon_sym_BREAK] = ACTIONS(4559),
    [anon_sym_Break] = ACTIONS(4559),
    [anon_sym_with] = ACTIONS(4559),
    [anon_sym_WITH] = ACTIONS(4559),
    [anon_sym_With] = ACTIONS(4559),
    [sym_asserterror_keyword] = ACTIONS(4561),
    [sym_page_keyword] = ACTIONS(4559),
    [anon_sym_codeunit] = ACTIONS(4559),
    [anon_sym_CODEUNIT] = ACTIONS(4559),
    [anon_sym_Codeunit] = ACTIONS(4559),
    [anon_sym_CodeUnit] = ACTIONS(4559),
    [anon_sym_COdeunit] = ACTIONS(4559),
    [anon_sym_codeUnit] = ACTIONS(4559),
    [sym_report_keyword] = ACTIONS(4559),
    [sym_query_keyword] = ACTIONS(4559),
    [anon_sym_xmlport] = ACTIONS(4559),
    [anon_sym_XMLPORT] = ACTIONS(4559),
    [anon_sym_Xmlport] = ACTIONS(4559),
    [anon_sym_XMLport] = ACTIONS(4559),
    [anon_sym_XMLPort] = ACTIONS(4559),
    [anon_sym_XmlPort] = ACTIONS(4559),
    [anon_sym_enum] = ACTIONS(4559),
    [anon_sym_ENUM] = ACTIONS(4559),
    [anon_sym_Enum] = ACTIONS(4559),
    [anon_sym_eNUM] = ACTIONS(4559),
    [anon_sym_eNum] = ACTIONS(4559),
    [anon_sym_ENum] = ACTIONS(4559),
    [sym_quoted_identifier] = ACTIONS(4561),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4561),
    [sym_integer] = ACTIONS(4559),
    [sym_continue_as_identifier] = ACTIONS(4561),
    [sym_preproc_open] = ACTIONS(4561),
    [sym_preproc_close] = ACTIONS(4561),
  },
  [STATE(1648)] = {
    [sym_identifier] = ACTIONS(4563),
    [anon_sym_SEMI] = ACTIONS(4565),
    [anon_sym_DASH] = ACTIONS(4565),
    [aux_sym_boolean_token1] = ACTIONS(4563),
    [aux_sym_boolean_token2] = ACTIONS(4563),
    [sym_decimal] = ACTIONS(4563),
    [anon_sym_LPAREN] = ACTIONS(4565),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4563),
    [anon_sym_LBRACK] = ACTIONS(4565),
    [aux_sym_record_type_token1] = ACTIONS(4563),
    [aux_sym_basic_type_token21] = ACTIONS(4563),
    [aux_sym_basic_type_token22] = ACTIONS(4563),
    [aux_sym_basic_type_token48] = ACTIONS(4563),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4563),
    [anon_sym_POUNDif] = ACTIONS(4565),
    [anon_sym_POUNDIF] = ACTIONS(4565),
    [anon_sym_POUNDIf] = ACTIONS(4565),
    [anon_sym_not] = ACTIONS(4563),
    [anon_sym_NOT] = ACTIONS(4563),
    [anon_sym_Not] = ACTIONS(4563),
    [anon_sym_POUNDelif] = ACTIONS(4565),
    [anon_sym_POUNDELIF] = ACTIONS(4565),
    [anon_sym_POUNDElif] = ACTIONS(4565),
    [anon_sym_POUNDelse] = ACTIONS(4565),
    [anon_sym_POUNDELSE] = ACTIONS(4565),
    [anon_sym_POUNDElse] = ACTIONS(4565),
    [anon_sym_POUNDendif] = ACTIONS(4565),
    [anon_sym_POUNDENDIF] = ACTIONS(4565),
    [anon_sym_POUNDEndif] = ACTIONS(4565),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4563),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4563),
    [anon_sym_PLUS] = ACTIONS(4565),
    [sym_datetime_literal] = ACTIONS(4565),
    [sym_date_literal] = ACTIONS(4563),
    [sym_time_literal] = ACTIONS(4563),
    [sym_biginteger_literal] = ACTIONS(4565),
    [anon_sym_if] = ACTIONS(4563),
    [anon_sym_IF] = ACTIONS(4563),
    [anon_sym_If] = ACTIONS(4563),
    [anon_sym_else] = ACTIONS(4563),
    [anon_sym_ELSE] = ACTIONS(4563),
    [anon_sym_Else] = ACTIONS(4563),
    [anon_sym_case] = ACTIONS(4563),
    [anon_sym_CASE] = ACTIONS(4563),
    [anon_sym_Case] = ACTIONS(4563),
    [anon_sym_for] = ACTIONS(4563),
    [anon_sym_FOR] = ACTIONS(4563),
    [anon_sym_For] = ACTIONS(4563),
    [anon_sym_foreach] = ACTIONS(4563),
    [anon_sym_FOREACH] = ACTIONS(4563),
    [anon_sym_Foreach] = ACTIONS(4563),
    [anon_sym_while] = ACTIONS(4563),
    [anon_sym_WHILE] = ACTIONS(4563),
    [anon_sym_While] = ACTIONS(4563),
    [anon_sym_repeat] = ACTIONS(4563),
    [anon_sym_REPEAT] = ACTIONS(4563),
    [anon_sym_Repeat] = ACTIONS(4563),
    [anon_sym_exit] = ACTIONS(4563),
    [anon_sym_EXIT] = ACTIONS(4563),
    [anon_sym_Exit] = ACTIONS(4563),
    [anon_sym_continue] = ACTIONS(4563),
    [anon_sym_CONTINUE] = ACTIONS(4563),
    [anon_sym_Continue] = ACTIONS(4563),
    [anon_sym_break] = ACTIONS(4563),
    [anon_sym_BREAK] = ACTIONS(4563),
    [anon_sym_Break] = ACTIONS(4563),
    [anon_sym_with] = ACTIONS(4563),
    [anon_sym_WITH] = ACTIONS(4563),
    [anon_sym_With] = ACTIONS(4563),
    [sym_asserterror_keyword] = ACTIONS(4565),
    [sym_page_keyword] = ACTIONS(4563),
    [anon_sym_codeunit] = ACTIONS(4563),
    [anon_sym_CODEUNIT] = ACTIONS(4563),
    [anon_sym_Codeunit] = ACTIONS(4563),
    [anon_sym_CodeUnit] = ACTIONS(4563),
    [anon_sym_COdeunit] = ACTIONS(4563),
    [anon_sym_codeUnit] = ACTIONS(4563),
    [sym_report_keyword] = ACTIONS(4563),
    [sym_query_keyword] = ACTIONS(4563),
    [anon_sym_xmlport] = ACTIONS(4563),
    [anon_sym_XMLPORT] = ACTIONS(4563),
    [anon_sym_Xmlport] = ACTIONS(4563),
    [anon_sym_XMLport] = ACTIONS(4563),
    [anon_sym_XMLPort] = ACTIONS(4563),
    [anon_sym_XmlPort] = ACTIONS(4563),
    [anon_sym_enum] = ACTIONS(4563),
    [anon_sym_ENUM] = ACTIONS(4563),
    [anon_sym_Enum] = ACTIONS(4563),
    [anon_sym_eNUM] = ACTIONS(4563),
    [anon_sym_eNum] = ACTIONS(4563),
    [anon_sym_ENum] = ACTIONS(4563),
    [sym_quoted_identifier] = ACTIONS(4565),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4565),
    [sym_integer] = ACTIONS(4563),
    [sym_continue_as_identifier] = ACTIONS(4565),
    [sym_preproc_open] = ACTIONS(4565),
    [sym_preproc_close] = ACTIONS(4565),
  },
  [STATE(1649)] = {
    [sym_identifier] = ACTIONS(4559),
    [anon_sym_SEMI] = ACTIONS(4561),
    [anon_sym_DASH] = ACTIONS(4561),
    [aux_sym_boolean_token1] = ACTIONS(4559),
    [aux_sym_boolean_token2] = ACTIONS(4559),
    [sym_decimal] = ACTIONS(4559),
    [anon_sym_LPAREN] = ACTIONS(4561),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4559),
    [anon_sym_LBRACK] = ACTIONS(4561),
    [aux_sym_record_type_token1] = ACTIONS(4559),
    [aux_sym_basic_type_token21] = ACTIONS(4559),
    [aux_sym_basic_type_token22] = ACTIONS(4559),
    [aux_sym_basic_type_token48] = ACTIONS(4559),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4559),
    [anon_sym_POUNDif] = ACTIONS(4561),
    [anon_sym_POUNDIF] = ACTIONS(4561),
    [anon_sym_POUNDIf] = ACTIONS(4561),
    [anon_sym_not] = ACTIONS(4559),
    [anon_sym_NOT] = ACTIONS(4559),
    [anon_sym_Not] = ACTIONS(4559),
    [anon_sym_POUNDelif] = ACTIONS(4561),
    [anon_sym_POUNDELIF] = ACTIONS(4561),
    [anon_sym_POUNDElif] = ACTIONS(4561),
    [anon_sym_POUNDelse] = ACTIONS(4561),
    [anon_sym_POUNDELSE] = ACTIONS(4561),
    [anon_sym_POUNDElse] = ACTIONS(4561),
    [anon_sym_POUNDendif] = ACTIONS(4561),
    [anon_sym_POUNDENDIF] = ACTIONS(4561),
    [anon_sym_POUNDEndif] = ACTIONS(4561),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4559),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4559),
    [anon_sym_PLUS] = ACTIONS(4561),
    [sym_datetime_literal] = ACTIONS(4561),
    [sym_date_literal] = ACTIONS(4559),
    [sym_time_literal] = ACTIONS(4559),
    [sym_biginteger_literal] = ACTIONS(4561),
    [anon_sym_if] = ACTIONS(4559),
    [anon_sym_IF] = ACTIONS(4559),
    [anon_sym_If] = ACTIONS(4559),
    [anon_sym_else] = ACTIONS(4559),
    [anon_sym_ELSE] = ACTIONS(4559),
    [anon_sym_Else] = ACTIONS(4559),
    [anon_sym_case] = ACTIONS(4559),
    [anon_sym_CASE] = ACTIONS(4559),
    [anon_sym_Case] = ACTIONS(4559),
    [anon_sym_for] = ACTIONS(4559),
    [anon_sym_FOR] = ACTIONS(4559),
    [anon_sym_For] = ACTIONS(4559),
    [anon_sym_foreach] = ACTIONS(4559),
    [anon_sym_FOREACH] = ACTIONS(4559),
    [anon_sym_Foreach] = ACTIONS(4559),
    [anon_sym_while] = ACTIONS(4559),
    [anon_sym_WHILE] = ACTIONS(4559),
    [anon_sym_While] = ACTIONS(4559),
    [anon_sym_repeat] = ACTIONS(4559),
    [anon_sym_REPEAT] = ACTIONS(4559),
    [anon_sym_Repeat] = ACTIONS(4559),
    [anon_sym_exit] = ACTIONS(4559),
    [anon_sym_EXIT] = ACTIONS(4559),
    [anon_sym_Exit] = ACTIONS(4559),
    [anon_sym_continue] = ACTIONS(4559),
    [anon_sym_CONTINUE] = ACTIONS(4559),
    [anon_sym_Continue] = ACTIONS(4559),
    [anon_sym_break] = ACTIONS(4559),
    [anon_sym_BREAK] = ACTIONS(4559),
    [anon_sym_Break] = ACTIONS(4559),
    [anon_sym_with] = ACTIONS(4559),
    [anon_sym_WITH] = ACTIONS(4559),
    [anon_sym_With] = ACTIONS(4559),
    [sym_asserterror_keyword] = ACTIONS(4561),
    [sym_page_keyword] = ACTIONS(4559),
    [anon_sym_codeunit] = ACTIONS(4559),
    [anon_sym_CODEUNIT] = ACTIONS(4559),
    [anon_sym_Codeunit] = ACTIONS(4559),
    [anon_sym_CodeUnit] = ACTIONS(4559),
    [anon_sym_COdeunit] = ACTIONS(4559),
    [anon_sym_codeUnit] = ACTIONS(4559),
    [sym_report_keyword] = ACTIONS(4559),
    [sym_query_keyword] = ACTIONS(4559),
    [anon_sym_xmlport] = ACTIONS(4559),
    [anon_sym_XMLPORT] = ACTIONS(4559),
    [anon_sym_Xmlport] = ACTIONS(4559),
    [anon_sym_XMLport] = ACTIONS(4559),
    [anon_sym_XMLPort] = ACTIONS(4559),
    [anon_sym_XmlPort] = ACTIONS(4559),
    [anon_sym_enum] = ACTIONS(4559),
    [anon_sym_ENUM] = ACTIONS(4559),
    [anon_sym_Enum] = ACTIONS(4559),
    [anon_sym_eNUM] = ACTIONS(4559),
    [anon_sym_eNum] = ACTIONS(4559),
    [anon_sym_ENum] = ACTIONS(4559),
    [sym_quoted_identifier] = ACTIONS(4561),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4561),
    [sym_integer] = ACTIONS(4559),
    [sym_continue_as_identifier] = ACTIONS(4561),
    [sym_preproc_open] = ACTIONS(4561),
    [sym_preproc_close] = ACTIONS(4561),
  },
  [STATE(1650)] = {
    [sym_identifier] = ACTIONS(2843),
    [anon_sym_SEMI] = ACTIONS(2841),
    [anon_sym_DASH] = ACTIONS(2841),
    [aux_sym_boolean_token1] = ACTIONS(2843),
    [aux_sym_boolean_token2] = ACTIONS(2843),
    [sym_decimal] = ACTIONS(2843),
    [anon_sym_LPAREN] = ACTIONS(2841),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2843),
    [anon_sym_LBRACK] = ACTIONS(2841),
    [aux_sym_record_type_token1] = ACTIONS(2843),
    [aux_sym_basic_type_token21] = ACTIONS(2843),
    [aux_sym_basic_type_token22] = ACTIONS(2843),
    [aux_sym_basic_type_token48] = ACTIONS(2843),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2843),
    [anon_sym_POUNDif] = ACTIONS(2841),
    [anon_sym_POUNDIF] = ACTIONS(2841),
    [anon_sym_POUNDIf] = ACTIONS(2841),
    [anon_sym_not] = ACTIONS(2843),
    [anon_sym_NOT] = ACTIONS(2843),
    [anon_sym_Not] = ACTIONS(2843),
    [anon_sym_POUNDelif] = ACTIONS(2841),
    [anon_sym_POUNDELIF] = ACTIONS(2841),
    [anon_sym_POUNDElif] = ACTIONS(2841),
    [anon_sym_POUNDelse] = ACTIONS(2841),
    [anon_sym_POUNDELSE] = ACTIONS(2841),
    [anon_sym_POUNDElse] = ACTIONS(2841),
    [anon_sym_POUNDendif] = ACTIONS(2841),
    [anon_sym_POUNDENDIF] = ACTIONS(2841),
    [anon_sym_POUNDEndif] = ACTIONS(2841),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2843),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2843),
    [anon_sym_PLUS] = ACTIONS(2841),
    [sym_datetime_literal] = ACTIONS(2841),
    [sym_date_literal] = ACTIONS(2843),
    [sym_time_literal] = ACTIONS(2843),
    [sym_biginteger_literal] = ACTIONS(2841),
    [anon_sym_if] = ACTIONS(2843),
    [anon_sym_IF] = ACTIONS(2843),
    [anon_sym_If] = ACTIONS(2843),
    [anon_sym_else] = ACTIONS(2843),
    [anon_sym_ELSE] = ACTIONS(2843),
    [anon_sym_Else] = ACTIONS(2843),
    [anon_sym_case] = ACTIONS(2843),
    [anon_sym_CASE] = ACTIONS(2843),
    [anon_sym_Case] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2843),
    [anon_sym_FOR] = ACTIONS(2843),
    [anon_sym_For] = ACTIONS(2843),
    [anon_sym_foreach] = ACTIONS(2843),
    [anon_sym_FOREACH] = ACTIONS(2843),
    [anon_sym_Foreach] = ACTIONS(2843),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_WHILE] = ACTIONS(2843),
    [anon_sym_While] = ACTIONS(2843),
    [anon_sym_repeat] = ACTIONS(2843),
    [anon_sym_REPEAT] = ACTIONS(2843),
    [anon_sym_Repeat] = ACTIONS(2843),
    [anon_sym_exit] = ACTIONS(2843),
    [anon_sym_EXIT] = ACTIONS(2843),
    [anon_sym_Exit] = ACTIONS(2843),
    [anon_sym_continue] = ACTIONS(2843),
    [anon_sym_CONTINUE] = ACTIONS(2843),
    [anon_sym_Continue] = ACTIONS(2843),
    [anon_sym_break] = ACTIONS(2843),
    [anon_sym_BREAK] = ACTIONS(2843),
    [anon_sym_Break] = ACTIONS(2843),
    [anon_sym_with] = ACTIONS(2843),
    [anon_sym_WITH] = ACTIONS(2843),
    [anon_sym_With] = ACTIONS(2843),
    [sym_asserterror_keyword] = ACTIONS(2841),
    [sym_page_keyword] = ACTIONS(2843),
    [anon_sym_codeunit] = ACTIONS(2843),
    [anon_sym_CODEUNIT] = ACTIONS(2843),
    [anon_sym_Codeunit] = ACTIONS(2843),
    [anon_sym_CodeUnit] = ACTIONS(2843),
    [anon_sym_COdeunit] = ACTIONS(2843),
    [anon_sym_codeUnit] = ACTIONS(2843),
    [sym_report_keyword] = ACTIONS(2843),
    [sym_query_keyword] = ACTIONS(2843),
    [anon_sym_xmlport] = ACTIONS(2843),
    [anon_sym_XMLPORT] = ACTIONS(2843),
    [anon_sym_Xmlport] = ACTIONS(2843),
    [anon_sym_XMLport] = ACTIONS(2843),
    [anon_sym_XMLPort] = ACTIONS(2843),
    [anon_sym_XmlPort] = ACTIONS(2843),
    [anon_sym_enum] = ACTIONS(2843),
    [anon_sym_ENUM] = ACTIONS(2843),
    [anon_sym_Enum] = ACTIONS(2843),
    [anon_sym_eNUM] = ACTIONS(2843),
    [anon_sym_eNum] = ACTIONS(2843),
    [anon_sym_ENum] = ACTIONS(2843),
    [sym_quoted_identifier] = ACTIONS(2841),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2841),
    [sym_integer] = ACTIONS(2843),
    [sym_continue_as_identifier] = ACTIONS(2841),
    [sym_preproc_open] = ACTIONS(2841),
    [sym_preproc_close] = ACTIONS(2841),
  },
  [STATE(1651)] = {
    [sym_identifier] = ACTIONS(4567),
    [anon_sym_SEMI] = ACTIONS(4569),
    [anon_sym_DASH] = ACTIONS(4571),
    [aux_sym_boolean_token1] = ACTIONS(4567),
    [aux_sym_boolean_token2] = ACTIONS(4567),
    [sym_decimal] = ACTIONS(4567),
    [anon_sym_LPAREN] = ACTIONS(4571),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4567),
    [anon_sym_LBRACK] = ACTIONS(4571),
    [aux_sym_record_type_token1] = ACTIONS(4567),
    [aux_sym_basic_type_token21] = ACTIONS(4567),
    [aux_sym_basic_type_token22] = ACTIONS(4567),
    [aux_sym_basic_type_token48] = ACTIONS(4567),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4567),
    [anon_sym_POUNDif] = ACTIONS(4571),
    [anon_sym_POUNDIF] = ACTIONS(4571),
    [anon_sym_POUNDIf] = ACTIONS(4571),
    [anon_sym_not] = ACTIONS(4567),
    [anon_sym_NOT] = ACTIONS(4567),
    [anon_sym_Not] = ACTIONS(4567),
    [anon_sym_POUNDelif] = ACTIONS(4571),
    [anon_sym_POUNDELIF] = ACTIONS(4571),
    [anon_sym_POUNDElif] = ACTIONS(4571),
    [anon_sym_POUNDelse] = ACTIONS(4571),
    [anon_sym_POUNDELSE] = ACTIONS(4571),
    [anon_sym_POUNDElse] = ACTIONS(4571),
    [anon_sym_POUNDendif] = ACTIONS(4571),
    [anon_sym_POUNDENDIF] = ACTIONS(4571),
    [anon_sym_POUNDEndif] = ACTIONS(4571),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4567),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4567),
    [anon_sym_PLUS] = ACTIONS(4571),
    [sym_datetime_literal] = ACTIONS(4571),
    [sym_date_literal] = ACTIONS(4567),
    [sym_time_literal] = ACTIONS(4567),
    [sym_biginteger_literal] = ACTIONS(4571),
    [anon_sym_if] = ACTIONS(4567),
    [anon_sym_IF] = ACTIONS(4567),
    [anon_sym_If] = ACTIONS(4567),
    [anon_sym_else] = ACTIONS(4567),
    [anon_sym_ELSE] = ACTIONS(4567),
    [anon_sym_Else] = ACTIONS(4567),
    [anon_sym_case] = ACTIONS(4567),
    [anon_sym_CASE] = ACTIONS(4567),
    [anon_sym_Case] = ACTIONS(4567),
    [anon_sym_for] = ACTIONS(4567),
    [anon_sym_FOR] = ACTIONS(4567),
    [anon_sym_For] = ACTIONS(4567),
    [anon_sym_foreach] = ACTIONS(4567),
    [anon_sym_FOREACH] = ACTIONS(4567),
    [anon_sym_Foreach] = ACTIONS(4567),
    [anon_sym_while] = ACTIONS(4567),
    [anon_sym_WHILE] = ACTIONS(4567),
    [anon_sym_While] = ACTIONS(4567),
    [anon_sym_repeat] = ACTIONS(4567),
    [anon_sym_REPEAT] = ACTIONS(4567),
    [anon_sym_Repeat] = ACTIONS(4567),
    [anon_sym_exit] = ACTIONS(4567),
    [anon_sym_EXIT] = ACTIONS(4567),
    [anon_sym_Exit] = ACTIONS(4567),
    [anon_sym_continue] = ACTIONS(4567),
    [anon_sym_CONTINUE] = ACTIONS(4567),
    [anon_sym_Continue] = ACTIONS(4567),
    [anon_sym_break] = ACTIONS(4567),
    [anon_sym_BREAK] = ACTIONS(4567),
    [anon_sym_Break] = ACTIONS(4567),
    [anon_sym_with] = ACTIONS(4567),
    [anon_sym_WITH] = ACTIONS(4567),
    [anon_sym_With] = ACTIONS(4567),
    [sym_asserterror_keyword] = ACTIONS(4571),
    [sym_page_keyword] = ACTIONS(4567),
    [anon_sym_codeunit] = ACTIONS(4567),
    [anon_sym_CODEUNIT] = ACTIONS(4567),
    [anon_sym_Codeunit] = ACTIONS(4567),
    [anon_sym_CodeUnit] = ACTIONS(4567),
    [anon_sym_COdeunit] = ACTIONS(4567),
    [anon_sym_codeUnit] = ACTIONS(4567),
    [sym_report_keyword] = ACTIONS(4567),
    [sym_query_keyword] = ACTIONS(4567),
    [anon_sym_xmlport] = ACTIONS(4567),
    [anon_sym_XMLPORT] = ACTIONS(4567),
    [anon_sym_Xmlport] = ACTIONS(4567),
    [anon_sym_XMLport] = ACTIONS(4567),
    [anon_sym_XMLPort] = ACTIONS(4567),
    [anon_sym_XmlPort] = ACTIONS(4567),
    [anon_sym_enum] = ACTIONS(4567),
    [anon_sym_ENUM] = ACTIONS(4567),
    [anon_sym_Enum] = ACTIONS(4567),
    [anon_sym_eNUM] = ACTIONS(4567),
    [anon_sym_eNum] = ACTIONS(4567),
    [anon_sym_ENum] = ACTIONS(4567),
    [sym_quoted_identifier] = ACTIONS(4571),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4571),
    [sym_integer] = ACTIONS(4567),
    [sym_continue_as_identifier] = ACTIONS(4571),
    [sym_preproc_open] = ACTIONS(4571),
    [sym_preproc_close] = ACTIONS(4571),
  },
  [STATE(1652)] = {
    [sym_identifier] = ACTIONS(4573),
    [anon_sym_SEMI] = ACTIONS(4575),
    [anon_sym_DASH] = ACTIONS(4575),
    [aux_sym_boolean_token1] = ACTIONS(4573),
    [aux_sym_boolean_token2] = ACTIONS(4573),
    [sym_decimal] = ACTIONS(4573),
    [anon_sym_LPAREN] = ACTIONS(4575),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4573),
    [anon_sym_LBRACK] = ACTIONS(4575),
    [aux_sym_record_type_token1] = ACTIONS(4573),
    [aux_sym_basic_type_token21] = ACTIONS(4573),
    [aux_sym_basic_type_token22] = ACTIONS(4573),
    [aux_sym_basic_type_token48] = ACTIONS(4573),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4573),
    [anon_sym_POUNDif] = ACTIONS(4575),
    [anon_sym_POUNDIF] = ACTIONS(4575),
    [anon_sym_POUNDIf] = ACTIONS(4575),
    [anon_sym_not] = ACTIONS(4573),
    [anon_sym_NOT] = ACTIONS(4573),
    [anon_sym_Not] = ACTIONS(4573),
    [anon_sym_POUNDelif] = ACTIONS(4575),
    [anon_sym_POUNDELIF] = ACTIONS(4575),
    [anon_sym_POUNDElif] = ACTIONS(4575),
    [anon_sym_POUNDelse] = ACTIONS(4575),
    [anon_sym_POUNDELSE] = ACTIONS(4575),
    [anon_sym_POUNDElse] = ACTIONS(4575),
    [anon_sym_POUNDendif] = ACTIONS(4575),
    [anon_sym_POUNDENDIF] = ACTIONS(4575),
    [anon_sym_POUNDEndif] = ACTIONS(4575),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4573),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4573),
    [anon_sym_PLUS] = ACTIONS(4575),
    [sym_datetime_literal] = ACTIONS(4575),
    [sym_date_literal] = ACTIONS(4573),
    [sym_time_literal] = ACTIONS(4573),
    [sym_biginteger_literal] = ACTIONS(4575),
    [anon_sym_if] = ACTIONS(4573),
    [anon_sym_IF] = ACTIONS(4573),
    [anon_sym_If] = ACTIONS(4573),
    [anon_sym_else] = ACTIONS(4573),
    [anon_sym_ELSE] = ACTIONS(4573),
    [anon_sym_Else] = ACTIONS(4573),
    [anon_sym_case] = ACTIONS(4573),
    [anon_sym_CASE] = ACTIONS(4573),
    [anon_sym_Case] = ACTIONS(4573),
    [anon_sym_for] = ACTIONS(4573),
    [anon_sym_FOR] = ACTIONS(4573),
    [anon_sym_For] = ACTIONS(4573),
    [anon_sym_foreach] = ACTIONS(4573),
    [anon_sym_FOREACH] = ACTIONS(4573),
    [anon_sym_Foreach] = ACTIONS(4573),
    [anon_sym_while] = ACTIONS(4573),
    [anon_sym_WHILE] = ACTIONS(4573),
    [anon_sym_While] = ACTIONS(4573),
    [anon_sym_repeat] = ACTIONS(4573),
    [anon_sym_REPEAT] = ACTIONS(4573),
    [anon_sym_Repeat] = ACTIONS(4573),
    [anon_sym_exit] = ACTIONS(4573),
    [anon_sym_EXIT] = ACTIONS(4573),
    [anon_sym_Exit] = ACTIONS(4573),
    [anon_sym_continue] = ACTIONS(4573),
    [anon_sym_CONTINUE] = ACTIONS(4573),
    [anon_sym_Continue] = ACTIONS(4573),
    [anon_sym_break] = ACTIONS(4573),
    [anon_sym_BREAK] = ACTIONS(4573),
    [anon_sym_Break] = ACTIONS(4573),
    [anon_sym_with] = ACTIONS(4573),
    [anon_sym_WITH] = ACTIONS(4573),
    [anon_sym_With] = ACTIONS(4573),
    [sym_asserterror_keyword] = ACTIONS(4575),
    [sym_page_keyword] = ACTIONS(4573),
    [anon_sym_codeunit] = ACTIONS(4573),
    [anon_sym_CODEUNIT] = ACTIONS(4573),
    [anon_sym_Codeunit] = ACTIONS(4573),
    [anon_sym_CodeUnit] = ACTIONS(4573),
    [anon_sym_COdeunit] = ACTIONS(4573),
    [anon_sym_codeUnit] = ACTIONS(4573),
    [sym_report_keyword] = ACTIONS(4573),
    [sym_query_keyword] = ACTIONS(4573),
    [anon_sym_xmlport] = ACTIONS(4573),
    [anon_sym_XMLPORT] = ACTIONS(4573),
    [anon_sym_Xmlport] = ACTIONS(4573),
    [anon_sym_XMLport] = ACTIONS(4573),
    [anon_sym_XMLPort] = ACTIONS(4573),
    [anon_sym_XmlPort] = ACTIONS(4573),
    [anon_sym_enum] = ACTIONS(4573),
    [anon_sym_ENUM] = ACTIONS(4573),
    [anon_sym_Enum] = ACTIONS(4573),
    [anon_sym_eNUM] = ACTIONS(4573),
    [anon_sym_eNum] = ACTIONS(4573),
    [anon_sym_ENum] = ACTIONS(4573),
    [sym_quoted_identifier] = ACTIONS(4575),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4575),
    [sym_integer] = ACTIONS(4573),
    [sym_continue_as_identifier] = ACTIONS(4575),
    [sym_preproc_open] = ACTIONS(4575),
    [sym_preproc_close] = ACTIONS(4575),
  },
  [STATE(1653)] = {
    [sym_identifier] = ACTIONS(4577),
    [anon_sym_SEMI] = ACTIONS(4579),
    [anon_sym_DASH] = ACTIONS(4579),
    [aux_sym_boolean_token1] = ACTIONS(4577),
    [aux_sym_boolean_token2] = ACTIONS(4577),
    [sym_decimal] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(4579),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4579),
    [aux_sym_record_type_token1] = ACTIONS(4577),
    [aux_sym_basic_type_token21] = ACTIONS(4577),
    [aux_sym_basic_type_token22] = ACTIONS(4577),
    [aux_sym_basic_type_token48] = ACTIONS(4577),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4577),
    [anon_sym_POUNDif] = ACTIONS(4579),
    [anon_sym_POUNDIF] = ACTIONS(4579),
    [anon_sym_POUNDIf] = ACTIONS(4579),
    [anon_sym_not] = ACTIONS(4577),
    [anon_sym_NOT] = ACTIONS(4577),
    [anon_sym_Not] = ACTIONS(4577),
    [anon_sym_POUNDelif] = ACTIONS(4579),
    [anon_sym_POUNDELIF] = ACTIONS(4579),
    [anon_sym_POUNDElif] = ACTIONS(4579),
    [anon_sym_POUNDelse] = ACTIONS(4579),
    [anon_sym_POUNDELSE] = ACTIONS(4579),
    [anon_sym_POUNDElse] = ACTIONS(4579),
    [anon_sym_POUNDendif] = ACTIONS(4579),
    [anon_sym_POUNDENDIF] = ACTIONS(4579),
    [anon_sym_POUNDEndif] = ACTIONS(4579),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4577),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4577),
    [anon_sym_PLUS] = ACTIONS(4579),
    [sym_datetime_literal] = ACTIONS(4579),
    [sym_date_literal] = ACTIONS(4577),
    [sym_time_literal] = ACTIONS(4577),
    [sym_biginteger_literal] = ACTIONS(4579),
    [anon_sym_if] = ACTIONS(4577),
    [anon_sym_IF] = ACTIONS(4577),
    [anon_sym_If] = ACTIONS(4577),
    [anon_sym_else] = ACTIONS(4577),
    [anon_sym_ELSE] = ACTIONS(4577),
    [anon_sym_Else] = ACTIONS(4577),
    [anon_sym_case] = ACTIONS(4577),
    [anon_sym_CASE] = ACTIONS(4577),
    [anon_sym_Case] = ACTIONS(4577),
    [anon_sym_for] = ACTIONS(4577),
    [anon_sym_FOR] = ACTIONS(4577),
    [anon_sym_For] = ACTIONS(4577),
    [anon_sym_foreach] = ACTIONS(4577),
    [anon_sym_FOREACH] = ACTIONS(4577),
    [anon_sym_Foreach] = ACTIONS(4577),
    [anon_sym_while] = ACTIONS(4577),
    [anon_sym_WHILE] = ACTIONS(4577),
    [anon_sym_While] = ACTIONS(4577),
    [anon_sym_repeat] = ACTIONS(4577),
    [anon_sym_REPEAT] = ACTIONS(4577),
    [anon_sym_Repeat] = ACTIONS(4577),
    [anon_sym_exit] = ACTIONS(4577),
    [anon_sym_EXIT] = ACTIONS(4577),
    [anon_sym_Exit] = ACTIONS(4577),
    [anon_sym_continue] = ACTIONS(4577),
    [anon_sym_CONTINUE] = ACTIONS(4577),
    [anon_sym_Continue] = ACTIONS(4577),
    [anon_sym_break] = ACTIONS(4577),
    [anon_sym_BREAK] = ACTIONS(4577),
    [anon_sym_Break] = ACTIONS(4577),
    [anon_sym_with] = ACTIONS(4577),
    [anon_sym_WITH] = ACTIONS(4577),
    [anon_sym_With] = ACTIONS(4577),
    [sym_asserterror_keyword] = ACTIONS(4579),
    [sym_page_keyword] = ACTIONS(4577),
    [anon_sym_codeunit] = ACTIONS(4577),
    [anon_sym_CODEUNIT] = ACTIONS(4577),
    [anon_sym_Codeunit] = ACTIONS(4577),
    [anon_sym_CodeUnit] = ACTIONS(4577),
    [anon_sym_COdeunit] = ACTIONS(4577),
    [anon_sym_codeUnit] = ACTIONS(4577),
    [sym_report_keyword] = ACTIONS(4577),
    [sym_query_keyword] = ACTIONS(4577),
    [anon_sym_xmlport] = ACTIONS(4577),
    [anon_sym_XMLPORT] = ACTIONS(4577),
    [anon_sym_Xmlport] = ACTIONS(4577),
    [anon_sym_XMLport] = ACTIONS(4577),
    [anon_sym_XMLPort] = ACTIONS(4577),
    [anon_sym_XmlPort] = ACTIONS(4577),
    [anon_sym_enum] = ACTIONS(4577),
    [anon_sym_ENUM] = ACTIONS(4577),
    [anon_sym_Enum] = ACTIONS(4577),
    [anon_sym_eNUM] = ACTIONS(4577),
    [anon_sym_eNum] = ACTIONS(4577),
    [anon_sym_ENum] = ACTIONS(4577),
    [sym_quoted_identifier] = ACTIONS(4579),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4579),
    [sym_integer] = ACTIONS(4577),
    [sym_continue_as_identifier] = ACTIONS(4579),
    [sym_preproc_open] = ACTIONS(4579),
    [sym_preproc_close] = ACTIONS(4579),
  },
  [STATE(1654)] = {
    [aux_sym_option_member_list_repeat2] = STATE(1654),
    [sym_identifier] = ACTIONS(565),
    [anon_sym_SEMI] = ACTIONS(567),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_EQ] = ACTIONS(567),
    [anon_sym_COMMA] = ACTIONS(4581),
    [anon_sym_COLON] = ACTIONS(565),
    [anon_sym_DASH] = ACTIONS(565),
    [aux_sym_boolean_token1] = ACTIONS(565),
    [aux_sym_boolean_token2] = ACTIONS(565),
    [anon_sym_RPAREN] = ACTIONS(567),
    [aux_sym_where_condition_token1] = ACTIONS(565),
    [anon_sym_DOT_DOT] = ACTIONS(567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(565),
    [anon_sym_STAR] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_RBRACK] = ACTIONS(567),
    [aux_sym_record_type_token1] = ACTIONS(565),
    [aux_sym_basic_type_token21] = ACTIONS(565),
    [aux_sym_basic_type_token22] = ACTIONS(565),
    [aux_sym_basic_type_token48] = ACTIONS(565),
    [aux_sym_basic_type_token53] = ACTIONS(565),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(565),
    [aux_sym_separator_action_token1] = ACTIONS(565),
    [aux_sym_type_declaration_token1] = ACTIONS(565),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(567),
    [aux_sym__expression_token1] = ACTIONS(567),
    [aux_sym__expression_token2] = ACTIONS(567),
    [aux_sym_keyword_identifier_token1] = ACTIONS(565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(565),
    [anon_sym_SLASH] = ACTIONS(565),
    [anon_sym_div] = ACTIONS(565),
    [anon_sym_DIV] = ACTIONS(565),
    [anon_sym_Div] = ACTIONS(565),
    [anon_sym_mod] = ACTIONS(565),
    [anon_sym_MOD] = ACTIONS(565),
    [anon_sym_Mod] = ACTIONS(565),
    [anon_sym_PLUS] = ACTIONS(565),
    [anon_sym_GT_EQ] = ACTIONS(567),
    [anon_sym_LT_EQ] = ACTIONS(567),
    [anon_sym_GT] = ACTIONS(565),
    [anon_sym_LT] = ACTIONS(565),
    [anon_sym_LT_GT] = ACTIONS(567),
    [anon_sym_and] = ACTIONS(565),
    [anon_sym_AND] = ACTIONS(565),
    [anon_sym_And] = ACTIONS(565),
    [anon_sym_or] = ACTIONS(565),
    [anon_sym_OR] = ACTIONS(565),
    [anon_sym_Or] = ACTIONS(565),
    [anon_sym_xor] = ACTIONS(565),
    [anon_sym_XOR] = ACTIONS(565),
    [anon_sym_Xor] = ACTIONS(565),
    [anon_sym_QMARK] = ACTIONS(567),
    [anon_sym_then] = ACTIONS(565),
    [anon_sym_THEN] = ACTIONS(565),
    [anon_sym_Then] = ACTIONS(565),
    [anon_sym_else] = ACTIONS(565),
    [anon_sym_ELSE] = ACTIONS(565),
    [anon_sym_Else] = ACTIONS(565),
    [anon_sym_of] = ACTIONS(565),
    [anon_sym_OF] = ACTIONS(565),
    [anon_sym_Of] = ACTIONS(565),
    [anon_sym_do] = ACTIONS(565),
    [anon_sym_DO] = ACTIONS(565),
    [anon_sym_Do] = ACTIONS(565),
    [anon_sym_in] = ACTIONS(565),
    [anon_sym_IN] = ACTIONS(565),
    [anon_sym_In] = ACTIONS(565),
    [sym_page_keyword] = ACTIONS(565),
    [anon_sym_codeunit] = ACTIONS(565),
    [anon_sym_CODEUNIT] = ACTIONS(565),
    [anon_sym_Codeunit] = ACTIONS(565),
    [anon_sym_CodeUnit] = ACTIONS(565),
    [anon_sym_COdeunit] = ACTIONS(565),
    [anon_sym_codeUnit] = ACTIONS(565),
    [sym_report_keyword] = ACTIONS(565),
    [sym_query_keyword] = ACTIONS(565),
    [anon_sym_xmlport] = ACTIONS(565),
    [anon_sym_XMLPORT] = ACTIONS(565),
    [anon_sym_Xmlport] = ACTIONS(565),
    [anon_sym_XMLport] = ACTIONS(565),
    [anon_sym_XMLPort] = ACTIONS(565),
    [anon_sym_XmlPort] = ACTIONS(565),
    [anon_sym_enum] = ACTIONS(565),
    [anon_sym_ENUM] = ACTIONS(565),
    [anon_sym_Enum] = ACTIONS(565),
    [anon_sym_eNUM] = ACTIONS(565),
    [anon_sym_eNum] = ACTIONS(565),
    [anon_sym_ENum] = ACTIONS(565),
    [sym_local_keyword] = ACTIONS(565),
    [sym_internal_keyword] = ACTIONS(565),
    [sym_protected_keyword] = ACTIONS(565),
    [sym_key_keyword] = ACTIONS(565),
    [sym_dataset_keyword] = ACTIONS(565),
    [sym_quoted_identifier] = ACTIONS(567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(567),
    [sym_integer] = ACTIONS(567),
  },
  [STATE(1655)] = {
    [sym_else_keyword] = STATE(11),
    [sym_identifier] = ACTIONS(4119),
    [anon_sym_SEMI] = ACTIONS(4121),
    [anon_sym_DASH] = ACTIONS(4121),
    [aux_sym_boolean_token1] = ACTIONS(4119),
    [aux_sym_boolean_token2] = ACTIONS(4119),
    [sym_decimal] = ACTIONS(4119),
    [anon_sym_LPAREN] = ACTIONS(4121),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4119),
    [anon_sym_LBRACK] = ACTIONS(4121),
    [aux_sym_record_type_token1] = ACTIONS(4119),
    [aux_sym_basic_type_token21] = ACTIONS(4119),
    [aux_sym_basic_type_token22] = ACTIONS(4119),
    [aux_sym_basic_type_token48] = ACTIONS(4119),
    [anon_sym_POUNDif] = ACTIONS(4121),
    [anon_sym_POUNDIF] = ACTIONS(4121),
    [anon_sym_POUNDIf] = ACTIONS(4121),
    [anon_sym_not] = ACTIONS(4119),
    [anon_sym_NOT] = ACTIONS(4119),
    [anon_sym_Not] = ACTIONS(4119),
    [anon_sym_POUNDelif] = ACTIONS(4121),
    [anon_sym_POUNDELIF] = ACTIONS(4121),
    [anon_sym_POUNDElif] = ACTIONS(4121),
    [anon_sym_POUNDelse] = ACTIONS(4121),
    [anon_sym_POUNDELSE] = ACTIONS(4121),
    [anon_sym_POUNDElse] = ACTIONS(4121),
    [anon_sym_POUNDendif] = ACTIONS(4121),
    [anon_sym_POUNDENDIF] = ACTIONS(4121),
    [anon_sym_POUNDEndif] = ACTIONS(4121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4119),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4119),
    [anon_sym_PLUS] = ACTIONS(4121),
    [sym_datetime_literal] = ACTIONS(4121),
    [sym_date_literal] = ACTIONS(4119),
    [sym_time_literal] = ACTIONS(4119),
    [sym_biginteger_literal] = ACTIONS(4121),
    [anon_sym_if] = ACTIONS(4119),
    [anon_sym_IF] = ACTIONS(4119),
    [anon_sym_If] = ACTIONS(4119),
    [anon_sym_else] = ACTIONS(4123),
    [anon_sym_ELSE] = ACTIONS(4123),
    [anon_sym_Else] = ACTIONS(4123),
    [anon_sym_case] = ACTIONS(4119),
    [anon_sym_CASE] = ACTIONS(4119),
    [anon_sym_Case] = ACTIONS(4119),
    [anon_sym_for] = ACTIONS(4119),
    [anon_sym_FOR] = ACTIONS(4119),
    [anon_sym_For] = ACTIONS(4119),
    [anon_sym_foreach] = ACTIONS(4119),
    [anon_sym_FOREACH] = ACTIONS(4119),
    [anon_sym_Foreach] = ACTIONS(4119),
    [anon_sym_while] = ACTIONS(4119),
    [anon_sym_WHILE] = ACTIONS(4119),
    [anon_sym_While] = ACTIONS(4119),
    [anon_sym_repeat] = ACTIONS(4119),
    [anon_sym_REPEAT] = ACTIONS(4119),
    [anon_sym_Repeat] = ACTIONS(4119),
    [anon_sym_exit] = ACTIONS(4119),
    [anon_sym_EXIT] = ACTIONS(4119),
    [anon_sym_Exit] = ACTIONS(4119),
    [anon_sym_continue] = ACTIONS(4119),
    [anon_sym_CONTINUE] = ACTIONS(4119),
    [anon_sym_Continue] = ACTIONS(4119),
    [anon_sym_break] = ACTIONS(4119),
    [anon_sym_BREAK] = ACTIONS(4119),
    [anon_sym_Break] = ACTIONS(4119),
    [anon_sym_with] = ACTIONS(4119),
    [anon_sym_WITH] = ACTIONS(4119),
    [anon_sym_With] = ACTIONS(4119),
    [sym_asserterror_keyword] = ACTIONS(4121),
    [sym_page_keyword] = ACTIONS(4119),
    [anon_sym_codeunit] = ACTIONS(4119),
    [anon_sym_CODEUNIT] = ACTIONS(4119),
    [anon_sym_Codeunit] = ACTIONS(4119),
    [anon_sym_CodeUnit] = ACTIONS(4119),
    [anon_sym_COdeunit] = ACTIONS(4119),
    [anon_sym_codeUnit] = ACTIONS(4119),
    [sym_report_keyword] = ACTIONS(4119),
    [sym_query_keyword] = ACTIONS(4119),
    [anon_sym_xmlport] = ACTIONS(4119),
    [anon_sym_XMLPORT] = ACTIONS(4119),
    [anon_sym_Xmlport] = ACTIONS(4119),
    [anon_sym_XMLport] = ACTIONS(4119),
    [anon_sym_XMLPort] = ACTIONS(4119),
    [anon_sym_XmlPort] = ACTIONS(4119),
    [anon_sym_enum] = ACTIONS(4119),
    [anon_sym_ENUM] = ACTIONS(4119),
    [anon_sym_Enum] = ACTIONS(4119),
    [anon_sym_eNUM] = ACTIONS(4119),
    [anon_sym_eNum] = ACTIONS(4119),
    [anon_sym_ENum] = ACTIONS(4119),
    [sym_quoted_identifier] = ACTIONS(4121),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4121),
    [sym_integer] = ACTIONS(4119),
    [sym_continue_as_identifier] = ACTIONS(4121),
    [sym_preproc_open] = ACTIONS(4121),
    [sym_preproc_close] = ACTIONS(4121),
  },
  [STATE(1656)] = {
    [sym_else_keyword] = STATE(12),
    [sym_identifier] = ACTIONS(4125),
    [anon_sym_SEMI] = ACTIONS(4127),
    [anon_sym_DASH] = ACTIONS(4127),
    [aux_sym_boolean_token1] = ACTIONS(4125),
    [aux_sym_boolean_token2] = ACTIONS(4125),
    [sym_decimal] = ACTIONS(4125),
    [anon_sym_LPAREN] = ACTIONS(4127),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4125),
    [anon_sym_LBRACK] = ACTIONS(4127),
    [aux_sym_record_type_token1] = ACTIONS(4125),
    [aux_sym_basic_type_token21] = ACTIONS(4125),
    [aux_sym_basic_type_token22] = ACTIONS(4125),
    [aux_sym_basic_type_token48] = ACTIONS(4125),
    [anon_sym_POUNDif] = ACTIONS(4127),
    [anon_sym_POUNDIF] = ACTIONS(4127),
    [anon_sym_POUNDIf] = ACTIONS(4127),
    [anon_sym_not] = ACTIONS(4125),
    [anon_sym_NOT] = ACTIONS(4125),
    [anon_sym_Not] = ACTIONS(4125),
    [anon_sym_POUNDelif] = ACTIONS(4127),
    [anon_sym_POUNDELIF] = ACTIONS(4127),
    [anon_sym_POUNDElif] = ACTIONS(4127),
    [anon_sym_POUNDelse] = ACTIONS(4127),
    [anon_sym_POUNDELSE] = ACTIONS(4127),
    [anon_sym_POUNDElse] = ACTIONS(4127),
    [anon_sym_POUNDendif] = ACTIONS(4127),
    [anon_sym_POUNDENDIF] = ACTIONS(4127),
    [anon_sym_POUNDEndif] = ACTIONS(4127),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4125),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4125),
    [anon_sym_PLUS] = ACTIONS(4127),
    [sym_datetime_literal] = ACTIONS(4127),
    [sym_date_literal] = ACTIONS(4125),
    [sym_time_literal] = ACTIONS(4125),
    [sym_biginteger_literal] = ACTIONS(4127),
    [anon_sym_if] = ACTIONS(4125),
    [anon_sym_IF] = ACTIONS(4125),
    [anon_sym_If] = ACTIONS(4125),
    [anon_sym_else] = ACTIONS(4123),
    [anon_sym_ELSE] = ACTIONS(4123),
    [anon_sym_Else] = ACTIONS(4123),
    [anon_sym_case] = ACTIONS(4125),
    [anon_sym_CASE] = ACTIONS(4125),
    [anon_sym_Case] = ACTIONS(4125),
    [anon_sym_for] = ACTIONS(4125),
    [anon_sym_FOR] = ACTIONS(4125),
    [anon_sym_For] = ACTIONS(4125),
    [anon_sym_foreach] = ACTIONS(4125),
    [anon_sym_FOREACH] = ACTIONS(4125),
    [anon_sym_Foreach] = ACTIONS(4125),
    [anon_sym_while] = ACTIONS(4125),
    [anon_sym_WHILE] = ACTIONS(4125),
    [anon_sym_While] = ACTIONS(4125),
    [anon_sym_repeat] = ACTIONS(4125),
    [anon_sym_REPEAT] = ACTIONS(4125),
    [anon_sym_Repeat] = ACTIONS(4125),
    [anon_sym_exit] = ACTIONS(4125),
    [anon_sym_EXIT] = ACTIONS(4125),
    [anon_sym_Exit] = ACTIONS(4125),
    [anon_sym_continue] = ACTIONS(4125),
    [anon_sym_CONTINUE] = ACTIONS(4125),
    [anon_sym_Continue] = ACTIONS(4125),
    [anon_sym_break] = ACTIONS(4125),
    [anon_sym_BREAK] = ACTIONS(4125),
    [anon_sym_Break] = ACTIONS(4125),
    [anon_sym_with] = ACTIONS(4125),
    [anon_sym_WITH] = ACTIONS(4125),
    [anon_sym_With] = ACTIONS(4125),
    [sym_asserterror_keyword] = ACTIONS(4127),
    [sym_page_keyword] = ACTIONS(4125),
    [anon_sym_codeunit] = ACTIONS(4125),
    [anon_sym_CODEUNIT] = ACTIONS(4125),
    [anon_sym_Codeunit] = ACTIONS(4125),
    [anon_sym_CodeUnit] = ACTIONS(4125),
    [anon_sym_COdeunit] = ACTIONS(4125),
    [anon_sym_codeUnit] = ACTIONS(4125),
    [sym_report_keyword] = ACTIONS(4125),
    [sym_query_keyword] = ACTIONS(4125),
    [anon_sym_xmlport] = ACTIONS(4125),
    [anon_sym_XMLPORT] = ACTIONS(4125),
    [anon_sym_Xmlport] = ACTIONS(4125),
    [anon_sym_XMLport] = ACTIONS(4125),
    [anon_sym_XMLPort] = ACTIONS(4125),
    [anon_sym_XmlPort] = ACTIONS(4125),
    [anon_sym_enum] = ACTIONS(4125),
    [anon_sym_ENUM] = ACTIONS(4125),
    [anon_sym_Enum] = ACTIONS(4125),
    [anon_sym_eNUM] = ACTIONS(4125),
    [anon_sym_eNum] = ACTIONS(4125),
    [anon_sym_ENum] = ACTIONS(4125),
    [sym_quoted_identifier] = ACTIONS(4127),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4127),
    [sym_integer] = ACTIONS(4125),
    [sym_continue_as_identifier] = ACTIONS(4127),
    [sym_preproc_open] = ACTIONS(4127),
    [sym_preproc_close] = ACTIONS(4127),
  },
  [STATE(1657)] = {
    [sym_identifier] = ACTIONS(4584),
    [anon_sym_SEMI] = ACTIONS(4586),
    [anon_sym_DASH] = ACTIONS(4586),
    [aux_sym_boolean_token1] = ACTIONS(4584),
    [aux_sym_boolean_token2] = ACTIONS(4584),
    [sym_decimal] = ACTIONS(4584),
    [anon_sym_LPAREN] = ACTIONS(4586),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4584),
    [anon_sym_LBRACK] = ACTIONS(4586),
    [aux_sym_record_type_token1] = ACTIONS(4584),
    [aux_sym_basic_type_token21] = ACTIONS(4584),
    [aux_sym_basic_type_token22] = ACTIONS(4584),
    [aux_sym_basic_type_token48] = ACTIONS(4584),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4584),
    [anon_sym_POUNDif] = ACTIONS(4586),
    [anon_sym_POUNDIF] = ACTIONS(4586),
    [anon_sym_POUNDIf] = ACTIONS(4586),
    [anon_sym_not] = ACTIONS(4584),
    [anon_sym_NOT] = ACTIONS(4584),
    [anon_sym_Not] = ACTIONS(4584),
    [anon_sym_POUNDelif] = ACTIONS(4586),
    [anon_sym_POUNDELIF] = ACTIONS(4586),
    [anon_sym_POUNDElif] = ACTIONS(4586),
    [anon_sym_POUNDelse] = ACTIONS(4586),
    [anon_sym_POUNDELSE] = ACTIONS(4586),
    [anon_sym_POUNDElse] = ACTIONS(4586),
    [anon_sym_POUNDendif] = ACTIONS(4586),
    [anon_sym_POUNDENDIF] = ACTIONS(4586),
    [anon_sym_POUNDEndif] = ACTIONS(4586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4584),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4584),
    [anon_sym_PLUS] = ACTIONS(4586),
    [sym_datetime_literal] = ACTIONS(4586),
    [sym_date_literal] = ACTIONS(4584),
    [sym_time_literal] = ACTIONS(4584),
    [sym_biginteger_literal] = ACTIONS(4586),
    [anon_sym_if] = ACTIONS(4584),
    [anon_sym_IF] = ACTIONS(4584),
    [anon_sym_If] = ACTIONS(4584),
    [anon_sym_else] = ACTIONS(4584),
    [anon_sym_ELSE] = ACTIONS(4584),
    [anon_sym_Else] = ACTIONS(4584),
    [anon_sym_case] = ACTIONS(4584),
    [anon_sym_CASE] = ACTIONS(4584),
    [anon_sym_Case] = ACTIONS(4584),
    [anon_sym_for] = ACTIONS(4584),
    [anon_sym_FOR] = ACTIONS(4584),
    [anon_sym_For] = ACTIONS(4584),
    [anon_sym_foreach] = ACTIONS(4584),
    [anon_sym_FOREACH] = ACTIONS(4584),
    [anon_sym_Foreach] = ACTIONS(4584),
    [anon_sym_while] = ACTIONS(4584),
    [anon_sym_WHILE] = ACTIONS(4584),
    [anon_sym_While] = ACTIONS(4584),
    [anon_sym_repeat] = ACTIONS(4584),
    [anon_sym_REPEAT] = ACTIONS(4584),
    [anon_sym_Repeat] = ACTIONS(4584),
    [anon_sym_exit] = ACTIONS(4584),
    [anon_sym_EXIT] = ACTIONS(4584),
    [anon_sym_Exit] = ACTIONS(4584),
    [anon_sym_continue] = ACTIONS(4584),
    [anon_sym_CONTINUE] = ACTIONS(4584),
    [anon_sym_Continue] = ACTIONS(4584),
    [anon_sym_break] = ACTIONS(4584),
    [anon_sym_BREAK] = ACTIONS(4584),
    [anon_sym_Break] = ACTIONS(4584),
    [anon_sym_with] = ACTIONS(4584),
    [anon_sym_WITH] = ACTIONS(4584),
    [anon_sym_With] = ACTIONS(4584),
    [sym_asserterror_keyword] = ACTIONS(4586),
    [sym_page_keyword] = ACTIONS(4584),
    [anon_sym_codeunit] = ACTIONS(4584),
    [anon_sym_CODEUNIT] = ACTIONS(4584),
    [anon_sym_Codeunit] = ACTIONS(4584),
    [anon_sym_CodeUnit] = ACTIONS(4584),
    [anon_sym_COdeunit] = ACTIONS(4584),
    [anon_sym_codeUnit] = ACTIONS(4584),
    [sym_report_keyword] = ACTIONS(4584),
    [sym_query_keyword] = ACTIONS(4584),
    [anon_sym_xmlport] = ACTIONS(4584),
    [anon_sym_XMLPORT] = ACTIONS(4584),
    [anon_sym_Xmlport] = ACTIONS(4584),
    [anon_sym_XMLport] = ACTIONS(4584),
    [anon_sym_XMLPort] = ACTIONS(4584),
    [anon_sym_XmlPort] = ACTIONS(4584),
    [anon_sym_enum] = ACTIONS(4584),
    [anon_sym_ENUM] = ACTIONS(4584),
    [anon_sym_Enum] = ACTIONS(4584),
    [anon_sym_eNUM] = ACTIONS(4584),
    [anon_sym_eNum] = ACTIONS(4584),
    [anon_sym_ENum] = ACTIONS(4584),
    [sym_quoted_identifier] = ACTIONS(4586),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4586),
    [sym_integer] = ACTIONS(4584),
    [sym_continue_as_identifier] = ACTIONS(4586),
    [sym_preproc_open] = ACTIONS(4586),
    [sym_preproc_close] = ACTIONS(4586),
  },
  [STATE(1658)] = {
    [sym_identifier] = ACTIONS(4588),
    [anon_sym_SEMI] = ACTIONS(4590),
    [anon_sym_DASH] = ACTIONS(4590),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(4588),
    [anon_sym_LPAREN] = ACTIONS(4590),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4588),
    [anon_sym_LBRACK] = ACTIONS(4590),
    [aux_sym_record_type_token1] = ACTIONS(4588),
    [aux_sym_basic_type_token21] = ACTIONS(4588),
    [aux_sym_basic_type_token22] = ACTIONS(4588),
    [aux_sym_basic_type_token48] = ACTIONS(4588),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4588),
    [anon_sym_POUNDif] = ACTIONS(4590),
    [anon_sym_POUNDIF] = ACTIONS(4590),
    [anon_sym_POUNDIf] = ACTIONS(4590),
    [anon_sym_not] = ACTIONS(4588),
    [anon_sym_NOT] = ACTIONS(4588),
    [anon_sym_Not] = ACTIONS(4588),
    [anon_sym_POUNDelif] = ACTIONS(4590),
    [anon_sym_POUNDELIF] = ACTIONS(4590),
    [anon_sym_POUNDElif] = ACTIONS(4590),
    [anon_sym_POUNDelse] = ACTIONS(4590),
    [anon_sym_POUNDELSE] = ACTIONS(4590),
    [anon_sym_POUNDElse] = ACTIONS(4590),
    [anon_sym_POUNDendif] = ACTIONS(4590),
    [anon_sym_POUNDENDIF] = ACTIONS(4590),
    [anon_sym_POUNDEndif] = ACTIONS(4590),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4588),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4588),
    [anon_sym_PLUS] = ACTIONS(4590),
    [sym_datetime_literal] = ACTIONS(4590),
    [sym_date_literal] = ACTIONS(4588),
    [sym_time_literal] = ACTIONS(4588),
    [sym_biginteger_literal] = ACTIONS(4590),
    [anon_sym_if] = ACTIONS(4588),
    [anon_sym_IF] = ACTIONS(4588),
    [anon_sym_If] = ACTIONS(4588),
    [anon_sym_else] = ACTIONS(4588),
    [anon_sym_ELSE] = ACTIONS(4588),
    [anon_sym_Else] = ACTIONS(4588),
    [anon_sym_case] = ACTIONS(4588),
    [anon_sym_CASE] = ACTIONS(4588),
    [anon_sym_Case] = ACTIONS(4588),
    [anon_sym_for] = ACTIONS(4588),
    [anon_sym_FOR] = ACTIONS(4588),
    [anon_sym_For] = ACTIONS(4588),
    [anon_sym_foreach] = ACTIONS(4588),
    [anon_sym_FOREACH] = ACTIONS(4588),
    [anon_sym_Foreach] = ACTIONS(4588),
    [anon_sym_while] = ACTIONS(4588),
    [anon_sym_WHILE] = ACTIONS(4588),
    [anon_sym_While] = ACTIONS(4588),
    [anon_sym_repeat] = ACTIONS(4588),
    [anon_sym_REPEAT] = ACTIONS(4588),
    [anon_sym_Repeat] = ACTIONS(4588),
    [anon_sym_exit] = ACTIONS(4588),
    [anon_sym_EXIT] = ACTIONS(4588),
    [anon_sym_Exit] = ACTIONS(4588),
    [anon_sym_continue] = ACTIONS(4588),
    [anon_sym_CONTINUE] = ACTIONS(4588),
    [anon_sym_Continue] = ACTIONS(4588),
    [anon_sym_break] = ACTIONS(4588),
    [anon_sym_BREAK] = ACTIONS(4588),
    [anon_sym_Break] = ACTIONS(4588),
    [anon_sym_with] = ACTIONS(4588),
    [anon_sym_WITH] = ACTIONS(4588),
    [anon_sym_With] = ACTIONS(4588),
    [sym_asserterror_keyword] = ACTIONS(4590),
    [sym_page_keyword] = ACTIONS(4588),
    [anon_sym_codeunit] = ACTIONS(4588),
    [anon_sym_CODEUNIT] = ACTIONS(4588),
    [anon_sym_Codeunit] = ACTIONS(4588),
    [anon_sym_CodeUnit] = ACTIONS(4588),
    [anon_sym_COdeunit] = ACTIONS(4588),
    [anon_sym_codeUnit] = ACTIONS(4588),
    [sym_report_keyword] = ACTIONS(4588),
    [sym_query_keyword] = ACTIONS(4588),
    [anon_sym_xmlport] = ACTIONS(4588),
    [anon_sym_XMLPORT] = ACTIONS(4588),
    [anon_sym_Xmlport] = ACTIONS(4588),
    [anon_sym_XMLport] = ACTIONS(4588),
    [anon_sym_XMLPort] = ACTIONS(4588),
    [anon_sym_XmlPort] = ACTIONS(4588),
    [anon_sym_enum] = ACTIONS(4588),
    [anon_sym_ENUM] = ACTIONS(4588),
    [anon_sym_Enum] = ACTIONS(4588),
    [anon_sym_eNUM] = ACTIONS(4588),
    [anon_sym_eNum] = ACTIONS(4588),
    [anon_sym_ENum] = ACTIONS(4588),
    [sym_quoted_identifier] = ACTIONS(4590),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4590),
    [sym_integer] = ACTIONS(4588),
    [sym_continue_as_identifier] = ACTIONS(4590),
    [sym_preproc_open] = ACTIONS(4590),
    [sym_preproc_close] = ACTIONS(4590),
  },
  [STATE(1659)] = {
    [sym_identifier] = ACTIONS(4592),
    [anon_sym_SEMI] = ACTIONS(4594),
    [anon_sym_DASH] = ACTIONS(4596),
    [aux_sym_boolean_token1] = ACTIONS(4592),
    [aux_sym_boolean_token2] = ACTIONS(4592),
    [sym_decimal] = ACTIONS(4592),
    [anon_sym_LPAREN] = ACTIONS(4596),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(4596),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4592),
    [anon_sym_POUNDif] = ACTIONS(4596),
    [anon_sym_POUNDIF] = ACTIONS(4596),
    [anon_sym_POUNDIf] = ACTIONS(4596),
    [anon_sym_not] = ACTIONS(4592),
    [anon_sym_NOT] = ACTIONS(4592),
    [anon_sym_Not] = ACTIONS(4592),
    [anon_sym_POUNDelif] = ACTIONS(4596),
    [anon_sym_POUNDELIF] = ACTIONS(4596),
    [anon_sym_POUNDElif] = ACTIONS(4596),
    [anon_sym_POUNDelse] = ACTIONS(4596),
    [anon_sym_POUNDELSE] = ACTIONS(4596),
    [anon_sym_POUNDElse] = ACTIONS(4596),
    [anon_sym_POUNDendif] = ACTIONS(4596),
    [anon_sym_POUNDENDIF] = ACTIONS(4596),
    [anon_sym_POUNDEndif] = ACTIONS(4596),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4592),
    [anon_sym_PLUS] = ACTIONS(4596),
    [sym_datetime_literal] = ACTIONS(4596),
    [sym_date_literal] = ACTIONS(4592),
    [sym_time_literal] = ACTIONS(4592),
    [sym_biginteger_literal] = ACTIONS(4596),
    [anon_sym_if] = ACTIONS(4592),
    [anon_sym_IF] = ACTIONS(4592),
    [anon_sym_If] = ACTIONS(4592),
    [anon_sym_else] = ACTIONS(4592),
    [anon_sym_ELSE] = ACTIONS(4592),
    [anon_sym_Else] = ACTIONS(4592),
    [anon_sym_case] = ACTIONS(4592),
    [anon_sym_CASE] = ACTIONS(4592),
    [anon_sym_Case] = ACTIONS(4592),
    [anon_sym_for] = ACTIONS(4592),
    [anon_sym_FOR] = ACTIONS(4592),
    [anon_sym_For] = ACTIONS(4592),
    [anon_sym_foreach] = ACTIONS(4592),
    [anon_sym_FOREACH] = ACTIONS(4592),
    [anon_sym_Foreach] = ACTIONS(4592),
    [anon_sym_while] = ACTIONS(4592),
    [anon_sym_WHILE] = ACTIONS(4592),
    [anon_sym_While] = ACTIONS(4592),
    [anon_sym_repeat] = ACTIONS(4592),
    [anon_sym_REPEAT] = ACTIONS(4592),
    [anon_sym_Repeat] = ACTIONS(4592),
    [anon_sym_exit] = ACTIONS(4592),
    [anon_sym_EXIT] = ACTIONS(4592),
    [anon_sym_Exit] = ACTIONS(4592),
    [anon_sym_continue] = ACTIONS(4592),
    [anon_sym_CONTINUE] = ACTIONS(4592),
    [anon_sym_Continue] = ACTIONS(4592),
    [anon_sym_break] = ACTIONS(4592),
    [anon_sym_BREAK] = ACTIONS(4592),
    [anon_sym_Break] = ACTIONS(4592),
    [anon_sym_with] = ACTIONS(4592),
    [anon_sym_WITH] = ACTIONS(4592),
    [anon_sym_With] = ACTIONS(4592),
    [sym_asserterror_keyword] = ACTIONS(4596),
    [sym_page_keyword] = ACTIONS(4592),
    [anon_sym_codeunit] = ACTIONS(4592),
    [anon_sym_CODEUNIT] = ACTIONS(4592),
    [anon_sym_Codeunit] = ACTIONS(4592),
    [anon_sym_CodeUnit] = ACTIONS(4592),
    [anon_sym_COdeunit] = ACTIONS(4592),
    [anon_sym_codeUnit] = ACTIONS(4592),
    [sym_report_keyword] = ACTIONS(4592),
    [sym_query_keyword] = ACTIONS(4592),
    [anon_sym_xmlport] = ACTIONS(4592),
    [anon_sym_XMLPORT] = ACTIONS(4592),
    [anon_sym_Xmlport] = ACTIONS(4592),
    [anon_sym_XMLport] = ACTIONS(4592),
    [anon_sym_XMLPort] = ACTIONS(4592),
    [anon_sym_XmlPort] = ACTIONS(4592),
    [anon_sym_enum] = ACTIONS(4592),
    [anon_sym_ENUM] = ACTIONS(4592),
    [anon_sym_Enum] = ACTIONS(4592),
    [anon_sym_eNUM] = ACTIONS(4592),
    [anon_sym_eNum] = ACTIONS(4592),
    [anon_sym_ENum] = ACTIONS(4592),
    [sym_quoted_identifier] = ACTIONS(4596),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4596),
    [sym_integer] = ACTIONS(4592),
    [sym_continue_as_identifier] = ACTIONS(4596),
    [sym_preproc_open] = ACTIONS(4596),
    [sym_preproc_close] = ACTIONS(4596),
  },
  [STATE(1660)] = {
    [sym_identifier] = ACTIONS(4598),
    [anon_sym_SEMI] = ACTIONS(4600),
    [anon_sym_DASH] = ACTIONS(4600),
    [aux_sym_boolean_token1] = ACTIONS(4598),
    [aux_sym_boolean_token2] = ACTIONS(4598),
    [sym_decimal] = ACTIONS(4598),
    [anon_sym_LPAREN] = ACTIONS(4600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4598),
    [anon_sym_LBRACK] = ACTIONS(4600),
    [aux_sym_record_type_token1] = ACTIONS(4598),
    [aux_sym_basic_type_token21] = ACTIONS(4598),
    [aux_sym_basic_type_token22] = ACTIONS(4598),
    [aux_sym_basic_type_token48] = ACTIONS(4598),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4598),
    [anon_sym_POUNDif] = ACTIONS(4600),
    [anon_sym_POUNDIF] = ACTIONS(4600),
    [anon_sym_POUNDIf] = ACTIONS(4600),
    [anon_sym_not] = ACTIONS(4598),
    [anon_sym_NOT] = ACTIONS(4598),
    [anon_sym_Not] = ACTIONS(4598),
    [anon_sym_POUNDelif] = ACTIONS(4600),
    [anon_sym_POUNDELIF] = ACTIONS(4600),
    [anon_sym_POUNDElif] = ACTIONS(4600),
    [anon_sym_POUNDelse] = ACTIONS(4600),
    [anon_sym_POUNDELSE] = ACTIONS(4600),
    [anon_sym_POUNDElse] = ACTIONS(4600),
    [anon_sym_POUNDendif] = ACTIONS(4600),
    [anon_sym_POUNDENDIF] = ACTIONS(4600),
    [anon_sym_POUNDEndif] = ACTIONS(4600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4598),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4598),
    [anon_sym_PLUS] = ACTIONS(4600),
    [sym_datetime_literal] = ACTIONS(4600),
    [sym_date_literal] = ACTIONS(4598),
    [sym_time_literal] = ACTIONS(4598),
    [sym_biginteger_literal] = ACTIONS(4600),
    [anon_sym_if] = ACTIONS(4598),
    [anon_sym_IF] = ACTIONS(4598),
    [anon_sym_If] = ACTIONS(4598),
    [anon_sym_else] = ACTIONS(4598),
    [anon_sym_ELSE] = ACTIONS(4598),
    [anon_sym_Else] = ACTIONS(4598),
    [anon_sym_case] = ACTIONS(4598),
    [anon_sym_CASE] = ACTIONS(4598),
    [anon_sym_Case] = ACTIONS(4598),
    [anon_sym_for] = ACTIONS(4598),
    [anon_sym_FOR] = ACTIONS(4598),
    [anon_sym_For] = ACTIONS(4598),
    [anon_sym_foreach] = ACTIONS(4598),
    [anon_sym_FOREACH] = ACTIONS(4598),
    [anon_sym_Foreach] = ACTIONS(4598),
    [anon_sym_while] = ACTIONS(4598),
    [anon_sym_WHILE] = ACTIONS(4598),
    [anon_sym_While] = ACTIONS(4598),
    [anon_sym_repeat] = ACTIONS(4598),
    [anon_sym_REPEAT] = ACTIONS(4598),
    [anon_sym_Repeat] = ACTIONS(4598),
    [anon_sym_exit] = ACTIONS(4598),
    [anon_sym_EXIT] = ACTIONS(4598),
    [anon_sym_Exit] = ACTIONS(4598),
    [anon_sym_continue] = ACTIONS(4598),
    [anon_sym_CONTINUE] = ACTIONS(4598),
    [anon_sym_Continue] = ACTIONS(4598),
    [anon_sym_break] = ACTIONS(4598),
    [anon_sym_BREAK] = ACTIONS(4598),
    [anon_sym_Break] = ACTIONS(4598),
    [anon_sym_with] = ACTIONS(4598),
    [anon_sym_WITH] = ACTIONS(4598),
    [anon_sym_With] = ACTIONS(4598),
    [sym_asserterror_keyword] = ACTIONS(4600),
    [sym_page_keyword] = ACTIONS(4598),
    [anon_sym_codeunit] = ACTIONS(4598),
    [anon_sym_CODEUNIT] = ACTIONS(4598),
    [anon_sym_Codeunit] = ACTIONS(4598),
    [anon_sym_CodeUnit] = ACTIONS(4598),
    [anon_sym_COdeunit] = ACTIONS(4598),
    [anon_sym_codeUnit] = ACTIONS(4598),
    [sym_report_keyword] = ACTIONS(4598),
    [sym_query_keyword] = ACTIONS(4598),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4598),
    [anon_sym_ENUM] = ACTIONS(4598),
    [anon_sym_Enum] = ACTIONS(4598),
    [anon_sym_eNUM] = ACTIONS(4598),
    [anon_sym_eNum] = ACTIONS(4598),
    [anon_sym_ENum] = ACTIONS(4598),
    [sym_quoted_identifier] = ACTIONS(4600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4600),
    [sym_integer] = ACTIONS(4598),
    [sym_continue_as_identifier] = ACTIONS(4600),
    [sym_preproc_open] = ACTIONS(4600),
    [sym_preproc_close] = ACTIONS(4600),
  },
  [STATE(1661)] = {
    [sym_identifier] = ACTIONS(4602),
    [anon_sym_SEMI] = ACTIONS(4604),
    [anon_sym_DASH] = ACTIONS(4604),
    [aux_sym_boolean_token1] = ACTIONS(4602),
    [aux_sym_boolean_token2] = ACTIONS(4602),
    [sym_decimal] = ACTIONS(4602),
    [anon_sym_LPAREN] = ACTIONS(4604),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4602),
    [anon_sym_LBRACK] = ACTIONS(4604),
    [aux_sym_record_type_token1] = ACTIONS(4602),
    [aux_sym_basic_type_token21] = ACTIONS(4602),
    [aux_sym_basic_type_token22] = ACTIONS(4602),
    [aux_sym_basic_type_token48] = ACTIONS(4602),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4602),
    [anon_sym_POUNDif] = ACTIONS(4604),
    [anon_sym_POUNDIF] = ACTIONS(4604),
    [anon_sym_POUNDIf] = ACTIONS(4604),
    [anon_sym_not] = ACTIONS(4602),
    [anon_sym_NOT] = ACTIONS(4602),
    [anon_sym_Not] = ACTIONS(4602),
    [anon_sym_POUNDelif] = ACTIONS(4604),
    [anon_sym_POUNDELIF] = ACTIONS(4604),
    [anon_sym_POUNDElif] = ACTIONS(4604),
    [anon_sym_POUNDelse] = ACTIONS(4604),
    [anon_sym_POUNDELSE] = ACTIONS(4604),
    [anon_sym_POUNDElse] = ACTIONS(4604),
    [anon_sym_POUNDendif] = ACTIONS(4604),
    [anon_sym_POUNDENDIF] = ACTIONS(4604),
    [anon_sym_POUNDEndif] = ACTIONS(4604),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4602),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4602),
    [anon_sym_PLUS] = ACTIONS(4604),
    [sym_datetime_literal] = ACTIONS(4604),
    [sym_date_literal] = ACTIONS(4602),
    [sym_time_literal] = ACTIONS(4602),
    [sym_biginteger_literal] = ACTIONS(4604),
    [anon_sym_if] = ACTIONS(4602),
    [anon_sym_IF] = ACTIONS(4602),
    [anon_sym_If] = ACTIONS(4602),
    [anon_sym_else] = ACTIONS(4602),
    [anon_sym_ELSE] = ACTIONS(4602),
    [anon_sym_Else] = ACTIONS(4602),
    [anon_sym_case] = ACTIONS(4602),
    [anon_sym_CASE] = ACTIONS(4602),
    [anon_sym_Case] = ACTIONS(4602),
    [anon_sym_for] = ACTIONS(4602),
    [anon_sym_FOR] = ACTIONS(4602),
    [anon_sym_For] = ACTIONS(4602),
    [anon_sym_foreach] = ACTIONS(4602),
    [anon_sym_FOREACH] = ACTIONS(4602),
    [anon_sym_Foreach] = ACTIONS(4602),
    [anon_sym_while] = ACTIONS(4602),
    [anon_sym_WHILE] = ACTIONS(4602),
    [anon_sym_While] = ACTIONS(4602),
    [anon_sym_repeat] = ACTIONS(4602),
    [anon_sym_REPEAT] = ACTIONS(4602),
    [anon_sym_Repeat] = ACTIONS(4602),
    [anon_sym_exit] = ACTIONS(4602),
    [anon_sym_EXIT] = ACTIONS(4602),
    [anon_sym_Exit] = ACTIONS(4602),
    [anon_sym_continue] = ACTIONS(4602),
    [anon_sym_CONTINUE] = ACTIONS(4602),
    [anon_sym_Continue] = ACTIONS(4602),
    [anon_sym_break] = ACTIONS(4602),
    [anon_sym_BREAK] = ACTIONS(4602),
    [anon_sym_Break] = ACTIONS(4602),
    [anon_sym_with] = ACTIONS(4602),
    [anon_sym_WITH] = ACTIONS(4602),
    [anon_sym_With] = ACTIONS(4602),
    [sym_asserterror_keyword] = ACTIONS(4604),
    [sym_page_keyword] = ACTIONS(4602),
    [anon_sym_codeunit] = ACTIONS(4602),
    [anon_sym_CODEUNIT] = ACTIONS(4602),
    [anon_sym_Codeunit] = ACTIONS(4602),
    [anon_sym_CodeUnit] = ACTIONS(4602),
    [anon_sym_COdeunit] = ACTIONS(4602),
    [anon_sym_codeUnit] = ACTIONS(4602),
    [sym_report_keyword] = ACTIONS(4602),
    [sym_query_keyword] = ACTIONS(4602),
    [anon_sym_xmlport] = ACTIONS(4602),
    [anon_sym_XMLPORT] = ACTIONS(4602),
    [anon_sym_Xmlport] = ACTIONS(4602),
    [anon_sym_XMLport] = ACTIONS(4602),
    [anon_sym_XMLPort] = ACTIONS(4602),
    [anon_sym_XmlPort] = ACTIONS(4602),
    [anon_sym_enum] = ACTIONS(4602),
    [anon_sym_ENUM] = ACTIONS(4602),
    [anon_sym_Enum] = ACTIONS(4602),
    [anon_sym_eNUM] = ACTIONS(4602),
    [anon_sym_eNum] = ACTIONS(4602),
    [anon_sym_ENum] = ACTIONS(4602),
    [sym_quoted_identifier] = ACTIONS(4604),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4604),
    [sym_integer] = ACTIONS(4602),
    [sym_continue_as_identifier] = ACTIONS(4604),
    [sym_preproc_open] = ACTIONS(4604),
    [sym_preproc_close] = ACTIONS(4604),
  },
  [STATE(1662)] = {
    [sym_identifier] = ACTIONS(4177),
    [anon_sym_SEMI] = ACTIONS(4179),
    [anon_sym_DASH] = ACTIONS(4179),
    [aux_sym_boolean_token1] = ACTIONS(4177),
    [aux_sym_boolean_token2] = ACTIONS(4177),
    [sym_decimal] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4179),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4177),
    [anon_sym_LBRACK] = ACTIONS(4179),
    [aux_sym_record_type_token1] = ACTIONS(4177),
    [aux_sym_basic_type_token21] = ACTIONS(4177),
    [aux_sym_basic_type_token22] = ACTIONS(4177),
    [aux_sym_basic_type_token48] = ACTIONS(4177),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4177),
    [anon_sym_POUNDif] = ACTIONS(4179),
    [anon_sym_POUNDIF] = ACTIONS(4179),
    [anon_sym_POUNDIf] = ACTIONS(4179),
    [anon_sym_not] = ACTIONS(4177),
    [anon_sym_NOT] = ACTIONS(4177),
    [anon_sym_Not] = ACTIONS(4177),
    [anon_sym_POUNDelif] = ACTIONS(4179),
    [anon_sym_POUNDELIF] = ACTIONS(4179),
    [anon_sym_POUNDElif] = ACTIONS(4179),
    [anon_sym_POUNDelse] = ACTIONS(4179),
    [anon_sym_POUNDELSE] = ACTIONS(4179),
    [anon_sym_POUNDElse] = ACTIONS(4179),
    [anon_sym_POUNDendif] = ACTIONS(4179),
    [anon_sym_POUNDENDIF] = ACTIONS(4179),
    [anon_sym_POUNDEndif] = ACTIONS(4179),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4177),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4179),
    [sym_datetime_literal] = ACTIONS(4179),
    [sym_date_literal] = ACTIONS(4177),
    [sym_time_literal] = ACTIONS(4177),
    [sym_biginteger_literal] = ACTIONS(4179),
    [anon_sym_if] = ACTIONS(4177),
    [anon_sym_IF] = ACTIONS(4177),
    [anon_sym_If] = ACTIONS(4177),
    [anon_sym_else] = ACTIONS(4177),
    [anon_sym_ELSE] = ACTIONS(4177),
    [anon_sym_Else] = ACTIONS(4177),
    [anon_sym_case] = ACTIONS(4177),
    [anon_sym_CASE] = ACTIONS(4177),
    [anon_sym_Case] = ACTIONS(4177),
    [anon_sym_for] = ACTIONS(4177),
    [anon_sym_FOR] = ACTIONS(4177),
    [anon_sym_For] = ACTIONS(4177),
    [anon_sym_foreach] = ACTIONS(4177),
    [anon_sym_FOREACH] = ACTIONS(4177),
    [anon_sym_Foreach] = ACTIONS(4177),
    [anon_sym_while] = ACTIONS(4177),
    [anon_sym_WHILE] = ACTIONS(4177),
    [anon_sym_While] = ACTIONS(4177),
    [anon_sym_repeat] = ACTIONS(4177),
    [anon_sym_REPEAT] = ACTIONS(4177),
    [anon_sym_Repeat] = ACTIONS(4177),
    [anon_sym_exit] = ACTIONS(4177),
    [anon_sym_EXIT] = ACTIONS(4177),
    [anon_sym_Exit] = ACTIONS(4177),
    [anon_sym_continue] = ACTIONS(4177),
    [anon_sym_CONTINUE] = ACTIONS(4177),
    [anon_sym_Continue] = ACTIONS(4177),
    [anon_sym_break] = ACTIONS(4177),
    [anon_sym_BREAK] = ACTIONS(4177),
    [anon_sym_Break] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4177),
    [anon_sym_WITH] = ACTIONS(4177),
    [anon_sym_With] = ACTIONS(4177),
    [sym_asserterror_keyword] = ACTIONS(4179),
    [sym_page_keyword] = ACTIONS(4177),
    [anon_sym_codeunit] = ACTIONS(4177),
    [anon_sym_CODEUNIT] = ACTIONS(4177),
    [anon_sym_Codeunit] = ACTIONS(4177),
    [anon_sym_CodeUnit] = ACTIONS(4177),
    [anon_sym_COdeunit] = ACTIONS(4177),
    [anon_sym_codeUnit] = ACTIONS(4177),
    [sym_report_keyword] = ACTIONS(4177),
    [sym_query_keyword] = ACTIONS(4177),
    [anon_sym_xmlport] = ACTIONS(4177),
    [anon_sym_XMLPORT] = ACTIONS(4177),
    [anon_sym_Xmlport] = ACTIONS(4177),
    [anon_sym_XMLport] = ACTIONS(4177),
    [anon_sym_XMLPort] = ACTIONS(4177),
    [anon_sym_XmlPort] = ACTIONS(4177),
    [anon_sym_enum] = ACTIONS(4177),
    [anon_sym_ENUM] = ACTIONS(4177),
    [anon_sym_Enum] = ACTIONS(4177),
    [anon_sym_eNUM] = ACTIONS(4177),
    [anon_sym_eNum] = ACTIONS(4177),
    [anon_sym_ENum] = ACTIONS(4177),
    [sym_quoted_identifier] = ACTIONS(4179),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4179),
    [sym_integer] = ACTIONS(4177),
    [sym_continue_as_identifier] = ACTIONS(4179),
    [sym_preproc_open] = ACTIONS(4179),
    [sym_preproc_close] = ACTIONS(4179),
  },
  [STATE(1663)] = {
    [sym_identifier] = ACTIONS(4606),
    [anon_sym_SEMI] = ACTIONS(4608),
    [anon_sym_DASH] = ACTIONS(4608),
    [aux_sym_boolean_token1] = ACTIONS(4606),
    [aux_sym_boolean_token2] = ACTIONS(4606),
    [sym_decimal] = ACTIONS(4606),
    [anon_sym_LPAREN] = ACTIONS(4608),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4606),
    [anon_sym_LBRACK] = ACTIONS(4608),
    [aux_sym_record_type_token1] = ACTIONS(4606),
    [aux_sym_basic_type_token21] = ACTIONS(4606),
    [aux_sym_basic_type_token22] = ACTIONS(4606),
    [aux_sym_basic_type_token48] = ACTIONS(4606),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4606),
    [anon_sym_POUNDif] = ACTIONS(4608),
    [anon_sym_POUNDIF] = ACTIONS(4608),
    [anon_sym_POUNDIf] = ACTIONS(4608),
    [anon_sym_not] = ACTIONS(4606),
    [anon_sym_NOT] = ACTIONS(4606),
    [anon_sym_Not] = ACTIONS(4606),
    [anon_sym_POUNDelif] = ACTIONS(4608),
    [anon_sym_POUNDELIF] = ACTIONS(4608),
    [anon_sym_POUNDElif] = ACTIONS(4608),
    [anon_sym_POUNDelse] = ACTIONS(4608),
    [anon_sym_POUNDELSE] = ACTIONS(4608),
    [anon_sym_POUNDElse] = ACTIONS(4608),
    [anon_sym_POUNDendif] = ACTIONS(4608),
    [anon_sym_POUNDENDIF] = ACTIONS(4608),
    [anon_sym_POUNDEndif] = ACTIONS(4608),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4606),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4606),
    [anon_sym_PLUS] = ACTIONS(4608),
    [sym_datetime_literal] = ACTIONS(4608),
    [sym_date_literal] = ACTIONS(4606),
    [sym_time_literal] = ACTIONS(4606),
    [sym_biginteger_literal] = ACTIONS(4608),
    [anon_sym_if] = ACTIONS(4606),
    [anon_sym_IF] = ACTIONS(4606),
    [anon_sym_If] = ACTIONS(4606),
    [anon_sym_else] = ACTIONS(4606),
    [anon_sym_ELSE] = ACTIONS(4606),
    [anon_sym_Else] = ACTIONS(4606),
    [anon_sym_case] = ACTIONS(4606),
    [anon_sym_CASE] = ACTIONS(4606),
    [anon_sym_Case] = ACTIONS(4606),
    [anon_sym_for] = ACTIONS(4606),
    [anon_sym_FOR] = ACTIONS(4606),
    [anon_sym_For] = ACTIONS(4606),
    [anon_sym_foreach] = ACTIONS(4606),
    [anon_sym_FOREACH] = ACTIONS(4606),
    [anon_sym_Foreach] = ACTIONS(4606),
    [anon_sym_while] = ACTIONS(4606),
    [anon_sym_WHILE] = ACTIONS(4606),
    [anon_sym_While] = ACTIONS(4606),
    [anon_sym_repeat] = ACTIONS(4606),
    [anon_sym_REPEAT] = ACTIONS(4606),
    [anon_sym_Repeat] = ACTIONS(4606),
    [anon_sym_exit] = ACTIONS(4606),
    [anon_sym_EXIT] = ACTIONS(4606),
    [anon_sym_Exit] = ACTIONS(4606),
    [anon_sym_continue] = ACTIONS(4606),
    [anon_sym_CONTINUE] = ACTIONS(4606),
    [anon_sym_Continue] = ACTIONS(4606),
    [anon_sym_break] = ACTIONS(4606),
    [anon_sym_BREAK] = ACTIONS(4606),
    [anon_sym_Break] = ACTIONS(4606),
    [anon_sym_with] = ACTIONS(4606),
    [anon_sym_WITH] = ACTIONS(4606),
    [anon_sym_With] = ACTIONS(4606),
    [sym_asserterror_keyword] = ACTIONS(4608),
    [sym_page_keyword] = ACTIONS(4606),
    [anon_sym_codeunit] = ACTIONS(4606),
    [anon_sym_CODEUNIT] = ACTIONS(4606),
    [anon_sym_Codeunit] = ACTIONS(4606),
    [anon_sym_CodeUnit] = ACTIONS(4606),
    [anon_sym_COdeunit] = ACTIONS(4606),
    [anon_sym_codeUnit] = ACTIONS(4606),
    [sym_report_keyword] = ACTIONS(4606),
    [sym_query_keyword] = ACTIONS(4606),
    [anon_sym_xmlport] = ACTIONS(4606),
    [anon_sym_XMLPORT] = ACTIONS(4606),
    [anon_sym_Xmlport] = ACTIONS(4606),
    [anon_sym_XMLport] = ACTIONS(4606),
    [anon_sym_XMLPort] = ACTIONS(4606),
    [anon_sym_XmlPort] = ACTIONS(4606),
    [anon_sym_enum] = ACTIONS(4606),
    [anon_sym_ENUM] = ACTIONS(4606),
    [anon_sym_Enum] = ACTIONS(4606),
    [anon_sym_eNUM] = ACTIONS(4606),
    [anon_sym_eNum] = ACTIONS(4606),
    [anon_sym_ENum] = ACTIONS(4606),
    [sym_quoted_identifier] = ACTIONS(4608),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4608),
    [sym_integer] = ACTIONS(4606),
    [sym_continue_as_identifier] = ACTIONS(4608),
    [sym_preproc_open] = ACTIONS(4608),
    [sym_preproc_close] = ACTIONS(4608),
  },
  [STATE(1664)] = {
    [sym_identifier] = ACTIONS(4610),
    [anon_sym_SEMI] = ACTIONS(4612),
    [anon_sym_DASH] = ACTIONS(4612),
    [aux_sym_boolean_token1] = ACTIONS(4610),
    [aux_sym_boolean_token2] = ACTIONS(4610),
    [sym_decimal] = ACTIONS(4610),
    [anon_sym_LPAREN] = ACTIONS(4612),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4610),
    [anon_sym_LBRACK] = ACTIONS(4612),
    [aux_sym_record_type_token1] = ACTIONS(4610),
    [aux_sym_basic_type_token21] = ACTIONS(4610),
    [aux_sym_basic_type_token22] = ACTIONS(4610),
    [aux_sym_basic_type_token48] = ACTIONS(4610),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4610),
    [anon_sym_POUNDif] = ACTIONS(4612),
    [anon_sym_POUNDIF] = ACTIONS(4612),
    [anon_sym_POUNDIf] = ACTIONS(4612),
    [anon_sym_not] = ACTIONS(4610),
    [anon_sym_NOT] = ACTIONS(4610),
    [anon_sym_Not] = ACTIONS(4610),
    [anon_sym_POUNDelif] = ACTIONS(4612),
    [anon_sym_POUNDELIF] = ACTIONS(4612),
    [anon_sym_POUNDElif] = ACTIONS(4612),
    [anon_sym_POUNDelse] = ACTIONS(4612),
    [anon_sym_POUNDELSE] = ACTIONS(4612),
    [anon_sym_POUNDElse] = ACTIONS(4612),
    [anon_sym_POUNDendif] = ACTIONS(4612),
    [anon_sym_POUNDENDIF] = ACTIONS(4612),
    [anon_sym_POUNDEndif] = ACTIONS(4612),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4610),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4610),
    [anon_sym_PLUS] = ACTIONS(4612),
    [sym_datetime_literal] = ACTIONS(4612),
    [sym_date_literal] = ACTIONS(4610),
    [sym_time_literal] = ACTIONS(4610),
    [sym_biginteger_literal] = ACTIONS(4612),
    [anon_sym_if] = ACTIONS(4610),
    [anon_sym_IF] = ACTIONS(4610),
    [anon_sym_If] = ACTIONS(4610),
    [anon_sym_else] = ACTIONS(4610),
    [anon_sym_ELSE] = ACTIONS(4610),
    [anon_sym_Else] = ACTIONS(4610),
    [anon_sym_case] = ACTIONS(4610),
    [anon_sym_CASE] = ACTIONS(4610),
    [anon_sym_Case] = ACTIONS(4610),
    [anon_sym_for] = ACTIONS(4610),
    [anon_sym_FOR] = ACTIONS(4610),
    [anon_sym_For] = ACTIONS(4610),
    [anon_sym_foreach] = ACTIONS(4610),
    [anon_sym_FOREACH] = ACTIONS(4610),
    [anon_sym_Foreach] = ACTIONS(4610),
    [anon_sym_while] = ACTIONS(4610),
    [anon_sym_WHILE] = ACTIONS(4610),
    [anon_sym_While] = ACTIONS(4610),
    [anon_sym_repeat] = ACTIONS(4610),
    [anon_sym_REPEAT] = ACTIONS(4610),
    [anon_sym_Repeat] = ACTIONS(4610),
    [anon_sym_exit] = ACTIONS(4610),
    [anon_sym_EXIT] = ACTIONS(4610),
    [anon_sym_Exit] = ACTIONS(4610),
    [anon_sym_continue] = ACTIONS(4610),
    [anon_sym_CONTINUE] = ACTIONS(4610),
    [anon_sym_Continue] = ACTIONS(4610),
    [anon_sym_break] = ACTIONS(4610),
    [anon_sym_BREAK] = ACTIONS(4610),
    [anon_sym_Break] = ACTIONS(4610),
    [anon_sym_with] = ACTIONS(4610),
    [anon_sym_WITH] = ACTIONS(4610),
    [anon_sym_With] = ACTIONS(4610),
    [sym_asserterror_keyword] = ACTIONS(4612),
    [sym_page_keyword] = ACTIONS(4610),
    [anon_sym_codeunit] = ACTIONS(4610),
    [anon_sym_CODEUNIT] = ACTIONS(4610),
    [anon_sym_Codeunit] = ACTIONS(4610),
    [anon_sym_CodeUnit] = ACTIONS(4610),
    [anon_sym_COdeunit] = ACTIONS(4610),
    [anon_sym_codeUnit] = ACTIONS(4610),
    [sym_report_keyword] = ACTIONS(4610),
    [sym_query_keyword] = ACTIONS(4610),
    [anon_sym_xmlport] = ACTIONS(4610),
    [anon_sym_XMLPORT] = ACTIONS(4610),
    [anon_sym_Xmlport] = ACTIONS(4610),
    [anon_sym_XMLport] = ACTIONS(4610),
    [anon_sym_XMLPort] = ACTIONS(4610),
    [anon_sym_XmlPort] = ACTIONS(4610),
    [anon_sym_enum] = ACTIONS(4610),
    [anon_sym_ENUM] = ACTIONS(4610),
    [anon_sym_Enum] = ACTIONS(4610),
    [anon_sym_eNUM] = ACTIONS(4610),
    [anon_sym_eNum] = ACTIONS(4610),
    [anon_sym_ENum] = ACTIONS(4610),
    [sym_quoted_identifier] = ACTIONS(4612),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4612),
    [sym_integer] = ACTIONS(4610),
    [sym_continue_as_identifier] = ACTIONS(4612),
    [sym_preproc_open] = ACTIONS(4612),
    [sym_preproc_close] = ACTIONS(4612),
  },
  [STATE(1665)] = {
    [sym_identifier] = ACTIONS(4614),
    [anon_sym_SEMI] = ACTIONS(4616),
    [anon_sym_DASH] = ACTIONS(4616),
    [aux_sym_boolean_token1] = ACTIONS(4614),
    [aux_sym_boolean_token2] = ACTIONS(4614),
    [sym_decimal] = ACTIONS(4614),
    [anon_sym_LPAREN] = ACTIONS(4616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4614),
    [anon_sym_LBRACK] = ACTIONS(4616),
    [aux_sym_record_type_token1] = ACTIONS(4614),
    [aux_sym_basic_type_token21] = ACTIONS(4614),
    [aux_sym_basic_type_token22] = ACTIONS(4614),
    [aux_sym_basic_type_token48] = ACTIONS(4614),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4614),
    [anon_sym_POUNDif] = ACTIONS(4616),
    [anon_sym_POUNDIF] = ACTIONS(4616),
    [anon_sym_POUNDIf] = ACTIONS(4616),
    [anon_sym_not] = ACTIONS(4614),
    [anon_sym_NOT] = ACTIONS(4614),
    [anon_sym_Not] = ACTIONS(4614),
    [anon_sym_POUNDelif] = ACTIONS(4616),
    [anon_sym_POUNDELIF] = ACTIONS(4616),
    [anon_sym_POUNDElif] = ACTIONS(4616),
    [anon_sym_POUNDelse] = ACTIONS(4616),
    [anon_sym_POUNDELSE] = ACTIONS(4616),
    [anon_sym_POUNDElse] = ACTIONS(4616),
    [anon_sym_POUNDendif] = ACTIONS(4616),
    [anon_sym_POUNDENDIF] = ACTIONS(4616),
    [anon_sym_POUNDEndif] = ACTIONS(4616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4614),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4614),
    [anon_sym_PLUS] = ACTIONS(4616),
    [sym_datetime_literal] = ACTIONS(4616),
    [sym_date_literal] = ACTIONS(4614),
    [sym_time_literal] = ACTIONS(4614),
    [sym_biginteger_literal] = ACTIONS(4616),
    [anon_sym_if] = ACTIONS(4614),
    [anon_sym_IF] = ACTIONS(4614),
    [anon_sym_If] = ACTIONS(4614),
    [anon_sym_else] = ACTIONS(4614),
    [anon_sym_ELSE] = ACTIONS(4614),
    [anon_sym_Else] = ACTIONS(4614),
    [anon_sym_case] = ACTIONS(4614),
    [anon_sym_CASE] = ACTIONS(4614),
    [anon_sym_Case] = ACTIONS(4614),
    [anon_sym_for] = ACTIONS(4614),
    [anon_sym_FOR] = ACTIONS(4614),
    [anon_sym_For] = ACTIONS(4614),
    [anon_sym_foreach] = ACTIONS(4614),
    [anon_sym_FOREACH] = ACTIONS(4614),
    [anon_sym_Foreach] = ACTIONS(4614),
    [anon_sym_while] = ACTIONS(4614),
    [anon_sym_WHILE] = ACTIONS(4614),
    [anon_sym_While] = ACTIONS(4614),
    [anon_sym_repeat] = ACTIONS(4614),
    [anon_sym_REPEAT] = ACTIONS(4614),
    [anon_sym_Repeat] = ACTIONS(4614),
    [anon_sym_exit] = ACTIONS(4614),
    [anon_sym_EXIT] = ACTIONS(4614),
    [anon_sym_Exit] = ACTIONS(4614),
    [anon_sym_continue] = ACTIONS(4614),
    [anon_sym_CONTINUE] = ACTIONS(4614),
    [anon_sym_Continue] = ACTIONS(4614),
    [anon_sym_break] = ACTIONS(4614),
    [anon_sym_BREAK] = ACTIONS(4614),
    [anon_sym_Break] = ACTIONS(4614),
    [anon_sym_with] = ACTIONS(4614),
    [anon_sym_WITH] = ACTIONS(4614),
    [anon_sym_With] = ACTIONS(4614),
    [sym_asserterror_keyword] = ACTIONS(4616),
    [sym_page_keyword] = ACTIONS(4614),
    [anon_sym_codeunit] = ACTIONS(4614),
    [anon_sym_CODEUNIT] = ACTIONS(4614),
    [anon_sym_Codeunit] = ACTIONS(4614),
    [anon_sym_CodeUnit] = ACTIONS(4614),
    [anon_sym_COdeunit] = ACTIONS(4614),
    [anon_sym_codeUnit] = ACTIONS(4614),
    [sym_report_keyword] = ACTIONS(4614),
    [sym_query_keyword] = ACTIONS(4614),
    [anon_sym_xmlport] = ACTIONS(4614),
    [anon_sym_XMLPORT] = ACTIONS(4614),
    [anon_sym_Xmlport] = ACTIONS(4614),
    [anon_sym_XMLport] = ACTIONS(4614),
    [anon_sym_XMLPort] = ACTIONS(4614),
    [anon_sym_XmlPort] = ACTIONS(4614),
    [anon_sym_enum] = ACTIONS(4614),
    [anon_sym_ENUM] = ACTIONS(4614),
    [anon_sym_Enum] = ACTIONS(4614),
    [anon_sym_eNUM] = ACTIONS(4614),
    [anon_sym_eNum] = ACTIONS(4614),
    [anon_sym_ENum] = ACTIONS(4614),
    [sym_quoted_identifier] = ACTIONS(4616),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4616),
    [sym_integer] = ACTIONS(4614),
    [sym_continue_as_identifier] = ACTIONS(4616),
    [sym_preproc_open] = ACTIONS(4616),
    [sym_preproc_close] = ACTIONS(4616),
  },
  [STATE(1666)] = {
    [sym_identifier] = ACTIONS(4618),
    [anon_sym_SEMI] = ACTIONS(4620),
    [anon_sym_DASH] = ACTIONS(4620),
    [aux_sym_boolean_token1] = ACTIONS(4618),
    [aux_sym_boolean_token2] = ACTIONS(4618),
    [sym_decimal] = ACTIONS(4618),
    [anon_sym_LPAREN] = ACTIONS(4620),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4618),
    [anon_sym_LBRACK] = ACTIONS(4620),
    [aux_sym_record_type_token1] = ACTIONS(4618),
    [aux_sym_basic_type_token21] = ACTIONS(4618),
    [aux_sym_basic_type_token22] = ACTIONS(4618),
    [aux_sym_basic_type_token48] = ACTIONS(4618),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4618),
    [anon_sym_POUNDif] = ACTIONS(4620),
    [anon_sym_POUNDIF] = ACTIONS(4620),
    [anon_sym_POUNDIf] = ACTIONS(4620),
    [anon_sym_not] = ACTIONS(4618),
    [anon_sym_NOT] = ACTIONS(4618),
    [anon_sym_Not] = ACTIONS(4618),
    [anon_sym_POUNDelif] = ACTIONS(4620),
    [anon_sym_POUNDELIF] = ACTIONS(4620),
    [anon_sym_POUNDElif] = ACTIONS(4620),
    [anon_sym_POUNDelse] = ACTIONS(4620),
    [anon_sym_POUNDELSE] = ACTIONS(4620),
    [anon_sym_POUNDElse] = ACTIONS(4620),
    [anon_sym_POUNDendif] = ACTIONS(4620),
    [anon_sym_POUNDENDIF] = ACTIONS(4620),
    [anon_sym_POUNDEndif] = ACTIONS(4620),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4618),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4618),
    [anon_sym_PLUS] = ACTIONS(4620),
    [sym_datetime_literal] = ACTIONS(4620),
    [sym_date_literal] = ACTIONS(4618),
    [sym_time_literal] = ACTIONS(4618),
    [sym_biginteger_literal] = ACTIONS(4620),
    [anon_sym_if] = ACTIONS(4618),
    [anon_sym_IF] = ACTIONS(4618),
    [anon_sym_If] = ACTIONS(4618),
    [anon_sym_else] = ACTIONS(4618),
    [anon_sym_ELSE] = ACTIONS(4618),
    [anon_sym_Else] = ACTIONS(4618),
    [anon_sym_case] = ACTIONS(4618),
    [anon_sym_CASE] = ACTIONS(4618),
    [anon_sym_Case] = ACTIONS(4618),
    [anon_sym_for] = ACTIONS(4618),
    [anon_sym_FOR] = ACTIONS(4618),
    [anon_sym_For] = ACTIONS(4618),
    [anon_sym_foreach] = ACTIONS(4618),
    [anon_sym_FOREACH] = ACTIONS(4618),
    [anon_sym_Foreach] = ACTIONS(4618),
    [anon_sym_while] = ACTIONS(4618),
    [anon_sym_WHILE] = ACTIONS(4618),
    [anon_sym_While] = ACTIONS(4618),
    [anon_sym_repeat] = ACTIONS(4618),
    [anon_sym_REPEAT] = ACTIONS(4618),
    [anon_sym_Repeat] = ACTIONS(4618),
    [anon_sym_exit] = ACTIONS(4618),
    [anon_sym_EXIT] = ACTIONS(4618),
    [anon_sym_Exit] = ACTIONS(4618),
    [anon_sym_continue] = ACTIONS(4618),
    [anon_sym_CONTINUE] = ACTIONS(4618),
    [anon_sym_Continue] = ACTIONS(4618),
    [anon_sym_break] = ACTIONS(4618),
    [anon_sym_BREAK] = ACTIONS(4618),
    [anon_sym_Break] = ACTIONS(4618),
    [anon_sym_with] = ACTIONS(4618),
    [anon_sym_WITH] = ACTIONS(4618),
    [anon_sym_With] = ACTIONS(4618),
    [sym_asserterror_keyword] = ACTIONS(4620),
    [sym_page_keyword] = ACTIONS(4618),
    [anon_sym_codeunit] = ACTIONS(4618),
    [anon_sym_CODEUNIT] = ACTIONS(4618),
    [anon_sym_Codeunit] = ACTIONS(4618),
    [anon_sym_CodeUnit] = ACTIONS(4618),
    [anon_sym_COdeunit] = ACTIONS(4618),
    [anon_sym_codeUnit] = ACTIONS(4618),
    [sym_report_keyword] = ACTIONS(4618),
    [sym_query_keyword] = ACTIONS(4618),
    [anon_sym_xmlport] = ACTIONS(4618),
    [anon_sym_XMLPORT] = ACTIONS(4618),
    [anon_sym_Xmlport] = ACTIONS(4618),
    [anon_sym_XMLport] = ACTIONS(4618),
    [anon_sym_XMLPort] = ACTIONS(4618),
    [anon_sym_XmlPort] = ACTIONS(4618),
    [anon_sym_enum] = ACTIONS(4618),
    [anon_sym_ENUM] = ACTIONS(4618),
    [anon_sym_Enum] = ACTIONS(4618),
    [anon_sym_eNUM] = ACTIONS(4618),
    [anon_sym_eNum] = ACTIONS(4618),
    [anon_sym_ENum] = ACTIONS(4618),
    [sym_quoted_identifier] = ACTIONS(4620),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4620),
    [sym_integer] = ACTIONS(4618),
    [sym_continue_as_identifier] = ACTIONS(4620),
    [sym_preproc_open] = ACTIONS(4620),
    [sym_preproc_close] = ACTIONS(4620),
  },
  [STATE(1667)] = {
    [sym_else_keyword] = STATE(15),
    [sym_identifier] = ACTIONS(4119),
    [anon_sym_SEMI] = ACTIONS(4121),
    [anon_sym_DASH] = ACTIONS(4121),
    [aux_sym_boolean_token1] = ACTIONS(4119),
    [aux_sym_boolean_token2] = ACTIONS(4119),
    [sym_decimal] = ACTIONS(4119),
    [anon_sym_LPAREN] = ACTIONS(4121),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4119),
    [anon_sym_LBRACK] = ACTIONS(4121),
    [aux_sym_record_type_token1] = ACTIONS(4119),
    [aux_sym_basic_type_token21] = ACTIONS(4119),
    [aux_sym_basic_type_token22] = ACTIONS(4119),
    [aux_sym_basic_type_token48] = ACTIONS(4119),
    [anon_sym_POUNDif] = ACTIONS(4121),
    [anon_sym_POUNDIF] = ACTIONS(4121),
    [anon_sym_POUNDIf] = ACTIONS(4121),
    [anon_sym_not] = ACTIONS(4119),
    [anon_sym_NOT] = ACTIONS(4119),
    [anon_sym_Not] = ACTIONS(4119),
    [anon_sym_POUNDelif] = ACTIONS(4121),
    [anon_sym_POUNDELIF] = ACTIONS(4121),
    [anon_sym_POUNDElif] = ACTIONS(4121),
    [anon_sym_POUNDelse] = ACTIONS(4121),
    [anon_sym_POUNDELSE] = ACTIONS(4121),
    [anon_sym_POUNDElse] = ACTIONS(4121),
    [anon_sym_POUNDendif] = ACTIONS(4121),
    [anon_sym_POUNDENDIF] = ACTIONS(4121),
    [anon_sym_POUNDEndif] = ACTIONS(4121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4119),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4119),
    [anon_sym_PLUS] = ACTIONS(4121),
    [sym_datetime_literal] = ACTIONS(4121),
    [sym_date_literal] = ACTIONS(4119),
    [sym_time_literal] = ACTIONS(4119),
    [sym_biginteger_literal] = ACTIONS(4121),
    [anon_sym_if] = ACTIONS(4119),
    [anon_sym_IF] = ACTIONS(4119),
    [anon_sym_If] = ACTIONS(4119),
    [anon_sym_else] = ACTIONS(4123),
    [anon_sym_ELSE] = ACTIONS(4123),
    [anon_sym_Else] = ACTIONS(4123),
    [anon_sym_case] = ACTIONS(4119),
    [anon_sym_CASE] = ACTIONS(4119),
    [anon_sym_Case] = ACTIONS(4119),
    [anon_sym_for] = ACTIONS(4119),
    [anon_sym_FOR] = ACTIONS(4119),
    [anon_sym_For] = ACTIONS(4119),
    [anon_sym_foreach] = ACTIONS(4119),
    [anon_sym_FOREACH] = ACTIONS(4119),
    [anon_sym_Foreach] = ACTIONS(4119),
    [anon_sym_while] = ACTIONS(4119),
    [anon_sym_WHILE] = ACTIONS(4119),
    [anon_sym_While] = ACTIONS(4119),
    [anon_sym_repeat] = ACTIONS(4119),
    [anon_sym_REPEAT] = ACTIONS(4119),
    [anon_sym_Repeat] = ACTIONS(4119),
    [anon_sym_exit] = ACTIONS(4119),
    [anon_sym_EXIT] = ACTIONS(4119),
    [anon_sym_Exit] = ACTIONS(4119),
    [anon_sym_continue] = ACTIONS(4119),
    [anon_sym_CONTINUE] = ACTIONS(4119),
    [anon_sym_Continue] = ACTIONS(4119),
    [anon_sym_break] = ACTIONS(4119),
    [anon_sym_BREAK] = ACTIONS(4119),
    [anon_sym_Break] = ACTIONS(4119),
    [anon_sym_with] = ACTIONS(4119),
    [anon_sym_WITH] = ACTIONS(4119),
    [anon_sym_With] = ACTIONS(4119),
    [sym_asserterror_keyword] = ACTIONS(4121),
    [sym_page_keyword] = ACTIONS(4119),
    [anon_sym_codeunit] = ACTIONS(4119),
    [anon_sym_CODEUNIT] = ACTIONS(4119),
    [anon_sym_Codeunit] = ACTIONS(4119),
    [anon_sym_CodeUnit] = ACTIONS(4119),
    [anon_sym_COdeunit] = ACTIONS(4119),
    [anon_sym_codeUnit] = ACTIONS(4119),
    [sym_report_keyword] = ACTIONS(4119),
    [sym_query_keyword] = ACTIONS(4119),
    [anon_sym_xmlport] = ACTIONS(4119),
    [anon_sym_XMLPORT] = ACTIONS(4119),
    [anon_sym_Xmlport] = ACTIONS(4119),
    [anon_sym_XMLport] = ACTIONS(4119),
    [anon_sym_XMLPort] = ACTIONS(4119),
    [anon_sym_XmlPort] = ACTIONS(4119),
    [anon_sym_enum] = ACTIONS(4119),
    [anon_sym_ENUM] = ACTIONS(4119),
    [anon_sym_Enum] = ACTIONS(4119),
    [anon_sym_eNUM] = ACTIONS(4119),
    [anon_sym_eNum] = ACTIONS(4119),
    [anon_sym_ENum] = ACTIONS(4119),
    [sym_quoted_identifier] = ACTIONS(4121),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4121),
    [sym_integer] = ACTIONS(4119),
    [sym_continue_as_identifier] = ACTIONS(4121),
    [sym_preproc_open] = ACTIONS(4121),
    [sym_preproc_close] = ACTIONS(4121),
  },
  [STATE(1668)] = {
    [sym_else_keyword] = STATE(16),
    [sym_identifier] = ACTIONS(4125),
    [anon_sym_SEMI] = ACTIONS(4127),
    [anon_sym_DASH] = ACTIONS(4127),
    [aux_sym_boolean_token1] = ACTIONS(4125),
    [aux_sym_boolean_token2] = ACTIONS(4125),
    [sym_decimal] = ACTIONS(4125),
    [anon_sym_LPAREN] = ACTIONS(4127),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4125),
    [anon_sym_LBRACK] = ACTIONS(4127),
    [aux_sym_record_type_token1] = ACTIONS(4125),
    [aux_sym_basic_type_token21] = ACTIONS(4125),
    [aux_sym_basic_type_token22] = ACTIONS(4125),
    [aux_sym_basic_type_token48] = ACTIONS(4125),
    [anon_sym_POUNDif] = ACTIONS(4127),
    [anon_sym_POUNDIF] = ACTIONS(4127),
    [anon_sym_POUNDIf] = ACTIONS(4127),
    [anon_sym_not] = ACTIONS(4125),
    [anon_sym_NOT] = ACTIONS(4125),
    [anon_sym_Not] = ACTIONS(4125),
    [anon_sym_POUNDelif] = ACTIONS(4127),
    [anon_sym_POUNDELIF] = ACTIONS(4127),
    [anon_sym_POUNDElif] = ACTIONS(4127),
    [anon_sym_POUNDelse] = ACTIONS(4127),
    [anon_sym_POUNDELSE] = ACTIONS(4127),
    [anon_sym_POUNDElse] = ACTIONS(4127),
    [anon_sym_POUNDendif] = ACTIONS(4127),
    [anon_sym_POUNDENDIF] = ACTIONS(4127),
    [anon_sym_POUNDEndif] = ACTIONS(4127),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4125),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4125),
    [anon_sym_PLUS] = ACTIONS(4127),
    [sym_datetime_literal] = ACTIONS(4127),
    [sym_date_literal] = ACTIONS(4125),
    [sym_time_literal] = ACTIONS(4125),
    [sym_biginteger_literal] = ACTIONS(4127),
    [anon_sym_if] = ACTIONS(4125),
    [anon_sym_IF] = ACTIONS(4125),
    [anon_sym_If] = ACTIONS(4125),
    [anon_sym_else] = ACTIONS(4123),
    [anon_sym_ELSE] = ACTIONS(4123),
    [anon_sym_Else] = ACTIONS(4123),
    [anon_sym_case] = ACTIONS(4125),
    [anon_sym_CASE] = ACTIONS(4125),
    [anon_sym_Case] = ACTIONS(4125),
    [anon_sym_for] = ACTIONS(4125),
    [anon_sym_FOR] = ACTIONS(4125),
    [anon_sym_For] = ACTIONS(4125),
    [anon_sym_foreach] = ACTIONS(4125),
    [anon_sym_FOREACH] = ACTIONS(4125),
    [anon_sym_Foreach] = ACTIONS(4125),
    [anon_sym_while] = ACTIONS(4125),
    [anon_sym_WHILE] = ACTIONS(4125),
    [anon_sym_While] = ACTIONS(4125),
    [anon_sym_repeat] = ACTIONS(4125),
    [anon_sym_REPEAT] = ACTIONS(4125),
    [anon_sym_Repeat] = ACTIONS(4125),
    [anon_sym_exit] = ACTIONS(4125),
    [anon_sym_EXIT] = ACTIONS(4125),
    [anon_sym_Exit] = ACTIONS(4125),
    [anon_sym_continue] = ACTIONS(4125),
    [anon_sym_CONTINUE] = ACTIONS(4125),
    [anon_sym_Continue] = ACTIONS(4125),
    [anon_sym_break] = ACTIONS(4125),
    [anon_sym_BREAK] = ACTIONS(4125),
    [anon_sym_Break] = ACTIONS(4125),
    [anon_sym_with] = ACTIONS(4125),
    [anon_sym_WITH] = ACTIONS(4125),
    [anon_sym_With] = ACTIONS(4125),
    [sym_asserterror_keyword] = ACTIONS(4127),
    [sym_page_keyword] = ACTIONS(4125),
    [anon_sym_codeunit] = ACTIONS(4125),
    [anon_sym_CODEUNIT] = ACTIONS(4125),
    [anon_sym_Codeunit] = ACTIONS(4125),
    [anon_sym_CodeUnit] = ACTIONS(4125),
    [anon_sym_COdeunit] = ACTIONS(4125),
    [anon_sym_codeUnit] = ACTIONS(4125),
    [sym_report_keyword] = ACTIONS(4125),
    [sym_query_keyword] = ACTIONS(4125),
    [anon_sym_xmlport] = ACTIONS(4125),
    [anon_sym_XMLPORT] = ACTIONS(4125),
    [anon_sym_Xmlport] = ACTIONS(4125),
    [anon_sym_XMLport] = ACTIONS(4125),
    [anon_sym_XMLPort] = ACTIONS(4125),
    [anon_sym_XmlPort] = ACTIONS(4125),
    [anon_sym_enum] = ACTIONS(4125),
    [anon_sym_ENUM] = ACTIONS(4125),
    [anon_sym_Enum] = ACTIONS(4125),
    [anon_sym_eNUM] = ACTIONS(4125),
    [anon_sym_eNum] = ACTIONS(4125),
    [anon_sym_ENum] = ACTIONS(4125),
    [sym_quoted_identifier] = ACTIONS(4127),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4127),
    [sym_integer] = ACTIONS(4125),
    [sym_continue_as_identifier] = ACTIONS(4127),
    [sym_preproc_open] = ACTIONS(4127),
    [sym_preproc_close] = ACTIONS(4127),
  },
  [STATE(1669)] = {
    [sym_else_keyword] = STATE(17),
    [sym_identifier] = ACTIONS(4119),
    [anon_sym_SEMI] = ACTIONS(4121),
    [anon_sym_DASH] = ACTIONS(4121),
    [aux_sym_boolean_token1] = ACTIONS(4119),
    [aux_sym_boolean_token2] = ACTIONS(4119),
    [sym_decimal] = ACTIONS(4119),
    [anon_sym_LPAREN] = ACTIONS(4121),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4119),
    [anon_sym_LBRACK] = ACTIONS(4121),
    [aux_sym_record_type_token1] = ACTIONS(4119),
    [aux_sym_basic_type_token21] = ACTIONS(4119),
    [aux_sym_basic_type_token22] = ACTIONS(4119),
    [aux_sym_basic_type_token48] = ACTIONS(4119),
    [anon_sym_POUNDif] = ACTIONS(4121),
    [anon_sym_POUNDIF] = ACTIONS(4121),
    [anon_sym_POUNDIf] = ACTIONS(4121),
    [anon_sym_not] = ACTIONS(4119),
    [anon_sym_NOT] = ACTIONS(4119),
    [anon_sym_Not] = ACTIONS(4119),
    [anon_sym_POUNDelif] = ACTIONS(4121),
    [anon_sym_POUNDELIF] = ACTIONS(4121),
    [anon_sym_POUNDElif] = ACTIONS(4121),
    [anon_sym_POUNDelse] = ACTIONS(4121),
    [anon_sym_POUNDELSE] = ACTIONS(4121),
    [anon_sym_POUNDElse] = ACTIONS(4121),
    [anon_sym_POUNDendif] = ACTIONS(4121),
    [anon_sym_POUNDENDIF] = ACTIONS(4121),
    [anon_sym_POUNDEndif] = ACTIONS(4121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4119),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4119),
    [anon_sym_PLUS] = ACTIONS(4121),
    [sym_datetime_literal] = ACTIONS(4121),
    [sym_date_literal] = ACTIONS(4119),
    [sym_time_literal] = ACTIONS(4119),
    [sym_biginteger_literal] = ACTIONS(4121),
    [anon_sym_if] = ACTIONS(4119),
    [anon_sym_IF] = ACTIONS(4119),
    [anon_sym_If] = ACTIONS(4119),
    [anon_sym_else] = ACTIONS(4123),
    [anon_sym_ELSE] = ACTIONS(4123),
    [anon_sym_Else] = ACTIONS(4123),
    [anon_sym_case] = ACTIONS(4119),
    [anon_sym_CASE] = ACTIONS(4119),
    [anon_sym_Case] = ACTIONS(4119),
    [anon_sym_for] = ACTIONS(4119),
    [anon_sym_FOR] = ACTIONS(4119),
    [anon_sym_For] = ACTIONS(4119),
    [anon_sym_foreach] = ACTIONS(4119),
    [anon_sym_FOREACH] = ACTIONS(4119),
    [anon_sym_Foreach] = ACTIONS(4119),
    [anon_sym_while] = ACTIONS(4119),
    [anon_sym_WHILE] = ACTIONS(4119),
    [anon_sym_While] = ACTIONS(4119),
    [anon_sym_repeat] = ACTIONS(4119),
    [anon_sym_REPEAT] = ACTIONS(4119),
    [anon_sym_Repeat] = ACTIONS(4119),
    [anon_sym_exit] = ACTIONS(4119),
    [anon_sym_EXIT] = ACTIONS(4119),
    [anon_sym_Exit] = ACTIONS(4119),
    [anon_sym_continue] = ACTIONS(4119),
    [anon_sym_CONTINUE] = ACTIONS(4119),
    [anon_sym_Continue] = ACTIONS(4119),
    [anon_sym_break] = ACTIONS(4119),
    [anon_sym_BREAK] = ACTIONS(4119),
    [anon_sym_Break] = ACTIONS(4119),
    [anon_sym_with] = ACTIONS(4119),
    [anon_sym_WITH] = ACTIONS(4119),
    [anon_sym_With] = ACTIONS(4119),
    [sym_asserterror_keyword] = ACTIONS(4121),
    [sym_page_keyword] = ACTIONS(4119),
    [anon_sym_codeunit] = ACTIONS(4119),
    [anon_sym_CODEUNIT] = ACTIONS(4119),
    [anon_sym_Codeunit] = ACTIONS(4119),
    [anon_sym_CodeUnit] = ACTIONS(4119),
    [anon_sym_COdeunit] = ACTIONS(4119),
    [anon_sym_codeUnit] = ACTIONS(4119),
    [sym_report_keyword] = ACTIONS(4119),
    [sym_query_keyword] = ACTIONS(4119),
    [anon_sym_xmlport] = ACTIONS(4119),
    [anon_sym_XMLPORT] = ACTIONS(4119),
    [anon_sym_Xmlport] = ACTIONS(4119),
    [anon_sym_XMLport] = ACTIONS(4119),
    [anon_sym_XMLPort] = ACTIONS(4119),
    [anon_sym_XmlPort] = ACTIONS(4119),
    [anon_sym_enum] = ACTIONS(4119),
    [anon_sym_ENUM] = ACTIONS(4119),
    [anon_sym_Enum] = ACTIONS(4119),
    [anon_sym_eNUM] = ACTIONS(4119),
    [anon_sym_eNum] = ACTIONS(4119),
    [anon_sym_ENum] = ACTIONS(4119),
    [sym_quoted_identifier] = ACTIONS(4121),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4121),
    [sym_integer] = ACTIONS(4119),
    [sym_continue_as_identifier] = ACTIONS(4121),
    [sym_preproc_open] = ACTIONS(4121),
    [sym_preproc_close] = ACTIONS(4121),
  },
  [STATE(1670)] = {
    [sym_else_keyword] = STATE(18),
    [sym_identifier] = ACTIONS(4125),
    [anon_sym_SEMI] = ACTIONS(4127),
    [anon_sym_DASH] = ACTIONS(4127),
    [aux_sym_boolean_token1] = ACTIONS(4125),
    [aux_sym_boolean_token2] = ACTIONS(4125),
    [sym_decimal] = ACTIONS(4125),
    [anon_sym_LPAREN] = ACTIONS(4127),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4125),
    [anon_sym_LBRACK] = ACTIONS(4127),
    [aux_sym_record_type_token1] = ACTIONS(4125),
    [aux_sym_basic_type_token21] = ACTIONS(4125),
    [aux_sym_basic_type_token22] = ACTIONS(4125),
    [aux_sym_basic_type_token48] = ACTIONS(4125),
    [anon_sym_POUNDif] = ACTIONS(4127),
    [anon_sym_POUNDIF] = ACTIONS(4127),
    [anon_sym_POUNDIf] = ACTIONS(4127),
    [anon_sym_not] = ACTIONS(4125),
    [anon_sym_NOT] = ACTIONS(4125),
    [anon_sym_Not] = ACTIONS(4125),
    [anon_sym_POUNDelif] = ACTIONS(4127),
    [anon_sym_POUNDELIF] = ACTIONS(4127),
    [anon_sym_POUNDElif] = ACTIONS(4127),
    [anon_sym_POUNDelse] = ACTIONS(4127),
    [anon_sym_POUNDELSE] = ACTIONS(4127),
    [anon_sym_POUNDElse] = ACTIONS(4127),
    [anon_sym_POUNDendif] = ACTIONS(4127),
    [anon_sym_POUNDENDIF] = ACTIONS(4127),
    [anon_sym_POUNDEndif] = ACTIONS(4127),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4125),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4125),
    [anon_sym_PLUS] = ACTIONS(4127),
    [sym_datetime_literal] = ACTIONS(4127),
    [sym_date_literal] = ACTIONS(4125),
    [sym_time_literal] = ACTIONS(4125),
    [sym_biginteger_literal] = ACTIONS(4127),
    [anon_sym_if] = ACTIONS(4125),
    [anon_sym_IF] = ACTIONS(4125),
    [anon_sym_If] = ACTIONS(4125),
    [anon_sym_else] = ACTIONS(4123),
    [anon_sym_ELSE] = ACTIONS(4123),
    [anon_sym_Else] = ACTIONS(4123),
    [anon_sym_case] = ACTIONS(4125),
    [anon_sym_CASE] = ACTIONS(4125),
    [anon_sym_Case] = ACTIONS(4125),
    [anon_sym_for] = ACTIONS(4125),
    [anon_sym_FOR] = ACTIONS(4125),
    [anon_sym_For] = ACTIONS(4125),
    [anon_sym_foreach] = ACTIONS(4125),
    [anon_sym_FOREACH] = ACTIONS(4125),
    [anon_sym_Foreach] = ACTIONS(4125),
    [anon_sym_while] = ACTIONS(4125),
    [anon_sym_WHILE] = ACTIONS(4125),
    [anon_sym_While] = ACTIONS(4125),
    [anon_sym_repeat] = ACTIONS(4125),
    [anon_sym_REPEAT] = ACTIONS(4125),
    [anon_sym_Repeat] = ACTIONS(4125),
    [anon_sym_exit] = ACTIONS(4125),
    [anon_sym_EXIT] = ACTIONS(4125),
    [anon_sym_Exit] = ACTIONS(4125),
    [anon_sym_continue] = ACTIONS(4125),
    [anon_sym_CONTINUE] = ACTIONS(4125),
    [anon_sym_Continue] = ACTIONS(4125),
    [anon_sym_break] = ACTIONS(4125),
    [anon_sym_BREAK] = ACTIONS(4125),
    [anon_sym_Break] = ACTIONS(4125),
    [anon_sym_with] = ACTIONS(4125),
    [anon_sym_WITH] = ACTIONS(4125),
    [anon_sym_With] = ACTIONS(4125),
    [sym_asserterror_keyword] = ACTIONS(4127),
    [sym_page_keyword] = ACTIONS(4125),
    [anon_sym_codeunit] = ACTIONS(4125),
    [anon_sym_CODEUNIT] = ACTIONS(4125),
    [anon_sym_Codeunit] = ACTIONS(4125),
    [anon_sym_CodeUnit] = ACTIONS(4125),
    [anon_sym_COdeunit] = ACTIONS(4125),
    [anon_sym_codeUnit] = ACTIONS(4125),
    [sym_report_keyword] = ACTIONS(4125),
    [sym_query_keyword] = ACTIONS(4125),
    [anon_sym_xmlport] = ACTIONS(4125),
    [anon_sym_XMLPORT] = ACTIONS(4125),
    [anon_sym_Xmlport] = ACTIONS(4125),
    [anon_sym_XMLport] = ACTIONS(4125),
    [anon_sym_XMLPort] = ACTIONS(4125),
    [anon_sym_XmlPort] = ACTIONS(4125),
    [anon_sym_enum] = ACTIONS(4125),
    [anon_sym_ENUM] = ACTIONS(4125),
    [anon_sym_Enum] = ACTIONS(4125),
    [anon_sym_eNUM] = ACTIONS(4125),
    [anon_sym_eNum] = ACTIONS(4125),
    [anon_sym_ENum] = ACTIONS(4125),
    [sym_quoted_identifier] = ACTIONS(4127),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4127),
    [sym_integer] = ACTIONS(4125),
    [sym_continue_as_identifier] = ACTIONS(4127),
    [sym_preproc_open] = ACTIONS(4127),
    [sym_preproc_close] = ACTIONS(4127),
  },
  [STATE(1671)] = {
    [sym_identifier] = ACTIONS(4622),
    [anon_sym_SEMI] = ACTIONS(4624),
    [anon_sym_DASH] = ACTIONS(4624),
    [aux_sym_boolean_token1] = ACTIONS(4622),
    [aux_sym_boolean_token2] = ACTIONS(4622),
    [sym_decimal] = ACTIONS(4622),
    [anon_sym_LPAREN] = ACTIONS(4624),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4622),
    [anon_sym_LBRACK] = ACTIONS(4624),
    [aux_sym_record_type_token1] = ACTIONS(4622),
    [aux_sym_basic_type_token21] = ACTIONS(4622),
    [aux_sym_basic_type_token22] = ACTIONS(4622),
    [aux_sym_basic_type_token48] = ACTIONS(4622),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4622),
    [anon_sym_POUNDif] = ACTIONS(4624),
    [anon_sym_POUNDIF] = ACTIONS(4624),
    [anon_sym_POUNDIf] = ACTIONS(4624),
    [anon_sym_not] = ACTIONS(4622),
    [anon_sym_NOT] = ACTIONS(4622),
    [anon_sym_Not] = ACTIONS(4622),
    [anon_sym_POUNDelif] = ACTIONS(4624),
    [anon_sym_POUNDELIF] = ACTIONS(4624),
    [anon_sym_POUNDElif] = ACTIONS(4624),
    [anon_sym_POUNDelse] = ACTIONS(4624),
    [anon_sym_POUNDELSE] = ACTIONS(4624),
    [anon_sym_POUNDElse] = ACTIONS(4624),
    [anon_sym_POUNDendif] = ACTIONS(4624),
    [anon_sym_POUNDENDIF] = ACTIONS(4624),
    [anon_sym_POUNDEndif] = ACTIONS(4624),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4622),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4622),
    [anon_sym_PLUS] = ACTIONS(4624),
    [sym_datetime_literal] = ACTIONS(4624),
    [sym_date_literal] = ACTIONS(4622),
    [sym_time_literal] = ACTIONS(4622),
    [sym_biginteger_literal] = ACTIONS(4624),
    [anon_sym_if] = ACTIONS(4622),
    [anon_sym_IF] = ACTIONS(4622),
    [anon_sym_If] = ACTIONS(4622),
    [anon_sym_else] = ACTIONS(4622),
    [anon_sym_ELSE] = ACTIONS(4622),
    [anon_sym_Else] = ACTIONS(4622),
    [anon_sym_case] = ACTIONS(4622),
    [anon_sym_CASE] = ACTIONS(4622),
    [anon_sym_Case] = ACTIONS(4622),
    [anon_sym_for] = ACTIONS(4622),
    [anon_sym_FOR] = ACTIONS(4622),
    [anon_sym_For] = ACTIONS(4622),
    [anon_sym_foreach] = ACTIONS(4622),
    [anon_sym_FOREACH] = ACTIONS(4622),
    [anon_sym_Foreach] = ACTIONS(4622),
    [anon_sym_while] = ACTIONS(4622),
    [anon_sym_WHILE] = ACTIONS(4622),
    [anon_sym_While] = ACTIONS(4622),
    [anon_sym_repeat] = ACTIONS(4622),
    [anon_sym_REPEAT] = ACTIONS(4622),
    [anon_sym_Repeat] = ACTIONS(4622),
    [anon_sym_exit] = ACTIONS(4622),
    [anon_sym_EXIT] = ACTIONS(4622),
    [anon_sym_Exit] = ACTIONS(4622),
    [anon_sym_continue] = ACTIONS(4622),
    [anon_sym_CONTINUE] = ACTIONS(4622),
    [anon_sym_Continue] = ACTIONS(4622),
    [anon_sym_break] = ACTIONS(4622),
    [anon_sym_BREAK] = ACTIONS(4622),
    [anon_sym_Break] = ACTIONS(4622),
    [anon_sym_with] = ACTIONS(4622),
    [anon_sym_WITH] = ACTIONS(4622),
    [anon_sym_With] = ACTIONS(4622),
    [sym_asserterror_keyword] = ACTIONS(4624),
    [sym_page_keyword] = ACTIONS(4622),
    [anon_sym_codeunit] = ACTIONS(4622),
    [anon_sym_CODEUNIT] = ACTIONS(4622),
    [anon_sym_Codeunit] = ACTIONS(4622),
    [anon_sym_CodeUnit] = ACTIONS(4622),
    [anon_sym_COdeunit] = ACTIONS(4622),
    [anon_sym_codeUnit] = ACTIONS(4622),
    [sym_report_keyword] = ACTIONS(4622),
    [sym_query_keyword] = ACTIONS(4622),
    [anon_sym_xmlport] = ACTIONS(4622),
    [anon_sym_XMLPORT] = ACTIONS(4622),
    [anon_sym_Xmlport] = ACTIONS(4622),
    [anon_sym_XMLport] = ACTIONS(4622),
    [anon_sym_XMLPort] = ACTIONS(4622),
    [anon_sym_XmlPort] = ACTIONS(4622),
    [anon_sym_enum] = ACTIONS(4622),
    [anon_sym_ENUM] = ACTIONS(4622),
    [anon_sym_Enum] = ACTIONS(4622),
    [anon_sym_eNUM] = ACTIONS(4622),
    [anon_sym_eNum] = ACTIONS(4622),
    [anon_sym_ENum] = ACTIONS(4622),
    [sym_quoted_identifier] = ACTIONS(4624),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4624),
    [sym_integer] = ACTIONS(4622),
    [sym_continue_as_identifier] = ACTIONS(4624),
    [sym_preproc_open] = ACTIONS(4624),
    [sym_preproc_close] = ACTIONS(4624),
  },
  [STATE(1672)] = {
    [sym_identifier] = ACTIONS(4626),
    [anon_sym_SEMI] = ACTIONS(4628),
    [anon_sym_DASH] = ACTIONS(4628),
    [aux_sym_boolean_token1] = ACTIONS(4626),
    [aux_sym_boolean_token2] = ACTIONS(4626),
    [sym_decimal] = ACTIONS(4626),
    [anon_sym_LPAREN] = ACTIONS(4628),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4626),
    [anon_sym_LBRACK] = ACTIONS(4628),
    [aux_sym_record_type_token1] = ACTIONS(4626),
    [aux_sym_basic_type_token21] = ACTIONS(4626),
    [aux_sym_basic_type_token22] = ACTIONS(4626),
    [aux_sym_basic_type_token48] = ACTIONS(4626),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4626),
    [anon_sym_POUNDif] = ACTIONS(4628),
    [anon_sym_POUNDIF] = ACTIONS(4628),
    [anon_sym_POUNDIf] = ACTIONS(4628),
    [anon_sym_not] = ACTIONS(4626),
    [anon_sym_NOT] = ACTIONS(4626),
    [anon_sym_Not] = ACTIONS(4626),
    [anon_sym_POUNDelif] = ACTIONS(4628),
    [anon_sym_POUNDELIF] = ACTIONS(4628),
    [anon_sym_POUNDElif] = ACTIONS(4628),
    [anon_sym_POUNDelse] = ACTIONS(4628),
    [anon_sym_POUNDELSE] = ACTIONS(4628),
    [anon_sym_POUNDElse] = ACTIONS(4628),
    [anon_sym_POUNDendif] = ACTIONS(4628),
    [anon_sym_POUNDENDIF] = ACTIONS(4628),
    [anon_sym_POUNDEndif] = ACTIONS(4628),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4626),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4626),
    [anon_sym_PLUS] = ACTIONS(4628),
    [sym_datetime_literal] = ACTIONS(4628),
    [sym_date_literal] = ACTIONS(4626),
    [sym_time_literal] = ACTIONS(4626),
    [sym_biginteger_literal] = ACTIONS(4628),
    [anon_sym_if] = ACTIONS(4626),
    [anon_sym_IF] = ACTIONS(4626),
    [anon_sym_If] = ACTIONS(4626),
    [anon_sym_else] = ACTIONS(4626),
    [anon_sym_ELSE] = ACTIONS(4626),
    [anon_sym_Else] = ACTIONS(4626),
    [anon_sym_case] = ACTIONS(4626),
    [anon_sym_CASE] = ACTIONS(4626),
    [anon_sym_Case] = ACTIONS(4626),
    [anon_sym_for] = ACTIONS(4626),
    [anon_sym_FOR] = ACTIONS(4626),
    [anon_sym_For] = ACTIONS(4626),
    [anon_sym_foreach] = ACTIONS(4626),
    [anon_sym_FOREACH] = ACTIONS(4626),
    [anon_sym_Foreach] = ACTIONS(4626),
    [anon_sym_while] = ACTIONS(4626),
    [anon_sym_WHILE] = ACTIONS(4626),
    [anon_sym_While] = ACTIONS(4626),
    [anon_sym_repeat] = ACTIONS(4626),
    [anon_sym_REPEAT] = ACTIONS(4626),
    [anon_sym_Repeat] = ACTIONS(4626),
    [anon_sym_exit] = ACTIONS(4626),
    [anon_sym_EXIT] = ACTIONS(4626),
    [anon_sym_Exit] = ACTIONS(4626),
    [anon_sym_continue] = ACTIONS(4626),
    [anon_sym_CONTINUE] = ACTIONS(4626),
    [anon_sym_Continue] = ACTIONS(4626),
    [anon_sym_break] = ACTIONS(4626),
    [anon_sym_BREAK] = ACTIONS(4626),
    [anon_sym_Break] = ACTIONS(4626),
    [anon_sym_with] = ACTIONS(4626),
    [anon_sym_WITH] = ACTIONS(4626),
    [anon_sym_With] = ACTIONS(4626),
    [sym_asserterror_keyword] = ACTIONS(4628),
    [sym_page_keyword] = ACTIONS(4626),
    [anon_sym_codeunit] = ACTIONS(4626),
    [anon_sym_CODEUNIT] = ACTIONS(4626),
    [anon_sym_Codeunit] = ACTIONS(4626),
    [anon_sym_CodeUnit] = ACTIONS(4626),
    [anon_sym_COdeunit] = ACTIONS(4626),
    [anon_sym_codeUnit] = ACTIONS(4626),
    [sym_report_keyword] = ACTIONS(4626),
    [sym_query_keyword] = ACTIONS(4626),
    [anon_sym_xmlport] = ACTIONS(4626),
    [anon_sym_XMLPORT] = ACTIONS(4626),
    [anon_sym_Xmlport] = ACTIONS(4626),
    [anon_sym_XMLport] = ACTIONS(4626),
    [anon_sym_XMLPort] = ACTIONS(4626),
    [anon_sym_XmlPort] = ACTIONS(4626),
    [anon_sym_enum] = ACTIONS(4626),
    [anon_sym_ENUM] = ACTIONS(4626),
    [anon_sym_Enum] = ACTIONS(4626),
    [anon_sym_eNUM] = ACTIONS(4626),
    [anon_sym_eNum] = ACTIONS(4626),
    [anon_sym_ENum] = ACTIONS(4626),
    [sym_quoted_identifier] = ACTIONS(4628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4628),
    [sym_integer] = ACTIONS(4626),
    [sym_continue_as_identifier] = ACTIONS(4628),
    [sym_preproc_open] = ACTIONS(4628),
    [sym_preproc_close] = ACTIONS(4628),
  },
  [STATE(1673)] = {
    [sym_identifier] = ACTIONS(4626),
    [anon_sym_SEMI] = ACTIONS(4628),
    [anon_sym_DASH] = ACTIONS(4628),
    [aux_sym_boolean_token1] = ACTIONS(4626),
    [aux_sym_boolean_token2] = ACTIONS(4626),
    [sym_decimal] = ACTIONS(4626),
    [anon_sym_LPAREN] = ACTIONS(4628),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4626),
    [anon_sym_LBRACK] = ACTIONS(4628),
    [aux_sym_record_type_token1] = ACTIONS(4626),
    [aux_sym_basic_type_token21] = ACTIONS(4626),
    [aux_sym_basic_type_token22] = ACTIONS(4626),
    [aux_sym_basic_type_token48] = ACTIONS(4626),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4626),
    [anon_sym_POUNDif] = ACTIONS(4628),
    [anon_sym_POUNDIF] = ACTIONS(4628),
    [anon_sym_POUNDIf] = ACTIONS(4628),
    [anon_sym_not] = ACTIONS(4626),
    [anon_sym_NOT] = ACTIONS(4626),
    [anon_sym_Not] = ACTIONS(4626),
    [anon_sym_POUNDelif] = ACTIONS(4628),
    [anon_sym_POUNDELIF] = ACTIONS(4628),
    [anon_sym_POUNDElif] = ACTIONS(4628),
    [anon_sym_POUNDelse] = ACTIONS(4628),
    [anon_sym_POUNDELSE] = ACTIONS(4628),
    [anon_sym_POUNDElse] = ACTIONS(4628),
    [anon_sym_POUNDendif] = ACTIONS(4628),
    [anon_sym_POUNDENDIF] = ACTIONS(4628),
    [anon_sym_POUNDEndif] = ACTIONS(4628),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4626),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4626),
    [anon_sym_PLUS] = ACTIONS(4628),
    [sym_datetime_literal] = ACTIONS(4628),
    [sym_date_literal] = ACTIONS(4626),
    [sym_time_literal] = ACTIONS(4626),
    [sym_biginteger_literal] = ACTIONS(4628),
    [anon_sym_if] = ACTIONS(4626),
    [anon_sym_IF] = ACTIONS(4626),
    [anon_sym_If] = ACTIONS(4626),
    [anon_sym_else] = ACTIONS(4626),
    [anon_sym_ELSE] = ACTIONS(4626),
    [anon_sym_Else] = ACTIONS(4626),
    [anon_sym_case] = ACTIONS(4626),
    [anon_sym_CASE] = ACTIONS(4626),
    [anon_sym_Case] = ACTIONS(4626),
    [anon_sym_for] = ACTIONS(4626),
    [anon_sym_FOR] = ACTIONS(4626),
    [anon_sym_For] = ACTIONS(4626),
    [anon_sym_foreach] = ACTIONS(4626),
    [anon_sym_FOREACH] = ACTIONS(4626),
    [anon_sym_Foreach] = ACTIONS(4626),
    [anon_sym_while] = ACTIONS(4626),
    [anon_sym_WHILE] = ACTIONS(4626),
    [anon_sym_While] = ACTIONS(4626),
    [anon_sym_repeat] = ACTIONS(4626),
    [anon_sym_REPEAT] = ACTIONS(4626),
    [anon_sym_Repeat] = ACTIONS(4626),
    [anon_sym_exit] = ACTIONS(4626),
    [anon_sym_EXIT] = ACTIONS(4626),
    [anon_sym_Exit] = ACTIONS(4626),
    [anon_sym_continue] = ACTIONS(4626),
    [anon_sym_CONTINUE] = ACTIONS(4626),
    [anon_sym_Continue] = ACTIONS(4626),
    [anon_sym_break] = ACTIONS(4626),
    [anon_sym_BREAK] = ACTIONS(4626),
    [anon_sym_Break] = ACTIONS(4626),
    [anon_sym_with] = ACTIONS(4626),
    [anon_sym_WITH] = ACTIONS(4626),
    [anon_sym_With] = ACTIONS(4626),
    [sym_asserterror_keyword] = ACTIONS(4628),
    [sym_page_keyword] = ACTIONS(4626),
    [anon_sym_codeunit] = ACTIONS(4626),
    [anon_sym_CODEUNIT] = ACTIONS(4626),
    [anon_sym_Codeunit] = ACTIONS(4626),
    [anon_sym_CodeUnit] = ACTIONS(4626),
    [anon_sym_COdeunit] = ACTIONS(4626),
    [anon_sym_codeUnit] = ACTIONS(4626),
    [sym_report_keyword] = ACTIONS(4626),
    [sym_query_keyword] = ACTIONS(4626),
    [anon_sym_xmlport] = ACTIONS(4626),
    [anon_sym_XMLPORT] = ACTIONS(4626),
    [anon_sym_Xmlport] = ACTIONS(4626),
    [anon_sym_XMLport] = ACTIONS(4626),
    [anon_sym_XMLPort] = ACTIONS(4626),
    [anon_sym_XmlPort] = ACTIONS(4626),
    [anon_sym_enum] = ACTIONS(4626),
    [anon_sym_ENUM] = ACTIONS(4626),
    [anon_sym_Enum] = ACTIONS(4626),
    [anon_sym_eNUM] = ACTIONS(4626),
    [anon_sym_eNum] = ACTIONS(4626),
    [anon_sym_ENum] = ACTIONS(4626),
    [sym_quoted_identifier] = ACTIONS(4628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4628),
    [sym_integer] = ACTIONS(4626),
    [sym_continue_as_identifier] = ACTIONS(4628),
    [sym_preproc_open] = ACTIONS(4628),
    [sym_preproc_close] = ACTIONS(4628),
  },
  [STATE(1674)] = {
    [sym_else_keyword] = STATE(19),
    [sym_identifier] = ACTIONS(4119),
    [anon_sym_SEMI] = ACTIONS(4121),
    [anon_sym_DASH] = ACTIONS(4121),
    [aux_sym_boolean_token1] = ACTIONS(4119),
    [aux_sym_boolean_token2] = ACTIONS(4119),
    [sym_decimal] = ACTIONS(4119),
    [anon_sym_LPAREN] = ACTIONS(4121),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4119),
    [anon_sym_LBRACK] = ACTIONS(4121),
    [aux_sym_record_type_token1] = ACTIONS(4119),
    [aux_sym_basic_type_token21] = ACTIONS(4119),
    [aux_sym_basic_type_token22] = ACTIONS(4119),
    [aux_sym_basic_type_token48] = ACTIONS(4119),
    [anon_sym_POUNDif] = ACTIONS(4121),
    [anon_sym_POUNDIF] = ACTIONS(4121),
    [anon_sym_POUNDIf] = ACTIONS(4121),
    [anon_sym_not] = ACTIONS(4119),
    [anon_sym_NOT] = ACTIONS(4119),
    [anon_sym_Not] = ACTIONS(4119),
    [anon_sym_POUNDelif] = ACTIONS(4121),
    [anon_sym_POUNDELIF] = ACTIONS(4121),
    [anon_sym_POUNDElif] = ACTIONS(4121),
    [anon_sym_POUNDelse] = ACTIONS(4121),
    [anon_sym_POUNDELSE] = ACTIONS(4121),
    [anon_sym_POUNDElse] = ACTIONS(4121),
    [anon_sym_POUNDendif] = ACTIONS(4121),
    [anon_sym_POUNDENDIF] = ACTIONS(4121),
    [anon_sym_POUNDEndif] = ACTIONS(4121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4119),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4119),
    [anon_sym_PLUS] = ACTIONS(4121),
    [sym_datetime_literal] = ACTIONS(4121),
    [sym_date_literal] = ACTIONS(4119),
    [sym_time_literal] = ACTIONS(4119),
    [sym_biginteger_literal] = ACTIONS(4121),
    [anon_sym_if] = ACTIONS(4119),
    [anon_sym_IF] = ACTIONS(4119),
    [anon_sym_If] = ACTIONS(4119),
    [anon_sym_else] = ACTIONS(4123),
    [anon_sym_ELSE] = ACTIONS(4123),
    [anon_sym_Else] = ACTIONS(4123),
    [anon_sym_case] = ACTIONS(4119),
    [anon_sym_CASE] = ACTIONS(4119),
    [anon_sym_Case] = ACTIONS(4119),
    [anon_sym_for] = ACTIONS(4119),
    [anon_sym_FOR] = ACTIONS(4119),
    [anon_sym_For] = ACTIONS(4119),
    [anon_sym_foreach] = ACTIONS(4119),
    [anon_sym_FOREACH] = ACTIONS(4119),
    [anon_sym_Foreach] = ACTIONS(4119),
    [anon_sym_while] = ACTIONS(4119),
    [anon_sym_WHILE] = ACTIONS(4119),
    [anon_sym_While] = ACTIONS(4119),
    [anon_sym_repeat] = ACTIONS(4119),
    [anon_sym_REPEAT] = ACTIONS(4119),
    [anon_sym_Repeat] = ACTIONS(4119),
    [anon_sym_exit] = ACTIONS(4119),
    [anon_sym_EXIT] = ACTIONS(4119),
    [anon_sym_Exit] = ACTIONS(4119),
    [anon_sym_continue] = ACTIONS(4119),
    [anon_sym_CONTINUE] = ACTIONS(4119),
    [anon_sym_Continue] = ACTIONS(4119),
    [anon_sym_break] = ACTIONS(4119),
    [anon_sym_BREAK] = ACTIONS(4119),
    [anon_sym_Break] = ACTIONS(4119),
    [anon_sym_with] = ACTIONS(4119),
    [anon_sym_WITH] = ACTIONS(4119),
    [anon_sym_With] = ACTIONS(4119),
    [sym_asserterror_keyword] = ACTIONS(4121),
    [sym_page_keyword] = ACTIONS(4119),
    [anon_sym_codeunit] = ACTIONS(4119),
    [anon_sym_CODEUNIT] = ACTIONS(4119),
    [anon_sym_Codeunit] = ACTIONS(4119),
    [anon_sym_CodeUnit] = ACTIONS(4119),
    [anon_sym_COdeunit] = ACTIONS(4119),
    [anon_sym_codeUnit] = ACTIONS(4119),
    [sym_report_keyword] = ACTIONS(4119),
    [sym_query_keyword] = ACTIONS(4119),
    [anon_sym_xmlport] = ACTIONS(4119),
    [anon_sym_XMLPORT] = ACTIONS(4119),
    [anon_sym_Xmlport] = ACTIONS(4119),
    [anon_sym_XMLport] = ACTIONS(4119),
    [anon_sym_XMLPort] = ACTIONS(4119),
    [anon_sym_XmlPort] = ACTIONS(4119),
    [anon_sym_enum] = ACTIONS(4119),
    [anon_sym_ENUM] = ACTIONS(4119),
    [anon_sym_Enum] = ACTIONS(4119),
    [anon_sym_eNUM] = ACTIONS(4119),
    [anon_sym_eNum] = ACTIONS(4119),
    [anon_sym_ENum] = ACTIONS(4119),
    [sym_quoted_identifier] = ACTIONS(4121),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4121),
    [sym_integer] = ACTIONS(4119),
    [sym_continue_as_identifier] = ACTIONS(4121),
    [sym_preproc_open] = ACTIONS(4121),
    [sym_preproc_close] = ACTIONS(4121),
  },
  [STATE(1675)] = {
    [sym_else_keyword] = STATE(20),
    [sym_identifier] = ACTIONS(4125),
    [anon_sym_SEMI] = ACTIONS(4127),
    [anon_sym_DASH] = ACTIONS(4127),
    [aux_sym_boolean_token1] = ACTIONS(4125),
    [aux_sym_boolean_token2] = ACTIONS(4125),
    [sym_decimal] = ACTIONS(4125),
    [anon_sym_LPAREN] = ACTIONS(4127),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4125),
    [anon_sym_LBRACK] = ACTIONS(4127),
    [aux_sym_record_type_token1] = ACTIONS(4125),
    [aux_sym_basic_type_token21] = ACTIONS(4125),
    [aux_sym_basic_type_token22] = ACTIONS(4125),
    [aux_sym_basic_type_token48] = ACTIONS(4125),
    [anon_sym_POUNDif] = ACTIONS(4127),
    [anon_sym_POUNDIF] = ACTIONS(4127),
    [anon_sym_POUNDIf] = ACTIONS(4127),
    [anon_sym_not] = ACTIONS(4125),
    [anon_sym_NOT] = ACTIONS(4125),
    [anon_sym_Not] = ACTIONS(4125),
    [anon_sym_POUNDelif] = ACTIONS(4127),
    [anon_sym_POUNDELIF] = ACTIONS(4127),
    [anon_sym_POUNDElif] = ACTIONS(4127),
    [anon_sym_POUNDelse] = ACTIONS(4127),
    [anon_sym_POUNDELSE] = ACTIONS(4127),
    [anon_sym_POUNDElse] = ACTIONS(4127),
    [anon_sym_POUNDendif] = ACTIONS(4127),
    [anon_sym_POUNDENDIF] = ACTIONS(4127),
    [anon_sym_POUNDEndif] = ACTIONS(4127),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4125),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4125),
    [anon_sym_PLUS] = ACTIONS(4127),
    [sym_datetime_literal] = ACTIONS(4127),
    [sym_date_literal] = ACTIONS(4125),
    [sym_time_literal] = ACTIONS(4125),
    [sym_biginteger_literal] = ACTIONS(4127),
    [anon_sym_if] = ACTIONS(4125),
    [anon_sym_IF] = ACTIONS(4125),
    [anon_sym_If] = ACTIONS(4125),
    [anon_sym_else] = ACTIONS(4123),
    [anon_sym_ELSE] = ACTIONS(4123),
    [anon_sym_Else] = ACTIONS(4123),
    [anon_sym_case] = ACTIONS(4125),
    [anon_sym_CASE] = ACTIONS(4125),
    [anon_sym_Case] = ACTIONS(4125),
    [anon_sym_for] = ACTIONS(4125),
    [anon_sym_FOR] = ACTIONS(4125),
    [anon_sym_For] = ACTIONS(4125),
    [anon_sym_foreach] = ACTIONS(4125),
    [anon_sym_FOREACH] = ACTIONS(4125),
    [anon_sym_Foreach] = ACTIONS(4125),
    [anon_sym_while] = ACTIONS(4125),
    [anon_sym_WHILE] = ACTIONS(4125),
    [anon_sym_While] = ACTIONS(4125),
    [anon_sym_repeat] = ACTIONS(4125),
    [anon_sym_REPEAT] = ACTIONS(4125),
    [anon_sym_Repeat] = ACTIONS(4125),
    [anon_sym_exit] = ACTIONS(4125),
    [anon_sym_EXIT] = ACTIONS(4125),
    [anon_sym_Exit] = ACTIONS(4125),
    [anon_sym_continue] = ACTIONS(4125),
    [anon_sym_CONTINUE] = ACTIONS(4125),
    [anon_sym_Continue] = ACTIONS(4125),
    [anon_sym_break] = ACTIONS(4125),
    [anon_sym_BREAK] = ACTIONS(4125),
    [anon_sym_Break] = ACTIONS(4125),
    [anon_sym_with] = ACTIONS(4125),
    [anon_sym_WITH] = ACTIONS(4125),
    [anon_sym_With] = ACTIONS(4125),
    [sym_asserterror_keyword] = ACTIONS(4127),
    [sym_page_keyword] = ACTIONS(4125),
    [anon_sym_codeunit] = ACTIONS(4125),
    [anon_sym_CODEUNIT] = ACTIONS(4125),
    [anon_sym_Codeunit] = ACTIONS(4125),
    [anon_sym_CodeUnit] = ACTIONS(4125),
    [anon_sym_COdeunit] = ACTIONS(4125),
    [anon_sym_codeUnit] = ACTIONS(4125),
    [sym_report_keyword] = ACTIONS(4125),
    [sym_query_keyword] = ACTIONS(4125),
    [anon_sym_xmlport] = ACTIONS(4125),
    [anon_sym_XMLPORT] = ACTIONS(4125),
    [anon_sym_Xmlport] = ACTIONS(4125),
    [anon_sym_XMLport] = ACTIONS(4125),
    [anon_sym_XMLPort] = ACTIONS(4125),
    [anon_sym_XmlPort] = ACTIONS(4125),
    [anon_sym_enum] = ACTIONS(4125),
    [anon_sym_ENUM] = ACTIONS(4125),
    [anon_sym_Enum] = ACTIONS(4125),
    [anon_sym_eNUM] = ACTIONS(4125),
    [anon_sym_eNum] = ACTIONS(4125),
    [anon_sym_ENum] = ACTIONS(4125),
    [sym_quoted_identifier] = ACTIONS(4127),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4127),
    [sym_integer] = ACTIONS(4125),
    [sym_continue_as_identifier] = ACTIONS(4127),
    [sym_preproc_open] = ACTIONS(4127),
    [sym_preproc_close] = ACTIONS(4127),
  },
  [STATE(1676)] = {
    [sym_identifier] = ACTIONS(4630),
    [anon_sym_SEMI] = ACTIONS(4632),
    [anon_sym_DASH] = ACTIONS(4632),
    [aux_sym_boolean_token1] = ACTIONS(4630),
    [aux_sym_boolean_token2] = ACTIONS(4630),
    [sym_decimal] = ACTIONS(4630),
    [anon_sym_LPAREN] = ACTIONS(4632),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4630),
    [anon_sym_LBRACK] = ACTIONS(4632),
    [aux_sym_record_type_token1] = ACTIONS(4630),
    [aux_sym_basic_type_token21] = ACTIONS(4630),
    [aux_sym_basic_type_token22] = ACTIONS(4630),
    [aux_sym_basic_type_token48] = ACTIONS(4630),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4630),
    [anon_sym_POUNDif] = ACTIONS(4632),
    [anon_sym_POUNDIF] = ACTIONS(4632),
    [anon_sym_POUNDIf] = ACTIONS(4632),
    [anon_sym_not] = ACTIONS(4630),
    [anon_sym_NOT] = ACTIONS(4630),
    [anon_sym_Not] = ACTIONS(4630),
    [anon_sym_POUNDelif] = ACTIONS(4632),
    [anon_sym_POUNDELIF] = ACTIONS(4632),
    [anon_sym_POUNDElif] = ACTIONS(4632),
    [anon_sym_POUNDelse] = ACTIONS(4632),
    [anon_sym_POUNDELSE] = ACTIONS(4632),
    [anon_sym_POUNDElse] = ACTIONS(4632),
    [anon_sym_POUNDendif] = ACTIONS(4632),
    [anon_sym_POUNDENDIF] = ACTIONS(4632),
    [anon_sym_POUNDEndif] = ACTIONS(4632),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4630),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4630),
    [anon_sym_PLUS] = ACTIONS(4632),
    [sym_datetime_literal] = ACTIONS(4632),
    [sym_date_literal] = ACTIONS(4630),
    [sym_time_literal] = ACTIONS(4630),
    [sym_biginteger_literal] = ACTIONS(4632),
    [anon_sym_if] = ACTIONS(4630),
    [anon_sym_IF] = ACTIONS(4630),
    [anon_sym_If] = ACTIONS(4630),
    [anon_sym_else] = ACTIONS(4630),
    [anon_sym_ELSE] = ACTIONS(4630),
    [anon_sym_Else] = ACTIONS(4630),
    [anon_sym_case] = ACTIONS(4630),
    [anon_sym_CASE] = ACTIONS(4630),
    [anon_sym_Case] = ACTIONS(4630),
    [anon_sym_for] = ACTIONS(4630),
    [anon_sym_FOR] = ACTIONS(4630),
    [anon_sym_For] = ACTIONS(4630),
    [anon_sym_foreach] = ACTIONS(4630),
    [anon_sym_FOREACH] = ACTIONS(4630),
    [anon_sym_Foreach] = ACTIONS(4630),
    [anon_sym_while] = ACTIONS(4630),
    [anon_sym_WHILE] = ACTIONS(4630),
    [anon_sym_While] = ACTIONS(4630),
    [anon_sym_repeat] = ACTIONS(4630),
    [anon_sym_REPEAT] = ACTIONS(4630),
    [anon_sym_Repeat] = ACTIONS(4630),
    [anon_sym_exit] = ACTIONS(4630),
    [anon_sym_EXIT] = ACTIONS(4630),
    [anon_sym_Exit] = ACTIONS(4630),
    [anon_sym_continue] = ACTIONS(4630),
    [anon_sym_CONTINUE] = ACTIONS(4630),
    [anon_sym_Continue] = ACTIONS(4630),
    [anon_sym_break] = ACTIONS(4630),
    [anon_sym_BREAK] = ACTIONS(4630),
    [anon_sym_Break] = ACTIONS(4630),
    [anon_sym_with] = ACTIONS(4630),
    [anon_sym_WITH] = ACTIONS(4630),
    [anon_sym_With] = ACTIONS(4630),
    [sym_asserterror_keyword] = ACTIONS(4632),
    [sym_page_keyword] = ACTIONS(4630),
    [anon_sym_codeunit] = ACTIONS(4630),
    [anon_sym_CODEUNIT] = ACTIONS(4630),
    [anon_sym_Codeunit] = ACTIONS(4630),
    [anon_sym_CodeUnit] = ACTIONS(4630),
    [anon_sym_COdeunit] = ACTIONS(4630),
    [anon_sym_codeUnit] = ACTIONS(4630),
    [sym_report_keyword] = ACTIONS(4630),
    [sym_query_keyword] = ACTIONS(4630),
    [anon_sym_xmlport] = ACTIONS(4630),
    [anon_sym_XMLPORT] = ACTIONS(4630),
    [anon_sym_Xmlport] = ACTIONS(4630),
    [anon_sym_XMLport] = ACTIONS(4630),
    [anon_sym_XMLPort] = ACTIONS(4630),
    [anon_sym_XmlPort] = ACTIONS(4630),
    [anon_sym_enum] = ACTIONS(4630),
    [anon_sym_ENUM] = ACTIONS(4630),
    [anon_sym_Enum] = ACTIONS(4630),
    [anon_sym_eNUM] = ACTIONS(4630),
    [anon_sym_eNum] = ACTIONS(4630),
    [anon_sym_ENum] = ACTIONS(4630),
    [sym_quoted_identifier] = ACTIONS(4632),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4632),
    [sym_integer] = ACTIONS(4630),
    [sym_continue_as_identifier] = ACTIONS(4632),
    [sym_preproc_open] = ACTIONS(4632),
    [sym_preproc_close] = ACTIONS(4632),
  },
  [STATE(1677)] = {
    [sym_identifier] = ACTIONS(4634),
    [anon_sym_SEMI] = ACTIONS(4636),
    [anon_sym_DASH] = ACTIONS(4636),
    [aux_sym_boolean_token1] = ACTIONS(4634),
    [aux_sym_boolean_token2] = ACTIONS(4634),
    [sym_decimal] = ACTIONS(4634),
    [anon_sym_LPAREN] = ACTIONS(4636),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4634),
    [anon_sym_LBRACK] = ACTIONS(4636),
    [aux_sym_record_type_token1] = ACTIONS(4634),
    [aux_sym_basic_type_token21] = ACTIONS(4634),
    [aux_sym_basic_type_token22] = ACTIONS(4634),
    [aux_sym_basic_type_token48] = ACTIONS(4634),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4634),
    [anon_sym_POUNDif] = ACTIONS(4636),
    [anon_sym_POUNDIF] = ACTIONS(4636),
    [anon_sym_POUNDIf] = ACTIONS(4636),
    [anon_sym_not] = ACTIONS(4634),
    [anon_sym_NOT] = ACTIONS(4634),
    [anon_sym_Not] = ACTIONS(4634),
    [anon_sym_POUNDelif] = ACTIONS(4636),
    [anon_sym_POUNDELIF] = ACTIONS(4636),
    [anon_sym_POUNDElif] = ACTIONS(4636),
    [anon_sym_POUNDelse] = ACTIONS(4636),
    [anon_sym_POUNDELSE] = ACTIONS(4636),
    [anon_sym_POUNDElse] = ACTIONS(4636),
    [anon_sym_POUNDendif] = ACTIONS(4636),
    [anon_sym_POUNDENDIF] = ACTIONS(4636),
    [anon_sym_POUNDEndif] = ACTIONS(4636),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4634),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4634),
    [anon_sym_PLUS] = ACTIONS(4636),
    [sym_datetime_literal] = ACTIONS(4636),
    [sym_date_literal] = ACTIONS(4634),
    [sym_time_literal] = ACTIONS(4634),
    [sym_biginteger_literal] = ACTIONS(4636),
    [anon_sym_if] = ACTIONS(4634),
    [anon_sym_IF] = ACTIONS(4634),
    [anon_sym_If] = ACTIONS(4634),
    [anon_sym_else] = ACTIONS(4634),
    [anon_sym_ELSE] = ACTIONS(4634),
    [anon_sym_Else] = ACTIONS(4634),
    [anon_sym_case] = ACTIONS(4634),
    [anon_sym_CASE] = ACTIONS(4634),
    [anon_sym_Case] = ACTIONS(4634),
    [anon_sym_for] = ACTIONS(4634),
    [anon_sym_FOR] = ACTIONS(4634),
    [anon_sym_For] = ACTIONS(4634),
    [anon_sym_foreach] = ACTIONS(4634),
    [anon_sym_FOREACH] = ACTIONS(4634),
    [anon_sym_Foreach] = ACTIONS(4634),
    [anon_sym_while] = ACTIONS(4634),
    [anon_sym_WHILE] = ACTIONS(4634),
    [anon_sym_While] = ACTIONS(4634),
    [anon_sym_repeat] = ACTIONS(4634),
    [anon_sym_REPEAT] = ACTIONS(4634),
    [anon_sym_Repeat] = ACTIONS(4634),
    [anon_sym_exit] = ACTIONS(4634),
    [anon_sym_EXIT] = ACTIONS(4634),
    [anon_sym_Exit] = ACTIONS(4634),
    [anon_sym_continue] = ACTIONS(4634),
    [anon_sym_CONTINUE] = ACTIONS(4634),
    [anon_sym_Continue] = ACTIONS(4634),
    [anon_sym_break] = ACTIONS(4634),
    [anon_sym_BREAK] = ACTIONS(4634),
    [anon_sym_Break] = ACTIONS(4634),
    [anon_sym_with] = ACTIONS(4634),
    [anon_sym_WITH] = ACTIONS(4634),
    [anon_sym_With] = ACTIONS(4634),
    [sym_asserterror_keyword] = ACTIONS(4636),
    [sym_page_keyword] = ACTIONS(4634),
    [anon_sym_codeunit] = ACTIONS(4634),
    [anon_sym_CODEUNIT] = ACTIONS(4634),
    [anon_sym_Codeunit] = ACTIONS(4634),
    [anon_sym_CodeUnit] = ACTIONS(4634),
    [anon_sym_COdeunit] = ACTIONS(4634),
    [anon_sym_codeUnit] = ACTIONS(4634),
    [sym_report_keyword] = ACTIONS(4634),
    [sym_query_keyword] = ACTIONS(4634),
    [anon_sym_xmlport] = ACTIONS(4634),
    [anon_sym_XMLPORT] = ACTIONS(4634),
    [anon_sym_Xmlport] = ACTIONS(4634),
    [anon_sym_XMLport] = ACTIONS(4634),
    [anon_sym_XMLPort] = ACTIONS(4634),
    [anon_sym_XmlPort] = ACTIONS(4634),
    [anon_sym_enum] = ACTIONS(4634),
    [anon_sym_ENUM] = ACTIONS(4634),
    [anon_sym_Enum] = ACTIONS(4634),
    [anon_sym_eNUM] = ACTIONS(4634),
    [anon_sym_eNum] = ACTIONS(4634),
    [anon_sym_ENum] = ACTIONS(4634),
    [sym_quoted_identifier] = ACTIONS(4636),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4636),
    [sym_integer] = ACTIONS(4634),
    [sym_continue_as_identifier] = ACTIONS(4636),
    [sym_preproc_open] = ACTIONS(4636),
    [sym_preproc_close] = ACTIONS(4636),
  },
  [STATE(1678)] = {
    [sym_identifier] = ACTIONS(4638),
    [anon_sym_SEMI] = ACTIONS(4640),
    [anon_sym_DASH] = ACTIONS(4640),
    [aux_sym_boolean_token1] = ACTIONS(4638),
    [aux_sym_boolean_token2] = ACTIONS(4638),
    [sym_decimal] = ACTIONS(4638),
    [anon_sym_LPAREN] = ACTIONS(4640),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4638),
    [anon_sym_LBRACK] = ACTIONS(4640),
    [aux_sym_record_type_token1] = ACTIONS(4638),
    [aux_sym_basic_type_token21] = ACTIONS(4638),
    [aux_sym_basic_type_token22] = ACTIONS(4638),
    [aux_sym_basic_type_token48] = ACTIONS(4638),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4638),
    [anon_sym_POUNDif] = ACTIONS(4640),
    [anon_sym_POUNDIF] = ACTIONS(4640),
    [anon_sym_POUNDIf] = ACTIONS(4640),
    [anon_sym_not] = ACTIONS(4638),
    [anon_sym_NOT] = ACTIONS(4638),
    [anon_sym_Not] = ACTIONS(4638),
    [anon_sym_POUNDelif] = ACTIONS(4640),
    [anon_sym_POUNDELIF] = ACTIONS(4640),
    [anon_sym_POUNDElif] = ACTIONS(4640),
    [anon_sym_POUNDelse] = ACTIONS(4640),
    [anon_sym_POUNDELSE] = ACTIONS(4640),
    [anon_sym_POUNDElse] = ACTIONS(4640),
    [anon_sym_POUNDendif] = ACTIONS(4640),
    [anon_sym_POUNDENDIF] = ACTIONS(4640),
    [anon_sym_POUNDEndif] = ACTIONS(4640),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4638),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4638),
    [anon_sym_PLUS] = ACTIONS(4640),
    [sym_datetime_literal] = ACTIONS(4640),
    [sym_date_literal] = ACTIONS(4638),
    [sym_time_literal] = ACTIONS(4638),
    [sym_biginteger_literal] = ACTIONS(4640),
    [anon_sym_if] = ACTIONS(4638),
    [anon_sym_IF] = ACTIONS(4638),
    [anon_sym_If] = ACTIONS(4638),
    [anon_sym_else] = ACTIONS(4638),
    [anon_sym_ELSE] = ACTIONS(4638),
    [anon_sym_Else] = ACTIONS(4638),
    [anon_sym_case] = ACTIONS(4638),
    [anon_sym_CASE] = ACTIONS(4638),
    [anon_sym_Case] = ACTIONS(4638),
    [anon_sym_for] = ACTIONS(4638),
    [anon_sym_FOR] = ACTIONS(4638),
    [anon_sym_For] = ACTIONS(4638),
    [anon_sym_foreach] = ACTIONS(4638),
    [anon_sym_FOREACH] = ACTIONS(4638),
    [anon_sym_Foreach] = ACTIONS(4638),
    [anon_sym_while] = ACTIONS(4638),
    [anon_sym_WHILE] = ACTIONS(4638),
    [anon_sym_While] = ACTIONS(4638),
    [anon_sym_repeat] = ACTIONS(4638),
    [anon_sym_REPEAT] = ACTIONS(4638),
    [anon_sym_Repeat] = ACTIONS(4638),
    [anon_sym_exit] = ACTIONS(4638),
    [anon_sym_EXIT] = ACTIONS(4638),
    [anon_sym_Exit] = ACTIONS(4638),
    [anon_sym_continue] = ACTIONS(4638),
    [anon_sym_CONTINUE] = ACTIONS(4638),
    [anon_sym_Continue] = ACTIONS(4638),
    [anon_sym_break] = ACTIONS(4638),
    [anon_sym_BREAK] = ACTIONS(4638),
    [anon_sym_Break] = ACTIONS(4638),
    [anon_sym_with] = ACTIONS(4638),
    [anon_sym_WITH] = ACTIONS(4638),
    [anon_sym_With] = ACTIONS(4638),
    [sym_asserterror_keyword] = ACTIONS(4640),
    [sym_page_keyword] = ACTIONS(4638),
    [anon_sym_codeunit] = ACTIONS(4638),
    [anon_sym_CODEUNIT] = ACTIONS(4638),
    [anon_sym_Codeunit] = ACTIONS(4638),
    [anon_sym_CodeUnit] = ACTIONS(4638),
    [anon_sym_COdeunit] = ACTIONS(4638),
    [anon_sym_codeUnit] = ACTIONS(4638),
    [sym_report_keyword] = ACTIONS(4638),
    [sym_query_keyword] = ACTIONS(4638),
    [anon_sym_xmlport] = ACTIONS(4638),
    [anon_sym_XMLPORT] = ACTIONS(4638),
    [anon_sym_Xmlport] = ACTIONS(4638),
    [anon_sym_XMLport] = ACTIONS(4638),
    [anon_sym_XMLPort] = ACTIONS(4638),
    [anon_sym_XmlPort] = ACTIONS(4638),
    [anon_sym_enum] = ACTIONS(4638),
    [anon_sym_ENUM] = ACTIONS(4638),
    [anon_sym_Enum] = ACTIONS(4638),
    [anon_sym_eNUM] = ACTIONS(4638),
    [anon_sym_eNum] = ACTIONS(4638),
    [anon_sym_ENum] = ACTIONS(4638),
    [sym_quoted_identifier] = ACTIONS(4640),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4640),
    [sym_integer] = ACTIONS(4638),
    [sym_continue_as_identifier] = ACTIONS(4640),
    [sym_preproc_open] = ACTIONS(4640),
    [sym_preproc_close] = ACTIONS(4640),
  },
  [STATE(1679)] = {
    [sym_identifier] = ACTIONS(4642),
    [anon_sym_SEMI] = ACTIONS(4644),
    [anon_sym_DASH] = ACTIONS(4644),
    [aux_sym_boolean_token1] = ACTIONS(4642),
    [aux_sym_boolean_token2] = ACTIONS(4642),
    [sym_decimal] = ACTIONS(4642),
    [anon_sym_LPAREN] = ACTIONS(4644),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4642),
    [anon_sym_LBRACK] = ACTIONS(4644),
    [aux_sym_record_type_token1] = ACTIONS(4642),
    [aux_sym_basic_type_token21] = ACTIONS(4642),
    [aux_sym_basic_type_token22] = ACTIONS(4642),
    [aux_sym_basic_type_token48] = ACTIONS(4642),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4642),
    [anon_sym_POUNDif] = ACTIONS(4644),
    [anon_sym_POUNDIF] = ACTIONS(4644),
    [anon_sym_POUNDIf] = ACTIONS(4644),
    [anon_sym_not] = ACTIONS(4642),
    [anon_sym_NOT] = ACTIONS(4642),
    [anon_sym_Not] = ACTIONS(4642),
    [anon_sym_POUNDelif] = ACTIONS(4644),
    [anon_sym_POUNDELIF] = ACTIONS(4644),
    [anon_sym_POUNDElif] = ACTIONS(4644),
    [anon_sym_POUNDelse] = ACTIONS(4644),
    [anon_sym_POUNDELSE] = ACTIONS(4644),
    [anon_sym_POUNDElse] = ACTIONS(4644),
    [anon_sym_POUNDendif] = ACTIONS(4644),
    [anon_sym_POUNDENDIF] = ACTIONS(4644),
    [anon_sym_POUNDEndif] = ACTIONS(4644),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4642),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4642),
    [anon_sym_PLUS] = ACTIONS(4644),
    [sym_datetime_literal] = ACTIONS(4644),
    [sym_date_literal] = ACTIONS(4642),
    [sym_time_literal] = ACTIONS(4642),
    [sym_biginteger_literal] = ACTIONS(4644),
    [anon_sym_if] = ACTIONS(4642),
    [anon_sym_IF] = ACTIONS(4642),
    [anon_sym_If] = ACTIONS(4642),
    [anon_sym_else] = ACTIONS(4642),
    [anon_sym_ELSE] = ACTIONS(4642),
    [anon_sym_Else] = ACTIONS(4642),
    [anon_sym_case] = ACTIONS(4642),
    [anon_sym_CASE] = ACTIONS(4642),
    [anon_sym_Case] = ACTIONS(4642),
    [anon_sym_for] = ACTIONS(4642),
    [anon_sym_FOR] = ACTIONS(4642),
    [anon_sym_For] = ACTIONS(4642),
    [anon_sym_foreach] = ACTIONS(4642),
    [anon_sym_FOREACH] = ACTIONS(4642),
    [anon_sym_Foreach] = ACTIONS(4642),
    [anon_sym_while] = ACTIONS(4642),
    [anon_sym_WHILE] = ACTIONS(4642),
    [anon_sym_While] = ACTIONS(4642),
    [anon_sym_repeat] = ACTIONS(4642),
    [anon_sym_REPEAT] = ACTIONS(4642),
    [anon_sym_Repeat] = ACTIONS(4642),
    [anon_sym_exit] = ACTIONS(4642),
    [anon_sym_EXIT] = ACTIONS(4642),
    [anon_sym_Exit] = ACTIONS(4642),
    [anon_sym_continue] = ACTIONS(4642),
    [anon_sym_CONTINUE] = ACTIONS(4642),
    [anon_sym_Continue] = ACTIONS(4642),
    [anon_sym_break] = ACTIONS(4642),
    [anon_sym_BREAK] = ACTIONS(4642),
    [anon_sym_Break] = ACTIONS(4642),
    [anon_sym_with] = ACTIONS(4642),
    [anon_sym_WITH] = ACTIONS(4642),
    [anon_sym_With] = ACTIONS(4642),
    [sym_asserterror_keyword] = ACTIONS(4644),
    [sym_page_keyword] = ACTIONS(4642),
    [anon_sym_codeunit] = ACTIONS(4642),
    [anon_sym_CODEUNIT] = ACTIONS(4642),
    [anon_sym_Codeunit] = ACTIONS(4642),
    [anon_sym_CodeUnit] = ACTIONS(4642),
    [anon_sym_COdeunit] = ACTIONS(4642),
    [anon_sym_codeUnit] = ACTIONS(4642),
    [sym_report_keyword] = ACTIONS(4642),
    [sym_query_keyword] = ACTIONS(4642),
    [anon_sym_xmlport] = ACTIONS(4642),
    [anon_sym_XMLPORT] = ACTIONS(4642),
    [anon_sym_Xmlport] = ACTIONS(4642),
    [anon_sym_XMLport] = ACTIONS(4642),
    [anon_sym_XMLPort] = ACTIONS(4642),
    [anon_sym_XmlPort] = ACTIONS(4642),
    [anon_sym_enum] = ACTIONS(4642),
    [anon_sym_ENUM] = ACTIONS(4642),
    [anon_sym_Enum] = ACTIONS(4642),
    [anon_sym_eNUM] = ACTIONS(4642),
    [anon_sym_eNum] = ACTIONS(4642),
    [anon_sym_ENum] = ACTIONS(4642),
    [sym_quoted_identifier] = ACTIONS(4644),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4644),
    [sym_integer] = ACTIONS(4642),
    [sym_continue_as_identifier] = ACTIONS(4644),
    [sym_preproc_open] = ACTIONS(4644),
    [sym_preproc_close] = ACTIONS(4644),
  },
  [STATE(1680)] = {
    [sym_identifier] = ACTIONS(4646),
    [anon_sym_SEMI] = ACTIONS(4648),
    [anon_sym_DASH] = ACTIONS(4648),
    [aux_sym_boolean_token1] = ACTIONS(4646),
    [aux_sym_boolean_token2] = ACTIONS(4646),
    [sym_decimal] = ACTIONS(4646),
    [anon_sym_LPAREN] = ACTIONS(4648),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4646),
    [anon_sym_LBRACK] = ACTIONS(4648),
    [aux_sym_record_type_token1] = ACTIONS(4646),
    [aux_sym_basic_type_token21] = ACTIONS(4646),
    [aux_sym_basic_type_token22] = ACTIONS(4646),
    [aux_sym_basic_type_token48] = ACTIONS(4646),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4646),
    [anon_sym_POUNDif] = ACTIONS(4648),
    [anon_sym_POUNDIF] = ACTIONS(4648),
    [anon_sym_POUNDIf] = ACTIONS(4648),
    [anon_sym_not] = ACTIONS(4646),
    [anon_sym_NOT] = ACTIONS(4646),
    [anon_sym_Not] = ACTIONS(4646),
    [anon_sym_POUNDelif] = ACTIONS(4648),
    [anon_sym_POUNDELIF] = ACTIONS(4648),
    [anon_sym_POUNDElif] = ACTIONS(4648),
    [anon_sym_POUNDelse] = ACTIONS(4648),
    [anon_sym_POUNDELSE] = ACTIONS(4648),
    [anon_sym_POUNDElse] = ACTIONS(4648),
    [anon_sym_POUNDendif] = ACTIONS(4648),
    [anon_sym_POUNDENDIF] = ACTIONS(4648),
    [anon_sym_POUNDEndif] = ACTIONS(4648),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4646),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4646),
    [anon_sym_PLUS] = ACTIONS(4648),
    [sym_datetime_literal] = ACTIONS(4648),
    [sym_date_literal] = ACTIONS(4646),
    [sym_time_literal] = ACTIONS(4646),
    [sym_biginteger_literal] = ACTIONS(4648),
    [anon_sym_if] = ACTIONS(4646),
    [anon_sym_IF] = ACTIONS(4646),
    [anon_sym_If] = ACTIONS(4646),
    [anon_sym_else] = ACTIONS(4646),
    [anon_sym_ELSE] = ACTIONS(4646),
    [anon_sym_Else] = ACTIONS(4646),
    [anon_sym_case] = ACTIONS(4646),
    [anon_sym_CASE] = ACTIONS(4646),
    [anon_sym_Case] = ACTIONS(4646),
    [anon_sym_for] = ACTIONS(4646),
    [anon_sym_FOR] = ACTIONS(4646),
    [anon_sym_For] = ACTIONS(4646),
    [anon_sym_foreach] = ACTIONS(4646),
    [anon_sym_FOREACH] = ACTIONS(4646),
    [anon_sym_Foreach] = ACTIONS(4646),
    [anon_sym_while] = ACTIONS(4646),
    [anon_sym_WHILE] = ACTIONS(4646),
    [anon_sym_While] = ACTIONS(4646),
    [anon_sym_repeat] = ACTIONS(4646),
    [anon_sym_REPEAT] = ACTIONS(4646),
    [anon_sym_Repeat] = ACTIONS(4646),
    [anon_sym_exit] = ACTIONS(4646),
    [anon_sym_EXIT] = ACTIONS(4646),
    [anon_sym_Exit] = ACTIONS(4646),
    [anon_sym_continue] = ACTIONS(4646),
    [anon_sym_CONTINUE] = ACTIONS(4646),
    [anon_sym_Continue] = ACTIONS(4646),
    [anon_sym_break] = ACTIONS(4646),
    [anon_sym_BREAK] = ACTIONS(4646),
    [anon_sym_Break] = ACTIONS(4646),
    [anon_sym_with] = ACTIONS(4646),
    [anon_sym_WITH] = ACTIONS(4646),
    [anon_sym_With] = ACTIONS(4646),
    [sym_asserterror_keyword] = ACTIONS(4648),
    [sym_page_keyword] = ACTIONS(4646),
    [anon_sym_codeunit] = ACTIONS(4646),
    [anon_sym_CODEUNIT] = ACTIONS(4646),
    [anon_sym_Codeunit] = ACTIONS(4646),
    [anon_sym_CodeUnit] = ACTIONS(4646),
    [anon_sym_COdeunit] = ACTIONS(4646),
    [anon_sym_codeUnit] = ACTIONS(4646),
    [sym_report_keyword] = ACTIONS(4646),
    [sym_query_keyword] = ACTIONS(4646),
    [anon_sym_xmlport] = ACTIONS(4646),
    [anon_sym_XMLPORT] = ACTIONS(4646),
    [anon_sym_Xmlport] = ACTIONS(4646),
    [anon_sym_XMLport] = ACTIONS(4646),
    [anon_sym_XMLPort] = ACTIONS(4646),
    [anon_sym_XmlPort] = ACTIONS(4646),
    [anon_sym_enum] = ACTIONS(4646),
    [anon_sym_ENUM] = ACTIONS(4646),
    [anon_sym_Enum] = ACTIONS(4646),
    [anon_sym_eNUM] = ACTIONS(4646),
    [anon_sym_eNum] = ACTIONS(4646),
    [anon_sym_ENum] = ACTIONS(4646),
    [sym_quoted_identifier] = ACTIONS(4648),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4648),
    [sym_integer] = ACTIONS(4646),
    [sym_continue_as_identifier] = ACTIONS(4648),
    [sym_preproc_open] = ACTIONS(4648),
    [sym_preproc_close] = ACTIONS(4648),
  },
  [STATE(1681)] = {
    [sym_identifier] = ACTIONS(4650),
    [anon_sym_SEMI] = ACTIONS(4652),
    [anon_sym_DASH] = ACTIONS(4652),
    [aux_sym_boolean_token1] = ACTIONS(4650),
    [aux_sym_boolean_token2] = ACTIONS(4650),
    [sym_decimal] = ACTIONS(4650),
    [anon_sym_LPAREN] = ACTIONS(4652),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4650),
    [anon_sym_LBRACK] = ACTIONS(4652),
    [aux_sym_record_type_token1] = ACTIONS(4650),
    [aux_sym_basic_type_token21] = ACTIONS(4650),
    [aux_sym_basic_type_token22] = ACTIONS(4650),
    [aux_sym_basic_type_token48] = ACTIONS(4650),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4650),
    [anon_sym_POUNDif] = ACTIONS(4652),
    [anon_sym_POUNDIF] = ACTIONS(4652),
    [anon_sym_POUNDIf] = ACTIONS(4652),
    [anon_sym_not] = ACTIONS(4650),
    [anon_sym_NOT] = ACTIONS(4650),
    [anon_sym_Not] = ACTIONS(4650),
    [anon_sym_POUNDelif] = ACTIONS(4652),
    [anon_sym_POUNDELIF] = ACTIONS(4652),
    [anon_sym_POUNDElif] = ACTIONS(4652),
    [anon_sym_POUNDelse] = ACTIONS(4652),
    [anon_sym_POUNDELSE] = ACTIONS(4652),
    [anon_sym_POUNDElse] = ACTIONS(4652),
    [anon_sym_POUNDendif] = ACTIONS(4652),
    [anon_sym_POUNDENDIF] = ACTIONS(4652),
    [anon_sym_POUNDEndif] = ACTIONS(4652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4650),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4650),
    [anon_sym_PLUS] = ACTIONS(4652),
    [sym_datetime_literal] = ACTIONS(4652),
    [sym_date_literal] = ACTIONS(4650),
    [sym_time_literal] = ACTIONS(4650),
    [sym_biginteger_literal] = ACTIONS(4652),
    [anon_sym_if] = ACTIONS(4650),
    [anon_sym_IF] = ACTIONS(4650),
    [anon_sym_If] = ACTIONS(4650),
    [anon_sym_else] = ACTIONS(4650),
    [anon_sym_ELSE] = ACTIONS(4650),
    [anon_sym_Else] = ACTIONS(4650),
    [anon_sym_case] = ACTIONS(4650),
    [anon_sym_CASE] = ACTIONS(4650),
    [anon_sym_Case] = ACTIONS(4650),
    [anon_sym_for] = ACTIONS(4650),
    [anon_sym_FOR] = ACTIONS(4650),
    [anon_sym_For] = ACTIONS(4650),
    [anon_sym_foreach] = ACTIONS(4650),
    [anon_sym_FOREACH] = ACTIONS(4650),
    [anon_sym_Foreach] = ACTIONS(4650),
    [anon_sym_while] = ACTIONS(4650),
    [anon_sym_WHILE] = ACTIONS(4650),
    [anon_sym_While] = ACTIONS(4650),
    [anon_sym_repeat] = ACTIONS(4650),
    [anon_sym_REPEAT] = ACTIONS(4650),
    [anon_sym_Repeat] = ACTIONS(4650),
    [anon_sym_exit] = ACTIONS(4650),
    [anon_sym_EXIT] = ACTIONS(4650),
    [anon_sym_Exit] = ACTIONS(4650),
    [anon_sym_continue] = ACTIONS(4650),
    [anon_sym_CONTINUE] = ACTIONS(4650),
    [anon_sym_Continue] = ACTIONS(4650),
    [anon_sym_break] = ACTIONS(4650),
    [anon_sym_BREAK] = ACTIONS(4650),
    [anon_sym_Break] = ACTIONS(4650),
    [anon_sym_with] = ACTIONS(4650),
    [anon_sym_WITH] = ACTIONS(4650),
    [anon_sym_With] = ACTIONS(4650),
    [sym_asserterror_keyword] = ACTIONS(4652),
    [sym_page_keyword] = ACTIONS(4650),
    [anon_sym_codeunit] = ACTIONS(4650),
    [anon_sym_CODEUNIT] = ACTIONS(4650),
    [anon_sym_Codeunit] = ACTIONS(4650),
    [anon_sym_CodeUnit] = ACTIONS(4650),
    [anon_sym_COdeunit] = ACTIONS(4650),
    [anon_sym_codeUnit] = ACTIONS(4650),
    [sym_report_keyword] = ACTIONS(4650),
    [sym_query_keyword] = ACTIONS(4650),
    [anon_sym_xmlport] = ACTIONS(4650),
    [anon_sym_XMLPORT] = ACTIONS(4650),
    [anon_sym_Xmlport] = ACTIONS(4650),
    [anon_sym_XMLport] = ACTIONS(4650),
    [anon_sym_XMLPort] = ACTIONS(4650),
    [anon_sym_XmlPort] = ACTIONS(4650),
    [anon_sym_enum] = ACTIONS(4650),
    [anon_sym_ENUM] = ACTIONS(4650),
    [anon_sym_Enum] = ACTIONS(4650),
    [anon_sym_eNUM] = ACTIONS(4650),
    [anon_sym_eNum] = ACTIONS(4650),
    [anon_sym_ENum] = ACTIONS(4650),
    [sym_quoted_identifier] = ACTIONS(4652),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4652),
    [sym_integer] = ACTIONS(4650),
    [sym_continue_as_identifier] = ACTIONS(4652),
    [sym_preproc_open] = ACTIONS(4652),
    [sym_preproc_close] = ACTIONS(4652),
  },
  [STATE(1682)] = {
    [sym_identifier] = ACTIONS(4646),
    [anon_sym_SEMI] = ACTIONS(4648),
    [anon_sym_DASH] = ACTIONS(4648),
    [aux_sym_boolean_token1] = ACTIONS(4646),
    [aux_sym_boolean_token2] = ACTIONS(4646),
    [sym_decimal] = ACTIONS(4646),
    [anon_sym_LPAREN] = ACTIONS(4648),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4646),
    [anon_sym_LBRACK] = ACTIONS(4648),
    [aux_sym_record_type_token1] = ACTIONS(4646),
    [aux_sym_basic_type_token21] = ACTIONS(4646),
    [aux_sym_basic_type_token22] = ACTIONS(4646),
    [aux_sym_basic_type_token48] = ACTIONS(4646),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4646),
    [anon_sym_POUNDif] = ACTIONS(4648),
    [anon_sym_POUNDIF] = ACTIONS(4648),
    [anon_sym_POUNDIf] = ACTIONS(4648),
    [anon_sym_not] = ACTIONS(4646),
    [anon_sym_NOT] = ACTIONS(4646),
    [anon_sym_Not] = ACTIONS(4646),
    [anon_sym_POUNDelif] = ACTIONS(4648),
    [anon_sym_POUNDELIF] = ACTIONS(4648),
    [anon_sym_POUNDElif] = ACTIONS(4648),
    [anon_sym_POUNDelse] = ACTIONS(4648),
    [anon_sym_POUNDELSE] = ACTIONS(4648),
    [anon_sym_POUNDElse] = ACTIONS(4648),
    [anon_sym_POUNDendif] = ACTIONS(4648),
    [anon_sym_POUNDENDIF] = ACTIONS(4648),
    [anon_sym_POUNDEndif] = ACTIONS(4648),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4646),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4646),
    [anon_sym_PLUS] = ACTIONS(4648),
    [sym_datetime_literal] = ACTIONS(4648),
    [sym_date_literal] = ACTIONS(4646),
    [sym_time_literal] = ACTIONS(4646),
    [sym_biginteger_literal] = ACTIONS(4648),
    [anon_sym_if] = ACTIONS(4646),
    [anon_sym_IF] = ACTIONS(4646),
    [anon_sym_If] = ACTIONS(4646),
    [anon_sym_else] = ACTIONS(4646),
    [anon_sym_ELSE] = ACTIONS(4646),
    [anon_sym_Else] = ACTIONS(4646),
    [anon_sym_case] = ACTIONS(4646),
    [anon_sym_CASE] = ACTIONS(4646),
    [anon_sym_Case] = ACTIONS(4646),
    [anon_sym_for] = ACTIONS(4646),
    [anon_sym_FOR] = ACTIONS(4646),
    [anon_sym_For] = ACTIONS(4646),
    [anon_sym_foreach] = ACTIONS(4646),
    [anon_sym_FOREACH] = ACTIONS(4646),
    [anon_sym_Foreach] = ACTIONS(4646),
    [anon_sym_while] = ACTIONS(4646),
    [anon_sym_WHILE] = ACTIONS(4646),
    [anon_sym_While] = ACTIONS(4646),
    [anon_sym_repeat] = ACTIONS(4646),
    [anon_sym_REPEAT] = ACTIONS(4646),
    [anon_sym_Repeat] = ACTIONS(4646),
    [anon_sym_exit] = ACTIONS(4646),
    [anon_sym_EXIT] = ACTIONS(4646),
    [anon_sym_Exit] = ACTIONS(4646),
    [anon_sym_continue] = ACTIONS(4646),
    [anon_sym_CONTINUE] = ACTIONS(4646),
    [anon_sym_Continue] = ACTIONS(4646),
    [anon_sym_break] = ACTIONS(4646),
    [anon_sym_BREAK] = ACTIONS(4646),
    [anon_sym_Break] = ACTIONS(4646),
    [anon_sym_with] = ACTIONS(4646),
    [anon_sym_WITH] = ACTIONS(4646),
    [anon_sym_With] = ACTIONS(4646),
    [sym_asserterror_keyword] = ACTIONS(4648),
    [sym_page_keyword] = ACTIONS(4646),
    [anon_sym_codeunit] = ACTIONS(4646),
    [anon_sym_CODEUNIT] = ACTIONS(4646),
    [anon_sym_Codeunit] = ACTIONS(4646),
    [anon_sym_CodeUnit] = ACTIONS(4646),
    [anon_sym_COdeunit] = ACTIONS(4646),
    [anon_sym_codeUnit] = ACTIONS(4646),
    [sym_report_keyword] = ACTIONS(4646),
    [sym_query_keyword] = ACTIONS(4646),
    [anon_sym_xmlport] = ACTIONS(4646),
    [anon_sym_XMLPORT] = ACTIONS(4646),
    [anon_sym_Xmlport] = ACTIONS(4646),
    [anon_sym_XMLport] = ACTIONS(4646),
    [anon_sym_XMLPort] = ACTIONS(4646),
    [anon_sym_XmlPort] = ACTIONS(4646),
    [anon_sym_enum] = ACTIONS(4646),
    [anon_sym_ENUM] = ACTIONS(4646),
    [anon_sym_Enum] = ACTIONS(4646),
    [anon_sym_eNUM] = ACTIONS(4646),
    [anon_sym_eNum] = ACTIONS(4646),
    [anon_sym_ENum] = ACTIONS(4646),
    [sym_quoted_identifier] = ACTIONS(4648),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4648),
    [sym_integer] = ACTIONS(4646),
    [sym_continue_as_identifier] = ACTIONS(4648),
    [sym_preproc_open] = ACTIONS(4648),
    [sym_preproc_close] = ACTIONS(4648),
  },
  [STATE(1683)] = {
    [sym_identifier] = ACTIONS(4654),
    [anon_sym_SEMI] = ACTIONS(4656),
    [anon_sym_DASH] = ACTIONS(4656),
    [aux_sym_boolean_token1] = ACTIONS(4654),
    [aux_sym_boolean_token2] = ACTIONS(4654),
    [sym_decimal] = ACTIONS(4654),
    [anon_sym_LPAREN] = ACTIONS(4656),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4654),
    [anon_sym_LBRACK] = ACTIONS(4656),
    [aux_sym_record_type_token1] = ACTIONS(4654),
    [aux_sym_basic_type_token21] = ACTIONS(4654),
    [aux_sym_basic_type_token22] = ACTIONS(4654),
    [aux_sym_basic_type_token48] = ACTIONS(4654),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4654),
    [anon_sym_POUNDif] = ACTIONS(4656),
    [anon_sym_POUNDIF] = ACTIONS(4656),
    [anon_sym_POUNDIf] = ACTIONS(4656),
    [anon_sym_not] = ACTIONS(4654),
    [anon_sym_NOT] = ACTIONS(4654),
    [anon_sym_Not] = ACTIONS(4654),
    [anon_sym_POUNDelif] = ACTIONS(4656),
    [anon_sym_POUNDELIF] = ACTIONS(4656),
    [anon_sym_POUNDElif] = ACTIONS(4656),
    [anon_sym_POUNDelse] = ACTIONS(4656),
    [anon_sym_POUNDELSE] = ACTIONS(4656),
    [anon_sym_POUNDElse] = ACTIONS(4656),
    [anon_sym_POUNDendif] = ACTIONS(4656),
    [anon_sym_POUNDENDIF] = ACTIONS(4656),
    [anon_sym_POUNDEndif] = ACTIONS(4656),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4654),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4654),
    [anon_sym_PLUS] = ACTIONS(4656),
    [sym_datetime_literal] = ACTIONS(4656),
    [sym_date_literal] = ACTIONS(4654),
    [sym_time_literal] = ACTIONS(4654),
    [sym_biginteger_literal] = ACTIONS(4656),
    [anon_sym_if] = ACTIONS(4654),
    [anon_sym_IF] = ACTIONS(4654),
    [anon_sym_If] = ACTIONS(4654),
    [anon_sym_else] = ACTIONS(4654),
    [anon_sym_ELSE] = ACTIONS(4654),
    [anon_sym_Else] = ACTIONS(4654),
    [anon_sym_case] = ACTIONS(4654),
    [anon_sym_CASE] = ACTIONS(4654),
    [anon_sym_Case] = ACTIONS(4654),
    [anon_sym_for] = ACTIONS(4654),
    [anon_sym_FOR] = ACTIONS(4654),
    [anon_sym_For] = ACTIONS(4654),
    [anon_sym_foreach] = ACTIONS(4654),
    [anon_sym_FOREACH] = ACTIONS(4654),
    [anon_sym_Foreach] = ACTIONS(4654),
    [anon_sym_while] = ACTIONS(4654),
    [anon_sym_WHILE] = ACTIONS(4654),
    [anon_sym_While] = ACTIONS(4654),
    [anon_sym_repeat] = ACTIONS(4654),
    [anon_sym_REPEAT] = ACTIONS(4654),
    [anon_sym_Repeat] = ACTIONS(4654),
    [anon_sym_exit] = ACTIONS(4654),
    [anon_sym_EXIT] = ACTIONS(4654),
    [anon_sym_Exit] = ACTIONS(4654),
    [anon_sym_continue] = ACTIONS(4654),
    [anon_sym_CONTINUE] = ACTIONS(4654),
    [anon_sym_Continue] = ACTIONS(4654),
    [anon_sym_break] = ACTIONS(4654),
    [anon_sym_BREAK] = ACTIONS(4654),
    [anon_sym_Break] = ACTIONS(4654),
    [anon_sym_with] = ACTIONS(4654),
    [anon_sym_WITH] = ACTIONS(4654),
    [anon_sym_With] = ACTIONS(4654),
    [sym_asserterror_keyword] = ACTIONS(4656),
    [sym_page_keyword] = ACTIONS(4654),
    [anon_sym_codeunit] = ACTIONS(4654),
    [anon_sym_CODEUNIT] = ACTIONS(4654),
    [anon_sym_Codeunit] = ACTIONS(4654),
    [anon_sym_CodeUnit] = ACTIONS(4654),
    [anon_sym_COdeunit] = ACTIONS(4654),
    [anon_sym_codeUnit] = ACTIONS(4654),
    [sym_report_keyword] = ACTIONS(4654),
    [sym_query_keyword] = ACTIONS(4654),
    [anon_sym_xmlport] = ACTIONS(4654),
    [anon_sym_XMLPORT] = ACTIONS(4654),
    [anon_sym_Xmlport] = ACTIONS(4654),
    [anon_sym_XMLport] = ACTIONS(4654),
    [anon_sym_XMLPort] = ACTIONS(4654),
    [anon_sym_XmlPort] = ACTIONS(4654),
    [anon_sym_enum] = ACTIONS(4654),
    [anon_sym_ENUM] = ACTIONS(4654),
    [anon_sym_Enum] = ACTIONS(4654),
    [anon_sym_eNUM] = ACTIONS(4654),
    [anon_sym_eNum] = ACTIONS(4654),
    [anon_sym_ENum] = ACTIONS(4654),
    [sym_quoted_identifier] = ACTIONS(4656),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4656),
    [sym_integer] = ACTIONS(4654),
    [sym_continue_as_identifier] = ACTIONS(4656),
    [sym_preproc_open] = ACTIONS(4656),
    [sym_preproc_close] = ACTIONS(4656),
  },
  [STATE(1684)] = {
    [sym_argument_list] = STATE(1432),
    [sym_identifier] = ACTIONS(4658),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_COMMA] = ACTIONS(4660),
    [anon_sym_COLON] = ACTIONS(4658),
    [anon_sym_DASH] = ACTIONS(4662),
    [aux_sym_boolean_token1] = ACTIONS(4658),
    [aux_sym_boolean_token2] = ACTIONS(4658),
    [sym_decimal] = ACTIONS(4658),
    [anon_sym_LPAREN] = ACTIONS(3760),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4658),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(4665),
    [aux_sym_record_type_token1] = ACTIONS(4658),
    [aux_sym_basic_type_token21] = ACTIONS(4658),
    [aux_sym_basic_type_token22] = ACTIONS(4658),
    [aux_sym_basic_type_token48] = ACTIONS(4658),
    [anon_sym_COLON_COLON] = ACTIONS(3762),
    [anon_sym_POUNDif] = ACTIONS(4660),
    [anon_sym_POUNDIF] = ACTIONS(4660),
    [anon_sym_POUNDIf] = ACTIONS(4660),
    [anon_sym_not] = ACTIONS(4658),
    [anon_sym_NOT] = ACTIONS(4658),
    [anon_sym_Not] = ACTIONS(4658),
    [anon_sym_POUNDelif] = ACTIONS(4660),
    [anon_sym_POUNDELIF] = ACTIONS(4660),
    [anon_sym_POUNDElif] = ACTIONS(4660),
    [anon_sym_POUNDelse] = ACTIONS(4660),
    [anon_sym_POUNDELSE] = ACTIONS(4660),
    [anon_sym_POUNDElse] = ACTIONS(4660),
    [anon_sym_POUNDendif] = ACTIONS(4660),
    [anon_sym_POUNDENDIF] = ACTIONS(4660),
    [anon_sym_POUNDEndif] = ACTIONS(4660),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4658),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4658),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(4662),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(4660),
    [sym_date_literal] = ACTIONS(4658),
    [sym_time_literal] = ACTIONS(4658),
    [sym_biginteger_literal] = ACTIONS(4660),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(4658),
    [anon_sym_codeunit] = ACTIONS(4658),
    [anon_sym_CODEUNIT] = ACTIONS(4658),
    [anon_sym_Codeunit] = ACTIONS(4658),
    [anon_sym_CodeUnit] = ACTIONS(4658),
    [anon_sym_COdeunit] = ACTIONS(4658),
    [anon_sym_codeUnit] = ACTIONS(4658),
    [sym_report_keyword] = ACTIONS(4658),
    [sym_query_keyword] = ACTIONS(4658),
    [anon_sym_xmlport] = ACTIONS(4658),
    [anon_sym_XMLPORT] = ACTIONS(4658),
    [anon_sym_Xmlport] = ACTIONS(4658),
    [anon_sym_XMLport] = ACTIONS(4658),
    [anon_sym_XMLPort] = ACTIONS(4658),
    [anon_sym_XmlPort] = ACTIONS(4658),
    [anon_sym_enum] = ACTIONS(4658),
    [anon_sym_ENUM] = ACTIONS(4658),
    [anon_sym_Enum] = ACTIONS(4658),
    [anon_sym_eNUM] = ACTIONS(4658),
    [anon_sym_eNum] = ACTIONS(4658),
    [anon_sym_ENum] = ACTIONS(4658),
    [sym_quoted_identifier] = ACTIONS(4660),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4660),
    [sym_integer] = ACTIONS(4658),
    [sym_continue_as_identifier] = ACTIONS(4660),
    [sym_preproc_open] = ACTIONS(4660),
    [sym_preproc_close] = ACTIONS(4660),
  },
  [STATE(1685)] = {
    [sym_identifier] = ACTIONS(4668),
    [anon_sym_SEMI] = ACTIONS(4670),
    [anon_sym_DASH] = ACTIONS(4670),
    [aux_sym_boolean_token1] = ACTIONS(4668),
    [aux_sym_boolean_token2] = ACTIONS(4668),
    [sym_decimal] = ACTIONS(4668),
    [anon_sym_LPAREN] = ACTIONS(4670),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4668),
    [anon_sym_LBRACK] = ACTIONS(4670),
    [aux_sym_record_type_token1] = ACTIONS(4668),
    [aux_sym_basic_type_token21] = ACTIONS(4668),
    [aux_sym_basic_type_token22] = ACTIONS(4668),
    [aux_sym_basic_type_token48] = ACTIONS(4668),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4668),
    [anon_sym_POUNDif] = ACTIONS(4670),
    [anon_sym_POUNDIF] = ACTIONS(4670),
    [anon_sym_POUNDIf] = ACTIONS(4670),
    [anon_sym_not] = ACTIONS(4668),
    [anon_sym_NOT] = ACTIONS(4668),
    [anon_sym_Not] = ACTIONS(4668),
    [anon_sym_POUNDelif] = ACTIONS(4670),
    [anon_sym_POUNDELIF] = ACTIONS(4670),
    [anon_sym_POUNDElif] = ACTIONS(4670),
    [anon_sym_POUNDelse] = ACTIONS(4670),
    [anon_sym_POUNDELSE] = ACTIONS(4670),
    [anon_sym_POUNDElse] = ACTIONS(4670),
    [anon_sym_POUNDendif] = ACTIONS(4670),
    [anon_sym_POUNDENDIF] = ACTIONS(4670),
    [anon_sym_POUNDEndif] = ACTIONS(4670),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4668),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4668),
    [anon_sym_PLUS] = ACTIONS(4670),
    [sym_datetime_literal] = ACTIONS(4670),
    [sym_date_literal] = ACTIONS(4668),
    [sym_time_literal] = ACTIONS(4668),
    [sym_biginteger_literal] = ACTIONS(4670),
    [anon_sym_if] = ACTIONS(4668),
    [anon_sym_IF] = ACTIONS(4668),
    [anon_sym_If] = ACTIONS(4668),
    [anon_sym_else] = ACTIONS(4668),
    [anon_sym_ELSE] = ACTIONS(4668),
    [anon_sym_Else] = ACTIONS(4668),
    [anon_sym_case] = ACTIONS(4668),
    [anon_sym_CASE] = ACTIONS(4668),
    [anon_sym_Case] = ACTIONS(4668),
    [anon_sym_for] = ACTIONS(4668),
    [anon_sym_FOR] = ACTIONS(4668),
    [anon_sym_For] = ACTIONS(4668),
    [anon_sym_foreach] = ACTIONS(4668),
    [anon_sym_FOREACH] = ACTIONS(4668),
    [anon_sym_Foreach] = ACTIONS(4668),
    [anon_sym_while] = ACTIONS(4668),
    [anon_sym_WHILE] = ACTIONS(4668),
    [anon_sym_While] = ACTIONS(4668),
    [anon_sym_repeat] = ACTIONS(4668),
    [anon_sym_REPEAT] = ACTIONS(4668),
    [anon_sym_Repeat] = ACTIONS(4668),
    [anon_sym_exit] = ACTIONS(4668),
    [anon_sym_EXIT] = ACTIONS(4668),
    [anon_sym_Exit] = ACTIONS(4668),
    [anon_sym_continue] = ACTIONS(4668),
    [anon_sym_CONTINUE] = ACTIONS(4668),
    [anon_sym_Continue] = ACTIONS(4668),
    [anon_sym_break] = ACTIONS(4668),
    [anon_sym_BREAK] = ACTIONS(4668),
    [anon_sym_Break] = ACTIONS(4668),
    [anon_sym_with] = ACTIONS(4668),
    [anon_sym_WITH] = ACTIONS(4668),
    [anon_sym_With] = ACTIONS(4668),
    [sym_asserterror_keyword] = ACTIONS(4670),
    [sym_page_keyword] = ACTIONS(4668),
    [anon_sym_codeunit] = ACTIONS(4668),
    [anon_sym_CODEUNIT] = ACTIONS(4668),
    [anon_sym_Codeunit] = ACTIONS(4668),
    [anon_sym_CodeUnit] = ACTIONS(4668),
    [anon_sym_COdeunit] = ACTIONS(4668),
    [anon_sym_codeUnit] = ACTIONS(4668),
    [sym_report_keyword] = ACTIONS(4668),
    [sym_query_keyword] = ACTIONS(4668),
    [anon_sym_xmlport] = ACTIONS(4668),
    [anon_sym_XMLPORT] = ACTIONS(4668),
    [anon_sym_Xmlport] = ACTIONS(4668),
    [anon_sym_XMLport] = ACTIONS(4668),
    [anon_sym_XMLPort] = ACTIONS(4668),
    [anon_sym_XmlPort] = ACTIONS(4668),
    [anon_sym_enum] = ACTIONS(4668),
    [anon_sym_ENUM] = ACTIONS(4668),
    [anon_sym_Enum] = ACTIONS(4668),
    [anon_sym_eNUM] = ACTIONS(4668),
    [anon_sym_eNum] = ACTIONS(4668),
    [anon_sym_ENum] = ACTIONS(4668),
    [sym_quoted_identifier] = ACTIONS(4670),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4670),
    [sym_integer] = ACTIONS(4668),
    [sym_continue_as_identifier] = ACTIONS(4670),
    [sym_preproc_open] = ACTIONS(4670),
    [sym_preproc_close] = ACTIONS(4670),
  },
  [STATE(1686)] = {
    [sym_identifier] = ACTIONS(4672),
    [anon_sym_SEMI] = ACTIONS(4674),
    [anon_sym_DASH] = ACTIONS(4674),
    [aux_sym_boolean_token1] = ACTIONS(4672),
    [aux_sym_boolean_token2] = ACTIONS(4672),
    [sym_decimal] = ACTIONS(4672),
    [anon_sym_LPAREN] = ACTIONS(4674),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4672),
    [anon_sym_LBRACK] = ACTIONS(4674),
    [aux_sym_record_type_token1] = ACTIONS(4672),
    [aux_sym_basic_type_token21] = ACTIONS(4672),
    [aux_sym_basic_type_token22] = ACTIONS(4672),
    [aux_sym_basic_type_token48] = ACTIONS(4672),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4672),
    [anon_sym_POUNDif] = ACTIONS(4674),
    [anon_sym_POUNDIF] = ACTIONS(4674),
    [anon_sym_POUNDIf] = ACTIONS(4674),
    [anon_sym_not] = ACTIONS(4672),
    [anon_sym_NOT] = ACTIONS(4672),
    [anon_sym_Not] = ACTIONS(4672),
    [anon_sym_POUNDelif] = ACTIONS(4674),
    [anon_sym_POUNDELIF] = ACTIONS(4674),
    [anon_sym_POUNDElif] = ACTIONS(4674),
    [anon_sym_POUNDelse] = ACTIONS(4674),
    [anon_sym_POUNDELSE] = ACTIONS(4674),
    [anon_sym_POUNDElse] = ACTIONS(4674),
    [anon_sym_POUNDendif] = ACTIONS(4674),
    [anon_sym_POUNDENDIF] = ACTIONS(4674),
    [anon_sym_POUNDEndif] = ACTIONS(4674),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4672),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4672),
    [anon_sym_PLUS] = ACTIONS(4674),
    [sym_datetime_literal] = ACTIONS(4674),
    [sym_date_literal] = ACTIONS(4672),
    [sym_time_literal] = ACTIONS(4672),
    [sym_biginteger_literal] = ACTIONS(4674),
    [anon_sym_if] = ACTIONS(4672),
    [anon_sym_IF] = ACTIONS(4672),
    [anon_sym_If] = ACTIONS(4672),
    [anon_sym_else] = ACTIONS(4672),
    [anon_sym_ELSE] = ACTIONS(4672),
    [anon_sym_Else] = ACTIONS(4672),
    [anon_sym_case] = ACTIONS(4672),
    [anon_sym_CASE] = ACTIONS(4672),
    [anon_sym_Case] = ACTIONS(4672),
    [anon_sym_for] = ACTIONS(4672),
    [anon_sym_FOR] = ACTIONS(4672),
    [anon_sym_For] = ACTIONS(4672),
    [anon_sym_foreach] = ACTIONS(4672),
    [anon_sym_FOREACH] = ACTIONS(4672),
    [anon_sym_Foreach] = ACTIONS(4672),
    [anon_sym_while] = ACTIONS(4672),
    [anon_sym_WHILE] = ACTIONS(4672),
    [anon_sym_While] = ACTIONS(4672),
    [anon_sym_repeat] = ACTIONS(4672),
    [anon_sym_REPEAT] = ACTIONS(4672),
    [anon_sym_Repeat] = ACTIONS(4672),
    [anon_sym_exit] = ACTIONS(4672),
    [anon_sym_EXIT] = ACTIONS(4672),
    [anon_sym_Exit] = ACTIONS(4672),
    [anon_sym_continue] = ACTIONS(4672),
    [anon_sym_CONTINUE] = ACTIONS(4672),
    [anon_sym_Continue] = ACTIONS(4672),
    [anon_sym_break] = ACTIONS(4672),
    [anon_sym_BREAK] = ACTIONS(4672),
    [anon_sym_Break] = ACTIONS(4672),
    [anon_sym_with] = ACTIONS(4672),
    [anon_sym_WITH] = ACTIONS(4672),
    [anon_sym_With] = ACTIONS(4672),
    [sym_asserterror_keyword] = ACTIONS(4674),
    [sym_page_keyword] = ACTIONS(4672),
    [anon_sym_codeunit] = ACTIONS(4672),
    [anon_sym_CODEUNIT] = ACTIONS(4672),
    [anon_sym_Codeunit] = ACTIONS(4672),
    [anon_sym_CodeUnit] = ACTIONS(4672),
    [anon_sym_COdeunit] = ACTIONS(4672),
    [anon_sym_codeUnit] = ACTIONS(4672),
    [sym_report_keyword] = ACTIONS(4672),
    [sym_query_keyword] = ACTIONS(4672),
    [anon_sym_xmlport] = ACTIONS(4672),
    [anon_sym_XMLPORT] = ACTIONS(4672),
    [anon_sym_Xmlport] = ACTIONS(4672),
    [anon_sym_XMLport] = ACTIONS(4672),
    [anon_sym_XMLPort] = ACTIONS(4672),
    [anon_sym_XmlPort] = ACTIONS(4672),
    [anon_sym_enum] = ACTIONS(4672),
    [anon_sym_ENUM] = ACTIONS(4672),
    [anon_sym_Enum] = ACTIONS(4672),
    [anon_sym_eNUM] = ACTIONS(4672),
    [anon_sym_eNum] = ACTIONS(4672),
    [anon_sym_ENum] = ACTIONS(4672),
    [sym_quoted_identifier] = ACTIONS(4674),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4674),
    [sym_integer] = ACTIONS(4672),
    [sym_continue_as_identifier] = ACTIONS(4674),
    [sym_preproc_open] = ACTIONS(4674),
    [sym_preproc_close] = ACTIONS(4674),
  },
  [STATE(1687)] = {
    [sym_identifier] = ACTIONS(4676),
    [anon_sym_SEMI] = ACTIONS(4678),
    [anon_sym_DASH] = ACTIONS(4678),
    [aux_sym_boolean_token1] = ACTIONS(4676),
    [aux_sym_boolean_token2] = ACTIONS(4676),
    [sym_decimal] = ACTIONS(4676),
    [anon_sym_LPAREN] = ACTIONS(4678),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4676),
    [anon_sym_LBRACK] = ACTIONS(4678),
    [aux_sym_record_type_token1] = ACTIONS(4676),
    [aux_sym_basic_type_token21] = ACTIONS(4676),
    [aux_sym_basic_type_token22] = ACTIONS(4676),
    [aux_sym_basic_type_token48] = ACTIONS(4676),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4676),
    [anon_sym_POUNDif] = ACTIONS(4678),
    [anon_sym_POUNDIF] = ACTIONS(4678),
    [anon_sym_POUNDIf] = ACTIONS(4678),
    [anon_sym_not] = ACTIONS(4676),
    [anon_sym_NOT] = ACTIONS(4676),
    [anon_sym_Not] = ACTIONS(4676),
    [anon_sym_POUNDelif] = ACTIONS(4678),
    [anon_sym_POUNDELIF] = ACTIONS(4678),
    [anon_sym_POUNDElif] = ACTIONS(4678),
    [anon_sym_POUNDelse] = ACTIONS(4678),
    [anon_sym_POUNDELSE] = ACTIONS(4678),
    [anon_sym_POUNDElse] = ACTIONS(4678),
    [anon_sym_POUNDendif] = ACTIONS(4678),
    [anon_sym_POUNDENDIF] = ACTIONS(4678),
    [anon_sym_POUNDEndif] = ACTIONS(4678),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4676),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4676),
    [anon_sym_PLUS] = ACTIONS(4678),
    [sym_datetime_literal] = ACTIONS(4678),
    [sym_date_literal] = ACTIONS(4676),
    [sym_time_literal] = ACTIONS(4676),
    [sym_biginteger_literal] = ACTIONS(4678),
    [anon_sym_if] = ACTIONS(4676),
    [anon_sym_IF] = ACTIONS(4676),
    [anon_sym_If] = ACTIONS(4676),
    [anon_sym_else] = ACTIONS(4676),
    [anon_sym_ELSE] = ACTIONS(4676),
    [anon_sym_Else] = ACTIONS(4676),
    [anon_sym_case] = ACTIONS(4676),
    [anon_sym_CASE] = ACTIONS(4676),
    [anon_sym_Case] = ACTIONS(4676),
    [anon_sym_for] = ACTIONS(4676),
    [anon_sym_FOR] = ACTIONS(4676),
    [anon_sym_For] = ACTIONS(4676),
    [anon_sym_foreach] = ACTIONS(4676),
    [anon_sym_FOREACH] = ACTIONS(4676),
    [anon_sym_Foreach] = ACTIONS(4676),
    [anon_sym_while] = ACTIONS(4676),
    [anon_sym_WHILE] = ACTIONS(4676),
    [anon_sym_While] = ACTIONS(4676),
    [anon_sym_repeat] = ACTIONS(4676),
    [anon_sym_REPEAT] = ACTIONS(4676),
    [anon_sym_Repeat] = ACTIONS(4676),
    [anon_sym_exit] = ACTIONS(4676),
    [anon_sym_EXIT] = ACTIONS(4676),
    [anon_sym_Exit] = ACTIONS(4676),
    [anon_sym_continue] = ACTIONS(4676),
    [anon_sym_CONTINUE] = ACTIONS(4676),
    [anon_sym_Continue] = ACTIONS(4676),
    [anon_sym_break] = ACTIONS(4676),
    [anon_sym_BREAK] = ACTIONS(4676),
    [anon_sym_Break] = ACTIONS(4676),
    [anon_sym_with] = ACTIONS(4676),
    [anon_sym_WITH] = ACTIONS(4676),
    [anon_sym_With] = ACTIONS(4676),
    [sym_asserterror_keyword] = ACTIONS(4678),
    [sym_page_keyword] = ACTIONS(4676),
    [anon_sym_codeunit] = ACTIONS(4676),
    [anon_sym_CODEUNIT] = ACTIONS(4676),
    [anon_sym_Codeunit] = ACTIONS(4676),
    [anon_sym_CodeUnit] = ACTIONS(4676),
    [anon_sym_COdeunit] = ACTIONS(4676),
    [anon_sym_codeUnit] = ACTIONS(4676),
    [sym_report_keyword] = ACTIONS(4676),
    [sym_query_keyword] = ACTIONS(4676),
    [anon_sym_xmlport] = ACTIONS(4676),
    [anon_sym_XMLPORT] = ACTIONS(4676),
    [anon_sym_Xmlport] = ACTIONS(4676),
    [anon_sym_XMLport] = ACTIONS(4676),
    [anon_sym_XMLPort] = ACTIONS(4676),
    [anon_sym_XmlPort] = ACTIONS(4676),
    [anon_sym_enum] = ACTIONS(4676),
    [anon_sym_ENUM] = ACTIONS(4676),
    [anon_sym_Enum] = ACTIONS(4676),
    [anon_sym_eNUM] = ACTIONS(4676),
    [anon_sym_eNum] = ACTIONS(4676),
    [anon_sym_ENum] = ACTIONS(4676),
    [sym_quoted_identifier] = ACTIONS(4678),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4678),
    [sym_integer] = ACTIONS(4676),
    [sym_continue_as_identifier] = ACTIONS(4678),
    [sym_preproc_open] = ACTIONS(4678),
    [sym_preproc_close] = ACTIONS(4678),
  },
  [STATE(1688)] = {
    [sym_identifier] = ACTIONS(4680),
    [anon_sym_SEMI] = ACTIONS(4682),
    [anon_sym_DASH] = ACTIONS(4682),
    [aux_sym_boolean_token1] = ACTIONS(4680),
    [aux_sym_boolean_token2] = ACTIONS(4680),
    [sym_decimal] = ACTIONS(4680),
    [anon_sym_LPAREN] = ACTIONS(4682),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4680),
    [anon_sym_LBRACK] = ACTIONS(4682),
    [aux_sym_record_type_token1] = ACTIONS(4680),
    [aux_sym_basic_type_token21] = ACTIONS(4680),
    [aux_sym_basic_type_token22] = ACTIONS(4680),
    [aux_sym_basic_type_token48] = ACTIONS(4680),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4680),
    [anon_sym_POUNDif] = ACTIONS(4682),
    [anon_sym_POUNDIF] = ACTIONS(4682),
    [anon_sym_POUNDIf] = ACTIONS(4682),
    [anon_sym_not] = ACTIONS(4680),
    [anon_sym_NOT] = ACTIONS(4680),
    [anon_sym_Not] = ACTIONS(4680),
    [anon_sym_POUNDelif] = ACTIONS(4682),
    [anon_sym_POUNDELIF] = ACTIONS(4682),
    [anon_sym_POUNDElif] = ACTIONS(4682),
    [anon_sym_POUNDelse] = ACTIONS(4682),
    [anon_sym_POUNDELSE] = ACTIONS(4682),
    [anon_sym_POUNDElse] = ACTIONS(4682),
    [anon_sym_POUNDendif] = ACTIONS(4682),
    [anon_sym_POUNDENDIF] = ACTIONS(4682),
    [anon_sym_POUNDEndif] = ACTIONS(4682),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4680),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4680),
    [anon_sym_PLUS] = ACTIONS(4682),
    [sym_datetime_literal] = ACTIONS(4682),
    [sym_date_literal] = ACTIONS(4680),
    [sym_time_literal] = ACTIONS(4680),
    [sym_biginteger_literal] = ACTIONS(4682),
    [anon_sym_if] = ACTIONS(4680),
    [anon_sym_IF] = ACTIONS(4680),
    [anon_sym_If] = ACTIONS(4680),
    [anon_sym_else] = ACTIONS(4680),
    [anon_sym_ELSE] = ACTIONS(4680),
    [anon_sym_Else] = ACTIONS(4680),
    [anon_sym_case] = ACTIONS(4680),
    [anon_sym_CASE] = ACTIONS(4680),
    [anon_sym_Case] = ACTIONS(4680),
    [anon_sym_for] = ACTIONS(4680),
    [anon_sym_FOR] = ACTIONS(4680),
    [anon_sym_For] = ACTIONS(4680),
    [anon_sym_foreach] = ACTIONS(4680),
    [anon_sym_FOREACH] = ACTIONS(4680),
    [anon_sym_Foreach] = ACTIONS(4680),
    [anon_sym_while] = ACTIONS(4680),
    [anon_sym_WHILE] = ACTIONS(4680),
    [anon_sym_While] = ACTIONS(4680),
    [anon_sym_repeat] = ACTIONS(4680),
    [anon_sym_REPEAT] = ACTIONS(4680),
    [anon_sym_Repeat] = ACTIONS(4680),
    [anon_sym_exit] = ACTIONS(4680),
    [anon_sym_EXIT] = ACTIONS(4680),
    [anon_sym_Exit] = ACTIONS(4680),
    [anon_sym_continue] = ACTIONS(4680),
    [anon_sym_CONTINUE] = ACTIONS(4680),
    [anon_sym_Continue] = ACTIONS(4680),
    [anon_sym_break] = ACTIONS(4680),
    [anon_sym_BREAK] = ACTIONS(4680),
    [anon_sym_Break] = ACTIONS(4680),
    [anon_sym_with] = ACTIONS(4680),
    [anon_sym_WITH] = ACTIONS(4680),
    [anon_sym_With] = ACTIONS(4680),
    [sym_asserterror_keyword] = ACTIONS(4682),
    [sym_page_keyword] = ACTIONS(4680),
    [anon_sym_codeunit] = ACTIONS(4680),
    [anon_sym_CODEUNIT] = ACTIONS(4680),
    [anon_sym_Codeunit] = ACTIONS(4680),
    [anon_sym_CodeUnit] = ACTIONS(4680),
    [anon_sym_COdeunit] = ACTIONS(4680),
    [anon_sym_codeUnit] = ACTIONS(4680),
    [sym_report_keyword] = ACTIONS(4680),
    [sym_query_keyword] = ACTIONS(4680),
    [anon_sym_xmlport] = ACTIONS(4680),
    [anon_sym_XMLPORT] = ACTIONS(4680),
    [anon_sym_Xmlport] = ACTIONS(4680),
    [anon_sym_XMLport] = ACTIONS(4680),
    [anon_sym_XMLPort] = ACTIONS(4680),
    [anon_sym_XmlPort] = ACTIONS(4680),
    [anon_sym_enum] = ACTIONS(4680),
    [anon_sym_ENUM] = ACTIONS(4680),
    [anon_sym_Enum] = ACTIONS(4680),
    [anon_sym_eNUM] = ACTIONS(4680),
    [anon_sym_eNum] = ACTIONS(4680),
    [anon_sym_ENum] = ACTIONS(4680),
    [sym_quoted_identifier] = ACTIONS(4682),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4682),
    [sym_integer] = ACTIONS(4680),
    [sym_continue_as_identifier] = ACTIONS(4682),
    [sym_preproc_open] = ACTIONS(4682),
    [sym_preproc_close] = ACTIONS(4682),
  },
  [STATE(1689)] = {
    [sym_identifier] = ACTIONS(4684),
    [anon_sym_SEMI] = ACTIONS(4686),
    [anon_sym_DASH] = ACTIONS(4686),
    [aux_sym_boolean_token1] = ACTIONS(4684),
    [aux_sym_boolean_token2] = ACTIONS(4684),
    [sym_decimal] = ACTIONS(4684),
    [anon_sym_LPAREN] = ACTIONS(4686),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4686),
    [aux_sym_record_type_token1] = ACTIONS(4684),
    [aux_sym_basic_type_token21] = ACTIONS(4684),
    [aux_sym_basic_type_token22] = ACTIONS(4684),
    [aux_sym_basic_type_token48] = ACTIONS(4684),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4684),
    [anon_sym_POUNDif] = ACTIONS(4686),
    [anon_sym_POUNDIF] = ACTIONS(4686),
    [anon_sym_POUNDIf] = ACTIONS(4686),
    [anon_sym_not] = ACTIONS(4684),
    [anon_sym_NOT] = ACTIONS(4684),
    [anon_sym_Not] = ACTIONS(4684),
    [anon_sym_POUNDelif] = ACTIONS(4686),
    [anon_sym_POUNDELIF] = ACTIONS(4686),
    [anon_sym_POUNDElif] = ACTIONS(4686),
    [anon_sym_POUNDelse] = ACTIONS(4686),
    [anon_sym_POUNDELSE] = ACTIONS(4686),
    [anon_sym_POUNDElse] = ACTIONS(4686),
    [anon_sym_POUNDendif] = ACTIONS(4686),
    [anon_sym_POUNDENDIF] = ACTIONS(4686),
    [anon_sym_POUNDEndif] = ACTIONS(4686),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4684),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4684),
    [anon_sym_PLUS] = ACTIONS(4686),
    [sym_datetime_literal] = ACTIONS(4686),
    [sym_date_literal] = ACTIONS(4684),
    [sym_time_literal] = ACTIONS(4684),
    [sym_biginteger_literal] = ACTIONS(4686),
    [anon_sym_if] = ACTIONS(4684),
    [anon_sym_IF] = ACTIONS(4684),
    [anon_sym_If] = ACTIONS(4684),
    [anon_sym_else] = ACTIONS(4684),
    [anon_sym_ELSE] = ACTIONS(4684),
    [anon_sym_Else] = ACTIONS(4684),
    [anon_sym_case] = ACTIONS(4684),
    [anon_sym_CASE] = ACTIONS(4684),
    [anon_sym_Case] = ACTIONS(4684),
    [anon_sym_for] = ACTIONS(4684),
    [anon_sym_FOR] = ACTIONS(4684),
    [anon_sym_For] = ACTIONS(4684),
    [anon_sym_foreach] = ACTIONS(4684),
    [anon_sym_FOREACH] = ACTIONS(4684),
    [anon_sym_Foreach] = ACTIONS(4684),
    [anon_sym_while] = ACTIONS(4684),
    [anon_sym_WHILE] = ACTIONS(4684),
    [anon_sym_While] = ACTIONS(4684),
    [anon_sym_repeat] = ACTIONS(4684),
    [anon_sym_REPEAT] = ACTIONS(4684),
    [anon_sym_Repeat] = ACTIONS(4684),
    [anon_sym_exit] = ACTIONS(4684),
    [anon_sym_EXIT] = ACTIONS(4684),
    [anon_sym_Exit] = ACTIONS(4684),
    [anon_sym_continue] = ACTIONS(4684),
    [anon_sym_CONTINUE] = ACTIONS(4684),
    [anon_sym_Continue] = ACTIONS(4684),
    [anon_sym_break] = ACTIONS(4684),
    [anon_sym_BREAK] = ACTIONS(4684),
    [anon_sym_Break] = ACTIONS(4684),
    [anon_sym_with] = ACTIONS(4684),
    [anon_sym_WITH] = ACTIONS(4684),
    [anon_sym_With] = ACTIONS(4684),
    [sym_asserterror_keyword] = ACTIONS(4686),
    [sym_page_keyword] = ACTIONS(4684),
    [anon_sym_codeunit] = ACTIONS(4684),
    [anon_sym_CODEUNIT] = ACTIONS(4684),
    [anon_sym_Codeunit] = ACTIONS(4684),
    [anon_sym_CodeUnit] = ACTIONS(4684),
    [anon_sym_COdeunit] = ACTIONS(4684),
    [anon_sym_codeUnit] = ACTIONS(4684),
    [sym_report_keyword] = ACTIONS(4684),
    [sym_query_keyword] = ACTIONS(4684),
    [anon_sym_xmlport] = ACTIONS(4684),
    [anon_sym_XMLPORT] = ACTIONS(4684),
    [anon_sym_Xmlport] = ACTIONS(4684),
    [anon_sym_XMLport] = ACTIONS(4684),
    [anon_sym_XMLPort] = ACTIONS(4684),
    [anon_sym_XmlPort] = ACTIONS(4684),
    [anon_sym_enum] = ACTIONS(4684),
    [anon_sym_ENUM] = ACTIONS(4684),
    [anon_sym_Enum] = ACTIONS(4684),
    [anon_sym_eNUM] = ACTIONS(4684),
    [anon_sym_eNum] = ACTIONS(4684),
    [anon_sym_ENum] = ACTIONS(4684),
    [sym_quoted_identifier] = ACTIONS(4686),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4686),
    [sym_integer] = ACTIONS(4684),
    [sym_continue_as_identifier] = ACTIONS(4686),
    [sym_preproc_open] = ACTIONS(4686),
    [sym_preproc_close] = ACTIONS(4686),
  },
  [STATE(1690)] = {
    [sym_identifier] = ACTIONS(4688),
    [anon_sym_SEMI] = ACTIONS(4690),
    [anon_sym_DASH] = ACTIONS(4690),
    [aux_sym_boolean_token1] = ACTIONS(4688),
    [aux_sym_boolean_token2] = ACTIONS(4688),
    [sym_decimal] = ACTIONS(4688),
    [anon_sym_LPAREN] = ACTIONS(4690),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4688),
    [anon_sym_LBRACK] = ACTIONS(4690),
    [aux_sym_record_type_token1] = ACTIONS(4688),
    [aux_sym_basic_type_token21] = ACTIONS(4688),
    [aux_sym_basic_type_token22] = ACTIONS(4688),
    [aux_sym_basic_type_token48] = ACTIONS(4688),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4688),
    [anon_sym_POUNDif] = ACTIONS(4690),
    [anon_sym_POUNDIF] = ACTIONS(4690),
    [anon_sym_POUNDIf] = ACTIONS(4690),
    [anon_sym_not] = ACTIONS(4688),
    [anon_sym_NOT] = ACTIONS(4688),
    [anon_sym_Not] = ACTIONS(4688),
    [anon_sym_POUNDelif] = ACTIONS(4690),
    [anon_sym_POUNDELIF] = ACTIONS(4690),
    [anon_sym_POUNDElif] = ACTIONS(4690),
    [anon_sym_POUNDelse] = ACTIONS(4690),
    [anon_sym_POUNDELSE] = ACTIONS(4690),
    [anon_sym_POUNDElse] = ACTIONS(4690),
    [anon_sym_POUNDendif] = ACTIONS(4690),
    [anon_sym_POUNDENDIF] = ACTIONS(4690),
    [anon_sym_POUNDEndif] = ACTIONS(4690),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4688),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4688),
    [anon_sym_PLUS] = ACTIONS(4690),
    [sym_datetime_literal] = ACTIONS(4690),
    [sym_date_literal] = ACTIONS(4688),
    [sym_time_literal] = ACTIONS(4688),
    [sym_biginteger_literal] = ACTIONS(4690),
    [anon_sym_if] = ACTIONS(4688),
    [anon_sym_IF] = ACTIONS(4688),
    [anon_sym_If] = ACTIONS(4688),
    [anon_sym_else] = ACTIONS(4688),
    [anon_sym_ELSE] = ACTIONS(4688),
    [anon_sym_Else] = ACTIONS(4688),
    [anon_sym_case] = ACTIONS(4688),
    [anon_sym_CASE] = ACTIONS(4688),
    [anon_sym_Case] = ACTIONS(4688),
    [anon_sym_for] = ACTIONS(4688),
    [anon_sym_FOR] = ACTIONS(4688),
    [anon_sym_For] = ACTIONS(4688),
    [anon_sym_foreach] = ACTIONS(4688),
    [anon_sym_FOREACH] = ACTIONS(4688),
    [anon_sym_Foreach] = ACTIONS(4688),
    [anon_sym_while] = ACTIONS(4688),
    [anon_sym_WHILE] = ACTIONS(4688),
    [anon_sym_While] = ACTIONS(4688),
    [anon_sym_repeat] = ACTIONS(4688),
    [anon_sym_REPEAT] = ACTIONS(4688),
    [anon_sym_Repeat] = ACTIONS(4688),
    [anon_sym_exit] = ACTIONS(4688),
    [anon_sym_EXIT] = ACTIONS(4688),
    [anon_sym_Exit] = ACTIONS(4688),
    [anon_sym_continue] = ACTIONS(4688),
    [anon_sym_CONTINUE] = ACTIONS(4688),
    [anon_sym_Continue] = ACTIONS(4688),
    [anon_sym_break] = ACTIONS(4688),
    [anon_sym_BREAK] = ACTIONS(4688),
    [anon_sym_Break] = ACTIONS(4688),
    [anon_sym_with] = ACTIONS(4688),
    [anon_sym_WITH] = ACTIONS(4688),
    [anon_sym_With] = ACTIONS(4688),
    [sym_asserterror_keyword] = ACTIONS(4690),
    [sym_page_keyword] = ACTIONS(4688),
    [anon_sym_codeunit] = ACTIONS(4688),
    [anon_sym_CODEUNIT] = ACTIONS(4688),
    [anon_sym_Codeunit] = ACTIONS(4688),
    [anon_sym_CodeUnit] = ACTIONS(4688),
    [anon_sym_COdeunit] = ACTIONS(4688),
    [anon_sym_codeUnit] = ACTIONS(4688),
    [sym_report_keyword] = ACTIONS(4688),
    [sym_query_keyword] = ACTIONS(4688),
    [anon_sym_xmlport] = ACTIONS(4688),
    [anon_sym_XMLPORT] = ACTIONS(4688),
    [anon_sym_Xmlport] = ACTIONS(4688),
    [anon_sym_XMLport] = ACTIONS(4688),
    [anon_sym_XMLPort] = ACTIONS(4688),
    [anon_sym_XmlPort] = ACTIONS(4688),
    [anon_sym_enum] = ACTIONS(4688),
    [anon_sym_ENUM] = ACTIONS(4688),
    [anon_sym_Enum] = ACTIONS(4688),
    [anon_sym_eNUM] = ACTIONS(4688),
    [anon_sym_eNum] = ACTIONS(4688),
    [anon_sym_ENum] = ACTIONS(4688),
    [sym_quoted_identifier] = ACTIONS(4690),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4690),
    [sym_integer] = ACTIONS(4688),
    [sym_continue_as_identifier] = ACTIONS(4690),
    [sym_preproc_open] = ACTIONS(4690),
    [sym_preproc_close] = ACTIONS(4690),
  },
  [STATE(1691)] = {
    [sym_identifier] = ACTIONS(4692),
    [anon_sym_SEMI] = ACTIONS(4694),
    [anon_sym_DASH] = ACTIONS(4694),
    [aux_sym_boolean_token1] = ACTIONS(4692),
    [aux_sym_boolean_token2] = ACTIONS(4692),
    [sym_decimal] = ACTIONS(4692),
    [anon_sym_LPAREN] = ACTIONS(4694),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4692),
    [anon_sym_LBRACK] = ACTIONS(4694),
    [aux_sym_record_type_token1] = ACTIONS(4692),
    [aux_sym_basic_type_token21] = ACTIONS(4692),
    [aux_sym_basic_type_token22] = ACTIONS(4692),
    [aux_sym_basic_type_token48] = ACTIONS(4692),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4692),
    [anon_sym_POUNDif] = ACTIONS(4694),
    [anon_sym_POUNDIF] = ACTIONS(4694),
    [anon_sym_POUNDIf] = ACTIONS(4694),
    [anon_sym_not] = ACTIONS(4692),
    [anon_sym_NOT] = ACTIONS(4692),
    [anon_sym_Not] = ACTIONS(4692),
    [anon_sym_POUNDelif] = ACTIONS(4694),
    [anon_sym_POUNDELIF] = ACTIONS(4694),
    [anon_sym_POUNDElif] = ACTIONS(4694),
    [anon_sym_POUNDelse] = ACTIONS(4694),
    [anon_sym_POUNDELSE] = ACTIONS(4694),
    [anon_sym_POUNDElse] = ACTIONS(4694),
    [anon_sym_POUNDendif] = ACTIONS(4694),
    [anon_sym_POUNDENDIF] = ACTIONS(4694),
    [anon_sym_POUNDEndif] = ACTIONS(4694),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4692),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4692),
    [anon_sym_PLUS] = ACTIONS(4694),
    [sym_datetime_literal] = ACTIONS(4694),
    [sym_date_literal] = ACTIONS(4692),
    [sym_time_literal] = ACTIONS(4692),
    [sym_biginteger_literal] = ACTIONS(4694),
    [anon_sym_if] = ACTIONS(4692),
    [anon_sym_IF] = ACTIONS(4692),
    [anon_sym_If] = ACTIONS(4692),
    [anon_sym_else] = ACTIONS(4692),
    [anon_sym_ELSE] = ACTIONS(4692),
    [anon_sym_Else] = ACTIONS(4692),
    [anon_sym_case] = ACTIONS(4692),
    [anon_sym_CASE] = ACTIONS(4692),
    [anon_sym_Case] = ACTIONS(4692),
    [anon_sym_for] = ACTIONS(4692),
    [anon_sym_FOR] = ACTIONS(4692),
    [anon_sym_For] = ACTIONS(4692),
    [anon_sym_foreach] = ACTIONS(4692),
    [anon_sym_FOREACH] = ACTIONS(4692),
    [anon_sym_Foreach] = ACTIONS(4692),
    [anon_sym_while] = ACTIONS(4692),
    [anon_sym_WHILE] = ACTIONS(4692),
    [anon_sym_While] = ACTIONS(4692),
    [anon_sym_repeat] = ACTIONS(4692),
    [anon_sym_REPEAT] = ACTIONS(4692),
    [anon_sym_Repeat] = ACTIONS(4692),
    [anon_sym_exit] = ACTIONS(4692),
    [anon_sym_EXIT] = ACTIONS(4692),
    [anon_sym_Exit] = ACTIONS(4692),
    [anon_sym_continue] = ACTIONS(4692),
    [anon_sym_CONTINUE] = ACTIONS(4692),
    [anon_sym_Continue] = ACTIONS(4692),
    [anon_sym_break] = ACTIONS(4692),
    [anon_sym_BREAK] = ACTIONS(4692),
    [anon_sym_Break] = ACTIONS(4692),
    [anon_sym_with] = ACTIONS(4692),
    [anon_sym_WITH] = ACTIONS(4692),
    [anon_sym_With] = ACTIONS(4692),
    [sym_asserterror_keyword] = ACTIONS(4694),
    [sym_page_keyword] = ACTIONS(4692),
    [anon_sym_codeunit] = ACTIONS(4692),
    [anon_sym_CODEUNIT] = ACTIONS(4692),
    [anon_sym_Codeunit] = ACTIONS(4692),
    [anon_sym_CodeUnit] = ACTIONS(4692),
    [anon_sym_COdeunit] = ACTIONS(4692),
    [anon_sym_codeUnit] = ACTIONS(4692),
    [sym_report_keyword] = ACTIONS(4692),
    [sym_query_keyword] = ACTIONS(4692),
    [anon_sym_xmlport] = ACTIONS(4692),
    [anon_sym_XMLPORT] = ACTIONS(4692),
    [anon_sym_Xmlport] = ACTIONS(4692),
    [anon_sym_XMLport] = ACTIONS(4692),
    [anon_sym_XMLPort] = ACTIONS(4692),
    [anon_sym_XmlPort] = ACTIONS(4692),
    [anon_sym_enum] = ACTIONS(4692),
    [anon_sym_ENUM] = ACTIONS(4692),
    [anon_sym_Enum] = ACTIONS(4692),
    [anon_sym_eNUM] = ACTIONS(4692),
    [anon_sym_eNum] = ACTIONS(4692),
    [anon_sym_ENum] = ACTIONS(4692),
    [sym_quoted_identifier] = ACTIONS(4694),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4694),
    [sym_integer] = ACTIONS(4692),
    [sym_continue_as_identifier] = ACTIONS(4694),
    [sym_preproc_open] = ACTIONS(4694),
    [sym_preproc_close] = ACTIONS(4694),
  },
  [STATE(1692)] = {
    [sym_identifier] = ACTIONS(4688),
    [anon_sym_SEMI] = ACTIONS(4690),
    [anon_sym_DASH] = ACTIONS(4690),
    [aux_sym_boolean_token1] = ACTIONS(4688),
    [aux_sym_boolean_token2] = ACTIONS(4688),
    [sym_decimal] = ACTIONS(4688),
    [anon_sym_LPAREN] = ACTIONS(4690),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4688),
    [anon_sym_LBRACK] = ACTIONS(4690),
    [aux_sym_record_type_token1] = ACTIONS(4688),
    [aux_sym_basic_type_token21] = ACTIONS(4688),
    [aux_sym_basic_type_token22] = ACTIONS(4688),
    [aux_sym_basic_type_token48] = ACTIONS(4688),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4688),
    [anon_sym_POUNDif] = ACTIONS(4690),
    [anon_sym_POUNDIF] = ACTIONS(4690),
    [anon_sym_POUNDIf] = ACTIONS(4690),
    [anon_sym_not] = ACTIONS(4688),
    [anon_sym_NOT] = ACTIONS(4688),
    [anon_sym_Not] = ACTIONS(4688),
    [anon_sym_POUNDelif] = ACTIONS(4690),
    [anon_sym_POUNDELIF] = ACTIONS(4690),
    [anon_sym_POUNDElif] = ACTIONS(4690),
    [anon_sym_POUNDelse] = ACTIONS(4690),
    [anon_sym_POUNDELSE] = ACTIONS(4690),
    [anon_sym_POUNDElse] = ACTIONS(4690),
    [anon_sym_POUNDendif] = ACTIONS(4690),
    [anon_sym_POUNDENDIF] = ACTIONS(4690),
    [anon_sym_POUNDEndif] = ACTIONS(4690),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4688),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4688),
    [anon_sym_PLUS] = ACTIONS(4690),
    [sym_datetime_literal] = ACTIONS(4690),
    [sym_date_literal] = ACTIONS(4688),
    [sym_time_literal] = ACTIONS(4688),
    [sym_biginteger_literal] = ACTIONS(4690),
    [anon_sym_if] = ACTIONS(4688),
    [anon_sym_IF] = ACTIONS(4688),
    [anon_sym_If] = ACTIONS(4688),
    [anon_sym_else] = ACTIONS(4688),
    [anon_sym_ELSE] = ACTIONS(4688),
    [anon_sym_Else] = ACTIONS(4688),
    [anon_sym_case] = ACTIONS(4688),
    [anon_sym_CASE] = ACTIONS(4688),
    [anon_sym_Case] = ACTIONS(4688),
    [anon_sym_for] = ACTIONS(4688),
    [anon_sym_FOR] = ACTIONS(4688),
    [anon_sym_For] = ACTIONS(4688),
    [anon_sym_foreach] = ACTIONS(4688),
    [anon_sym_FOREACH] = ACTIONS(4688),
    [anon_sym_Foreach] = ACTIONS(4688),
    [anon_sym_while] = ACTIONS(4688),
    [anon_sym_WHILE] = ACTIONS(4688),
    [anon_sym_While] = ACTIONS(4688),
    [anon_sym_repeat] = ACTIONS(4688),
    [anon_sym_REPEAT] = ACTIONS(4688),
    [anon_sym_Repeat] = ACTIONS(4688),
    [anon_sym_exit] = ACTIONS(4688),
    [anon_sym_EXIT] = ACTIONS(4688),
    [anon_sym_Exit] = ACTIONS(4688),
    [anon_sym_continue] = ACTIONS(4688),
    [anon_sym_CONTINUE] = ACTIONS(4688),
    [anon_sym_Continue] = ACTIONS(4688),
    [anon_sym_break] = ACTIONS(4688),
    [anon_sym_BREAK] = ACTIONS(4688),
    [anon_sym_Break] = ACTIONS(4688),
    [anon_sym_with] = ACTIONS(4688),
    [anon_sym_WITH] = ACTIONS(4688),
    [anon_sym_With] = ACTIONS(4688),
    [sym_asserterror_keyword] = ACTIONS(4690),
    [sym_page_keyword] = ACTIONS(4688),
    [anon_sym_codeunit] = ACTIONS(4688),
    [anon_sym_CODEUNIT] = ACTIONS(4688),
    [anon_sym_Codeunit] = ACTIONS(4688),
    [anon_sym_CodeUnit] = ACTIONS(4688),
    [anon_sym_COdeunit] = ACTIONS(4688),
    [anon_sym_codeUnit] = ACTIONS(4688),
    [sym_report_keyword] = ACTIONS(4688),
    [sym_query_keyword] = ACTIONS(4688),
    [anon_sym_xmlport] = ACTIONS(4688),
    [anon_sym_XMLPORT] = ACTIONS(4688),
    [anon_sym_Xmlport] = ACTIONS(4688),
    [anon_sym_XMLport] = ACTIONS(4688),
    [anon_sym_XMLPort] = ACTIONS(4688),
    [anon_sym_XmlPort] = ACTIONS(4688),
    [anon_sym_enum] = ACTIONS(4688),
    [anon_sym_ENUM] = ACTIONS(4688),
    [anon_sym_Enum] = ACTIONS(4688),
    [anon_sym_eNUM] = ACTIONS(4688),
    [anon_sym_eNum] = ACTIONS(4688),
    [anon_sym_ENum] = ACTIONS(4688),
    [sym_quoted_identifier] = ACTIONS(4690),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4690),
    [sym_integer] = ACTIONS(4688),
    [sym_continue_as_identifier] = ACTIONS(4690),
    [sym_preproc_open] = ACTIONS(4690),
    [sym_preproc_close] = ACTIONS(4690),
  },
  [STATE(1693)] = {
    [sym_identifier] = ACTIONS(4696),
    [anon_sym_SEMI] = ACTIONS(4698),
    [anon_sym_DASH] = ACTIONS(4698),
    [aux_sym_boolean_token1] = ACTIONS(4696),
    [aux_sym_boolean_token2] = ACTIONS(4696),
    [sym_decimal] = ACTIONS(4696),
    [anon_sym_LPAREN] = ACTIONS(4698),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4696),
    [anon_sym_LBRACK] = ACTIONS(4698),
    [aux_sym_record_type_token1] = ACTIONS(4696),
    [aux_sym_basic_type_token21] = ACTIONS(4696),
    [aux_sym_basic_type_token22] = ACTIONS(4696),
    [aux_sym_basic_type_token48] = ACTIONS(4696),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4696),
    [anon_sym_POUNDif] = ACTIONS(4698),
    [anon_sym_POUNDIF] = ACTIONS(4698),
    [anon_sym_POUNDIf] = ACTIONS(4698),
    [anon_sym_not] = ACTIONS(4696),
    [anon_sym_NOT] = ACTIONS(4696),
    [anon_sym_Not] = ACTIONS(4696),
    [anon_sym_POUNDelif] = ACTIONS(4698),
    [anon_sym_POUNDELIF] = ACTIONS(4698),
    [anon_sym_POUNDElif] = ACTIONS(4698),
    [anon_sym_POUNDelse] = ACTIONS(4698),
    [anon_sym_POUNDELSE] = ACTIONS(4698),
    [anon_sym_POUNDElse] = ACTIONS(4698),
    [anon_sym_POUNDendif] = ACTIONS(4698),
    [anon_sym_POUNDENDIF] = ACTIONS(4698),
    [anon_sym_POUNDEndif] = ACTIONS(4698),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4696),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4696),
    [anon_sym_PLUS] = ACTIONS(4698),
    [sym_datetime_literal] = ACTIONS(4698),
    [sym_date_literal] = ACTIONS(4696),
    [sym_time_literal] = ACTIONS(4696),
    [sym_biginteger_literal] = ACTIONS(4698),
    [anon_sym_if] = ACTIONS(4696),
    [anon_sym_IF] = ACTIONS(4696),
    [anon_sym_If] = ACTIONS(4696),
    [anon_sym_else] = ACTIONS(4696),
    [anon_sym_ELSE] = ACTIONS(4696),
    [anon_sym_Else] = ACTIONS(4696),
    [anon_sym_case] = ACTIONS(4696),
    [anon_sym_CASE] = ACTIONS(4696),
    [anon_sym_Case] = ACTIONS(4696),
    [anon_sym_for] = ACTIONS(4696),
    [anon_sym_FOR] = ACTIONS(4696),
    [anon_sym_For] = ACTIONS(4696),
    [anon_sym_foreach] = ACTIONS(4696),
    [anon_sym_FOREACH] = ACTIONS(4696),
    [anon_sym_Foreach] = ACTIONS(4696),
    [anon_sym_while] = ACTIONS(4696),
    [anon_sym_WHILE] = ACTIONS(4696),
    [anon_sym_While] = ACTIONS(4696),
    [anon_sym_repeat] = ACTIONS(4696),
    [anon_sym_REPEAT] = ACTIONS(4696),
    [anon_sym_Repeat] = ACTIONS(4696),
    [anon_sym_exit] = ACTIONS(4696),
    [anon_sym_EXIT] = ACTIONS(4696),
    [anon_sym_Exit] = ACTIONS(4696),
    [anon_sym_continue] = ACTIONS(4696),
    [anon_sym_CONTINUE] = ACTIONS(4696),
    [anon_sym_Continue] = ACTIONS(4696),
    [anon_sym_break] = ACTIONS(4696),
    [anon_sym_BREAK] = ACTIONS(4696),
    [anon_sym_Break] = ACTIONS(4696),
    [anon_sym_with] = ACTIONS(4696),
    [anon_sym_WITH] = ACTIONS(4696),
    [anon_sym_With] = ACTIONS(4696),
    [sym_asserterror_keyword] = ACTIONS(4698),
    [sym_page_keyword] = ACTIONS(4696),
    [anon_sym_codeunit] = ACTIONS(4696),
    [anon_sym_CODEUNIT] = ACTIONS(4696),
    [anon_sym_Codeunit] = ACTIONS(4696),
    [anon_sym_CodeUnit] = ACTIONS(4696),
    [anon_sym_COdeunit] = ACTIONS(4696),
    [anon_sym_codeUnit] = ACTIONS(4696),
    [sym_report_keyword] = ACTIONS(4696),
    [sym_query_keyword] = ACTIONS(4696),
    [anon_sym_xmlport] = ACTIONS(4696),
    [anon_sym_XMLPORT] = ACTIONS(4696),
    [anon_sym_Xmlport] = ACTIONS(4696),
    [anon_sym_XMLport] = ACTIONS(4696),
    [anon_sym_XMLPort] = ACTIONS(4696),
    [anon_sym_XmlPort] = ACTIONS(4696),
    [anon_sym_enum] = ACTIONS(4696),
    [anon_sym_ENUM] = ACTIONS(4696),
    [anon_sym_Enum] = ACTIONS(4696),
    [anon_sym_eNUM] = ACTIONS(4696),
    [anon_sym_eNum] = ACTIONS(4696),
    [anon_sym_ENum] = ACTIONS(4696),
    [sym_quoted_identifier] = ACTIONS(4698),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4698),
    [sym_integer] = ACTIONS(4696),
    [sym_continue_as_identifier] = ACTIONS(4698),
    [sym_preproc_open] = ACTIONS(4698),
    [sym_preproc_close] = ACTIONS(4698),
  },
  [STATE(1694)] = {
    [sym_identifier] = ACTIONS(4696),
    [anon_sym_SEMI] = ACTIONS(4698),
    [anon_sym_DASH] = ACTIONS(4698),
    [aux_sym_boolean_token1] = ACTIONS(4696),
    [aux_sym_boolean_token2] = ACTIONS(4696),
    [sym_decimal] = ACTIONS(4696),
    [anon_sym_LPAREN] = ACTIONS(4698),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4696),
    [anon_sym_LBRACK] = ACTIONS(4698),
    [aux_sym_record_type_token1] = ACTIONS(4696),
    [aux_sym_basic_type_token21] = ACTIONS(4696),
    [aux_sym_basic_type_token22] = ACTIONS(4696),
    [aux_sym_basic_type_token48] = ACTIONS(4696),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4696),
    [anon_sym_POUNDif] = ACTIONS(4698),
    [anon_sym_POUNDIF] = ACTIONS(4698),
    [anon_sym_POUNDIf] = ACTIONS(4698),
    [anon_sym_not] = ACTIONS(4696),
    [anon_sym_NOT] = ACTIONS(4696),
    [anon_sym_Not] = ACTIONS(4696),
    [anon_sym_POUNDelif] = ACTIONS(4698),
    [anon_sym_POUNDELIF] = ACTIONS(4698),
    [anon_sym_POUNDElif] = ACTIONS(4698),
    [anon_sym_POUNDelse] = ACTIONS(4698),
    [anon_sym_POUNDELSE] = ACTIONS(4698),
    [anon_sym_POUNDElse] = ACTIONS(4698),
    [anon_sym_POUNDendif] = ACTIONS(4698),
    [anon_sym_POUNDENDIF] = ACTIONS(4698),
    [anon_sym_POUNDEndif] = ACTIONS(4698),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4696),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4696),
    [anon_sym_PLUS] = ACTIONS(4698),
    [sym_datetime_literal] = ACTIONS(4698),
    [sym_date_literal] = ACTIONS(4696),
    [sym_time_literal] = ACTIONS(4696),
    [sym_biginteger_literal] = ACTIONS(4698),
    [anon_sym_if] = ACTIONS(4696),
    [anon_sym_IF] = ACTIONS(4696),
    [anon_sym_If] = ACTIONS(4696),
    [anon_sym_else] = ACTIONS(4696),
    [anon_sym_ELSE] = ACTIONS(4696),
    [anon_sym_Else] = ACTIONS(4696),
    [anon_sym_case] = ACTIONS(4696),
    [anon_sym_CASE] = ACTIONS(4696),
    [anon_sym_Case] = ACTIONS(4696),
    [anon_sym_for] = ACTIONS(4696),
    [anon_sym_FOR] = ACTIONS(4696),
    [anon_sym_For] = ACTIONS(4696),
    [anon_sym_foreach] = ACTIONS(4696),
    [anon_sym_FOREACH] = ACTIONS(4696),
    [anon_sym_Foreach] = ACTIONS(4696),
    [anon_sym_while] = ACTIONS(4696),
    [anon_sym_WHILE] = ACTIONS(4696),
    [anon_sym_While] = ACTIONS(4696),
    [anon_sym_repeat] = ACTIONS(4696),
    [anon_sym_REPEAT] = ACTIONS(4696),
    [anon_sym_Repeat] = ACTIONS(4696),
    [anon_sym_exit] = ACTIONS(4696),
    [anon_sym_EXIT] = ACTIONS(4696),
    [anon_sym_Exit] = ACTIONS(4696),
    [anon_sym_continue] = ACTIONS(4696),
    [anon_sym_CONTINUE] = ACTIONS(4696),
    [anon_sym_Continue] = ACTIONS(4696),
    [anon_sym_break] = ACTIONS(4696),
    [anon_sym_BREAK] = ACTIONS(4696),
    [anon_sym_Break] = ACTIONS(4696),
    [anon_sym_with] = ACTIONS(4696),
    [anon_sym_WITH] = ACTIONS(4696),
    [anon_sym_With] = ACTIONS(4696),
    [sym_asserterror_keyword] = ACTIONS(4698),
    [sym_page_keyword] = ACTIONS(4696),
    [anon_sym_codeunit] = ACTIONS(4696),
    [anon_sym_CODEUNIT] = ACTIONS(4696),
    [anon_sym_Codeunit] = ACTIONS(4696),
    [anon_sym_CodeUnit] = ACTIONS(4696),
    [anon_sym_COdeunit] = ACTIONS(4696),
    [anon_sym_codeUnit] = ACTIONS(4696),
    [sym_report_keyword] = ACTIONS(4696),
    [sym_query_keyword] = ACTIONS(4696),
    [anon_sym_xmlport] = ACTIONS(4696),
    [anon_sym_XMLPORT] = ACTIONS(4696),
    [anon_sym_Xmlport] = ACTIONS(4696),
    [anon_sym_XMLport] = ACTIONS(4696),
    [anon_sym_XMLPort] = ACTIONS(4696),
    [anon_sym_XmlPort] = ACTIONS(4696),
    [anon_sym_enum] = ACTIONS(4696),
    [anon_sym_ENUM] = ACTIONS(4696),
    [anon_sym_Enum] = ACTIONS(4696),
    [anon_sym_eNUM] = ACTIONS(4696),
    [anon_sym_eNum] = ACTIONS(4696),
    [anon_sym_ENum] = ACTIONS(4696),
    [sym_quoted_identifier] = ACTIONS(4698),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4698),
    [sym_integer] = ACTIONS(4696),
    [sym_continue_as_identifier] = ACTIONS(4698),
    [sym_preproc_open] = ACTIONS(4698),
    [sym_preproc_close] = ACTIONS(4698),
  },
  [STATE(1695)] = {
    [sym_identifier] = ACTIONS(4700),
    [anon_sym_SEMI] = ACTIONS(4702),
    [anon_sym_DASH] = ACTIONS(4702),
    [aux_sym_boolean_token1] = ACTIONS(4700),
    [aux_sym_boolean_token2] = ACTIONS(4700),
    [sym_decimal] = ACTIONS(4700),
    [anon_sym_LPAREN] = ACTIONS(4702),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4700),
    [anon_sym_LBRACK] = ACTIONS(4702),
    [aux_sym_record_type_token1] = ACTIONS(4700),
    [aux_sym_basic_type_token21] = ACTIONS(4700),
    [aux_sym_basic_type_token22] = ACTIONS(4700),
    [aux_sym_basic_type_token48] = ACTIONS(4700),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4700),
    [anon_sym_POUNDif] = ACTIONS(4702),
    [anon_sym_POUNDIF] = ACTIONS(4702),
    [anon_sym_POUNDIf] = ACTIONS(4702),
    [anon_sym_not] = ACTIONS(4700),
    [anon_sym_NOT] = ACTIONS(4700),
    [anon_sym_Not] = ACTIONS(4700),
    [anon_sym_POUNDelif] = ACTIONS(4702),
    [anon_sym_POUNDELIF] = ACTIONS(4702),
    [anon_sym_POUNDElif] = ACTIONS(4702),
    [anon_sym_POUNDelse] = ACTIONS(4702),
    [anon_sym_POUNDELSE] = ACTIONS(4702),
    [anon_sym_POUNDElse] = ACTIONS(4702),
    [anon_sym_POUNDendif] = ACTIONS(4702),
    [anon_sym_POUNDENDIF] = ACTIONS(4702),
    [anon_sym_POUNDEndif] = ACTIONS(4702),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4700),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4700),
    [anon_sym_PLUS] = ACTIONS(4702),
    [sym_datetime_literal] = ACTIONS(4702),
    [sym_date_literal] = ACTIONS(4700),
    [sym_time_literal] = ACTIONS(4700),
    [sym_biginteger_literal] = ACTIONS(4702),
    [anon_sym_if] = ACTIONS(4700),
    [anon_sym_IF] = ACTIONS(4700),
    [anon_sym_If] = ACTIONS(4700),
    [anon_sym_else] = ACTIONS(4700),
    [anon_sym_ELSE] = ACTIONS(4700),
    [anon_sym_Else] = ACTIONS(4700),
    [anon_sym_case] = ACTIONS(4700),
    [anon_sym_CASE] = ACTIONS(4700),
    [anon_sym_Case] = ACTIONS(4700),
    [anon_sym_for] = ACTIONS(4700),
    [anon_sym_FOR] = ACTIONS(4700),
    [anon_sym_For] = ACTIONS(4700),
    [anon_sym_foreach] = ACTIONS(4700),
    [anon_sym_FOREACH] = ACTIONS(4700),
    [anon_sym_Foreach] = ACTIONS(4700),
    [anon_sym_while] = ACTIONS(4700),
    [anon_sym_WHILE] = ACTIONS(4700),
    [anon_sym_While] = ACTIONS(4700),
    [anon_sym_repeat] = ACTIONS(4700),
    [anon_sym_REPEAT] = ACTIONS(4700),
    [anon_sym_Repeat] = ACTIONS(4700),
    [anon_sym_exit] = ACTIONS(4700),
    [anon_sym_EXIT] = ACTIONS(4700),
    [anon_sym_Exit] = ACTIONS(4700),
    [anon_sym_continue] = ACTIONS(4700),
    [anon_sym_CONTINUE] = ACTIONS(4700),
    [anon_sym_Continue] = ACTIONS(4700),
    [anon_sym_break] = ACTIONS(4700),
    [anon_sym_BREAK] = ACTIONS(4700),
    [anon_sym_Break] = ACTIONS(4700),
    [anon_sym_with] = ACTIONS(4700),
    [anon_sym_WITH] = ACTIONS(4700),
    [anon_sym_With] = ACTIONS(4700),
    [sym_asserterror_keyword] = ACTIONS(4702),
    [sym_page_keyword] = ACTIONS(4700),
    [anon_sym_codeunit] = ACTIONS(4700),
    [anon_sym_CODEUNIT] = ACTIONS(4700),
    [anon_sym_Codeunit] = ACTIONS(4700),
    [anon_sym_CodeUnit] = ACTIONS(4700),
    [anon_sym_COdeunit] = ACTIONS(4700),
    [anon_sym_codeUnit] = ACTIONS(4700),
    [sym_report_keyword] = ACTIONS(4700),
    [sym_query_keyword] = ACTIONS(4700),
    [anon_sym_xmlport] = ACTIONS(4700),
    [anon_sym_XMLPORT] = ACTIONS(4700),
    [anon_sym_Xmlport] = ACTIONS(4700),
    [anon_sym_XMLport] = ACTIONS(4700),
    [anon_sym_XMLPort] = ACTIONS(4700),
    [anon_sym_XmlPort] = ACTIONS(4700),
    [anon_sym_enum] = ACTIONS(4700),
    [anon_sym_ENUM] = ACTIONS(4700),
    [anon_sym_Enum] = ACTIONS(4700),
    [anon_sym_eNUM] = ACTIONS(4700),
    [anon_sym_eNum] = ACTIONS(4700),
    [anon_sym_ENum] = ACTIONS(4700),
    [sym_quoted_identifier] = ACTIONS(4702),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4702),
    [sym_integer] = ACTIONS(4700),
    [sym_continue_as_identifier] = ACTIONS(4702),
    [sym_preproc_open] = ACTIONS(4702),
    [sym_preproc_close] = ACTIONS(4702),
  },
  [STATE(1696)] = {
    [sym_identifier] = ACTIONS(4704),
    [anon_sym_SEMI] = ACTIONS(4706),
    [anon_sym_DASH] = ACTIONS(4706),
    [aux_sym_boolean_token1] = ACTIONS(4704),
    [aux_sym_boolean_token2] = ACTIONS(4704),
    [sym_decimal] = ACTIONS(4704),
    [anon_sym_LPAREN] = ACTIONS(4706),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4704),
    [anon_sym_LBRACK] = ACTIONS(4706),
    [aux_sym_record_type_token1] = ACTIONS(4704),
    [aux_sym_basic_type_token21] = ACTIONS(4704),
    [aux_sym_basic_type_token22] = ACTIONS(4704),
    [aux_sym_basic_type_token48] = ACTIONS(4704),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4704),
    [anon_sym_POUNDif] = ACTIONS(4706),
    [anon_sym_POUNDIF] = ACTIONS(4706),
    [anon_sym_POUNDIf] = ACTIONS(4706),
    [anon_sym_not] = ACTIONS(4704),
    [anon_sym_NOT] = ACTIONS(4704),
    [anon_sym_Not] = ACTIONS(4704),
    [anon_sym_POUNDelif] = ACTIONS(4706),
    [anon_sym_POUNDELIF] = ACTIONS(4706),
    [anon_sym_POUNDElif] = ACTIONS(4706),
    [anon_sym_POUNDelse] = ACTIONS(4706),
    [anon_sym_POUNDELSE] = ACTIONS(4706),
    [anon_sym_POUNDElse] = ACTIONS(4706),
    [anon_sym_POUNDendif] = ACTIONS(4706),
    [anon_sym_POUNDENDIF] = ACTIONS(4706),
    [anon_sym_POUNDEndif] = ACTIONS(4706),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4704),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4704),
    [anon_sym_PLUS] = ACTIONS(4706),
    [sym_datetime_literal] = ACTIONS(4706),
    [sym_date_literal] = ACTIONS(4704),
    [sym_time_literal] = ACTIONS(4704),
    [sym_biginteger_literal] = ACTIONS(4706),
    [anon_sym_if] = ACTIONS(4704),
    [anon_sym_IF] = ACTIONS(4704),
    [anon_sym_If] = ACTIONS(4704),
    [anon_sym_else] = ACTIONS(4704),
    [anon_sym_ELSE] = ACTIONS(4704),
    [anon_sym_Else] = ACTIONS(4704),
    [anon_sym_case] = ACTIONS(4704),
    [anon_sym_CASE] = ACTIONS(4704),
    [anon_sym_Case] = ACTIONS(4704),
    [anon_sym_for] = ACTIONS(4704),
    [anon_sym_FOR] = ACTIONS(4704),
    [anon_sym_For] = ACTIONS(4704),
    [anon_sym_foreach] = ACTIONS(4704),
    [anon_sym_FOREACH] = ACTIONS(4704),
    [anon_sym_Foreach] = ACTIONS(4704),
    [anon_sym_while] = ACTIONS(4704),
    [anon_sym_WHILE] = ACTIONS(4704),
    [anon_sym_While] = ACTIONS(4704),
    [anon_sym_repeat] = ACTIONS(4704),
    [anon_sym_REPEAT] = ACTIONS(4704),
    [anon_sym_Repeat] = ACTIONS(4704),
    [anon_sym_exit] = ACTIONS(4704),
    [anon_sym_EXIT] = ACTIONS(4704),
    [anon_sym_Exit] = ACTIONS(4704),
    [anon_sym_continue] = ACTIONS(4704),
    [anon_sym_CONTINUE] = ACTIONS(4704),
    [anon_sym_Continue] = ACTIONS(4704),
    [anon_sym_break] = ACTIONS(4704),
    [anon_sym_BREAK] = ACTIONS(4704),
    [anon_sym_Break] = ACTIONS(4704),
    [anon_sym_with] = ACTIONS(4704),
    [anon_sym_WITH] = ACTIONS(4704),
    [anon_sym_With] = ACTIONS(4704),
    [sym_asserterror_keyword] = ACTIONS(4706),
    [sym_page_keyword] = ACTIONS(4704),
    [anon_sym_codeunit] = ACTIONS(4704),
    [anon_sym_CODEUNIT] = ACTIONS(4704),
    [anon_sym_Codeunit] = ACTIONS(4704),
    [anon_sym_CodeUnit] = ACTIONS(4704),
    [anon_sym_COdeunit] = ACTIONS(4704),
    [anon_sym_codeUnit] = ACTIONS(4704),
    [sym_report_keyword] = ACTIONS(4704),
    [sym_query_keyword] = ACTIONS(4704),
    [anon_sym_xmlport] = ACTIONS(4704),
    [anon_sym_XMLPORT] = ACTIONS(4704),
    [anon_sym_Xmlport] = ACTIONS(4704),
    [anon_sym_XMLport] = ACTIONS(4704),
    [anon_sym_XMLPort] = ACTIONS(4704),
    [anon_sym_XmlPort] = ACTIONS(4704),
    [anon_sym_enum] = ACTIONS(4704),
    [anon_sym_ENUM] = ACTIONS(4704),
    [anon_sym_Enum] = ACTIONS(4704),
    [anon_sym_eNUM] = ACTIONS(4704),
    [anon_sym_eNum] = ACTIONS(4704),
    [anon_sym_ENum] = ACTIONS(4704),
    [sym_quoted_identifier] = ACTIONS(4706),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4706),
    [sym_integer] = ACTIONS(4704),
    [sym_continue_as_identifier] = ACTIONS(4706),
    [sym_preproc_open] = ACTIONS(4706),
    [sym_preproc_close] = ACTIONS(4706),
  },
  [STATE(1697)] = {
    [sym_identifier] = ACTIONS(4700),
    [anon_sym_SEMI] = ACTIONS(4702),
    [anon_sym_DASH] = ACTIONS(4702),
    [aux_sym_boolean_token1] = ACTIONS(4700),
    [aux_sym_boolean_token2] = ACTIONS(4700),
    [sym_decimal] = ACTIONS(4700),
    [anon_sym_LPAREN] = ACTIONS(4702),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4700),
    [anon_sym_LBRACK] = ACTIONS(4702),
    [aux_sym_record_type_token1] = ACTIONS(4700),
    [aux_sym_basic_type_token21] = ACTIONS(4700),
    [aux_sym_basic_type_token22] = ACTIONS(4700),
    [aux_sym_basic_type_token48] = ACTIONS(4700),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4700),
    [anon_sym_POUNDif] = ACTIONS(4702),
    [anon_sym_POUNDIF] = ACTIONS(4702),
    [anon_sym_POUNDIf] = ACTIONS(4702),
    [anon_sym_not] = ACTIONS(4700),
    [anon_sym_NOT] = ACTIONS(4700),
    [anon_sym_Not] = ACTIONS(4700),
    [anon_sym_POUNDelif] = ACTIONS(4702),
    [anon_sym_POUNDELIF] = ACTIONS(4702),
    [anon_sym_POUNDElif] = ACTIONS(4702),
    [anon_sym_POUNDelse] = ACTIONS(4702),
    [anon_sym_POUNDELSE] = ACTIONS(4702),
    [anon_sym_POUNDElse] = ACTIONS(4702),
    [anon_sym_POUNDendif] = ACTIONS(4702),
    [anon_sym_POUNDENDIF] = ACTIONS(4702),
    [anon_sym_POUNDEndif] = ACTIONS(4702),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4700),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4700),
    [anon_sym_PLUS] = ACTIONS(4702),
    [sym_datetime_literal] = ACTIONS(4702),
    [sym_date_literal] = ACTIONS(4700),
    [sym_time_literal] = ACTIONS(4700),
    [sym_biginteger_literal] = ACTIONS(4702),
    [anon_sym_if] = ACTIONS(4700),
    [anon_sym_IF] = ACTIONS(4700),
    [anon_sym_If] = ACTIONS(4700),
    [anon_sym_else] = ACTIONS(4700),
    [anon_sym_ELSE] = ACTIONS(4700),
    [anon_sym_Else] = ACTIONS(4700),
    [anon_sym_case] = ACTIONS(4700),
    [anon_sym_CASE] = ACTIONS(4700),
    [anon_sym_Case] = ACTIONS(4700),
    [anon_sym_for] = ACTIONS(4700),
    [anon_sym_FOR] = ACTIONS(4700),
    [anon_sym_For] = ACTIONS(4700),
    [anon_sym_foreach] = ACTIONS(4700),
    [anon_sym_FOREACH] = ACTIONS(4700),
    [anon_sym_Foreach] = ACTIONS(4700),
    [anon_sym_while] = ACTIONS(4700),
    [anon_sym_WHILE] = ACTIONS(4700),
    [anon_sym_While] = ACTIONS(4700),
    [anon_sym_repeat] = ACTIONS(4700),
    [anon_sym_REPEAT] = ACTIONS(4700),
    [anon_sym_Repeat] = ACTIONS(4700),
    [anon_sym_exit] = ACTIONS(4700),
    [anon_sym_EXIT] = ACTIONS(4700),
    [anon_sym_Exit] = ACTIONS(4700),
    [anon_sym_continue] = ACTIONS(4700),
    [anon_sym_CONTINUE] = ACTIONS(4700),
    [anon_sym_Continue] = ACTIONS(4700),
    [anon_sym_break] = ACTIONS(4700),
    [anon_sym_BREAK] = ACTIONS(4700),
    [anon_sym_Break] = ACTIONS(4700),
    [anon_sym_with] = ACTIONS(4700),
    [anon_sym_WITH] = ACTIONS(4700),
    [anon_sym_With] = ACTIONS(4700),
    [sym_asserterror_keyword] = ACTIONS(4702),
    [sym_page_keyword] = ACTIONS(4700),
    [anon_sym_codeunit] = ACTIONS(4700),
    [anon_sym_CODEUNIT] = ACTIONS(4700),
    [anon_sym_Codeunit] = ACTIONS(4700),
    [anon_sym_CodeUnit] = ACTIONS(4700),
    [anon_sym_COdeunit] = ACTIONS(4700),
    [anon_sym_codeUnit] = ACTIONS(4700),
    [sym_report_keyword] = ACTIONS(4700),
    [sym_query_keyword] = ACTIONS(4700),
    [anon_sym_xmlport] = ACTIONS(4700),
    [anon_sym_XMLPORT] = ACTIONS(4700),
    [anon_sym_Xmlport] = ACTIONS(4700),
    [anon_sym_XMLport] = ACTIONS(4700),
    [anon_sym_XMLPort] = ACTIONS(4700),
    [anon_sym_XmlPort] = ACTIONS(4700),
    [anon_sym_enum] = ACTIONS(4700),
    [anon_sym_ENUM] = ACTIONS(4700),
    [anon_sym_Enum] = ACTIONS(4700),
    [anon_sym_eNUM] = ACTIONS(4700),
    [anon_sym_eNum] = ACTIONS(4700),
    [anon_sym_ENum] = ACTIONS(4700),
    [sym_quoted_identifier] = ACTIONS(4702),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4702),
    [sym_integer] = ACTIONS(4700),
    [sym_continue_as_identifier] = ACTIONS(4702),
    [sym_preproc_open] = ACTIONS(4702),
    [sym_preproc_close] = ACTIONS(4702),
  },
  [STATE(1698)] = {
    [sym_identifier] = ACTIONS(4708),
    [anon_sym_SEMI] = ACTIONS(4710),
    [anon_sym_DASH] = ACTIONS(4710),
    [aux_sym_boolean_token1] = ACTIONS(4708),
    [aux_sym_boolean_token2] = ACTIONS(4708),
    [sym_decimal] = ACTIONS(4708),
    [anon_sym_LPAREN] = ACTIONS(4710),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4708),
    [anon_sym_LBRACK] = ACTIONS(4710),
    [aux_sym_record_type_token1] = ACTIONS(4708),
    [aux_sym_basic_type_token21] = ACTIONS(4708),
    [aux_sym_basic_type_token22] = ACTIONS(4708),
    [aux_sym_basic_type_token48] = ACTIONS(4708),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4708),
    [anon_sym_POUNDif] = ACTIONS(4710),
    [anon_sym_POUNDIF] = ACTIONS(4710),
    [anon_sym_POUNDIf] = ACTIONS(4710),
    [anon_sym_not] = ACTIONS(4708),
    [anon_sym_NOT] = ACTIONS(4708),
    [anon_sym_Not] = ACTIONS(4708),
    [anon_sym_POUNDelif] = ACTIONS(4710),
    [anon_sym_POUNDELIF] = ACTIONS(4710),
    [anon_sym_POUNDElif] = ACTIONS(4710),
    [anon_sym_POUNDelse] = ACTIONS(4710),
    [anon_sym_POUNDELSE] = ACTIONS(4710),
    [anon_sym_POUNDElse] = ACTIONS(4710),
    [anon_sym_POUNDendif] = ACTIONS(4710),
    [anon_sym_POUNDENDIF] = ACTIONS(4710),
    [anon_sym_POUNDEndif] = ACTIONS(4710),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4708),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4708),
    [anon_sym_PLUS] = ACTIONS(4710),
    [sym_datetime_literal] = ACTIONS(4710),
    [sym_date_literal] = ACTIONS(4708),
    [sym_time_literal] = ACTIONS(4708),
    [sym_biginteger_literal] = ACTIONS(4710),
    [anon_sym_if] = ACTIONS(4708),
    [anon_sym_IF] = ACTIONS(4708),
    [anon_sym_If] = ACTIONS(4708),
    [anon_sym_else] = ACTIONS(4708),
    [anon_sym_ELSE] = ACTIONS(4708),
    [anon_sym_Else] = ACTIONS(4708),
    [anon_sym_case] = ACTIONS(4708),
    [anon_sym_CASE] = ACTIONS(4708),
    [anon_sym_Case] = ACTIONS(4708),
    [anon_sym_for] = ACTIONS(4708),
    [anon_sym_FOR] = ACTIONS(4708),
    [anon_sym_For] = ACTIONS(4708),
    [anon_sym_foreach] = ACTIONS(4708),
    [anon_sym_FOREACH] = ACTIONS(4708),
    [anon_sym_Foreach] = ACTIONS(4708),
    [anon_sym_while] = ACTIONS(4708),
    [anon_sym_WHILE] = ACTIONS(4708),
    [anon_sym_While] = ACTIONS(4708),
    [anon_sym_repeat] = ACTIONS(4708),
    [anon_sym_REPEAT] = ACTIONS(4708),
    [anon_sym_Repeat] = ACTIONS(4708),
    [anon_sym_exit] = ACTIONS(4708),
    [anon_sym_EXIT] = ACTIONS(4708),
    [anon_sym_Exit] = ACTIONS(4708),
    [anon_sym_continue] = ACTIONS(4708),
    [anon_sym_CONTINUE] = ACTIONS(4708),
    [anon_sym_Continue] = ACTIONS(4708),
    [anon_sym_break] = ACTIONS(4708),
    [anon_sym_BREAK] = ACTIONS(4708),
    [anon_sym_Break] = ACTIONS(4708),
    [anon_sym_with] = ACTIONS(4708),
    [anon_sym_WITH] = ACTIONS(4708),
    [anon_sym_With] = ACTIONS(4708),
    [sym_asserterror_keyword] = ACTIONS(4710),
    [sym_page_keyword] = ACTIONS(4708),
    [anon_sym_codeunit] = ACTIONS(4708),
    [anon_sym_CODEUNIT] = ACTIONS(4708),
    [anon_sym_Codeunit] = ACTIONS(4708),
    [anon_sym_CodeUnit] = ACTIONS(4708),
    [anon_sym_COdeunit] = ACTIONS(4708),
    [anon_sym_codeUnit] = ACTIONS(4708),
    [sym_report_keyword] = ACTIONS(4708),
    [sym_query_keyword] = ACTIONS(4708),
    [anon_sym_xmlport] = ACTIONS(4708),
    [anon_sym_XMLPORT] = ACTIONS(4708),
    [anon_sym_Xmlport] = ACTIONS(4708),
    [anon_sym_XMLport] = ACTIONS(4708),
    [anon_sym_XMLPort] = ACTIONS(4708),
    [anon_sym_XmlPort] = ACTIONS(4708),
    [anon_sym_enum] = ACTIONS(4708),
    [anon_sym_ENUM] = ACTIONS(4708),
    [anon_sym_Enum] = ACTIONS(4708),
    [anon_sym_eNUM] = ACTIONS(4708),
    [anon_sym_eNum] = ACTIONS(4708),
    [anon_sym_ENum] = ACTIONS(4708),
    [sym_quoted_identifier] = ACTIONS(4710),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4710),
    [sym_integer] = ACTIONS(4708),
    [sym_continue_as_identifier] = ACTIONS(4710),
    [sym_preproc_open] = ACTIONS(4710),
    [sym_preproc_close] = ACTIONS(4710),
  },
  [STATE(1699)] = {
    [sym_identifier] = ACTIONS(4712),
    [anon_sym_SEMI] = ACTIONS(4714),
    [anon_sym_DASH] = ACTIONS(4714),
    [aux_sym_boolean_token1] = ACTIONS(4712),
    [aux_sym_boolean_token2] = ACTIONS(4712),
    [sym_decimal] = ACTIONS(4712),
    [anon_sym_LPAREN] = ACTIONS(4714),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4712),
    [anon_sym_LBRACK] = ACTIONS(4714),
    [aux_sym_record_type_token1] = ACTIONS(4712),
    [aux_sym_basic_type_token21] = ACTIONS(4712),
    [aux_sym_basic_type_token22] = ACTIONS(4712),
    [aux_sym_basic_type_token48] = ACTIONS(4712),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4712),
    [anon_sym_POUNDif] = ACTIONS(4714),
    [anon_sym_POUNDIF] = ACTIONS(4714),
    [anon_sym_POUNDIf] = ACTIONS(4714),
    [anon_sym_not] = ACTIONS(4712),
    [anon_sym_NOT] = ACTIONS(4712),
    [anon_sym_Not] = ACTIONS(4712),
    [anon_sym_POUNDelif] = ACTIONS(4714),
    [anon_sym_POUNDELIF] = ACTIONS(4714),
    [anon_sym_POUNDElif] = ACTIONS(4714),
    [anon_sym_POUNDelse] = ACTIONS(4714),
    [anon_sym_POUNDELSE] = ACTIONS(4714),
    [anon_sym_POUNDElse] = ACTIONS(4714),
    [anon_sym_POUNDendif] = ACTIONS(4714),
    [anon_sym_POUNDENDIF] = ACTIONS(4714),
    [anon_sym_POUNDEndif] = ACTIONS(4714),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4712),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4712),
    [anon_sym_PLUS] = ACTIONS(4714),
    [sym_datetime_literal] = ACTIONS(4714),
    [sym_date_literal] = ACTIONS(4712),
    [sym_time_literal] = ACTIONS(4712),
    [sym_biginteger_literal] = ACTIONS(4714),
    [anon_sym_if] = ACTIONS(4712),
    [anon_sym_IF] = ACTIONS(4712),
    [anon_sym_If] = ACTIONS(4712),
    [anon_sym_else] = ACTIONS(4712),
    [anon_sym_ELSE] = ACTIONS(4712),
    [anon_sym_Else] = ACTIONS(4712),
    [anon_sym_case] = ACTIONS(4712),
    [anon_sym_CASE] = ACTIONS(4712),
    [anon_sym_Case] = ACTIONS(4712),
    [anon_sym_for] = ACTIONS(4712),
    [anon_sym_FOR] = ACTIONS(4712),
    [anon_sym_For] = ACTIONS(4712),
    [anon_sym_foreach] = ACTIONS(4712),
    [anon_sym_FOREACH] = ACTIONS(4712),
    [anon_sym_Foreach] = ACTIONS(4712),
    [anon_sym_while] = ACTIONS(4712),
    [anon_sym_WHILE] = ACTIONS(4712),
    [anon_sym_While] = ACTIONS(4712),
    [anon_sym_repeat] = ACTIONS(4712),
    [anon_sym_REPEAT] = ACTIONS(4712),
    [anon_sym_Repeat] = ACTIONS(4712),
    [anon_sym_exit] = ACTIONS(4712),
    [anon_sym_EXIT] = ACTIONS(4712),
    [anon_sym_Exit] = ACTIONS(4712),
    [anon_sym_continue] = ACTIONS(4712),
    [anon_sym_CONTINUE] = ACTIONS(4712),
    [anon_sym_Continue] = ACTIONS(4712),
    [anon_sym_break] = ACTIONS(4712),
    [anon_sym_BREAK] = ACTIONS(4712),
    [anon_sym_Break] = ACTIONS(4712),
    [anon_sym_with] = ACTIONS(4712),
    [anon_sym_WITH] = ACTIONS(4712),
    [anon_sym_With] = ACTIONS(4712),
    [sym_asserterror_keyword] = ACTIONS(4714),
    [sym_page_keyword] = ACTIONS(4712),
    [anon_sym_codeunit] = ACTIONS(4712),
    [anon_sym_CODEUNIT] = ACTIONS(4712),
    [anon_sym_Codeunit] = ACTIONS(4712),
    [anon_sym_CodeUnit] = ACTIONS(4712),
    [anon_sym_COdeunit] = ACTIONS(4712),
    [anon_sym_codeUnit] = ACTIONS(4712),
    [sym_report_keyword] = ACTIONS(4712),
    [sym_query_keyword] = ACTIONS(4712),
    [anon_sym_xmlport] = ACTIONS(4712),
    [anon_sym_XMLPORT] = ACTIONS(4712),
    [anon_sym_Xmlport] = ACTIONS(4712),
    [anon_sym_XMLport] = ACTIONS(4712),
    [anon_sym_XMLPort] = ACTIONS(4712),
    [anon_sym_XmlPort] = ACTIONS(4712),
    [anon_sym_enum] = ACTIONS(4712),
    [anon_sym_ENUM] = ACTIONS(4712),
    [anon_sym_Enum] = ACTIONS(4712),
    [anon_sym_eNUM] = ACTIONS(4712),
    [anon_sym_eNum] = ACTIONS(4712),
    [anon_sym_ENum] = ACTIONS(4712),
    [sym_quoted_identifier] = ACTIONS(4714),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4714),
    [sym_integer] = ACTIONS(4712),
    [sym_continue_as_identifier] = ACTIONS(4714),
    [sym_preproc_open] = ACTIONS(4714),
    [sym_preproc_close] = ACTIONS(4714),
  },
  [STATE(1700)] = {
    [sym_identifier] = ACTIONS(4708),
    [anon_sym_SEMI] = ACTIONS(4710),
    [anon_sym_DASH] = ACTIONS(4710),
    [aux_sym_boolean_token1] = ACTIONS(4708),
    [aux_sym_boolean_token2] = ACTIONS(4708),
    [sym_decimal] = ACTIONS(4708),
    [anon_sym_LPAREN] = ACTIONS(4710),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4708),
    [anon_sym_LBRACK] = ACTIONS(4710),
    [aux_sym_record_type_token1] = ACTIONS(4708),
    [aux_sym_basic_type_token21] = ACTIONS(4708),
    [aux_sym_basic_type_token22] = ACTIONS(4708),
    [aux_sym_basic_type_token48] = ACTIONS(4708),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4708),
    [anon_sym_POUNDif] = ACTIONS(4710),
    [anon_sym_POUNDIF] = ACTIONS(4710),
    [anon_sym_POUNDIf] = ACTIONS(4710),
    [anon_sym_not] = ACTIONS(4708),
    [anon_sym_NOT] = ACTIONS(4708),
    [anon_sym_Not] = ACTIONS(4708),
    [anon_sym_POUNDelif] = ACTIONS(4710),
    [anon_sym_POUNDELIF] = ACTIONS(4710),
    [anon_sym_POUNDElif] = ACTIONS(4710),
    [anon_sym_POUNDelse] = ACTIONS(4710),
    [anon_sym_POUNDELSE] = ACTIONS(4710),
    [anon_sym_POUNDElse] = ACTIONS(4710),
    [anon_sym_POUNDendif] = ACTIONS(4710),
    [anon_sym_POUNDENDIF] = ACTIONS(4710),
    [anon_sym_POUNDEndif] = ACTIONS(4710),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4708),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4708),
    [anon_sym_PLUS] = ACTIONS(4710),
    [sym_datetime_literal] = ACTIONS(4710),
    [sym_date_literal] = ACTIONS(4708),
    [sym_time_literal] = ACTIONS(4708),
    [sym_biginteger_literal] = ACTIONS(4710),
    [anon_sym_if] = ACTIONS(4708),
    [anon_sym_IF] = ACTIONS(4708),
    [anon_sym_If] = ACTIONS(4708),
    [anon_sym_else] = ACTIONS(4708),
    [anon_sym_ELSE] = ACTIONS(4708),
    [anon_sym_Else] = ACTIONS(4708),
    [anon_sym_case] = ACTIONS(4708),
    [anon_sym_CASE] = ACTIONS(4708),
    [anon_sym_Case] = ACTIONS(4708),
    [anon_sym_for] = ACTIONS(4708),
    [anon_sym_FOR] = ACTIONS(4708),
    [anon_sym_For] = ACTIONS(4708),
    [anon_sym_foreach] = ACTIONS(4708),
    [anon_sym_FOREACH] = ACTIONS(4708),
    [anon_sym_Foreach] = ACTIONS(4708),
    [anon_sym_while] = ACTIONS(4708),
    [anon_sym_WHILE] = ACTIONS(4708),
    [anon_sym_While] = ACTIONS(4708),
    [anon_sym_repeat] = ACTIONS(4708),
    [anon_sym_REPEAT] = ACTIONS(4708),
    [anon_sym_Repeat] = ACTIONS(4708),
    [anon_sym_exit] = ACTIONS(4708),
    [anon_sym_EXIT] = ACTIONS(4708),
    [anon_sym_Exit] = ACTIONS(4708),
    [anon_sym_continue] = ACTIONS(4708),
    [anon_sym_CONTINUE] = ACTIONS(4708),
    [anon_sym_Continue] = ACTIONS(4708),
    [anon_sym_break] = ACTIONS(4708),
    [anon_sym_BREAK] = ACTIONS(4708),
    [anon_sym_Break] = ACTIONS(4708),
    [anon_sym_with] = ACTIONS(4708),
    [anon_sym_WITH] = ACTIONS(4708),
    [anon_sym_With] = ACTIONS(4708),
    [sym_asserterror_keyword] = ACTIONS(4710),
    [sym_page_keyword] = ACTIONS(4708),
    [anon_sym_codeunit] = ACTIONS(4708),
    [anon_sym_CODEUNIT] = ACTIONS(4708),
    [anon_sym_Codeunit] = ACTIONS(4708),
    [anon_sym_CodeUnit] = ACTIONS(4708),
    [anon_sym_COdeunit] = ACTIONS(4708),
    [anon_sym_codeUnit] = ACTIONS(4708),
    [sym_report_keyword] = ACTIONS(4708),
    [sym_query_keyword] = ACTIONS(4708),
    [anon_sym_xmlport] = ACTIONS(4708),
    [anon_sym_XMLPORT] = ACTIONS(4708),
    [anon_sym_Xmlport] = ACTIONS(4708),
    [anon_sym_XMLport] = ACTIONS(4708),
    [anon_sym_XMLPort] = ACTIONS(4708),
    [anon_sym_XmlPort] = ACTIONS(4708),
    [anon_sym_enum] = ACTIONS(4708),
    [anon_sym_ENUM] = ACTIONS(4708),
    [anon_sym_Enum] = ACTIONS(4708),
    [anon_sym_eNUM] = ACTIONS(4708),
    [anon_sym_eNum] = ACTIONS(4708),
    [anon_sym_ENum] = ACTIONS(4708),
    [sym_quoted_identifier] = ACTIONS(4710),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4710),
    [sym_integer] = ACTIONS(4708),
    [sym_continue_as_identifier] = ACTIONS(4710),
    [sym_preproc_open] = ACTIONS(4710),
    [sym_preproc_close] = ACTIONS(4710),
  },
  [STATE(1701)] = {
    [sym_identifier] = ACTIONS(4716),
    [anon_sym_SEMI] = ACTIONS(4718),
    [anon_sym_DASH] = ACTIONS(4718),
    [aux_sym_boolean_token1] = ACTIONS(4716),
    [aux_sym_boolean_token2] = ACTIONS(4716),
    [sym_decimal] = ACTIONS(4716),
    [anon_sym_LPAREN] = ACTIONS(4718),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4716),
    [anon_sym_LBRACK] = ACTIONS(4718),
    [aux_sym_record_type_token1] = ACTIONS(4716),
    [aux_sym_basic_type_token21] = ACTIONS(4716),
    [aux_sym_basic_type_token22] = ACTIONS(4716),
    [aux_sym_basic_type_token48] = ACTIONS(4716),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4716),
    [anon_sym_POUNDif] = ACTIONS(4718),
    [anon_sym_POUNDIF] = ACTIONS(4718),
    [anon_sym_POUNDIf] = ACTIONS(4718),
    [anon_sym_not] = ACTIONS(4716),
    [anon_sym_NOT] = ACTIONS(4716),
    [anon_sym_Not] = ACTIONS(4716),
    [anon_sym_POUNDelif] = ACTIONS(4718),
    [anon_sym_POUNDELIF] = ACTIONS(4718),
    [anon_sym_POUNDElif] = ACTIONS(4718),
    [anon_sym_POUNDelse] = ACTIONS(4718),
    [anon_sym_POUNDELSE] = ACTIONS(4718),
    [anon_sym_POUNDElse] = ACTIONS(4718),
    [anon_sym_POUNDendif] = ACTIONS(4718),
    [anon_sym_POUNDENDIF] = ACTIONS(4718),
    [anon_sym_POUNDEndif] = ACTIONS(4718),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4716),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4716),
    [anon_sym_PLUS] = ACTIONS(4718),
    [sym_datetime_literal] = ACTIONS(4718),
    [sym_date_literal] = ACTIONS(4716),
    [sym_time_literal] = ACTIONS(4716),
    [sym_biginteger_literal] = ACTIONS(4718),
    [anon_sym_if] = ACTIONS(4716),
    [anon_sym_IF] = ACTIONS(4716),
    [anon_sym_If] = ACTIONS(4716),
    [anon_sym_else] = ACTIONS(4716),
    [anon_sym_ELSE] = ACTIONS(4716),
    [anon_sym_Else] = ACTIONS(4716),
    [anon_sym_case] = ACTIONS(4716),
    [anon_sym_CASE] = ACTIONS(4716),
    [anon_sym_Case] = ACTIONS(4716),
    [anon_sym_for] = ACTIONS(4716),
    [anon_sym_FOR] = ACTIONS(4716),
    [anon_sym_For] = ACTIONS(4716),
    [anon_sym_foreach] = ACTIONS(4716),
    [anon_sym_FOREACH] = ACTIONS(4716),
    [anon_sym_Foreach] = ACTIONS(4716),
    [anon_sym_while] = ACTIONS(4716),
    [anon_sym_WHILE] = ACTIONS(4716),
    [anon_sym_While] = ACTIONS(4716),
    [anon_sym_repeat] = ACTIONS(4716),
    [anon_sym_REPEAT] = ACTIONS(4716),
    [anon_sym_Repeat] = ACTIONS(4716),
    [anon_sym_exit] = ACTIONS(4716),
    [anon_sym_EXIT] = ACTIONS(4716),
    [anon_sym_Exit] = ACTIONS(4716),
    [anon_sym_continue] = ACTIONS(4716),
    [anon_sym_CONTINUE] = ACTIONS(4716),
    [anon_sym_Continue] = ACTIONS(4716),
    [anon_sym_break] = ACTIONS(4716),
    [anon_sym_BREAK] = ACTIONS(4716),
    [anon_sym_Break] = ACTIONS(4716),
    [anon_sym_with] = ACTIONS(4716),
    [anon_sym_WITH] = ACTIONS(4716),
    [anon_sym_With] = ACTIONS(4716),
    [sym_asserterror_keyword] = ACTIONS(4718),
    [sym_page_keyword] = ACTIONS(4716),
    [anon_sym_codeunit] = ACTIONS(4716),
    [anon_sym_CODEUNIT] = ACTIONS(4716),
    [anon_sym_Codeunit] = ACTIONS(4716),
    [anon_sym_CodeUnit] = ACTIONS(4716),
    [anon_sym_COdeunit] = ACTIONS(4716),
    [anon_sym_codeUnit] = ACTIONS(4716),
    [sym_report_keyword] = ACTIONS(4716),
    [sym_query_keyword] = ACTIONS(4716),
    [anon_sym_xmlport] = ACTIONS(4716),
    [anon_sym_XMLPORT] = ACTIONS(4716),
    [anon_sym_Xmlport] = ACTIONS(4716),
    [anon_sym_XMLport] = ACTIONS(4716),
    [anon_sym_XMLPort] = ACTIONS(4716),
    [anon_sym_XmlPort] = ACTIONS(4716),
    [anon_sym_enum] = ACTIONS(4716),
    [anon_sym_ENUM] = ACTIONS(4716),
    [anon_sym_Enum] = ACTIONS(4716),
    [anon_sym_eNUM] = ACTIONS(4716),
    [anon_sym_eNum] = ACTIONS(4716),
    [anon_sym_ENum] = ACTIONS(4716),
    [sym_quoted_identifier] = ACTIONS(4718),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4718),
    [sym_integer] = ACTIONS(4716),
    [sym_continue_as_identifier] = ACTIONS(4718),
    [sym_preproc_open] = ACTIONS(4718),
    [sym_preproc_close] = ACTIONS(4718),
  },
  [STATE(1702)] = {
    [sym_identifier] = ACTIONS(4720),
    [anon_sym_SEMI] = ACTIONS(4722),
    [anon_sym_DASH] = ACTIONS(4722),
    [aux_sym_boolean_token1] = ACTIONS(4720),
    [aux_sym_boolean_token2] = ACTIONS(4720),
    [sym_decimal] = ACTIONS(4720),
    [anon_sym_LPAREN] = ACTIONS(4722),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4720),
    [anon_sym_LBRACK] = ACTIONS(4722),
    [aux_sym_record_type_token1] = ACTIONS(4720),
    [aux_sym_basic_type_token21] = ACTIONS(4720),
    [aux_sym_basic_type_token22] = ACTIONS(4720),
    [aux_sym_basic_type_token48] = ACTIONS(4720),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4720),
    [anon_sym_POUNDif] = ACTIONS(4722),
    [anon_sym_POUNDIF] = ACTIONS(4722),
    [anon_sym_POUNDIf] = ACTIONS(4722),
    [anon_sym_not] = ACTIONS(4720),
    [anon_sym_NOT] = ACTIONS(4720),
    [anon_sym_Not] = ACTIONS(4720),
    [anon_sym_POUNDelif] = ACTIONS(4722),
    [anon_sym_POUNDELIF] = ACTIONS(4722),
    [anon_sym_POUNDElif] = ACTIONS(4722),
    [anon_sym_POUNDelse] = ACTIONS(4722),
    [anon_sym_POUNDELSE] = ACTIONS(4722),
    [anon_sym_POUNDElse] = ACTIONS(4722),
    [anon_sym_POUNDendif] = ACTIONS(4722),
    [anon_sym_POUNDENDIF] = ACTIONS(4722),
    [anon_sym_POUNDEndif] = ACTIONS(4722),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4720),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4720),
    [anon_sym_PLUS] = ACTIONS(4722),
    [sym_datetime_literal] = ACTIONS(4722),
    [sym_date_literal] = ACTIONS(4720),
    [sym_time_literal] = ACTIONS(4720),
    [sym_biginteger_literal] = ACTIONS(4722),
    [anon_sym_if] = ACTIONS(4720),
    [anon_sym_IF] = ACTIONS(4720),
    [anon_sym_If] = ACTIONS(4720),
    [anon_sym_else] = ACTIONS(4720),
    [anon_sym_ELSE] = ACTIONS(4720),
    [anon_sym_Else] = ACTIONS(4720),
    [anon_sym_case] = ACTIONS(4720),
    [anon_sym_CASE] = ACTIONS(4720),
    [anon_sym_Case] = ACTIONS(4720),
    [anon_sym_for] = ACTIONS(4720),
    [anon_sym_FOR] = ACTIONS(4720),
    [anon_sym_For] = ACTIONS(4720),
    [anon_sym_foreach] = ACTIONS(4720),
    [anon_sym_FOREACH] = ACTIONS(4720),
    [anon_sym_Foreach] = ACTIONS(4720),
    [anon_sym_while] = ACTIONS(4720),
    [anon_sym_WHILE] = ACTIONS(4720),
    [anon_sym_While] = ACTIONS(4720),
    [anon_sym_repeat] = ACTIONS(4720),
    [anon_sym_REPEAT] = ACTIONS(4720),
    [anon_sym_Repeat] = ACTIONS(4720),
    [anon_sym_exit] = ACTIONS(4720),
    [anon_sym_EXIT] = ACTIONS(4720),
    [anon_sym_Exit] = ACTIONS(4720),
    [anon_sym_continue] = ACTIONS(4720),
    [anon_sym_CONTINUE] = ACTIONS(4720),
    [anon_sym_Continue] = ACTIONS(4720),
    [anon_sym_break] = ACTIONS(4720),
    [anon_sym_BREAK] = ACTIONS(4720),
    [anon_sym_Break] = ACTIONS(4720),
    [anon_sym_with] = ACTIONS(4720),
    [anon_sym_WITH] = ACTIONS(4720),
    [anon_sym_With] = ACTIONS(4720),
    [sym_asserterror_keyword] = ACTIONS(4722),
    [sym_page_keyword] = ACTIONS(4720),
    [anon_sym_codeunit] = ACTIONS(4720),
    [anon_sym_CODEUNIT] = ACTIONS(4720),
    [anon_sym_Codeunit] = ACTIONS(4720),
    [anon_sym_CodeUnit] = ACTIONS(4720),
    [anon_sym_COdeunit] = ACTIONS(4720),
    [anon_sym_codeUnit] = ACTIONS(4720),
    [sym_report_keyword] = ACTIONS(4720),
    [sym_query_keyword] = ACTIONS(4720),
    [anon_sym_xmlport] = ACTIONS(4720),
    [anon_sym_XMLPORT] = ACTIONS(4720),
    [anon_sym_Xmlport] = ACTIONS(4720),
    [anon_sym_XMLport] = ACTIONS(4720),
    [anon_sym_XMLPort] = ACTIONS(4720),
    [anon_sym_XmlPort] = ACTIONS(4720),
    [anon_sym_enum] = ACTIONS(4720),
    [anon_sym_ENUM] = ACTIONS(4720),
    [anon_sym_Enum] = ACTIONS(4720),
    [anon_sym_eNUM] = ACTIONS(4720),
    [anon_sym_eNum] = ACTIONS(4720),
    [anon_sym_ENum] = ACTIONS(4720),
    [sym_quoted_identifier] = ACTIONS(4722),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4722),
    [sym_integer] = ACTIONS(4720),
    [sym_continue_as_identifier] = ACTIONS(4722),
    [sym_preproc_open] = ACTIONS(4722),
    [sym_preproc_close] = ACTIONS(4722),
  },
  [STATE(1703)] = {
    [sym_identifier] = ACTIONS(4724),
    [anon_sym_SEMI] = ACTIONS(4726),
    [anon_sym_DASH] = ACTIONS(4726),
    [aux_sym_boolean_token1] = ACTIONS(4724),
    [aux_sym_boolean_token2] = ACTIONS(4724),
    [sym_decimal] = ACTIONS(4724),
    [anon_sym_LPAREN] = ACTIONS(4726),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4724),
    [anon_sym_LBRACK] = ACTIONS(4726),
    [aux_sym_record_type_token1] = ACTIONS(4724),
    [aux_sym_basic_type_token21] = ACTIONS(4724),
    [aux_sym_basic_type_token22] = ACTIONS(4724),
    [aux_sym_basic_type_token48] = ACTIONS(4724),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4724),
    [anon_sym_POUNDif] = ACTIONS(4726),
    [anon_sym_POUNDIF] = ACTIONS(4726),
    [anon_sym_POUNDIf] = ACTIONS(4726),
    [anon_sym_not] = ACTIONS(4724),
    [anon_sym_NOT] = ACTIONS(4724),
    [anon_sym_Not] = ACTIONS(4724),
    [anon_sym_POUNDelif] = ACTIONS(4726),
    [anon_sym_POUNDELIF] = ACTIONS(4726),
    [anon_sym_POUNDElif] = ACTIONS(4726),
    [anon_sym_POUNDelse] = ACTIONS(4726),
    [anon_sym_POUNDELSE] = ACTIONS(4726),
    [anon_sym_POUNDElse] = ACTIONS(4726),
    [anon_sym_POUNDendif] = ACTIONS(4726),
    [anon_sym_POUNDENDIF] = ACTIONS(4726),
    [anon_sym_POUNDEndif] = ACTIONS(4726),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4724),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4724),
    [anon_sym_PLUS] = ACTIONS(4726),
    [sym_datetime_literal] = ACTIONS(4726),
    [sym_date_literal] = ACTIONS(4724),
    [sym_time_literal] = ACTIONS(4724),
    [sym_biginteger_literal] = ACTIONS(4726),
    [anon_sym_if] = ACTIONS(4724),
    [anon_sym_IF] = ACTIONS(4724),
    [anon_sym_If] = ACTIONS(4724),
    [anon_sym_else] = ACTIONS(4724),
    [anon_sym_ELSE] = ACTIONS(4724),
    [anon_sym_Else] = ACTIONS(4724),
    [anon_sym_case] = ACTIONS(4724),
    [anon_sym_CASE] = ACTIONS(4724),
    [anon_sym_Case] = ACTIONS(4724),
    [anon_sym_for] = ACTIONS(4724),
    [anon_sym_FOR] = ACTIONS(4724),
    [anon_sym_For] = ACTIONS(4724),
    [anon_sym_foreach] = ACTIONS(4724),
    [anon_sym_FOREACH] = ACTIONS(4724),
    [anon_sym_Foreach] = ACTIONS(4724),
    [anon_sym_while] = ACTIONS(4724),
    [anon_sym_WHILE] = ACTIONS(4724),
    [anon_sym_While] = ACTIONS(4724),
    [anon_sym_repeat] = ACTIONS(4724),
    [anon_sym_REPEAT] = ACTIONS(4724),
    [anon_sym_Repeat] = ACTIONS(4724),
    [anon_sym_exit] = ACTIONS(4724),
    [anon_sym_EXIT] = ACTIONS(4724),
    [anon_sym_Exit] = ACTIONS(4724),
    [anon_sym_continue] = ACTIONS(4724),
    [anon_sym_CONTINUE] = ACTIONS(4724),
    [anon_sym_Continue] = ACTIONS(4724),
    [anon_sym_break] = ACTIONS(4724),
    [anon_sym_BREAK] = ACTIONS(4724),
    [anon_sym_Break] = ACTIONS(4724),
    [anon_sym_with] = ACTIONS(4724),
    [anon_sym_WITH] = ACTIONS(4724),
    [anon_sym_With] = ACTIONS(4724),
    [sym_asserterror_keyword] = ACTIONS(4726),
    [sym_page_keyword] = ACTIONS(4724),
    [anon_sym_codeunit] = ACTIONS(4724),
    [anon_sym_CODEUNIT] = ACTIONS(4724),
    [anon_sym_Codeunit] = ACTIONS(4724),
    [anon_sym_CodeUnit] = ACTIONS(4724),
    [anon_sym_COdeunit] = ACTIONS(4724),
    [anon_sym_codeUnit] = ACTIONS(4724),
    [sym_report_keyword] = ACTIONS(4724),
    [sym_query_keyword] = ACTIONS(4724),
    [anon_sym_xmlport] = ACTIONS(4724),
    [anon_sym_XMLPORT] = ACTIONS(4724),
    [anon_sym_Xmlport] = ACTIONS(4724),
    [anon_sym_XMLport] = ACTIONS(4724),
    [anon_sym_XMLPort] = ACTIONS(4724),
    [anon_sym_XmlPort] = ACTIONS(4724),
    [anon_sym_enum] = ACTIONS(4724),
    [anon_sym_ENUM] = ACTIONS(4724),
    [anon_sym_Enum] = ACTIONS(4724),
    [anon_sym_eNUM] = ACTIONS(4724),
    [anon_sym_eNum] = ACTIONS(4724),
    [anon_sym_ENum] = ACTIONS(4724),
    [sym_quoted_identifier] = ACTIONS(4726),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4726),
    [sym_integer] = ACTIONS(4724),
    [sym_continue_as_identifier] = ACTIONS(4726),
    [sym_preproc_open] = ACTIONS(4726),
    [sym_preproc_close] = ACTIONS(4726),
  },
  [STATE(1704)] = {
    [sym_identifier] = ACTIONS(4720),
    [anon_sym_SEMI] = ACTIONS(4722),
    [anon_sym_DASH] = ACTIONS(4722),
    [aux_sym_boolean_token1] = ACTIONS(4720),
    [aux_sym_boolean_token2] = ACTIONS(4720),
    [sym_decimal] = ACTIONS(4720),
    [anon_sym_LPAREN] = ACTIONS(4722),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4720),
    [anon_sym_LBRACK] = ACTIONS(4722),
    [aux_sym_record_type_token1] = ACTIONS(4720),
    [aux_sym_basic_type_token21] = ACTIONS(4720),
    [aux_sym_basic_type_token22] = ACTIONS(4720),
    [aux_sym_basic_type_token48] = ACTIONS(4720),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4720),
    [anon_sym_POUNDif] = ACTIONS(4722),
    [anon_sym_POUNDIF] = ACTIONS(4722),
    [anon_sym_POUNDIf] = ACTIONS(4722),
    [anon_sym_not] = ACTIONS(4720),
    [anon_sym_NOT] = ACTIONS(4720),
    [anon_sym_Not] = ACTIONS(4720),
    [anon_sym_POUNDelif] = ACTIONS(4722),
    [anon_sym_POUNDELIF] = ACTIONS(4722),
    [anon_sym_POUNDElif] = ACTIONS(4722),
    [anon_sym_POUNDelse] = ACTIONS(4722),
    [anon_sym_POUNDELSE] = ACTIONS(4722),
    [anon_sym_POUNDElse] = ACTIONS(4722),
    [anon_sym_POUNDendif] = ACTIONS(4722),
    [anon_sym_POUNDENDIF] = ACTIONS(4722),
    [anon_sym_POUNDEndif] = ACTIONS(4722),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4720),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4720),
    [anon_sym_PLUS] = ACTIONS(4722),
    [sym_datetime_literal] = ACTIONS(4722),
    [sym_date_literal] = ACTIONS(4720),
    [sym_time_literal] = ACTIONS(4720),
    [sym_biginteger_literal] = ACTIONS(4722),
    [anon_sym_if] = ACTIONS(4720),
    [anon_sym_IF] = ACTIONS(4720),
    [anon_sym_If] = ACTIONS(4720),
    [anon_sym_else] = ACTIONS(4720),
    [anon_sym_ELSE] = ACTIONS(4720),
    [anon_sym_Else] = ACTIONS(4720),
    [anon_sym_case] = ACTIONS(4720),
    [anon_sym_CASE] = ACTIONS(4720),
    [anon_sym_Case] = ACTIONS(4720),
    [anon_sym_for] = ACTIONS(4720),
    [anon_sym_FOR] = ACTIONS(4720),
    [anon_sym_For] = ACTIONS(4720),
    [anon_sym_foreach] = ACTIONS(4720),
    [anon_sym_FOREACH] = ACTIONS(4720),
    [anon_sym_Foreach] = ACTIONS(4720),
    [anon_sym_while] = ACTIONS(4720),
    [anon_sym_WHILE] = ACTIONS(4720),
    [anon_sym_While] = ACTIONS(4720),
    [anon_sym_repeat] = ACTIONS(4720),
    [anon_sym_REPEAT] = ACTIONS(4720),
    [anon_sym_Repeat] = ACTIONS(4720),
    [anon_sym_exit] = ACTIONS(4720),
    [anon_sym_EXIT] = ACTIONS(4720),
    [anon_sym_Exit] = ACTIONS(4720),
    [anon_sym_continue] = ACTIONS(4720),
    [anon_sym_CONTINUE] = ACTIONS(4720),
    [anon_sym_Continue] = ACTIONS(4720),
    [anon_sym_break] = ACTIONS(4720),
    [anon_sym_BREAK] = ACTIONS(4720),
    [anon_sym_Break] = ACTIONS(4720),
    [anon_sym_with] = ACTIONS(4720),
    [anon_sym_WITH] = ACTIONS(4720),
    [anon_sym_With] = ACTIONS(4720),
    [sym_asserterror_keyword] = ACTIONS(4722),
    [sym_page_keyword] = ACTIONS(4720),
    [anon_sym_codeunit] = ACTIONS(4720),
    [anon_sym_CODEUNIT] = ACTIONS(4720),
    [anon_sym_Codeunit] = ACTIONS(4720),
    [anon_sym_CodeUnit] = ACTIONS(4720),
    [anon_sym_COdeunit] = ACTIONS(4720),
    [anon_sym_codeUnit] = ACTIONS(4720),
    [sym_report_keyword] = ACTIONS(4720),
    [sym_query_keyword] = ACTIONS(4720),
    [anon_sym_xmlport] = ACTIONS(4720),
    [anon_sym_XMLPORT] = ACTIONS(4720),
    [anon_sym_Xmlport] = ACTIONS(4720),
    [anon_sym_XMLport] = ACTIONS(4720),
    [anon_sym_XMLPort] = ACTIONS(4720),
    [anon_sym_XmlPort] = ACTIONS(4720),
    [anon_sym_enum] = ACTIONS(4720),
    [anon_sym_ENUM] = ACTIONS(4720),
    [anon_sym_Enum] = ACTIONS(4720),
    [anon_sym_eNUM] = ACTIONS(4720),
    [anon_sym_eNum] = ACTIONS(4720),
    [anon_sym_ENum] = ACTIONS(4720),
    [sym_quoted_identifier] = ACTIONS(4722),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4722),
    [sym_integer] = ACTIONS(4720),
    [sym_continue_as_identifier] = ACTIONS(4722),
    [sym_preproc_open] = ACTIONS(4722),
    [sym_preproc_close] = ACTIONS(4722),
  },
  [STATE(1705)] = {
    [sym_identifier] = ACTIONS(4728),
    [anon_sym_SEMI] = ACTIONS(4730),
    [anon_sym_DASH] = ACTIONS(4730),
    [aux_sym_boolean_token1] = ACTIONS(4728),
    [aux_sym_boolean_token2] = ACTIONS(4728),
    [sym_decimal] = ACTIONS(4728),
    [anon_sym_LPAREN] = ACTIONS(4730),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4728),
    [anon_sym_LBRACK] = ACTIONS(4730),
    [aux_sym_record_type_token1] = ACTIONS(4728),
    [aux_sym_basic_type_token21] = ACTIONS(4728),
    [aux_sym_basic_type_token22] = ACTIONS(4728),
    [aux_sym_basic_type_token48] = ACTIONS(4728),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4728),
    [anon_sym_POUNDif] = ACTIONS(4730),
    [anon_sym_POUNDIF] = ACTIONS(4730),
    [anon_sym_POUNDIf] = ACTIONS(4730),
    [anon_sym_not] = ACTIONS(4728),
    [anon_sym_NOT] = ACTIONS(4728),
    [anon_sym_Not] = ACTIONS(4728),
    [anon_sym_POUNDelif] = ACTIONS(4730),
    [anon_sym_POUNDELIF] = ACTIONS(4730),
    [anon_sym_POUNDElif] = ACTIONS(4730),
    [anon_sym_POUNDelse] = ACTIONS(4730),
    [anon_sym_POUNDELSE] = ACTIONS(4730),
    [anon_sym_POUNDElse] = ACTIONS(4730),
    [anon_sym_POUNDendif] = ACTIONS(4730),
    [anon_sym_POUNDENDIF] = ACTIONS(4730),
    [anon_sym_POUNDEndif] = ACTIONS(4730),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4728),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4728),
    [anon_sym_PLUS] = ACTIONS(4730),
    [sym_datetime_literal] = ACTIONS(4730),
    [sym_date_literal] = ACTIONS(4728),
    [sym_time_literal] = ACTIONS(4728),
    [sym_biginteger_literal] = ACTIONS(4730),
    [anon_sym_if] = ACTIONS(4728),
    [anon_sym_IF] = ACTIONS(4728),
    [anon_sym_If] = ACTIONS(4728),
    [anon_sym_else] = ACTIONS(4728),
    [anon_sym_ELSE] = ACTIONS(4728),
    [anon_sym_Else] = ACTIONS(4728),
    [anon_sym_case] = ACTIONS(4728),
    [anon_sym_CASE] = ACTIONS(4728),
    [anon_sym_Case] = ACTIONS(4728),
    [anon_sym_for] = ACTIONS(4728),
    [anon_sym_FOR] = ACTIONS(4728),
    [anon_sym_For] = ACTIONS(4728),
    [anon_sym_foreach] = ACTIONS(4728),
    [anon_sym_FOREACH] = ACTIONS(4728),
    [anon_sym_Foreach] = ACTIONS(4728),
    [anon_sym_while] = ACTIONS(4728),
    [anon_sym_WHILE] = ACTIONS(4728),
    [anon_sym_While] = ACTIONS(4728),
    [anon_sym_repeat] = ACTIONS(4728),
    [anon_sym_REPEAT] = ACTIONS(4728),
    [anon_sym_Repeat] = ACTIONS(4728),
    [anon_sym_exit] = ACTIONS(4728),
    [anon_sym_EXIT] = ACTIONS(4728),
    [anon_sym_Exit] = ACTIONS(4728),
    [anon_sym_continue] = ACTIONS(4728),
    [anon_sym_CONTINUE] = ACTIONS(4728),
    [anon_sym_Continue] = ACTIONS(4728),
    [anon_sym_break] = ACTIONS(4728),
    [anon_sym_BREAK] = ACTIONS(4728),
    [anon_sym_Break] = ACTIONS(4728),
    [anon_sym_with] = ACTIONS(4728),
    [anon_sym_WITH] = ACTIONS(4728),
    [anon_sym_With] = ACTIONS(4728),
    [sym_asserterror_keyword] = ACTIONS(4730),
    [sym_page_keyword] = ACTIONS(4728),
    [anon_sym_codeunit] = ACTIONS(4728),
    [anon_sym_CODEUNIT] = ACTIONS(4728),
    [anon_sym_Codeunit] = ACTIONS(4728),
    [anon_sym_CodeUnit] = ACTIONS(4728),
    [anon_sym_COdeunit] = ACTIONS(4728),
    [anon_sym_codeUnit] = ACTIONS(4728),
    [sym_report_keyword] = ACTIONS(4728),
    [sym_query_keyword] = ACTIONS(4728),
    [anon_sym_xmlport] = ACTIONS(4728),
    [anon_sym_XMLPORT] = ACTIONS(4728),
    [anon_sym_Xmlport] = ACTIONS(4728),
    [anon_sym_XMLport] = ACTIONS(4728),
    [anon_sym_XMLPort] = ACTIONS(4728),
    [anon_sym_XmlPort] = ACTIONS(4728),
    [anon_sym_enum] = ACTIONS(4728),
    [anon_sym_ENUM] = ACTIONS(4728),
    [anon_sym_Enum] = ACTIONS(4728),
    [anon_sym_eNUM] = ACTIONS(4728),
    [anon_sym_eNum] = ACTIONS(4728),
    [anon_sym_ENum] = ACTIONS(4728),
    [sym_quoted_identifier] = ACTIONS(4730),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4730),
    [sym_integer] = ACTIONS(4728),
    [sym_continue_as_identifier] = ACTIONS(4730),
    [sym_preproc_open] = ACTIONS(4730),
    [sym_preproc_close] = ACTIONS(4730),
  },
  [STATE(1706)] = {
    [sym_identifier] = ACTIONS(4732),
    [anon_sym_SEMI] = ACTIONS(4734),
    [anon_sym_DASH] = ACTIONS(4734),
    [aux_sym_boolean_token1] = ACTIONS(4732),
    [aux_sym_boolean_token2] = ACTIONS(4732),
    [sym_decimal] = ACTIONS(4732),
    [anon_sym_LPAREN] = ACTIONS(4734),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4732),
    [anon_sym_LBRACK] = ACTIONS(4734),
    [aux_sym_record_type_token1] = ACTIONS(4732),
    [aux_sym_basic_type_token21] = ACTIONS(4732),
    [aux_sym_basic_type_token22] = ACTIONS(4732),
    [aux_sym_basic_type_token48] = ACTIONS(4732),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4732),
    [anon_sym_POUNDif] = ACTIONS(4734),
    [anon_sym_POUNDIF] = ACTIONS(4734),
    [anon_sym_POUNDIf] = ACTIONS(4734),
    [anon_sym_not] = ACTIONS(4732),
    [anon_sym_NOT] = ACTIONS(4732),
    [anon_sym_Not] = ACTIONS(4732),
    [anon_sym_POUNDelif] = ACTIONS(4734),
    [anon_sym_POUNDELIF] = ACTIONS(4734),
    [anon_sym_POUNDElif] = ACTIONS(4734),
    [anon_sym_POUNDelse] = ACTIONS(4734),
    [anon_sym_POUNDELSE] = ACTIONS(4734),
    [anon_sym_POUNDElse] = ACTIONS(4734),
    [anon_sym_POUNDendif] = ACTIONS(4734),
    [anon_sym_POUNDENDIF] = ACTIONS(4734),
    [anon_sym_POUNDEndif] = ACTIONS(4734),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4732),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4732),
    [anon_sym_PLUS] = ACTIONS(4734),
    [sym_datetime_literal] = ACTIONS(4734),
    [sym_date_literal] = ACTIONS(4732),
    [sym_time_literal] = ACTIONS(4732),
    [sym_biginteger_literal] = ACTIONS(4734),
    [anon_sym_if] = ACTIONS(4732),
    [anon_sym_IF] = ACTIONS(4732),
    [anon_sym_If] = ACTIONS(4732),
    [anon_sym_else] = ACTIONS(4732),
    [anon_sym_ELSE] = ACTIONS(4732),
    [anon_sym_Else] = ACTIONS(4732),
    [anon_sym_case] = ACTIONS(4732),
    [anon_sym_CASE] = ACTIONS(4732),
    [anon_sym_Case] = ACTIONS(4732),
    [anon_sym_for] = ACTIONS(4732),
    [anon_sym_FOR] = ACTIONS(4732),
    [anon_sym_For] = ACTIONS(4732),
    [anon_sym_foreach] = ACTIONS(4732),
    [anon_sym_FOREACH] = ACTIONS(4732),
    [anon_sym_Foreach] = ACTIONS(4732),
    [anon_sym_while] = ACTIONS(4732),
    [anon_sym_WHILE] = ACTIONS(4732),
    [anon_sym_While] = ACTIONS(4732),
    [anon_sym_repeat] = ACTIONS(4732),
    [anon_sym_REPEAT] = ACTIONS(4732),
    [anon_sym_Repeat] = ACTIONS(4732),
    [anon_sym_exit] = ACTIONS(4732),
    [anon_sym_EXIT] = ACTIONS(4732),
    [anon_sym_Exit] = ACTIONS(4732),
    [anon_sym_continue] = ACTIONS(4732),
    [anon_sym_CONTINUE] = ACTIONS(4732),
    [anon_sym_Continue] = ACTIONS(4732),
    [anon_sym_break] = ACTIONS(4732),
    [anon_sym_BREAK] = ACTIONS(4732),
    [anon_sym_Break] = ACTIONS(4732),
    [anon_sym_with] = ACTIONS(4732),
    [anon_sym_WITH] = ACTIONS(4732),
    [anon_sym_With] = ACTIONS(4732),
    [sym_asserterror_keyword] = ACTIONS(4734),
    [sym_page_keyword] = ACTIONS(4732),
    [anon_sym_codeunit] = ACTIONS(4732),
    [anon_sym_CODEUNIT] = ACTIONS(4732),
    [anon_sym_Codeunit] = ACTIONS(4732),
    [anon_sym_CodeUnit] = ACTIONS(4732),
    [anon_sym_COdeunit] = ACTIONS(4732),
    [anon_sym_codeUnit] = ACTIONS(4732),
    [sym_report_keyword] = ACTIONS(4732),
    [sym_query_keyword] = ACTIONS(4732),
    [anon_sym_xmlport] = ACTIONS(4732),
    [anon_sym_XMLPORT] = ACTIONS(4732),
    [anon_sym_Xmlport] = ACTIONS(4732),
    [anon_sym_XMLport] = ACTIONS(4732),
    [anon_sym_XMLPort] = ACTIONS(4732),
    [anon_sym_XmlPort] = ACTIONS(4732),
    [anon_sym_enum] = ACTIONS(4732),
    [anon_sym_ENUM] = ACTIONS(4732),
    [anon_sym_Enum] = ACTIONS(4732),
    [anon_sym_eNUM] = ACTIONS(4732),
    [anon_sym_eNum] = ACTIONS(4732),
    [anon_sym_ENum] = ACTIONS(4732),
    [sym_quoted_identifier] = ACTIONS(4734),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4734),
    [sym_integer] = ACTIONS(4732),
    [sym_continue_as_identifier] = ACTIONS(4734),
    [sym_preproc_open] = ACTIONS(4734),
    [sym_preproc_close] = ACTIONS(4734),
  },
  [STATE(1707)] = {
    [sym_identifier] = ACTIONS(4728),
    [anon_sym_SEMI] = ACTIONS(4730),
    [anon_sym_DASH] = ACTIONS(4730),
    [aux_sym_boolean_token1] = ACTIONS(4728),
    [aux_sym_boolean_token2] = ACTIONS(4728),
    [sym_decimal] = ACTIONS(4728),
    [anon_sym_LPAREN] = ACTIONS(4730),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4728),
    [anon_sym_LBRACK] = ACTIONS(4730),
    [aux_sym_record_type_token1] = ACTIONS(4728),
    [aux_sym_basic_type_token21] = ACTIONS(4728),
    [aux_sym_basic_type_token22] = ACTIONS(4728),
    [aux_sym_basic_type_token48] = ACTIONS(4728),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4728),
    [anon_sym_POUNDif] = ACTIONS(4730),
    [anon_sym_POUNDIF] = ACTIONS(4730),
    [anon_sym_POUNDIf] = ACTIONS(4730),
    [anon_sym_not] = ACTIONS(4728),
    [anon_sym_NOT] = ACTIONS(4728),
    [anon_sym_Not] = ACTIONS(4728),
    [anon_sym_POUNDelif] = ACTIONS(4730),
    [anon_sym_POUNDELIF] = ACTIONS(4730),
    [anon_sym_POUNDElif] = ACTIONS(4730),
    [anon_sym_POUNDelse] = ACTIONS(4730),
    [anon_sym_POUNDELSE] = ACTIONS(4730),
    [anon_sym_POUNDElse] = ACTIONS(4730),
    [anon_sym_POUNDendif] = ACTIONS(4730),
    [anon_sym_POUNDENDIF] = ACTIONS(4730),
    [anon_sym_POUNDEndif] = ACTIONS(4730),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4728),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4728),
    [anon_sym_PLUS] = ACTIONS(4730),
    [sym_datetime_literal] = ACTIONS(4730),
    [sym_date_literal] = ACTIONS(4728),
    [sym_time_literal] = ACTIONS(4728),
    [sym_biginteger_literal] = ACTIONS(4730),
    [anon_sym_if] = ACTIONS(4728),
    [anon_sym_IF] = ACTIONS(4728),
    [anon_sym_If] = ACTIONS(4728),
    [anon_sym_else] = ACTIONS(4728),
    [anon_sym_ELSE] = ACTIONS(4728),
    [anon_sym_Else] = ACTIONS(4728),
    [anon_sym_case] = ACTIONS(4728),
    [anon_sym_CASE] = ACTIONS(4728),
    [anon_sym_Case] = ACTIONS(4728),
    [anon_sym_for] = ACTIONS(4728),
    [anon_sym_FOR] = ACTIONS(4728),
    [anon_sym_For] = ACTIONS(4728),
    [anon_sym_foreach] = ACTIONS(4728),
    [anon_sym_FOREACH] = ACTIONS(4728),
    [anon_sym_Foreach] = ACTIONS(4728),
    [anon_sym_while] = ACTIONS(4728),
    [anon_sym_WHILE] = ACTIONS(4728),
    [anon_sym_While] = ACTIONS(4728),
    [anon_sym_repeat] = ACTIONS(4728),
    [anon_sym_REPEAT] = ACTIONS(4728),
    [anon_sym_Repeat] = ACTIONS(4728),
    [anon_sym_exit] = ACTIONS(4728),
    [anon_sym_EXIT] = ACTIONS(4728),
    [anon_sym_Exit] = ACTIONS(4728),
    [anon_sym_continue] = ACTIONS(4728),
    [anon_sym_CONTINUE] = ACTIONS(4728),
    [anon_sym_Continue] = ACTIONS(4728),
    [anon_sym_break] = ACTIONS(4728),
    [anon_sym_BREAK] = ACTIONS(4728),
    [anon_sym_Break] = ACTIONS(4728),
    [anon_sym_with] = ACTIONS(4728),
    [anon_sym_WITH] = ACTIONS(4728),
    [anon_sym_With] = ACTIONS(4728),
    [sym_asserterror_keyword] = ACTIONS(4730),
    [sym_page_keyword] = ACTIONS(4728),
    [anon_sym_codeunit] = ACTIONS(4728),
    [anon_sym_CODEUNIT] = ACTIONS(4728),
    [anon_sym_Codeunit] = ACTIONS(4728),
    [anon_sym_CodeUnit] = ACTIONS(4728),
    [anon_sym_COdeunit] = ACTIONS(4728),
    [anon_sym_codeUnit] = ACTIONS(4728),
    [sym_report_keyword] = ACTIONS(4728),
    [sym_query_keyword] = ACTIONS(4728),
    [anon_sym_xmlport] = ACTIONS(4728),
    [anon_sym_XMLPORT] = ACTIONS(4728),
    [anon_sym_Xmlport] = ACTIONS(4728),
    [anon_sym_XMLport] = ACTIONS(4728),
    [anon_sym_XMLPort] = ACTIONS(4728),
    [anon_sym_XmlPort] = ACTIONS(4728),
    [anon_sym_enum] = ACTIONS(4728),
    [anon_sym_ENUM] = ACTIONS(4728),
    [anon_sym_Enum] = ACTIONS(4728),
    [anon_sym_eNUM] = ACTIONS(4728),
    [anon_sym_eNum] = ACTIONS(4728),
    [anon_sym_ENum] = ACTIONS(4728),
    [sym_quoted_identifier] = ACTIONS(4730),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4730),
    [sym_integer] = ACTIONS(4728),
    [sym_continue_as_identifier] = ACTIONS(4730),
    [sym_preproc_open] = ACTIONS(4730),
    [sym_preproc_close] = ACTIONS(4730),
  },
  [STATE(1708)] = {
    [sym_identifier] = ACTIONS(4736),
    [anon_sym_SEMI] = ACTIONS(4738),
    [anon_sym_DASH] = ACTIONS(4738),
    [aux_sym_boolean_token1] = ACTIONS(4736),
    [aux_sym_boolean_token2] = ACTIONS(4736),
    [sym_decimal] = ACTIONS(4736),
    [anon_sym_LPAREN] = ACTIONS(4738),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4736),
    [anon_sym_LBRACK] = ACTIONS(4738),
    [aux_sym_record_type_token1] = ACTIONS(4736),
    [aux_sym_basic_type_token21] = ACTIONS(4736),
    [aux_sym_basic_type_token22] = ACTIONS(4736),
    [aux_sym_basic_type_token48] = ACTIONS(4736),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4736),
    [anon_sym_POUNDif] = ACTIONS(4738),
    [anon_sym_POUNDIF] = ACTIONS(4738),
    [anon_sym_POUNDIf] = ACTIONS(4738),
    [anon_sym_not] = ACTIONS(4736),
    [anon_sym_NOT] = ACTIONS(4736),
    [anon_sym_Not] = ACTIONS(4736),
    [anon_sym_POUNDelif] = ACTIONS(4738),
    [anon_sym_POUNDELIF] = ACTIONS(4738),
    [anon_sym_POUNDElif] = ACTIONS(4738),
    [anon_sym_POUNDelse] = ACTIONS(4738),
    [anon_sym_POUNDELSE] = ACTIONS(4738),
    [anon_sym_POUNDElse] = ACTIONS(4738),
    [anon_sym_POUNDendif] = ACTIONS(4738),
    [anon_sym_POUNDENDIF] = ACTIONS(4738),
    [anon_sym_POUNDEndif] = ACTIONS(4738),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4736),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4736),
    [anon_sym_PLUS] = ACTIONS(4738),
    [sym_datetime_literal] = ACTIONS(4738),
    [sym_date_literal] = ACTIONS(4736),
    [sym_time_literal] = ACTIONS(4736),
    [sym_biginteger_literal] = ACTIONS(4738),
    [anon_sym_if] = ACTIONS(4736),
    [anon_sym_IF] = ACTIONS(4736),
    [anon_sym_If] = ACTIONS(4736),
    [anon_sym_else] = ACTIONS(4736),
    [anon_sym_ELSE] = ACTIONS(4736),
    [anon_sym_Else] = ACTIONS(4736),
    [anon_sym_case] = ACTIONS(4736),
    [anon_sym_CASE] = ACTIONS(4736),
    [anon_sym_Case] = ACTIONS(4736),
    [anon_sym_for] = ACTIONS(4736),
    [anon_sym_FOR] = ACTIONS(4736),
    [anon_sym_For] = ACTIONS(4736),
    [anon_sym_foreach] = ACTIONS(4736),
    [anon_sym_FOREACH] = ACTIONS(4736),
    [anon_sym_Foreach] = ACTIONS(4736),
    [anon_sym_while] = ACTIONS(4736),
    [anon_sym_WHILE] = ACTIONS(4736),
    [anon_sym_While] = ACTIONS(4736),
    [anon_sym_repeat] = ACTIONS(4736),
    [anon_sym_REPEAT] = ACTIONS(4736),
    [anon_sym_Repeat] = ACTIONS(4736),
    [anon_sym_exit] = ACTIONS(4736),
    [anon_sym_EXIT] = ACTIONS(4736),
    [anon_sym_Exit] = ACTIONS(4736),
    [anon_sym_continue] = ACTIONS(4736),
    [anon_sym_CONTINUE] = ACTIONS(4736),
    [anon_sym_Continue] = ACTIONS(4736),
    [anon_sym_break] = ACTIONS(4736),
    [anon_sym_BREAK] = ACTIONS(4736),
    [anon_sym_Break] = ACTIONS(4736),
    [anon_sym_with] = ACTIONS(4736),
    [anon_sym_WITH] = ACTIONS(4736),
    [anon_sym_With] = ACTIONS(4736),
    [sym_asserterror_keyword] = ACTIONS(4738),
    [sym_page_keyword] = ACTIONS(4736),
    [anon_sym_codeunit] = ACTIONS(4736),
    [anon_sym_CODEUNIT] = ACTIONS(4736),
    [anon_sym_Codeunit] = ACTIONS(4736),
    [anon_sym_CodeUnit] = ACTIONS(4736),
    [anon_sym_COdeunit] = ACTIONS(4736),
    [anon_sym_codeUnit] = ACTIONS(4736),
    [sym_report_keyword] = ACTIONS(4736),
    [sym_query_keyword] = ACTIONS(4736),
    [anon_sym_xmlport] = ACTIONS(4736),
    [anon_sym_XMLPORT] = ACTIONS(4736),
    [anon_sym_Xmlport] = ACTIONS(4736),
    [anon_sym_XMLport] = ACTIONS(4736),
    [anon_sym_XMLPort] = ACTIONS(4736),
    [anon_sym_XmlPort] = ACTIONS(4736),
    [anon_sym_enum] = ACTIONS(4736),
    [anon_sym_ENUM] = ACTIONS(4736),
    [anon_sym_Enum] = ACTIONS(4736),
    [anon_sym_eNUM] = ACTIONS(4736),
    [anon_sym_eNum] = ACTIONS(4736),
    [anon_sym_ENum] = ACTIONS(4736),
    [sym_quoted_identifier] = ACTIONS(4738),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4738),
    [sym_integer] = ACTIONS(4736),
    [sym_continue_as_identifier] = ACTIONS(4738),
    [sym_preproc_open] = ACTIONS(4738),
    [sym_preproc_close] = ACTIONS(4738),
  },
  [STATE(1709)] = {
    [sym_identifier] = ACTIONS(4740),
    [anon_sym_SEMI] = ACTIONS(4742),
    [anon_sym_DASH] = ACTIONS(4742),
    [aux_sym_boolean_token1] = ACTIONS(4740),
    [aux_sym_boolean_token2] = ACTIONS(4740),
    [sym_decimal] = ACTIONS(4740),
    [anon_sym_LPAREN] = ACTIONS(4742),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4740),
    [anon_sym_LBRACK] = ACTIONS(4742),
    [aux_sym_record_type_token1] = ACTIONS(4740),
    [aux_sym_basic_type_token21] = ACTIONS(4740),
    [aux_sym_basic_type_token22] = ACTIONS(4740),
    [aux_sym_basic_type_token48] = ACTIONS(4740),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4740),
    [anon_sym_POUNDif] = ACTIONS(4742),
    [anon_sym_POUNDIF] = ACTIONS(4742),
    [anon_sym_POUNDIf] = ACTIONS(4742),
    [anon_sym_not] = ACTIONS(4740),
    [anon_sym_NOT] = ACTIONS(4740),
    [anon_sym_Not] = ACTIONS(4740),
    [anon_sym_POUNDelif] = ACTIONS(4742),
    [anon_sym_POUNDELIF] = ACTIONS(4742),
    [anon_sym_POUNDElif] = ACTIONS(4742),
    [anon_sym_POUNDelse] = ACTIONS(4742),
    [anon_sym_POUNDELSE] = ACTIONS(4742),
    [anon_sym_POUNDElse] = ACTIONS(4742),
    [anon_sym_POUNDendif] = ACTIONS(4742),
    [anon_sym_POUNDENDIF] = ACTIONS(4742),
    [anon_sym_POUNDEndif] = ACTIONS(4742),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4740),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4740),
    [anon_sym_PLUS] = ACTIONS(4742),
    [sym_datetime_literal] = ACTIONS(4742),
    [sym_date_literal] = ACTIONS(4740),
    [sym_time_literal] = ACTIONS(4740),
    [sym_biginteger_literal] = ACTIONS(4742),
    [anon_sym_if] = ACTIONS(4740),
    [anon_sym_IF] = ACTIONS(4740),
    [anon_sym_If] = ACTIONS(4740),
    [anon_sym_else] = ACTIONS(4740),
    [anon_sym_ELSE] = ACTIONS(4740),
    [anon_sym_Else] = ACTIONS(4740),
    [anon_sym_case] = ACTIONS(4740),
    [anon_sym_CASE] = ACTIONS(4740),
    [anon_sym_Case] = ACTIONS(4740),
    [anon_sym_for] = ACTIONS(4740),
    [anon_sym_FOR] = ACTIONS(4740),
    [anon_sym_For] = ACTIONS(4740),
    [anon_sym_foreach] = ACTIONS(4740),
    [anon_sym_FOREACH] = ACTIONS(4740),
    [anon_sym_Foreach] = ACTIONS(4740),
    [anon_sym_while] = ACTIONS(4740),
    [anon_sym_WHILE] = ACTIONS(4740),
    [anon_sym_While] = ACTIONS(4740),
    [anon_sym_repeat] = ACTIONS(4740),
    [anon_sym_REPEAT] = ACTIONS(4740),
    [anon_sym_Repeat] = ACTIONS(4740),
    [anon_sym_exit] = ACTIONS(4740),
    [anon_sym_EXIT] = ACTIONS(4740),
    [anon_sym_Exit] = ACTIONS(4740),
    [anon_sym_continue] = ACTIONS(4740),
    [anon_sym_CONTINUE] = ACTIONS(4740),
    [anon_sym_Continue] = ACTIONS(4740),
    [anon_sym_break] = ACTIONS(4740),
    [anon_sym_BREAK] = ACTIONS(4740),
    [anon_sym_Break] = ACTIONS(4740),
    [anon_sym_with] = ACTIONS(4740),
    [anon_sym_WITH] = ACTIONS(4740),
    [anon_sym_With] = ACTIONS(4740),
    [sym_asserterror_keyword] = ACTIONS(4742),
    [sym_page_keyword] = ACTIONS(4740),
    [anon_sym_codeunit] = ACTIONS(4740),
    [anon_sym_CODEUNIT] = ACTIONS(4740),
    [anon_sym_Codeunit] = ACTIONS(4740),
    [anon_sym_CodeUnit] = ACTIONS(4740),
    [anon_sym_COdeunit] = ACTIONS(4740),
    [anon_sym_codeUnit] = ACTIONS(4740),
    [sym_report_keyword] = ACTIONS(4740),
    [sym_query_keyword] = ACTIONS(4740),
    [anon_sym_xmlport] = ACTIONS(4740),
    [anon_sym_XMLPORT] = ACTIONS(4740),
    [anon_sym_Xmlport] = ACTIONS(4740),
    [anon_sym_XMLport] = ACTIONS(4740),
    [anon_sym_XMLPort] = ACTIONS(4740),
    [anon_sym_XmlPort] = ACTIONS(4740),
    [anon_sym_enum] = ACTIONS(4740),
    [anon_sym_ENUM] = ACTIONS(4740),
    [anon_sym_Enum] = ACTIONS(4740),
    [anon_sym_eNUM] = ACTIONS(4740),
    [anon_sym_eNum] = ACTIONS(4740),
    [anon_sym_ENum] = ACTIONS(4740),
    [sym_quoted_identifier] = ACTIONS(4742),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4742),
    [sym_integer] = ACTIONS(4740),
    [sym_continue_as_identifier] = ACTIONS(4742),
    [sym_preproc_open] = ACTIONS(4742),
    [sym_preproc_close] = ACTIONS(4742),
  },
  [STATE(1710)] = {
    [sym_identifier] = ACTIONS(4744),
    [anon_sym_SEMI] = ACTIONS(4746),
    [anon_sym_DASH] = ACTIONS(4746),
    [aux_sym_boolean_token1] = ACTIONS(4744),
    [aux_sym_boolean_token2] = ACTIONS(4744),
    [sym_decimal] = ACTIONS(4744),
    [anon_sym_LPAREN] = ACTIONS(4746),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4744),
    [anon_sym_LBRACK] = ACTIONS(4746),
    [aux_sym_record_type_token1] = ACTIONS(4744),
    [aux_sym_basic_type_token21] = ACTIONS(4744),
    [aux_sym_basic_type_token22] = ACTIONS(4744),
    [aux_sym_basic_type_token48] = ACTIONS(4744),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4744),
    [anon_sym_POUNDif] = ACTIONS(4746),
    [anon_sym_POUNDIF] = ACTIONS(4746),
    [anon_sym_POUNDIf] = ACTIONS(4746),
    [anon_sym_not] = ACTIONS(4744),
    [anon_sym_NOT] = ACTIONS(4744),
    [anon_sym_Not] = ACTIONS(4744),
    [anon_sym_POUNDelif] = ACTIONS(4746),
    [anon_sym_POUNDELIF] = ACTIONS(4746),
    [anon_sym_POUNDElif] = ACTIONS(4746),
    [anon_sym_POUNDelse] = ACTIONS(4746),
    [anon_sym_POUNDELSE] = ACTIONS(4746),
    [anon_sym_POUNDElse] = ACTIONS(4746),
    [anon_sym_POUNDendif] = ACTIONS(4746),
    [anon_sym_POUNDENDIF] = ACTIONS(4746),
    [anon_sym_POUNDEndif] = ACTIONS(4746),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4744),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4744),
    [anon_sym_PLUS] = ACTIONS(4746),
    [sym_datetime_literal] = ACTIONS(4746),
    [sym_date_literal] = ACTIONS(4744),
    [sym_time_literal] = ACTIONS(4744),
    [sym_biginteger_literal] = ACTIONS(4746),
    [anon_sym_if] = ACTIONS(4744),
    [anon_sym_IF] = ACTIONS(4744),
    [anon_sym_If] = ACTIONS(4744),
    [anon_sym_else] = ACTIONS(4744),
    [anon_sym_ELSE] = ACTIONS(4744),
    [anon_sym_Else] = ACTIONS(4744),
    [anon_sym_case] = ACTIONS(4744),
    [anon_sym_CASE] = ACTIONS(4744),
    [anon_sym_Case] = ACTIONS(4744),
    [anon_sym_for] = ACTIONS(4744),
    [anon_sym_FOR] = ACTIONS(4744),
    [anon_sym_For] = ACTIONS(4744),
    [anon_sym_foreach] = ACTIONS(4744),
    [anon_sym_FOREACH] = ACTIONS(4744),
    [anon_sym_Foreach] = ACTIONS(4744),
    [anon_sym_while] = ACTIONS(4744),
    [anon_sym_WHILE] = ACTIONS(4744),
    [anon_sym_While] = ACTIONS(4744),
    [anon_sym_repeat] = ACTIONS(4744),
    [anon_sym_REPEAT] = ACTIONS(4744),
    [anon_sym_Repeat] = ACTIONS(4744),
    [anon_sym_exit] = ACTIONS(4744),
    [anon_sym_EXIT] = ACTIONS(4744),
    [anon_sym_Exit] = ACTIONS(4744),
    [anon_sym_continue] = ACTIONS(4744),
    [anon_sym_CONTINUE] = ACTIONS(4744),
    [anon_sym_Continue] = ACTIONS(4744),
    [anon_sym_break] = ACTIONS(4744),
    [anon_sym_BREAK] = ACTIONS(4744),
    [anon_sym_Break] = ACTIONS(4744),
    [anon_sym_with] = ACTIONS(4744),
    [anon_sym_WITH] = ACTIONS(4744),
    [anon_sym_With] = ACTIONS(4744),
    [sym_asserterror_keyword] = ACTIONS(4746),
    [sym_page_keyword] = ACTIONS(4744),
    [anon_sym_codeunit] = ACTIONS(4744),
    [anon_sym_CODEUNIT] = ACTIONS(4744),
    [anon_sym_Codeunit] = ACTIONS(4744),
    [anon_sym_CodeUnit] = ACTIONS(4744),
    [anon_sym_COdeunit] = ACTIONS(4744),
    [anon_sym_codeUnit] = ACTIONS(4744),
    [sym_report_keyword] = ACTIONS(4744),
    [sym_query_keyword] = ACTIONS(4744),
    [anon_sym_xmlport] = ACTIONS(4744),
    [anon_sym_XMLPORT] = ACTIONS(4744),
    [anon_sym_Xmlport] = ACTIONS(4744),
    [anon_sym_XMLport] = ACTIONS(4744),
    [anon_sym_XMLPort] = ACTIONS(4744),
    [anon_sym_XmlPort] = ACTIONS(4744),
    [anon_sym_enum] = ACTIONS(4744),
    [anon_sym_ENUM] = ACTIONS(4744),
    [anon_sym_Enum] = ACTIONS(4744),
    [anon_sym_eNUM] = ACTIONS(4744),
    [anon_sym_eNum] = ACTIONS(4744),
    [anon_sym_ENum] = ACTIONS(4744),
    [sym_quoted_identifier] = ACTIONS(4746),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4746),
    [sym_integer] = ACTIONS(4744),
    [sym_continue_as_identifier] = ACTIONS(4746),
    [sym_preproc_open] = ACTIONS(4746),
    [sym_preproc_close] = ACTIONS(4746),
  },
  [STATE(1711)] = {
    [sym_identifier] = ACTIONS(4748),
    [anon_sym_SEMI] = ACTIONS(4750),
    [anon_sym_DASH] = ACTIONS(4750),
    [aux_sym_boolean_token1] = ACTIONS(4748),
    [aux_sym_boolean_token2] = ACTIONS(4748),
    [sym_decimal] = ACTIONS(4748),
    [anon_sym_LPAREN] = ACTIONS(4750),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4748),
    [anon_sym_LBRACK] = ACTIONS(4750),
    [aux_sym_record_type_token1] = ACTIONS(4748),
    [aux_sym_basic_type_token21] = ACTIONS(4748),
    [aux_sym_basic_type_token22] = ACTIONS(4748),
    [aux_sym_basic_type_token48] = ACTIONS(4748),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4748),
    [anon_sym_POUNDif] = ACTIONS(4750),
    [anon_sym_POUNDIF] = ACTIONS(4750),
    [anon_sym_POUNDIf] = ACTIONS(4750),
    [anon_sym_not] = ACTIONS(4748),
    [anon_sym_NOT] = ACTIONS(4748),
    [anon_sym_Not] = ACTIONS(4748),
    [anon_sym_POUNDelif] = ACTIONS(4750),
    [anon_sym_POUNDELIF] = ACTIONS(4750),
    [anon_sym_POUNDElif] = ACTIONS(4750),
    [anon_sym_POUNDelse] = ACTIONS(4750),
    [anon_sym_POUNDELSE] = ACTIONS(4750),
    [anon_sym_POUNDElse] = ACTIONS(4750),
    [anon_sym_POUNDendif] = ACTIONS(4750),
    [anon_sym_POUNDENDIF] = ACTIONS(4750),
    [anon_sym_POUNDEndif] = ACTIONS(4750),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4748),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4748),
    [anon_sym_PLUS] = ACTIONS(4750),
    [sym_datetime_literal] = ACTIONS(4750),
    [sym_date_literal] = ACTIONS(4748),
    [sym_time_literal] = ACTIONS(4748),
    [sym_biginteger_literal] = ACTIONS(4750),
    [anon_sym_if] = ACTIONS(4748),
    [anon_sym_IF] = ACTIONS(4748),
    [anon_sym_If] = ACTIONS(4748),
    [anon_sym_else] = ACTIONS(4748),
    [anon_sym_ELSE] = ACTIONS(4748),
    [anon_sym_Else] = ACTIONS(4748),
    [anon_sym_case] = ACTIONS(4748),
    [anon_sym_CASE] = ACTIONS(4748),
    [anon_sym_Case] = ACTIONS(4748),
    [anon_sym_for] = ACTIONS(4748),
    [anon_sym_FOR] = ACTIONS(4748),
    [anon_sym_For] = ACTIONS(4748),
    [anon_sym_foreach] = ACTIONS(4748),
    [anon_sym_FOREACH] = ACTIONS(4748),
    [anon_sym_Foreach] = ACTIONS(4748),
    [anon_sym_while] = ACTIONS(4748),
    [anon_sym_WHILE] = ACTIONS(4748),
    [anon_sym_While] = ACTIONS(4748),
    [anon_sym_repeat] = ACTIONS(4748),
    [anon_sym_REPEAT] = ACTIONS(4748),
    [anon_sym_Repeat] = ACTIONS(4748),
    [anon_sym_exit] = ACTIONS(4748),
    [anon_sym_EXIT] = ACTIONS(4748),
    [anon_sym_Exit] = ACTIONS(4748),
    [anon_sym_continue] = ACTIONS(4748),
    [anon_sym_CONTINUE] = ACTIONS(4748),
    [anon_sym_Continue] = ACTIONS(4748),
    [anon_sym_break] = ACTIONS(4748),
    [anon_sym_BREAK] = ACTIONS(4748),
    [anon_sym_Break] = ACTIONS(4748),
    [anon_sym_with] = ACTIONS(4748),
    [anon_sym_WITH] = ACTIONS(4748),
    [anon_sym_With] = ACTIONS(4748),
    [sym_asserterror_keyword] = ACTIONS(4750),
    [sym_page_keyword] = ACTIONS(4748),
    [anon_sym_codeunit] = ACTIONS(4748),
    [anon_sym_CODEUNIT] = ACTIONS(4748),
    [anon_sym_Codeunit] = ACTIONS(4748),
    [anon_sym_CodeUnit] = ACTIONS(4748),
    [anon_sym_COdeunit] = ACTIONS(4748),
    [anon_sym_codeUnit] = ACTIONS(4748),
    [sym_report_keyword] = ACTIONS(4748),
    [sym_query_keyword] = ACTIONS(4748),
    [anon_sym_xmlport] = ACTIONS(4748),
    [anon_sym_XMLPORT] = ACTIONS(4748),
    [anon_sym_Xmlport] = ACTIONS(4748),
    [anon_sym_XMLport] = ACTIONS(4748),
    [anon_sym_XMLPort] = ACTIONS(4748),
    [anon_sym_XmlPort] = ACTIONS(4748),
    [anon_sym_enum] = ACTIONS(4748),
    [anon_sym_ENUM] = ACTIONS(4748),
    [anon_sym_Enum] = ACTIONS(4748),
    [anon_sym_eNUM] = ACTIONS(4748),
    [anon_sym_eNum] = ACTIONS(4748),
    [anon_sym_ENum] = ACTIONS(4748),
    [sym_quoted_identifier] = ACTIONS(4750),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4750),
    [sym_integer] = ACTIONS(4748),
    [sym_continue_as_identifier] = ACTIONS(4750),
    [sym_preproc_open] = ACTIONS(4750),
    [sym_preproc_close] = ACTIONS(4750),
  },
  [STATE(1712)] = {
    [sym_identifier] = ACTIONS(4752),
    [anon_sym_SEMI] = ACTIONS(4754),
    [anon_sym_DASH] = ACTIONS(4754),
    [aux_sym_boolean_token1] = ACTIONS(4752),
    [aux_sym_boolean_token2] = ACTIONS(4752),
    [sym_decimal] = ACTIONS(4752),
    [anon_sym_LPAREN] = ACTIONS(4754),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4752),
    [anon_sym_LBRACK] = ACTIONS(4754),
    [aux_sym_record_type_token1] = ACTIONS(4752),
    [aux_sym_basic_type_token21] = ACTIONS(4752),
    [aux_sym_basic_type_token22] = ACTIONS(4752),
    [aux_sym_basic_type_token48] = ACTIONS(4752),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4752),
    [anon_sym_POUNDif] = ACTIONS(4754),
    [anon_sym_POUNDIF] = ACTIONS(4754),
    [anon_sym_POUNDIf] = ACTIONS(4754),
    [anon_sym_not] = ACTIONS(4752),
    [anon_sym_NOT] = ACTIONS(4752),
    [anon_sym_Not] = ACTIONS(4752),
    [anon_sym_POUNDelif] = ACTIONS(4754),
    [anon_sym_POUNDELIF] = ACTIONS(4754),
    [anon_sym_POUNDElif] = ACTIONS(4754),
    [anon_sym_POUNDelse] = ACTIONS(4754),
    [anon_sym_POUNDELSE] = ACTIONS(4754),
    [anon_sym_POUNDElse] = ACTIONS(4754),
    [anon_sym_POUNDendif] = ACTIONS(4754),
    [anon_sym_POUNDENDIF] = ACTIONS(4754),
    [anon_sym_POUNDEndif] = ACTIONS(4754),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4752),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4752),
    [anon_sym_PLUS] = ACTIONS(4754),
    [sym_datetime_literal] = ACTIONS(4754),
    [sym_date_literal] = ACTIONS(4752),
    [sym_time_literal] = ACTIONS(4752),
    [sym_biginteger_literal] = ACTIONS(4754),
    [anon_sym_if] = ACTIONS(4752),
    [anon_sym_IF] = ACTIONS(4752),
    [anon_sym_If] = ACTIONS(4752),
    [anon_sym_else] = ACTIONS(4752),
    [anon_sym_ELSE] = ACTIONS(4752),
    [anon_sym_Else] = ACTIONS(4752),
    [anon_sym_case] = ACTIONS(4752),
    [anon_sym_CASE] = ACTIONS(4752),
    [anon_sym_Case] = ACTIONS(4752),
    [anon_sym_for] = ACTIONS(4752),
    [anon_sym_FOR] = ACTIONS(4752),
    [anon_sym_For] = ACTIONS(4752),
    [anon_sym_foreach] = ACTIONS(4752),
    [anon_sym_FOREACH] = ACTIONS(4752),
    [anon_sym_Foreach] = ACTIONS(4752),
    [anon_sym_while] = ACTIONS(4752),
    [anon_sym_WHILE] = ACTIONS(4752),
    [anon_sym_While] = ACTIONS(4752),
    [anon_sym_repeat] = ACTIONS(4752),
    [anon_sym_REPEAT] = ACTIONS(4752),
    [anon_sym_Repeat] = ACTIONS(4752),
    [anon_sym_exit] = ACTIONS(4752),
    [anon_sym_EXIT] = ACTIONS(4752),
    [anon_sym_Exit] = ACTIONS(4752),
    [anon_sym_continue] = ACTIONS(4752),
    [anon_sym_CONTINUE] = ACTIONS(4752),
    [anon_sym_Continue] = ACTIONS(4752),
    [anon_sym_break] = ACTIONS(4752),
    [anon_sym_BREAK] = ACTIONS(4752),
    [anon_sym_Break] = ACTIONS(4752),
    [anon_sym_with] = ACTIONS(4752),
    [anon_sym_WITH] = ACTIONS(4752),
    [anon_sym_With] = ACTIONS(4752),
    [sym_asserterror_keyword] = ACTIONS(4754),
    [sym_page_keyword] = ACTIONS(4752),
    [anon_sym_codeunit] = ACTIONS(4752),
    [anon_sym_CODEUNIT] = ACTIONS(4752),
    [anon_sym_Codeunit] = ACTIONS(4752),
    [anon_sym_CodeUnit] = ACTIONS(4752),
    [anon_sym_COdeunit] = ACTIONS(4752),
    [anon_sym_codeUnit] = ACTIONS(4752),
    [sym_report_keyword] = ACTIONS(4752),
    [sym_query_keyword] = ACTIONS(4752),
    [anon_sym_xmlport] = ACTIONS(4752),
    [anon_sym_XMLPORT] = ACTIONS(4752),
    [anon_sym_Xmlport] = ACTIONS(4752),
    [anon_sym_XMLport] = ACTIONS(4752),
    [anon_sym_XMLPort] = ACTIONS(4752),
    [anon_sym_XmlPort] = ACTIONS(4752),
    [anon_sym_enum] = ACTIONS(4752),
    [anon_sym_ENUM] = ACTIONS(4752),
    [anon_sym_Enum] = ACTIONS(4752),
    [anon_sym_eNUM] = ACTIONS(4752),
    [anon_sym_eNum] = ACTIONS(4752),
    [anon_sym_ENum] = ACTIONS(4752),
    [sym_quoted_identifier] = ACTIONS(4754),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4754),
    [sym_integer] = ACTIONS(4752),
    [sym_continue_as_identifier] = ACTIONS(4754),
    [sym_preproc_open] = ACTIONS(4754),
    [sym_preproc_close] = ACTIONS(4754),
  },
  [STATE(1713)] = {
    [sym_identifier] = ACTIONS(4748),
    [anon_sym_SEMI] = ACTIONS(4750),
    [anon_sym_DASH] = ACTIONS(4750),
    [aux_sym_boolean_token1] = ACTIONS(4748),
    [aux_sym_boolean_token2] = ACTIONS(4748),
    [sym_decimal] = ACTIONS(4748),
    [anon_sym_LPAREN] = ACTIONS(4750),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4748),
    [anon_sym_LBRACK] = ACTIONS(4750),
    [aux_sym_record_type_token1] = ACTIONS(4748),
    [aux_sym_basic_type_token21] = ACTIONS(4748),
    [aux_sym_basic_type_token22] = ACTIONS(4748),
    [aux_sym_basic_type_token48] = ACTIONS(4748),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4748),
    [anon_sym_POUNDif] = ACTIONS(4750),
    [anon_sym_POUNDIF] = ACTIONS(4750),
    [anon_sym_POUNDIf] = ACTIONS(4750),
    [anon_sym_not] = ACTIONS(4748),
    [anon_sym_NOT] = ACTIONS(4748),
    [anon_sym_Not] = ACTIONS(4748),
    [anon_sym_POUNDelif] = ACTIONS(4750),
    [anon_sym_POUNDELIF] = ACTIONS(4750),
    [anon_sym_POUNDElif] = ACTIONS(4750),
    [anon_sym_POUNDelse] = ACTIONS(4750),
    [anon_sym_POUNDELSE] = ACTIONS(4750),
    [anon_sym_POUNDElse] = ACTIONS(4750),
    [anon_sym_POUNDendif] = ACTIONS(4750),
    [anon_sym_POUNDENDIF] = ACTIONS(4750),
    [anon_sym_POUNDEndif] = ACTIONS(4750),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4748),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4748),
    [anon_sym_PLUS] = ACTIONS(4750),
    [sym_datetime_literal] = ACTIONS(4750),
    [sym_date_literal] = ACTIONS(4748),
    [sym_time_literal] = ACTIONS(4748),
    [sym_biginteger_literal] = ACTIONS(4750),
    [anon_sym_if] = ACTIONS(4748),
    [anon_sym_IF] = ACTIONS(4748),
    [anon_sym_If] = ACTIONS(4748),
    [anon_sym_else] = ACTIONS(4748),
    [anon_sym_ELSE] = ACTIONS(4748),
    [anon_sym_Else] = ACTIONS(4748),
    [anon_sym_case] = ACTIONS(4748),
    [anon_sym_CASE] = ACTIONS(4748),
    [anon_sym_Case] = ACTIONS(4748),
    [anon_sym_for] = ACTIONS(4748),
    [anon_sym_FOR] = ACTIONS(4748),
    [anon_sym_For] = ACTIONS(4748),
    [anon_sym_foreach] = ACTIONS(4748),
    [anon_sym_FOREACH] = ACTIONS(4748),
    [anon_sym_Foreach] = ACTIONS(4748),
    [anon_sym_while] = ACTIONS(4748),
    [anon_sym_WHILE] = ACTIONS(4748),
    [anon_sym_While] = ACTIONS(4748),
    [anon_sym_repeat] = ACTIONS(4748),
    [anon_sym_REPEAT] = ACTIONS(4748),
    [anon_sym_Repeat] = ACTIONS(4748),
    [anon_sym_exit] = ACTIONS(4748),
    [anon_sym_EXIT] = ACTIONS(4748),
    [anon_sym_Exit] = ACTIONS(4748),
    [anon_sym_continue] = ACTIONS(4748),
    [anon_sym_CONTINUE] = ACTIONS(4748),
    [anon_sym_Continue] = ACTIONS(4748),
    [anon_sym_break] = ACTIONS(4748),
    [anon_sym_BREAK] = ACTIONS(4748),
    [anon_sym_Break] = ACTIONS(4748),
    [anon_sym_with] = ACTIONS(4748),
    [anon_sym_WITH] = ACTIONS(4748),
    [anon_sym_With] = ACTIONS(4748),
    [sym_asserterror_keyword] = ACTIONS(4750),
    [sym_page_keyword] = ACTIONS(4748),
    [anon_sym_codeunit] = ACTIONS(4748),
    [anon_sym_CODEUNIT] = ACTIONS(4748),
    [anon_sym_Codeunit] = ACTIONS(4748),
    [anon_sym_CodeUnit] = ACTIONS(4748),
    [anon_sym_COdeunit] = ACTIONS(4748),
    [anon_sym_codeUnit] = ACTIONS(4748),
    [sym_report_keyword] = ACTIONS(4748),
    [sym_query_keyword] = ACTIONS(4748),
    [anon_sym_xmlport] = ACTIONS(4748),
    [anon_sym_XMLPORT] = ACTIONS(4748),
    [anon_sym_Xmlport] = ACTIONS(4748),
    [anon_sym_XMLport] = ACTIONS(4748),
    [anon_sym_XMLPort] = ACTIONS(4748),
    [anon_sym_XmlPort] = ACTIONS(4748),
    [anon_sym_enum] = ACTIONS(4748),
    [anon_sym_ENUM] = ACTIONS(4748),
    [anon_sym_Enum] = ACTIONS(4748),
    [anon_sym_eNUM] = ACTIONS(4748),
    [anon_sym_eNum] = ACTIONS(4748),
    [anon_sym_ENum] = ACTIONS(4748),
    [sym_quoted_identifier] = ACTIONS(4750),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4750),
    [sym_integer] = ACTIONS(4748),
    [sym_continue_as_identifier] = ACTIONS(4750),
    [sym_preproc_open] = ACTIONS(4750),
    [sym_preproc_close] = ACTIONS(4750),
  },
  [STATE(1714)] = {
    [sym_identifier] = ACTIONS(4756),
    [anon_sym_SEMI] = ACTIONS(4758),
    [anon_sym_DASH] = ACTIONS(4758),
    [aux_sym_boolean_token1] = ACTIONS(4756),
    [aux_sym_boolean_token2] = ACTIONS(4756),
    [sym_decimal] = ACTIONS(4756),
    [anon_sym_LPAREN] = ACTIONS(4758),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4756),
    [anon_sym_LBRACK] = ACTIONS(4758),
    [aux_sym_record_type_token1] = ACTIONS(4756),
    [aux_sym_basic_type_token21] = ACTIONS(4756),
    [aux_sym_basic_type_token22] = ACTIONS(4756),
    [aux_sym_basic_type_token48] = ACTIONS(4756),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4756),
    [anon_sym_POUNDif] = ACTIONS(4758),
    [anon_sym_POUNDIF] = ACTIONS(4758),
    [anon_sym_POUNDIf] = ACTIONS(4758),
    [anon_sym_not] = ACTIONS(4756),
    [anon_sym_NOT] = ACTIONS(4756),
    [anon_sym_Not] = ACTIONS(4756),
    [anon_sym_POUNDelif] = ACTIONS(4758),
    [anon_sym_POUNDELIF] = ACTIONS(4758),
    [anon_sym_POUNDElif] = ACTIONS(4758),
    [anon_sym_POUNDelse] = ACTIONS(4758),
    [anon_sym_POUNDELSE] = ACTIONS(4758),
    [anon_sym_POUNDElse] = ACTIONS(4758),
    [anon_sym_POUNDendif] = ACTIONS(4758),
    [anon_sym_POUNDENDIF] = ACTIONS(4758),
    [anon_sym_POUNDEndif] = ACTIONS(4758),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4756),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4756),
    [anon_sym_PLUS] = ACTIONS(4758),
    [sym_datetime_literal] = ACTIONS(4758),
    [sym_date_literal] = ACTIONS(4756),
    [sym_time_literal] = ACTIONS(4756),
    [sym_biginteger_literal] = ACTIONS(4758),
    [anon_sym_if] = ACTIONS(4756),
    [anon_sym_IF] = ACTIONS(4756),
    [anon_sym_If] = ACTIONS(4756),
    [anon_sym_else] = ACTIONS(4756),
    [anon_sym_ELSE] = ACTIONS(4756),
    [anon_sym_Else] = ACTIONS(4756),
    [anon_sym_case] = ACTIONS(4756),
    [anon_sym_CASE] = ACTIONS(4756),
    [anon_sym_Case] = ACTIONS(4756),
    [anon_sym_for] = ACTIONS(4756),
    [anon_sym_FOR] = ACTIONS(4756),
    [anon_sym_For] = ACTIONS(4756),
    [anon_sym_foreach] = ACTIONS(4756),
    [anon_sym_FOREACH] = ACTIONS(4756),
    [anon_sym_Foreach] = ACTIONS(4756),
    [anon_sym_while] = ACTIONS(4756),
    [anon_sym_WHILE] = ACTIONS(4756),
    [anon_sym_While] = ACTIONS(4756),
    [anon_sym_repeat] = ACTIONS(4756),
    [anon_sym_REPEAT] = ACTIONS(4756),
    [anon_sym_Repeat] = ACTIONS(4756),
    [anon_sym_exit] = ACTIONS(4756),
    [anon_sym_EXIT] = ACTIONS(4756),
    [anon_sym_Exit] = ACTIONS(4756),
    [anon_sym_continue] = ACTIONS(4756),
    [anon_sym_CONTINUE] = ACTIONS(4756),
    [anon_sym_Continue] = ACTIONS(4756),
    [anon_sym_break] = ACTIONS(4756),
    [anon_sym_BREAK] = ACTIONS(4756),
    [anon_sym_Break] = ACTIONS(4756),
    [anon_sym_with] = ACTIONS(4756),
    [anon_sym_WITH] = ACTIONS(4756),
    [anon_sym_With] = ACTIONS(4756),
    [sym_asserterror_keyword] = ACTIONS(4758),
    [sym_page_keyword] = ACTIONS(4756),
    [anon_sym_codeunit] = ACTIONS(4756),
    [anon_sym_CODEUNIT] = ACTIONS(4756),
    [anon_sym_Codeunit] = ACTIONS(4756),
    [anon_sym_CodeUnit] = ACTIONS(4756),
    [anon_sym_COdeunit] = ACTIONS(4756),
    [anon_sym_codeUnit] = ACTIONS(4756),
    [sym_report_keyword] = ACTIONS(4756),
    [sym_query_keyword] = ACTIONS(4756),
    [anon_sym_xmlport] = ACTIONS(4756),
    [anon_sym_XMLPORT] = ACTIONS(4756),
    [anon_sym_Xmlport] = ACTIONS(4756),
    [anon_sym_XMLport] = ACTIONS(4756),
    [anon_sym_XMLPort] = ACTIONS(4756),
    [anon_sym_XmlPort] = ACTIONS(4756),
    [anon_sym_enum] = ACTIONS(4756),
    [anon_sym_ENUM] = ACTIONS(4756),
    [anon_sym_Enum] = ACTIONS(4756),
    [anon_sym_eNUM] = ACTIONS(4756),
    [anon_sym_eNum] = ACTIONS(4756),
    [anon_sym_ENum] = ACTIONS(4756),
    [sym_quoted_identifier] = ACTIONS(4758),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4758),
    [sym_integer] = ACTIONS(4756),
    [sym_continue_as_identifier] = ACTIONS(4758),
    [sym_preproc_open] = ACTIONS(4758),
    [sym_preproc_close] = ACTIONS(4758),
  },
  [STATE(1715)] = {
    [sym_identifier] = ACTIONS(4760),
    [anon_sym_SEMI] = ACTIONS(4762),
    [anon_sym_DASH] = ACTIONS(4762),
    [aux_sym_boolean_token1] = ACTIONS(4760),
    [aux_sym_boolean_token2] = ACTIONS(4760),
    [sym_decimal] = ACTIONS(4760),
    [anon_sym_LPAREN] = ACTIONS(4762),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4760),
    [anon_sym_LBRACK] = ACTIONS(4762),
    [aux_sym_record_type_token1] = ACTIONS(4760),
    [aux_sym_basic_type_token21] = ACTIONS(4760),
    [aux_sym_basic_type_token22] = ACTIONS(4760),
    [aux_sym_basic_type_token48] = ACTIONS(4760),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4760),
    [anon_sym_POUNDif] = ACTIONS(4762),
    [anon_sym_POUNDIF] = ACTIONS(4762),
    [anon_sym_POUNDIf] = ACTIONS(4762),
    [anon_sym_not] = ACTIONS(4760),
    [anon_sym_NOT] = ACTIONS(4760),
    [anon_sym_Not] = ACTIONS(4760),
    [anon_sym_POUNDelif] = ACTIONS(4762),
    [anon_sym_POUNDELIF] = ACTIONS(4762),
    [anon_sym_POUNDElif] = ACTIONS(4762),
    [anon_sym_POUNDelse] = ACTIONS(4762),
    [anon_sym_POUNDELSE] = ACTIONS(4762),
    [anon_sym_POUNDElse] = ACTIONS(4762),
    [anon_sym_POUNDendif] = ACTIONS(4762),
    [anon_sym_POUNDENDIF] = ACTIONS(4762),
    [anon_sym_POUNDEndif] = ACTIONS(4762),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4760),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4760),
    [anon_sym_PLUS] = ACTIONS(4762),
    [sym_datetime_literal] = ACTIONS(4762),
    [sym_date_literal] = ACTIONS(4760),
    [sym_time_literal] = ACTIONS(4760),
    [sym_biginteger_literal] = ACTIONS(4762),
    [anon_sym_if] = ACTIONS(4760),
    [anon_sym_IF] = ACTIONS(4760),
    [anon_sym_If] = ACTIONS(4760),
    [anon_sym_else] = ACTIONS(4760),
    [anon_sym_ELSE] = ACTIONS(4760),
    [anon_sym_Else] = ACTIONS(4760),
    [anon_sym_case] = ACTIONS(4760),
    [anon_sym_CASE] = ACTIONS(4760),
    [anon_sym_Case] = ACTIONS(4760),
    [anon_sym_for] = ACTIONS(4760),
    [anon_sym_FOR] = ACTIONS(4760),
    [anon_sym_For] = ACTIONS(4760),
    [anon_sym_foreach] = ACTIONS(4760),
    [anon_sym_FOREACH] = ACTIONS(4760),
    [anon_sym_Foreach] = ACTIONS(4760),
    [anon_sym_while] = ACTIONS(4760),
    [anon_sym_WHILE] = ACTIONS(4760),
    [anon_sym_While] = ACTIONS(4760),
    [anon_sym_repeat] = ACTIONS(4760),
    [anon_sym_REPEAT] = ACTIONS(4760),
    [anon_sym_Repeat] = ACTIONS(4760),
    [anon_sym_exit] = ACTIONS(4760),
    [anon_sym_EXIT] = ACTIONS(4760),
    [anon_sym_Exit] = ACTIONS(4760),
    [anon_sym_continue] = ACTIONS(4760),
    [anon_sym_CONTINUE] = ACTIONS(4760),
    [anon_sym_Continue] = ACTIONS(4760),
    [anon_sym_break] = ACTIONS(4760),
    [anon_sym_BREAK] = ACTIONS(4760),
    [anon_sym_Break] = ACTIONS(4760),
    [anon_sym_with] = ACTIONS(4760),
    [anon_sym_WITH] = ACTIONS(4760),
    [anon_sym_With] = ACTIONS(4760),
    [sym_asserterror_keyword] = ACTIONS(4762),
    [sym_page_keyword] = ACTIONS(4760),
    [anon_sym_codeunit] = ACTIONS(4760),
    [anon_sym_CODEUNIT] = ACTIONS(4760),
    [anon_sym_Codeunit] = ACTIONS(4760),
    [anon_sym_CodeUnit] = ACTIONS(4760),
    [anon_sym_COdeunit] = ACTIONS(4760),
    [anon_sym_codeUnit] = ACTIONS(4760),
    [sym_report_keyword] = ACTIONS(4760),
    [sym_query_keyword] = ACTIONS(4760),
    [anon_sym_xmlport] = ACTIONS(4760),
    [anon_sym_XMLPORT] = ACTIONS(4760),
    [anon_sym_Xmlport] = ACTIONS(4760),
    [anon_sym_XMLport] = ACTIONS(4760),
    [anon_sym_XMLPort] = ACTIONS(4760),
    [anon_sym_XmlPort] = ACTIONS(4760),
    [anon_sym_enum] = ACTIONS(4760),
    [anon_sym_ENUM] = ACTIONS(4760),
    [anon_sym_Enum] = ACTIONS(4760),
    [anon_sym_eNUM] = ACTIONS(4760),
    [anon_sym_eNum] = ACTIONS(4760),
    [anon_sym_ENum] = ACTIONS(4760),
    [sym_quoted_identifier] = ACTIONS(4762),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4762),
    [sym_integer] = ACTIONS(4760),
    [sym_continue_as_identifier] = ACTIONS(4762),
    [sym_preproc_open] = ACTIONS(4762),
    [sym_preproc_close] = ACTIONS(4762),
  },
  [STATE(1716)] = {
    [sym_identifier] = ACTIONS(4756),
    [anon_sym_SEMI] = ACTIONS(4758),
    [anon_sym_DASH] = ACTIONS(4758),
    [aux_sym_boolean_token1] = ACTIONS(4756),
    [aux_sym_boolean_token2] = ACTIONS(4756),
    [sym_decimal] = ACTIONS(4756),
    [anon_sym_LPAREN] = ACTIONS(4758),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4756),
    [anon_sym_LBRACK] = ACTIONS(4758),
    [aux_sym_record_type_token1] = ACTIONS(4756),
    [aux_sym_basic_type_token21] = ACTIONS(4756),
    [aux_sym_basic_type_token22] = ACTIONS(4756),
    [aux_sym_basic_type_token48] = ACTIONS(4756),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4756),
    [anon_sym_POUNDif] = ACTIONS(4758),
    [anon_sym_POUNDIF] = ACTIONS(4758),
    [anon_sym_POUNDIf] = ACTIONS(4758),
    [anon_sym_not] = ACTIONS(4756),
    [anon_sym_NOT] = ACTIONS(4756),
    [anon_sym_Not] = ACTIONS(4756),
    [anon_sym_POUNDelif] = ACTIONS(4758),
    [anon_sym_POUNDELIF] = ACTIONS(4758),
    [anon_sym_POUNDElif] = ACTIONS(4758),
    [anon_sym_POUNDelse] = ACTIONS(4758),
    [anon_sym_POUNDELSE] = ACTIONS(4758),
    [anon_sym_POUNDElse] = ACTIONS(4758),
    [anon_sym_POUNDendif] = ACTIONS(4758),
    [anon_sym_POUNDENDIF] = ACTIONS(4758),
    [anon_sym_POUNDEndif] = ACTIONS(4758),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4756),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4756),
    [anon_sym_PLUS] = ACTIONS(4758),
    [sym_datetime_literal] = ACTIONS(4758),
    [sym_date_literal] = ACTIONS(4756),
    [sym_time_literal] = ACTIONS(4756),
    [sym_biginteger_literal] = ACTIONS(4758),
    [anon_sym_if] = ACTIONS(4756),
    [anon_sym_IF] = ACTIONS(4756),
    [anon_sym_If] = ACTIONS(4756),
    [anon_sym_else] = ACTIONS(4756),
    [anon_sym_ELSE] = ACTIONS(4756),
    [anon_sym_Else] = ACTIONS(4756),
    [anon_sym_case] = ACTIONS(4756),
    [anon_sym_CASE] = ACTIONS(4756),
    [anon_sym_Case] = ACTIONS(4756),
    [anon_sym_for] = ACTIONS(4756),
    [anon_sym_FOR] = ACTIONS(4756),
    [anon_sym_For] = ACTIONS(4756),
    [anon_sym_foreach] = ACTIONS(4756),
    [anon_sym_FOREACH] = ACTIONS(4756),
    [anon_sym_Foreach] = ACTIONS(4756),
    [anon_sym_while] = ACTIONS(4756),
    [anon_sym_WHILE] = ACTIONS(4756),
    [anon_sym_While] = ACTIONS(4756),
    [anon_sym_repeat] = ACTIONS(4756),
    [anon_sym_REPEAT] = ACTIONS(4756),
    [anon_sym_Repeat] = ACTIONS(4756),
    [anon_sym_exit] = ACTIONS(4756),
    [anon_sym_EXIT] = ACTIONS(4756),
    [anon_sym_Exit] = ACTIONS(4756),
    [anon_sym_continue] = ACTIONS(4756),
    [anon_sym_CONTINUE] = ACTIONS(4756),
    [anon_sym_Continue] = ACTIONS(4756),
    [anon_sym_break] = ACTIONS(4756),
    [anon_sym_BREAK] = ACTIONS(4756),
    [anon_sym_Break] = ACTIONS(4756),
    [anon_sym_with] = ACTIONS(4756),
    [anon_sym_WITH] = ACTIONS(4756),
    [anon_sym_With] = ACTIONS(4756),
    [sym_asserterror_keyword] = ACTIONS(4758),
    [sym_page_keyword] = ACTIONS(4756),
    [anon_sym_codeunit] = ACTIONS(4756),
    [anon_sym_CODEUNIT] = ACTIONS(4756),
    [anon_sym_Codeunit] = ACTIONS(4756),
    [anon_sym_CodeUnit] = ACTIONS(4756),
    [anon_sym_COdeunit] = ACTIONS(4756),
    [anon_sym_codeUnit] = ACTIONS(4756),
    [sym_report_keyword] = ACTIONS(4756),
    [sym_query_keyword] = ACTIONS(4756),
    [anon_sym_xmlport] = ACTIONS(4756),
    [anon_sym_XMLPORT] = ACTIONS(4756),
    [anon_sym_Xmlport] = ACTIONS(4756),
    [anon_sym_XMLport] = ACTIONS(4756),
    [anon_sym_XMLPort] = ACTIONS(4756),
    [anon_sym_XmlPort] = ACTIONS(4756),
    [anon_sym_enum] = ACTIONS(4756),
    [anon_sym_ENUM] = ACTIONS(4756),
    [anon_sym_Enum] = ACTIONS(4756),
    [anon_sym_eNUM] = ACTIONS(4756),
    [anon_sym_eNum] = ACTIONS(4756),
    [anon_sym_ENum] = ACTIONS(4756),
    [sym_quoted_identifier] = ACTIONS(4758),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4758),
    [sym_integer] = ACTIONS(4756),
    [sym_continue_as_identifier] = ACTIONS(4758),
    [sym_preproc_open] = ACTIONS(4758),
    [sym_preproc_close] = ACTIONS(4758),
  },
  [STATE(1717)] = {
    [sym_identifier] = ACTIONS(4764),
    [anon_sym_SEMI] = ACTIONS(4766),
    [anon_sym_DASH] = ACTIONS(4766),
    [aux_sym_boolean_token1] = ACTIONS(4764),
    [aux_sym_boolean_token2] = ACTIONS(4764),
    [sym_decimal] = ACTIONS(4764),
    [anon_sym_LPAREN] = ACTIONS(4766),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4764),
    [anon_sym_LBRACK] = ACTIONS(4766),
    [aux_sym_record_type_token1] = ACTIONS(4764),
    [aux_sym_basic_type_token21] = ACTIONS(4764),
    [aux_sym_basic_type_token22] = ACTIONS(4764),
    [aux_sym_basic_type_token48] = ACTIONS(4764),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4764),
    [anon_sym_POUNDif] = ACTIONS(4766),
    [anon_sym_POUNDIF] = ACTIONS(4766),
    [anon_sym_POUNDIf] = ACTIONS(4766),
    [anon_sym_not] = ACTIONS(4764),
    [anon_sym_NOT] = ACTIONS(4764),
    [anon_sym_Not] = ACTIONS(4764),
    [anon_sym_POUNDelif] = ACTIONS(4766),
    [anon_sym_POUNDELIF] = ACTIONS(4766),
    [anon_sym_POUNDElif] = ACTIONS(4766),
    [anon_sym_POUNDelse] = ACTIONS(4766),
    [anon_sym_POUNDELSE] = ACTIONS(4766),
    [anon_sym_POUNDElse] = ACTIONS(4766),
    [anon_sym_POUNDendif] = ACTIONS(4766),
    [anon_sym_POUNDENDIF] = ACTIONS(4766),
    [anon_sym_POUNDEndif] = ACTIONS(4766),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4764),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4764),
    [anon_sym_PLUS] = ACTIONS(4766),
    [sym_datetime_literal] = ACTIONS(4766),
    [sym_date_literal] = ACTIONS(4764),
    [sym_time_literal] = ACTIONS(4764),
    [sym_biginteger_literal] = ACTIONS(4766),
    [anon_sym_if] = ACTIONS(4764),
    [anon_sym_IF] = ACTIONS(4764),
    [anon_sym_If] = ACTIONS(4764),
    [anon_sym_else] = ACTIONS(4764),
    [anon_sym_ELSE] = ACTIONS(4764),
    [anon_sym_Else] = ACTIONS(4764),
    [anon_sym_case] = ACTIONS(4764),
    [anon_sym_CASE] = ACTIONS(4764),
    [anon_sym_Case] = ACTIONS(4764),
    [anon_sym_for] = ACTIONS(4764),
    [anon_sym_FOR] = ACTIONS(4764),
    [anon_sym_For] = ACTIONS(4764),
    [anon_sym_foreach] = ACTIONS(4764),
    [anon_sym_FOREACH] = ACTIONS(4764),
    [anon_sym_Foreach] = ACTIONS(4764),
    [anon_sym_while] = ACTIONS(4764),
    [anon_sym_WHILE] = ACTIONS(4764),
    [anon_sym_While] = ACTIONS(4764),
    [anon_sym_repeat] = ACTIONS(4764),
    [anon_sym_REPEAT] = ACTIONS(4764),
    [anon_sym_Repeat] = ACTIONS(4764),
    [anon_sym_exit] = ACTIONS(4764),
    [anon_sym_EXIT] = ACTIONS(4764),
    [anon_sym_Exit] = ACTIONS(4764),
    [anon_sym_continue] = ACTIONS(4764),
    [anon_sym_CONTINUE] = ACTIONS(4764),
    [anon_sym_Continue] = ACTIONS(4764),
    [anon_sym_break] = ACTIONS(4764),
    [anon_sym_BREAK] = ACTIONS(4764),
    [anon_sym_Break] = ACTIONS(4764),
    [anon_sym_with] = ACTIONS(4764),
    [anon_sym_WITH] = ACTIONS(4764),
    [anon_sym_With] = ACTIONS(4764),
    [sym_asserterror_keyword] = ACTIONS(4766),
    [sym_page_keyword] = ACTIONS(4764),
    [anon_sym_codeunit] = ACTIONS(4764),
    [anon_sym_CODEUNIT] = ACTIONS(4764),
    [anon_sym_Codeunit] = ACTIONS(4764),
    [anon_sym_CodeUnit] = ACTIONS(4764),
    [anon_sym_COdeunit] = ACTIONS(4764),
    [anon_sym_codeUnit] = ACTIONS(4764),
    [sym_report_keyword] = ACTIONS(4764),
    [sym_query_keyword] = ACTIONS(4764),
    [anon_sym_xmlport] = ACTIONS(4764),
    [anon_sym_XMLPORT] = ACTIONS(4764),
    [anon_sym_Xmlport] = ACTIONS(4764),
    [anon_sym_XMLport] = ACTIONS(4764),
    [anon_sym_XMLPort] = ACTIONS(4764),
    [anon_sym_XmlPort] = ACTIONS(4764),
    [anon_sym_enum] = ACTIONS(4764),
    [anon_sym_ENUM] = ACTIONS(4764),
    [anon_sym_Enum] = ACTIONS(4764),
    [anon_sym_eNUM] = ACTIONS(4764),
    [anon_sym_eNum] = ACTIONS(4764),
    [anon_sym_ENum] = ACTIONS(4764),
    [sym_quoted_identifier] = ACTIONS(4766),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4766),
    [sym_integer] = ACTIONS(4764),
    [sym_continue_as_identifier] = ACTIONS(4766),
    [sym_preproc_open] = ACTIONS(4766),
    [sym_preproc_close] = ACTIONS(4766),
  },
  [STATE(1718)] = {
    [sym_identifier] = ACTIONS(4768),
    [anon_sym_SEMI] = ACTIONS(4770),
    [anon_sym_DASH] = ACTIONS(4770),
    [aux_sym_boolean_token1] = ACTIONS(4768),
    [aux_sym_boolean_token2] = ACTIONS(4768),
    [sym_decimal] = ACTIONS(4768),
    [anon_sym_LPAREN] = ACTIONS(4770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4768),
    [anon_sym_LBRACK] = ACTIONS(4770),
    [aux_sym_record_type_token1] = ACTIONS(4768),
    [aux_sym_basic_type_token21] = ACTIONS(4768),
    [aux_sym_basic_type_token22] = ACTIONS(4768),
    [aux_sym_basic_type_token48] = ACTIONS(4768),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4768),
    [anon_sym_POUNDif] = ACTIONS(4770),
    [anon_sym_POUNDIF] = ACTIONS(4770),
    [anon_sym_POUNDIf] = ACTIONS(4770),
    [anon_sym_not] = ACTIONS(4768),
    [anon_sym_NOT] = ACTIONS(4768),
    [anon_sym_Not] = ACTIONS(4768),
    [anon_sym_POUNDelif] = ACTIONS(4770),
    [anon_sym_POUNDELIF] = ACTIONS(4770),
    [anon_sym_POUNDElif] = ACTIONS(4770),
    [anon_sym_POUNDelse] = ACTIONS(4770),
    [anon_sym_POUNDELSE] = ACTIONS(4770),
    [anon_sym_POUNDElse] = ACTIONS(4770),
    [anon_sym_POUNDendif] = ACTIONS(4770),
    [anon_sym_POUNDENDIF] = ACTIONS(4770),
    [anon_sym_POUNDEndif] = ACTIONS(4770),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4768),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4768),
    [anon_sym_PLUS] = ACTIONS(4770),
    [sym_datetime_literal] = ACTIONS(4770),
    [sym_date_literal] = ACTIONS(4768),
    [sym_time_literal] = ACTIONS(4768),
    [sym_biginteger_literal] = ACTIONS(4770),
    [anon_sym_if] = ACTIONS(4768),
    [anon_sym_IF] = ACTIONS(4768),
    [anon_sym_If] = ACTIONS(4768),
    [anon_sym_else] = ACTIONS(4768),
    [anon_sym_ELSE] = ACTIONS(4768),
    [anon_sym_Else] = ACTIONS(4768),
    [anon_sym_case] = ACTIONS(4768),
    [anon_sym_CASE] = ACTIONS(4768),
    [anon_sym_Case] = ACTIONS(4768),
    [anon_sym_for] = ACTIONS(4768),
    [anon_sym_FOR] = ACTIONS(4768),
    [anon_sym_For] = ACTIONS(4768),
    [anon_sym_foreach] = ACTIONS(4768),
    [anon_sym_FOREACH] = ACTIONS(4768),
    [anon_sym_Foreach] = ACTIONS(4768),
    [anon_sym_while] = ACTIONS(4768),
    [anon_sym_WHILE] = ACTIONS(4768),
    [anon_sym_While] = ACTIONS(4768),
    [anon_sym_repeat] = ACTIONS(4768),
    [anon_sym_REPEAT] = ACTIONS(4768),
    [anon_sym_Repeat] = ACTIONS(4768),
    [anon_sym_exit] = ACTIONS(4768),
    [anon_sym_EXIT] = ACTIONS(4768),
    [anon_sym_Exit] = ACTIONS(4768),
    [anon_sym_continue] = ACTIONS(4768),
    [anon_sym_CONTINUE] = ACTIONS(4768),
    [anon_sym_Continue] = ACTIONS(4768),
    [anon_sym_break] = ACTIONS(4768),
    [anon_sym_BREAK] = ACTIONS(4768),
    [anon_sym_Break] = ACTIONS(4768),
    [anon_sym_with] = ACTIONS(4768),
    [anon_sym_WITH] = ACTIONS(4768),
    [anon_sym_With] = ACTIONS(4768),
    [sym_asserterror_keyword] = ACTIONS(4770),
    [sym_page_keyword] = ACTIONS(4768),
    [anon_sym_codeunit] = ACTIONS(4768),
    [anon_sym_CODEUNIT] = ACTIONS(4768),
    [anon_sym_Codeunit] = ACTIONS(4768),
    [anon_sym_CodeUnit] = ACTIONS(4768),
    [anon_sym_COdeunit] = ACTIONS(4768),
    [anon_sym_codeUnit] = ACTIONS(4768),
    [sym_report_keyword] = ACTIONS(4768),
    [sym_query_keyword] = ACTIONS(4768),
    [anon_sym_xmlport] = ACTIONS(4768),
    [anon_sym_XMLPORT] = ACTIONS(4768),
    [anon_sym_Xmlport] = ACTIONS(4768),
    [anon_sym_XMLport] = ACTIONS(4768),
    [anon_sym_XMLPort] = ACTIONS(4768),
    [anon_sym_XmlPort] = ACTIONS(4768),
    [anon_sym_enum] = ACTIONS(4768),
    [anon_sym_ENUM] = ACTIONS(4768),
    [anon_sym_Enum] = ACTIONS(4768),
    [anon_sym_eNUM] = ACTIONS(4768),
    [anon_sym_eNum] = ACTIONS(4768),
    [anon_sym_ENum] = ACTIONS(4768),
    [sym_quoted_identifier] = ACTIONS(4770),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4770),
    [sym_integer] = ACTIONS(4768),
    [sym_continue_as_identifier] = ACTIONS(4770),
    [sym_preproc_open] = ACTIONS(4770),
    [sym_preproc_close] = ACTIONS(4770),
  },
  [STATE(1719)] = {
    [sym_identifier] = ACTIONS(4772),
    [anon_sym_SEMI] = ACTIONS(4774),
    [anon_sym_DASH] = ACTIONS(4774),
    [aux_sym_boolean_token1] = ACTIONS(4772),
    [aux_sym_boolean_token2] = ACTIONS(4772),
    [sym_decimal] = ACTIONS(4772),
    [anon_sym_LPAREN] = ACTIONS(4774),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4772),
    [anon_sym_LBRACK] = ACTIONS(4774),
    [aux_sym_record_type_token1] = ACTIONS(4772),
    [aux_sym_basic_type_token21] = ACTIONS(4772),
    [aux_sym_basic_type_token22] = ACTIONS(4772),
    [aux_sym_basic_type_token48] = ACTIONS(4772),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4772),
    [anon_sym_POUNDif] = ACTIONS(4774),
    [anon_sym_POUNDIF] = ACTIONS(4774),
    [anon_sym_POUNDIf] = ACTIONS(4774),
    [anon_sym_not] = ACTIONS(4772),
    [anon_sym_NOT] = ACTIONS(4772),
    [anon_sym_Not] = ACTIONS(4772),
    [anon_sym_POUNDelif] = ACTIONS(4774),
    [anon_sym_POUNDELIF] = ACTIONS(4774),
    [anon_sym_POUNDElif] = ACTIONS(4774),
    [anon_sym_POUNDelse] = ACTIONS(4774),
    [anon_sym_POUNDELSE] = ACTIONS(4774),
    [anon_sym_POUNDElse] = ACTIONS(4774),
    [anon_sym_POUNDendif] = ACTIONS(4774),
    [anon_sym_POUNDENDIF] = ACTIONS(4774),
    [anon_sym_POUNDEndif] = ACTIONS(4774),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4772),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4772),
    [anon_sym_PLUS] = ACTIONS(4774),
    [sym_datetime_literal] = ACTIONS(4774),
    [sym_date_literal] = ACTIONS(4772),
    [sym_time_literal] = ACTIONS(4772),
    [sym_biginteger_literal] = ACTIONS(4774),
    [anon_sym_if] = ACTIONS(4772),
    [anon_sym_IF] = ACTIONS(4772),
    [anon_sym_If] = ACTIONS(4772),
    [anon_sym_else] = ACTIONS(4772),
    [anon_sym_ELSE] = ACTIONS(4772),
    [anon_sym_Else] = ACTIONS(4772),
    [anon_sym_case] = ACTIONS(4772),
    [anon_sym_CASE] = ACTIONS(4772),
    [anon_sym_Case] = ACTIONS(4772),
    [anon_sym_for] = ACTIONS(4772),
    [anon_sym_FOR] = ACTIONS(4772),
    [anon_sym_For] = ACTIONS(4772),
    [anon_sym_foreach] = ACTIONS(4772),
    [anon_sym_FOREACH] = ACTIONS(4772),
    [anon_sym_Foreach] = ACTIONS(4772),
    [anon_sym_while] = ACTIONS(4772),
    [anon_sym_WHILE] = ACTIONS(4772),
    [anon_sym_While] = ACTIONS(4772),
    [anon_sym_repeat] = ACTIONS(4772),
    [anon_sym_REPEAT] = ACTIONS(4772),
    [anon_sym_Repeat] = ACTIONS(4772),
    [anon_sym_exit] = ACTIONS(4772),
    [anon_sym_EXIT] = ACTIONS(4772),
    [anon_sym_Exit] = ACTIONS(4772),
    [anon_sym_continue] = ACTIONS(4772),
    [anon_sym_CONTINUE] = ACTIONS(4772),
    [anon_sym_Continue] = ACTIONS(4772),
    [anon_sym_break] = ACTIONS(4772),
    [anon_sym_BREAK] = ACTIONS(4772),
    [anon_sym_Break] = ACTIONS(4772),
    [anon_sym_with] = ACTIONS(4772),
    [anon_sym_WITH] = ACTIONS(4772),
    [anon_sym_With] = ACTIONS(4772),
    [sym_asserterror_keyword] = ACTIONS(4774),
    [sym_page_keyword] = ACTIONS(4772),
    [anon_sym_codeunit] = ACTIONS(4772),
    [anon_sym_CODEUNIT] = ACTIONS(4772),
    [anon_sym_Codeunit] = ACTIONS(4772),
    [anon_sym_CodeUnit] = ACTIONS(4772),
    [anon_sym_COdeunit] = ACTIONS(4772),
    [anon_sym_codeUnit] = ACTIONS(4772),
    [sym_report_keyword] = ACTIONS(4772),
    [sym_query_keyword] = ACTIONS(4772),
    [anon_sym_xmlport] = ACTIONS(4772),
    [anon_sym_XMLPORT] = ACTIONS(4772),
    [anon_sym_Xmlport] = ACTIONS(4772),
    [anon_sym_XMLport] = ACTIONS(4772),
    [anon_sym_XMLPort] = ACTIONS(4772),
    [anon_sym_XmlPort] = ACTIONS(4772),
    [anon_sym_enum] = ACTIONS(4772),
    [anon_sym_ENUM] = ACTIONS(4772),
    [anon_sym_Enum] = ACTIONS(4772),
    [anon_sym_eNUM] = ACTIONS(4772),
    [anon_sym_eNum] = ACTIONS(4772),
    [anon_sym_ENum] = ACTIONS(4772),
    [sym_quoted_identifier] = ACTIONS(4774),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4774),
    [sym_integer] = ACTIONS(4772),
    [sym_continue_as_identifier] = ACTIONS(4774),
    [sym_preproc_open] = ACTIONS(4774),
    [sym_preproc_close] = ACTIONS(4774),
  },
  [STATE(1720)] = {
    [sym_identifier] = ACTIONS(4776),
    [anon_sym_SEMI] = ACTIONS(4778),
    [anon_sym_DASH] = ACTIONS(4778),
    [aux_sym_boolean_token1] = ACTIONS(4776),
    [aux_sym_boolean_token2] = ACTIONS(4776),
    [sym_decimal] = ACTIONS(4776),
    [anon_sym_LPAREN] = ACTIONS(4778),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4776),
    [anon_sym_LBRACK] = ACTIONS(4778),
    [aux_sym_record_type_token1] = ACTIONS(4776),
    [aux_sym_basic_type_token21] = ACTIONS(4776),
    [aux_sym_basic_type_token22] = ACTIONS(4776),
    [aux_sym_basic_type_token48] = ACTIONS(4776),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4776),
    [anon_sym_POUNDif] = ACTIONS(4778),
    [anon_sym_POUNDIF] = ACTIONS(4778),
    [anon_sym_POUNDIf] = ACTIONS(4778),
    [anon_sym_not] = ACTIONS(4776),
    [anon_sym_NOT] = ACTIONS(4776),
    [anon_sym_Not] = ACTIONS(4776),
    [anon_sym_POUNDelif] = ACTIONS(4778),
    [anon_sym_POUNDELIF] = ACTIONS(4778),
    [anon_sym_POUNDElif] = ACTIONS(4778),
    [anon_sym_POUNDelse] = ACTIONS(4778),
    [anon_sym_POUNDELSE] = ACTIONS(4778),
    [anon_sym_POUNDElse] = ACTIONS(4778),
    [anon_sym_POUNDendif] = ACTIONS(4778),
    [anon_sym_POUNDENDIF] = ACTIONS(4778),
    [anon_sym_POUNDEndif] = ACTIONS(4778),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4776),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4776),
    [anon_sym_PLUS] = ACTIONS(4778),
    [sym_datetime_literal] = ACTIONS(4778),
    [sym_date_literal] = ACTIONS(4776),
    [sym_time_literal] = ACTIONS(4776),
    [sym_biginteger_literal] = ACTIONS(4778),
    [anon_sym_if] = ACTIONS(4776),
    [anon_sym_IF] = ACTIONS(4776),
    [anon_sym_If] = ACTIONS(4776),
    [anon_sym_else] = ACTIONS(4776),
    [anon_sym_ELSE] = ACTIONS(4776),
    [anon_sym_Else] = ACTIONS(4776),
    [anon_sym_case] = ACTIONS(4776),
    [anon_sym_CASE] = ACTIONS(4776),
    [anon_sym_Case] = ACTIONS(4776),
    [anon_sym_for] = ACTIONS(4776),
    [anon_sym_FOR] = ACTIONS(4776),
    [anon_sym_For] = ACTIONS(4776),
    [anon_sym_foreach] = ACTIONS(4776),
    [anon_sym_FOREACH] = ACTIONS(4776),
    [anon_sym_Foreach] = ACTIONS(4776),
    [anon_sym_while] = ACTIONS(4776),
    [anon_sym_WHILE] = ACTIONS(4776),
    [anon_sym_While] = ACTIONS(4776),
    [anon_sym_repeat] = ACTIONS(4776),
    [anon_sym_REPEAT] = ACTIONS(4776),
    [anon_sym_Repeat] = ACTIONS(4776),
    [anon_sym_exit] = ACTIONS(4776),
    [anon_sym_EXIT] = ACTIONS(4776),
    [anon_sym_Exit] = ACTIONS(4776),
    [anon_sym_continue] = ACTIONS(4776),
    [anon_sym_CONTINUE] = ACTIONS(4776),
    [anon_sym_Continue] = ACTIONS(4776),
    [anon_sym_break] = ACTIONS(4776),
    [anon_sym_BREAK] = ACTIONS(4776),
    [anon_sym_Break] = ACTIONS(4776),
    [anon_sym_with] = ACTIONS(4776),
    [anon_sym_WITH] = ACTIONS(4776),
    [anon_sym_With] = ACTIONS(4776),
    [sym_asserterror_keyword] = ACTIONS(4778),
    [sym_page_keyword] = ACTIONS(4776),
    [anon_sym_codeunit] = ACTIONS(4776),
    [anon_sym_CODEUNIT] = ACTIONS(4776),
    [anon_sym_Codeunit] = ACTIONS(4776),
    [anon_sym_CodeUnit] = ACTIONS(4776),
    [anon_sym_COdeunit] = ACTIONS(4776),
    [anon_sym_codeUnit] = ACTIONS(4776),
    [sym_report_keyword] = ACTIONS(4776),
    [sym_query_keyword] = ACTIONS(4776),
    [anon_sym_xmlport] = ACTIONS(4776),
    [anon_sym_XMLPORT] = ACTIONS(4776),
    [anon_sym_Xmlport] = ACTIONS(4776),
    [anon_sym_XMLport] = ACTIONS(4776),
    [anon_sym_XMLPort] = ACTIONS(4776),
    [anon_sym_XmlPort] = ACTIONS(4776),
    [anon_sym_enum] = ACTIONS(4776),
    [anon_sym_ENUM] = ACTIONS(4776),
    [anon_sym_Enum] = ACTIONS(4776),
    [anon_sym_eNUM] = ACTIONS(4776),
    [anon_sym_eNum] = ACTIONS(4776),
    [anon_sym_ENum] = ACTIONS(4776),
    [sym_quoted_identifier] = ACTIONS(4778),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4778),
    [sym_integer] = ACTIONS(4776),
    [sym_continue_as_identifier] = ACTIONS(4778),
    [sym_preproc_open] = ACTIONS(4778),
    [sym_preproc_close] = ACTIONS(4778),
  },
  [STATE(1721)] = {
    [sym_identifier] = ACTIONS(4772),
    [anon_sym_SEMI] = ACTIONS(4774),
    [anon_sym_DASH] = ACTIONS(4774),
    [aux_sym_boolean_token1] = ACTIONS(4772),
    [aux_sym_boolean_token2] = ACTIONS(4772),
    [sym_decimal] = ACTIONS(4772),
    [anon_sym_LPAREN] = ACTIONS(4774),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4772),
    [anon_sym_LBRACK] = ACTIONS(4774),
    [aux_sym_record_type_token1] = ACTIONS(4772),
    [aux_sym_basic_type_token21] = ACTIONS(4772),
    [aux_sym_basic_type_token22] = ACTIONS(4772),
    [aux_sym_basic_type_token48] = ACTIONS(4772),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4772),
    [anon_sym_POUNDif] = ACTIONS(4774),
    [anon_sym_POUNDIF] = ACTIONS(4774),
    [anon_sym_POUNDIf] = ACTIONS(4774),
    [anon_sym_not] = ACTIONS(4772),
    [anon_sym_NOT] = ACTIONS(4772),
    [anon_sym_Not] = ACTIONS(4772),
    [anon_sym_POUNDelif] = ACTIONS(4774),
    [anon_sym_POUNDELIF] = ACTIONS(4774),
    [anon_sym_POUNDElif] = ACTIONS(4774),
    [anon_sym_POUNDelse] = ACTIONS(4774),
    [anon_sym_POUNDELSE] = ACTIONS(4774),
    [anon_sym_POUNDElse] = ACTIONS(4774),
    [anon_sym_POUNDendif] = ACTIONS(4774),
    [anon_sym_POUNDENDIF] = ACTIONS(4774),
    [anon_sym_POUNDEndif] = ACTIONS(4774),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4772),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4772),
    [anon_sym_PLUS] = ACTIONS(4774),
    [sym_datetime_literal] = ACTIONS(4774),
    [sym_date_literal] = ACTIONS(4772),
    [sym_time_literal] = ACTIONS(4772),
    [sym_biginteger_literal] = ACTIONS(4774),
    [anon_sym_if] = ACTIONS(4772),
    [anon_sym_IF] = ACTIONS(4772),
    [anon_sym_If] = ACTIONS(4772),
    [anon_sym_else] = ACTIONS(4772),
    [anon_sym_ELSE] = ACTIONS(4772),
    [anon_sym_Else] = ACTIONS(4772),
    [anon_sym_case] = ACTIONS(4772),
    [anon_sym_CASE] = ACTIONS(4772),
    [anon_sym_Case] = ACTIONS(4772),
    [anon_sym_for] = ACTIONS(4772),
    [anon_sym_FOR] = ACTIONS(4772),
    [anon_sym_For] = ACTIONS(4772),
    [anon_sym_foreach] = ACTIONS(4772),
    [anon_sym_FOREACH] = ACTIONS(4772),
    [anon_sym_Foreach] = ACTIONS(4772),
    [anon_sym_while] = ACTIONS(4772),
    [anon_sym_WHILE] = ACTIONS(4772),
    [anon_sym_While] = ACTIONS(4772),
    [anon_sym_repeat] = ACTIONS(4772),
    [anon_sym_REPEAT] = ACTIONS(4772),
    [anon_sym_Repeat] = ACTIONS(4772),
    [anon_sym_exit] = ACTIONS(4772),
    [anon_sym_EXIT] = ACTIONS(4772),
    [anon_sym_Exit] = ACTIONS(4772),
    [anon_sym_continue] = ACTIONS(4772),
    [anon_sym_CONTINUE] = ACTIONS(4772),
    [anon_sym_Continue] = ACTIONS(4772),
    [anon_sym_break] = ACTIONS(4772),
    [anon_sym_BREAK] = ACTIONS(4772),
    [anon_sym_Break] = ACTIONS(4772),
    [anon_sym_with] = ACTIONS(4772),
    [anon_sym_WITH] = ACTIONS(4772),
    [anon_sym_With] = ACTIONS(4772),
    [sym_asserterror_keyword] = ACTIONS(4774),
    [sym_page_keyword] = ACTIONS(4772),
    [anon_sym_codeunit] = ACTIONS(4772),
    [anon_sym_CODEUNIT] = ACTIONS(4772),
    [anon_sym_Codeunit] = ACTIONS(4772),
    [anon_sym_CodeUnit] = ACTIONS(4772),
    [anon_sym_COdeunit] = ACTIONS(4772),
    [anon_sym_codeUnit] = ACTIONS(4772),
    [sym_report_keyword] = ACTIONS(4772),
    [sym_query_keyword] = ACTIONS(4772),
    [anon_sym_xmlport] = ACTIONS(4772),
    [anon_sym_XMLPORT] = ACTIONS(4772),
    [anon_sym_Xmlport] = ACTIONS(4772),
    [anon_sym_XMLport] = ACTIONS(4772),
    [anon_sym_XMLPort] = ACTIONS(4772),
    [anon_sym_XmlPort] = ACTIONS(4772),
    [anon_sym_enum] = ACTIONS(4772),
    [anon_sym_ENUM] = ACTIONS(4772),
    [anon_sym_Enum] = ACTIONS(4772),
    [anon_sym_eNUM] = ACTIONS(4772),
    [anon_sym_eNum] = ACTIONS(4772),
    [anon_sym_ENum] = ACTIONS(4772),
    [sym_quoted_identifier] = ACTIONS(4774),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4774),
    [sym_integer] = ACTIONS(4772),
    [sym_continue_as_identifier] = ACTIONS(4774),
    [sym_preproc_open] = ACTIONS(4774),
    [sym_preproc_close] = ACTIONS(4774),
  },
  [STATE(1722)] = {
    [sym_identifier] = ACTIONS(4780),
    [anon_sym_SEMI] = ACTIONS(4782),
    [anon_sym_DASH] = ACTIONS(4782),
    [aux_sym_boolean_token1] = ACTIONS(4780),
    [aux_sym_boolean_token2] = ACTIONS(4780),
    [sym_decimal] = ACTIONS(4780),
    [anon_sym_LPAREN] = ACTIONS(4782),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4780),
    [anon_sym_LBRACK] = ACTIONS(4782),
    [aux_sym_record_type_token1] = ACTIONS(4780),
    [aux_sym_basic_type_token21] = ACTIONS(4780),
    [aux_sym_basic_type_token22] = ACTIONS(4780),
    [aux_sym_basic_type_token48] = ACTIONS(4780),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4780),
    [anon_sym_POUNDif] = ACTIONS(4782),
    [anon_sym_POUNDIF] = ACTIONS(4782),
    [anon_sym_POUNDIf] = ACTIONS(4782),
    [anon_sym_not] = ACTIONS(4780),
    [anon_sym_NOT] = ACTIONS(4780),
    [anon_sym_Not] = ACTIONS(4780),
    [anon_sym_POUNDelif] = ACTIONS(4782),
    [anon_sym_POUNDELIF] = ACTIONS(4782),
    [anon_sym_POUNDElif] = ACTIONS(4782),
    [anon_sym_POUNDelse] = ACTIONS(4782),
    [anon_sym_POUNDELSE] = ACTIONS(4782),
    [anon_sym_POUNDElse] = ACTIONS(4782),
    [anon_sym_POUNDendif] = ACTIONS(4782),
    [anon_sym_POUNDENDIF] = ACTIONS(4782),
    [anon_sym_POUNDEndif] = ACTIONS(4782),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4780),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4780),
    [anon_sym_PLUS] = ACTIONS(4782),
    [sym_datetime_literal] = ACTIONS(4782),
    [sym_date_literal] = ACTIONS(4780),
    [sym_time_literal] = ACTIONS(4780),
    [sym_biginteger_literal] = ACTIONS(4782),
    [anon_sym_if] = ACTIONS(4780),
    [anon_sym_IF] = ACTIONS(4780),
    [anon_sym_If] = ACTIONS(4780),
    [anon_sym_else] = ACTIONS(4780),
    [anon_sym_ELSE] = ACTIONS(4780),
    [anon_sym_Else] = ACTIONS(4780),
    [anon_sym_case] = ACTIONS(4780),
    [anon_sym_CASE] = ACTIONS(4780),
    [anon_sym_Case] = ACTIONS(4780),
    [anon_sym_for] = ACTIONS(4780),
    [anon_sym_FOR] = ACTIONS(4780),
    [anon_sym_For] = ACTIONS(4780),
    [anon_sym_foreach] = ACTIONS(4780),
    [anon_sym_FOREACH] = ACTIONS(4780),
    [anon_sym_Foreach] = ACTIONS(4780),
    [anon_sym_while] = ACTIONS(4780),
    [anon_sym_WHILE] = ACTIONS(4780),
    [anon_sym_While] = ACTIONS(4780),
    [anon_sym_repeat] = ACTIONS(4780),
    [anon_sym_REPEAT] = ACTIONS(4780),
    [anon_sym_Repeat] = ACTIONS(4780),
    [anon_sym_exit] = ACTIONS(4780),
    [anon_sym_EXIT] = ACTIONS(4780),
    [anon_sym_Exit] = ACTIONS(4780),
    [anon_sym_continue] = ACTIONS(4780),
    [anon_sym_CONTINUE] = ACTIONS(4780),
    [anon_sym_Continue] = ACTIONS(4780),
    [anon_sym_break] = ACTIONS(4780),
    [anon_sym_BREAK] = ACTIONS(4780),
    [anon_sym_Break] = ACTIONS(4780),
    [anon_sym_with] = ACTIONS(4780),
    [anon_sym_WITH] = ACTIONS(4780),
    [anon_sym_With] = ACTIONS(4780),
    [sym_asserterror_keyword] = ACTIONS(4782),
    [sym_page_keyword] = ACTIONS(4780),
    [anon_sym_codeunit] = ACTIONS(4780),
    [anon_sym_CODEUNIT] = ACTIONS(4780),
    [anon_sym_Codeunit] = ACTIONS(4780),
    [anon_sym_CodeUnit] = ACTIONS(4780),
    [anon_sym_COdeunit] = ACTIONS(4780),
    [anon_sym_codeUnit] = ACTIONS(4780),
    [sym_report_keyword] = ACTIONS(4780),
    [sym_query_keyword] = ACTIONS(4780),
    [anon_sym_xmlport] = ACTIONS(4780),
    [anon_sym_XMLPORT] = ACTIONS(4780),
    [anon_sym_Xmlport] = ACTIONS(4780),
    [anon_sym_XMLport] = ACTIONS(4780),
    [anon_sym_XMLPort] = ACTIONS(4780),
    [anon_sym_XmlPort] = ACTIONS(4780),
    [anon_sym_enum] = ACTIONS(4780),
    [anon_sym_ENUM] = ACTIONS(4780),
    [anon_sym_Enum] = ACTIONS(4780),
    [anon_sym_eNUM] = ACTIONS(4780),
    [anon_sym_eNum] = ACTIONS(4780),
    [anon_sym_ENum] = ACTIONS(4780),
    [sym_quoted_identifier] = ACTIONS(4782),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4782),
    [sym_integer] = ACTIONS(4780),
    [sym_continue_as_identifier] = ACTIONS(4782),
    [sym_preproc_open] = ACTIONS(4782),
    [sym_preproc_close] = ACTIONS(4782),
  },
  [STATE(1723)] = {
    [sym_identifier] = ACTIONS(4784),
    [anon_sym_SEMI] = ACTIONS(4786),
    [anon_sym_DASH] = ACTIONS(4786),
    [aux_sym_boolean_token1] = ACTIONS(4784),
    [aux_sym_boolean_token2] = ACTIONS(4784),
    [sym_decimal] = ACTIONS(4784),
    [anon_sym_LPAREN] = ACTIONS(4786),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4784),
    [anon_sym_LBRACK] = ACTIONS(4786),
    [aux_sym_record_type_token1] = ACTIONS(4784),
    [aux_sym_basic_type_token21] = ACTIONS(4784),
    [aux_sym_basic_type_token22] = ACTIONS(4784),
    [aux_sym_basic_type_token48] = ACTIONS(4784),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4784),
    [anon_sym_POUNDif] = ACTIONS(4786),
    [anon_sym_POUNDIF] = ACTIONS(4786),
    [anon_sym_POUNDIf] = ACTIONS(4786),
    [anon_sym_not] = ACTIONS(4784),
    [anon_sym_NOT] = ACTIONS(4784),
    [anon_sym_Not] = ACTIONS(4784),
    [anon_sym_POUNDelif] = ACTIONS(4786),
    [anon_sym_POUNDELIF] = ACTIONS(4786),
    [anon_sym_POUNDElif] = ACTIONS(4786),
    [anon_sym_POUNDelse] = ACTIONS(4786),
    [anon_sym_POUNDELSE] = ACTIONS(4786),
    [anon_sym_POUNDElse] = ACTIONS(4786),
    [anon_sym_POUNDendif] = ACTIONS(4786),
    [anon_sym_POUNDENDIF] = ACTIONS(4786),
    [anon_sym_POUNDEndif] = ACTIONS(4786),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4784),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4784),
    [anon_sym_PLUS] = ACTIONS(4786),
    [sym_datetime_literal] = ACTIONS(4786),
    [sym_date_literal] = ACTIONS(4784),
    [sym_time_literal] = ACTIONS(4784),
    [sym_biginteger_literal] = ACTIONS(4786),
    [anon_sym_if] = ACTIONS(4784),
    [anon_sym_IF] = ACTIONS(4784),
    [anon_sym_If] = ACTIONS(4784),
    [anon_sym_else] = ACTIONS(4784),
    [anon_sym_ELSE] = ACTIONS(4784),
    [anon_sym_Else] = ACTIONS(4784),
    [anon_sym_case] = ACTIONS(4784),
    [anon_sym_CASE] = ACTIONS(4784),
    [anon_sym_Case] = ACTIONS(4784),
    [anon_sym_for] = ACTIONS(4784),
    [anon_sym_FOR] = ACTIONS(4784),
    [anon_sym_For] = ACTIONS(4784),
    [anon_sym_foreach] = ACTIONS(4784),
    [anon_sym_FOREACH] = ACTIONS(4784),
    [anon_sym_Foreach] = ACTIONS(4784),
    [anon_sym_while] = ACTIONS(4784),
    [anon_sym_WHILE] = ACTIONS(4784),
    [anon_sym_While] = ACTIONS(4784),
    [anon_sym_repeat] = ACTIONS(4784),
    [anon_sym_REPEAT] = ACTIONS(4784),
    [anon_sym_Repeat] = ACTIONS(4784),
    [anon_sym_exit] = ACTIONS(4784),
    [anon_sym_EXIT] = ACTIONS(4784),
    [anon_sym_Exit] = ACTIONS(4784),
    [anon_sym_continue] = ACTIONS(4784),
    [anon_sym_CONTINUE] = ACTIONS(4784),
    [anon_sym_Continue] = ACTIONS(4784),
    [anon_sym_break] = ACTIONS(4784),
    [anon_sym_BREAK] = ACTIONS(4784),
    [anon_sym_Break] = ACTIONS(4784),
    [anon_sym_with] = ACTIONS(4784),
    [anon_sym_WITH] = ACTIONS(4784),
    [anon_sym_With] = ACTIONS(4784),
    [sym_asserterror_keyword] = ACTIONS(4786),
    [sym_page_keyword] = ACTIONS(4784),
    [anon_sym_codeunit] = ACTIONS(4784),
    [anon_sym_CODEUNIT] = ACTIONS(4784),
    [anon_sym_Codeunit] = ACTIONS(4784),
    [anon_sym_CodeUnit] = ACTIONS(4784),
    [anon_sym_COdeunit] = ACTIONS(4784),
    [anon_sym_codeUnit] = ACTIONS(4784),
    [sym_report_keyword] = ACTIONS(4784),
    [sym_query_keyword] = ACTIONS(4784),
    [anon_sym_xmlport] = ACTIONS(4784),
    [anon_sym_XMLPORT] = ACTIONS(4784),
    [anon_sym_Xmlport] = ACTIONS(4784),
    [anon_sym_XMLport] = ACTIONS(4784),
    [anon_sym_XMLPort] = ACTIONS(4784),
    [anon_sym_XmlPort] = ACTIONS(4784),
    [anon_sym_enum] = ACTIONS(4784),
    [anon_sym_ENUM] = ACTIONS(4784),
    [anon_sym_Enum] = ACTIONS(4784),
    [anon_sym_eNUM] = ACTIONS(4784),
    [anon_sym_eNum] = ACTIONS(4784),
    [anon_sym_ENum] = ACTIONS(4784),
    [sym_quoted_identifier] = ACTIONS(4786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4786),
    [sym_integer] = ACTIONS(4784),
    [sym_continue_as_identifier] = ACTIONS(4786),
    [sym_preproc_open] = ACTIONS(4786),
    [sym_preproc_close] = ACTIONS(4786),
  },
  [STATE(1724)] = {
    [sym_identifier] = ACTIONS(4780),
    [anon_sym_SEMI] = ACTIONS(4782),
    [anon_sym_DASH] = ACTIONS(4782),
    [aux_sym_boolean_token1] = ACTIONS(4780),
    [aux_sym_boolean_token2] = ACTIONS(4780),
    [sym_decimal] = ACTIONS(4780),
    [anon_sym_LPAREN] = ACTIONS(4782),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4780),
    [anon_sym_LBRACK] = ACTIONS(4782),
    [aux_sym_record_type_token1] = ACTIONS(4780),
    [aux_sym_basic_type_token21] = ACTIONS(4780),
    [aux_sym_basic_type_token22] = ACTIONS(4780),
    [aux_sym_basic_type_token48] = ACTIONS(4780),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4780),
    [anon_sym_POUNDif] = ACTIONS(4782),
    [anon_sym_POUNDIF] = ACTIONS(4782),
    [anon_sym_POUNDIf] = ACTIONS(4782),
    [anon_sym_not] = ACTIONS(4780),
    [anon_sym_NOT] = ACTIONS(4780),
    [anon_sym_Not] = ACTIONS(4780),
    [anon_sym_POUNDelif] = ACTIONS(4782),
    [anon_sym_POUNDELIF] = ACTIONS(4782),
    [anon_sym_POUNDElif] = ACTIONS(4782),
    [anon_sym_POUNDelse] = ACTIONS(4782),
    [anon_sym_POUNDELSE] = ACTIONS(4782),
    [anon_sym_POUNDElse] = ACTIONS(4782),
    [anon_sym_POUNDendif] = ACTIONS(4782),
    [anon_sym_POUNDENDIF] = ACTIONS(4782),
    [anon_sym_POUNDEndif] = ACTIONS(4782),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4780),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4780),
    [anon_sym_PLUS] = ACTIONS(4782),
    [sym_datetime_literal] = ACTIONS(4782),
    [sym_date_literal] = ACTIONS(4780),
    [sym_time_literal] = ACTIONS(4780),
    [sym_biginteger_literal] = ACTIONS(4782),
    [anon_sym_if] = ACTIONS(4780),
    [anon_sym_IF] = ACTIONS(4780),
    [anon_sym_If] = ACTIONS(4780),
    [anon_sym_else] = ACTIONS(4780),
    [anon_sym_ELSE] = ACTIONS(4780),
    [anon_sym_Else] = ACTIONS(4780),
    [anon_sym_case] = ACTIONS(4780),
    [anon_sym_CASE] = ACTIONS(4780),
    [anon_sym_Case] = ACTIONS(4780),
    [anon_sym_for] = ACTIONS(4780),
    [anon_sym_FOR] = ACTIONS(4780),
    [anon_sym_For] = ACTIONS(4780),
    [anon_sym_foreach] = ACTIONS(4780),
    [anon_sym_FOREACH] = ACTIONS(4780),
    [anon_sym_Foreach] = ACTIONS(4780),
    [anon_sym_while] = ACTIONS(4780),
    [anon_sym_WHILE] = ACTIONS(4780),
    [anon_sym_While] = ACTIONS(4780),
    [anon_sym_repeat] = ACTIONS(4780),
    [anon_sym_REPEAT] = ACTIONS(4780),
    [anon_sym_Repeat] = ACTIONS(4780),
    [anon_sym_exit] = ACTIONS(4780),
    [anon_sym_EXIT] = ACTIONS(4780),
    [anon_sym_Exit] = ACTIONS(4780),
    [anon_sym_continue] = ACTIONS(4780),
    [anon_sym_CONTINUE] = ACTIONS(4780),
    [anon_sym_Continue] = ACTIONS(4780),
    [anon_sym_break] = ACTIONS(4780),
    [anon_sym_BREAK] = ACTIONS(4780),
    [anon_sym_Break] = ACTIONS(4780),
    [anon_sym_with] = ACTIONS(4780),
    [anon_sym_WITH] = ACTIONS(4780),
    [anon_sym_With] = ACTIONS(4780),
    [sym_asserterror_keyword] = ACTIONS(4782),
    [sym_page_keyword] = ACTIONS(4780),
    [anon_sym_codeunit] = ACTIONS(4780),
    [anon_sym_CODEUNIT] = ACTIONS(4780),
    [anon_sym_Codeunit] = ACTIONS(4780),
    [anon_sym_CodeUnit] = ACTIONS(4780),
    [anon_sym_COdeunit] = ACTIONS(4780),
    [anon_sym_codeUnit] = ACTIONS(4780),
    [sym_report_keyword] = ACTIONS(4780),
    [sym_query_keyword] = ACTIONS(4780),
    [anon_sym_xmlport] = ACTIONS(4780),
    [anon_sym_XMLPORT] = ACTIONS(4780),
    [anon_sym_Xmlport] = ACTIONS(4780),
    [anon_sym_XMLport] = ACTIONS(4780),
    [anon_sym_XMLPort] = ACTIONS(4780),
    [anon_sym_XmlPort] = ACTIONS(4780),
    [anon_sym_enum] = ACTIONS(4780),
    [anon_sym_ENUM] = ACTIONS(4780),
    [anon_sym_Enum] = ACTIONS(4780),
    [anon_sym_eNUM] = ACTIONS(4780),
    [anon_sym_eNum] = ACTIONS(4780),
    [anon_sym_ENum] = ACTIONS(4780),
    [sym_quoted_identifier] = ACTIONS(4782),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4782),
    [sym_integer] = ACTIONS(4780),
    [sym_continue_as_identifier] = ACTIONS(4782),
    [sym_preproc_open] = ACTIONS(4782),
    [sym_preproc_close] = ACTIONS(4782),
  },
  [STATE(1725)] = {
    [sym_identifier] = ACTIONS(4788),
    [anon_sym_SEMI] = ACTIONS(4790),
    [anon_sym_DASH] = ACTIONS(4790),
    [aux_sym_boolean_token1] = ACTIONS(4788),
    [aux_sym_boolean_token2] = ACTIONS(4788),
    [sym_decimal] = ACTIONS(4788),
    [anon_sym_LPAREN] = ACTIONS(4790),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4788),
    [anon_sym_LBRACK] = ACTIONS(4790),
    [aux_sym_record_type_token1] = ACTIONS(4788),
    [aux_sym_basic_type_token21] = ACTIONS(4788),
    [aux_sym_basic_type_token22] = ACTIONS(4788),
    [aux_sym_basic_type_token48] = ACTIONS(4788),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4788),
    [anon_sym_POUNDif] = ACTIONS(4790),
    [anon_sym_POUNDIF] = ACTIONS(4790),
    [anon_sym_POUNDIf] = ACTIONS(4790),
    [anon_sym_not] = ACTIONS(4788),
    [anon_sym_NOT] = ACTIONS(4788),
    [anon_sym_Not] = ACTIONS(4788),
    [anon_sym_POUNDelif] = ACTIONS(4790),
    [anon_sym_POUNDELIF] = ACTIONS(4790),
    [anon_sym_POUNDElif] = ACTIONS(4790),
    [anon_sym_POUNDelse] = ACTIONS(4790),
    [anon_sym_POUNDELSE] = ACTIONS(4790),
    [anon_sym_POUNDElse] = ACTIONS(4790),
    [anon_sym_POUNDendif] = ACTIONS(4790),
    [anon_sym_POUNDENDIF] = ACTIONS(4790),
    [anon_sym_POUNDEndif] = ACTIONS(4790),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4788),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4788),
    [anon_sym_PLUS] = ACTIONS(4790),
    [sym_datetime_literal] = ACTIONS(4790),
    [sym_date_literal] = ACTIONS(4788),
    [sym_time_literal] = ACTIONS(4788),
    [sym_biginteger_literal] = ACTIONS(4790),
    [anon_sym_if] = ACTIONS(4788),
    [anon_sym_IF] = ACTIONS(4788),
    [anon_sym_If] = ACTIONS(4788),
    [anon_sym_else] = ACTIONS(4788),
    [anon_sym_ELSE] = ACTIONS(4788),
    [anon_sym_Else] = ACTIONS(4788),
    [anon_sym_case] = ACTIONS(4788),
    [anon_sym_CASE] = ACTIONS(4788),
    [anon_sym_Case] = ACTIONS(4788),
    [anon_sym_for] = ACTIONS(4788),
    [anon_sym_FOR] = ACTIONS(4788),
    [anon_sym_For] = ACTIONS(4788),
    [anon_sym_foreach] = ACTIONS(4788),
    [anon_sym_FOREACH] = ACTIONS(4788),
    [anon_sym_Foreach] = ACTIONS(4788),
    [anon_sym_while] = ACTIONS(4788),
    [anon_sym_WHILE] = ACTIONS(4788),
    [anon_sym_While] = ACTIONS(4788),
    [anon_sym_repeat] = ACTIONS(4788),
    [anon_sym_REPEAT] = ACTIONS(4788),
    [anon_sym_Repeat] = ACTIONS(4788),
    [anon_sym_exit] = ACTIONS(4788),
    [anon_sym_EXIT] = ACTIONS(4788),
    [anon_sym_Exit] = ACTIONS(4788),
    [anon_sym_continue] = ACTIONS(4788),
    [anon_sym_CONTINUE] = ACTIONS(4788),
    [anon_sym_Continue] = ACTIONS(4788),
    [anon_sym_break] = ACTIONS(4788),
    [anon_sym_BREAK] = ACTIONS(4788),
    [anon_sym_Break] = ACTIONS(4788),
    [anon_sym_with] = ACTIONS(4788),
    [anon_sym_WITH] = ACTIONS(4788),
    [anon_sym_With] = ACTIONS(4788),
    [sym_asserterror_keyword] = ACTIONS(4790),
    [sym_page_keyword] = ACTIONS(4788),
    [anon_sym_codeunit] = ACTIONS(4788),
    [anon_sym_CODEUNIT] = ACTIONS(4788),
    [anon_sym_Codeunit] = ACTIONS(4788),
    [anon_sym_CodeUnit] = ACTIONS(4788),
    [anon_sym_COdeunit] = ACTIONS(4788),
    [anon_sym_codeUnit] = ACTIONS(4788),
    [sym_report_keyword] = ACTIONS(4788),
    [sym_query_keyword] = ACTIONS(4788),
    [anon_sym_xmlport] = ACTIONS(4788),
    [anon_sym_XMLPORT] = ACTIONS(4788),
    [anon_sym_Xmlport] = ACTIONS(4788),
    [anon_sym_XMLport] = ACTIONS(4788),
    [anon_sym_XMLPort] = ACTIONS(4788),
    [anon_sym_XmlPort] = ACTIONS(4788),
    [anon_sym_enum] = ACTIONS(4788),
    [anon_sym_ENUM] = ACTIONS(4788),
    [anon_sym_Enum] = ACTIONS(4788),
    [anon_sym_eNUM] = ACTIONS(4788),
    [anon_sym_eNum] = ACTIONS(4788),
    [anon_sym_ENum] = ACTIONS(4788),
    [sym_quoted_identifier] = ACTIONS(4790),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4790),
    [sym_integer] = ACTIONS(4788),
    [sym_continue_as_identifier] = ACTIONS(4790),
    [sym_preproc_open] = ACTIONS(4790),
    [sym_preproc_close] = ACTIONS(4790),
  },
  [STATE(1726)] = {
    [sym_identifier] = ACTIONS(4792),
    [anon_sym_SEMI] = ACTIONS(4794),
    [anon_sym_DASH] = ACTIONS(4794),
    [aux_sym_boolean_token1] = ACTIONS(4792),
    [aux_sym_boolean_token2] = ACTIONS(4792),
    [sym_decimal] = ACTIONS(4792),
    [anon_sym_LPAREN] = ACTIONS(4794),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4792),
    [anon_sym_LBRACK] = ACTIONS(4794),
    [aux_sym_record_type_token1] = ACTIONS(4792),
    [aux_sym_basic_type_token21] = ACTIONS(4792),
    [aux_sym_basic_type_token22] = ACTIONS(4792),
    [aux_sym_basic_type_token48] = ACTIONS(4792),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4792),
    [anon_sym_POUNDif] = ACTIONS(4794),
    [anon_sym_POUNDIF] = ACTIONS(4794),
    [anon_sym_POUNDIf] = ACTIONS(4794),
    [anon_sym_not] = ACTIONS(4792),
    [anon_sym_NOT] = ACTIONS(4792),
    [anon_sym_Not] = ACTIONS(4792),
    [anon_sym_POUNDelif] = ACTIONS(4794),
    [anon_sym_POUNDELIF] = ACTIONS(4794),
    [anon_sym_POUNDElif] = ACTIONS(4794),
    [anon_sym_POUNDelse] = ACTIONS(4794),
    [anon_sym_POUNDELSE] = ACTIONS(4794),
    [anon_sym_POUNDElse] = ACTIONS(4794),
    [anon_sym_POUNDendif] = ACTIONS(4794),
    [anon_sym_POUNDENDIF] = ACTIONS(4794),
    [anon_sym_POUNDEndif] = ACTIONS(4794),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4792),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4792),
    [anon_sym_PLUS] = ACTIONS(4794),
    [sym_datetime_literal] = ACTIONS(4794),
    [sym_date_literal] = ACTIONS(4792),
    [sym_time_literal] = ACTIONS(4792),
    [sym_biginteger_literal] = ACTIONS(4794),
    [anon_sym_if] = ACTIONS(4792),
    [anon_sym_IF] = ACTIONS(4792),
    [anon_sym_If] = ACTIONS(4792),
    [anon_sym_else] = ACTIONS(4792),
    [anon_sym_ELSE] = ACTIONS(4792),
    [anon_sym_Else] = ACTIONS(4792),
    [anon_sym_case] = ACTIONS(4792),
    [anon_sym_CASE] = ACTIONS(4792),
    [anon_sym_Case] = ACTIONS(4792),
    [anon_sym_for] = ACTIONS(4792),
    [anon_sym_FOR] = ACTIONS(4792),
    [anon_sym_For] = ACTIONS(4792),
    [anon_sym_foreach] = ACTIONS(4792),
    [anon_sym_FOREACH] = ACTIONS(4792),
    [anon_sym_Foreach] = ACTIONS(4792),
    [anon_sym_while] = ACTIONS(4792),
    [anon_sym_WHILE] = ACTIONS(4792),
    [anon_sym_While] = ACTIONS(4792),
    [anon_sym_repeat] = ACTIONS(4792),
    [anon_sym_REPEAT] = ACTIONS(4792),
    [anon_sym_Repeat] = ACTIONS(4792),
    [anon_sym_exit] = ACTIONS(4792),
    [anon_sym_EXIT] = ACTIONS(4792),
    [anon_sym_Exit] = ACTIONS(4792),
    [anon_sym_continue] = ACTIONS(4792),
    [anon_sym_CONTINUE] = ACTIONS(4792),
    [anon_sym_Continue] = ACTIONS(4792),
    [anon_sym_break] = ACTIONS(4792),
    [anon_sym_BREAK] = ACTIONS(4792),
    [anon_sym_Break] = ACTIONS(4792),
    [anon_sym_with] = ACTIONS(4792),
    [anon_sym_WITH] = ACTIONS(4792),
    [anon_sym_With] = ACTIONS(4792),
    [sym_asserterror_keyword] = ACTIONS(4794),
    [sym_page_keyword] = ACTIONS(4792),
    [anon_sym_codeunit] = ACTIONS(4792),
    [anon_sym_CODEUNIT] = ACTIONS(4792),
    [anon_sym_Codeunit] = ACTIONS(4792),
    [anon_sym_CodeUnit] = ACTIONS(4792),
    [anon_sym_COdeunit] = ACTIONS(4792),
    [anon_sym_codeUnit] = ACTIONS(4792),
    [sym_report_keyword] = ACTIONS(4792),
    [sym_query_keyword] = ACTIONS(4792),
    [anon_sym_xmlport] = ACTIONS(4792),
    [anon_sym_XMLPORT] = ACTIONS(4792),
    [anon_sym_Xmlport] = ACTIONS(4792),
    [anon_sym_XMLport] = ACTIONS(4792),
    [anon_sym_XMLPort] = ACTIONS(4792),
    [anon_sym_XmlPort] = ACTIONS(4792),
    [anon_sym_enum] = ACTIONS(4792),
    [anon_sym_ENUM] = ACTIONS(4792),
    [anon_sym_Enum] = ACTIONS(4792),
    [anon_sym_eNUM] = ACTIONS(4792),
    [anon_sym_eNum] = ACTIONS(4792),
    [anon_sym_ENum] = ACTIONS(4792),
    [sym_quoted_identifier] = ACTIONS(4794),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4794),
    [sym_integer] = ACTIONS(4792),
    [sym_continue_as_identifier] = ACTIONS(4794),
    [sym_preproc_open] = ACTIONS(4794),
    [sym_preproc_close] = ACTIONS(4794),
  },
  [STATE(1727)] = {
    [sym_identifier] = ACTIONS(4796),
    [anon_sym_SEMI] = ACTIONS(4798),
    [anon_sym_DASH] = ACTIONS(4798),
    [aux_sym_boolean_token1] = ACTIONS(4796),
    [aux_sym_boolean_token2] = ACTIONS(4796),
    [sym_decimal] = ACTIONS(4796),
    [anon_sym_LPAREN] = ACTIONS(4798),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4796),
    [anon_sym_LBRACK] = ACTIONS(4798),
    [aux_sym_record_type_token1] = ACTIONS(4796),
    [aux_sym_basic_type_token21] = ACTIONS(4796),
    [aux_sym_basic_type_token22] = ACTIONS(4796),
    [aux_sym_basic_type_token48] = ACTIONS(4796),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4796),
    [anon_sym_POUNDif] = ACTIONS(4798),
    [anon_sym_POUNDIF] = ACTIONS(4798),
    [anon_sym_POUNDIf] = ACTIONS(4798),
    [anon_sym_not] = ACTIONS(4796),
    [anon_sym_NOT] = ACTIONS(4796),
    [anon_sym_Not] = ACTIONS(4796),
    [anon_sym_POUNDelif] = ACTIONS(4798),
    [anon_sym_POUNDELIF] = ACTIONS(4798),
    [anon_sym_POUNDElif] = ACTIONS(4798),
    [anon_sym_POUNDelse] = ACTIONS(4798),
    [anon_sym_POUNDELSE] = ACTIONS(4798),
    [anon_sym_POUNDElse] = ACTIONS(4798),
    [anon_sym_POUNDendif] = ACTIONS(4798),
    [anon_sym_POUNDENDIF] = ACTIONS(4798),
    [anon_sym_POUNDEndif] = ACTIONS(4798),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4796),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4796),
    [anon_sym_PLUS] = ACTIONS(4798),
    [sym_datetime_literal] = ACTIONS(4798),
    [sym_date_literal] = ACTIONS(4796),
    [sym_time_literal] = ACTIONS(4796),
    [sym_biginteger_literal] = ACTIONS(4798),
    [anon_sym_if] = ACTIONS(4796),
    [anon_sym_IF] = ACTIONS(4796),
    [anon_sym_If] = ACTIONS(4796),
    [anon_sym_else] = ACTIONS(4796),
    [anon_sym_ELSE] = ACTIONS(4796),
    [anon_sym_Else] = ACTIONS(4796),
    [anon_sym_case] = ACTIONS(4796),
    [anon_sym_CASE] = ACTIONS(4796),
    [anon_sym_Case] = ACTIONS(4796),
    [anon_sym_for] = ACTIONS(4796),
    [anon_sym_FOR] = ACTIONS(4796),
    [anon_sym_For] = ACTIONS(4796),
    [anon_sym_foreach] = ACTIONS(4796),
    [anon_sym_FOREACH] = ACTIONS(4796),
    [anon_sym_Foreach] = ACTIONS(4796),
    [anon_sym_while] = ACTIONS(4796),
    [anon_sym_WHILE] = ACTIONS(4796),
    [anon_sym_While] = ACTIONS(4796),
    [anon_sym_repeat] = ACTIONS(4796),
    [anon_sym_REPEAT] = ACTIONS(4796),
    [anon_sym_Repeat] = ACTIONS(4796),
    [anon_sym_exit] = ACTIONS(4796),
    [anon_sym_EXIT] = ACTIONS(4796),
    [anon_sym_Exit] = ACTIONS(4796),
    [anon_sym_continue] = ACTIONS(4796),
    [anon_sym_CONTINUE] = ACTIONS(4796),
    [anon_sym_Continue] = ACTIONS(4796),
    [anon_sym_break] = ACTIONS(4796),
    [anon_sym_BREAK] = ACTIONS(4796),
    [anon_sym_Break] = ACTIONS(4796),
    [anon_sym_with] = ACTIONS(4796),
    [anon_sym_WITH] = ACTIONS(4796),
    [anon_sym_With] = ACTIONS(4796),
    [sym_asserterror_keyword] = ACTIONS(4798),
    [sym_page_keyword] = ACTIONS(4796),
    [anon_sym_codeunit] = ACTIONS(4796),
    [anon_sym_CODEUNIT] = ACTIONS(4796),
    [anon_sym_Codeunit] = ACTIONS(4796),
    [anon_sym_CodeUnit] = ACTIONS(4796),
    [anon_sym_COdeunit] = ACTIONS(4796),
    [anon_sym_codeUnit] = ACTIONS(4796),
    [sym_report_keyword] = ACTIONS(4796),
    [sym_query_keyword] = ACTIONS(4796),
    [anon_sym_xmlport] = ACTIONS(4796),
    [anon_sym_XMLPORT] = ACTIONS(4796),
    [anon_sym_Xmlport] = ACTIONS(4796),
    [anon_sym_XMLport] = ACTIONS(4796),
    [anon_sym_XMLPort] = ACTIONS(4796),
    [anon_sym_XmlPort] = ACTIONS(4796),
    [anon_sym_enum] = ACTIONS(4796),
    [anon_sym_ENUM] = ACTIONS(4796),
    [anon_sym_Enum] = ACTIONS(4796),
    [anon_sym_eNUM] = ACTIONS(4796),
    [anon_sym_eNum] = ACTIONS(4796),
    [anon_sym_ENum] = ACTIONS(4796),
    [sym_quoted_identifier] = ACTIONS(4798),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4798),
    [sym_integer] = ACTIONS(4796),
    [sym_continue_as_identifier] = ACTIONS(4798),
    [sym_preproc_open] = ACTIONS(4798),
    [sym_preproc_close] = ACTIONS(4798),
  },
  [STATE(1728)] = {
    [sym_identifier] = ACTIONS(4800),
    [anon_sym_SEMI] = ACTIONS(4802),
    [anon_sym_DASH] = ACTIONS(4802),
    [aux_sym_boolean_token1] = ACTIONS(4800),
    [aux_sym_boolean_token2] = ACTIONS(4800),
    [sym_decimal] = ACTIONS(4800),
    [anon_sym_LPAREN] = ACTIONS(4802),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4800),
    [anon_sym_LBRACK] = ACTIONS(4802),
    [aux_sym_record_type_token1] = ACTIONS(4800),
    [aux_sym_basic_type_token21] = ACTIONS(4800),
    [aux_sym_basic_type_token22] = ACTIONS(4800),
    [aux_sym_basic_type_token48] = ACTIONS(4800),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4800),
    [anon_sym_POUNDif] = ACTIONS(4802),
    [anon_sym_POUNDIF] = ACTIONS(4802),
    [anon_sym_POUNDIf] = ACTIONS(4802),
    [anon_sym_not] = ACTIONS(4800),
    [anon_sym_NOT] = ACTIONS(4800),
    [anon_sym_Not] = ACTIONS(4800),
    [anon_sym_POUNDelif] = ACTIONS(4802),
    [anon_sym_POUNDELIF] = ACTIONS(4802),
    [anon_sym_POUNDElif] = ACTIONS(4802),
    [anon_sym_POUNDelse] = ACTIONS(4802),
    [anon_sym_POUNDELSE] = ACTIONS(4802),
    [anon_sym_POUNDElse] = ACTIONS(4802),
    [anon_sym_POUNDendif] = ACTIONS(4802),
    [anon_sym_POUNDENDIF] = ACTIONS(4802),
    [anon_sym_POUNDEndif] = ACTIONS(4802),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4800),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4800),
    [anon_sym_PLUS] = ACTIONS(4802),
    [sym_datetime_literal] = ACTIONS(4802),
    [sym_date_literal] = ACTIONS(4800),
    [sym_time_literal] = ACTIONS(4800),
    [sym_biginteger_literal] = ACTIONS(4802),
    [anon_sym_if] = ACTIONS(4800),
    [anon_sym_IF] = ACTIONS(4800),
    [anon_sym_If] = ACTIONS(4800),
    [anon_sym_else] = ACTIONS(4800),
    [anon_sym_ELSE] = ACTIONS(4800),
    [anon_sym_Else] = ACTIONS(4800),
    [anon_sym_case] = ACTIONS(4800),
    [anon_sym_CASE] = ACTIONS(4800),
    [anon_sym_Case] = ACTIONS(4800),
    [anon_sym_for] = ACTIONS(4800),
    [anon_sym_FOR] = ACTIONS(4800),
    [anon_sym_For] = ACTIONS(4800),
    [anon_sym_foreach] = ACTIONS(4800),
    [anon_sym_FOREACH] = ACTIONS(4800),
    [anon_sym_Foreach] = ACTIONS(4800),
    [anon_sym_while] = ACTIONS(4800),
    [anon_sym_WHILE] = ACTIONS(4800),
    [anon_sym_While] = ACTIONS(4800),
    [anon_sym_repeat] = ACTIONS(4800),
    [anon_sym_REPEAT] = ACTIONS(4800),
    [anon_sym_Repeat] = ACTIONS(4800),
    [anon_sym_exit] = ACTIONS(4800),
    [anon_sym_EXIT] = ACTIONS(4800),
    [anon_sym_Exit] = ACTIONS(4800),
    [anon_sym_continue] = ACTIONS(4800),
    [anon_sym_CONTINUE] = ACTIONS(4800),
    [anon_sym_Continue] = ACTIONS(4800),
    [anon_sym_break] = ACTIONS(4800),
    [anon_sym_BREAK] = ACTIONS(4800),
    [anon_sym_Break] = ACTIONS(4800),
    [anon_sym_with] = ACTIONS(4800),
    [anon_sym_WITH] = ACTIONS(4800),
    [anon_sym_With] = ACTIONS(4800),
    [sym_asserterror_keyword] = ACTIONS(4802),
    [sym_page_keyword] = ACTIONS(4800),
    [anon_sym_codeunit] = ACTIONS(4800),
    [anon_sym_CODEUNIT] = ACTIONS(4800),
    [anon_sym_Codeunit] = ACTIONS(4800),
    [anon_sym_CodeUnit] = ACTIONS(4800),
    [anon_sym_COdeunit] = ACTIONS(4800),
    [anon_sym_codeUnit] = ACTIONS(4800),
    [sym_report_keyword] = ACTIONS(4800),
    [sym_query_keyword] = ACTIONS(4800),
    [anon_sym_xmlport] = ACTIONS(4800),
    [anon_sym_XMLPORT] = ACTIONS(4800),
    [anon_sym_Xmlport] = ACTIONS(4800),
    [anon_sym_XMLport] = ACTIONS(4800),
    [anon_sym_XMLPort] = ACTIONS(4800),
    [anon_sym_XmlPort] = ACTIONS(4800),
    [anon_sym_enum] = ACTIONS(4800),
    [anon_sym_ENUM] = ACTIONS(4800),
    [anon_sym_Enum] = ACTIONS(4800),
    [anon_sym_eNUM] = ACTIONS(4800),
    [anon_sym_eNum] = ACTIONS(4800),
    [anon_sym_ENum] = ACTIONS(4800),
    [sym_quoted_identifier] = ACTIONS(4802),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4802),
    [sym_integer] = ACTIONS(4800),
    [sym_continue_as_identifier] = ACTIONS(4802),
    [sym_preproc_open] = ACTIONS(4802),
    [sym_preproc_close] = ACTIONS(4802),
  },
  [STATE(1729)] = {
    [sym_identifier] = ACTIONS(4189),
    [anon_sym_SEMI] = ACTIONS(4191),
    [anon_sym_DASH] = ACTIONS(4191),
    [aux_sym_boolean_token1] = ACTIONS(4189),
    [aux_sym_boolean_token2] = ACTIONS(4189),
    [sym_decimal] = ACTIONS(4189),
    [anon_sym_LPAREN] = ACTIONS(4191),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4189),
    [anon_sym_LBRACK] = ACTIONS(4191),
    [aux_sym_record_type_token1] = ACTIONS(4189),
    [aux_sym_basic_type_token21] = ACTIONS(4189),
    [aux_sym_basic_type_token22] = ACTIONS(4189),
    [aux_sym_basic_type_token48] = ACTIONS(4189),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4189),
    [anon_sym_POUNDif] = ACTIONS(4191),
    [anon_sym_POUNDIF] = ACTIONS(4191),
    [anon_sym_POUNDIf] = ACTIONS(4191),
    [anon_sym_not] = ACTIONS(4189),
    [anon_sym_NOT] = ACTIONS(4189),
    [anon_sym_Not] = ACTIONS(4189),
    [anon_sym_POUNDelif] = ACTIONS(4191),
    [anon_sym_POUNDELIF] = ACTIONS(4191),
    [anon_sym_POUNDElif] = ACTIONS(4191),
    [anon_sym_POUNDelse] = ACTIONS(4191),
    [anon_sym_POUNDELSE] = ACTIONS(4191),
    [anon_sym_POUNDElse] = ACTIONS(4191),
    [anon_sym_POUNDendif] = ACTIONS(4191),
    [anon_sym_POUNDENDIF] = ACTIONS(4191),
    [anon_sym_POUNDEndif] = ACTIONS(4191),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4189),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4189),
    [anon_sym_PLUS] = ACTIONS(4191),
    [sym_datetime_literal] = ACTIONS(4191),
    [sym_date_literal] = ACTIONS(4189),
    [sym_time_literal] = ACTIONS(4189),
    [sym_biginteger_literal] = ACTIONS(4191),
    [anon_sym_if] = ACTIONS(4189),
    [anon_sym_IF] = ACTIONS(4189),
    [anon_sym_If] = ACTIONS(4189),
    [anon_sym_else] = ACTIONS(4189),
    [anon_sym_ELSE] = ACTIONS(4189),
    [anon_sym_Else] = ACTIONS(4189),
    [anon_sym_case] = ACTIONS(4189),
    [anon_sym_CASE] = ACTIONS(4189),
    [anon_sym_Case] = ACTIONS(4189),
    [anon_sym_for] = ACTIONS(4189),
    [anon_sym_FOR] = ACTIONS(4189),
    [anon_sym_For] = ACTIONS(4189),
    [anon_sym_foreach] = ACTIONS(4189),
    [anon_sym_FOREACH] = ACTIONS(4189),
    [anon_sym_Foreach] = ACTIONS(4189),
    [anon_sym_while] = ACTIONS(4189),
    [anon_sym_WHILE] = ACTIONS(4189),
    [anon_sym_While] = ACTIONS(4189),
    [anon_sym_repeat] = ACTIONS(4189),
    [anon_sym_REPEAT] = ACTIONS(4189),
    [anon_sym_Repeat] = ACTIONS(4189),
    [anon_sym_exit] = ACTIONS(4189),
    [anon_sym_EXIT] = ACTIONS(4189),
    [anon_sym_Exit] = ACTIONS(4189),
    [anon_sym_continue] = ACTIONS(4189),
    [anon_sym_CONTINUE] = ACTIONS(4189),
    [anon_sym_Continue] = ACTIONS(4189),
    [anon_sym_break] = ACTIONS(4189),
    [anon_sym_BREAK] = ACTIONS(4189),
    [anon_sym_Break] = ACTIONS(4189),
    [anon_sym_with] = ACTIONS(4189),
    [anon_sym_WITH] = ACTIONS(4189),
    [anon_sym_With] = ACTIONS(4189),
    [sym_asserterror_keyword] = ACTIONS(4191),
    [sym_page_keyword] = ACTIONS(4189),
    [anon_sym_codeunit] = ACTIONS(4189),
    [anon_sym_CODEUNIT] = ACTIONS(4189),
    [anon_sym_Codeunit] = ACTIONS(4189),
    [anon_sym_CodeUnit] = ACTIONS(4189),
    [anon_sym_COdeunit] = ACTIONS(4189),
    [anon_sym_codeUnit] = ACTIONS(4189),
    [sym_report_keyword] = ACTIONS(4189),
    [sym_query_keyword] = ACTIONS(4189),
    [anon_sym_xmlport] = ACTIONS(4189),
    [anon_sym_XMLPORT] = ACTIONS(4189),
    [anon_sym_Xmlport] = ACTIONS(4189),
    [anon_sym_XMLport] = ACTIONS(4189),
    [anon_sym_XMLPort] = ACTIONS(4189),
    [anon_sym_XmlPort] = ACTIONS(4189),
    [anon_sym_enum] = ACTIONS(4189),
    [anon_sym_ENUM] = ACTIONS(4189),
    [anon_sym_Enum] = ACTIONS(4189),
    [anon_sym_eNUM] = ACTIONS(4189),
    [anon_sym_eNum] = ACTIONS(4189),
    [anon_sym_ENum] = ACTIONS(4189),
    [sym_quoted_identifier] = ACTIONS(4191),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4191),
    [sym_integer] = ACTIONS(4189),
    [sym_continue_as_identifier] = ACTIONS(4191),
    [sym_preproc_open] = ACTIONS(4191),
    [sym_preproc_close] = ACTIONS(4191),
  },
  [STATE(1730)] = {
    [sym_identifier] = ACTIONS(4804),
    [anon_sym_SEMI] = ACTIONS(4806),
    [anon_sym_DASH] = ACTIONS(4806),
    [aux_sym_boolean_token1] = ACTIONS(4804),
    [aux_sym_boolean_token2] = ACTIONS(4804),
    [sym_decimal] = ACTIONS(4804),
    [anon_sym_LPAREN] = ACTIONS(4806),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4804),
    [anon_sym_LBRACK] = ACTIONS(4806),
    [aux_sym_record_type_token1] = ACTIONS(4804),
    [aux_sym_basic_type_token21] = ACTIONS(4804),
    [aux_sym_basic_type_token22] = ACTIONS(4804),
    [aux_sym_basic_type_token48] = ACTIONS(4804),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4804),
    [anon_sym_POUNDif] = ACTIONS(4806),
    [anon_sym_POUNDIF] = ACTIONS(4806),
    [anon_sym_POUNDIf] = ACTIONS(4806),
    [anon_sym_not] = ACTIONS(4804),
    [anon_sym_NOT] = ACTIONS(4804),
    [anon_sym_Not] = ACTIONS(4804),
    [anon_sym_POUNDelif] = ACTIONS(4806),
    [anon_sym_POUNDELIF] = ACTIONS(4806),
    [anon_sym_POUNDElif] = ACTIONS(4806),
    [anon_sym_POUNDelse] = ACTIONS(4806),
    [anon_sym_POUNDELSE] = ACTIONS(4806),
    [anon_sym_POUNDElse] = ACTIONS(4806),
    [anon_sym_POUNDendif] = ACTIONS(4806),
    [anon_sym_POUNDENDIF] = ACTIONS(4806),
    [anon_sym_POUNDEndif] = ACTIONS(4806),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4804),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4804),
    [anon_sym_PLUS] = ACTIONS(4806),
    [sym_datetime_literal] = ACTIONS(4806),
    [sym_date_literal] = ACTIONS(4804),
    [sym_time_literal] = ACTIONS(4804),
    [sym_biginteger_literal] = ACTIONS(4806),
    [anon_sym_if] = ACTIONS(4804),
    [anon_sym_IF] = ACTIONS(4804),
    [anon_sym_If] = ACTIONS(4804),
    [anon_sym_else] = ACTIONS(4804),
    [anon_sym_ELSE] = ACTIONS(4804),
    [anon_sym_Else] = ACTIONS(4804),
    [anon_sym_case] = ACTIONS(4804),
    [anon_sym_CASE] = ACTIONS(4804),
    [anon_sym_Case] = ACTIONS(4804),
    [anon_sym_for] = ACTIONS(4804),
    [anon_sym_FOR] = ACTIONS(4804),
    [anon_sym_For] = ACTIONS(4804),
    [anon_sym_foreach] = ACTIONS(4804),
    [anon_sym_FOREACH] = ACTIONS(4804),
    [anon_sym_Foreach] = ACTIONS(4804),
    [anon_sym_while] = ACTIONS(4804),
    [anon_sym_WHILE] = ACTIONS(4804),
    [anon_sym_While] = ACTIONS(4804),
    [anon_sym_repeat] = ACTIONS(4804),
    [anon_sym_REPEAT] = ACTIONS(4804),
    [anon_sym_Repeat] = ACTIONS(4804),
    [anon_sym_exit] = ACTIONS(4804),
    [anon_sym_EXIT] = ACTIONS(4804),
    [anon_sym_Exit] = ACTIONS(4804),
    [anon_sym_continue] = ACTIONS(4804),
    [anon_sym_CONTINUE] = ACTIONS(4804),
    [anon_sym_Continue] = ACTIONS(4804),
    [anon_sym_break] = ACTIONS(4804),
    [anon_sym_BREAK] = ACTIONS(4804),
    [anon_sym_Break] = ACTIONS(4804),
    [anon_sym_with] = ACTIONS(4804),
    [anon_sym_WITH] = ACTIONS(4804),
    [anon_sym_With] = ACTIONS(4804),
    [sym_asserterror_keyword] = ACTIONS(4806),
    [sym_page_keyword] = ACTIONS(4804),
    [anon_sym_codeunit] = ACTIONS(4804),
    [anon_sym_CODEUNIT] = ACTIONS(4804),
    [anon_sym_Codeunit] = ACTIONS(4804),
    [anon_sym_CodeUnit] = ACTIONS(4804),
    [anon_sym_COdeunit] = ACTIONS(4804),
    [anon_sym_codeUnit] = ACTIONS(4804),
    [sym_report_keyword] = ACTIONS(4804),
    [sym_query_keyword] = ACTIONS(4804),
    [anon_sym_xmlport] = ACTIONS(4804),
    [anon_sym_XMLPORT] = ACTIONS(4804),
    [anon_sym_Xmlport] = ACTIONS(4804),
    [anon_sym_XMLport] = ACTIONS(4804),
    [anon_sym_XMLPort] = ACTIONS(4804),
    [anon_sym_XmlPort] = ACTIONS(4804),
    [anon_sym_enum] = ACTIONS(4804),
    [anon_sym_ENUM] = ACTIONS(4804),
    [anon_sym_Enum] = ACTIONS(4804),
    [anon_sym_eNUM] = ACTIONS(4804),
    [anon_sym_eNum] = ACTIONS(4804),
    [anon_sym_ENum] = ACTIONS(4804),
    [sym_quoted_identifier] = ACTIONS(4806),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4806),
    [sym_integer] = ACTIONS(4804),
    [sym_continue_as_identifier] = ACTIONS(4806),
    [sym_preproc_open] = ACTIONS(4806),
    [sym_preproc_close] = ACTIONS(4806),
  },
  [STATE(1731)] = {
    [sym_identifier] = ACTIONS(4808),
    [anon_sym_SEMI] = ACTIONS(4810),
    [anon_sym_DASH] = ACTIONS(4810),
    [aux_sym_boolean_token1] = ACTIONS(4808),
    [aux_sym_boolean_token2] = ACTIONS(4808),
    [sym_decimal] = ACTIONS(4808),
    [anon_sym_LPAREN] = ACTIONS(4810),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4808),
    [anon_sym_LBRACK] = ACTIONS(4810),
    [aux_sym_record_type_token1] = ACTIONS(4808),
    [aux_sym_basic_type_token21] = ACTIONS(4808),
    [aux_sym_basic_type_token22] = ACTIONS(4808),
    [aux_sym_basic_type_token48] = ACTIONS(4808),
    [anon_sym_POUNDif] = ACTIONS(4810),
    [anon_sym_POUNDIF] = ACTIONS(4810),
    [anon_sym_POUNDIf] = ACTIONS(4810),
    [anon_sym_not] = ACTIONS(4808),
    [anon_sym_NOT] = ACTIONS(4808),
    [anon_sym_Not] = ACTIONS(4808),
    [anon_sym_POUNDelif] = ACTIONS(4810),
    [anon_sym_POUNDELIF] = ACTIONS(4810),
    [anon_sym_POUNDElif] = ACTIONS(4810),
    [anon_sym_POUNDelse] = ACTIONS(4810),
    [anon_sym_POUNDELSE] = ACTIONS(4810),
    [anon_sym_POUNDElse] = ACTIONS(4810),
    [anon_sym_POUNDendif] = ACTIONS(4810),
    [anon_sym_POUNDENDIF] = ACTIONS(4810),
    [anon_sym_POUNDEndif] = ACTIONS(4810),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4808),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4808),
    [anon_sym_PLUS] = ACTIONS(4810),
    [sym_datetime_literal] = ACTIONS(4810),
    [sym_date_literal] = ACTIONS(4808),
    [sym_time_literal] = ACTIONS(4808),
    [sym_biginteger_literal] = ACTIONS(4810),
    [anon_sym_if] = ACTIONS(4808),
    [anon_sym_IF] = ACTIONS(4808),
    [anon_sym_If] = ACTIONS(4808),
    [anon_sym_else] = ACTIONS(4808),
    [anon_sym_ELSE] = ACTIONS(4808),
    [anon_sym_Else] = ACTIONS(4808),
    [anon_sym_case] = ACTIONS(4808),
    [anon_sym_CASE] = ACTIONS(4808),
    [anon_sym_Case] = ACTIONS(4808),
    [anon_sym_for] = ACTIONS(4808),
    [anon_sym_FOR] = ACTIONS(4808),
    [anon_sym_For] = ACTIONS(4808),
    [anon_sym_foreach] = ACTIONS(4808),
    [anon_sym_FOREACH] = ACTIONS(4808),
    [anon_sym_Foreach] = ACTIONS(4808),
    [anon_sym_while] = ACTIONS(4808),
    [anon_sym_WHILE] = ACTIONS(4808),
    [anon_sym_While] = ACTIONS(4808),
    [anon_sym_repeat] = ACTIONS(4808),
    [anon_sym_REPEAT] = ACTIONS(4808),
    [anon_sym_Repeat] = ACTIONS(4808),
    [anon_sym_exit] = ACTIONS(4808),
    [anon_sym_EXIT] = ACTIONS(4808),
    [anon_sym_Exit] = ACTIONS(4808),
    [anon_sym_continue] = ACTIONS(4808),
    [anon_sym_CONTINUE] = ACTIONS(4808),
    [anon_sym_Continue] = ACTIONS(4808),
    [anon_sym_break] = ACTIONS(4808),
    [anon_sym_BREAK] = ACTIONS(4808),
    [anon_sym_Break] = ACTIONS(4808),
    [anon_sym_with] = ACTIONS(4808),
    [anon_sym_WITH] = ACTIONS(4808),
    [anon_sym_With] = ACTIONS(4808),
    [sym_asserterror_keyword] = ACTIONS(4810),
    [sym_page_keyword] = ACTIONS(4808),
    [anon_sym_codeunit] = ACTIONS(4808),
    [anon_sym_CODEUNIT] = ACTIONS(4808),
    [anon_sym_Codeunit] = ACTIONS(4808),
    [anon_sym_CodeUnit] = ACTIONS(4808),
    [anon_sym_COdeunit] = ACTIONS(4808),
    [anon_sym_codeUnit] = ACTIONS(4808),
    [sym_report_keyword] = ACTIONS(4808),
    [sym_query_keyword] = ACTIONS(4808),
    [anon_sym_xmlport] = ACTIONS(4808),
    [anon_sym_XMLPORT] = ACTIONS(4808),
    [anon_sym_Xmlport] = ACTIONS(4808),
    [anon_sym_XMLport] = ACTIONS(4808),
    [anon_sym_XMLPort] = ACTIONS(4808),
    [anon_sym_XmlPort] = ACTIONS(4808),
    [anon_sym_enum] = ACTIONS(4808),
    [anon_sym_ENUM] = ACTIONS(4808),
    [anon_sym_Enum] = ACTIONS(4808),
    [anon_sym_eNUM] = ACTIONS(4808),
    [anon_sym_eNum] = ACTIONS(4808),
    [anon_sym_ENum] = ACTIONS(4808),
    [sym_quoted_identifier] = ACTIONS(4810),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4810),
    [sym_integer] = ACTIONS(4808),
    [sym_continue_as_identifier] = ACTIONS(4810),
    [sym_preproc_open] = ACTIONS(4810),
    [sym_preproc_close] = ACTIONS(4810),
  },
  [STATE(1732)] = {
    [sym_boolean] = STATE(1741),
    [sym_preproc_if] = STATE(2441),
    [sym_assignment_expression] = STATE(6354),
    [sym_case_branch] = STATE(1742),
    [sym_preproc_split_case_branch] = STATE(3395),
    [aux_sym__case_pattern] = STATE(2579),
    [sym_preproc_conditional_case_patterns] = STATE(2579),
    [sym__single_pattern] = STATE(3450),
    [sym_case_else_branch] = STATE(8963),
    [sym__expression] = STATE(6354),
    [sym_keyword_identifier] = STATE(1684),
    [sym_range_expression] = STATE(1741),
    [sym_multiplicative_expression] = STATE(1741),
    [sym_additive_expression] = STATE(1741),
    [sym_comparison_expression] = STATE(1741),
    [sym_logical_expression] = STATE(1741),
    [sym_ternary_expression] = STATE(6354),
    [sym_unary_expression] = STATE(1741),
    [sym_call_expression] = STATE(1734),
    [sym_member_expression] = STATE(1684),
    [sym_subscript_expression] = STATE(1684),
    [sym_parenthesized_expression] = STATE(1741),
    [sym_list_literal] = STATE(6354),
    [sym_qualified_enum_value] = STATE(1684),
    [sym_database_reference] = STATE(1741),
    [sym__literal_value] = STATE(1741),
    [sym_else_keyword] = STATE(87),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(1742),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2561),
    [sym_identifier] = ACTIONS(3746),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(3748),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [anon_sym_POUNDelif] = ACTIONS(4812),
    [anon_sym_POUNDELIF] = ACTIONS(4812),
    [anon_sym_POUNDElif] = ACTIONS(4812),
    [anon_sym_POUNDelse] = ACTIONS(4812),
    [anon_sym_POUNDELSE] = ACTIONS(4812),
    [anon_sym_POUNDElse] = ACTIONS(4812),
    [anon_sym_POUNDendif] = ACTIONS(4812),
    [anon_sym_POUNDENDIF] = ACTIONS(4812),
    [anon_sym_POUNDEndif] = ACTIONS(4812),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(3752),
    [sym_date_literal] = ACTIONS(3748),
    [sym_time_literal] = ACTIONS(3748),
    [sym_biginteger_literal] = ACTIONS(3752),
    [anon_sym_else] = ACTIONS(3754),
    [anon_sym_ELSE] = ACTIONS(3754),
    [anon_sym_Else] = ACTIONS(3754),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(3756),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3752),
    [sym_integer] = ACTIONS(3748),
    [sym_continue_as_identifier] = ACTIONS(3758),
    [sym_preproc_open] = ACTIONS(3750),
    [sym_preproc_close] = ACTIONS(4812),
  },
  [STATE(1733)] = {
    [sym_identifier] = ACTIONS(4815),
    [anon_sym_SEMI] = ACTIONS(4817),
    [anon_sym_DASH] = ACTIONS(4817),
    [aux_sym_boolean_token1] = ACTIONS(4815),
    [aux_sym_boolean_token2] = ACTIONS(4815),
    [sym_decimal] = ACTIONS(4815),
    [anon_sym_LPAREN] = ACTIONS(4817),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4817),
    [aux_sym_record_type_token1] = ACTIONS(4815),
    [aux_sym_basic_type_token21] = ACTIONS(4815),
    [aux_sym_basic_type_token22] = ACTIONS(4815),
    [aux_sym_basic_type_token48] = ACTIONS(4815),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(4815),
    [anon_sym_POUNDif] = ACTIONS(4817),
    [anon_sym_POUNDIF] = ACTIONS(4817),
    [anon_sym_POUNDIf] = ACTIONS(4817),
    [anon_sym_not] = ACTIONS(4815),
    [anon_sym_NOT] = ACTIONS(4815),
    [anon_sym_Not] = ACTIONS(4815),
    [anon_sym_POUNDelif] = ACTIONS(4817),
    [anon_sym_POUNDELIF] = ACTIONS(4817),
    [anon_sym_POUNDElif] = ACTIONS(4817),
    [anon_sym_POUNDelse] = ACTIONS(4817),
    [anon_sym_POUNDELSE] = ACTIONS(4817),
    [anon_sym_POUNDElse] = ACTIONS(4817),
    [anon_sym_POUNDendif] = ACTIONS(4817),
    [anon_sym_POUNDENDIF] = ACTIONS(4817),
    [anon_sym_POUNDEndif] = ACTIONS(4817),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4815),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4815),
    [anon_sym_PLUS] = ACTIONS(4817),
    [sym_datetime_literal] = ACTIONS(4817),
    [sym_date_literal] = ACTIONS(4815),
    [sym_time_literal] = ACTIONS(4815),
    [sym_biginteger_literal] = ACTIONS(4817),
    [anon_sym_if] = ACTIONS(4815),
    [anon_sym_IF] = ACTIONS(4815),
    [anon_sym_If] = ACTIONS(4815),
    [anon_sym_case] = ACTIONS(4815),
    [anon_sym_CASE] = ACTIONS(4815),
    [anon_sym_Case] = ACTIONS(4815),
    [anon_sym_for] = ACTIONS(4815),
    [anon_sym_FOR] = ACTIONS(4815),
    [anon_sym_For] = ACTIONS(4815),
    [anon_sym_foreach] = ACTIONS(4815),
    [anon_sym_FOREACH] = ACTIONS(4815),
    [anon_sym_Foreach] = ACTIONS(4815),
    [anon_sym_while] = ACTIONS(4815),
    [anon_sym_WHILE] = ACTIONS(4815),
    [anon_sym_While] = ACTIONS(4815),
    [anon_sym_repeat] = ACTIONS(4815),
    [anon_sym_REPEAT] = ACTIONS(4815),
    [anon_sym_Repeat] = ACTIONS(4815),
    [anon_sym_exit] = ACTIONS(4815),
    [anon_sym_EXIT] = ACTIONS(4815),
    [anon_sym_Exit] = ACTIONS(4815),
    [anon_sym_continue] = ACTIONS(4815),
    [anon_sym_CONTINUE] = ACTIONS(4815),
    [anon_sym_Continue] = ACTIONS(4815),
    [anon_sym_break] = ACTIONS(4815),
    [anon_sym_BREAK] = ACTIONS(4815),
    [anon_sym_Break] = ACTIONS(4815),
    [anon_sym_with] = ACTIONS(4815),
    [anon_sym_WITH] = ACTIONS(4815),
    [anon_sym_With] = ACTIONS(4815),
    [sym_asserterror_keyword] = ACTIONS(4817),
    [sym_page_keyword] = ACTIONS(4815),
    [anon_sym_codeunit] = ACTIONS(4815),
    [anon_sym_CODEUNIT] = ACTIONS(4815),
    [anon_sym_Codeunit] = ACTIONS(4815),
    [anon_sym_CodeUnit] = ACTIONS(4815),
    [anon_sym_COdeunit] = ACTIONS(4815),
    [anon_sym_codeUnit] = ACTIONS(4815),
    [sym_report_keyword] = ACTIONS(4815),
    [sym_query_keyword] = ACTIONS(4815),
    [anon_sym_xmlport] = ACTIONS(4815),
    [anon_sym_XMLPORT] = ACTIONS(4815),
    [anon_sym_Xmlport] = ACTIONS(4815),
    [anon_sym_XMLport] = ACTIONS(4815),
    [anon_sym_XMLPort] = ACTIONS(4815),
    [anon_sym_XmlPort] = ACTIONS(4815),
    [anon_sym_enum] = ACTIONS(4815),
    [anon_sym_ENUM] = ACTIONS(4815),
    [anon_sym_Enum] = ACTIONS(4815),
    [anon_sym_eNUM] = ACTIONS(4815),
    [anon_sym_eNum] = ACTIONS(4815),
    [anon_sym_ENum] = ACTIONS(4815),
    [sym_quoted_identifier] = ACTIONS(4817),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4817),
    [sym_integer] = ACTIONS(4815),
    [sym_continue_as_identifier] = ACTIONS(4817),
    [sym_preproc_open] = ACTIONS(4817),
    [sym_preproc_close] = ACTIONS(4817),
    [sym_begin_keyword] = ACTIONS(4817),
    [sym_preproc_split_begin] = ACTIONS(4817),
  },
  [STATE(1734)] = {
    [sym_identifier] = ACTIONS(4658),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_COMMA] = ACTIONS(4660),
    [anon_sym_COLON] = ACTIONS(4658),
    [anon_sym_DASH] = ACTIONS(4662),
    [aux_sym_boolean_token1] = ACTIONS(4658),
    [aux_sym_boolean_token2] = ACTIONS(4658),
    [sym_decimal] = ACTIONS(4658),
    [anon_sym_LPAREN] = ACTIONS(4660),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4658),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(4665),
    [aux_sym_record_type_token1] = ACTIONS(4658),
    [aux_sym_basic_type_token21] = ACTIONS(4658),
    [aux_sym_basic_type_token22] = ACTIONS(4658),
    [aux_sym_basic_type_token48] = ACTIONS(4658),
    [anon_sym_COLON_COLON] = ACTIONS(3762),
    [anon_sym_POUNDif] = ACTIONS(4660),
    [anon_sym_POUNDIF] = ACTIONS(4660),
    [anon_sym_POUNDIf] = ACTIONS(4660),
    [anon_sym_not] = ACTIONS(4658),
    [anon_sym_NOT] = ACTIONS(4658),
    [anon_sym_Not] = ACTIONS(4658),
    [anon_sym_POUNDelif] = ACTIONS(4660),
    [anon_sym_POUNDELIF] = ACTIONS(4660),
    [anon_sym_POUNDElif] = ACTIONS(4660),
    [anon_sym_POUNDelse] = ACTIONS(4660),
    [anon_sym_POUNDELSE] = ACTIONS(4660),
    [anon_sym_POUNDElse] = ACTIONS(4660),
    [anon_sym_POUNDendif] = ACTIONS(4660),
    [anon_sym_POUNDENDIF] = ACTIONS(4660),
    [anon_sym_POUNDEndif] = ACTIONS(4660),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4658),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4658),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(4662),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(4660),
    [sym_date_literal] = ACTIONS(4658),
    [sym_time_literal] = ACTIONS(4658),
    [sym_biginteger_literal] = ACTIONS(4660),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(4658),
    [anon_sym_codeunit] = ACTIONS(4658),
    [anon_sym_CODEUNIT] = ACTIONS(4658),
    [anon_sym_Codeunit] = ACTIONS(4658),
    [anon_sym_CodeUnit] = ACTIONS(4658),
    [anon_sym_COdeunit] = ACTIONS(4658),
    [anon_sym_codeUnit] = ACTIONS(4658),
    [sym_report_keyword] = ACTIONS(4658),
    [sym_query_keyword] = ACTIONS(4658),
    [anon_sym_xmlport] = ACTIONS(4658),
    [anon_sym_XMLPORT] = ACTIONS(4658),
    [anon_sym_Xmlport] = ACTIONS(4658),
    [anon_sym_XMLport] = ACTIONS(4658),
    [anon_sym_XMLPort] = ACTIONS(4658),
    [anon_sym_XmlPort] = ACTIONS(4658),
    [anon_sym_enum] = ACTIONS(4658),
    [anon_sym_ENUM] = ACTIONS(4658),
    [anon_sym_Enum] = ACTIONS(4658),
    [anon_sym_eNUM] = ACTIONS(4658),
    [anon_sym_eNum] = ACTIONS(4658),
    [anon_sym_ENum] = ACTIONS(4658),
    [sym_quoted_identifier] = ACTIONS(4660),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4660),
    [sym_integer] = ACTIONS(4658),
    [sym_continue_as_identifier] = ACTIONS(4660),
    [sym_preproc_open] = ACTIONS(4660),
    [sym_preproc_close] = ACTIONS(4660),
  },
  [STATE(1735)] = {
    [sym_identifier] = ACTIONS(4819),
    [anon_sym_SEMI] = ACTIONS(4821),
    [anon_sym_DASH] = ACTIONS(4821),
    [aux_sym_boolean_token1] = ACTIONS(4819),
    [aux_sym_boolean_token2] = ACTIONS(4819),
    [sym_decimal] = ACTIONS(4819),
    [anon_sym_LPAREN] = ACTIONS(4821),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [aux_sym_record_type_token1] = ACTIONS(4819),
    [aux_sym_basic_type_token21] = ACTIONS(4819),
    [aux_sym_basic_type_token22] = ACTIONS(4819),
    [aux_sym_basic_type_token48] = ACTIONS(4819),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(4819),
    [anon_sym_POUNDif] = ACTIONS(4821),
    [anon_sym_POUNDIF] = ACTIONS(4821),
    [anon_sym_POUNDIf] = ACTIONS(4821),
    [anon_sym_not] = ACTIONS(4819),
    [anon_sym_NOT] = ACTIONS(4819),
    [anon_sym_Not] = ACTIONS(4819),
    [anon_sym_POUNDelif] = ACTIONS(4821),
    [anon_sym_POUNDELIF] = ACTIONS(4821),
    [anon_sym_POUNDElif] = ACTIONS(4821),
    [anon_sym_POUNDelse] = ACTIONS(4821),
    [anon_sym_POUNDELSE] = ACTIONS(4821),
    [anon_sym_POUNDElse] = ACTIONS(4821),
    [anon_sym_POUNDendif] = ACTIONS(4821),
    [anon_sym_POUNDENDIF] = ACTIONS(4821),
    [anon_sym_POUNDEndif] = ACTIONS(4821),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4819),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4819),
    [anon_sym_PLUS] = ACTIONS(4821),
    [sym_datetime_literal] = ACTIONS(4821),
    [sym_date_literal] = ACTIONS(4819),
    [sym_time_literal] = ACTIONS(4819),
    [sym_biginteger_literal] = ACTIONS(4821),
    [anon_sym_if] = ACTIONS(4819),
    [anon_sym_IF] = ACTIONS(4819),
    [anon_sym_If] = ACTIONS(4819),
    [anon_sym_case] = ACTIONS(4819),
    [anon_sym_CASE] = ACTIONS(4819),
    [anon_sym_Case] = ACTIONS(4819),
    [anon_sym_for] = ACTIONS(4819),
    [anon_sym_FOR] = ACTIONS(4819),
    [anon_sym_For] = ACTIONS(4819),
    [anon_sym_foreach] = ACTIONS(4819),
    [anon_sym_FOREACH] = ACTIONS(4819),
    [anon_sym_Foreach] = ACTIONS(4819),
    [anon_sym_while] = ACTIONS(4819),
    [anon_sym_WHILE] = ACTIONS(4819),
    [anon_sym_While] = ACTIONS(4819),
    [anon_sym_repeat] = ACTIONS(4819),
    [anon_sym_REPEAT] = ACTIONS(4819),
    [anon_sym_Repeat] = ACTIONS(4819),
    [anon_sym_exit] = ACTIONS(4819),
    [anon_sym_EXIT] = ACTIONS(4819),
    [anon_sym_Exit] = ACTIONS(4819),
    [anon_sym_continue] = ACTIONS(4819),
    [anon_sym_CONTINUE] = ACTIONS(4819),
    [anon_sym_Continue] = ACTIONS(4819),
    [anon_sym_break] = ACTIONS(4819),
    [anon_sym_BREAK] = ACTIONS(4819),
    [anon_sym_Break] = ACTIONS(4819),
    [anon_sym_with] = ACTIONS(4819),
    [anon_sym_WITH] = ACTIONS(4819),
    [anon_sym_With] = ACTIONS(4819),
    [sym_asserterror_keyword] = ACTIONS(4821),
    [sym_page_keyword] = ACTIONS(4819),
    [anon_sym_codeunit] = ACTIONS(4819),
    [anon_sym_CODEUNIT] = ACTIONS(4819),
    [anon_sym_Codeunit] = ACTIONS(4819),
    [anon_sym_CodeUnit] = ACTIONS(4819),
    [anon_sym_COdeunit] = ACTIONS(4819),
    [anon_sym_codeUnit] = ACTIONS(4819),
    [sym_report_keyword] = ACTIONS(4819),
    [sym_query_keyword] = ACTIONS(4819),
    [anon_sym_xmlport] = ACTIONS(4819),
    [anon_sym_XMLPORT] = ACTIONS(4819),
    [anon_sym_Xmlport] = ACTIONS(4819),
    [anon_sym_XMLport] = ACTIONS(4819),
    [anon_sym_XMLPort] = ACTIONS(4819),
    [anon_sym_XmlPort] = ACTIONS(4819),
    [anon_sym_enum] = ACTIONS(4819),
    [anon_sym_ENUM] = ACTIONS(4819),
    [anon_sym_Enum] = ACTIONS(4819),
    [anon_sym_eNUM] = ACTIONS(4819),
    [anon_sym_eNum] = ACTIONS(4819),
    [anon_sym_ENum] = ACTIONS(4819),
    [sym_quoted_identifier] = ACTIONS(4821),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4821),
    [sym_integer] = ACTIONS(4819),
    [sym_continue_as_identifier] = ACTIONS(4821),
    [sym_preproc_open] = ACTIONS(4821),
    [sym_preproc_close] = ACTIONS(4821),
    [sym_begin_keyword] = ACTIONS(4821),
    [sym_preproc_split_begin] = ACTIONS(4821),
  },
  [STATE(1736)] = {
    [sym_identifier] = ACTIONS(4819),
    [anon_sym_SEMI] = ACTIONS(4821),
    [anon_sym_DASH] = ACTIONS(4821),
    [aux_sym_boolean_token1] = ACTIONS(4819),
    [aux_sym_boolean_token2] = ACTIONS(4819),
    [sym_decimal] = ACTIONS(4819),
    [anon_sym_LPAREN] = ACTIONS(4821),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [aux_sym_record_type_token1] = ACTIONS(4819),
    [aux_sym_basic_type_token21] = ACTIONS(4819),
    [aux_sym_basic_type_token22] = ACTIONS(4819),
    [aux_sym_basic_type_token48] = ACTIONS(4819),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(4819),
    [anon_sym_POUNDif] = ACTIONS(4821),
    [anon_sym_POUNDIF] = ACTIONS(4821),
    [anon_sym_POUNDIf] = ACTIONS(4821),
    [anon_sym_not] = ACTIONS(4819),
    [anon_sym_NOT] = ACTIONS(4819),
    [anon_sym_Not] = ACTIONS(4819),
    [anon_sym_POUNDelif] = ACTIONS(4821),
    [anon_sym_POUNDELIF] = ACTIONS(4821),
    [anon_sym_POUNDElif] = ACTIONS(4821),
    [anon_sym_POUNDelse] = ACTIONS(4821),
    [anon_sym_POUNDELSE] = ACTIONS(4821),
    [anon_sym_POUNDElse] = ACTIONS(4821),
    [anon_sym_POUNDendif] = ACTIONS(4821),
    [anon_sym_POUNDENDIF] = ACTIONS(4821),
    [anon_sym_POUNDEndif] = ACTIONS(4821),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4819),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4819),
    [anon_sym_PLUS] = ACTIONS(4821),
    [sym_datetime_literal] = ACTIONS(4821),
    [sym_date_literal] = ACTIONS(4819),
    [sym_time_literal] = ACTIONS(4819),
    [sym_biginteger_literal] = ACTIONS(4821),
    [anon_sym_if] = ACTIONS(4819),
    [anon_sym_IF] = ACTIONS(4819),
    [anon_sym_If] = ACTIONS(4819),
    [anon_sym_case] = ACTIONS(4819),
    [anon_sym_CASE] = ACTIONS(4819),
    [anon_sym_Case] = ACTIONS(4819),
    [anon_sym_for] = ACTIONS(4819),
    [anon_sym_FOR] = ACTIONS(4819),
    [anon_sym_For] = ACTIONS(4819),
    [anon_sym_foreach] = ACTIONS(4819),
    [anon_sym_FOREACH] = ACTIONS(4819),
    [anon_sym_Foreach] = ACTIONS(4819),
    [anon_sym_while] = ACTIONS(4819),
    [anon_sym_WHILE] = ACTIONS(4819),
    [anon_sym_While] = ACTIONS(4819),
    [anon_sym_repeat] = ACTIONS(4819),
    [anon_sym_REPEAT] = ACTIONS(4819),
    [anon_sym_Repeat] = ACTIONS(4819),
    [anon_sym_exit] = ACTIONS(4819),
    [anon_sym_EXIT] = ACTIONS(4819),
    [anon_sym_Exit] = ACTIONS(4819),
    [anon_sym_continue] = ACTIONS(4819),
    [anon_sym_CONTINUE] = ACTIONS(4819),
    [anon_sym_Continue] = ACTIONS(4819),
    [anon_sym_break] = ACTIONS(4819),
    [anon_sym_BREAK] = ACTIONS(4819),
    [anon_sym_Break] = ACTIONS(4819),
    [anon_sym_with] = ACTIONS(4819),
    [anon_sym_WITH] = ACTIONS(4819),
    [anon_sym_With] = ACTIONS(4819),
    [sym_asserterror_keyword] = ACTIONS(4821),
    [sym_page_keyword] = ACTIONS(4819),
    [anon_sym_codeunit] = ACTIONS(4819),
    [anon_sym_CODEUNIT] = ACTIONS(4819),
    [anon_sym_Codeunit] = ACTIONS(4819),
    [anon_sym_CodeUnit] = ACTIONS(4819),
    [anon_sym_COdeunit] = ACTIONS(4819),
    [anon_sym_codeUnit] = ACTIONS(4819),
    [sym_report_keyword] = ACTIONS(4819),
    [sym_query_keyword] = ACTIONS(4819),
    [anon_sym_xmlport] = ACTIONS(4819),
    [anon_sym_XMLPORT] = ACTIONS(4819),
    [anon_sym_Xmlport] = ACTIONS(4819),
    [anon_sym_XMLport] = ACTIONS(4819),
    [anon_sym_XMLPort] = ACTIONS(4819),
    [anon_sym_XmlPort] = ACTIONS(4819),
    [anon_sym_enum] = ACTIONS(4819),
    [anon_sym_ENUM] = ACTIONS(4819),
    [anon_sym_Enum] = ACTIONS(4819),
    [anon_sym_eNUM] = ACTIONS(4819),
    [anon_sym_eNum] = ACTIONS(4819),
    [anon_sym_ENum] = ACTIONS(4819),
    [sym_quoted_identifier] = ACTIONS(4821),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4821),
    [sym_integer] = ACTIONS(4819),
    [sym_continue_as_identifier] = ACTIONS(4821),
    [sym_preproc_open] = ACTIONS(4821),
    [sym_preproc_close] = ACTIONS(4821),
    [sym_begin_keyword] = ACTIONS(4821),
  },
  [STATE(1737)] = {
    [sym_identifier] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_COMMA] = ACTIONS(4825),
    [anon_sym_COLON] = ACTIONS(4823),
    [anon_sym_DASH] = ACTIONS(4827),
    [aux_sym_boolean_token1] = ACTIONS(4823),
    [aux_sym_boolean_token2] = ACTIONS(4823),
    [sym_decimal] = ACTIONS(4823),
    [anon_sym_LPAREN] = ACTIONS(4825),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4823),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(4830),
    [aux_sym_record_type_token1] = ACTIONS(4823),
    [aux_sym_basic_type_token21] = ACTIONS(4823),
    [aux_sym_basic_type_token22] = ACTIONS(4823),
    [aux_sym_basic_type_token48] = ACTIONS(4823),
    [anon_sym_POUNDif] = ACTIONS(4825),
    [anon_sym_POUNDIF] = ACTIONS(4825),
    [anon_sym_POUNDIf] = ACTIONS(4825),
    [anon_sym_not] = ACTIONS(4823),
    [anon_sym_NOT] = ACTIONS(4823),
    [anon_sym_Not] = ACTIONS(4823),
    [anon_sym_POUNDelif] = ACTIONS(4825),
    [anon_sym_POUNDELIF] = ACTIONS(4825),
    [anon_sym_POUNDElif] = ACTIONS(4825),
    [anon_sym_POUNDelse] = ACTIONS(4825),
    [anon_sym_POUNDELSE] = ACTIONS(4825),
    [anon_sym_POUNDElse] = ACTIONS(4825),
    [anon_sym_POUNDendif] = ACTIONS(4825),
    [anon_sym_POUNDENDIF] = ACTIONS(4825),
    [anon_sym_POUNDEndif] = ACTIONS(4825),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2595),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4823),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4823),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(4827),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(4825),
    [sym_date_literal] = ACTIONS(4823),
    [sym_time_literal] = ACTIONS(4823),
    [sym_biginteger_literal] = ACTIONS(4825),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(4823),
    [anon_sym_codeunit] = ACTIONS(4823),
    [anon_sym_CODEUNIT] = ACTIONS(4823),
    [anon_sym_Codeunit] = ACTIONS(4823),
    [anon_sym_CodeUnit] = ACTIONS(4823),
    [anon_sym_COdeunit] = ACTIONS(4823),
    [anon_sym_codeUnit] = ACTIONS(4823),
    [sym_report_keyword] = ACTIONS(4823),
    [sym_query_keyword] = ACTIONS(4823),
    [anon_sym_xmlport] = ACTIONS(4823),
    [anon_sym_XMLPORT] = ACTIONS(4823),
    [anon_sym_Xmlport] = ACTIONS(4823),
    [anon_sym_XMLport] = ACTIONS(4823),
    [anon_sym_XMLPort] = ACTIONS(4823),
    [anon_sym_XmlPort] = ACTIONS(4823),
    [anon_sym_enum] = ACTIONS(4823),
    [anon_sym_ENUM] = ACTIONS(4823),
    [anon_sym_Enum] = ACTIONS(4823),
    [anon_sym_eNUM] = ACTIONS(4823),
    [anon_sym_eNum] = ACTIONS(4823),
    [anon_sym_ENum] = ACTIONS(4823),
    [sym_quoted_identifier] = ACTIONS(4825),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4825),
    [sym_integer] = ACTIONS(4823),
    [sym_continue_as_identifier] = ACTIONS(4825),
    [sym_preproc_open] = ACTIONS(4825),
    [sym_preproc_close] = ACTIONS(4825),
  },
  [STATE(1738)] = {
    [sym__body_element] = STATE(3335),
    [sym_empty_statement] = STATE(3335),
    [sym_property] = STATE(4854),
    [sym_fields_section] = STATE(3335),
    [sym_keys_section] = STATE(3335),
    [sym_fieldgroups_section] = STATE(3335),
    [sym_enum_value_declaration] = STATE(3335),
    [sym_labels_section] = STATE(3335),
    [sym_layout_section] = STATE(3335),
    [sym_modify_modification] = STATE(3335),
    [sym_actions_section] = STATE(3335),
    [sym__action_element] = STATE(4906),
    [sym_action_area_section] = STATE(4906),
    [sym_action_group_section] = STATE(4906),
    [sym_action_declaration] = STATE(4906),
    [sym_separator_action] = STATE(4906),
    [sym_actionref_declaration] = STATE(4906),
    [sym_systemaction_declaration] = STATE(4906),
    [sym_fileuploadaction_declaration] = STATE(4906),
    [sym_customaction_declaration] = STATE(4906),
    [sym_addfirst_action_modification] = STATE(4906),
    [sym_addlast_action_modification] = STATE(4906),
    [sym_addafter_action_modification] = STATE(4906),
    [sym_addbefore_action_modification] = STATE(4906),
    [sym_modify_action_modification] = STATE(4906),
    [sym_views_section] = STATE(3335),
    [sym_dataset_section] = STATE(3335),
    [sym_requestpage_section] = STATE(3335),
    [sym_rendering_section] = STATE(3335),
    [sym_elements_section] = STATE(3335),
    [sym_schema_section] = STATE(3335),
    [sym_assembly_declaration] = STATE(3335),
    [sym_event_declaration] = STATE(3335),
    [sym_procedure] = STATE(3335),
    [sym_preproc_split_procedure] = STATE(3335),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(4854),
    [sym_var_section] = STATE(3335),
    [sym_attribute_item] = STATE(4854),
    [sym_preproc_conditional] = STATE(3335),
    [sym_preproc_if] = STATE(1393),
    [sym_preproc_conditional_actions] = STATE(4906),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3335),
    [aux_sym_actions_section_repeat1] = STATE(4906),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3676),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3678),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token22] = ACTIONS(3680),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(3682),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3684),
    [aux_sym_modify_modification_token1] = ACTIONS(3686),
    [aux_sym_separator_action_token1] = ACTIONS(3688),
    [aux_sym_actionref_declaration_token1] = ACTIONS(3690),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(3692),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(3694),
    [aux_sym_customaction_declaration_token1] = ACTIONS(3696),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(4833),
    [anon_sym_POUNDELIF] = ACTIONS(4833),
    [anon_sym_POUNDElif] = ACTIONS(4833),
    [anon_sym_POUNDelse] = ACTIONS(4833),
    [anon_sym_POUNDELSE] = ACTIONS(4833),
    [anon_sym_POUNDElse] = ACTIONS(4833),
    [anon_sym_POUNDendif] = ACTIONS(4833),
    [anon_sym_POUNDENDIF] = ACTIONS(4833),
    [anon_sym_POUNDEndif] = ACTIONS(4833),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(3698),
    [sym_group_keyword] = ACTIONS(3700),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(4833),
  },
  [STATE(1739)] = {
    [sym_boolean] = STATE(5949),
    [sym_option_member_list] = STATE(6001),
    [sym_option_member] = STATE(5905),
    [sym_keyword_identifier] = STATE(5949),
    [sym_codeunit_keyword] = STATE(5754),
    [sym_xmlport_keyword] = STATE(5754),
    [sym_enum_keyword] = STATE(5754),
    [sym_keyword_as_identifier] = STATE(5949),
    [aux_sym_option_member_list_repeat2] = STATE(1769),
    [sym_identifier] = ACTIONS(4836),
    [anon_sym_DOT] = ACTIONS(277),
    [anon_sym_EQ] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(4838),
    [anon_sym_DASH] = ACTIONS(4840),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [aux_sym_where_condition_token1] = ACTIONS(4844),
    [anon_sym_DOT_DOT] = ACTIONS(275),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(275),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4848),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [aux_sym_basic_type_token53] = ACTIONS(4844),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4844),
    [aux_sym_separator_action_token1] = ACTIONS(4844),
    [aux_sym_type_declaration_token1] = ACTIONS(4844),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(275),
    [aux_sym__expression_token1] = ACTIONS(275),
    [aux_sym__expression_token2] = ACTIONS(275),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4846),
    [anon_sym_SLASH] = ACTIONS(277),
    [anon_sym_div] = ACTIONS(277),
    [anon_sym_DIV] = ACTIONS(277),
    [anon_sym_Div] = ACTIONS(277),
    [anon_sym_mod] = ACTIONS(277),
    [anon_sym_MOD] = ACTIONS(277),
    [anon_sym_Mod] = ACTIONS(277),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(275),
    [anon_sym_LT_EQ] = ACTIONS(275),
    [anon_sym_GT] = ACTIONS(277),
    [anon_sym_LT] = ACTIONS(277),
    [anon_sym_LT_GT] = ACTIONS(275),
    [anon_sym_and] = ACTIONS(277),
    [anon_sym_AND] = ACTIONS(277),
    [anon_sym_And] = ACTIONS(277),
    [anon_sym_or] = ACTIONS(277),
    [anon_sym_OR] = ACTIONS(277),
    [anon_sym_Or] = ACTIONS(277),
    [anon_sym_xor] = ACTIONS(277),
    [anon_sym_XOR] = ACTIONS(277),
    [anon_sym_Xor] = ACTIONS(277),
    [anon_sym_QMARK] = ACTIONS(275),
    [anon_sym_in] = ACTIONS(277),
    [anon_sym_IN] = ACTIONS(277),
    [anon_sym_In] = ACTIONS(277),
    [anon_sym_to] = ACTIONS(277),
    [anon_sym_TO] = ACTIONS(277),
    [anon_sym_To] = ACTIONS(277),
    [anon_sym_downto] = ACTIONS(277),
    [anon_sym_DOWNTO] = ACTIONS(277),
    [anon_sym_Downto] = ACTIONS(277),
    [sym_page_keyword] = ACTIONS(4846),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(4846),
    [sym_query_keyword] = ACTIONS(4846),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_local_keyword] = ACTIONS(4836),
    [sym_internal_keyword] = ACTIONS(4836),
    [sym_protected_keyword] = ACTIONS(4836),
    [sym_key_keyword] = ACTIONS(4844),
    [sym_dataset_keyword] = ACTIONS(4844),
    [sym_quoted_identifier] = ACTIONS(4856),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4856),
    [sym_integer] = ACTIONS(4856),
  },
  [STATE(1740)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2441),
    [sym_assignment_expression] = STATE(6338),
    [sym_case_branch] = STATE(1742),
    [sym_preproc_split_case_branch] = STATE(3395),
    [aux_sym__case_pattern] = STATE(2579),
    [sym_preproc_conditional_case_patterns] = STATE(2579),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(8963),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(87),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(1742),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [anon_sym_POUNDelif] = ACTIONS(4858),
    [anon_sym_POUNDELIF] = ACTIONS(4858),
    [anon_sym_POUNDElif] = ACTIONS(4858),
    [anon_sym_POUNDelse] = ACTIONS(4858),
    [anon_sym_POUNDELSE] = ACTIONS(4858),
    [anon_sym_POUNDElse] = ACTIONS(4858),
    [anon_sym_POUNDendif] = ACTIONS(4858),
    [anon_sym_POUNDENDIF] = ACTIONS(4858),
    [anon_sym_POUNDEndif] = ACTIONS(4858),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(3754),
    [anon_sym_ELSE] = ACTIONS(3754),
    [anon_sym_Else] = ACTIONS(3754),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
    [sym_preproc_close] = ACTIONS(4858),
  },
  [STATE(1741)] = {
    [sym_identifier] = ACTIONS(4658),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_COMMA] = ACTIONS(4660),
    [anon_sym_COLON] = ACTIONS(4658),
    [anon_sym_DASH] = ACTIONS(4662),
    [aux_sym_boolean_token1] = ACTIONS(4658),
    [aux_sym_boolean_token2] = ACTIONS(4658),
    [sym_decimal] = ACTIONS(4658),
    [anon_sym_LPAREN] = ACTIONS(4660),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4658),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(4665),
    [aux_sym_record_type_token1] = ACTIONS(4658),
    [aux_sym_basic_type_token21] = ACTIONS(4658),
    [aux_sym_basic_type_token22] = ACTIONS(4658),
    [aux_sym_basic_type_token48] = ACTIONS(4658),
    [anon_sym_POUNDif] = ACTIONS(4660),
    [anon_sym_POUNDIF] = ACTIONS(4660),
    [anon_sym_POUNDIf] = ACTIONS(4660),
    [anon_sym_not] = ACTIONS(4658),
    [anon_sym_NOT] = ACTIONS(4658),
    [anon_sym_Not] = ACTIONS(4658),
    [anon_sym_POUNDelif] = ACTIONS(4660),
    [anon_sym_POUNDELIF] = ACTIONS(4660),
    [anon_sym_POUNDElif] = ACTIONS(4660),
    [anon_sym_POUNDelse] = ACTIONS(4660),
    [anon_sym_POUNDELSE] = ACTIONS(4660),
    [anon_sym_POUNDElse] = ACTIONS(4660),
    [anon_sym_POUNDendif] = ACTIONS(4660),
    [anon_sym_POUNDENDIF] = ACTIONS(4660),
    [anon_sym_POUNDEndif] = ACTIONS(4660),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4658),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4658),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(4662),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(4660),
    [sym_date_literal] = ACTIONS(4658),
    [sym_time_literal] = ACTIONS(4658),
    [sym_biginteger_literal] = ACTIONS(4660),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(4658),
    [anon_sym_codeunit] = ACTIONS(4658),
    [anon_sym_CODEUNIT] = ACTIONS(4658),
    [anon_sym_Codeunit] = ACTIONS(4658),
    [anon_sym_CodeUnit] = ACTIONS(4658),
    [anon_sym_COdeunit] = ACTIONS(4658),
    [anon_sym_codeUnit] = ACTIONS(4658),
    [sym_report_keyword] = ACTIONS(4658),
    [sym_query_keyword] = ACTIONS(4658),
    [anon_sym_xmlport] = ACTIONS(4658),
    [anon_sym_XMLPORT] = ACTIONS(4658),
    [anon_sym_Xmlport] = ACTIONS(4658),
    [anon_sym_XMLport] = ACTIONS(4658),
    [anon_sym_XMLPort] = ACTIONS(4658),
    [anon_sym_XmlPort] = ACTIONS(4658),
    [anon_sym_enum] = ACTIONS(4658),
    [anon_sym_ENUM] = ACTIONS(4658),
    [anon_sym_Enum] = ACTIONS(4658),
    [anon_sym_eNUM] = ACTIONS(4658),
    [anon_sym_eNum] = ACTIONS(4658),
    [anon_sym_ENum] = ACTIONS(4658),
    [sym_quoted_identifier] = ACTIONS(4660),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4660),
    [sym_integer] = ACTIONS(4658),
    [sym_continue_as_identifier] = ACTIONS(4660),
    [sym_preproc_open] = ACTIONS(4660),
    [sym_preproc_close] = ACTIONS(4660),
  },
  [STATE(1742)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2441),
    [sym_assignment_expression] = STATE(6338),
    [sym_case_branch] = STATE(1939),
    [sym_preproc_split_case_branch] = STATE(3395),
    [aux_sym__case_pattern] = STATE(2579),
    [sym_preproc_conditional_case_patterns] = STATE(2579),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(8881),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(87),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(1939),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [anon_sym_POUNDelif] = ACTIONS(4860),
    [anon_sym_POUNDELIF] = ACTIONS(4860),
    [anon_sym_POUNDElif] = ACTIONS(4860),
    [anon_sym_POUNDelse] = ACTIONS(4860),
    [anon_sym_POUNDELSE] = ACTIONS(4860),
    [anon_sym_POUNDElse] = ACTIONS(4860),
    [anon_sym_POUNDendif] = ACTIONS(4860),
    [anon_sym_POUNDENDIF] = ACTIONS(4860),
    [anon_sym_POUNDEndif] = ACTIONS(4860),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(3754),
    [anon_sym_ELSE] = ACTIONS(3754),
    [anon_sym_Else] = ACTIONS(3754),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
    [sym_preproc_close] = ACTIONS(4860),
  },
  [STATE(1743)] = {
    [sym_else_keyword] = STATE(286),
    [sym_identifier] = ACTIONS(4157),
    [anon_sym_SEMI] = ACTIONS(4159),
    [anon_sym_DASH] = ACTIONS(4159),
    [aux_sym_boolean_token1] = ACTIONS(4157),
    [aux_sym_boolean_token2] = ACTIONS(4157),
    [sym_decimal] = ACTIONS(4157),
    [anon_sym_LPAREN] = ACTIONS(4159),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4157),
    [anon_sym_LBRACK] = ACTIONS(4159),
    [aux_sym_record_type_token1] = ACTIONS(4157),
    [aux_sym_basic_type_token21] = ACTIONS(4157),
    [aux_sym_basic_type_token22] = ACTIONS(4157),
    [aux_sym_basic_type_token48] = ACTIONS(4157),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4157),
    [anon_sym_POUNDif] = ACTIONS(4159),
    [anon_sym_POUNDIF] = ACTIONS(4159),
    [anon_sym_POUNDIf] = ACTIONS(4159),
    [anon_sym_not] = ACTIONS(4157),
    [anon_sym_NOT] = ACTIONS(4157),
    [anon_sym_Not] = ACTIONS(4157),
    [anon_sym_POUNDelse] = ACTIONS(4159),
    [anon_sym_POUNDELSE] = ACTIONS(4159),
    [anon_sym_POUNDElse] = ACTIONS(4159),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4157),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4157),
    [anon_sym_PLUS] = ACTIONS(4159),
    [sym_datetime_literal] = ACTIONS(4159),
    [sym_date_literal] = ACTIONS(4157),
    [sym_time_literal] = ACTIONS(4157),
    [sym_biginteger_literal] = ACTIONS(4159),
    [anon_sym_if] = ACTIONS(4157),
    [anon_sym_IF] = ACTIONS(4157),
    [anon_sym_If] = ACTIONS(4157),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4157),
    [anon_sym_CASE] = ACTIONS(4157),
    [anon_sym_Case] = ACTIONS(4157),
    [anon_sym_for] = ACTIONS(4157),
    [anon_sym_FOR] = ACTIONS(4157),
    [anon_sym_For] = ACTIONS(4157),
    [anon_sym_foreach] = ACTIONS(4157),
    [anon_sym_FOREACH] = ACTIONS(4157),
    [anon_sym_Foreach] = ACTIONS(4157),
    [anon_sym_while] = ACTIONS(4157),
    [anon_sym_WHILE] = ACTIONS(4157),
    [anon_sym_While] = ACTIONS(4157),
    [anon_sym_repeat] = ACTIONS(4157),
    [anon_sym_REPEAT] = ACTIONS(4157),
    [anon_sym_Repeat] = ACTIONS(4157),
    [anon_sym_until] = ACTIONS(4157),
    [anon_sym_UNTIL] = ACTIONS(4157),
    [anon_sym_Until] = ACTIONS(4157),
    [anon_sym_exit] = ACTIONS(4157),
    [anon_sym_EXIT] = ACTIONS(4157),
    [anon_sym_Exit] = ACTIONS(4157),
    [anon_sym_continue] = ACTIONS(4157),
    [anon_sym_CONTINUE] = ACTIONS(4157),
    [anon_sym_Continue] = ACTIONS(4157),
    [anon_sym_break] = ACTIONS(4157),
    [anon_sym_BREAK] = ACTIONS(4157),
    [anon_sym_Break] = ACTIONS(4157),
    [anon_sym_with] = ACTIONS(4157),
    [anon_sym_WITH] = ACTIONS(4157),
    [anon_sym_With] = ACTIONS(4157),
    [sym_asserterror_keyword] = ACTIONS(4159),
    [sym_page_keyword] = ACTIONS(4157),
    [anon_sym_codeunit] = ACTIONS(4157),
    [anon_sym_CODEUNIT] = ACTIONS(4157),
    [anon_sym_Codeunit] = ACTIONS(4157),
    [anon_sym_CodeUnit] = ACTIONS(4157),
    [anon_sym_COdeunit] = ACTIONS(4157),
    [anon_sym_codeUnit] = ACTIONS(4157),
    [sym_report_keyword] = ACTIONS(4157),
    [sym_query_keyword] = ACTIONS(4157),
    [anon_sym_xmlport] = ACTIONS(4157),
    [anon_sym_XMLPORT] = ACTIONS(4157),
    [anon_sym_Xmlport] = ACTIONS(4157),
    [anon_sym_XMLport] = ACTIONS(4157),
    [anon_sym_XMLPort] = ACTIONS(4157),
    [anon_sym_XmlPort] = ACTIONS(4157),
    [anon_sym_enum] = ACTIONS(4157),
    [anon_sym_ENUM] = ACTIONS(4157),
    [anon_sym_Enum] = ACTIONS(4157),
    [anon_sym_eNUM] = ACTIONS(4157),
    [anon_sym_eNum] = ACTIONS(4157),
    [anon_sym_ENum] = ACTIONS(4157),
    [sym_quoted_identifier] = ACTIONS(4159),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4159),
    [sym_integer] = ACTIONS(4157),
    [sym_continue_as_identifier] = ACTIONS(4159),
    [sym_preproc_open] = ACTIONS(4159),
  },
  [STATE(1744)] = {
    [sym_identifier] = ACTIONS(4467),
    [anon_sym_SEMI] = ACTIONS(4469),
    [anon_sym_DASH] = ACTIONS(4469),
    [aux_sym_boolean_token1] = ACTIONS(4467),
    [aux_sym_boolean_token2] = ACTIONS(4467),
    [sym_decimal] = ACTIONS(4467),
    [anon_sym_LPAREN] = ACTIONS(4469),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4467),
    [anon_sym_LBRACK] = ACTIONS(4469),
    [aux_sym_record_type_token1] = ACTIONS(4467),
    [aux_sym_basic_type_token21] = ACTIONS(4467),
    [aux_sym_basic_type_token22] = ACTIONS(4467),
    [aux_sym_basic_type_token48] = ACTIONS(4467),
    [anon_sym_POUNDif] = ACTIONS(4469),
    [anon_sym_POUNDIF] = ACTIONS(4469),
    [anon_sym_POUNDIf] = ACTIONS(4469),
    [anon_sym_not] = ACTIONS(4467),
    [anon_sym_NOT] = ACTIONS(4467),
    [anon_sym_Not] = ACTIONS(4467),
    [anon_sym_POUNDelif] = ACTIONS(4469),
    [anon_sym_POUNDELIF] = ACTIONS(4469),
    [anon_sym_POUNDElif] = ACTIONS(4469),
    [anon_sym_POUNDelse] = ACTIONS(4469),
    [anon_sym_POUNDELSE] = ACTIONS(4469),
    [anon_sym_POUNDElse] = ACTIONS(4469),
    [anon_sym_POUNDendif] = ACTIONS(4469),
    [anon_sym_POUNDENDIF] = ACTIONS(4469),
    [anon_sym_POUNDEndif] = ACTIONS(4469),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4467),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4467),
    [anon_sym_PLUS] = ACTIONS(4469),
    [sym_datetime_literal] = ACTIONS(4469),
    [sym_date_literal] = ACTIONS(4467),
    [sym_time_literal] = ACTIONS(4467),
    [sym_biginteger_literal] = ACTIONS(4469),
    [anon_sym_if] = ACTIONS(4467),
    [anon_sym_IF] = ACTIONS(4467),
    [anon_sym_If] = ACTIONS(4467),
    [anon_sym_case] = ACTIONS(4467),
    [anon_sym_CASE] = ACTIONS(4467),
    [anon_sym_Case] = ACTIONS(4467),
    [anon_sym_for] = ACTIONS(4467),
    [anon_sym_FOR] = ACTIONS(4467),
    [anon_sym_For] = ACTIONS(4467),
    [anon_sym_foreach] = ACTIONS(4467),
    [anon_sym_FOREACH] = ACTIONS(4467),
    [anon_sym_Foreach] = ACTIONS(4467),
    [anon_sym_while] = ACTIONS(4467),
    [anon_sym_WHILE] = ACTIONS(4467),
    [anon_sym_While] = ACTIONS(4467),
    [anon_sym_repeat] = ACTIONS(4467),
    [anon_sym_REPEAT] = ACTIONS(4467),
    [anon_sym_Repeat] = ACTIONS(4467),
    [anon_sym_exit] = ACTIONS(4467),
    [anon_sym_EXIT] = ACTIONS(4467),
    [anon_sym_Exit] = ACTIONS(4467),
    [anon_sym_continue] = ACTIONS(4467),
    [anon_sym_CONTINUE] = ACTIONS(4467),
    [anon_sym_Continue] = ACTIONS(4467),
    [anon_sym_break] = ACTIONS(4467),
    [anon_sym_BREAK] = ACTIONS(4467),
    [anon_sym_Break] = ACTIONS(4467),
    [anon_sym_with] = ACTIONS(4467),
    [anon_sym_WITH] = ACTIONS(4467),
    [anon_sym_With] = ACTIONS(4467),
    [sym_asserterror_keyword] = ACTIONS(4469),
    [sym_page_keyword] = ACTIONS(4467),
    [anon_sym_codeunit] = ACTIONS(4467),
    [anon_sym_CODEUNIT] = ACTIONS(4467),
    [anon_sym_Codeunit] = ACTIONS(4467),
    [anon_sym_CodeUnit] = ACTIONS(4467),
    [anon_sym_COdeunit] = ACTIONS(4467),
    [anon_sym_codeUnit] = ACTIONS(4467),
    [sym_report_keyword] = ACTIONS(4467),
    [sym_query_keyword] = ACTIONS(4467),
    [anon_sym_xmlport] = ACTIONS(4467),
    [anon_sym_XMLPORT] = ACTIONS(4467),
    [anon_sym_Xmlport] = ACTIONS(4467),
    [anon_sym_XMLport] = ACTIONS(4467),
    [anon_sym_XMLPort] = ACTIONS(4467),
    [anon_sym_XmlPort] = ACTIONS(4467),
    [anon_sym_enum] = ACTIONS(4467),
    [anon_sym_ENUM] = ACTIONS(4467),
    [anon_sym_Enum] = ACTIONS(4467),
    [anon_sym_eNUM] = ACTIONS(4467),
    [anon_sym_eNum] = ACTIONS(4467),
    [anon_sym_ENum] = ACTIONS(4467),
    [sym_quoted_identifier] = ACTIONS(4469),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4469),
    [sym_integer] = ACTIONS(4467),
    [sym_continue_as_identifier] = ACTIONS(4469),
    [sym_preproc_open] = ACTIONS(4469),
    [sym_preproc_close] = ACTIONS(4469),
    [sym_preproc_split_end] = ACTIONS(4469),
  },
  [STATE(1745)] = {
    [sym_else_keyword] = STATE(288),
    [sym_identifier] = ACTIONS(4165),
    [anon_sym_SEMI] = ACTIONS(4167),
    [anon_sym_DASH] = ACTIONS(4167),
    [aux_sym_boolean_token1] = ACTIONS(4165),
    [aux_sym_boolean_token2] = ACTIONS(4165),
    [sym_decimal] = ACTIONS(4165),
    [anon_sym_LPAREN] = ACTIONS(4167),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4165),
    [anon_sym_LBRACK] = ACTIONS(4167),
    [aux_sym_record_type_token1] = ACTIONS(4165),
    [aux_sym_basic_type_token21] = ACTIONS(4165),
    [aux_sym_basic_type_token22] = ACTIONS(4165),
    [aux_sym_basic_type_token48] = ACTIONS(4165),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4165),
    [anon_sym_POUNDif] = ACTIONS(4167),
    [anon_sym_POUNDIF] = ACTIONS(4167),
    [anon_sym_POUNDIf] = ACTIONS(4167),
    [anon_sym_not] = ACTIONS(4165),
    [anon_sym_NOT] = ACTIONS(4165),
    [anon_sym_Not] = ACTIONS(4165),
    [anon_sym_POUNDelse] = ACTIONS(4167),
    [anon_sym_POUNDELSE] = ACTIONS(4167),
    [anon_sym_POUNDElse] = ACTIONS(4167),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4165),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4165),
    [anon_sym_PLUS] = ACTIONS(4167),
    [sym_datetime_literal] = ACTIONS(4167),
    [sym_date_literal] = ACTIONS(4165),
    [sym_time_literal] = ACTIONS(4165),
    [sym_biginteger_literal] = ACTIONS(4167),
    [anon_sym_if] = ACTIONS(4165),
    [anon_sym_IF] = ACTIONS(4165),
    [anon_sym_If] = ACTIONS(4165),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4165),
    [anon_sym_CASE] = ACTIONS(4165),
    [anon_sym_Case] = ACTIONS(4165),
    [anon_sym_for] = ACTIONS(4165),
    [anon_sym_FOR] = ACTIONS(4165),
    [anon_sym_For] = ACTIONS(4165),
    [anon_sym_foreach] = ACTIONS(4165),
    [anon_sym_FOREACH] = ACTIONS(4165),
    [anon_sym_Foreach] = ACTIONS(4165),
    [anon_sym_while] = ACTIONS(4165),
    [anon_sym_WHILE] = ACTIONS(4165),
    [anon_sym_While] = ACTIONS(4165),
    [anon_sym_repeat] = ACTIONS(4165),
    [anon_sym_REPEAT] = ACTIONS(4165),
    [anon_sym_Repeat] = ACTIONS(4165),
    [anon_sym_until] = ACTIONS(4165),
    [anon_sym_UNTIL] = ACTIONS(4165),
    [anon_sym_Until] = ACTIONS(4165),
    [anon_sym_exit] = ACTIONS(4165),
    [anon_sym_EXIT] = ACTIONS(4165),
    [anon_sym_Exit] = ACTIONS(4165),
    [anon_sym_continue] = ACTIONS(4165),
    [anon_sym_CONTINUE] = ACTIONS(4165),
    [anon_sym_Continue] = ACTIONS(4165),
    [anon_sym_break] = ACTIONS(4165),
    [anon_sym_BREAK] = ACTIONS(4165),
    [anon_sym_Break] = ACTIONS(4165),
    [anon_sym_with] = ACTIONS(4165),
    [anon_sym_WITH] = ACTIONS(4165),
    [anon_sym_With] = ACTIONS(4165),
    [sym_asserterror_keyword] = ACTIONS(4167),
    [sym_page_keyword] = ACTIONS(4165),
    [anon_sym_codeunit] = ACTIONS(4165),
    [anon_sym_CODEUNIT] = ACTIONS(4165),
    [anon_sym_Codeunit] = ACTIONS(4165),
    [anon_sym_CodeUnit] = ACTIONS(4165),
    [anon_sym_COdeunit] = ACTIONS(4165),
    [anon_sym_codeUnit] = ACTIONS(4165),
    [sym_report_keyword] = ACTIONS(4165),
    [sym_query_keyword] = ACTIONS(4165),
    [anon_sym_xmlport] = ACTIONS(4165),
    [anon_sym_XMLPORT] = ACTIONS(4165),
    [anon_sym_Xmlport] = ACTIONS(4165),
    [anon_sym_XMLport] = ACTIONS(4165),
    [anon_sym_XMLPort] = ACTIONS(4165),
    [anon_sym_XmlPort] = ACTIONS(4165),
    [anon_sym_enum] = ACTIONS(4165),
    [anon_sym_ENUM] = ACTIONS(4165),
    [anon_sym_Enum] = ACTIONS(4165),
    [anon_sym_eNUM] = ACTIONS(4165),
    [anon_sym_eNum] = ACTIONS(4165),
    [anon_sym_ENum] = ACTIONS(4165),
    [sym_quoted_identifier] = ACTIONS(4167),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4167),
    [sym_integer] = ACTIONS(4165),
    [sym_continue_as_identifier] = ACTIONS(4167),
    [sym_preproc_open] = ACTIONS(4167),
  },
  [STATE(1746)] = {
    [sym_else_keyword] = STATE(294),
    [sym_identifier] = ACTIONS(4131),
    [anon_sym_SEMI] = ACTIONS(4133),
    [anon_sym_DASH] = ACTIONS(4133),
    [aux_sym_boolean_token1] = ACTIONS(4131),
    [aux_sym_boolean_token2] = ACTIONS(4131),
    [sym_decimal] = ACTIONS(4131),
    [anon_sym_LPAREN] = ACTIONS(4133),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4131),
    [anon_sym_LBRACK] = ACTIONS(4133),
    [aux_sym_record_type_token1] = ACTIONS(4131),
    [aux_sym_basic_type_token21] = ACTIONS(4131),
    [aux_sym_basic_type_token22] = ACTIONS(4131),
    [aux_sym_basic_type_token48] = ACTIONS(4131),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4131),
    [anon_sym_POUNDif] = ACTIONS(4133),
    [anon_sym_POUNDIF] = ACTIONS(4133),
    [anon_sym_POUNDIf] = ACTIONS(4133),
    [anon_sym_not] = ACTIONS(4131),
    [anon_sym_NOT] = ACTIONS(4131),
    [anon_sym_Not] = ACTIONS(4131),
    [anon_sym_POUNDelse] = ACTIONS(4133),
    [anon_sym_POUNDELSE] = ACTIONS(4133),
    [anon_sym_POUNDElse] = ACTIONS(4133),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4131),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4131),
    [anon_sym_PLUS] = ACTIONS(4133),
    [sym_datetime_literal] = ACTIONS(4133),
    [sym_date_literal] = ACTIONS(4131),
    [sym_time_literal] = ACTIONS(4131),
    [sym_biginteger_literal] = ACTIONS(4133),
    [anon_sym_if] = ACTIONS(4131),
    [anon_sym_IF] = ACTIONS(4131),
    [anon_sym_If] = ACTIONS(4131),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4131),
    [anon_sym_CASE] = ACTIONS(4131),
    [anon_sym_Case] = ACTIONS(4131),
    [anon_sym_for] = ACTIONS(4131),
    [anon_sym_FOR] = ACTIONS(4131),
    [anon_sym_For] = ACTIONS(4131),
    [anon_sym_foreach] = ACTIONS(4131),
    [anon_sym_FOREACH] = ACTIONS(4131),
    [anon_sym_Foreach] = ACTIONS(4131),
    [anon_sym_while] = ACTIONS(4131),
    [anon_sym_WHILE] = ACTIONS(4131),
    [anon_sym_While] = ACTIONS(4131),
    [anon_sym_repeat] = ACTIONS(4131),
    [anon_sym_REPEAT] = ACTIONS(4131),
    [anon_sym_Repeat] = ACTIONS(4131),
    [anon_sym_until] = ACTIONS(4131),
    [anon_sym_UNTIL] = ACTIONS(4131),
    [anon_sym_Until] = ACTIONS(4131),
    [anon_sym_exit] = ACTIONS(4131),
    [anon_sym_EXIT] = ACTIONS(4131),
    [anon_sym_Exit] = ACTIONS(4131),
    [anon_sym_continue] = ACTIONS(4131),
    [anon_sym_CONTINUE] = ACTIONS(4131),
    [anon_sym_Continue] = ACTIONS(4131),
    [anon_sym_break] = ACTIONS(4131),
    [anon_sym_BREAK] = ACTIONS(4131),
    [anon_sym_Break] = ACTIONS(4131),
    [anon_sym_with] = ACTIONS(4131),
    [anon_sym_WITH] = ACTIONS(4131),
    [anon_sym_With] = ACTIONS(4131),
    [sym_asserterror_keyword] = ACTIONS(4133),
    [sym_page_keyword] = ACTIONS(4131),
    [anon_sym_codeunit] = ACTIONS(4131),
    [anon_sym_CODEUNIT] = ACTIONS(4131),
    [anon_sym_Codeunit] = ACTIONS(4131),
    [anon_sym_CodeUnit] = ACTIONS(4131),
    [anon_sym_COdeunit] = ACTIONS(4131),
    [anon_sym_codeUnit] = ACTIONS(4131),
    [sym_report_keyword] = ACTIONS(4131),
    [sym_query_keyword] = ACTIONS(4131),
    [anon_sym_xmlport] = ACTIONS(4131),
    [anon_sym_XMLPORT] = ACTIONS(4131),
    [anon_sym_Xmlport] = ACTIONS(4131),
    [anon_sym_XMLport] = ACTIONS(4131),
    [anon_sym_XMLPort] = ACTIONS(4131),
    [anon_sym_XmlPort] = ACTIONS(4131),
    [anon_sym_enum] = ACTIONS(4131),
    [anon_sym_ENUM] = ACTIONS(4131),
    [anon_sym_Enum] = ACTIONS(4131),
    [anon_sym_eNUM] = ACTIONS(4131),
    [anon_sym_eNum] = ACTIONS(4131),
    [anon_sym_ENum] = ACTIONS(4131),
    [sym_quoted_identifier] = ACTIONS(4133),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4133),
    [sym_integer] = ACTIONS(4131),
    [sym_continue_as_identifier] = ACTIONS(4133),
    [sym_preproc_open] = ACTIONS(4133),
  },
  [STATE(1747)] = {
    [sym_identifier] = ACTIONS(4139),
    [anon_sym_SEMI] = ACTIONS(4141),
    [anon_sym_DASH] = ACTIONS(4141),
    [aux_sym_boolean_token1] = ACTIONS(4139),
    [aux_sym_boolean_token2] = ACTIONS(4139),
    [sym_decimal] = ACTIONS(4139),
    [anon_sym_LPAREN] = ACTIONS(4139),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4139),
    [anon_sym_LBRACK] = ACTIONS(4141),
    [aux_sym_record_type_token1] = ACTIONS(4139),
    [aux_sym_basic_type_token21] = ACTIONS(4139),
    [aux_sym_basic_type_token22] = ACTIONS(4139),
    [aux_sym_basic_type_token48] = ACTIONS(4139),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4139),
    [anon_sym_POUNDif] = ACTIONS(4141),
    [anon_sym_POUNDIF] = ACTIONS(4141),
    [anon_sym_POUNDIf] = ACTIONS(4141),
    [anon_sym_not] = ACTIONS(4139),
    [anon_sym_NOT] = ACTIONS(4139),
    [anon_sym_Not] = ACTIONS(4139),
    [anon_sym_POUNDelse] = ACTIONS(4141),
    [anon_sym_POUNDELSE] = ACTIONS(4141),
    [anon_sym_POUNDElse] = ACTIONS(4141),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_LPAREN2] = ACTIONS(4862),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4139),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4139),
    [anon_sym_PLUS] = ACTIONS(4141),
    [sym_datetime_literal] = ACTIONS(4141),
    [sym_date_literal] = ACTIONS(4139),
    [sym_time_literal] = ACTIONS(4139),
    [sym_biginteger_literal] = ACTIONS(4141),
    [anon_sym_if] = ACTIONS(4139),
    [anon_sym_IF] = ACTIONS(4139),
    [anon_sym_If] = ACTIONS(4139),
    [anon_sym_else] = ACTIONS(4139),
    [anon_sym_ELSE] = ACTIONS(4139),
    [anon_sym_Else] = ACTIONS(4139),
    [anon_sym_case] = ACTIONS(4139),
    [anon_sym_CASE] = ACTIONS(4139),
    [anon_sym_Case] = ACTIONS(4139),
    [anon_sym_for] = ACTIONS(4139),
    [anon_sym_FOR] = ACTIONS(4139),
    [anon_sym_For] = ACTIONS(4139),
    [anon_sym_foreach] = ACTIONS(4139),
    [anon_sym_FOREACH] = ACTIONS(4139),
    [anon_sym_Foreach] = ACTIONS(4139),
    [anon_sym_while] = ACTIONS(4139),
    [anon_sym_WHILE] = ACTIONS(4139),
    [anon_sym_While] = ACTIONS(4139),
    [anon_sym_repeat] = ACTIONS(4139),
    [anon_sym_REPEAT] = ACTIONS(4139),
    [anon_sym_Repeat] = ACTIONS(4139),
    [anon_sym_until] = ACTIONS(4139),
    [anon_sym_UNTIL] = ACTIONS(4139),
    [anon_sym_Until] = ACTIONS(4139),
    [anon_sym_exit] = ACTIONS(4139),
    [anon_sym_EXIT] = ACTIONS(4139),
    [anon_sym_Exit] = ACTIONS(4139),
    [anon_sym_continue] = ACTIONS(4139),
    [anon_sym_CONTINUE] = ACTIONS(4139),
    [anon_sym_Continue] = ACTIONS(4139),
    [anon_sym_break] = ACTIONS(4139),
    [anon_sym_BREAK] = ACTIONS(4139),
    [anon_sym_Break] = ACTIONS(4139),
    [anon_sym_with] = ACTIONS(4139),
    [anon_sym_WITH] = ACTIONS(4139),
    [anon_sym_With] = ACTIONS(4139),
    [sym_asserterror_keyword] = ACTIONS(4141),
    [sym_page_keyword] = ACTIONS(4139),
    [anon_sym_codeunit] = ACTIONS(4139),
    [anon_sym_CODEUNIT] = ACTIONS(4139),
    [anon_sym_Codeunit] = ACTIONS(4139),
    [anon_sym_CodeUnit] = ACTIONS(4139),
    [anon_sym_COdeunit] = ACTIONS(4139),
    [anon_sym_codeUnit] = ACTIONS(4139),
    [sym_report_keyword] = ACTIONS(4139),
    [sym_query_keyword] = ACTIONS(4139),
    [anon_sym_xmlport] = ACTIONS(4139),
    [anon_sym_XMLPORT] = ACTIONS(4139),
    [anon_sym_Xmlport] = ACTIONS(4139),
    [anon_sym_XMLport] = ACTIONS(4139),
    [anon_sym_XMLPort] = ACTIONS(4139),
    [anon_sym_XmlPort] = ACTIONS(4139),
    [anon_sym_enum] = ACTIONS(4139),
    [anon_sym_ENUM] = ACTIONS(4139),
    [anon_sym_Enum] = ACTIONS(4139),
    [anon_sym_eNUM] = ACTIONS(4139),
    [anon_sym_eNum] = ACTIONS(4139),
    [anon_sym_ENum] = ACTIONS(4139),
    [sym_quoted_identifier] = ACTIONS(4141),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4141),
    [sym_integer] = ACTIONS(4139),
    [sym_continue_as_identifier] = ACTIONS(4141),
    [sym_preproc_open] = ACTIONS(4141),
  },
  [STATE(1748)] = {
    [sym_identifier] = ACTIONS(2843),
    [anon_sym_SEMI] = ACTIONS(2841),
    [anon_sym_COLON] = ACTIONS(2841),
    [anon_sym_DASH] = ACTIONS(2841),
    [aux_sym_boolean_token1] = ACTIONS(2843),
    [aux_sym_boolean_token2] = ACTIONS(2843),
    [sym_decimal] = ACTIONS(2843),
    [anon_sym_LPAREN] = ACTIONS(2841),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2843),
    [anon_sym_LBRACK] = ACTIONS(2841),
    [aux_sym_record_type_token1] = ACTIONS(2843),
    [aux_sym_basic_type_token21] = ACTIONS(2843),
    [aux_sym_basic_type_token22] = ACTIONS(2843),
    [aux_sym_basic_type_token48] = ACTIONS(2843),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2843),
    [anon_sym_POUNDif] = ACTIONS(2841),
    [anon_sym_POUNDIF] = ACTIONS(2841),
    [anon_sym_POUNDIf] = ACTIONS(2841),
    [anon_sym_not] = ACTIONS(2843),
    [anon_sym_NOT] = ACTIONS(2843),
    [anon_sym_Not] = ACTIONS(2843),
    [anon_sym_POUNDelse] = ACTIONS(2841),
    [anon_sym_POUNDELSE] = ACTIONS(2841),
    [anon_sym_POUNDElse] = ACTIONS(2841),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2843),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2843),
    [anon_sym_PLUS] = ACTIONS(2841),
    [sym_datetime_literal] = ACTIONS(2841),
    [sym_date_literal] = ACTIONS(2843),
    [sym_time_literal] = ACTIONS(2843),
    [sym_biginteger_literal] = ACTIONS(2841),
    [anon_sym_if] = ACTIONS(2843),
    [anon_sym_IF] = ACTIONS(2843),
    [anon_sym_If] = ACTIONS(2843),
    [anon_sym_else] = ACTIONS(2843),
    [anon_sym_ELSE] = ACTIONS(2843),
    [anon_sym_Else] = ACTIONS(2843),
    [anon_sym_case] = ACTIONS(2843),
    [anon_sym_CASE] = ACTIONS(2843),
    [anon_sym_Case] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2843),
    [anon_sym_FOR] = ACTIONS(2843),
    [anon_sym_For] = ACTIONS(2843),
    [anon_sym_foreach] = ACTIONS(2843),
    [anon_sym_FOREACH] = ACTIONS(2843),
    [anon_sym_Foreach] = ACTIONS(2843),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_WHILE] = ACTIONS(2843),
    [anon_sym_While] = ACTIONS(2843),
    [anon_sym_repeat] = ACTIONS(2843),
    [anon_sym_REPEAT] = ACTIONS(2843),
    [anon_sym_Repeat] = ACTIONS(2843),
    [anon_sym_until] = ACTIONS(2843),
    [anon_sym_UNTIL] = ACTIONS(2843),
    [anon_sym_Until] = ACTIONS(2843),
    [anon_sym_exit] = ACTIONS(2843),
    [anon_sym_EXIT] = ACTIONS(2843),
    [anon_sym_Exit] = ACTIONS(2843),
    [anon_sym_continue] = ACTIONS(2843),
    [anon_sym_CONTINUE] = ACTIONS(2843),
    [anon_sym_Continue] = ACTIONS(2843),
    [anon_sym_break] = ACTIONS(2843),
    [anon_sym_BREAK] = ACTIONS(2843),
    [anon_sym_Break] = ACTIONS(2843),
    [anon_sym_with] = ACTIONS(2843),
    [anon_sym_WITH] = ACTIONS(2843),
    [anon_sym_With] = ACTIONS(2843),
    [sym_asserterror_keyword] = ACTIONS(2841),
    [sym_page_keyword] = ACTIONS(2843),
    [anon_sym_codeunit] = ACTIONS(2843),
    [anon_sym_CODEUNIT] = ACTIONS(2843),
    [anon_sym_Codeunit] = ACTIONS(2843),
    [anon_sym_CodeUnit] = ACTIONS(2843),
    [anon_sym_COdeunit] = ACTIONS(2843),
    [anon_sym_codeUnit] = ACTIONS(2843),
    [sym_report_keyword] = ACTIONS(2843),
    [sym_query_keyword] = ACTIONS(2843),
    [anon_sym_xmlport] = ACTIONS(2843),
    [anon_sym_XMLPORT] = ACTIONS(2843),
    [anon_sym_Xmlport] = ACTIONS(2843),
    [anon_sym_XMLport] = ACTIONS(2843),
    [anon_sym_XMLPort] = ACTIONS(2843),
    [anon_sym_XmlPort] = ACTIONS(2843),
    [anon_sym_enum] = ACTIONS(2843),
    [anon_sym_ENUM] = ACTIONS(2843),
    [anon_sym_Enum] = ACTIONS(2843),
    [anon_sym_eNUM] = ACTIONS(2843),
    [anon_sym_eNum] = ACTIONS(2843),
    [anon_sym_ENum] = ACTIONS(2843),
    [sym_quoted_identifier] = ACTIONS(2841),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2841),
    [sym_integer] = ACTIONS(2843),
    [sym_continue_as_identifier] = ACTIONS(2841),
    [sym_preproc_open] = ACTIONS(2841),
  },
  [STATE(1749)] = {
    [sym_boolean] = STATE(6346),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(9063),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1387),
    [sym_preproc_endif] = STATE(11924),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7706),
    [sym_keyword_as_identifier] = STATE(7706),
    [sym_identifier] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDendif] = ACTIONS(223),
    [anon_sym_POUNDENDIF] = ACTIONS(223),
    [anon_sym_POUNDEndif] = ACTIONS(223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(223),
  },
  [STATE(1750)] = {
    [anon_sym_POUNDif] = ACTIONS(4810),
    [anon_sym_POUNDIF] = ACTIONS(4810),
    [anon_sym_POUNDIf] = ACTIONS(4810),
    [anon_sym_POUNDelif] = ACTIONS(4810),
    [anon_sym_POUNDELIF] = ACTIONS(4810),
    [anon_sym_POUNDElif] = ACTIONS(4810),
    [anon_sym_POUNDelse] = ACTIONS(4810),
    [anon_sym_POUNDELSE] = ACTIONS(4810),
    [anon_sym_POUNDElse] = ACTIONS(4810),
    [anon_sym_POUNDendif] = ACTIONS(4810),
    [anon_sym_POUNDENDIF] = ACTIONS(4810),
    [anon_sym_POUNDEndif] = ACTIONS(4810),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4808),
    [anon_sym_tableextension] = ACTIONS(4810),
    [anon_sym_TABLEEXTENSION] = ACTIONS(4810),
    [anon_sym_Tableextension] = ACTIONS(4810),
    [anon_sym_TableExtension] = ACTIONS(4810),
    [anon_sym_tableExtension] = ACTIONS(4810),
    [sym_page_keyword] = ACTIONS(4808),
    [anon_sym_pageextension] = ACTIONS(4810),
    [anon_sym_PAGEEXTENSION] = ACTIONS(4810),
    [anon_sym_Pageextension] = ACTIONS(4810),
    [anon_sym_PageExtension] = ACTIONS(4810),
    [anon_sym_pageExtension] = ACTIONS(4810),
    [anon_sym_codeunit] = ACTIONS(4810),
    [anon_sym_CODEUNIT] = ACTIONS(4810),
    [anon_sym_Codeunit] = ACTIONS(4810),
    [anon_sym_CodeUnit] = ACTIONS(4810),
    [anon_sym_COdeunit] = ACTIONS(4810),
    [anon_sym_codeUnit] = ACTIONS(4810),
    [sym_report_keyword] = ACTIONS(4808),
    [anon_sym_reportextension] = ACTIONS(4810),
    [anon_sym_REPORTEXTENSION] = ACTIONS(4810),
    [anon_sym_Reportextension] = ACTIONS(4810),
    [anon_sym_ReportExtension] = ACTIONS(4810),
    [anon_sym_reportExtension] = ACTIONS(4810),
    [sym_query_keyword] = ACTIONS(4810),
    [anon_sym_xmlport] = ACTIONS(4810),
    [anon_sym_XMLPORT] = ACTIONS(4810),
    [anon_sym_Xmlport] = ACTIONS(4810),
    [anon_sym_XMLport] = ACTIONS(4810),
    [anon_sym_XMLPort] = ACTIONS(4810),
    [anon_sym_XmlPort] = ACTIONS(4810),
    [anon_sym_enum] = ACTIONS(4808),
    [anon_sym_ENUM] = ACTIONS(4808),
    [anon_sym_Enum] = ACTIONS(4808),
    [anon_sym_eNUM] = ACTIONS(4810),
    [anon_sym_eNum] = ACTIONS(4810),
    [anon_sym_ENum] = ACTIONS(4810),
    [anon_sym_enumextension] = ACTIONS(4810),
    [anon_sym_ENUMEXTENSION] = ACTIONS(4810),
    [anon_sym_Enumextension] = ACTIONS(4810),
    [anon_sym_EnumExtension] = ACTIONS(4810),
    [anon_sym_enumExtension] = ACTIONS(4810),
    [sym_interface_keyword] = ACTIONS(4810),
    [anon_sym_controladdin] = ACTIONS(4810),
    [anon_sym_CONTROLADDIN] = ACTIONS(4810),
    [anon_sym_Controladdin] = ACTIONS(4810),
    [anon_sym_ControlAddIn] = ACTIONS(4810),
    [anon_sym_ControlAddin] = ACTIONS(4810),
    [anon_sym_controlAddIn] = ACTIONS(4810),
    [anon_sym_controlAddin] = ACTIONS(4810),
    [anon_sym_dotnet] = ACTIONS(4810),
    [anon_sym_DOTNET] = ACTIONS(4810),
    [anon_sym_Dotnet] = ACTIONS(4810),
    [anon_sym_DotNet] = ACTIONS(4810),
    [anon_sym_dotNet] = ACTIONS(4810),
    [sym_profile_keyword] = ACTIONS(4808),
    [anon_sym_profileextension] = ACTIONS(4810),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(4810),
    [anon_sym_Profileextension] = ACTIONS(4810),
    [anon_sym_ProfileExtension] = ACTIONS(4810),
    [anon_sym_profileExtension] = ACTIONS(4810),
    [anon_sym_permissionset] = ACTIONS(4808),
    [anon_sym_PERMISSIONSET] = ACTIONS(4808),
    [anon_sym_Permissionset] = ACTIONS(4808),
    [anon_sym_PermissionSet] = ACTIONS(4808),
    [anon_sym_permissionSet] = ACTIONS(4808),
    [anon_sym_permissionsetextension] = ACTIONS(4810),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(4810),
    [anon_sym_Permissionsetextension] = ACTIONS(4810),
    [anon_sym_PermissionSetExtension] = ACTIONS(4810),
    [anon_sym_permissionSetExtension] = ACTIONS(4810),
    [sym_entitlement_keyword] = ACTIONS(4810),
    [anon_sym_pagecustomization] = ACTIONS(4810),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(4810),
    [anon_sym_Pagecustomization] = ACTIONS(4810),
    [anon_sym_PageCustomization] = ACTIONS(4810),
    [anon_sym_pageCustomization] = ACTIONS(4810),
    [sym_namespace_keyword] = ACTIONS(4810),
    [sym_using_keyword] = ACTIONS(4810),
    [sym_fieldgroup_keyword] = ACTIONS(4810),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(4810),
    [sym_preproc_close] = ACTIONS(4810),
  },
  [STATE(1751)] = {
    [sym_else_keyword] = STATE(285),
    [sym_identifier] = ACTIONS(4153),
    [anon_sym_SEMI] = ACTIONS(4155),
    [anon_sym_DASH] = ACTIONS(4155),
    [aux_sym_boolean_token1] = ACTIONS(4153),
    [aux_sym_boolean_token2] = ACTIONS(4153),
    [sym_decimal] = ACTIONS(4153),
    [anon_sym_LPAREN] = ACTIONS(4155),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4153),
    [anon_sym_LBRACK] = ACTIONS(4155),
    [aux_sym_record_type_token1] = ACTIONS(4153),
    [aux_sym_basic_type_token21] = ACTIONS(4153),
    [aux_sym_basic_type_token22] = ACTIONS(4153),
    [aux_sym_basic_type_token48] = ACTIONS(4153),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4153),
    [anon_sym_POUNDif] = ACTIONS(4155),
    [anon_sym_POUNDIF] = ACTIONS(4155),
    [anon_sym_POUNDIf] = ACTIONS(4155),
    [anon_sym_not] = ACTIONS(4153),
    [anon_sym_NOT] = ACTIONS(4153),
    [anon_sym_Not] = ACTIONS(4153),
    [anon_sym_POUNDelse] = ACTIONS(4155),
    [anon_sym_POUNDELSE] = ACTIONS(4155),
    [anon_sym_POUNDElse] = ACTIONS(4155),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4153),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4153),
    [anon_sym_PLUS] = ACTIONS(4155),
    [sym_datetime_literal] = ACTIONS(4155),
    [sym_date_literal] = ACTIONS(4153),
    [sym_time_literal] = ACTIONS(4153),
    [sym_biginteger_literal] = ACTIONS(4155),
    [anon_sym_if] = ACTIONS(4153),
    [anon_sym_IF] = ACTIONS(4153),
    [anon_sym_If] = ACTIONS(4153),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4153),
    [anon_sym_CASE] = ACTIONS(4153),
    [anon_sym_Case] = ACTIONS(4153),
    [anon_sym_for] = ACTIONS(4153),
    [anon_sym_FOR] = ACTIONS(4153),
    [anon_sym_For] = ACTIONS(4153),
    [anon_sym_foreach] = ACTIONS(4153),
    [anon_sym_FOREACH] = ACTIONS(4153),
    [anon_sym_Foreach] = ACTIONS(4153),
    [anon_sym_while] = ACTIONS(4153),
    [anon_sym_WHILE] = ACTIONS(4153),
    [anon_sym_While] = ACTIONS(4153),
    [anon_sym_repeat] = ACTIONS(4153),
    [anon_sym_REPEAT] = ACTIONS(4153),
    [anon_sym_Repeat] = ACTIONS(4153),
    [anon_sym_until] = ACTIONS(4153),
    [anon_sym_UNTIL] = ACTIONS(4153),
    [anon_sym_Until] = ACTIONS(4153),
    [anon_sym_exit] = ACTIONS(4153),
    [anon_sym_EXIT] = ACTIONS(4153),
    [anon_sym_Exit] = ACTIONS(4153),
    [anon_sym_continue] = ACTIONS(4153),
    [anon_sym_CONTINUE] = ACTIONS(4153),
    [anon_sym_Continue] = ACTIONS(4153),
    [anon_sym_break] = ACTIONS(4153),
    [anon_sym_BREAK] = ACTIONS(4153),
    [anon_sym_Break] = ACTIONS(4153),
    [anon_sym_with] = ACTIONS(4153),
    [anon_sym_WITH] = ACTIONS(4153),
    [anon_sym_With] = ACTIONS(4153),
    [sym_asserterror_keyword] = ACTIONS(4155),
    [sym_page_keyword] = ACTIONS(4153),
    [anon_sym_codeunit] = ACTIONS(4153),
    [anon_sym_CODEUNIT] = ACTIONS(4153),
    [anon_sym_Codeunit] = ACTIONS(4153),
    [anon_sym_CodeUnit] = ACTIONS(4153),
    [anon_sym_COdeunit] = ACTIONS(4153),
    [anon_sym_codeUnit] = ACTIONS(4153),
    [sym_report_keyword] = ACTIONS(4153),
    [sym_query_keyword] = ACTIONS(4153),
    [anon_sym_xmlport] = ACTIONS(4153),
    [anon_sym_XMLPORT] = ACTIONS(4153),
    [anon_sym_Xmlport] = ACTIONS(4153),
    [anon_sym_XMLport] = ACTIONS(4153),
    [anon_sym_XMLPort] = ACTIONS(4153),
    [anon_sym_XmlPort] = ACTIONS(4153),
    [anon_sym_enum] = ACTIONS(4153),
    [anon_sym_ENUM] = ACTIONS(4153),
    [anon_sym_Enum] = ACTIONS(4153),
    [anon_sym_eNUM] = ACTIONS(4153),
    [anon_sym_eNum] = ACTIONS(4153),
    [anon_sym_ENum] = ACTIONS(4153),
    [sym_quoted_identifier] = ACTIONS(4155),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4155),
    [sym_integer] = ACTIONS(4153),
    [sym_continue_as_identifier] = ACTIONS(4155),
    [sym_preproc_open] = ACTIONS(4155),
  },
  [STATE(1752)] = {
    [sym_boolean] = STATE(6346),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(9238),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1387),
    [sym_preproc_endif] = STATE(8800),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7706),
    [sym_keyword_as_identifier] = STATE(7706),
    [sym_identifier] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDendif] = ACTIONS(3674),
    [anon_sym_POUNDENDIF] = ACTIONS(3674),
    [anon_sym_POUNDEndif] = ACTIONS(3674),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(3674),
  },
  [STATE(1753)] = {
    [sym_boolean] = STATE(6346),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(9209),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1387),
    [sym_preproc_endif] = STATE(12271),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7706),
    [sym_keyword_as_identifier] = STATE(7706),
    [sym_identifier] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDendif] = ACTIONS(223),
    [anon_sym_POUNDENDIF] = ACTIONS(223),
    [anon_sym_POUNDEndif] = ACTIONS(223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(223),
  },
  [STATE(1754)] = {
    [sym_else_keyword] = STATE(279),
    [sym_identifier] = ACTIONS(4145),
    [anon_sym_SEMI] = ACTIONS(4147),
    [anon_sym_DASH] = ACTIONS(4147),
    [aux_sym_boolean_token1] = ACTIONS(4145),
    [aux_sym_boolean_token2] = ACTIONS(4145),
    [sym_decimal] = ACTIONS(4145),
    [anon_sym_LPAREN] = ACTIONS(4147),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4145),
    [anon_sym_LBRACK] = ACTIONS(4147),
    [aux_sym_record_type_token1] = ACTIONS(4145),
    [aux_sym_basic_type_token21] = ACTIONS(4145),
    [aux_sym_basic_type_token22] = ACTIONS(4145),
    [aux_sym_basic_type_token48] = ACTIONS(4145),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4145),
    [anon_sym_POUNDif] = ACTIONS(4147),
    [anon_sym_POUNDIF] = ACTIONS(4147),
    [anon_sym_POUNDIf] = ACTIONS(4147),
    [anon_sym_not] = ACTIONS(4145),
    [anon_sym_NOT] = ACTIONS(4145),
    [anon_sym_Not] = ACTIONS(4145),
    [anon_sym_POUNDelse] = ACTIONS(4147),
    [anon_sym_POUNDELSE] = ACTIONS(4147),
    [anon_sym_POUNDElse] = ACTIONS(4147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4145),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4145),
    [anon_sym_PLUS] = ACTIONS(4147),
    [sym_datetime_literal] = ACTIONS(4147),
    [sym_date_literal] = ACTIONS(4145),
    [sym_time_literal] = ACTIONS(4145),
    [sym_biginteger_literal] = ACTIONS(4147),
    [anon_sym_if] = ACTIONS(4145),
    [anon_sym_IF] = ACTIONS(4145),
    [anon_sym_If] = ACTIONS(4145),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4145),
    [anon_sym_CASE] = ACTIONS(4145),
    [anon_sym_Case] = ACTIONS(4145),
    [anon_sym_for] = ACTIONS(4145),
    [anon_sym_FOR] = ACTIONS(4145),
    [anon_sym_For] = ACTIONS(4145),
    [anon_sym_foreach] = ACTIONS(4145),
    [anon_sym_FOREACH] = ACTIONS(4145),
    [anon_sym_Foreach] = ACTIONS(4145),
    [anon_sym_while] = ACTIONS(4145),
    [anon_sym_WHILE] = ACTIONS(4145),
    [anon_sym_While] = ACTIONS(4145),
    [anon_sym_repeat] = ACTIONS(4145),
    [anon_sym_REPEAT] = ACTIONS(4145),
    [anon_sym_Repeat] = ACTIONS(4145),
    [anon_sym_until] = ACTIONS(4145),
    [anon_sym_UNTIL] = ACTIONS(4145),
    [anon_sym_Until] = ACTIONS(4145),
    [anon_sym_exit] = ACTIONS(4145),
    [anon_sym_EXIT] = ACTIONS(4145),
    [anon_sym_Exit] = ACTIONS(4145),
    [anon_sym_continue] = ACTIONS(4145),
    [anon_sym_CONTINUE] = ACTIONS(4145),
    [anon_sym_Continue] = ACTIONS(4145),
    [anon_sym_break] = ACTIONS(4145),
    [anon_sym_BREAK] = ACTIONS(4145),
    [anon_sym_Break] = ACTIONS(4145),
    [anon_sym_with] = ACTIONS(4145),
    [anon_sym_WITH] = ACTIONS(4145),
    [anon_sym_With] = ACTIONS(4145),
    [sym_asserterror_keyword] = ACTIONS(4147),
    [sym_page_keyword] = ACTIONS(4145),
    [anon_sym_codeunit] = ACTIONS(4145),
    [anon_sym_CODEUNIT] = ACTIONS(4145),
    [anon_sym_Codeunit] = ACTIONS(4145),
    [anon_sym_CodeUnit] = ACTIONS(4145),
    [anon_sym_COdeunit] = ACTIONS(4145),
    [anon_sym_codeUnit] = ACTIONS(4145),
    [sym_report_keyword] = ACTIONS(4145),
    [sym_query_keyword] = ACTIONS(4145),
    [anon_sym_xmlport] = ACTIONS(4145),
    [anon_sym_XMLPORT] = ACTIONS(4145),
    [anon_sym_Xmlport] = ACTIONS(4145),
    [anon_sym_XMLport] = ACTIONS(4145),
    [anon_sym_XMLPort] = ACTIONS(4145),
    [anon_sym_XmlPort] = ACTIONS(4145),
    [anon_sym_enum] = ACTIONS(4145),
    [anon_sym_ENUM] = ACTIONS(4145),
    [anon_sym_Enum] = ACTIONS(4145),
    [anon_sym_eNUM] = ACTIONS(4145),
    [anon_sym_eNum] = ACTIONS(4145),
    [anon_sym_ENum] = ACTIONS(4145),
    [sym_quoted_identifier] = ACTIONS(4147),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4147),
    [sym_integer] = ACTIONS(4145),
    [sym_continue_as_identifier] = ACTIONS(4147),
    [sym_preproc_open] = ACTIONS(4147),
  },
  [STATE(1755)] = {
    [sym_else_keyword] = STATE(280),
    [sym_identifier] = ACTIONS(4149),
    [anon_sym_SEMI] = ACTIONS(4151),
    [anon_sym_DASH] = ACTIONS(4151),
    [aux_sym_boolean_token1] = ACTIONS(4149),
    [aux_sym_boolean_token2] = ACTIONS(4149),
    [sym_decimal] = ACTIONS(4149),
    [anon_sym_LPAREN] = ACTIONS(4151),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4149),
    [anon_sym_LBRACK] = ACTIONS(4151),
    [aux_sym_record_type_token1] = ACTIONS(4149),
    [aux_sym_basic_type_token21] = ACTIONS(4149),
    [aux_sym_basic_type_token22] = ACTIONS(4149),
    [aux_sym_basic_type_token48] = ACTIONS(4149),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4149),
    [anon_sym_POUNDif] = ACTIONS(4151),
    [anon_sym_POUNDIF] = ACTIONS(4151),
    [anon_sym_POUNDIf] = ACTIONS(4151),
    [anon_sym_not] = ACTIONS(4149),
    [anon_sym_NOT] = ACTIONS(4149),
    [anon_sym_Not] = ACTIONS(4149),
    [anon_sym_POUNDelse] = ACTIONS(4151),
    [anon_sym_POUNDELSE] = ACTIONS(4151),
    [anon_sym_POUNDElse] = ACTIONS(4151),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4149),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4149),
    [anon_sym_PLUS] = ACTIONS(4151),
    [sym_datetime_literal] = ACTIONS(4151),
    [sym_date_literal] = ACTIONS(4149),
    [sym_time_literal] = ACTIONS(4149),
    [sym_biginteger_literal] = ACTIONS(4151),
    [anon_sym_if] = ACTIONS(4149),
    [anon_sym_IF] = ACTIONS(4149),
    [anon_sym_If] = ACTIONS(4149),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4149),
    [anon_sym_CASE] = ACTIONS(4149),
    [anon_sym_Case] = ACTIONS(4149),
    [anon_sym_for] = ACTIONS(4149),
    [anon_sym_FOR] = ACTIONS(4149),
    [anon_sym_For] = ACTIONS(4149),
    [anon_sym_foreach] = ACTIONS(4149),
    [anon_sym_FOREACH] = ACTIONS(4149),
    [anon_sym_Foreach] = ACTIONS(4149),
    [anon_sym_while] = ACTIONS(4149),
    [anon_sym_WHILE] = ACTIONS(4149),
    [anon_sym_While] = ACTIONS(4149),
    [anon_sym_repeat] = ACTIONS(4149),
    [anon_sym_REPEAT] = ACTIONS(4149),
    [anon_sym_Repeat] = ACTIONS(4149),
    [anon_sym_until] = ACTIONS(4149),
    [anon_sym_UNTIL] = ACTIONS(4149),
    [anon_sym_Until] = ACTIONS(4149),
    [anon_sym_exit] = ACTIONS(4149),
    [anon_sym_EXIT] = ACTIONS(4149),
    [anon_sym_Exit] = ACTIONS(4149),
    [anon_sym_continue] = ACTIONS(4149),
    [anon_sym_CONTINUE] = ACTIONS(4149),
    [anon_sym_Continue] = ACTIONS(4149),
    [anon_sym_break] = ACTIONS(4149),
    [anon_sym_BREAK] = ACTIONS(4149),
    [anon_sym_Break] = ACTIONS(4149),
    [anon_sym_with] = ACTIONS(4149),
    [anon_sym_WITH] = ACTIONS(4149),
    [anon_sym_With] = ACTIONS(4149),
    [sym_asserterror_keyword] = ACTIONS(4151),
    [sym_page_keyword] = ACTIONS(4149),
    [anon_sym_codeunit] = ACTIONS(4149),
    [anon_sym_CODEUNIT] = ACTIONS(4149),
    [anon_sym_Codeunit] = ACTIONS(4149),
    [anon_sym_CodeUnit] = ACTIONS(4149),
    [anon_sym_COdeunit] = ACTIONS(4149),
    [anon_sym_codeUnit] = ACTIONS(4149),
    [sym_report_keyword] = ACTIONS(4149),
    [sym_query_keyword] = ACTIONS(4149),
    [anon_sym_xmlport] = ACTIONS(4149),
    [anon_sym_XMLPORT] = ACTIONS(4149),
    [anon_sym_Xmlport] = ACTIONS(4149),
    [anon_sym_XMLport] = ACTIONS(4149),
    [anon_sym_XMLPort] = ACTIONS(4149),
    [anon_sym_XmlPort] = ACTIONS(4149),
    [anon_sym_enum] = ACTIONS(4149),
    [anon_sym_ENUM] = ACTIONS(4149),
    [anon_sym_Enum] = ACTIONS(4149),
    [anon_sym_eNUM] = ACTIONS(4149),
    [anon_sym_eNum] = ACTIONS(4149),
    [anon_sym_ENum] = ACTIONS(4149),
    [sym_quoted_identifier] = ACTIONS(4151),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4151),
    [sym_integer] = ACTIONS(4149),
    [sym_continue_as_identifier] = ACTIONS(4151),
    [sym_preproc_open] = ACTIONS(4151),
  },
  [STATE(1756)] = {
    [sym_boolean] = STATE(6346),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(9231),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1387),
    [sym_preproc_endif] = STATE(8789),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7706),
    [sym_keyword_as_identifier] = STATE(7706),
    [sym_identifier] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDendif] = ACTIONS(3674),
    [anon_sym_POUNDENDIF] = ACTIONS(3674),
    [anon_sym_POUNDEndif] = ACTIONS(3674),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(3674),
  },
  [STATE(1757)] = {
    [sym_identifier] = ACTIONS(4567),
    [anon_sym_SEMI] = ACTIONS(4864),
    [anon_sym_DASH] = ACTIONS(4571),
    [aux_sym_boolean_token1] = ACTIONS(4567),
    [aux_sym_boolean_token2] = ACTIONS(4567),
    [sym_decimal] = ACTIONS(4567),
    [anon_sym_LPAREN] = ACTIONS(4571),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4567),
    [anon_sym_LBRACK] = ACTIONS(4571),
    [aux_sym_record_type_token1] = ACTIONS(4567),
    [aux_sym_basic_type_token21] = ACTIONS(4567),
    [aux_sym_basic_type_token22] = ACTIONS(4567),
    [aux_sym_basic_type_token48] = ACTIONS(4567),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4567),
    [anon_sym_POUNDif] = ACTIONS(4571),
    [anon_sym_POUNDIF] = ACTIONS(4571),
    [anon_sym_POUNDIf] = ACTIONS(4571),
    [anon_sym_not] = ACTIONS(4567),
    [anon_sym_NOT] = ACTIONS(4567),
    [anon_sym_Not] = ACTIONS(4567),
    [anon_sym_POUNDelif] = ACTIONS(4571),
    [anon_sym_POUNDELIF] = ACTIONS(4571),
    [anon_sym_POUNDElif] = ACTIONS(4571),
    [anon_sym_POUNDelse] = ACTIONS(4571),
    [anon_sym_POUNDELSE] = ACTIONS(4571),
    [anon_sym_POUNDElse] = ACTIONS(4571),
    [anon_sym_POUNDendif] = ACTIONS(4571),
    [anon_sym_POUNDENDIF] = ACTIONS(4571),
    [anon_sym_POUNDEndif] = ACTIONS(4571),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4567),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4567),
    [anon_sym_PLUS] = ACTIONS(4571),
    [sym_datetime_literal] = ACTIONS(4571),
    [sym_date_literal] = ACTIONS(4567),
    [sym_time_literal] = ACTIONS(4567),
    [sym_biginteger_literal] = ACTIONS(4571),
    [anon_sym_if] = ACTIONS(4567),
    [anon_sym_IF] = ACTIONS(4567),
    [anon_sym_If] = ACTIONS(4567),
    [anon_sym_case] = ACTIONS(4567),
    [anon_sym_CASE] = ACTIONS(4567),
    [anon_sym_Case] = ACTIONS(4567),
    [anon_sym_for] = ACTIONS(4567),
    [anon_sym_FOR] = ACTIONS(4567),
    [anon_sym_For] = ACTIONS(4567),
    [anon_sym_foreach] = ACTIONS(4567),
    [anon_sym_FOREACH] = ACTIONS(4567),
    [anon_sym_Foreach] = ACTIONS(4567),
    [anon_sym_while] = ACTIONS(4567),
    [anon_sym_WHILE] = ACTIONS(4567),
    [anon_sym_While] = ACTIONS(4567),
    [anon_sym_repeat] = ACTIONS(4567),
    [anon_sym_REPEAT] = ACTIONS(4567),
    [anon_sym_Repeat] = ACTIONS(4567),
    [anon_sym_exit] = ACTIONS(4567),
    [anon_sym_EXIT] = ACTIONS(4567),
    [anon_sym_Exit] = ACTIONS(4567),
    [anon_sym_continue] = ACTIONS(4567),
    [anon_sym_CONTINUE] = ACTIONS(4567),
    [anon_sym_Continue] = ACTIONS(4567),
    [anon_sym_break] = ACTIONS(4567),
    [anon_sym_BREAK] = ACTIONS(4567),
    [anon_sym_Break] = ACTIONS(4567),
    [anon_sym_with] = ACTIONS(4567),
    [anon_sym_WITH] = ACTIONS(4567),
    [anon_sym_With] = ACTIONS(4567),
    [sym_asserterror_keyword] = ACTIONS(4571),
    [sym_page_keyword] = ACTIONS(4567),
    [anon_sym_codeunit] = ACTIONS(4567),
    [anon_sym_CODEUNIT] = ACTIONS(4567),
    [anon_sym_Codeunit] = ACTIONS(4567),
    [anon_sym_CodeUnit] = ACTIONS(4567),
    [anon_sym_COdeunit] = ACTIONS(4567),
    [anon_sym_codeUnit] = ACTIONS(4567),
    [sym_report_keyword] = ACTIONS(4567),
    [sym_query_keyword] = ACTIONS(4567),
    [anon_sym_xmlport] = ACTIONS(4567),
    [anon_sym_XMLPORT] = ACTIONS(4567),
    [anon_sym_Xmlport] = ACTIONS(4567),
    [anon_sym_XMLport] = ACTIONS(4567),
    [anon_sym_XMLPort] = ACTIONS(4567),
    [anon_sym_XmlPort] = ACTIONS(4567),
    [anon_sym_enum] = ACTIONS(4567),
    [anon_sym_ENUM] = ACTIONS(4567),
    [anon_sym_Enum] = ACTIONS(4567),
    [anon_sym_eNUM] = ACTIONS(4567),
    [anon_sym_eNum] = ACTIONS(4567),
    [anon_sym_ENum] = ACTIONS(4567),
    [sym_quoted_identifier] = ACTIONS(4571),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4571),
    [sym_integer] = ACTIONS(4567),
    [sym_continue_as_identifier] = ACTIONS(4571),
    [sym_preproc_open] = ACTIONS(4571),
    [sym_preproc_close] = ACTIONS(4571),
  },
  [STATE(1758)] = {
    [sym_else_keyword] = STATE(247),
    [sym_identifier] = ACTIONS(4119),
    [anon_sym_SEMI] = ACTIONS(4121),
    [anon_sym_DASH] = ACTIONS(4121),
    [aux_sym_boolean_token1] = ACTIONS(4119),
    [aux_sym_boolean_token2] = ACTIONS(4119),
    [sym_decimal] = ACTIONS(4119),
    [anon_sym_LPAREN] = ACTIONS(4121),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4119),
    [anon_sym_LBRACK] = ACTIONS(4121),
    [aux_sym_record_type_token1] = ACTIONS(4119),
    [aux_sym_basic_type_token21] = ACTIONS(4119),
    [aux_sym_basic_type_token22] = ACTIONS(4119),
    [aux_sym_basic_type_token48] = ACTIONS(4119),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4119),
    [anon_sym_POUNDif] = ACTIONS(4121),
    [anon_sym_POUNDIF] = ACTIONS(4121),
    [anon_sym_POUNDIf] = ACTIONS(4121),
    [anon_sym_not] = ACTIONS(4119),
    [anon_sym_NOT] = ACTIONS(4119),
    [anon_sym_Not] = ACTIONS(4119),
    [anon_sym_POUNDelse] = ACTIONS(4121),
    [anon_sym_POUNDELSE] = ACTIONS(4121),
    [anon_sym_POUNDElse] = ACTIONS(4121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4119),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4119),
    [anon_sym_PLUS] = ACTIONS(4121),
    [sym_datetime_literal] = ACTIONS(4121),
    [sym_date_literal] = ACTIONS(4119),
    [sym_time_literal] = ACTIONS(4119),
    [sym_biginteger_literal] = ACTIONS(4121),
    [anon_sym_if] = ACTIONS(4119),
    [anon_sym_IF] = ACTIONS(4119),
    [anon_sym_If] = ACTIONS(4119),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4119),
    [anon_sym_CASE] = ACTIONS(4119),
    [anon_sym_Case] = ACTIONS(4119),
    [anon_sym_for] = ACTIONS(4119),
    [anon_sym_FOR] = ACTIONS(4119),
    [anon_sym_For] = ACTIONS(4119),
    [anon_sym_foreach] = ACTIONS(4119),
    [anon_sym_FOREACH] = ACTIONS(4119),
    [anon_sym_Foreach] = ACTIONS(4119),
    [anon_sym_while] = ACTIONS(4119),
    [anon_sym_WHILE] = ACTIONS(4119),
    [anon_sym_While] = ACTIONS(4119),
    [anon_sym_repeat] = ACTIONS(4119),
    [anon_sym_REPEAT] = ACTIONS(4119),
    [anon_sym_Repeat] = ACTIONS(4119),
    [anon_sym_until] = ACTIONS(4119),
    [anon_sym_UNTIL] = ACTIONS(4119),
    [anon_sym_Until] = ACTIONS(4119),
    [anon_sym_exit] = ACTIONS(4119),
    [anon_sym_EXIT] = ACTIONS(4119),
    [anon_sym_Exit] = ACTIONS(4119),
    [anon_sym_continue] = ACTIONS(4119),
    [anon_sym_CONTINUE] = ACTIONS(4119),
    [anon_sym_Continue] = ACTIONS(4119),
    [anon_sym_break] = ACTIONS(4119),
    [anon_sym_BREAK] = ACTIONS(4119),
    [anon_sym_Break] = ACTIONS(4119),
    [anon_sym_with] = ACTIONS(4119),
    [anon_sym_WITH] = ACTIONS(4119),
    [anon_sym_With] = ACTIONS(4119),
    [sym_asserterror_keyword] = ACTIONS(4121),
    [sym_page_keyword] = ACTIONS(4119),
    [anon_sym_codeunit] = ACTIONS(4119),
    [anon_sym_CODEUNIT] = ACTIONS(4119),
    [anon_sym_Codeunit] = ACTIONS(4119),
    [anon_sym_CodeUnit] = ACTIONS(4119),
    [anon_sym_COdeunit] = ACTIONS(4119),
    [anon_sym_codeUnit] = ACTIONS(4119),
    [sym_report_keyword] = ACTIONS(4119),
    [sym_query_keyword] = ACTIONS(4119),
    [anon_sym_xmlport] = ACTIONS(4119),
    [anon_sym_XMLPORT] = ACTIONS(4119),
    [anon_sym_Xmlport] = ACTIONS(4119),
    [anon_sym_XMLport] = ACTIONS(4119),
    [anon_sym_XMLPort] = ACTIONS(4119),
    [anon_sym_XmlPort] = ACTIONS(4119),
    [anon_sym_enum] = ACTIONS(4119),
    [anon_sym_ENUM] = ACTIONS(4119),
    [anon_sym_Enum] = ACTIONS(4119),
    [anon_sym_eNUM] = ACTIONS(4119),
    [anon_sym_eNum] = ACTIONS(4119),
    [anon_sym_ENum] = ACTIONS(4119),
    [sym_quoted_identifier] = ACTIONS(4121),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4121),
    [sym_integer] = ACTIONS(4119),
    [sym_continue_as_identifier] = ACTIONS(4121),
    [sym_preproc_open] = ACTIONS(4121),
  },
  [STATE(1759)] = {
    [sym_else_keyword] = STATE(248),
    [sym_identifier] = ACTIONS(4125),
    [anon_sym_SEMI] = ACTIONS(4127),
    [anon_sym_DASH] = ACTIONS(4127),
    [aux_sym_boolean_token1] = ACTIONS(4125),
    [aux_sym_boolean_token2] = ACTIONS(4125),
    [sym_decimal] = ACTIONS(4125),
    [anon_sym_LPAREN] = ACTIONS(4127),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4125),
    [anon_sym_LBRACK] = ACTIONS(4127),
    [aux_sym_record_type_token1] = ACTIONS(4125),
    [aux_sym_basic_type_token21] = ACTIONS(4125),
    [aux_sym_basic_type_token22] = ACTIONS(4125),
    [aux_sym_basic_type_token48] = ACTIONS(4125),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4125),
    [anon_sym_POUNDif] = ACTIONS(4127),
    [anon_sym_POUNDIF] = ACTIONS(4127),
    [anon_sym_POUNDIf] = ACTIONS(4127),
    [anon_sym_not] = ACTIONS(4125),
    [anon_sym_NOT] = ACTIONS(4125),
    [anon_sym_Not] = ACTIONS(4125),
    [anon_sym_POUNDelse] = ACTIONS(4127),
    [anon_sym_POUNDELSE] = ACTIONS(4127),
    [anon_sym_POUNDElse] = ACTIONS(4127),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4125),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4125),
    [anon_sym_PLUS] = ACTIONS(4127),
    [sym_datetime_literal] = ACTIONS(4127),
    [sym_date_literal] = ACTIONS(4125),
    [sym_time_literal] = ACTIONS(4125),
    [sym_biginteger_literal] = ACTIONS(4127),
    [anon_sym_if] = ACTIONS(4125),
    [anon_sym_IF] = ACTIONS(4125),
    [anon_sym_If] = ACTIONS(4125),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4125),
    [anon_sym_CASE] = ACTIONS(4125),
    [anon_sym_Case] = ACTIONS(4125),
    [anon_sym_for] = ACTIONS(4125),
    [anon_sym_FOR] = ACTIONS(4125),
    [anon_sym_For] = ACTIONS(4125),
    [anon_sym_foreach] = ACTIONS(4125),
    [anon_sym_FOREACH] = ACTIONS(4125),
    [anon_sym_Foreach] = ACTIONS(4125),
    [anon_sym_while] = ACTIONS(4125),
    [anon_sym_WHILE] = ACTIONS(4125),
    [anon_sym_While] = ACTIONS(4125),
    [anon_sym_repeat] = ACTIONS(4125),
    [anon_sym_REPEAT] = ACTIONS(4125),
    [anon_sym_Repeat] = ACTIONS(4125),
    [anon_sym_until] = ACTIONS(4125),
    [anon_sym_UNTIL] = ACTIONS(4125),
    [anon_sym_Until] = ACTIONS(4125),
    [anon_sym_exit] = ACTIONS(4125),
    [anon_sym_EXIT] = ACTIONS(4125),
    [anon_sym_Exit] = ACTIONS(4125),
    [anon_sym_continue] = ACTIONS(4125),
    [anon_sym_CONTINUE] = ACTIONS(4125),
    [anon_sym_Continue] = ACTIONS(4125),
    [anon_sym_break] = ACTIONS(4125),
    [anon_sym_BREAK] = ACTIONS(4125),
    [anon_sym_Break] = ACTIONS(4125),
    [anon_sym_with] = ACTIONS(4125),
    [anon_sym_WITH] = ACTIONS(4125),
    [anon_sym_With] = ACTIONS(4125),
    [sym_asserterror_keyword] = ACTIONS(4127),
    [sym_page_keyword] = ACTIONS(4125),
    [anon_sym_codeunit] = ACTIONS(4125),
    [anon_sym_CODEUNIT] = ACTIONS(4125),
    [anon_sym_Codeunit] = ACTIONS(4125),
    [anon_sym_CodeUnit] = ACTIONS(4125),
    [anon_sym_COdeunit] = ACTIONS(4125),
    [anon_sym_codeUnit] = ACTIONS(4125),
    [sym_report_keyword] = ACTIONS(4125),
    [sym_query_keyword] = ACTIONS(4125),
    [anon_sym_xmlport] = ACTIONS(4125),
    [anon_sym_XMLPORT] = ACTIONS(4125),
    [anon_sym_Xmlport] = ACTIONS(4125),
    [anon_sym_XMLport] = ACTIONS(4125),
    [anon_sym_XMLPort] = ACTIONS(4125),
    [anon_sym_XmlPort] = ACTIONS(4125),
    [anon_sym_enum] = ACTIONS(4125),
    [anon_sym_ENUM] = ACTIONS(4125),
    [anon_sym_Enum] = ACTIONS(4125),
    [anon_sym_eNUM] = ACTIONS(4125),
    [anon_sym_eNum] = ACTIONS(4125),
    [anon_sym_ENum] = ACTIONS(4125),
    [sym_quoted_identifier] = ACTIONS(4127),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4127),
    [sym_integer] = ACTIONS(4125),
    [sym_continue_as_identifier] = ACTIONS(4127),
    [sym_preproc_open] = ACTIONS(4127),
  },
  [STATE(1760)] = {
    [sym_boolean] = STATE(6346),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(9140),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1387),
    [sym_preproc_endif] = STATE(11915),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7706),
    [sym_keyword_as_identifier] = STATE(7706),
    [sym_identifier] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDendif] = ACTIONS(223),
    [anon_sym_POUNDENDIF] = ACTIONS(223),
    [anon_sym_POUNDEndif] = ACTIONS(223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(223),
  },
  [STATE(1761)] = {
    [sym_else_keyword] = STATE(293),
    [sym_identifier] = ACTIONS(4169),
    [anon_sym_SEMI] = ACTIONS(4171),
    [anon_sym_DASH] = ACTIONS(4171),
    [aux_sym_boolean_token1] = ACTIONS(4169),
    [aux_sym_boolean_token2] = ACTIONS(4169),
    [sym_decimal] = ACTIONS(4169),
    [anon_sym_LPAREN] = ACTIONS(4171),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4169),
    [anon_sym_LBRACK] = ACTIONS(4171),
    [aux_sym_record_type_token1] = ACTIONS(4169),
    [aux_sym_basic_type_token21] = ACTIONS(4169),
    [aux_sym_basic_type_token22] = ACTIONS(4169),
    [aux_sym_basic_type_token48] = ACTIONS(4169),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4169),
    [anon_sym_POUNDif] = ACTIONS(4171),
    [anon_sym_POUNDIF] = ACTIONS(4171),
    [anon_sym_POUNDIf] = ACTIONS(4171),
    [anon_sym_not] = ACTIONS(4169),
    [anon_sym_NOT] = ACTIONS(4169),
    [anon_sym_Not] = ACTIONS(4169),
    [anon_sym_POUNDelse] = ACTIONS(4171),
    [anon_sym_POUNDELSE] = ACTIONS(4171),
    [anon_sym_POUNDElse] = ACTIONS(4171),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4169),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4169),
    [anon_sym_PLUS] = ACTIONS(4171),
    [sym_datetime_literal] = ACTIONS(4171),
    [sym_date_literal] = ACTIONS(4169),
    [sym_time_literal] = ACTIONS(4169),
    [sym_biginteger_literal] = ACTIONS(4171),
    [anon_sym_if] = ACTIONS(4169),
    [anon_sym_IF] = ACTIONS(4169),
    [anon_sym_If] = ACTIONS(4169),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4169),
    [anon_sym_CASE] = ACTIONS(4169),
    [anon_sym_Case] = ACTIONS(4169),
    [anon_sym_for] = ACTIONS(4169),
    [anon_sym_FOR] = ACTIONS(4169),
    [anon_sym_For] = ACTIONS(4169),
    [anon_sym_foreach] = ACTIONS(4169),
    [anon_sym_FOREACH] = ACTIONS(4169),
    [anon_sym_Foreach] = ACTIONS(4169),
    [anon_sym_while] = ACTIONS(4169),
    [anon_sym_WHILE] = ACTIONS(4169),
    [anon_sym_While] = ACTIONS(4169),
    [anon_sym_repeat] = ACTIONS(4169),
    [anon_sym_REPEAT] = ACTIONS(4169),
    [anon_sym_Repeat] = ACTIONS(4169),
    [anon_sym_until] = ACTIONS(4169),
    [anon_sym_UNTIL] = ACTIONS(4169),
    [anon_sym_Until] = ACTIONS(4169),
    [anon_sym_exit] = ACTIONS(4169),
    [anon_sym_EXIT] = ACTIONS(4169),
    [anon_sym_Exit] = ACTIONS(4169),
    [anon_sym_continue] = ACTIONS(4169),
    [anon_sym_CONTINUE] = ACTIONS(4169),
    [anon_sym_Continue] = ACTIONS(4169),
    [anon_sym_break] = ACTIONS(4169),
    [anon_sym_BREAK] = ACTIONS(4169),
    [anon_sym_Break] = ACTIONS(4169),
    [anon_sym_with] = ACTIONS(4169),
    [anon_sym_WITH] = ACTIONS(4169),
    [anon_sym_With] = ACTIONS(4169),
    [sym_asserterror_keyword] = ACTIONS(4171),
    [sym_page_keyword] = ACTIONS(4169),
    [anon_sym_codeunit] = ACTIONS(4169),
    [anon_sym_CODEUNIT] = ACTIONS(4169),
    [anon_sym_Codeunit] = ACTIONS(4169),
    [anon_sym_CodeUnit] = ACTIONS(4169),
    [anon_sym_COdeunit] = ACTIONS(4169),
    [anon_sym_codeUnit] = ACTIONS(4169),
    [sym_report_keyword] = ACTIONS(4169),
    [sym_query_keyword] = ACTIONS(4169),
    [anon_sym_xmlport] = ACTIONS(4169),
    [anon_sym_XMLPORT] = ACTIONS(4169),
    [anon_sym_Xmlport] = ACTIONS(4169),
    [anon_sym_XMLport] = ACTIONS(4169),
    [anon_sym_XMLPort] = ACTIONS(4169),
    [anon_sym_XmlPort] = ACTIONS(4169),
    [anon_sym_enum] = ACTIONS(4169),
    [anon_sym_ENUM] = ACTIONS(4169),
    [anon_sym_Enum] = ACTIONS(4169),
    [anon_sym_eNUM] = ACTIONS(4169),
    [anon_sym_eNum] = ACTIONS(4169),
    [anon_sym_ENum] = ACTIONS(4169),
    [sym_quoted_identifier] = ACTIONS(4171),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4171),
    [sym_integer] = ACTIONS(4169),
    [sym_continue_as_identifier] = ACTIONS(4171),
    [sym_preproc_open] = ACTIONS(4171),
  },
  [STATE(1762)] = {
    [anon_sym_POUNDif] = ACTIONS(4465),
    [anon_sym_POUNDIF] = ACTIONS(4465),
    [anon_sym_POUNDIf] = ACTIONS(4465),
    [anon_sym_POUNDelif] = ACTIONS(4465),
    [anon_sym_POUNDELIF] = ACTIONS(4465),
    [anon_sym_POUNDElif] = ACTIONS(4465),
    [anon_sym_POUNDelse] = ACTIONS(4465),
    [anon_sym_POUNDELSE] = ACTIONS(4465),
    [anon_sym_POUNDElse] = ACTIONS(4465),
    [anon_sym_POUNDendif] = ACTIONS(4465),
    [anon_sym_POUNDENDIF] = ACTIONS(4465),
    [anon_sym_POUNDEndif] = ACTIONS(4465),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4463),
    [anon_sym_tableextension] = ACTIONS(4465),
    [anon_sym_TABLEEXTENSION] = ACTIONS(4465),
    [anon_sym_Tableextension] = ACTIONS(4465),
    [anon_sym_TableExtension] = ACTIONS(4465),
    [anon_sym_tableExtension] = ACTIONS(4465),
    [sym_page_keyword] = ACTIONS(4463),
    [anon_sym_pageextension] = ACTIONS(4465),
    [anon_sym_PAGEEXTENSION] = ACTIONS(4465),
    [anon_sym_Pageextension] = ACTIONS(4465),
    [anon_sym_PageExtension] = ACTIONS(4465),
    [anon_sym_pageExtension] = ACTIONS(4465),
    [anon_sym_codeunit] = ACTIONS(4465),
    [anon_sym_CODEUNIT] = ACTIONS(4465),
    [anon_sym_Codeunit] = ACTIONS(4465),
    [anon_sym_CodeUnit] = ACTIONS(4465),
    [anon_sym_COdeunit] = ACTIONS(4465),
    [anon_sym_codeUnit] = ACTIONS(4465),
    [sym_report_keyword] = ACTIONS(4463),
    [anon_sym_reportextension] = ACTIONS(4465),
    [anon_sym_REPORTEXTENSION] = ACTIONS(4465),
    [anon_sym_Reportextension] = ACTIONS(4465),
    [anon_sym_ReportExtension] = ACTIONS(4465),
    [anon_sym_reportExtension] = ACTIONS(4465),
    [sym_query_keyword] = ACTIONS(4465),
    [anon_sym_xmlport] = ACTIONS(4465),
    [anon_sym_XMLPORT] = ACTIONS(4465),
    [anon_sym_Xmlport] = ACTIONS(4465),
    [anon_sym_XMLport] = ACTIONS(4465),
    [anon_sym_XMLPort] = ACTIONS(4465),
    [anon_sym_XmlPort] = ACTIONS(4465),
    [anon_sym_enum] = ACTIONS(4463),
    [anon_sym_ENUM] = ACTIONS(4463),
    [anon_sym_Enum] = ACTIONS(4463),
    [anon_sym_eNUM] = ACTIONS(4465),
    [anon_sym_eNum] = ACTIONS(4465),
    [anon_sym_ENum] = ACTIONS(4465),
    [anon_sym_enumextension] = ACTIONS(4465),
    [anon_sym_ENUMEXTENSION] = ACTIONS(4465),
    [anon_sym_Enumextension] = ACTIONS(4465),
    [anon_sym_EnumExtension] = ACTIONS(4465),
    [anon_sym_enumExtension] = ACTIONS(4465),
    [sym_interface_keyword] = ACTIONS(4465),
    [anon_sym_controladdin] = ACTIONS(4465),
    [anon_sym_CONTROLADDIN] = ACTIONS(4465),
    [anon_sym_Controladdin] = ACTIONS(4465),
    [anon_sym_ControlAddIn] = ACTIONS(4465),
    [anon_sym_ControlAddin] = ACTIONS(4465),
    [anon_sym_controlAddIn] = ACTIONS(4465),
    [anon_sym_controlAddin] = ACTIONS(4465),
    [anon_sym_dotnet] = ACTIONS(4465),
    [anon_sym_DOTNET] = ACTIONS(4465),
    [anon_sym_Dotnet] = ACTIONS(4465),
    [anon_sym_DotNet] = ACTIONS(4465),
    [anon_sym_dotNet] = ACTIONS(4465),
    [sym_profile_keyword] = ACTIONS(4463),
    [anon_sym_profileextension] = ACTIONS(4465),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(4465),
    [anon_sym_Profileextension] = ACTIONS(4465),
    [anon_sym_ProfileExtension] = ACTIONS(4465),
    [anon_sym_profileExtension] = ACTIONS(4465),
    [anon_sym_permissionset] = ACTIONS(4463),
    [anon_sym_PERMISSIONSET] = ACTIONS(4463),
    [anon_sym_Permissionset] = ACTIONS(4463),
    [anon_sym_PermissionSet] = ACTIONS(4463),
    [anon_sym_permissionSet] = ACTIONS(4463),
    [anon_sym_permissionsetextension] = ACTIONS(4465),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(4465),
    [anon_sym_Permissionsetextension] = ACTIONS(4465),
    [anon_sym_PermissionSetExtension] = ACTIONS(4465),
    [anon_sym_permissionSetExtension] = ACTIONS(4465),
    [sym_entitlement_keyword] = ACTIONS(4465),
    [anon_sym_pagecustomization] = ACTIONS(4465),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(4465),
    [anon_sym_Pagecustomization] = ACTIONS(4465),
    [anon_sym_PageCustomization] = ACTIONS(4465),
    [anon_sym_pageCustomization] = ACTIONS(4465),
    [sym_namespace_keyword] = ACTIONS(4465),
    [sym_using_keyword] = ACTIONS(4465),
    [sym_fieldgroup_keyword] = ACTIONS(4465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(4465),
    [sym_preproc_close] = ACTIONS(4465),
  },
  [STATE(1763)] = {
    [sym_boolean] = STATE(6346),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(9251),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1387),
    [sym_preproc_endif] = STATE(8824),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7706),
    [sym_keyword_as_identifier] = STATE(7706),
    [sym_identifier] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDendif] = ACTIONS(3674),
    [anon_sym_POUNDENDIF] = ACTIONS(3674),
    [anon_sym_POUNDEndif] = ACTIONS(3674),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(3674),
  },
  [STATE(1764)] = {
    [anon_sym_POUNDif] = ACTIONS(4469),
    [anon_sym_POUNDIF] = ACTIONS(4469),
    [anon_sym_POUNDIf] = ACTIONS(4469),
    [anon_sym_POUNDelif] = ACTIONS(4469),
    [anon_sym_POUNDELIF] = ACTIONS(4469),
    [anon_sym_POUNDElif] = ACTIONS(4469),
    [anon_sym_POUNDelse] = ACTIONS(4469),
    [anon_sym_POUNDELSE] = ACTIONS(4469),
    [anon_sym_POUNDElse] = ACTIONS(4469),
    [anon_sym_POUNDendif] = ACTIONS(4469),
    [anon_sym_POUNDENDIF] = ACTIONS(4469),
    [anon_sym_POUNDEndif] = ACTIONS(4469),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4467),
    [anon_sym_tableextension] = ACTIONS(4469),
    [anon_sym_TABLEEXTENSION] = ACTIONS(4469),
    [anon_sym_Tableextension] = ACTIONS(4469),
    [anon_sym_TableExtension] = ACTIONS(4469),
    [anon_sym_tableExtension] = ACTIONS(4469),
    [sym_page_keyword] = ACTIONS(4467),
    [anon_sym_pageextension] = ACTIONS(4469),
    [anon_sym_PAGEEXTENSION] = ACTIONS(4469),
    [anon_sym_Pageextension] = ACTIONS(4469),
    [anon_sym_PageExtension] = ACTIONS(4469),
    [anon_sym_pageExtension] = ACTIONS(4469),
    [anon_sym_codeunit] = ACTIONS(4469),
    [anon_sym_CODEUNIT] = ACTIONS(4469),
    [anon_sym_Codeunit] = ACTIONS(4469),
    [anon_sym_CodeUnit] = ACTIONS(4469),
    [anon_sym_COdeunit] = ACTIONS(4469),
    [anon_sym_codeUnit] = ACTIONS(4469),
    [sym_report_keyword] = ACTIONS(4467),
    [anon_sym_reportextension] = ACTIONS(4469),
    [anon_sym_REPORTEXTENSION] = ACTIONS(4469),
    [anon_sym_Reportextension] = ACTIONS(4469),
    [anon_sym_ReportExtension] = ACTIONS(4469),
    [anon_sym_reportExtension] = ACTIONS(4469),
    [sym_query_keyword] = ACTIONS(4469),
    [anon_sym_xmlport] = ACTIONS(4469),
    [anon_sym_XMLPORT] = ACTIONS(4469),
    [anon_sym_Xmlport] = ACTIONS(4469),
    [anon_sym_XMLport] = ACTIONS(4469),
    [anon_sym_XMLPort] = ACTIONS(4469),
    [anon_sym_XmlPort] = ACTIONS(4469),
    [anon_sym_enum] = ACTIONS(4467),
    [anon_sym_ENUM] = ACTIONS(4467),
    [anon_sym_Enum] = ACTIONS(4467),
    [anon_sym_eNUM] = ACTIONS(4469),
    [anon_sym_eNum] = ACTIONS(4469),
    [anon_sym_ENum] = ACTIONS(4469),
    [anon_sym_enumextension] = ACTIONS(4469),
    [anon_sym_ENUMEXTENSION] = ACTIONS(4469),
    [anon_sym_Enumextension] = ACTIONS(4469),
    [anon_sym_EnumExtension] = ACTIONS(4469),
    [anon_sym_enumExtension] = ACTIONS(4469),
    [sym_interface_keyword] = ACTIONS(4469),
    [anon_sym_controladdin] = ACTIONS(4469),
    [anon_sym_CONTROLADDIN] = ACTIONS(4469),
    [anon_sym_Controladdin] = ACTIONS(4469),
    [anon_sym_ControlAddIn] = ACTIONS(4469),
    [anon_sym_ControlAddin] = ACTIONS(4469),
    [anon_sym_controlAddIn] = ACTIONS(4469),
    [anon_sym_controlAddin] = ACTIONS(4469),
    [anon_sym_dotnet] = ACTIONS(4469),
    [anon_sym_DOTNET] = ACTIONS(4469),
    [anon_sym_Dotnet] = ACTIONS(4469),
    [anon_sym_DotNet] = ACTIONS(4469),
    [anon_sym_dotNet] = ACTIONS(4469),
    [sym_profile_keyword] = ACTIONS(4467),
    [anon_sym_profileextension] = ACTIONS(4469),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(4469),
    [anon_sym_Profileextension] = ACTIONS(4469),
    [anon_sym_ProfileExtension] = ACTIONS(4469),
    [anon_sym_profileExtension] = ACTIONS(4469),
    [anon_sym_permissionset] = ACTIONS(4467),
    [anon_sym_PERMISSIONSET] = ACTIONS(4467),
    [anon_sym_Permissionset] = ACTIONS(4467),
    [anon_sym_PermissionSet] = ACTIONS(4467),
    [anon_sym_permissionSet] = ACTIONS(4467),
    [anon_sym_permissionsetextension] = ACTIONS(4469),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(4469),
    [anon_sym_Permissionsetextension] = ACTIONS(4469),
    [anon_sym_PermissionSetExtension] = ACTIONS(4469),
    [anon_sym_permissionSetExtension] = ACTIONS(4469),
    [sym_entitlement_keyword] = ACTIONS(4469),
    [anon_sym_pagecustomization] = ACTIONS(4469),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(4469),
    [anon_sym_Pagecustomization] = ACTIONS(4469),
    [anon_sym_PageCustomization] = ACTIONS(4469),
    [anon_sym_pageCustomization] = ACTIONS(4469),
    [sym_namespace_keyword] = ACTIONS(4469),
    [sym_using_keyword] = ACTIONS(4469),
    [sym_fieldgroup_keyword] = ACTIONS(4469),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(4469),
    [sym_preproc_close] = ACTIONS(4469),
  },
  [STATE(1765)] = {
    [sym_boolean] = STATE(6346),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(9300),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1387),
    [sym_preproc_endif] = STATE(8791),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7706),
    [sym_keyword_as_identifier] = STATE(7706),
    [sym_identifier] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDendif] = ACTIONS(3674),
    [anon_sym_POUNDENDIF] = ACTIONS(3674),
    [anon_sym_POUNDEndif] = ACTIONS(3674),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(3674),
  },
  [STATE(1766)] = {
    [sym_identifier] = ACTIONS(4866),
    [anon_sym_SEMI] = ACTIONS(4579),
    [anon_sym_DASH] = ACTIONS(4869),
    [aux_sym_boolean_token1] = ACTIONS(4866),
    [aux_sym_boolean_token2] = ACTIONS(4866),
    [sym_decimal] = ACTIONS(4866),
    [anon_sym_LPAREN] = ACTIONS(4869),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4866),
    [anon_sym_LBRACK] = ACTIONS(4869),
    [aux_sym_record_type_token1] = ACTIONS(4866),
    [aux_sym_basic_type_token21] = ACTIONS(4866),
    [aux_sym_basic_type_token22] = ACTIONS(4866),
    [aux_sym_basic_type_token48] = ACTIONS(4866),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4577),
    [anon_sym_POUNDif] = ACTIONS(4579),
    [anon_sym_POUNDIF] = ACTIONS(4579),
    [anon_sym_POUNDIf] = ACTIONS(4579),
    [anon_sym_not] = ACTIONS(4866),
    [anon_sym_NOT] = ACTIONS(4866),
    [anon_sym_Not] = ACTIONS(4866),
    [anon_sym_POUNDelif] = ACTIONS(4579),
    [anon_sym_POUNDELIF] = ACTIONS(4579),
    [anon_sym_POUNDElif] = ACTIONS(4579),
    [anon_sym_POUNDelse] = ACTIONS(4579),
    [anon_sym_POUNDELSE] = ACTIONS(4579),
    [anon_sym_POUNDElse] = ACTIONS(4579),
    [anon_sym_POUNDendif] = ACTIONS(4579),
    [anon_sym_POUNDENDIF] = ACTIONS(4579),
    [anon_sym_POUNDEndif] = ACTIONS(4579),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4866),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4866),
    [anon_sym_PLUS] = ACTIONS(4869),
    [sym_datetime_literal] = ACTIONS(4869),
    [sym_date_literal] = ACTIONS(4866),
    [sym_time_literal] = ACTIONS(4866),
    [sym_biginteger_literal] = ACTIONS(4869),
    [anon_sym_if] = ACTIONS(4866),
    [anon_sym_IF] = ACTIONS(4866),
    [anon_sym_If] = ACTIONS(4866),
    [anon_sym_case] = ACTIONS(4577),
    [anon_sym_CASE] = ACTIONS(4577),
    [anon_sym_Case] = ACTIONS(4577),
    [anon_sym_for] = ACTIONS(4577),
    [anon_sym_FOR] = ACTIONS(4577),
    [anon_sym_For] = ACTIONS(4577),
    [anon_sym_foreach] = ACTIONS(4577),
    [anon_sym_FOREACH] = ACTIONS(4577),
    [anon_sym_Foreach] = ACTIONS(4577),
    [anon_sym_while] = ACTIONS(4577),
    [anon_sym_WHILE] = ACTIONS(4577),
    [anon_sym_While] = ACTIONS(4577),
    [anon_sym_repeat] = ACTIONS(4577),
    [anon_sym_REPEAT] = ACTIONS(4577),
    [anon_sym_Repeat] = ACTIONS(4577),
    [anon_sym_exit] = ACTIONS(4577),
    [anon_sym_EXIT] = ACTIONS(4577),
    [anon_sym_Exit] = ACTIONS(4577),
    [anon_sym_continue] = ACTIONS(4577),
    [anon_sym_CONTINUE] = ACTIONS(4577),
    [anon_sym_Continue] = ACTIONS(4577),
    [anon_sym_break] = ACTIONS(4577),
    [anon_sym_BREAK] = ACTIONS(4577),
    [anon_sym_Break] = ACTIONS(4577),
    [anon_sym_with] = ACTIONS(4577),
    [anon_sym_WITH] = ACTIONS(4577),
    [anon_sym_With] = ACTIONS(4577),
    [sym_asserterror_keyword] = ACTIONS(4579),
    [sym_page_keyword] = ACTIONS(4866),
    [anon_sym_codeunit] = ACTIONS(4866),
    [anon_sym_CODEUNIT] = ACTIONS(4866),
    [anon_sym_Codeunit] = ACTIONS(4866),
    [anon_sym_CodeUnit] = ACTIONS(4866),
    [anon_sym_COdeunit] = ACTIONS(4866),
    [anon_sym_codeUnit] = ACTIONS(4866),
    [sym_report_keyword] = ACTIONS(4866),
    [sym_query_keyword] = ACTIONS(4866),
    [anon_sym_xmlport] = ACTIONS(4866),
    [anon_sym_XMLPORT] = ACTIONS(4866),
    [anon_sym_Xmlport] = ACTIONS(4866),
    [anon_sym_XMLport] = ACTIONS(4866),
    [anon_sym_XMLPort] = ACTIONS(4866),
    [anon_sym_XmlPort] = ACTIONS(4866),
    [anon_sym_enum] = ACTIONS(4866),
    [anon_sym_ENUM] = ACTIONS(4866),
    [anon_sym_Enum] = ACTIONS(4866),
    [anon_sym_eNUM] = ACTIONS(4866),
    [anon_sym_eNum] = ACTIONS(4866),
    [anon_sym_ENum] = ACTIONS(4866),
    [sym_quoted_identifier] = ACTIONS(4869),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4869),
    [sym_integer] = ACTIONS(4866),
    [sym_continue_as_identifier] = ACTIONS(4869),
    [sym_preproc_open] = ACTIONS(4579),
    [sym_preproc_close] = ACTIONS(4579),
  },
  [STATE(1767)] = {
    [sym_boolean] = STATE(6346),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(9180),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1387),
    [sym_preproc_endif] = STATE(12224),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7706),
    [sym_keyword_as_identifier] = STATE(7706),
    [sym_identifier] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [anon_sym_POUNDendif] = ACTIONS(223),
    [anon_sym_POUNDENDIF] = ACTIONS(223),
    [anon_sym_POUNDEndif] = ACTIONS(223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
    [sym_preproc_close] = ACTIONS(223),
  },
  [STATE(1768)] = {
    [sym_identifier] = ACTIONS(4135),
    [anon_sym_SEMI] = ACTIONS(4137),
    [anon_sym_DASH] = ACTIONS(4137),
    [aux_sym_boolean_token1] = ACTIONS(4135),
    [aux_sym_boolean_token2] = ACTIONS(4135),
    [sym_decimal] = ACTIONS(4135),
    [anon_sym_LPAREN] = ACTIONS(4135),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4135),
    [anon_sym_LBRACK] = ACTIONS(4137),
    [aux_sym_record_type_token1] = ACTIONS(4135),
    [aux_sym_basic_type_token21] = ACTIONS(4135),
    [aux_sym_basic_type_token22] = ACTIONS(4135),
    [aux_sym_basic_type_token48] = ACTIONS(4135),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4135),
    [anon_sym_POUNDif] = ACTIONS(4137),
    [anon_sym_POUNDIF] = ACTIONS(4137),
    [anon_sym_POUNDIf] = ACTIONS(4137),
    [anon_sym_not] = ACTIONS(4135),
    [anon_sym_NOT] = ACTIONS(4135),
    [anon_sym_Not] = ACTIONS(4135),
    [anon_sym_POUNDelse] = ACTIONS(4137),
    [anon_sym_POUNDELSE] = ACTIONS(4137),
    [anon_sym_POUNDElse] = ACTIONS(4137),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_LPAREN2] = ACTIONS(4137),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4135),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [sym_datetime_literal] = ACTIONS(4137),
    [sym_date_literal] = ACTIONS(4135),
    [sym_time_literal] = ACTIONS(4135),
    [sym_biginteger_literal] = ACTIONS(4137),
    [anon_sym_if] = ACTIONS(4135),
    [anon_sym_IF] = ACTIONS(4135),
    [anon_sym_If] = ACTIONS(4135),
    [anon_sym_else] = ACTIONS(4135),
    [anon_sym_ELSE] = ACTIONS(4135),
    [anon_sym_Else] = ACTIONS(4135),
    [anon_sym_case] = ACTIONS(4135),
    [anon_sym_CASE] = ACTIONS(4135),
    [anon_sym_Case] = ACTIONS(4135),
    [anon_sym_for] = ACTIONS(4135),
    [anon_sym_FOR] = ACTIONS(4135),
    [anon_sym_For] = ACTIONS(4135),
    [anon_sym_foreach] = ACTIONS(4135),
    [anon_sym_FOREACH] = ACTIONS(4135),
    [anon_sym_Foreach] = ACTIONS(4135),
    [anon_sym_while] = ACTIONS(4135),
    [anon_sym_WHILE] = ACTIONS(4135),
    [anon_sym_While] = ACTIONS(4135),
    [anon_sym_repeat] = ACTIONS(4135),
    [anon_sym_REPEAT] = ACTIONS(4135),
    [anon_sym_Repeat] = ACTIONS(4135),
    [anon_sym_until] = ACTIONS(4135),
    [anon_sym_UNTIL] = ACTIONS(4135),
    [anon_sym_Until] = ACTIONS(4135),
    [anon_sym_exit] = ACTIONS(4135),
    [anon_sym_EXIT] = ACTIONS(4135),
    [anon_sym_Exit] = ACTIONS(4135),
    [anon_sym_continue] = ACTIONS(4135),
    [anon_sym_CONTINUE] = ACTIONS(4135),
    [anon_sym_Continue] = ACTIONS(4135),
    [anon_sym_break] = ACTIONS(4135),
    [anon_sym_BREAK] = ACTIONS(4135),
    [anon_sym_Break] = ACTIONS(4135),
    [anon_sym_with] = ACTIONS(4135),
    [anon_sym_WITH] = ACTIONS(4135),
    [anon_sym_With] = ACTIONS(4135),
    [sym_asserterror_keyword] = ACTIONS(4137),
    [sym_page_keyword] = ACTIONS(4135),
    [anon_sym_codeunit] = ACTIONS(4135),
    [anon_sym_CODEUNIT] = ACTIONS(4135),
    [anon_sym_Codeunit] = ACTIONS(4135),
    [anon_sym_CodeUnit] = ACTIONS(4135),
    [anon_sym_COdeunit] = ACTIONS(4135),
    [anon_sym_codeUnit] = ACTIONS(4135),
    [sym_report_keyword] = ACTIONS(4135),
    [sym_query_keyword] = ACTIONS(4135),
    [anon_sym_xmlport] = ACTIONS(4135),
    [anon_sym_XMLPORT] = ACTIONS(4135),
    [anon_sym_Xmlport] = ACTIONS(4135),
    [anon_sym_XMLport] = ACTIONS(4135),
    [anon_sym_XMLPort] = ACTIONS(4135),
    [anon_sym_XmlPort] = ACTIONS(4135),
    [anon_sym_enum] = ACTIONS(4135),
    [anon_sym_ENUM] = ACTIONS(4135),
    [anon_sym_Enum] = ACTIONS(4135),
    [anon_sym_eNUM] = ACTIONS(4135),
    [anon_sym_eNum] = ACTIONS(4135),
    [anon_sym_ENum] = ACTIONS(4135),
    [sym_quoted_identifier] = ACTIONS(4137),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4137),
    [sym_integer] = ACTIONS(4135),
    [sym_continue_as_identifier] = ACTIONS(4137),
    [sym_preproc_open] = ACTIONS(4137),
  },
  [STATE(1769)] = {
    [sym_boolean] = STATE(5949),
    [sym_option_member] = STATE(5901),
    [sym_keyword_identifier] = STATE(5949),
    [sym_codeunit_keyword] = STATE(5754),
    [sym_xmlport_keyword] = STATE(5754),
    [sym_enum_keyword] = STATE(5754),
    [sym_keyword_as_identifier] = STATE(5949),
    [aux_sym_option_member_list_repeat2] = STATE(2415),
    [sym_identifier] = ACTIONS(4836),
    [anon_sym_DOT] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(4872),
    [anon_sym_DASH] = ACTIONS(4840),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [aux_sym_where_condition_token1] = ACTIONS(4844),
    [anon_sym_DOT_DOT] = ACTIONS(374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4848),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [aux_sym_basic_type_token53] = ACTIONS(4844),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4844),
    [aux_sym_separator_action_token1] = ACTIONS(4844),
    [aux_sym_type_declaration_token1] = ACTIONS(4844),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(374),
    [aux_sym__expression_token1] = ACTIONS(374),
    [aux_sym__expression_token2] = ACTIONS(374),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4846),
    [anon_sym_SLASH] = ACTIONS(376),
    [anon_sym_div] = ACTIONS(376),
    [anon_sym_DIV] = ACTIONS(376),
    [anon_sym_Div] = ACTIONS(376),
    [anon_sym_mod] = ACTIONS(376),
    [anon_sym_MOD] = ACTIONS(376),
    [anon_sym_Mod] = ACTIONS(376),
    [anon_sym_PLUS] = ACTIONS(376),
    [anon_sym_GT_EQ] = ACTIONS(374),
    [anon_sym_LT_EQ] = ACTIONS(374),
    [anon_sym_GT] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(376),
    [anon_sym_LT_GT] = ACTIONS(374),
    [anon_sym_and] = ACTIONS(376),
    [anon_sym_AND] = ACTIONS(376),
    [anon_sym_And] = ACTIONS(376),
    [anon_sym_or] = ACTIONS(376),
    [anon_sym_OR] = ACTIONS(376),
    [anon_sym_Or] = ACTIONS(376),
    [anon_sym_xor] = ACTIONS(376),
    [anon_sym_XOR] = ACTIONS(376),
    [anon_sym_Xor] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(374),
    [anon_sym_in] = ACTIONS(376),
    [anon_sym_IN] = ACTIONS(376),
    [anon_sym_In] = ACTIONS(376),
    [anon_sym_to] = ACTIONS(376),
    [anon_sym_TO] = ACTIONS(376),
    [anon_sym_To] = ACTIONS(376),
    [anon_sym_downto] = ACTIONS(376),
    [anon_sym_DOWNTO] = ACTIONS(376),
    [anon_sym_Downto] = ACTIONS(376),
    [sym_page_keyword] = ACTIONS(4846),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(4846),
    [sym_query_keyword] = ACTIONS(4846),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_local_keyword] = ACTIONS(4836),
    [sym_internal_keyword] = ACTIONS(4836),
    [sym_protected_keyword] = ACTIONS(4836),
    [sym_key_keyword] = ACTIONS(4844),
    [sym_dataset_keyword] = ACTIONS(4844),
    [sym_quoted_identifier] = ACTIONS(4856),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4856),
    [sym_integer] = ACTIONS(4856),
  },
  [STATE(1770)] = {
    [sym_identifier] = ACTIONS(4874),
    [anon_sym_SEMI] = ACTIONS(4876),
    [anon_sym_DASH] = ACTIONS(4876),
    [aux_sym_boolean_token1] = ACTIONS(4874),
    [aux_sym_boolean_token2] = ACTIONS(4874),
    [sym_decimal] = ACTIONS(4874),
    [anon_sym_LPAREN] = ACTIONS(4876),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4874),
    [anon_sym_LBRACK] = ACTIONS(4876),
    [aux_sym_record_type_token1] = ACTIONS(4874),
    [aux_sym_basic_type_token21] = ACTIONS(4874),
    [aux_sym_basic_type_token22] = ACTIONS(4874),
    [aux_sym_basic_type_token48] = ACTIONS(4874),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4874),
    [anon_sym_POUNDif] = ACTIONS(4876),
    [anon_sym_POUNDIF] = ACTIONS(4876),
    [anon_sym_POUNDIf] = ACTIONS(4876),
    [anon_sym_not] = ACTIONS(4874),
    [anon_sym_NOT] = ACTIONS(4874),
    [anon_sym_Not] = ACTIONS(4874),
    [anon_sym_POUNDelif] = ACTIONS(4876),
    [anon_sym_POUNDELIF] = ACTIONS(4876),
    [anon_sym_POUNDElif] = ACTIONS(4876),
    [anon_sym_POUNDelse] = ACTIONS(4876),
    [anon_sym_POUNDELSE] = ACTIONS(4876),
    [anon_sym_POUNDElse] = ACTIONS(4876),
    [anon_sym_POUNDendif] = ACTIONS(4876),
    [anon_sym_POUNDENDIF] = ACTIONS(4876),
    [anon_sym_POUNDEndif] = ACTIONS(4876),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4874),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4874),
    [anon_sym_PLUS] = ACTIONS(4876),
    [sym_datetime_literal] = ACTIONS(4876),
    [sym_date_literal] = ACTIONS(4874),
    [sym_time_literal] = ACTIONS(4874),
    [sym_biginteger_literal] = ACTIONS(4876),
    [anon_sym_if] = ACTIONS(4874),
    [anon_sym_IF] = ACTIONS(4874),
    [anon_sym_If] = ACTIONS(4874),
    [anon_sym_case] = ACTIONS(4874),
    [anon_sym_CASE] = ACTIONS(4874),
    [anon_sym_Case] = ACTIONS(4874),
    [anon_sym_for] = ACTIONS(4874),
    [anon_sym_FOR] = ACTIONS(4874),
    [anon_sym_For] = ACTIONS(4874),
    [anon_sym_foreach] = ACTIONS(4874),
    [anon_sym_FOREACH] = ACTIONS(4874),
    [anon_sym_Foreach] = ACTIONS(4874),
    [anon_sym_while] = ACTIONS(4874),
    [anon_sym_WHILE] = ACTIONS(4874),
    [anon_sym_While] = ACTIONS(4874),
    [anon_sym_repeat] = ACTIONS(4874),
    [anon_sym_REPEAT] = ACTIONS(4874),
    [anon_sym_Repeat] = ACTIONS(4874),
    [anon_sym_exit] = ACTIONS(4874),
    [anon_sym_EXIT] = ACTIONS(4874),
    [anon_sym_Exit] = ACTIONS(4874),
    [anon_sym_continue] = ACTIONS(4874),
    [anon_sym_CONTINUE] = ACTIONS(4874),
    [anon_sym_Continue] = ACTIONS(4874),
    [anon_sym_break] = ACTIONS(4874),
    [anon_sym_BREAK] = ACTIONS(4874),
    [anon_sym_Break] = ACTIONS(4874),
    [anon_sym_with] = ACTIONS(4874),
    [anon_sym_WITH] = ACTIONS(4874),
    [anon_sym_With] = ACTIONS(4874),
    [sym_asserterror_keyword] = ACTIONS(4876),
    [sym_page_keyword] = ACTIONS(4874),
    [anon_sym_codeunit] = ACTIONS(4874),
    [anon_sym_CODEUNIT] = ACTIONS(4874),
    [anon_sym_Codeunit] = ACTIONS(4874),
    [anon_sym_CodeUnit] = ACTIONS(4874),
    [anon_sym_COdeunit] = ACTIONS(4874),
    [anon_sym_codeUnit] = ACTIONS(4874),
    [sym_report_keyword] = ACTIONS(4874),
    [sym_query_keyword] = ACTIONS(4874),
    [anon_sym_xmlport] = ACTIONS(4874),
    [anon_sym_XMLPORT] = ACTIONS(4874),
    [anon_sym_Xmlport] = ACTIONS(4874),
    [anon_sym_XMLport] = ACTIONS(4874),
    [anon_sym_XMLPort] = ACTIONS(4874),
    [anon_sym_XmlPort] = ACTIONS(4874),
    [anon_sym_enum] = ACTIONS(4874),
    [anon_sym_ENUM] = ACTIONS(4874),
    [anon_sym_Enum] = ACTIONS(4874),
    [anon_sym_eNUM] = ACTIONS(4874),
    [anon_sym_eNum] = ACTIONS(4874),
    [anon_sym_ENum] = ACTIONS(4874),
    [sym_quoted_identifier] = ACTIONS(4876),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4876),
    [sym_integer] = ACTIONS(4874),
    [sym_continue_as_identifier] = ACTIONS(4876),
    [sym_preproc_open] = ACTIONS(4876),
    [sym_preproc_close] = ACTIONS(4876),
  },
  [STATE(1771)] = {
    [sym_else_keyword] = STATE(287),
    [sym_identifier] = ACTIONS(4161),
    [anon_sym_SEMI] = ACTIONS(4163),
    [anon_sym_DASH] = ACTIONS(4163),
    [aux_sym_boolean_token1] = ACTIONS(4161),
    [aux_sym_boolean_token2] = ACTIONS(4161),
    [sym_decimal] = ACTIONS(4161),
    [anon_sym_LPAREN] = ACTIONS(4163),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4161),
    [anon_sym_LBRACK] = ACTIONS(4163),
    [aux_sym_record_type_token1] = ACTIONS(4161),
    [aux_sym_basic_type_token21] = ACTIONS(4161),
    [aux_sym_basic_type_token22] = ACTIONS(4161),
    [aux_sym_basic_type_token48] = ACTIONS(4161),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4161),
    [anon_sym_POUNDif] = ACTIONS(4163),
    [anon_sym_POUNDIF] = ACTIONS(4163),
    [anon_sym_POUNDIf] = ACTIONS(4163),
    [anon_sym_not] = ACTIONS(4161),
    [anon_sym_NOT] = ACTIONS(4161),
    [anon_sym_Not] = ACTIONS(4161),
    [anon_sym_POUNDelse] = ACTIONS(4163),
    [anon_sym_POUNDELSE] = ACTIONS(4163),
    [anon_sym_POUNDElse] = ACTIONS(4163),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4161),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4161),
    [anon_sym_PLUS] = ACTIONS(4163),
    [sym_datetime_literal] = ACTIONS(4163),
    [sym_date_literal] = ACTIONS(4161),
    [sym_time_literal] = ACTIONS(4161),
    [sym_biginteger_literal] = ACTIONS(4163),
    [anon_sym_if] = ACTIONS(4161),
    [anon_sym_IF] = ACTIONS(4161),
    [anon_sym_If] = ACTIONS(4161),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4161),
    [anon_sym_CASE] = ACTIONS(4161),
    [anon_sym_Case] = ACTIONS(4161),
    [anon_sym_for] = ACTIONS(4161),
    [anon_sym_FOR] = ACTIONS(4161),
    [anon_sym_For] = ACTIONS(4161),
    [anon_sym_foreach] = ACTIONS(4161),
    [anon_sym_FOREACH] = ACTIONS(4161),
    [anon_sym_Foreach] = ACTIONS(4161),
    [anon_sym_while] = ACTIONS(4161),
    [anon_sym_WHILE] = ACTIONS(4161),
    [anon_sym_While] = ACTIONS(4161),
    [anon_sym_repeat] = ACTIONS(4161),
    [anon_sym_REPEAT] = ACTIONS(4161),
    [anon_sym_Repeat] = ACTIONS(4161),
    [anon_sym_until] = ACTIONS(4161),
    [anon_sym_UNTIL] = ACTIONS(4161),
    [anon_sym_Until] = ACTIONS(4161),
    [anon_sym_exit] = ACTIONS(4161),
    [anon_sym_EXIT] = ACTIONS(4161),
    [anon_sym_Exit] = ACTIONS(4161),
    [anon_sym_continue] = ACTIONS(4161),
    [anon_sym_CONTINUE] = ACTIONS(4161),
    [anon_sym_Continue] = ACTIONS(4161),
    [anon_sym_break] = ACTIONS(4161),
    [anon_sym_BREAK] = ACTIONS(4161),
    [anon_sym_Break] = ACTIONS(4161),
    [anon_sym_with] = ACTIONS(4161),
    [anon_sym_WITH] = ACTIONS(4161),
    [anon_sym_With] = ACTIONS(4161),
    [sym_asserterror_keyword] = ACTIONS(4163),
    [sym_page_keyword] = ACTIONS(4161),
    [anon_sym_codeunit] = ACTIONS(4161),
    [anon_sym_CODEUNIT] = ACTIONS(4161),
    [anon_sym_Codeunit] = ACTIONS(4161),
    [anon_sym_CodeUnit] = ACTIONS(4161),
    [anon_sym_COdeunit] = ACTIONS(4161),
    [anon_sym_codeUnit] = ACTIONS(4161),
    [sym_report_keyword] = ACTIONS(4161),
    [sym_query_keyword] = ACTIONS(4161),
    [anon_sym_xmlport] = ACTIONS(4161),
    [anon_sym_XMLPORT] = ACTIONS(4161),
    [anon_sym_Xmlport] = ACTIONS(4161),
    [anon_sym_XMLport] = ACTIONS(4161),
    [anon_sym_XMLPort] = ACTIONS(4161),
    [anon_sym_XmlPort] = ACTIONS(4161),
    [anon_sym_enum] = ACTIONS(4161),
    [anon_sym_ENUM] = ACTIONS(4161),
    [anon_sym_Enum] = ACTIONS(4161),
    [anon_sym_eNUM] = ACTIONS(4161),
    [anon_sym_eNum] = ACTIONS(4161),
    [anon_sym_ENum] = ACTIONS(4161),
    [sym_quoted_identifier] = ACTIONS(4163),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4163),
    [sym_integer] = ACTIONS(4161),
    [sym_continue_as_identifier] = ACTIONS(4163),
    [sym_preproc_open] = ACTIONS(4163),
  },
  [STATE(1772)] = {
    [sym_identifier] = ACTIONS(4463),
    [anon_sym_SEMI] = ACTIONS(4465),
    [anon_sym_DASH] = ACTIONS(4465),
    [aux_sym_boolean_token1] = ACTIONS(4463),
    [aux_sym_boolean_token2] = ACTIONS(4463),
    [sym_decimal] = ACTIONS(4463),
    [anon_sym_LPAREN] = ACTIONS(4465),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4463),
    [anon_sym_LBRACK] = ACTIONS(4465),
    [aux_sym_record_type_token1] = ACTIONS(4463),
    [aux_sym_basic_type_token21] = ACTIONS(4463),
    [aux_sym_basic_type_token22] = ACTIONS(4463),
    [aux_sym_basic_type_token48] = ACTIONS(4463),
    [anon_sym_POUNDif] = ACTIONS(4465),
    [anon_sym_POUNDIF] = ACTIONS(4465),
    [anon_sym_POUNDIf] = ACTIONS(4465),
    [anon_sym_not] = ACTIONS(4463),
    [anon_sym_NOT] = ACTIONS(4463),
    [anon_sym_Not] = ACTIONS(4463),
    [anon_sym_POUNDelif] = ACTIONS(4465),
    [anon_sym_POUNDELIF] = ACTIONS(4465),
    [anon_sym_POUNDElif] = ACTIONS(4465),
    [anon_sym_POUNDelse] = ACTIONS(4465),
    [anon_sym_POUNDELSE] = ACTIONS(4465),
    [anon_sym_POUNDElse] = ACTIONS(4465),
    [anon_sym_POUNDendif] = ACTIONS(4465),
    [anon_sym_POUNDENDIF] = ACTIONS(4465),
    [anon_sym_POUNDEndif] = ACTIONS(4465),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4463),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4463),
    [anon_sym_PLUS] = ACTIONS(4465),
    [sym_datetime_literal] = ACTIONS(4465),
    [sym_date_literal] = ACTIONS(4463),
    [sym_time_literal] = ACTIONS(4463),
    [sym_biginteger_literal] = ACTIONS(4465),
    [anon_sym_if] = ACTIONS(4463),
    [anon_sym_IF] = ACTIONS(4463),
    [anon_sym_If] = ACTIONS(4463),
    [anon_sym_case] = ACTIONS(4463),
    [anon_sym_CASE] = ACTIONS(4463),
    [anon_sym_Case] = ACTIONS(4463),
    [anon_sym_for] = ACTIONS(4463),
    [anon_sym_FOR] = ACTIONS(4463),
    [anon_sym_For] = ACTIONS(4463),
    [anon_sym_foreach] = ACTIONS(4463),
    [anon_sym_FOREACH] = ACTIONS(4463),
    [anon_sym_Foreach] = ACTIONS(4463),
    [anon_sym_while] = ACTIONS(4463),
    [anon_sym_WHILE] = ACTIONS(4463),
    [anon_sym_While] = ACTIONS(4463),
    [anon_sym_repeat] = ACTIONS(4463),
    [anon_sym_REPEAT] = ACTIONS(4463),
    [anon_sym_Repeat] = ACTIONS(4463),
    [anon_sym_exit] = ACTIONS(4463),
    [anon_sym_EXIT] = ACTIONS(4463),
    [anon_sym_Exit] = ACTIONS(4463),
    [anon_sym_continue] = ACTIONS(4463),
    [anon_sym_CONTINUE] = ACTIONS(4463),
    [anon_sym_Continue] = ACTIONS(4463),
    [anon_sym_break] = ACTIONS(4463),
    [anon_sym_BREAK] = ACTIONS(4463),
    [anon_sym_Break] = ACTIONS(4463),
    [anon_sym_with] = ACTIONS(4463),
    [anon_sym_WITH] = ACTIONS(4463),
    [anon_sym_With] = ACTIONS(4463),
    [sym_asserterror_keyword] = ACTIONS(4465),
    [sym_page_keyword] = ACTIONS(4463),
    [anon_sym_codeunit] = ACTIONS(4463),
    [anon_sym_CODEUNIT] = ACTIONS(4463),
    [anon_sym_Codeunit] = ACTIONS(4463),
    [anon_sym_CodeUnit] = ACTIONS(4463),
    [anon_sym_COdeunit] = ACTIONS(4463),
    [anon_sym_codeUnit] = ACTIONS(4463),
    [sym_report_keyword] = ACTIONS(4463),
    [sym_query_keyword] = ACTIONS(4463),
    [anon_sym_xmlport] = ACTIONS(4463),
    [anon_sym_XMLPORT] = ACTIONS(4463),
    [anon_sym_Xmlport] = ACTIONS(4463),
    [anon_sym_XMLport] = ACTIONS(4463),
    [anon_sym_XMLPort] = ACTIONS(4463),
    [anon_sym_XmlPort] = ACTIONS(4463),
    [anon_sym_enum] = ACTIONS(4463),
    [anon_sym_ENUM] = ACTIONS(4463),
    [anon_sym_Enum] = ACTIONS(4463),
    [anon_sym_eNUM] = ACTIONS(4463),
    [anon_sym_eNum] = ACTIONS(4463),
    [anon_sym_ENum] = ACTIONS(4463),
    [sym_quoted_identifier] = ACTIONS(4465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4465),
    [sym_integer] = ACTIONS(4463),
    [sym_continue_as_identifier] = ACTIONS(4465),
    [sym_preproc_open] = ACTIONS(4465),
    [sym_preproc_close] = ACTIONS(4465),
    [sym_preproc_split_end] = ACTIONS(4465),
  },
  [STATE(1773)] = {
    [sym_identifier] = ACTIONS(4559),
    [anon_sym_SEMI] = ACTIONS(4561),
    [anon_sym_DASH] = ACTIONS(4561),
    [aux_sym_boolean_token1] = ACTIONS(4559),
    [aux_sym_boolean_token2] = ACTIONS(4559),
    [sym_decimal] = ACTIONS(4559),
    [anon_sym_LPAREN] = ACTIONS(4561),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4559),
    [anon_sym_LBRACK] = ACTIONS(4561),
    [aux_sym_record_type_token1] = ACTIONS(4559),
    [aux_sym_basic_type_token21] = ACTIONS(4559),
    [aux_sym_basic_type_token22] = ACTIONS(4559),
    [aux_sym_basic_type_token48] = ACTIONS(4559),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4559),
    [anon_sym_POUNDif] = ACTIONS(4561),
    [anon_sym_POUNDIF] = ACTIONS(4561),
    [anon_sym_POUNDIf] = ACTIONS(4561),
    [anon_sym_not] = ACTIONS(4559),
    [anon_sym_NOT] = ACTIONS(4559),
    [anon_sym_Not] = ACTIONS(4559),
    [anon_sym_POUNDelse] = ACTIONS(4561),
    [anon_sym_POUNDELSE] = ACTIONS(4561),
    [anon_sym_POUNDElse] = ACTIONS(4561),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4559),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4559),
    [anon_sym_PLUS] = ACTIONS(4561),
    [sym_datetime_literal] = ACTIONS(4561),
    [sym_date_literal] = ACTIONS(4559),
    [sym_time_literal] = ACTIONS(4559),
    [sym_biginteger_literal] = ACTIONS(4561),
    [anon_sym_if] = ACTIONS(4559),
    [anon_sym_IF] = ACTIONS(4559),
    [anon_sym_If] = ACTIONS(4559),
    [anon_sym_else] = ACTIONS(4559),
    [anon_sym_ELSE] = ACTIONS(4559),
    [anon_sym_Else] = ACTIONS(4559),
    [anon_sym_case] = ACTIONS(4559),
    [anon_sym_CASE] = ACTIONS(4559),
    [anon_sym_Case] = ACTIONS(4559),
    [anon_sym_for] = ACTIONS(4559),
    [anon_sym_FOR] = ACTIONS(4559),
    [anon_sym_For] = ACTIONS(4559),
    [anon_sym_foreach] = ACTIONS(4559),
    [anon_sym_FOREACH] = ACTIONS(4559),
    [anon_sym_Foreach] = ACTIONS(4559),
    [anon_sym_while] = ACTIONS(4559),
    [anon_sym_WHILE] = ACTIONS(4559),
    [anon_sym_While] = ACTIONS(4559),
    [anon_sym_repeat] = ACTIONS(4559),
    [anon_sym_REPEAT] = ACTIONS(4559),
    [anon_sym_Repeat] = ACTIONS(4559),
    [anon_sym_until] = ACTIONS(4559),
    [anon_sym_UNTIL] = ACTIONS(4559),
    [anon_sym_Until] = ACTIONS(4559),
    [anon_sym_exit] = ACTIONS(4559),
    [anon_sym_EXIT] = ACTIONS(4559),
    [anon_sym_Exit] = ACTIONS(4559),
    [anon_sym_continue] = ACTIONS(4559),
    [anon_sym_CONTINUE] = ACTIONS(4559),
    [anon_sym_Continue] = ACTIONS(4559),
    [anon_sym_break] = ACTIONS(4559),
    [anon_sym_BREAK] = ACTIONS(4559),
    [anon_sym_Break] = ACTIONS(4559),
    [anon_sym_with] = ACTIONS(4559),
    [anon_sym_WITH] = ACTIONS(4559),
    [anon_sym_With] = ACTIONS(4559),
    [sym_asserterror_keyword] = ACTIONS(4561),
    [sym_page_keyword] = ACTIONS(4559),
    [anon_sym_codeunit] = ACTIONS(4559),
    [anon_sym_CODEUNIT] = ACTIONS(4559),
    [anon_sym_Codeunit] = ACTIONS(4559),
    [anon_sym_CodeUnit] = ACTIONS(4559),
    [anon_sym_COdeunit] = ACTIONS(4559),
    [anon_sym_codeUnit] = ACTIONS(4559),
    [sym_report_keyword] = ACTIONS(4559),
    [sym_query_keyword] = ACTIONS(4559),
    [anon_sym_xmlport] = ACTIONS(4559),
    [anon_sym_XMLPORT] = ACTIONS(4559),
    [anon_sym_Xmlport] = ACTIONS(4559),
    [anon_sym_XMLport] = ACTIONS(4559),
    [anon_sym_XMLPort] = ACTIONS(4559),
    [anon_sym_XmlPort] = ACTIONS(4559),
    [anon_sym_enum] = ACTIONS(4559),
    [anon_sym_ENUM] = ACTIONS(4559),
    [anon_sym_Enum] = ACTIONS(4559),
    [anon_sym_eNUM] = ACTIONS(4559),
    [anon_sym_eNum] = ACTIONS(4559),
    [anon_sym_ENum] = ACTIONS(4559),
    [sym_quoted_identifier] = ACTIONS(4561),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4561),
    [sym_integer] = ACTIONS(4559),
    [sym_continue_as_identifier] = ACTIONS(4561),
    [sym_preproc_open] = ACTIONS(4561),
  },
  [STATE(1774)] = {
    [sym_identifier] = ACTIONS(4728),
    [anon_sym_SEMI] = ACTIONS(4730),
    [anon_sym_DASH] = ACTIONS(4730),
    [aux_sym_boolean_token1] = ACTIONS(4728),
    [aux_sym_boolean_token2] = ACTIONS(4728),
    [sym_decimal] = ACTIONS(4728),
    [anon_sym_LPAREN] = ACTIONS(4730),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4728),
    [anon_sym_LBRACK] = ACTIONS(4730),
    [aux_sym_record_type_token1] = ACTIONS(4728),
    [aux_sym_basic_type_token21] = ACTIONS(4728),
    [aux_sym_basic_type_token22] = ACTIONS(4728),
    [aux_sym_basic_type_token48] = ACTIONS(4728),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4728),
    [anon_sym_POUNDif] = ACTIONS(4730),
    [anon_sym_POUNDIF] = ACTIONS(4730),
    [anon_sym_POUNDIf] = ACTIONS(4730),
    [anon_sym_not] = ACTIONS(4728),
    [anon_sym_NOT] = ACTIONS(4728),
    [anon_sym_Not] = ACTIONS(4728),
    [anon_sym_POUNDelse] = ACTIONS(4730),
    [anon_sym_POUNDELSE] = ACTIONS(4730),
    [anon_sym_POUNDElse] = ACTIONS(4730),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4728),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4728),
    [anon_sym_PLUS] = ACTIONS(4730),
    [sym_datetime_literal] = ACTIONS(4730),
    [sym_date_literal] = ACTIONS(4728),
    [sym_time_literal] = ACTIONS(4728),
    [sym_biginteger_literal] = ACTIONS(4730),
    [anon_sym_if] = ACTIONS(4728),
    [anon_sym_IF] = ACTIONS(4728),
    [anon_sym_If] = ACTIONS(4728),
    [anon_sym_else] = ACTIONS(4728),
    [anon_sym_ELSE] = ACTIONS(4728),
    [anon_sym_Else] = ACTIONS(4728),
    [anon_sym_case] = ACTIONS(4728),
    [anon_sym_CASE] = ACTIONS(4728),
    [anon_sym_Case] = ACTIONS(4728),
    [anon_sym_for] = ACTIONS(4728),
    [anon_sym_FOR] = ACTIONS(4728),
    [anon_sym_For] = ACTIONS(4728),
    [anon_sym_foreach] = ACTIONS(4728),
    [anon_sym_FOREACH] = ACTIONS(4728),
    [anon_sym_Foreach] = ACTIONS(4728),
    [anon_sym_while] = ACTIONS(4728),
    [anon_sym_WHILE] = ACTIONS(4728),
    [anon_sym_While] = ACTIONS(4728),
    [anon_sym_repeat] = ACTIONS(4728),
    [anon_sym_REPEAT] = ACTIONS(4728),
    [anon_sym_Repeat] = ACTIONS(4728),
    [anon_sym_until] = ACTIONS(4728),
    [anon_sym_UNTIL] = ACTIONS(4728),
    [anon_sym_Until] = ACTIONS(4728),
    [anon_sym_exit] = ACTIONS(4728),
    [anon_sym_EXIT] = ACTIONS(4728),
    [anon_sym_Exit] = ACTIONS(4728),
    [anon_sym_continue] = ACTIONS(4728),
    [anon_sym_CONTINUE] = ACTIONS(4728),
    [anon_sym_Continue] = ACTIONS(4728),
    [anon_sym_break] = ACTIONS(4728),
    [anon_sym_BREAK] = ACTIONS(4728),
    [anon_sym_Break] = ACTIONS(4728),
    [anon_sym_with] = ACTIONS(4728),
    [anon_sym_WITH] = ACTIONS(4728),
    [anon_sym_With] = ACTIONS(4728),
    [sym_asserterror_keyword] = ACTIONS(4730),
    [sym_page_keyword] = ACTIONS(4728),
    [anon_sym_codeunit] = ACTIONS(4728),
    [anon_sym_CODEUNIT] = ACTIONS(4728),
    [anon_sym_Codeunit] = ACTIONS(4728),
    [anon_sym_CodeUnit] = ACTIONS(4728),
    [anon_sym_COdeunit] = ACTIONS(4728),
    [anon_sym_codeUnit] = ACTIONS(4728),
    [sym_report_keyword] = ACTIONS(4728),
    [sym_query_keyword] = ACTIONS(4728),
    [anon_sym_xmlport] = ACTIONS(4728),
    [anon_sym_XMLPORT] = ACTIONS(4728),
    [anon_sym_Xmlport] = ACTIONS(4728),
    [anon_sym_XMLport] = ACTIONS(4728),
    [anon_sym_XMLPort] = ACTIONS(4728),
    [anon_sym_XmlPort] = ACTIONS(4728),
    [anon_sym_enum] = ACTIONS(4728),
    [anon_sym_ENUM] = ACTIONS(4728),
    [anon_sym_Enum] = ACTIONS(4728),
    [anon_sym_eNUM] = ACTIONS(4728),
    [anon_sym_eNum] = ACTIONS(4728),
    [anon_sym_ENum] = ACTIONS(4728),
    [sym_quoted_identifier] = ACTIONS(4730),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4730),
    [sym_integer] = ACTIONS(4728),
    [sym_continue_as_identifier] = ACTIONS(4730),
    [sym_preproc_open] = ACTIONS(4730),
  },
  [STATE(1775)] = {
    [sym_identifier] = ACTIONS(4732),
    [anon_sym_SEMI] = ACTIONS(4734),
    [anon_sym_DASH] = ACTIONS(4734),
    [aux_sym_boolean_token1] = ACTIONS(4732),
    [aux_sym_boolean_token2] = ACTIONS(4732),
    [sym_decimal] = ACTIONS(4732),
    [anon_sym_LPAREN] = ACTIONS(4734),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4732),
    [anon_sym_LBRACK] = ACTIONS(4734),
    [aux_sym_record_type_token1] = ACTIONS(4732),
    [aux_sym_basic_type_token21] = ACTIONS(4732),
    [aux_sym_basic_type_token22] = ACTIONS(4732),
    [aux_sym_basic_type_token48] = ACTIONS(4732),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4732),
    [anon_sym_POUNDif] = ACTIONS(4734),
    [anon_sym_POUNDIF] = ACTIONS(4734),
    [anon_sym_POUNDIf] = ACTIONS(4734),
    [anon_sym_not] = ACTIONS(4732),
    [anon_sym_NOT] = ACTIONS(4732),
    [anon_sym_Not] = ACTIONS(4732),
    [anon_sym_POUNDelse] = ACTIONS(4734),
    [anon_sym_POUNDELSE] = ACTIONS(4734),
    [anon_sym_POUNDElse] = ACTIONS(4734),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4732),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4732),
    [anon_sym_PLUS] = ACTIONS(4734),
    [sym_datetime_literal] = ACTIONS(4734),
    [sym_date_literal] = ACTIONS(4732),
    [sym_time_literal] = ACTIONS(4732),
    [sym_biginteger_literal] = ACTIONS(4734),
    [anon_sym_if] = ACTIONS(4732),
    [anon_sym_IF] = ACTIONS(4732),
    [anon_sym_If] = ACTIONS(4732),
    [anon_sym_else] = ACTIONS(4732),
    [anon_sym_ELSE] = ACTIONS(4732),
    [anon_sym_Else] = ACTIONS(4732),
    [anon_sym_case] = ACTIONS(4732),
    [anon_sym_CASE] = ACTIONS(4732),
    [anon_sym_Case] = ACTIONS(4732),
    [anon_sym_for] = ACTIONS(4732),
    [anon_sym_FOR] = ACTIONS(4732),
    [anon_sym_For] = ACTIONS(4732),
    [anon_sym_foreach] = ACTIONS(4732),
    [anon_sym_FOREACH] = ACTIONS(4732),
    [anon_sym_Foreach] = ACTIONS(4732),
    [anon_sym_while] = ACTIONS(4732),
    [anon_sym_WHILE] = ACTIONS(4732),
    [anon_sym_While] = ACTIONS(4732),
    [anon_sym_repeat] = ACTIONS(4732),
    [anon_sym_REPEAT] = ACTIONS(4732),
    [anon_sym_Repeat] = ACTIONS(4732),
    [anon_sym_until] = ACTIONS(4732),
    [anon_sym_UNTIL] = ACTIONS(4732),
    [anon_sym_Until] = ACTIONS(4732),
    [anon_sym_exit] = ACTIONS(4732),
    [anon_sym_EXIT] = ACTIONS(4732),
    [anon_sym_Exit] = ACTIONS(4732),
    [anon_sym_continue] = ACTIONS(4732),
    [anon_sym_CONTINUE] = ACTIONS(4732),
    [anon_sym_Continue] = ACTIONS(4732),
    [anon_sym_break] = ACTIONS(4732),
    [anon_sym_BREAK] = ACTIONS(4732),
    [anon_sym_Break] = ACTIONS(4732),
    [anon_sym_with] = ACTIONS(4732),
    [anon_sym_WITH] = ACTIONS(4732),
    [anon_sym_With] = ACTIONS(4732),
    [sym_asserterror_keyword] = ACTIONS(4734),
    [sym_page_keyword] = ACTIONS(4732),
    [anon_sym_codeunit] = ACTIONS(4732),
    [anon_sym_CODEUNIT] = ACTIONS(4732),
    [anon_sym_Codeunit] = ACTIONS(4732),
    [anon_sym_CodeUnit] = ACTIONS(4732),
    [anon_sym_COdeunit] = ACTIONS(4732),
    [anon_sym_codeUnit] = ACTIONS(4732),
    [sym_report_keyword] = ACTIONS(4732),
    [sym_query_keyword] = ACTIONS(4732),
    [anon_sym_xmlport] = ACTIONS(4732),
    [anon_sym_XMLPORT] = ACTIONS(4732),
    [anon_sym_Xmlport] = ACTIONS(4732),
    [anon_sym_XMLport] = ACTIONS(4732),
    [anon_sym_XMLPort] = ACTIONS(4732),
    [anon_sym_XmlPort] = ACTIONS(4732),
    [anon_sym_enum] = ACTIONS(4732),
    [anon_sym_ENUM] = ACTIONS(4732),
    [anon_sym_Enum] = ACTIONS(4732),
    [anon_sym_eNUM] = ACTIONS(4732),
    [anon_sym_eNum] = ACTIONS(4732),
    [anon_sym_ENum] = ACTIONS(4732),
    [sym_quoted_identifier] = ACTIONS(4734),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4734),
    [sym_integer] = ACTIONS(4732),
    [sym_continue_as_identifier] = ACTIONS(4734),
    [sym_preproc_open] = ACTIONS(4734),
  },
  [STATE(1776)] = {
    [sym_identifier] = ACTIONS(4728),
    [anon_sym_SEMI] = ACTIONS(4730),
    [anon_sym_DASH] = ACTIONS(4730),
    [aux_sym_boolean_token1] = ACTIONS(4728),
    [aux_sym_boolean_token2] = ACTIONS(4728),
    [sym_decimal] = ACTIONS(4728),
    [anon_sym_LPAREN] = ACTIONS(4730),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4728),
    [anon_sym_LBRACK] = ACTIONS(4730),
    [aux_sym_record_type_token1] = ACTIONS(4728),
    [aux_sym_basic_type_token21] = ACTIONS(4728),
    [aux_sym_basic_type_token22] = ACTIONS(4728),
    [aux_sym_basic_type_token48] = ACTIONS(4728),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4728),
    [anon_sym_POUNDif] = ACTIONS(4730),
    [anon_sym_POUNDIF] = ACTIONS(4730),
    [anon_sym_POUNDIf] = ACTIONS(4730),
    [anon_sym_not] = ACTIONS(4728),
    [anon_sym_NOT] = ACTIONS(4728),
    [anon_sym_Not] = ACTIONS(4728),
    [anon_sym_POUNDelse] = ACTIONS(4730),
    [anon_sym_POUNDELSE] = ACTIONS(4730),
    [anon_sym_POUNDElse] = ACTIONS(4730),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4728),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4728),
    [anon_sym_PLUS] = ACTIONS(4730),
    [sym_datetime_literal] = ACTIONS(4730),
    [sym_date_literal] = ACTIONS(4728),
    [sym_time_literal] = ACTIONS(4728),
    [sym_biginteger_literal] = ACTIONS(4730),
    [anon_sym_if] = ACTIONS(4728),
    [anon_sym_IF] = ACTIONS(4728),
    [anon_sym_If] = ACTIONS(4728),
    [anon_sym_else] = ACTIONS(4728),
    [anon_sym_ELSE] = ACTIONS(4728),
    [anon_sym_Else] = ACTIONS(4728),
    [anon_sym_case] = ACTIONS(4728),
    [anon_sym_CASE] = ACTIONS(4728),
    [anon_sym_Case] = ACTIONS(4728),
    [anon_sym_for] = ACTIONS(4728),
    [anon_sym_FOR] = ACTIONS(4728),
    [anon_sym_For] = ACTIONS(4728),
    [anon_sym_foreach] = ACTIONS(4728),
    [anon_sym_FOREACH] = ACTIONS(4728),
    [anon_sym_Foreach] = ACTIONS(4728),
    [anon_sym_while] = ACTIONS(4728),
    [anon_sym_WHILE] = ACTIONS(4728),
    [anon_sym_While] = ACTIONS(4728),
    [anon_sym_repeat] = ACTIONS(4728),
    [anon_sym_REPEAT] = ACTIONS(4728),
    [anon_sym_Repeat] = ACTIONS(4728),
    [anon_sym_until] = ACTIONS(4728),
    [anon_sym_UNTIL] = ACTIONS(4728),
    [anon_sym_Until] = ACTIONS(4728),
    [anon_sym_exit] = ACTIONS(4728),
    [anon_sym_EXIT] = ACTIONS(4728),
    [anon_sym_Exit] = ACTIONS(4728),
    [anon_sym_continue] = ACTIONS(4728),
    [anon_sym_CONTINUE] = ACTIONS(4728),
    [anon_sym_Continue] = ACTIONS(4728),
    [anon_sym_break] = ACTIONS(4728),
    [anon_sym_BREAK] = ACTIONS(4728),
    [anon_sym_Break] = ACTIONS(4728),
    [anon_sym_with] = ACTIONS(4728),
    [anon_sym_WITH] = ACTIONS(4728),
    [anon_sym_With] = ACTIONS(4728),
    [sym_asserterror_keyword] = ACTIONS(4730),
    [sym_page_keyword] = ACTIONS(4728),
    [anon_sym_codeunit] = ACTIONS(4728),
    [anon_sym_CODEUNIT] = ACTIONS(4728),
    [anon_sym_Codeunit] = ACTIONS(4728),
    [anon_sym_CodeUnit] = ACTIONS(4728),
    [anon_sym_COdeunit] = ACTIONS(4728),
    [anon_sym_codeUnit] = ACTIONS(4728),
    [sym_report_keyword] = ACTIONS(4728),
    [sym_query_keyword] = ACTIONS(4728),
    [anon_sym_xmlport] = ACTIONS(4728),
    [anon_sym_XMLPORT] = ACTIONS(4728),
    [anon_sym_Xmlport] = ACTIONS(4728),
    [anon_sym_XMLport] = ACTIONS(4728),
    [anon_sym_XMLPort] = ACTIONS(4728),
    [anon_sym_XmlPort] = ACTIONS(4728),
    [anon_sym_enum] = ACTIONS(4728),
    [anon_sym_ENUM] = ACTIONS(4728),
    [anon_sym_Enum] = ACTIONS(4728),
    [anon_sym_eNUM] = ACTIONS(4728),
    [anon_sym_eNum] = ACTIONS(4728),
    [anon_sym_ENum] = ACTIONS(4728),
    [sym_quoted_identifier] = ACTIONS(4730),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4730),
    [sym_integer] = ACTIONS(4728),
    [sym_continue_as_identifier] = ACTIONS(4730),
    [sym_preproc_open] = ACTIONS(4730),
  },
  [STATE(1777)] = {
    [sym_identifier] = ACTIONS(4736),
    [anon_sym_SEMI] = ACTIONS(4738),
    [anon_sym_DASH] = ACTIONS(4738),
    [aux_sym_boolean_token1] = ACTIONS(4736),
    [aux_sym_boolean_token2] = ACTIONS(4736),
    [sym_decimal] = ACTIONS(4736),
    [anon_sym_LPAREN] = ACTIONS(4738),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4736),
    [anon_sym_LBRACK] = ACTIONS(4738),
    [aux_sym_record_type_token1] = ACTIONS(4736),
    [aux_sym_basic_type_token21] = ACTIONS(4736),
    [aux_sym_basic_type_token22] = ACTIONS(4736),
    [aux_sym_basic_type_token48] = ACTIONS(4736),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4736),
    [anon_sym_POUNDif] = ACTIONS(4738),
    [anon_sym_POUNDIF] = ACTIONS(4738),
    [anon_sym_POUNDIf] = ACTIONS(4738),
    [anon_sym_not] = ACTIONS(4736),
    [anon_sym_NOT] = ACTIONS(4736),
    [anon_sym_Not] = ACTIONS(4736),
    [anon_sym_POUNDelse] = ACTIONS(4738),
    [anon_sym_POUNDELSE] = ACTIONS(4738),
    [anon_sym_POUNDElse] = ACTIONS(4738),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4736),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4736),
    [anon_sym_PLUS] = ACTIONS(4738),
    [sym_datetime_literal] = ACTIONS(4738),
    [sym_date_literal] = ACTIONS(4736),
    [sym_time_literal] = ACTIONS(4736),
    [sym_biginteger_literal] = ACTIONS(4738),
    [anon_sym_if] = ACTIONS(4736),
    [anon_sym_IF] = ACTIONS(4736),
    [anon_sym_If] = ACTIONS(4736),
    [anon_sym_else] = ACTIONS(4736),
    [anon_sym_ELSE] = ACTIONS(4736),
    [anon_sym_Else] = ACTIONS(4736),
    [anon_sym_case] = ACTIONS(4736),
    [anon_sym_CASE] = ACTIONS(4736),
    [anon_sym_Case] = ACTIONS(4736),
    [anon_sym_for] = ACTIONS(4736),
    [anon_sym_FOR] = ACTIONS(4736),
    [anon_sym_For] = ACTIONS(4736),
    [anon_sym_foreach] = ACTIONS(4736),
    [anon_sym_FOREACH] = ACTIONS(4736),
    [anon_sym_Foreach] = ACTIONS(4736),
    [anon_sym_while] = ACTIONS(4736),
    [anon_sym_WHILE] = ACTIONS(4736),
    [anon_sym_While] = ACTIONS(4736),
    [anon_sym_repeat] = ACTIONS(4736),
    [anon_sym_REPEAT] = ACTIONS(4736),
    [anon_sym_Repeat] = ACTIONS(4736),
    [anon_sym_until] = ACTIONS(4736),
    [anon_sym_UNTIL] = ACTIONS(4736),
    [anon_sym_Until] = ACTIONS(4736),
    [anon_sym_exit] = ACTIONS(4736),
    [anon_sym_EXIT] = ACTIONS(4736),
    [anon_sym_Exit] = ACTIONS(4736),
    [anon_sym_continue] = ACTIONS(4736),
    [anon_sym_CONTINUE] = ACTIONS(4736),
    [anon_sym_Continue] = ACTIONS(4736),
    [anon_sym_break] = ACTIONS(4736),
    [anon_sym_BREAK] = ACTIONS(4736),
    [anon_sym_Break] = ACTIONS(4736),
    [anon_sym_with] = ACTIONS(4736),
    [anon_sym_WITH] = ACTIONS(4736),
    [anon_sym_With] = ACTIONS(4736),
    [sym_asserterror_keyword] = ACTIONS(4738),
    [sym_page_keyword] = ACTIONS(4736),
    [anon_sym_codeunit] = ACTIONS(4736),
    [anon_sym_CODEUNIT] = ACTIONS(4736),
    [anon_sym_Codeunit] = ACTIONS(4736),
    [anon_sym_CodeUnit] = ACTIONS(4736),
    [anon_sym_COdeunit] = ACTIONS(4736),
    [anon_sym_codeUnit] = ACTIONS(4736),
    [sym_report_keyword] = ACTIONS(4736),
    [sym_query_keyword] = ACTIONS(4736),
    [anon_sym_xmlport] = ACTIONS(4736),
    [anon_sym_XMLPORT] = ACTIONS(4736),
    [anon_sym_Xmlport] = ACTIONS(4736),
    [anon_sym_XMLport] = ACTIONS(4736),
    [anon_sym_XMLPort] = ACTIONS(4736),
    [anon_sym_XmlPort] = ACTIONS(4736),
    [anon_sym_enum] = ACTIONS(4736),
    [anon_sym_ENUM] = ACTIONS(4736),
    [anon_sym_Enum] = ACTIONS(4736),
    [anon_sym_eNUM] = ACTIONS(4736),
    [anon_sym_eNum] = ACTIONS(4736),
    [anon_sym_ENum] = ACTIONS(4736),
    [sym_quoted_identifier] = ACTIONS(4738),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4738),
    [sym_integer] = ACTIONS(4736),
    [sym_continue_as_identifier] = ACTIONS(4738),
    [sym_preproc_open] = ACTIONS(4738),
  },
  [STATE(1778)] = {
    [sym_identifier] = ACTIONS(4740),
    [anon_sym_SEMI] = ACTIONS(4742),
    [anon_sym_DASH] = ACTIONS(4742),
    [aux_sym_boolean_token1] = ACTIONS(4740),
    [aux_sym_boolean_token2] = ACTIONS(4740),
    [sym_decimal] = ACTIONS(4740),
    [anon_sym_LPAREN] = ACTIONS(4742),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4740),
    [anon_sym_LBRACK] = ACTIONS(4742),
    [aux_sym_record_type_token1] = ACTIONS(4740),
    [aux_sym_basic_type_token21] = ACTIONS(4740),
    [aux_sym_basic_type_token22] = ACTIONS(4740),
    [aux_sym_basic_type_token48] = ACTIONS(4740),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4740),
    [anon_sym_POUNDif] = ACTIONS(4742),
    [anon_sym_POUNDIF] = ACTIONS(4742),
    [anon_sym_POUNDIf] = ACTIONS(4742),
    [anon_sym_not] = ACTIONS(4740),
    [anon_sym_NOT] = ACTIONS(4740),
    [anon_sym_Not] = ACTIONS(4740),
    [anon_sym_POUNDelse] = ACTIONS(4742),
    [anon_sym_POUNDELSE] = ACTIONS(4742),
    [anon_sym_POUNDElse] = ACTIONS(4742),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4740),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4740),
    [anon_sym_PLUS] = ACTIONS(4742),
    [sym_datetime_literal] = ACTIONS(4742),
    [sym_date_literal] = ACTIONS(4740),
    [sym_time_literal] = ACTIONS(4740),
    [sym_biginteger_literal] = ACTIONS(4742),
    [anon_sym_if] = ACTIONS(4740),
    [anon_sym_IF] = ACTIONS(4740),
    [anon_sym_If] = ACTIONS(4740),
    [anon_sym_else] = ACTIONS(4740),
    [anon_sym_ELSE] = ACTIONS(4740),
    [anon_sym_Else] = ACTIONS(4740),
    [anon_sym_case] = ACTIONS(4740),
    [anon_sym_CASE] = ACTIONS(4740),
    [anon_sym_Case] = ACTIONS(4740),
    [anon_sym_for] = ACTIONS(4740),
    [anon_sym_FOR] = ACTIONS(4740),
    [anon_sym_For] = ACTIONS(4740),
    [anon_sym_foreach] = ACTIONS(4740),
    [anon_sym_FOREACH] = ACTIONS(4740),
    [anon_sym_Foreach] = ACTIONS(4740),
    [anon_sym_while] = ACTIONS(4740),
    [anon_sym_WHILE] = ACTIONS(4740),
    [anon_sym_While] = ACTIONS(4740),
    [anon_sym_repeat] = ACTIONS(4740),
    [anon_sym_REPEAT] = ACTIONS(4740),
    [anon_sym_Repeat] = ACTIONS(4740),
    [anon_sym_until] = ACTIONS(4740),
    [anon_sym_UNTIL] = ACTIONS(4740),
    [anon_sym_Until] = ACTIONS(4740),
    [anon_sym_exit] = ACTIONS(4740),
    [anon_sym_EXIT] = ACTIONS(4740),
    [anon_sym_Exit] = ACTIONS(4740),
    [anon_sym_continue] = ACTIONS(4740),
    [anon_sym_CONTINUE] = ACTIONS(4740),
    [anon_sym_Continue] = ACTIONS(4740),
    [anon_sym_break] = ACTIONS(4740),
    [anon_sym_BREAK] = ACTIONS(4740),
    [anon_sym_Break] = ACTIONS(4740),
    [anon_sym_with] = ACTIONS(4740),
    [anon_sym_WITH] = ACTIONS(4740),
    [anon_sym_With] = ACTIONS(4740),
    [sym_asserterror_keyword] = ACTIONS(4742),
    [sym_page_keyword] = ACTIONS(4740),
    [anon_sym_codeunit] = ACTIONS(4740),
    [anon_sym_CODEUNIT] = ACTIONS(4740),
    [anon_sym_Codeunit] = ACTIONS(4740),
    [anon_sym_CodeUnit] = ACTIONS(4740),
    [anon_sym_COdeunit] = ACTIONS(4740),
    [anon_sym_codeUnit] = ACTIONS(4740),
    [sym_report_keyword] = ACTIONS(4740),
    [sym_query_keyword] = ACTIONS(4740),
    [anon_sym_xmlport] = ACTIONS(4740),
    [anon_sym_XMLPORT] = ACTIONS(4740),
    [anon_sym_Xmlport] = ACTIONS(4740),
    [anon_sym_XMLport] = ACTIONS(4740),
    [anon_sym_XMLPort] = ACTIONS(4740),
    [anon_sym_XmlPort] = ACTIONS(4740),
    [anon_sym_enum] = ACTIONS(4740),
    [anon_sym_ENUM] = ACTIONS(4740),
    [anon_sym_Enum] = ACTIONS(4740),
    [anon_sym_eNUM] = ACTIONS(4740),
    [anon_sym_eNum] = ACTIONS(4740),
    [anon_sym_ENum] = ACTIONS(4740),
    [sym_quoted_identifier] = ACTIONS(4742),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4742),
    [sym_integer] = ACTIONS(4740),
    [sym_continue_as_identifier] = ACTIONS(4742),
    [sym_preproc_open] = ACTIONS(4742),
  },
  [STATE(1779)] = {
    [sym_identifier] = ACTIONS(4744),
    [anon_sym_SEMI] = ACTIONS(4746),
    [anon_sym_DASH] = ACTIONS(4746),
    [aux_sym_boolean_token1] = ACTIONS(4744),
    [aux_sym_boolean_token2] = ACTIONS(4744),
    [sym_decimal] = ACTIONS(4744),
    [anon_sym_LPAREN] = ACTIONS(4746),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4744),
    [anon_sym_LBRACK] = ACTIONS(4746),
    [aux_sym_record_type_token1] = ACTIONS(4744),
    [aux_sym_basic_type_token21] = ACTIONS(4744),
    [aux_sym_basic_type_token22] = ACTIONS(4744),
    [aux_sym_basic_type_token48] = ACTIONS(4744),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4744),
    [anon_sym_POUNDif] = ACTIONS(4746),
    [anon_sym_POUNDIF] = ACTIONS(4746),
    [anon_sym_POUNDIf] = ACTIONS(4746),
    [anon_sym_not] = ACTIONS(4744),
    [anon_sym_NOT] = ACTIONS(4744),
    [anon_sym_Not] = ACTIONS(4744),
    [anon_sym_POUNDelse] = ACTIONS(4746),
    [anon_sym_POUNDELSE] = ACTIONS(4746),
    [anon_sym_POUNDElse] = ACTIONS(4746),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4744),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4744),
    [anon_sym_PLUS] = ACTIONS(4746),
    [sym_datetime_literal] = ACTIONS(4746),
    [sym_date_literal] = ACTIONS(4744),
    [sym_time_literal] = ACTIONS(4744),
    [sym_biginteger_literal] = ACTIONS(4746),
    [anon_sym_if] = ACTIONS(4744),
    [anon_sym_IF] = ACTIONS(4744),
    [anon_sym_If] = ACTIONS(4744),
    [anon_sym_else] = ACTIONS(4744),
    [anon_sym_ELSE] = ACTIONS(4744),
    [anon_sym_Else] = ACTIONS(4744),
    [anon_sym_case] = ACTIONS(4744),
    [anon_sym_CASE] = ACTIONS(4744),
    [anon_sym_Case] = ACTIONS(4744),
    [anon_sym_for] = ACTIONS(4744),
    [anon_sym_FOR] = ACTIONS(4744),
    [anon_sym_For] = ACTIONS(4744),
    [anon_sym_foreach] = ACTIONS(4744),
    [anon_sym_FOREACH] = ACTIONS(4744),
    [anon_sym_Foreach] = ACTIONS(4744),
    [anon_sym_while] = ACTIONS(4744),
    [anon_sym_WHILE] = ACTIONS(4744),
    [anon_sym_While] = ACTIONS(4744),
    [anon_sym_repeat] = ACTIONS(4744),
    [anon_sym_REPEAT] = ACTIONS(4744),
    [anon_sym_Repeat] = ACTIONS(4744),
    [anon_sym_until] = ACTIONS(4744),
    [anon_sym_UNTIL] = ACTIONS(4744),
    [anon_sym_Until] = ACTIONS(4744),
    [anon_sym_exit] = ACTIONS(4744),
    [anon_sym_EXIT] = ACTIONS(4744),
    [anon_sym_Exit] = ACTIONS(4744),
    [anon_sym_continue] = ACTIONS(4744),
    [anon_sym_CONTINUE] = ACTIONS(4744),
    [anon_sym_Continue] = ACTIONS(4744),
    [anon_sym_break] = ACTIONS(4744),
    [anon_sym_BREAK] = ACTIONS(4744),
    [anon_sym_Break] = ACTIONS(4744),
    [anon_sym_with] = ACTIONS(4744),
    [anon_sym_WITH] = ACTIONS(4744),
    [anon_sym_With] = ACTIONS(4744),
    [sym_asserterror_keyword] = ACTIONS(4746),
    [sym_page_keyword] = ACTIONS(4744),
    [anon_sym_codeunit] = ACTIONS(4744),
    [anon_sym_CODEUNIT] = ACTIONS(4744),
    [anon_sym_Codeunit] = ACTIONS(4744),
    [anon_sym_CodeUnit] = ACTIONS(4744),
    [anon_sym_COdeunit] = ACTIONS(4744),
    [anon_sym_codeUnit] = ACTIONS(4744),
    [sym_report_keyword] = ACTIONS(4744),
    [sym_query_keyword] = ACTIONS(4744),
    [anon_sym_xmlport] = ACTIONS(4744),
    [anon_sym_XMLPORT] = ACTIONS(4744),
    [anon_sym_Xmlport] = ACTIONS(4744),
    [anon_sym_XMLport] = ACTIONS(4744),
    [anon_sym_XMLPort] = ACTIONS(4744),
    [anon_sym_XmlPort] = ACTIONS(4744),
    [anon_sym_enum] = ACTIONS(4744),
    [anon_sym_ENUM] = ACTIONS(4744),
    [anon_sym_Enum] = ACTIONS(4744),
    [anon_sym_eNUM] = ACTIONS(4744),
    [anon_sym_eNum] = ACTIONS(4744),
    [anon_sym_ENum] = ACTIONS(4744),
    [sym_quoted_identifier] = ACTIONS(4746),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4746),
    [sym_integer] = ACTIONS(4744),
    [sym_continue_as_identifier] = ACTIONS(4746),
    [sym_preproc_open] = ACTIONS(4746),
  },
  [STATE(1780)] = {
    [sym_identifier] = ACTIONS(4696),
    [anon_sym_SEMI] = ACTIONS(4698),
    [anon_sym_DASH] = ACTIONS(4698),
    [aux_sym_boolean_token1] = ACTIONS(4696),
    [aux_sym_boolean_token2] = ACTIONS(4696),
    [sym_decimal] = ACTIONS(4696),
    [anon_sym_LPAREN] = ACTIONS(4698),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4696),
    [anon_sym_LBRACK] = ACTIONS(4698),
    [aux_sym_record_type_token1] = ACTIONS(4696),
    [aux_sym_basic_type_token21] = ACTIONS(4696),
    [aux_sym_basic_type_token22] = ACTIONS(4696),
    [aux_sym_basic_type_token48] = ACTIONS(4696),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4696),
    [anon_sym_POUNDif] = ACTIONS(4698),
    [anon_sym_POUNDIF] = ACTIONS(4698),
    [anon_sym_POUNDIf] = ACTIONS(4698),
    [anon_sym_not] = ACTIONS(4696),
    [anon_sym_NOT] = ACTIONS(4696),
    [anon_sym_Not] = ACTIONS(4696),
    [anon_sym_POUNDelse] = ACTIONS(4698),
    [anon_sym_POUNDELSE] = ACTIONS(4698),
    [anon_sym_POUNDElse] = ACTIONS(4698),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4696),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4696),
    [anon_sym_PLUS] = ACTIONS(4698),
    [sym_datetime_literal] = ACTIONS(4698),
    [sym_date_literal] = ACTIONS(4696),
    [sym_time_literal] = ACTIONS(4696),
    [sym_biginteger_literal] = ACTIONS(4698),
    [anon_sym_if] = ACTIONS(4696),
    [anon_sym_IF] = ACTIONS(4696),
    [anon_sym_If] = ACTIONS(4696),
    [anon_sym_else] = ACTIONS(4696),
    [anon_sym_ELSE] = ACTIONS(4696),
    [anon_sym_Else] = ACTIONS(4696),
    [anon_sym_case] = ACTIONS(4696),
    [anon_sym_CASE] = ACTIONS(4696),
    [anon_sym_Case] = ACTIONS(4696),
    [anon_sym_for] = ACTIONS(4696),
    [anon_sym_FOR] = ACTIONS(4696),
    [anon_sym_For] = ACTIONS(4696),
    [anon_sym_foreach] = ACTIONS(4696),
    [anon_sym_FOREACH] = ACTIONS(4696),
    [anon_sym_Foreach] = ACTIONS(4696),
    [anon_sym_while] = ACTIONS(4696),
    [anon_sym_WHILE] = ACTIONS(4696),
    [anon_sym_While] = ACTIONS(4696),
    [anon_sym_repeat] = ACTIONS(4696),
    [anon_sym_REPEAT] = ACTIONS(4696),
    [anon_sym_Repeat] = ACTIONS(4696),
    [anon_sym_until] = ACTIONS(4696),
    [anon_sym_UNTIL] = ACTIONS(4696),
    [anon_sym_Until] = ACTIONS(4696),
    [anon_sym_exit] = ACTIONS(4696),
    [anon_sym_EXIT] = ACTIONS(4696),
    [anon_sym_Exit] = ACTIONS(4696),
    [anon_sym_continue] = ACTIONS(4696),
    [anon_sym_CONTINUE] = ACTIONS(4696),
    [anon_sym_Continue] = ACTIONS(4696),
    [anon_sym_break] = ACTIONS(4696),
    [anon_sym_BREAK] = ACTIONS(4696),
    [anon_sym_Break] = ACTIONS(4696),
    [anon_sym_with] = ACTIONS(4696),
    [anon_sym_WITH] = ACTIONS(4696),
    [anon_sym_With] = ACTIONS(4696),
    [sym_asserterror_keyword] = ACTIONS(4698),
    [sym_page_keyword] = ACTIONS(4696),
    [anon_sym_codeunit] = ACTIONS(4696),
    [anon_sym_CODEUNIT] = ACTIONS(4696),
    [anon_sym_Codeunit] = ACTIONS(4696),
    [anon_sym_CodeUnit] = ACTIONS(4696),
    [anon_sym_COdeunit] = ACTIONS(4696),
    [anon_sym_codeUnit] = ACTIONS(4696),
    [sym_report_keyword] = ACTIONS(4696),
    [sym_query_keyword] = ACTIONS(4696),
    [anon_sym_xmlport] = ACTIONS(4696),
    [anon_sym_XMLPORT] = ACTIONS(4696),
    [anon_sym_Xmlport] = ACTIONS(4696),
    [anon_sym_XMLport] = ACTIONS(4696),
    [anon_sym_XMLPort] = ACTIONS(4696),
    [anon_sym_XmlPort] = ACTIONS(4696),
    [anon_sym_enum] = ACTIONS(4696),
    [anon_sym_ENUM] = ACTIONS(4696),
    [anon_sym_Enum] = ACTIONS(4696),
    [anon_sym_eNUM] = ACTIONS(4696),
    [anon_sym_eNum] = ACTIONS(4696),
    [anon_sym_ENum] = ACTIONS(4696),
    [sym_quoted_identifier] = ACTIONS(4698),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4698),
    [sym_integer] = ACTIONS(4696),
    [sym_continue_as_identifier] = ACTIONS(4698),
    [sym_preproc_open] = ACTIONS(4698),
  },
  [STATE(1781)] = {
    [sym_identifier] = ACTIONS(4696),
    [anon_sym_SEMI] = ACTIONS(4698),
    [anon_sym_DASH] = ACTIONS(4698),
    [aux_sym_boolean_token1] = ACTIONS(4696),
    [aux_sym_boolean_token2] = ACTIONS(4696),
    [sym_decimal] = ACTIONS(4696),
    [anon_sym_LPAREN] = ACTIONS(4698),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4696),
    [anon_sym_LBRACK] = ACTIONS(4698),
    [aux_sym_record_type_token1] = ACTIONS(4696),
    [aux_sym_basic_type_token21] = ACTIONS(4696),
    [aux_sym_basic_type_token22] = ACTIONS(4696),
    [aux_sym_basic_type_token48] = ACTIONS(4696),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4696),
    [anon_sym_POUNDif] = ACTIONS(4698),
    [anon_sym_POUNDIF] = ACTIONS(4698),
    [anon_sym_POUNDIf] = ACTIONS(4698),
    [anon_sym_not] = ACTIONS(4696),
    [anon_sym_NOT] = ACTIONS(4696),
    [anon_sym_Not] = ACTIONS(4696),
    [anon_sym_POUNDelse] = ACTIONS(4698),
    [anon_sym_POUNDELSE] = ACTIONS(4698),
    [anon_sym_POUNDElse] = ACTIONS(4698),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4696),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4696),
    [anon_sym_PLUS] = ACTIONS(4698),
    [sym_datetime_literal] = ACTIONS(4698),
    [sym_date_literal] = ACTIONS(4696),
    [sym_time_literal] = ACTIONS(4696),
    [sym_biginteger_literal] = ACTIONS(4698),
    [anon_sym_if] = ACTIONS(4696),
    [anon_sym_IF] = ACTIONS(4696),
    [anon_sym_If] = ACTIONS(4696),
    [anon_sym_else] = ACTIONS(4696),
    [anon_sym_ELSE] = ACTIONS(4696),
    [anon_sym_Else] = ACTIONS(4696),
    [anon_sym_case] = ACTIONS(4696),
    [anon_sym_CASE] = ACTIONS(4696),
    [anon_sym_Case] = ACTIONS(4696),
    [anon_sym_for] = ACTIONS(4696),
    [anon_sym_FOR] = ACTIONS(4696),
    [anon_sym_For] = ACTIONS(4696),
    [anon_sym_foreach] = ACTIONS(4696),
    [anon_sym_FOREACH] = ACTIONS(4696),
    [anon_sym_Foreach] = ACTIONS(4696),
    [anon_sym_while] = ACTIONS(4696),
    [anon_sym_WHILE] = ACTIONS(4696),
    [anon_sym_While] = ACTIONS(4696),
    [anon_sym_repeat] = ACTIONS(4696),
    [anon_sym_REPEAT] = ACTIONS(4696),
    [anon_sym_Repeat] = ACTIONS(4696),
    [anon_sym_until] = ACTIONS(4696),
    [anon_sym_UNTIL] = ACTIONS(4696),
    [anon_sym_Until] = ACTIONS(4696),
    [anon_sym_exit] = ACTIONS(4696),
    [anon_sym_EXIT] = ACTIONS(4696),
    [anon_sym_Exit] = ACTIONS(4696),
    [anon_sym_continue] = ACTIONS(4696),
    [anon_sym_CONTINUE] = ACTIONS(4696),
    [anon_sym_Continue] = ACTIONS(4696),
    [anon_sym_break] = ACTIONS(4696),
    [anon_sym_BREAK] = ACTIONS(4696),
    [anon_sym_Break] = ACTIONS(4696),
    [anon_sym_with] = ACTIONS(4696),
    [anon_sym_WITH] = ACTIONS(4696),
    [anon_sym_With] = ACTIONS(4696),
    [sym_asserterror_keyword] = ACTIONS(4698),
    [sym_page_keyword] = ACTIONS(4696),
    [anon_sym_codeunit] = ACTIONS(4696),
    [anon_sym_CODEUNIT] = ACTIONS(4696),
    [anon_sym_Codeunit] = ACTIONS(4696),
    [anon_sym_CodeUnit] = ACTIONS(4696),
    [anon_sym_COdeunit] = ACTIONS(4696),
    [anon_sym_codeUnit] = ACTIONS(4696),
    [sym_report_keyword] = ACTIONS(4696),
    [sym_query_keyword] = ACTIONS(4696),
    [anon_sym_xmlport] = ACTIONS(4696),
    [anon_sym_XMLPORT] = ACTIONS(4696),
    [anon_sym_Xmlport] = ACTIONS(4696),
    [anon_sym_XMLport] = ACTIONS(4696),
    [anon_sym_XMLPort] = ACTIONS(4696),
    [anon_sym_XmlPort] = ACTIONS(4696),
    [anon_sym_enum] = ACTIONS(4696),
    [anon_sym_ENUM] = ACTIONS(4696),
    [anon_sym_Enum] = ACTIONS(4696),
    [anon_sym_eNUM] = ACTIONS(4696),
    [anon_sym_eNum] = ACTIONS(4696),
    [anon_sym_ENum] = ACTIONS(4696),
    [sym_quoted_identifier] = ACTIONS(4698),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4698),
    [sym_integer] = ACTIONS(4696),
    [sym_continue_as_identifier] = ACTIONS(4698),
    [sym_preproc_open] = ACTIONS(4698),
  },
  [STATE(1782)] = {
    [sym_identifier] = ACTIONS(4748),
    [anon_sym_SEMI] = ACTIONS(4750),
    [anon_sym_DASH] = ACTIONS(4750),
    [aux_sym_boolean_token1] = ACTIONS(4748),
    [aux_sym_boolean_token2] = ACTIONS(4748),
    [sym_decimal] = ACTIONS(4748),
    [anon_sym_LPAREN] = ACTIONS(4750),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4748),
    [anon_sym_LBRACK] = ACTIONS(4750),
    [aux_sym_record_type_token1] = ACTIONS(4748),
    [aux_sym_basic_type_token21] = ACTIONS(4748),
    [aux_sym_basic_type_token22] = ACTIONS(4748),
    [aux_sym_basic_type_token48] = ACTIONS(4748),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4748),
    [anon_sym_POUNDif] = ACTIONS(4750),
    [anon_sym_POUNDIF] = ACTIONS(4750),
    [anon_sym_POUNDIf] = ACTIONS(4750),
    [anon_sym_not] = ACTIONS(4748),
    [anon_sym_NOT] = ACTIONS(4748),
    [anon_sym_Not] = ACTIONS(4748),
    [anon_sym_POUNDelse] = ACTIONS(4750),
    [anon_sym_POUNDELSE] = ACTIONS(4750),
    [anon_sym_POUNDElse] = ACTIONS(4750),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4748),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4748),
    [anon_sym_PLUS] = ACTIONS(4750),
    [sym_datetime_literal] = ACTIONS(4750),
    [sym_date_literal] = ACTIONS(4748),
    [sym_time_literal] = ACTIONS(4748),
    [sym_biginteger_literal] = ACTIONS(4750),
    [anon_sym_if] = ACTIONS(4748),
    [anon_sym_IF] = ACTIONS(4748),
    [anon_sym_If] = ACTIONS(4748),
    [anon_sym_else] = ACTIONS(4748),
    [anon_sym_ELSE] = ACTIONS(4748),
    [anon_sym_Else] = ACTIONS(4748),
    [anon_sym_case] = ACTIONS(4748),
    [anon_sym_CASE] = ACTIONS(4748),
    [anon_sym_Case] = ACTIONS(4748),
    [anon_sym_for] = ACTIONS(4748),
    [anon_sym_FOR] = ACTIONS(4748),
    [anon_sym_For] = ACTIONS(4748),
    [anon_sym_foreach] = ACTIONS(4748),
    [anon_sym_FOREACH] = ACTIONS(4748),
    [anon_sym_Foreach] = ACTIONS(4748),
    [anon_sym_while] = ACTIONS(4748),
    [anon_sym_WHILE] = ACTIONS(4748),
    [anon_sym_While] = ACTIONS(4748),
    [anon_sym_repeat] = ACTIONS(4748),
    [anon_sym_REPEAT] = ACTIONS(4748),
    [anon_sym_Repeat] = ACTIONS(4748),
    [anon_sym_until] = ACTIONS(4748),
    [anon_sym_UNTIL] = ACTIONS(4748),
    [anon_sym_Until] = ACTIONS(4748),
    [anon_sym_exit] = ACTIONS(4748),
    [anon_sym_EXIT] = ACTIONS(4748),
    [anon_sym_Exit] = ACTIONS(4748),
    [anon_sym_continue] = ACTIONS(4748),
    [anon_sym_CONTINUE] = ACTIONS(4748),
    [anon_sym_Continue] = ACTIONS(4748),
    [anon_sym_break] = ACTIONS(4748),
    [anon_sym_BREAK] = ACTIONS(4748),
    [anon_sym_Break] = ACTIONS(4748),
    [anon_sym_with] = ACTIONS(4748),
    [anon_sym_WITH] = ACTIONS(4748),
    [anon_sym_With] = ACTIONS(4748),
    [sym_asserterror_keyword] = ACTIONS(4750),
    [sym_page_keyword] = ACTIONS(4748),
    [anon_sym_codeunit] = ACTIONS(4748),
    [anon_sym_CODEUNIT] = ACTIONS(4748),
    [anon_sym_Codeunit] = ACTIONS(4748),
    [anon_sym_CodeUnit] = ACTIONS(4748),
    [anon_sym_COdeunit] = ACTIONS(4748),
    [anon_sym_codeUnit] = ACTIONS(4748),
    [sym_report_keyword] = ACTIONS(4748),
    [sym_query_keyword] = ACTIONS(4748),
    [anon_sym_xmlport] = ACTIONS(4748),
    [anon_sym_XMLPORT] = ACTIONS(4748),
    [anon_sym_Xmlport] = ACTIONS(4748),
    [anon_sym_XMLport] = ACTIONS(4748),
    [anon_sym_XMLPort] = ACTIONS(4748),
    [anon_sym_XmlPort] = ACTIONS(4748),
    [anon_sym_enum] = ACTIONS(4748),
    [anon_sym_ENUM] = ACTIONS(4748),
    [anon_sym_Enum] = ACTIONS(4748),
    [anon_sym_eNUM] = ACTIONS(4748),
    [anon_sym_eNum] = ACTIONS(4748),
    [anon_sym_ENum] = ACTIONS(4748),
    [sym_quoted_identifier] = ACTIONS(4750),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4750),
    [sym_integer] = ACTIONS(4748),
    [sym_continue_as_identifier] = ACTIONS(4750),
    [sym_preproc_open] = ACTIONS(4750),
  },
  [STATE(1783)] = {
    [sym_identifier] = ACTIONS(4752),
    [anon_sym_SEMI] = ACTIONS(4754),
    [anon_sym_DASH] = ACTIONS(4754),
    [aux_sym_boolean_token1] = ACTIONS(4752),
    [aux_sym_boolean_token2] = ACTIONS(4752),
    [sym_decimal] = ACTIONS(4752),
    [anon_sym_LPAREN] = ACTIONS(4754),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4752),
    [anon_sym_LBRACK] = ACTIONS(4754),
    [aux_sym_record_type_token1] = ACTIONS(4752),
    [aux_sym_basic_type_token21] = ACTIONS(4752),
    [aux_sym_basic_type_token22] = ACTIONS(4752),
    [aux_sym_basic_type_token48] = ACTIONS(4752),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4752),
    [anon_sym_POUNDif] = ACTIONS(4754),
    [anon_sym_POUNDIF] = ACTIONS(4754),
    [anon_sym_POUNDIf] = ACTIONS(4754),
    [anon_sym_not] = ACTIONS(4752),
    [anon_sym_NOT] = ACTIONS(4752),
    [anon_sym_Not] = ACTIONS(4752),
    [anon_sym_POUNDelse] = ACTIONS(4754),
    [anon_sym_POUNDELSE] = ACTIONS(4754),
    [anon_sym_POUNDElse] = ACTIONS(4754),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4752),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4752),
    [anon_sym_PLUS] = ACTIONS(4754),
    [sym_datetime_literal] = ACTIONS(4754),
    [sym_date_literal] = ACTIONS(4752),
    [sym_time_literal] = ACTIONS(4752),
    [sym_biginteger_literal] = ACTIONS(4754),
    [anon_sym_if] = ACTIONS(4752),
    [anon_sym_IF] = ACTIONS(4752),
    [anon_sym_If] = ACTIONS(4752),
    [anon_sym_else] = ACTIONS(4752),
    [anon_sym_ELSE] = ACTIONS(4752),
    [anon_sym_Else] = ACTIONS(4752),
    [anon_sym_case] = ACTIONS(4752),
    [anon_sym_CASE] = ACTIONS(4752),
    [anon_sym_Case] = ACTIONS(4752),
    [anon_sym_for] = ACTIONS(4752),
    [anon_sym_FOR] = ACTIONS(4752),
    [anon_sym_For] = ACTIONS(4752),
    [anon_sym_foreach] = ACTIONS(4752),
    [anon_sym_FOREACH] = ACTIONS(4752),
    [anon_sym_Foreach] = ACTIONS(4752),
    [anon_sym_while] = ACTIONS(4752),
    [anon_sym_WHILE] = ACTIONS(4752),
    [anon_sym_While] = ACTIONS(4752),
    [anon_sym_repeat] = ACTIONS(4752),
    [anon_sym_REPEAT] = ACTIONS(4752),
    [anon_sym_Repeat] = ACTIONS(4752),
    [anon_sym_until] = ACTIONS(4752),
    [anon_sym_UNTIL] = ACTIONS(4752),
    [anon_sym_Until] = ACTIONS(4752),
    [anon_sym_exit] = ACTIONS(4752),
    [anon_sym_EXIT] = ACTIONS(4752),
    [anon_sym_Exit] = ACTIONS(4752),
    [anon_sym_continue] = ACTIONS(4752),
    [anon_sym_CONTINUE] = ACTIONS(4752),
    [anon_sym_Continue] = ACTIONS(4752),
    [anon_sym_break] = ACTIONS(4752),
    [anon_sym_BREAK] = ACTIONS(4752),
    [anon_sym_Break] = ACTIONS(4752),
    [anon_sym_with] = ACTIONS(4752),
    [anon_sym_WITH] = ACTIONS(4752),
    [anon_sym_With] = ACTIONS(4752),
    [sym_asserterror_keyword] = ACTIONS(4754),
    [sym_page_keyword] = ACTIONS(4752),
    [anon_sym_codeunit] = ACTIONS(4752),
    [anon_sym_CODEUNIT] = ACTIONS(4752),
    [anon_sym_Codeunit] = ACTIONS(4752),
    [anon_sym_CodeUnit] = ACTIONS(4752),
    [anon_sym_COdeunit] = ACTIONS(4752),
    [anon_sym_codeUnit] = ACTIONS(4752),
    [sym_report_keyword] = ACTIONS(4752),
    [sym_query_keyword] = ACTIONS(4752),
    [anon_sym_xmlport] = ACTIONS(4752),
    [anon_sym_XMLPORT] = ACTIONS(4752),
    [anon_sym_Xmlport] = ACTIONS(4752),
    [anon_sym_XMLport] = ACTIONS(4752),
    [anon_sym_XMLPort] = ACTIONS(4752),
    [anon_sym_XmlPort] = ACTIONS(4752),
    [anon_sym_enum] = ACTIONS(4752),
    [anon_sym_ENUM] = ACTIONS(4752),
    [anon_sym_Enum] = ACTIONS(4752),
    [anon_sym_eNUM] = ACTIONS(4752),
    [anon_sym_eNum] = ACTIONS(4752),
    [anon_sym_ENum] = ACTIONS(4752),
    [sym_quoted_identifier] = ACTIONS(4754),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4754),
    [sym_integer] = ACTIONS(4752),
    [sym_continue_as_identifier] = ACTIONS(4754),
    [sym_preproc_open] = ACTIONS(4754),
  },
  [STATE(1784)] = {
    [sym_identifier] = ACTIONS(4748),
    [anon_sym_SEMI] = ACTIONS(4750),
    [anon_sym_DASH] = ACTIONS(4750),
    [aux_sym_boolean_token1] = ACTIONS(4748),
    [aux_sym_boolean_token2] = ACTIONS(4748),
    [sym_decimal] = ACTIONS(4748),
    [anon_sym_LPAREN] = ACTIONS(4750),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4748),
    [anon_sym_LBRACK] = ACTIONS(4750),
    [aux_sym_record_type_token1] = ACTIONS(4748),
    [aux_sym_basic_type_token21] = ACTIONS(4748),
    [aux_sym_basic_type_token22] = ACTIONS(4748),
    [aux_sym_basic_type_token48] = ACTIONS(4748),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4748),
    [anon_sym_POUNDif] = ACTIONS(4750),
    [anon_sym_POUNDIF] = ACTIONS(4750),
    [anon_sym_POUNDIf] = ACTIONS(4750),
    [anon_sym_not] = ACTIONS(4748),
    [anon_sym_NOT] = ACTIONS(4748),
    [anon_sym_Not] = ACTIONS(4748),
    [anon_sym_POUNDelse] = ACTIONS(4750),
    [anon_sym_POUNDELSE] = ACTIONS(4750),
    [anon_sym_POUNDElse] = ACTIONS(4750),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4748),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4748),
    [anon_sym_PLUS] = ACTIONS(4750),
    [sym_datetime_literal] = ACTIONS(4750),
    [sym_date_literal] = ACTIONS(4748),
    [sym_time_literal] = ACTIONS(4748),
    [sym_biginteger_literal] = ACTIONS(4750),
    [anon_sym_if] = ACTIONS(4748),
    [anon_sym_IF] = ACTIONS(4748),
    [anon_sym_If] = ACTIONS(4748),
    [anon_sym_else] = ACTIONS(4748),
    [anon_sym_ELSE] = ACTIONS(4748),
    [anon_sym_Else] = ACTIONS(4748),
    [anon_sym_case] = ACTIONS(4748),
    [anon_sym_CASE] = ACTIONS(4748),
    [anon_sym_Case] = ACTIONS(4748),
    [anon_sym_for] = ACTIONS(4748),
    [anon_sym_FOR] = ACTIONS(4748),
    [anon_sym_For] = ACTIONS(4748),
    [anon_sym_foreach] = ACTIONS(4748),
    [anon_sym_FOREACH] = ACTIONS(4748),
    [anon_sym_Foreach] = ACTIONS(4748),
    [anon_sym_while] = ACTIONS(4748),
    [anon_sym_WHILE] = ACTIONS(4748),
    [anon_sym_While] = ACTIONS(4748),
    [anon_sym_repeat] = ACTIONS(4748),
    [anon_sym_REPEAT] = ACTIONS(4748),
    [anon_sym_Repeat] = ACTIONS(4748),
    [anon_sym_until] = ACTIONS(4748),
    [anon_sym_UNTIL] = ACTIONS(4748),
    [anon_sym_Until] = ACTIONS(4748),
    [anon_sym_exit] = ACTIONS(4748),
    [anon_sym_EXIT] = ACTIONS(4748),
    [anon_sym_Exit] = ACTIONS(4748),
    [anon_sym_continue] = ACTIONS(4748),
    [anon_sym_CONTINUE] = ACTIONS(4748),
    [anon_sym_Continue] = ACTIONS(4748),
    [anon_sym_break] = ACTIONS(4748),
    [anon_sym_BREAK] = ACTIONS(4748),
    [anon_sym_Break] = ACTIONS(4748),
    [anon_sym_with] = ACTIONS(4748),
    [anon_sym_WITH] = ACTIONS(4748),
    [anon_sym_With] = ACTIONS(4748),
    [sym_asserterror_keyword] = ACTIONS(4750),
    [sym_page_keyword] = ACTIONS(4748),
    [anon_sym_codeunit] = ACTIONS(4748),
    [anon_sym_CODEUNIT] = ACTIONS(4748),
    [anon_sym_Codeunit] = ACTIONS(4748),
    [anon_sym_CodeUnit] = ACTIONS(4748),
    [anon_sym_COdeunit] = ACTIONS(4748),
    [anon_sym_codeUnit] = ACTIONS(4748),
    [sym_report_keyword] = ACTIONS(4748),
    [sym_query_keyword] = ACTIONS(4748),
    [anon_sym_xmlport] = ACTIONS(4748),
    [anon_sym_XMLPORT] = ACTIONS(4748),
    [anon_sym_Xmlport] = ACTIONS(4748),
    [anon_sym_XMLport] = ACTIONS(4748),
    [anon_sym_XMLPort] = ACTIONS(4748),
    [anon_sym_XmlPort] = ACTIONS(4748),
    [anon_sym_enum] = ACTIONS(4748),
    [anon_sym_ENUM] = ACTIONS(4748),
    [anon_sym_Enum] = ACTIONS(4748),
    [anon_sym_eNUM] = ACTIONS(4748),
    [anon_sym_eNum] = ACTIONS(4748),
    [anon_sym_ENum] = ACTIONS(4748),
    [sym_quoted_identifier] = ACTIONS(4750),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4750),
    [sym_integer] = ACTIONS(4748),
    [sym_continue_as_identifier] = ACTIONS(4750),
    [sym_preproc_open] = ACTIONS(4750),
  },
  [STATE(1785)] = {
    [sym_identifier] = ACTIONS(4756),
    [anon_sym_SEMI] = ACTIONS(4758),
    [anon_sym_DASH] = ACTIONS(4758),
    [aux_sym_boolean_token1] = ACTIONS(4756),
    [aux_sym_boolean_token2] = ACTIONS(4756),
    [sym_decimal] = ACTIONS(4756),
    [anon_sym_LPAREN] = ACTIONS(4758),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4756),
    [anon_sym_LBRACK] = ACTIONS(4758),
    [aux_sym_record_type_token1] = ACTIONS(4756),
    [aux_sym_basic_type_token21] = ACTIONS(4756),
    [aux_sym_basic_type_token22] = ACTIONS(4756),
    [aux_sym_basic_type_token48] = ACTIONS(4756),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4756),
    [anon_sym_POUNDif] = ACTIONS(4758),
    [anon_sym_POUNDIF] = ACTIONS(4758),
    [anon_sym_POUNDIf] = ACTIONS(4758),
    [anon_sym_not] = ACTIONS(4756),
    [anon_sym_NOT] = ACTIONS(4756),
    [anon_sym_Not] = ACTIONS(4756),
    [anon_sym_POUNDelse] = ACTIONS(4758),
    [anon_sym_POUNDELSE] = ACTIONS(4758),
    [anon_sym_POUNDElse] = ACTIONS(4758),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4756),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4756),
    [anon_sym_PLUS] = ACTIONS(4758),
    [sym_datetime_literal] = ACTIONS(4758),
    [sym_date_literal] = ACTIONS(4756),
    [sym_time_literal] = ACTIONS(4756),
    [sym_biginteger_literal] = ACTIONS(4758),
    [anon_sym_if] = ACTIONS(4756),
    [anon_sym_IF] = ACTIONS(4756),
    [anon_sym_If] = ACTIONS(4756),
    [anon_sym_else] = ACTIONS(4756),
    [anon_sym_ELSE] = ACTIONS(4756),
    [anon_sym_Else] = ACTIONS(4756),
    [anon_sym_case] = ACTIONS(4756),
    [anon_sym_CASE] = ACTIONS(4756),
    [anon_sym_Case] = ACTIONS(4756),
    [anon_sym_for] = ACTIONS(4756),
    [anon_sym_FOR] = ACTIONS(4756),
    [anon_sym_For] = ACTIONS(4756),
    [anon_sym_foreach] = ACTIONS(4756),
    [anon_sym_FOREACH] = ACTIONS(4756),
    [anon_sym_Foreach] = ACTIONS(4756),
    [anon_sym_while] = ACTIONS(4756),
    [anon_sym_WHILE] = ACTIONS(4756),
    [anon_sym_While] = ACTIONS(4756),
    [anon_sym_repeat] = ACTIONS(4756),
    [anon_sym_REPEAT] = ACTIONS(4756),
    [anon_sym_Repeat] = ACTIONS(4756),
    [anon_sym_until] = ACTIONS(4756),
    [anon_sym_UNTIL] = ACTIONS(4756),
    [anon_sym_Until] = ACTIONS(4756),
    [anon_sym_exit] = ACTIONS(4756),
    [anon_sym_EXIT] = ACTIONS(4756),
    [anon_sym_Exit] = ACTIONS(4756),
    [anon_sym_continue] = ACTIONS(4756),
    [anon_sym_CONTINUE] = ACTIONS(4756),
    [anon_sym_Continue] = ACTIONS(4756),
    [anon_sym_break] = ACTIONS(4756),
    [anon_sym_BREAK] = ACTIONS(4756),
    [anon_sym_Break] = ACTIONS(4756),
    [anon_sym_with] = ACTIONS(4756),
    [anon_sym_WITH] = ACTIONS(4756),
    [anon_sym_With] = ACTIONS(4756),
    [sym_asserterror_keyword] = ACTIONS(4758),
    [sym_page_keyword] = ACTIONS(4756),
    [anon_sym_codeunit] = ACTIONS(4756),
    [anon_sym_CODEUNIT] = ACTIONS(4756),
    [anon_sym_Codeunit] = ACTIONS(4756),
    [anon_sym_CodeUnit] = ACTIONS(4756),
    [anon_sym_COdeunit] = ACTIONS(4756),
    [anon_sym_codeUnit] = ACTIONS(4756),
    [sym_report_keyword] = ACTIONS(4756),
    [sym_query_keyword] = ACTIONS(4756),
    [anon_sym_xmlport] = ACTIONS(4756),
    [anon_sym_XMLPORT] = ACTIONS(4756),
    [anon_sym_Xmlport] = ACTIONS(4756),
    [anon_sym_XMLport] = ACTIONS(4756),
    [anon_sym_XMLPort] = ACTIONS(4756),
    [anon_sym_XmlPort] = ACTIONS(4756),
    [anon_sym_enum] = ACTIONS(4756),
    [anon_sym_ENUM] = ACTIONS(4756),
    [anon_sym_Enum] = ACTIONS(4756),
    [anon_sym_eNUM] = ACTIONS(4756),
    [anon_sym_eNum] = ACTIONS(4756),
    [anon_sym_ENum] = ACTIONS(4756),
    [sym_quoted_identifier] = ACTIONS(4758),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4758),
    [sym_integer] = ACTIONS(4756),
    [sym_continue_as_identifier] = ACTIONS(4758),
    [sym_preproc_open] = ACTIONS(4758),
  },
  [STATE(1786)] = {
    [sym_identifier] = ACTIONS(4760),
    [anon_sym_SEMI] = ACTIONS(4762),
    [anon_sym_DASH] = ACTIONS(4762),
    [aux_sym_boolean_token1] = ACTIONS(4760),
    [aux_sym_boolean_token2] = ACTIONS(4760),
    [sym_decimal] = ACTIONS(4760),
    [anon_sym_LPAREN] = ACTIONS(4762),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4760),
    [anon_sym_LBRACK] = ACTIONS(4762),
    [aux_sym_record_type_token1] = ACTIONS(4760),
    [aux_sym_basic_type_token21] = ACTIONS(4760),
    [aux_sym_basic_type_token22] = ACTIONS(4760),
    [aux_sym_basic_type_token48] = ACTIONS(4760),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4760),
    [anon_sym_POUNDif] = ACTIONS(4762),
    [anon_sym_POUNDIF] = ACTIONS(4762),
    [anon_sym_POUNDIf] = ACTIONS(4762),
    [anon_sym_not] = ACTIONS(4760),
    [anon_sym_NOT] = ACTIONS(4760),
    [anon_sym_Not] = ACTIONS(4760),
    [anon_sym_POUNDelse] = ACTIONS(4762),
    [anon_sym_POUNDELSE] = ACTIONS(4762),
    [anon_sym_POUNDElse] = ACTIONS(4762),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4760),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4760),
    [anon_sym_PLUS] = ACTIONS(4762),
    [sym_datetime_literal] = ACTIONS(4762),
    [sym_date_literal] = ACTIONS(4760),
    [sym_time_literal] = ACTIONS(4760),
    [sym_biginteger_literal] = ACTIONS(4762),
    [anon_sym_if] = ACTIONS(4760),
    [anon_sym_IF] = ACTIONS(4760),
    [anon_sym_If] = ACTIONS(4760),
    [anon_sym_else] = ACTIONS(4760),
    [anon_sym_ELSE] = ACTIONS(4760),
    [anon_sym_Else] = ACTIONS(4760),
    [anon_sym_case] = ACTIONS(4760),
    [anon_sym_CASE] = ACTIONS(4760),
    [anon_sym_Case] = ACTIONS(4760),
    [anon_sym_for] = ACTIONS(4760),
    [anon_sym_FOR] = ACTIONS(4760),
    [anon_sym_For] = ACTIONS(4760),
    [anon_sym_foreach] = ACTIONS(4760),
    [anon_sym_FOREACH] = ACTIONS(4760),
    [anon_sym_Foreach] = ACTIONS(4760),
    [anon_sym_while] = ACTIONS(4760),
    [anon_sym_WHILE] = ACTIONS(4760),
    [anon_sym_While] = ACTIONS(4760),
    [anon_sym_repeat] = ACTIONS(4760),
    [anon_sym_REPEAT] = ACTIONS(4760),
    [anon_sym_Repeat] = ACTIONS(4760),
    [anon_sym_until] = ACTIONS(4760),
    [anon_sym_UNTIL] = ACTIONS(4760),
    [anon_sym_Until] = ACTIONS(4760),
    [anon_sym_exit] = ACTIONS(4760),
    [anon_sym_EXIT] = ACTIONS(4760),
    [anon_sym_Exit] = ACTIONS(4760),
    [anon_sym_continue] = ACTIONS(4760),
    [anon_sym_CONTINUE] = ACTIONS(4760),
    [anon_sym_Continue] = ACTIONS(4760),
    [anon_sym_break] = ACTIONS(4760),
    [anon_sym_BREAK] = ACTIONS(4760),
    [anon_sym_Break] = ACTIONS(4760),
    [anon_sym_with] = ACTIONS(4760),
    [anon_sym_WITH] = ACTIONS(4760),
    [anon_sym_With] = ACTIONS(4760),
    [sym_asserterror_keyword] = ACTIONS(4762),
    [sym_page_keyword] = ACTIONS(4760),
    [anon_sym_codeunit] = ACTIONS(4760),
    [anon_sym_CODEUNIT] = ACTIONS(4760),
    [anon_sym_Codeunit] = ACTIONS(4760),
    [anon_sym_CodeUnit] = ACTIONS(4760),
    [anon_sym_COdeunit] = ACTIONS(4760),
    [anon_sym_codeUnit] = ACTIONS(4760),
    [sym_report_keyword] = ACTIONS(4760),
    [sym_query_keyword] = ACTIONS(4760),
    [anon_sym_xmlport] = ACTIONS(4760),
    [anon_sym_XMLPORT] = ACTIONS(4760),
    [anon_sym_Xmlport] = ACTIONS(4760),
    [anon_sym_XMLport] = ACTIONS(4760),
    [anon_sym_XMLPort] = ACTIONS(4760),
    [anon_sym_XmlPort] = ACTIONS(4760),
    [anon_sym_enum] = ACTIONS(4760),
    [anon_sym_ENUM] = ACTIONS(4760),
    [anon_sym_Enum] = ACTIONS(4760),
    [anon_sym_eNUM] = ACTIONS(4760),
    [anon_sym_eNum] = ACTIONS(4760),
    [anon_sym_ENum] = ACTIONS(4760),
    [sym_quoted_identifier] = ACTIONS(4762),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4762),
    [sym_integer] = ACTIONS(4760),
    [sym_continue_as_identifier] = ACTIONS(4762),
    [sym_preproc_open] = ACTIONS(4762),
  },
  [STATE(1787)] = {
    [sym_identifier] = ACTIONS(4756),
    [anon_sym_SEMI] = ACTIONS(4758),
    [anon_sym_DASH] = ACTIONS(4758),
    [aux_sym_boolean_token1] = ACTIONS(4756),
    [aux_sym_boolean_token2] = ACTIONS(4756),
    [sym_decimal] = ACTIONS(4756),
    [anon_sym_LPAREN] = ACTIONS(4758),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4756),
    [anon_sym_LBRACK] = ACTIONS(4758),
    [aux_sym_record_type_token1] = ACTIONS(4756),
    [aux_sym_basic_type_token21] = ACTIONS(4756),
    [aux_sym_basic_type_token22] = ACTIONS(4756),
    [aux_sym_basic_type_token48] = ACTIONS(4756),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4756),
    [anon_sym_POUNDif] = ACTIONS(4758),
    [anon_sym_POUNDIF] = ACTIONS(4758),
    [anon_sym_POUNDIf] = ACTIONS(4758),
    [anon_sym_not] = ACTIONS(4756),
    [anon_sym_NOT] = ACTIONS(4756),
    [anon_sym_Not] = ACTIONS(4756),
    [anon_sym_POUNDelse] = ACTIONS(4758),
    [anon_sym_POUNDELSE] = ACTIONS(4758),
    [anon_sym_POUNDElse] = ACTIONS(4758),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4756),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4756),
    [anon_sym_PLUS] = ACTIONS(4758),
    [sym_datetime_literal] = ACTIONS(4758),
    [sym_date_literal] = ACTIONS(4756),
    [sym_time_literal] = ACTIONS(4756),
    [sym_biginteger_literal] = ACTIONS(4758),
    [anon_sym_if] = ACTIONS(4756),
    [anon_sym_IF] = ACTIONS(4756),
    [anon_sym_If] = ACTIONS(4756),
    [anon_sym_else] = ACTIONS(4756),
    [anon_sym_ELSE] = ACTIONS(4756),
    [anon_sym_Else] = ACTIONS(4756),
    [anon_sym_case] = ACTIONS(4756),
    [anon_sym_CASE] = ACTIONS(4756),
    [anon_sym_Case] = ACTIONS(4756),
    [anon_sym_for] = ACTIONS(4756),
    [anon_sym_FOR] = ACTIONS(4756),
    [anon_sym_For] = ACTIONS(4756),
    [anon_sym_foreach] = ACTIONS(4756),
    [anon_sym_FOREACH] = ACTIONS(4756),
    [anon_sym_Foreach] = ACTIONS(4756),
    [anon_sym_while] = ACTIONS(4756),
    [anon_sym_WHILE] = ACTIONS(4756),
    [anon_sym_While] = ACTIONS(4756),
    [anon_sym_repeat] = ACTIONS(4756),
    [anon_sym_REPEAT] = ACTIONS(4756),
    [anon_sym_Repeat] = ACTIONS(4756),
    [anon_sym_until] = ACTIONS(4756),
    [anon_sym_UNTIL] = ACTIONS(4756),
    [anon_sym_Until] = ACTIONS(4756),
    [anon_sym_exit] = ACTIONS(4756),
    [anon_sym_EXIT] = ACTIONS(4756),
    [anon_sym_Exit] = ACTIONS(4756),
    [anon_sym_continue] = ACTIONS(4756),
    [anon_sym_CONTINUE] = ACTIONS(4756),
    [anon_sym_Continue] = ACTIONS(4756),
    [anon_sym_break] = ACTIONS(4756),
    [anon_sym_BREAK] = ACTIONS(4756),
    [anon_sym_Break] = ACTIONS(4756),
    [anon_sym_with] = ACTIONS(4756),
    [anon_sym_WITH] = ACTIONS(4756),
    [anon_sym_With] = ACTIONS(4756),
    [sym_asserterror_keyword] = ACTIONS(4758),
    [sym_page_keyword] = ACTIONS(4756),
    [anon_sym_codeunit] = ACTIONS(4756),
    [anon_sym_CODEUNIT] = ACTIONS(4756),
    [anon_sym_Codeunit] = ACTIONS(4756),
    [anon_sym_CodeUnit] = ACTIONS(4756),
    [anon_sym_COdeunit] = ACTIONS(4756),
    [anon_sym_codeUnit] = ACTIONS(4756),
    [sym_report_keyword] = ACTIONS(4756),
    [sym_query_keyword] = ACTIONS(4756),
    [anon_sym_xmlport] = ACTIONS(4756),
    [anon_sym_XMLPORT] = ACTIONS(4756),
    [anon_sym_Xmlport] = ACTIONS(4756),
    [anon_sym_XMLport] = ACTIONS(4756),
    [anon_sym_XMLPort] = ACTIONS(4756),
    [anon_sym_XmlPort] = ACTIONS(4756),
    [anon_sym_enum] = ACTIONS(4756),
    [anon_sym_ENUM] = ACTIONS(4756),
    [anon_sym_Enum] = ACTIONS(4756),
    [anon_sym_eNUM] = ACTIONS(4756),
    [anon_sym_eNum] = ACTIONS(4756),
    [anon_sym_ENum] = ACTIONS(4756),
    [sym_quoted_identifier] = ACTIONS(4758),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4758),
    [sym_integer] = ACTIONS(4756),
    [sym_continue_as_identifier] = ACTIONS(4758),
    [sym_preproc_open] = ACTIONS(4758),
  },
  [STATE(1788)] = {
    [sym_identifier] = ACTIONS(4720),
    [anon_sym_SEMI] = ACTIONS(4722),
    [anon_sym_DASH] = ACTIONS(4722),
    [aux_sym_boolean_token1] = ACTIONS(4720),
    [aux_sym_boolean_token2] = ACTIONS(4720),
    [sym_decimal] = ACTIONS(4720),
    [anon_sym_LPAREN] = ACTIONS(4722),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4720),
    [anon_sym_LBRACK] = ACTIONS(4722),
    [aux_sym_record_type_token1] = ACTIONS(4720),
    [aux_sym_basic_type_token21] = ACTIONS(4720),
    [aux_sym_basic_type_token22] = ACTIONS(4720),
    [aux_sym_basic_type_token48] = ACTIONS(4720),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4720),
    [anon_sym_POUNDif] = ACTIONS(4722),
    [anon_sym_POUNDIF] = ACTIONS(4722),
    [anon_sym_POUNDIf] = ACTIONS(4722),
    [anon_sym_not] = ACTIONS(4720),
    [anon_sym_NOT] = ACTIONS(4720),
    [anon_sym_Not] = ACTIONS(4720),
    [anon_sym_POUNDelse] = ACTIONS(4722),
    [anon_sym_POUNDELSE] = ACTIONS(4722),
    [anon_sym_POUNDElse] = ACTIONS(4722),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4720),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4720),
    [anon_sym_PLUS] = ACTIONS(4722),
    [sym_datetime_literal] = ACTIONS(4722),
    [sym_date_literal] = ACTIONS(4720),
    [sym_time_literal] = ACTIONS(4720),
    [sym_biginteger_literal] = ACTIONS(4722),
    [anon_sym_if] = ACTIONS(4720),
    [anon_sym_IF] = ACTIONS(4720),
    [anon_sym_If] = ACTIONS(4720),
    [anon_sym_else] = ACTIONS(4720),
    [anon_sym_ELSE] = ACTIONS(4720),
    [anon_sym_Else] = ACTIONS(4720),
    [anon_sym_case] = ACTIONS(4720),
    [anon_sym_CASE] = ACTIONS(4720),
    [anon_sym_Case] = ACTIONS(4720),
    [anon_sym_for] = ACTIONS(4720),
    [anon_sym_FOR] = ACTIONS(4720),
    [anon_sym_For] = ACTIONS(4720),
    [anon_sym_foreach] = ACTIONS(4720),
    [anon_sym_FOREACH] = ACTIONS(4720),
    [anon_sym_Foreach] = ACTIONS(4720),
    [anon_sym_while] = ACTIONS(4720),
    [anon_sym_WHILE] = ACTIONS(4720),
    [anon_sym_While] = ACTIONS(4720),
    [anon_sym_repeat] = ACTIONS(4720),
    [anon_sym_REPEAT] = ACTIONS(4720),
    [anon_sym_Repeat] = ACTIONS(4720),
    [anon_sym_until] = ACTIONS(4720),
    [anon_sym_UNTIL] = ACTIONS(4720),
    [anon_sym_Until] = ACTIONS(4720),
    [anon_sym_exit] = ACTIONS(4720),
    [anon_sym_EXIT] = ACTIONS(4720),
    [anon_sym_Exit] = ACTIONS(4720),
    [anon_sym_continue] = ACTIONS(4720),
    [anon_sym_CONTINUE] = ACTIONS(4720),
    [anon_sym_Continue] = ACTIONS(4720),
    [anon_sym_break] = ACTIONS(4720),
    [anon_sym_BREAK] = ACTIONS(4720),
    [anon_sym_Break] = ACTIONS(4720),
    [anon_sym_with] = ACTIONS(4720),
    [anon_sym_WITH] = ACTIONS(4720),
    [anon_sym_With] = ACTIONS(4720),
    [sym_asserterror_keyword] = ACTIONS(4722),
    [sym_page_keyword] = ACTIONS(4720),
    [anon_sym_codeunit] = ACTIONS(4720),
    [anon_sym_CODEUNIT] = ACTIONS(4720),
    [anon_sym_Codeunit] = ACTIONS(4720),
    [anon_sym_CodeUnit] = ACTIONS(4720),
    [anon_sym_COdeunit] = ACTIONS(4720),
    [anon_sym_codeUnit] = ACTIONS(4720),
    [sym_report_keyword] = ACTIONS(4720),
    [sym_query_keyword] = ACTIONS(4720),
    [anon_sym_xmlport] = ACTIONS(4720),
    [anon_sym_XMLPORT] = ACTIONS(4720),
    [anon_sym_Xmlport] = ACTIONS(4720),
    [anon_sym_XMLport] = ACTIONS(4720),
    [anon_sym_XMLPort] = ACTIONS(4720),
    [anon_sym_XmlPort] = ACTIONS(4720),
    [anon_sym_enum] = ACTIONS(4720),
    [anon_sym_ENUM] = ACTIONS(4720),
    [anon_sym_Enum] = ACTIONS(4720),
    [anon_sym_eNUM] = ACTIONS(4720),
    [anon_sym_eNum] = ACTIONS(4720),
    [anon_sym_ENum] = ACTIONS(4720),
    [sym_quoted_identifier] = ACTIONS(4722),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4722),
    [sym_integer] = ACTIONS(4720),
    [sym_continue_as_identifier] = ACTIONS(4722),
    [sym_preproc_open] = ACTIONS(4722),
  },
  [STATE(1789)] = {
    [sym_identifier] = ACTIONS(4768),
    [anon_sym_SEMI] = ACTIONS(4770),
    [anon_sym_DASH] = ACTIONS(4770),
    [aux_sym_boolean_token1] = ACTIONS(4768),
    [aux_sym_boolean_token2] = ACTIONS(4768),
    [sym_decimal] = ACTIONS(4768),
    [anon_sym_LPAREN] = ACTIONS(4770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4768),
    [anon_sym_LBRACK] = ACTIONS(4770),
    [aux_sym_record_type_token1] = ACTIONS(4768),
    [aux_sym_basic_type_token21] = ACTIONS(4768),
    [aux_sym_basic_type_token22] = ACTIONS(4768),
    [aux_sym_basic_type_token48] = ACTIONS(4768),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4768),
    [anon_sym_POUNDif] = ACTIONS(4770),
    [anon_sym_POUNDIF] = ACTIONS(4770),
    [anon_sym_POUNDIf] = ACTIONS(4770),
    [anon_sym_not] = ACTIONS(4768),
    [anon_sym_NOT] = ACTIONS(4768),
    [anon_sym_Not] = ACTIONS(4768),
    [anon_sym_POUNDelse] = ACTIONS(4770),
    [anon_sym_POUNDELSE] = ACTIONS(4770),
    [anon_sym_POUNDElse] = ACTIONS(4770),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4768),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4768),
    [anon_sym_PLUS] = ACTIONS(4770),
    [sym_datetime_literal] = ACTIONS(4770),
    [sym_date_literal] = ACTIONS(4768),
    [sym_time_literal] = ACTIONS(4768),
    [sym_biginteger_literal] = ACTIONS(4770),
    [anon_sym_if] = ACTIONS(4768),
    [anon_sym_IF] = ACTIONS(4768),
    [anon_sym_If] = ACTIONS(4768),
    [anon_sym_else] = ACTIONS(4768),
    [anon_sym_ELSE] = ACTIONS(4768),
    [anon_sym_Else] = ACTIONS(4768),
    [anon_sym_case] = ACTIONS(4768),
    [anon_sym_CASE] = ACTIONS(4768),
    [anon_sym_Case] = ACTIONS(4768),
    [anon_sym_for] = ACTIONS(4768),
    [anon_sym_FOR] = ACTIONS(4768),
    [anon_sym_For] = ACTIONS(4768),
    [anon_sym_foreach] = ACTIONS(4768),
    [anon_sym_FOREACH] = ACTIONS(4768),
    [anon_sym_Foreach] = ACTIONS(4768),
    [anon_sym_while] = ACTIONS(4768),
    [anon_sym_WHILE] = ACTIONS(4768),
    [anon_sym_While] = ACTIONS(4768),
    [anon_sym_repeat] = ACTIONS(4768),
    [anon_sym_REPEAT] = ACTIONS(4768),
    [anon_sym_Repeat] = ACTIONS(4768),
    [anon_sym_until] = ACTIONS(4768),
    [anon_sym_UNTIL] = ACTIONS(4768),
    [anon_sym_Until] = ACTIONS(4768),
    [anon_sym_exit] = ACTIONS(4768),
    [anon_sym_EXIT] = ACTIONS(4768),
    [anon_sym_Exit] = ACTIONS(4768),
    [anon_sym_continue] = ACTIONS(4768),
    [anon_sym_CONTINUE] = ACTIONS(4768),
    [anon_sym_Continue] = ACTIONS(4768),
    [anon_sym_break] = ACTIONS(4768),
    [anon_sym_BREAK] = ACTIONS(4768),
    [anon_sym_Break] = ACTIONS(4768),
    [anon_sym_with] = ACTIONS(4768),
    [anon_sym_WITH] = ACTIONS(4768),
    [anon_sym_With] = ACTIONS(4768),
    [sym_asserterror_keyword] = ACTIONS(4770),
    [sym_page_keyword] = ACTIONS(4768),
    [anon_sym_codeunit] = ACTIONS(4768),
    [anon_sym_CODEUNIT] = ACTIONS(4768),
    [anon_sym_Codeunit] = ACTIONS(4768),
    [anon_sym_CodeUnit] = ACTIONS(4768),
    [anon_sym_COdeunit] = ACTIONS(4768),
    [anon_sym_codeUnit] = ACTIONS(4768),
    [sym_report_keyword] = ACTIONS(4768),
    [sym_query_keyword] = ACTIONS(4768),
    [anon_sym_xmlport] = ACTIONS(4768),
    [anon_sym_XMLPORT] = ACTIONS(4768),
    [anon_sym_Xmlport] = ACTIONS(4768),
    [anon_sym_XMLport] = ACTIONS(4768),
    [anon_sym_XMLPort] = ACTIONS(4768),
    [anon_sym_XmlPort] = ACTIONS(4768),
    [anon_sym_enum] = ACTIONS(4768),
    [anon_sym_ENUM] = ACTIONS(4768),
    [anon_sym_Enum] = ACTIONS(4768),
    [anon_sym_eNUM] = ACTIONS(4768),
    [anon_sym_eNum] = ACTIONS(4768),
    [anon_sym_ENum] = ACTIONS(4768),
    [sym_quoted_identifier] = ACTIONS(4770),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4770),
    [sym_integer] = ACTIONS(4768),
    [sym_continue_as_identifier] = ACTIONS(4770),
    [sym_preproc_open] = ACTIONS(4770),
  },
  [STATE(1790)] = {
    [sym_identifier] = ACTIONS(4772),
    [anon_sym_SEMI] = ACTIONS(4774),
    [anon_sym_DASH] = ACTIONS(4774),
    [aux_sym_boolean_token1] = ACTIONS(4772),
    [aux_sym_boolean_token2] = ACTIONS(4772),
    [sym_decimal] = ACTIONS(4772),
    [anon_sym_LPAREN] = ACTIONS(4774),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4772),
    [anon_sym_LBRACK] = ACTIONS(4774),
    [aux_sym_record_type_token1] = ACTIONS(4772),
    [aux_sym_basic_type_token21] = ACTIONS(4772),
    [aux_sym_basic_type_token22] = ACTIONS(4772),
    [aux_sym_basic_type_token48] = ACTIONS(4772),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4772),
    [anon_sym_POUNDif] = ACTIONS(4774),
    [anon_sym_POUNDIF] = ACTIONS(4774),
    [anon_sym_POUNDIf] = ACTIONS(4774),
    [anon_sym_not] = ACTIONS(4772),
    [anon_sym_NOT] = ACTIONS(4772),
    [anon_sym_Not] = ACTIONS(4772),
    [anon_sym_POUNDelse] = ACTIONS(4774),
    [anon_sym_POUNDELSE] = ACTIONS(4774),
    [anon_sym_POUNDElse] = ACTIONS(4774),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4772),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4772),
    [anon_sym_PLUS] = ACTIONS(4774),
    [sym_datetime_literal] = ACTIONS(4774),
    [sym_date_literal] = ACTIONS(4772),
    [sym_time_literal] = ACTIONS(4772),
    [sym_biginteger_literal] = ACTIONS(4774),
    [anon_sym_if] = ACTIONS(4772),
    [anon_sym_IF] = ACTIONS(4772),
    [anon_sym_If] = ACTIONS(4772),
    [anon_sym_else] = ACTIONS(4772),
    [anon_sym_ELSE] = ACTIONS(4772),
    [anon_sym_Else] = ACTIONS(4772),
    [anon_sym_case] = ACTIONS(4772),
    [anon_sym_CASE] = ACTIONS(4772),
    [anon_sym_Case] = ACTIONS(4772),
    [anon_sym_for] = ACTIONS(4772),
    [anon_sym_FOR] = ACTIONS(4772),
    [anon_sym_For] = ACTIONS(4772),
    [anon_sym_foreach] = ACTIONS(4772),
    [anon_sym_FOREACH] = ACTIONS(4772),
    [anon_sym_Foreach] = ACTIONS(4772),
    [anon_sym_while] = ACTIONS(4772),
    [anon_sym_WHILE] = ACTIONS(4772),
    [anon_sym_While] = ACTIONS(4772),
    [anon_sym_repeat] = ACTIONS(4772),
    [anon_sym_REPEAT] = ACTIONS(4772),
    [anon_sym_Repeat] = ACTIONS(4772),
    [anon_sym_until] = ACTIONS(4772),
    [anon_sym_UNTIL] = ACTIONS(4772),
    [anon_sym_Until] = ACTIONS(4772),
    [anon_sym_exit] = ACTIONS(4772),
    [anon_sym_EXIT] = ACTIONS(4772),
    [anon_sym_Exit] = ACTIONS(4772),
    [anon_sym_continue] = ACTIONS(4772),
    [anon_sym_CONTINUE] = ACTIONS(4772),
    [anon_sym_Continue] = ACTIONS(4772),
    [anon_sym_break] = ACTIONS(4772),
    [anon_sym_BREAK] = ACTIONS(4772),
    [anon_sym_Break] = ACTIONS(4772),
    [anon_sym_with] = ACTIONS(4772),
    [anon_sym_WITH] = ACTIONS(4772),
    [anon_sym_With] = ACTIONS(4772),
    [sym_asserterror_keyword] = ACTIONS(4774),
    [sym_page_keyword] = ACTIONS(4772),
    [anon_sym_codeunit] = ACTIONS(4772),
    [anon_sym_CODEUNIT] = ACTIONS(4772),
    [anon_sym_Codeunit] = ACTIONS(4772),
    [anon_sym_CodeUnit] = ACTIONS(4772),
    [anon_sym_COdeunit] = ACTIONS(4772),
    [anon_sym_codeUnit] = ACTIONS(4772),
    [sym_report_keyword] = ACTIONS(4772),
    [sym_query_keyword] = ACTIONS(4772),
    [anon_sym_xmlport] = ACTIONS(4772),
    [anon_sym_XMLPORT] = ACTIONS(4772),
    [anon_sym_Xmlport] = ACTIONS(4772),
    [anon_sym_XMLport] = ACTIONS(4772),
    [anon_sym_XMLPort] = ACTIONS(4772),
    [anon_sym_XmlPort] = ACTIONS(4772),
    [anon_sym_enum] = ACTIONS(4772),
    [anon_sym_ENUM] = ACTIONS(4772),
    [anon_sym_Enum] = ACTIONS(4772),
    [anon_sym_eNUM] = ACTIONS(4772),
    [anon_sym_eNum] = ACTIONS(4772),
    [anon_sym_ENum] = ACTIONS(4772),
    [sym_quoted_identifier] = ACTIONS(4774),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4774),
    [sym_integer] = ACTIONS(4772),
    [sym_continue_as_identifier] = ACTIONS(4774),
    [sym_preproc_open] = ACTIONS(4774),
  },
  [STATE(1791)] = {
    [sym_identifier] = ACTIONS(4213),
    [anon_sym_SEMI] = ACTIONS(4215),
    [anon_sym_DASH] = ACTIONS(4215),
    [aux_sym_boolean_token1] = ACTIONS(4213),
    [aux_sym_boolean_token2] = ACTIONS(4213),
    [sym_decimal] = ACTIONS(4213),
    [anon_sym_LPAREN] = ACTIONS(4215),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4213),
    [anon_sym_LBRACK] = ACTIONS(4215),
    [aux_sym_record_type_token1] = ACTIONS(4213),
    [aux_sym_basic_type_token21] = ACTIONS(4213),
    [aux_sym_basic_type_token22] = ACTIONS(4213),
    [aux_sym_basic_type_token48] = ACTIONS(4213),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4213),
    [anon_sym_POUNDif] = ACTIONS(4215),
    [anon_sym_POUNDIF] = ACTIONS(4215),
    [anon_sym_POUNDIf] = ACTIONS(4215),
    [anon_sym_not] = ACTIONS(4213),
    [anon_sym_NOT] = ACTIONS(4213),
    [anon_sym_Not] = ACTIONS(4213),
    [anon_sym_POUNDelse] = ACTIONS(4215),
    [anon_sym_POUNDELSE] = ACTIONS(4215),
    [anon_sym_POUNDElse] = ACTIONS(4215),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4213),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4213),
    [anon_sym_PLUS] = ACTIONS(4215),
    [sym_datetime_literal] = ACTIONS(4215),
    [sym_date_literal] = ACTIONS(4213),
    [sym_time_literal] = ACTIONS(4213),
    [sym_biginteger_literal] = ACTIONS(4215),
    [anon_sym_if] = ACTIONS(4213),
    [anon_sym_IF] = ACTIONS(4213),
    [anon_sym_If] = ACTIONS(4213),
    [anon_sym_else] = ACTIONS(4213),
    [anon_sym_ELSE] = ACTIONS(4213),
    [anon_sym_Else] = ACTIONS(4213),
    [anon_sym_case] = ACTIONS(4213),
    [anon_sym_CASE] = ACTIONS(4213),
    [anon_sym_Case] = ACTIONS(4213),
    [anon_sym_for] = ACTIONS(4213),
    [anon_sym_FOR] = ACTIONS(4213),
    [anon_sym_For] = ACTIONS(4213),
    [anon_sym_foreach] = ACTIONS(4213),
    [anon_sym_FOREACH] = ACTIONS(4213),
    [anon_sym_Foreach] = ACTIONS(4213),
    [anon_sym_while] = ACTIONS(4213),
    [anon_sym_WHILE] = ACTIONS(4213),
    [anon_sym_While] = ACTIONS(4213),
    [anon_sym_repeat] = ACTIONS(4213),
    [anon_sym_REPEAT] = ACTIONS(4213),
    [anon_sym_Repeat] = ACTIONS(4213),
    [anon_sym_until] = ACTIONS(4213),
    [anon_sym_UNTIL] = ACTIONS(4213),
    [anon_sym_Until] = ACTIONS(4213),
    [anon_sym_exit] = ACTIONS(4213),
    [anon_sym_EXIT] = ACTIONS(4213),
    [anon_sym_Exit] = ACTIONS(4213),
    [anon_sym_continue] = ACTIONS(4213),
    [anon_sym_CONTINUE] = ACTIONS(4213),
    [anon_sym_Continue] = ACTIONS(4213),
    [anon_sym_break] = ACTIONS(4213),
    [anon_sym_BREAK] = ACTIONS(4213),
    [anon_sym_Break] = ACTIONS(4213),
    [anon_sym_with] = ACTIONS(4213),
    [anon_sym_WITH] = ACTIONS(4213),
    [anon_sym_With] = ACTIONS(4213),
    [sym_asserterror_keyword] = ACTIONS(4215),
    [sym_page_keyword] = ACTIONS(4213),
    [anon_sym_codeunit] = ACTIONS(4213),
    [anon_sym_CODEUNIT] = ACTIONS(4213),
    [anon_sym_Codeunit] = ACTIONS(4213),
    [anon_sym_CodeUnit] = ACTIONS(4213),
    [anon_sym_COdeunit] = ACTIONS(4213),
    [anon_sym_codeUnit] = ACTIONS(4213),
    [sym_report_keyword] = ACTIONS(4213),
    [sym_query_keyword] = ACTIONS(4213),
    [anon_sym_xmlport] = ACTIONS(4213),
    [anon_sym_XMLPORT] = ACTIONS(4213),
    [anon_sym_Xmlport] = ACTIONS(4213),
    [anon_sym_XMLport] = ACTIONS(4213),
    [anon_sym_XMLPort] = ACTIONS(4213),
    [anon_sym_XmlPort] = ACTIONS(4213),
    [anon_sym_enum] = ACTIONS(4213),
    [anon_sym_ENUM] = ACTIONS(4213),
    [anon_sym_Enum] = ACTIONS(4213),
    [anon_sym_eNUM] = ACTIONS(4213),
    [anon_sym_eNum] = ACTIONS(4213),
    [anon_sym_ENum] = ACTIONS(4213),
    [sym_quoted_identifier] = ACTIONS(4215),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4215),
    [sym_integer] = ACTIONS(4213),
    [sym_continue_as_identifier] = ACTIONS(4215),
    [sym_preproc_open] = ACTIONS(4215),
  },
  [STATE(1792)] = {
    [sym_identifier] = ACTIONS(4776),
    [anon_sym_SEMI] = ACTIONS(4778),
    [anon_sym_DASH] = ACTIONS(4778),
    [aux_sym_boolean_token1] = ACTIONS(4776),
    [aux_sym_boolean_token2] = ACTIONS(4776),
    [sym_decimal] = ACTIONS(4776),
    [anon_sym_LPAREN] = ACTIONS(4778),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4776),
    [anon_sym_LBRACK] = ACTIONS(4778),
    [aux_sym_record_type_token1] = ACTIONS(4776),
    [aux_sym_basic_type_token21] = ACTIONS(4776),
    [aux_sym_basic_type_token22] = ACTIONS(4776),
    [aux_sym_basic_type_token48] = ACTIONS(4776),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4776),
    [anon_sym_POUNDif] = ACTIONS(4778),
    [anon_sym_POUNDIF] = ACTIONS(4778),
    [anon_sym_POUNDIf] = ACTIONS(4778),
    [anon_sym_not] = ACTIONS(4776),
    [anon_sym_NOT] = ACTIONS(4776),
    [anon_sym_Not] = ACTIONS(4776),
    [anon_sym_POUNDelse] = ACTIONS(4778),
    [anon_sym_POUNDELSE] = ACTIONS(4778),
    [anon_sym_POUNDElse] = ACTIONS(4778),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4776),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4776),
    [anon_sym_PLUS] = ACTIONS(4778),
    [sym_datetime_literal] = ACTIONS(4778),
    [sym_date_literal] = ACTIONS(4776),
    [sym_time_literal] = ACTIONS(4776),
    [sym_biginteger_literal] = ACTIONS(4778),
    [anon_sym_if] = ACTIONS(4776),
    [anon_sym_IF] = ACTIONS(4776),
    [anon_sym_If] = ACTIONS(4776),
    [anon_sym_else] = ACTIONS(4776),
    [anon_sym_ELSE] = ACTIONS(4776),
    [anon_sym_Else] = ACTIONS(4776),
    [anon_sym_case] = ACTIONS(4776),
    [anon_sym_CASE] = ACTIONS(4776),
    [anon_sym_Case] = ACTIONS(4776),
    [anon_sym_for] = ACTIONS(4776),
    [anon_sym_FOR] = ACTIONS(4776),
    [anon_sym_For] = ACTIONS(4776),
    [anon_sym_foreach] = ACTIONS(4776),
    [anon_sym_FOREACH] = ACTIONS(4776),
    [anon_sym_Foreach] = ACTIONS(4776),
    [anon_sym_while] = ACTIONS(4776),
    [anon_sym_WHILE] = ACTIONS(4776),
    [anon_sym_While] = ACTIONS(4776),
    [anon_sym_repeat] = ACTIONS(4776),
    [anon_sym_REPEAT] = ACTIONS(4776),
    [anon_sym_Repeat] = ACTIONS(4776),
    [anon_sym_until] = ACTIONS(4776),
    [anon_sym_UNTIL] = ACTIONS(4776),
    [anon_sym_Until] = ACTIONS(4776),
    [anon_sym_exit] = ACTIONS(4776),
    [anon_sym_EXIT] = ACTIONS(4776),
    [anon_sym_Exit] = ACTIONS(4776),
    [anon_sym_continue] = ACTIONS(4776),
    [anon_sym_CONTINUE] = ACTIONS(4776),
    [anon_sym_Continue] = ACTIONS(4776),
    [anon_sym_break] = ACTIONS(4776),
    [anon_sym_BREAK] = ACTIONS(4776),
    [anon_sym_Break] = ACTIONS(4776),
    [anon_sym_with] = ACTIONS(4776),
    [anon_sym_WITH] = ACTIONS(4776),
    [anon_sym_With] = ACTIONS(4776),
    [sym_asserterror_keyword] = ACTIONS(4778),
    [sym_page_keyword] = ACTIONS(4776),
    [anon_sym_codeunit] = ACTIONS(4776),
    [anon_sym_CODEUNIT] = ACTIONS(4776),
    [anon_sym_Codeunit] = ACTIONS(4776),
    [anon_sym_CodeUnit] = ACTIONS(4776),
    [anon_sym_COdeunit] = ACTIONS(4776),
    [anon_sym_codeUnit] = ACTIONS(4776),
    [sym_report_keyword] = ACTIONS(4776),
    [sym_query_keyword] = ACTIONS(4776),
    [anon_sym_xmlport] = ACTIONS(4776),
    [anon_sym_XMLPORT] = ACTIONS(4776),
    [anon_sym_Xmlport] = ACTIONS(4776),
    [anon_sym_XMLport] = ACTIONS(4776),
    [anon_sym_XMLPort] = ACTIONS(4776),
    [anon_sym_XmlPort] = ACTIONS(4776),
    [anon_sym_enum] = ACTIONS(4776),
    [anon_sym_ENUM] = ACTIONS(4776),
    [anon_sym_Enum] = ACTIONS(4776),
    [anon_sym_eNUM] = ACTIONS(4776),
    [anon_sym_eNum] = ACTIONS(4776),
    [anon_sym_ENum] = ACTIONS(4776),
    [sym_quoted_identifier] = ACTIONS(4778),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4778),
    [sym_integer] = ACTIONS(4776),
    [sym_continue_as_identifier] = ACTIONS(4778),
    [sym_preproc_open] = ACTIONS(4778),
  },
  [STATE(1793)] = {
    [sym_identifier] = ACTIONS(4772),
    [anon_sym_SEMI] = ACTIONS(4774),
    [anon_sym_DASH] = ACTIONS(4774),
    [aux_sym_boolean_token1] = ACTIONS(4772),
    [aux_sym_boolean_token2] = ACTIONS(4772),
    [sym_decimal] = ACTIONS(4772),
    [anon_sym_LPAREN] = ACTIONS(4774),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4772),
    [anon_sym_LBRACK] = ACTIONS(4774),
    [aux_sym_record_type_token1] = ACTIONS(4772),
    [aux_sym_basic_type_token21] = ACTIONS(4772),
    [aux_sym_basic_type_token22] = ACTIONS(4772),
    [aux_sym_basic_type_token48] = ACTIONS(4772),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4772),
    [anon_sym_POUNDif] = ACTIONS(4774),
    [anon_sym_POUNDIF] = ACTIONS(4774),
    [anon_sym_POUNDIf] = ACTIONS(4774),
    [anon_sym_not] = ACTIONS(4772),
    [anon_sym_NOT] = ACTIONS(4772),
    [anon_sym_Not] = ACTIONS(4772),
    [anon_sym_POUNDelse] = ACTIONS(4774),
    [anon_sym_POUNDELSE] = ACTIONS(4774),
    [anon_sym_POUNDElse] = ACTIONS(4774),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4772),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4772),
    [anon_sym_PLUS] = ACTIONS(4774),
    [sym_datetime_literal] = ACTIONS(4774),
    [sym_date_literal] = ACTIONS(4772),
    [sym_time_literal] = ACTIONS(4772),
    [sym_biginteger_literal] = ACTIONS(4774),
    [anon_sym_if] = ACTIONS(4772),
    [anon_sym_IF] = ACTIONS(4772),
    [anon_sym_If] = ACTIONS(4772),
    [anon_sym_else] = ACTIONS(4772),
    [anon_sym_ELSE] = ACTIONS(4772),
    [anon_sym_Else] = ACTIONS(4772),
    [anon_sym_case] = ACTIONS(4772),
    [anon_sym_CASE] = ACTIONS(4772),
    [anon_sym_Case] = ACTIONS(4772),
    [anon_sym_for] = ACTIONS(4772),
    [anon_sym_FOR] = ACTIONS(4772),
    [anon_sym_For] = ACTIONS(4772),
    [anon_sym_foreach] = ACTIONS(4772),
    [anon_sym_FOREACH] = ACTIONS(4772),
    [anon_sym_Foreach] = ACTIONS(4772),
    [anon_sym_while] = ACTIONS(4772),
    [anon_sym_WHILE] = ACTIONS(4772),
    [anon_sym_While] = ACTIONS(4772),
    [anon_sym_repeat] = ACTIONS(4772),
    [anon_sym_REPEAT] = ACTIONS(4772),
    [anon_sym_Repeat] = ACTIONS(4772),
    [anon_sym_until] = ACTIONS(4772),
    [anon_sym_UNTIL] = ACTIONS(4772),
    [anon_sym_Until] = ACTIONS(4772),
    [anon_sym_exit] = ACTIONS(4772),
    [anon_sym_EXIT] = ACTIONS(4772),
    [anon_sym_Exit] = ACTIONS(4772),
    [anon_sym_continue] = ACTIONS(4772),
    [anon_sym_CONTINUE] = ACTIONS(4772),
    [anon_sym_Continue] = ACTIONS(4772),
    [anon_sym_break] = ACTIONS(4772),
    [anon_sym_BREAK] = ACTIONS(4772),
    [anon_sym_Break] = ACTIONS(4772),
    [anon_sym_with] = ACTIONS(4772),
    [anon_sym_WITH] = ACTIONS(4772),
    [anon_sym_With] = ACTIONS(4772),
    [sym_asserterror_keyword] = ACTIONS(4774),
    [sym_page_keyword] = ACTIONS(4772),
    [anon_sym_codeunit] = ACTIONS(4772),
    [anon_sym_CODEUNIT] = ACTIONS(4772),
    [anon_sym_Codeunit] = ACTIONS(4772),
    [anon_sym_CodeUnit] = ACTIONS(4772),
    [anon_sym_COdeunit] = ACTIONS(4772),
    [anon_sym_codeUnit] = ACTIONS(4772),
    [sym_report_keyword] = ACTIONS(4772),
    [sym_query_keyword] = ACTIONS(4772),
    [anon_sym_xmlport] = ACTIONS(4772),
    [anon_sym_XMLPORT] = ACTIONS(4772),
    [anon_sym_Xmlport] = ACTIONS(4772),
    [anon_sym_XMLport] = ACTIONS(4772),
    [anon_sym_XMLPort] = ACTIONS(4772),
    [anon_sym_XmlPort] = ACTIONS(4772),
    [anon_sym_enum] = ACTIONS(4772),
    [anon_sym_ENUM] = ACTIONS(4772),
    [anon_sym_Enum] = ACTIONS(4772),
    [anon_sym_eNUM] = ACTIONS(4772),
    [anon_sym_eNum] = ACTIONS(4772),
    [anon_sym_ENum] = ACTIONS(4772),
    [sym_quoted_identifier] = ACTIONS(4774),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4774),
    [sym_integer] = ACTIONS(4772),
    [sym_continue_as_identifier] = ACTIONS(4774),
    [sym_preproc_open] = ACTIONS(4774),
  },
  [STATE(1794)] = {
    [sym_identifier] = ACTIONS(4780),
    [anon_sym_SEMI] = ACTIONS(4782),
    [anon_sym_DASH] = ACTIONS(4782),
    [aux_sym_boolean_token1] = ACTIONS(4780),
    [aux_sym_boolean_token2] = ACTIONS(4780),
    [sym_decimal] = ACTIONS(4780),
    [anon_sym_LPAREN] = ACTIONS(4782),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4780),
    [anon_sym_LBRACK] = ACTIONS(4782),
    [aux_sym_record_type_token1] = ACTIONS(4780),
    [aux_sym_basic_type_token21] = ACTIONS(4780),
    [aux_sym_basic_type_token22] = ACTIONS(4780),
    [aux_sym_basic_type_token48] = ACTIONS(4780),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4780),
    [anon_sym_POUNDif] = ACTIONS(4782),
    [anon_sym_POUNDIF] = ACTIONS(4782),
    [anon_sym_POUNDIf] = ACTIONS(4782),
    [anon_sym_not] = ACTIONS(4780),
    [anon_sym_NOT] = ACTIONS(4780),
    [anon_sym_Not] = ACTIONS(4780),
    [anon_sym_POUNDelse] = ACTIONS(4782),
    [anon_sym_POUNDELSE] = ACTIONS(4782),
    [anon_sym_POUNDElse] = ACTIONS(4782),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4780),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4780),
    [anon_sym_PLUS] = ACTIONS(4782),
    [sym_datetime_literal] = ACTIONS(4782),
    [sym_date_literal] = ACTIONS(4780),
    [sym_time_literal] = ACTIONS(4780),
    [sym_biginteger_literal] = ACTIONS(4782),
    [anon_sym_if] = ACTIONS(4780),
    [anon_sym_IF] = ACTIONS(4780),
    [anon_sym_If] = ACTIONS(4780),
    [anon_sym_else] = ACTIONS(4780),
    [anon_sym_ELSE] = ACTIONS(4780),
    [anon_sym_Else] = ACTIONS(4780),
    [anon_sym_case] = ACTIONS(4780),
    [anon_sym_CASE] = ACTIONS(4780),
    [anon_sym_Case] = ACTIONS(4780),
    [anon_sym_for] = ACTIONS(4780),
    [anon_sym_FOR] = ACTIONS(4780),
    [anon_sym_For] = ACTIONS(4780),
    [anon_sym_foreach] = ACTIONS(4780),
    [anon_sym_FOREACH] = ACTIONS(4780),
    [anon_sym_Foreach] = ACTIONS(4780),
    [anon_sym_while] = ACTIONS(4780),
    [anon_sym_WHILE] = ACTIONS(4780),
    [anon_sym_While] = ACTIONS(4780),
    [anon_sym_repeat] = ACTIONS(4780),
    [anon_sym_REPEAT] = ACTIONS(4780),
    [anon_sym_Repeat] = ACTIONS(4780),
    [anon_sym_until] = ACTIONS(4780),
    [anon_sym_UNTIL] = ACTIONS(4780),
    [anon_sym_Until] = ACTIONS(4780),
    [anon_sym_exit] = ACTIONS(4780),
    [anon_sym_EXIT] = ACTIONS(4780),
    [anon_sym_Exit] = ACTIONS(4780),
    [anon_sym_continue] = ACTIONS(4780),
    [anon_sym_CONTINUE] = ACTIONS(4780),
    [anon_sym_Continue] = ACTIONS(4780),
    [anon_sym_break] = ACTIONS(4780),
    [anon_sym_BREAK] = ACTIONS(4780),
    [anon_sym_Break] = ACTIONS(4780),
    [anon_sym_with] = ACTIONS(4780),
    [anon_sym_WITH] = ACTIONS(4780),
    [anon_sym_With] = ACTIONS(4780),
    [sym_asserterror_keyword] = ACTIONS(4782),
    [sym_page_keyword] = ACTIONS(4780),
    [anon_sym_codeunit] = ACTIONS(4780),
    [anon_sym_CODEUNIT] = ACTIONS(4780),
    [anon_sym_Codeunit] = ACTIONS(4780),
    [anon_sym_CodeUnit] = ACTIONS(4780),
    [anon_sym_COdeunit] = ACTIONS(4780),
    [anon_sym_codeUnit] = ACTIONS(4780),
    [sym_report_keyword] = ACTIONS(4780),
    [sym_query_keyword] = ACTIONS(4780),
    [anon_sym_xmlport] = ACTIONS(4780),
    [anon_sym_XMLPORT] = ACTIONS(4780),
    [anon_sym_Xmlport] = ACTIONS(4780),
    [anon_sym_XMLport] = ACTIONS(4780),
    [anon_sym_XMLPort] = ACTIONS(4780),
    [anon_sym_XmlPort] = ACTIONS(4780),
    [anon_sym_enum] = ACTIONS(4780),
    [anon_sym_ENUM] = ACTIONS(4780),
    [anon_sym_Enum] = ACTIONS(4780),
    [anon_sym_eNUM] = ACTIONS(4780),
    [anon_sym_eNum] = ACTIONS(4780),
    [anon_sym_ENum] = ACTIONS(4780),
    [sym_quoted_identifier] = ACTIONS(4782),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4782),
    [sym_integer] = ACTIONS(4780),
    [sym_continue_as_identifier] = ACTIONS(4782),
    [sym_preproc_open] = ACTIONS(4782),
  },
  [STATE(1795)] = {
    [sym_identifier] = ACTIONS(4784),
    [anon_sym_SEMI] = ACTIONS(4786),
    [anon_sym_DASH] = ACTIONS(4786),
    [aux_sym_boolean_token1] = ACTIONS(4784),
    [aux_sym_boolean_token2] = ACTIONS(4784),
    [sym_decimal] = ACTIONS(4784),
    [anon_sym_LPAREN] = ACTIONS(4786),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4784),
    [anon_sym_LBRACK] = ACTIONS(4786),
    [aux_sym_record_type_token1] = ACTIONS(4784),
    [aux_sym_basic_type_token21] = ACTIONS(4784),
    [aux_sym_basic_type_token22] = ACTIONS(4784),
    [aux_sym_basic_type_token48] = ACTIONS(4784),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4784),
    [anon_sym_POUNDif] = ACTIONS(4786),
    [anon_sym_POUNDIF] = ACTIONS(4786),
    [anon_sym_POUNDIf] = ACTIONS(4786),
    [anon_sym_not] = ACTIONS(4784),
    [anon_sym_NOT] = ACTIONS(4784),
    [anon_sym_Not] = ACTIONS(4784),
    [anon_sym_POUNDelse] = ACTIONS(4786),
    [anon_sym_POUNDELSE] = ACTIONS(4786),
    [anon_sym_POUNDElse] = ACTIONS(4786),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4784),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4784),
    [anon_sym_PLUS] = ACTIONS(4786),
    [sym_datetime_literal] = ACTIONS(4786),
    [sym_date_literal] = ACTIONS(4784),
    [sym_time_literal] = ACTIONS(4784),
    [sym_biginteger_literal] = ACTIONS(4786),
    [anon_sym_if] = ACTIONS(4784),
    [anon_sym_IF] = ACTIONS(4784),
    [anon_sym_If] = ACTIONS(4784),
    [anon_sym_else] = ACTIONS(4784),
    [anon_sym_ELSE] = ACTIONS(4784),
    [anon_sym_Else] = ACTIONS(4784),
    [anon_sym_case] = ACTIONS(4784),
    [anon_sym_CASE] = ACTIONS(4784),
    [anon_sym_Case] = ACTIONS(4784),
    [anon_sym_for] = ACTIONS(4784),
    [anon_sym_FOR] = ACTIONS(4784),
    [anon_sym_For] = ACTIONS(4784),
    [anon_sym_foreach] = ACTIONS(4784),
    [anon_sym_FOREACH] = ACTIONS(4784),
    [anon_sym_Foreach] = ACTIONS(4784),
    [anon_sym_while] = ACTIONS(4784),
    [anon_sym_WHILE] = ACTIONS(4784),
    [anon_sym_While] = ACTIONS(4784),
    [anon_sym_repeat] = ACTIONS(4784),
    [anon_sym_REPEAT] = ACTIONS(4784),
    [anon_sym_Repeat] = ACTIONS(4784),
    [anon_sym_until] = ACTIONS(4784),
    [anon_sym_UNTIL] = ACTIONS(4784),
    [anon_sym_Until] = ACTIONS(4784),
    [anon_sym_exit] = ACTIONS(4784),
    [anon_sym_EXIT] = ACTIONS(4784),
    [anon_sym_Exit] = ACTIONS(4784),
    [anon_sym_continue] = ACTIONS(4784),
    [anon_sym_CONTINUE] = ACTIONS(4784),
    [anon_sym_Continue] = ACTIONS(4784),
    [anon_sym_break] = ACTIONS(4784),
    [anon_sym_BREAK] = ACTIONS(4784),
    [anon_sym_Break] = ACTIONS(4784),
    [anon_sym_with] = ACTIONS(4784),
    [anon_sym_WITH] = ACTIONS(4784),
    [anon_sym_With] = ACTIONS(4784),
    [sym_asserterror_keyword] = ACTIONS(4786),
    [sym_page_keyword] = ACTIONS(4784),
    [anon_sym_codeunit] = ACTIONS(4784),
    [anon_sym_CODEUNIT] = ACTIONS(4784),
    [anon_sym_Codeunit] = ACTIONS(4784),
    [anon_sym_CodeUnit] = ACTIONS(4784),
    [anon_sym_COdeunit] = ACTIONS(4784),
    [anon_sym_codeUnit] = ACTIONS(4784),
    [sym_report_keyword] = ACTIONS(4784),
    [sym_query_keyword] = ACTIONS(4784),
    [anon_sym_xmlport] = ACTIONS(4784),
    [anon_sym_XMLPORT] = ACTIONS(4784),
    [anon_sym_Xmlport] = ACTIONS(4784),
    [anon_sym_XMLport] = ACTIONS(4784),
    [anon_sym_XMLPort] = ACTIONS(4784),
    [anon_sym_XmlPort] = ACTIONS(4784),
    [anon_sym_enum] = ACTIONS(4784),
    [anon_sym_ENUM] = ACTIONS(4784),
    [anon_sym_Enum] = ACTIONS(4784),
    [anon_sym_eNUM] = ACTIONS(4784),
    [anon_sym_eNum] = ACTIONS(4784),
    [anon_sym_ENum] = ACTIONS(4784),
    [sym_quoted_identifier] = ACTIONS(4786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4786),
    [sym_integer] = ACTIONS(4784),
    [sym_continue_as_identifier] = ACTIONS(4786),
    [sym_preproc_open] = ACTIONS(4786),
  },
  [STATE(1796)] = {
    [sym_identifier] = ACTIONS(4780),
    [anon_sym_SEMI] = ACTIONS(4782),
    [anon_sym_DASH] = ACTIONS(4782),
    [aux_sym_boolean_token1] = ACTIONS(4780),
    [aux_sym_boolean_token2] = ACTIONS(4780),
    [sym_decimal] = ACTIONS(4780),
    [anon_sym_LPAREN] = ACTIONS(4782),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4780),
    [anon_sym_LBRACK] = ACTIONS(4782),
    [aux_sym_record_type_token1] = ACTIONS(4780),
    [aux_sym_basic_type_token21] = ACTIONS(4780),
    [aux_sym_basic_type_token22] = ACTIONS(4780),
    [aux_sym_basic_type_token48] = ACTIONS(4780),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4780),
    [anon_sym_POUNDif] = ACTIONS(4782),
    [anon_sym_POUNDIF] = ACTIONS(4782),
    [anon_sym_POUNDIf] = ACTIONS(4782),
    [anon_sym_not] = ACTIONS(4780),
    [anon_sym_NOT] = ACTIONS(4780),
    [anon_sym_Not] = ACTIONS(4780),
    [anon_sym_POUNDelse] = ACTIONS(4782),
    [anon_sym_POUNDELSE] = ACTIONS(4782),
    [anon_sym_POUNDElse] = ACTIONS(4782),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4780),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4780),
    [anon_sym_PLUS] = ACTIONS(4782),
    [sym_datetime_literal] = ACTIONS(4782),
    [sym_date_literal] = ACTIONS(4780),
    [sym_time_literal] = ACTIONS(4780),
    [sym_biginteger_literal] = ACTIONS(4782),
    [anon_sym_if] = ACTIONS(4780),
    [anon_sym_IF] = ACTIONS(4780),
    [anon_sym_If] = ACTIONS(4780),
    [anon_sym_else] = ACTIONS(4780),
    [anon_sym_ELSE] = ACTIONS(4780),
    [anon_sym_Else] = ACTIONS(4780),
    [anon_sym_case] = ACTIONS(4780),
    [anon_sym_CASE] = ACTIONS(4780),
    [anon_sym_Case] = ACTIONS(4780),
    [anon_sym_for] = ACTIONS(4780),
    [anon_sym_FOR] = ACTIONS(4780),
    [anon_sym_For] = ACTIONS(4780),
    [anon_sym_foreach] = ACTIONS(4780),
    [anon_sym_FOREACH] = ACTIONS(4780),
    [anon_sym_Foreach] = ACTIONS(4780),
    [anon_sym_while] = ACTIONS(4780),
    [anon_sym_WHILE] = ACTIONS(4780),
    [anon_sym_While] = ACTIONS(4780),
    [anon_sym_repeat] = ACTIONS(4780),
    [anon_sym_REPEAT] = ACTIONS(4780),
    [anon_sym_Repeat] = ACTIONS(4780),
    [anon_sym_until] = ACTIONS(4780),
    [anon_sym_UNTIL] = ACTIONS(4780),
    [anon_sym_Until] = ACTIONS(4780),
    [anon_sym_exit] = ACTIONS(4780),
    [anon_sym_EXIT] = ACTIONS(4780),
    [anon_sym_Exit] = ACTIONS(4780),
    [anon_sym_continue] = ACTIONS(4780),
    [anon_sym_CONTINUE] = ACTIONS(4780),
    [anon_sym_Continue] = ACTIONS(4780),
    [anon_sym_break] = ACTIONS(4780),
    [anon_sym_BREAK] = ACTIONS(4780),
    [anon_sym_Break] = ACTIONS(4780),
    [anon_sym_with] = ACTIONS(4780),
    [anon_sym_WITH] = ACTIONS(4780),
    [anon_sym_With] = ACTIONS(4780),
    [sym_asserterror_keyword] = ACTIONS(4782),
    [sym_page_keyword] = ACTIONS(4780),
    [anon_sym_codeunit] = ACTIONS(4780),
    [anon_sym_CODEUNIT] = ACTIONS(4780),
    [anon_sym_Codeunit] = ACTIONS(4780),
    [anon_sym_CodeUnit] = ACTIONS(4780),
    [anon_sym_COdeunit] = ACTIONS(4780),
    [anon_sym_codeUnit] = ACTIONS(4780),
    [sym_report_keyword] = ACTIONS(4780),
    [sym_query_keyword] = ACTIONS(4780),
    [anon_sym_xmlport] = ACTIONS(4780),
    [anon_sym_XMLPORT] = ACTIONS(4780),
    [anon_sym_Xmlport] = ACTIONS(4780),
    [anon_sym_XMLport] = ACTIONS(4780),
    [anon_sym_XMLPort] = ACTIONS(4780),
    [anon_sym_XmlPort] = ACTIONS(4780),
    [anon_sym_enum] = ACTIONS(4780),
    [anon_sym_ENUM] = ACTIONS(4780),
    [anon_sym_Enum] = ACTIONS(4780),
    [anon_sym_eNUM] = ACTIONS(4780),
    [anon_sym_eNum] = ACTIONS(4780),
    [anon_sym_ENum] = ACTIONS(4780),
    [sym_quoted_identifier] = ACTIONS(4782),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4782),
    [sym_integer] = ACTIONS(4780),
    [sym_continue_as_identifier] = ACTIONS(4782),
    [sym_preproc_open] = ACTIONS(4782),
  },
  [STATE(1797)] = {
    [sym_identifier] = ACTIONS(4788),
    [anon_sym_SEMI] = ACTIONS(4790),
    [anon_sym_DASH] = ACTIONS(4790),
    [aux_sym_boolean_token1] = ACTIONS(4788),
    [aux_sym_boolean_token2] = ACTIONS(4788),
    [sym_decimal] = ACTIONS(4788),
    [anon_sym_LPAREN] = ACTIONS(4790),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4788),
    [anon_sym_LBRACK] = ACTIONS(4790),
    [aux_sym_record_type_token1] = ACTIONS(4788),
    [aux_sym_basic_type_token21] = ACTIONS(4788),
    [aux_sym_basic_type_token22] = ACTIONS(4788),
    [aux_sym_basic_type_token48] = ACTIONS(4788),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4788),
    [anon_sym_POUNDif] = ACTIONS(4790),
    [anon_sym_POUNDIF] = ACTIONS(4790),
    [anon_sym_POUNDIf] = ACTIONS(4790),
    [anon_sym_not] = ACTIONS(4788),
    [anon_sym_NOT] = ACTIONS(4788),
    [anon_sym_Not] = ACTIONS(4788),
    [anon_sym_POUNDelse] = ACTIONS(4790),
    [anon_sym_POUNDELSE] = ACTIONS(4790),
    [anon_sym_POUNDElse] = ACTIONS(4790),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4788),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4788),
    [anon_sym_PLUS] = ACTIONS(4790),
    [sym_datetime_literal] = ACTIONS(4790),
    [sym_date_literal] = ACTIONS(4788),
    [sym_time_literal] = ACTIONS(4788),
    [sym_biginteger_literal] = ACTIONS(4790),
    [anon_sym_if] = ACTIONS(4788),
    [anon_sym_IF] = ACTIONS(4788),
    [anon_sym_If] = ACTIONS(4788),
    [anon_sym_else] = ACTIONS(4788),
    [anon_sym_ELSE] = ACTIONS(4788),
    [anon_sym_Else] = ACTIONS(4788),
    [anon_sym_case] = ACTIONS(4788),
    [anon_sym_CASE] = ACTIONS(4788),
    [anon_sym_Case] = ACTIONS(4788),
    [anon_sym_for] = ACTIONS(4788),
    [anon_sym_FOR] = ACTIONS(4788),
    [anon_sym_For] = ACTIONS(4788),
    [anon_sym_foreach] = ACTIONS(4788),
    [anon_sym_FOREACH] = ACTIONS(4788),
    [anon_sym_Foreach] = ACTIONS(4788),
    [anon_sym_while] = ACTIONS(4788),
    [anon_sym_WHILE] = ACTIONS(4788),
    [anon_sym_While] = ACTIONS(4788),
    [anon_sym_repeat] = ACTIONS(4788),
    [anon_sym_REPEAT] = ACTIONS(4788),
    [anon_sym_Repeat] = ACTIONS(4788),
    [anon_sym_until] = ACTIONS(4788),
    [anon_sym_UNTIL] = ACTIONS(4788),
    [anon_sym_Until] = ACTIONS(4788),
    [anon_sym_exit] = ACTIONS(4788),
    [anon_sym_EXIT] = ACTIONS(4788),
    [anon_sym_Exit] = ACTIONS(4788),
    [anon_sym_continue] = ACTIONS(4788),
    [anon_sym_CONTINUE] = ACTIONS(4788),
    [anon_sym_Continue] = ACTIONS(4788),
    [anon_sym_break] = ACTIONS(4788),
    [anon_sym_BREAK] = ACTIONS(4788),
    [anon_sym_Break] = ACTIONS(4788),
    [anon_sym_with] = ACTIONS(4788),
    [anon_sym_WITH] = ACTIONS(4788),
    [anon_sym_With] = ACTIONS(4788),
    [sym_asserterror_keyword] = ACTIONS(4790),
    [sym_page_keyword] = ACTIONS(4788),
    [anon_sym_codeunit] = ACTIONS(4788),
    [anon_sym_CODEUNIT] = ACTIONS(4788),
    [anon_sym_Codeunit] = ACTIONS(4788),
    [anon_sym_CodeUnit] = ACTIONS(4788),
    [anon_sym_COdeunit] = ACTIONS(4788),
    [anon_sym_codeUnit] = ACTIONS(4788),
    [sym_report_keyword] = ACTIONS(4788),
    [sym_query_keyword] = ACTIONS(4788),
    [anon_sym_xmlport] = ACTIONS(4788),
    [anon_sym_XMLPORT] = ACTIONS(4788),
    [anon_sym_Xmlport] = ACTIONS(4788),
    [anon_sym_XMLport] = ACTIONS(4788),
    [anon_sym_XMLPort] = ACTIONS(4788),
    [anon_sym_XmlPort] = ACTIONS(4788),
    [anon_sym_enum] = ACTIONS(4788),
    [anon_sym_ENUM] = ACTIONS(4788),
    [anon_sym_Enum] = ACTIONS(4788),
    [anon_sym_eNUM] = ACTIONS(4788),
    [anon_sym_eNum] = ACTIONS(4788),
    [anon_sym_ENum] = ACTIONS(4788),
    [sym_quoted_identifier] = ACTIONS(4790),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4790),
    [sym_integer] = ACTIONS(4788),
    [sym_continue_as_identifier] = ACTIONS(4790),
    [sym_preproc_open] = ACTIONS(4790),
  },
  [STATE(1798)] = {
    [sym_identifier] = ACTIONS(4792),
    [anon_sym_SEMI] = ACTIONS(4794),
    [anon_sym_DASH] = ACTIONS(4794),
    [aux_sym_boolean_token1] = ACTIONS(4792),
    [aux_sym_boolean_token2] = ACTIONS(4792),
    [sym_decimal] = ACTIONS(4792),
    [anon_sym_LPAREN] = ACTIONS(4794),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4792),
    [anon_sym_LBRACK] = ACTIONS(4794),
    [aux_sym_record_type_token1] = ACTIONS(4792),
    [aux_sym_basic_type_token21] = ACTIONS(4792),
    [aux_sym_basic_type_token22] = ACTIONS(4792),
    [aux_sym_basic_type_token48] = ACTIONS(4792),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4792),
    [anon_sym_POUNDif] = ACTIONS(4794),
    [anon_sym_POUNDIF] = ACTIONS(4794),
    [anon_sym_POUNDIf] = ACTIONS(4794),
    [anon_sym_not] = ACTIONS(4792),
    [anon_sym_NOT] = ACTIONS(4792),
    [anon_sym_Not] = ACTIONS(4792),
    [anon_sym_POUNDelse] = ACTIONS(4794),
    [anon_sym_POUNDELSE] = ACTIONS(4794),
    [anon_sym_POUNDElse] = ACTIONS(4794),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4792),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4792),
    [anon_sym_PLUS] = ACTIONS(4794),
    [sym_datetime_literal] = ACTIONS(4794),
    [sym_date_literal] = ACTIONS(4792),
    [sym_time_literal] = ACTIONS(4792),
    [sym_biginteger_literal] = ACTIONS(4794),
    [anon_sym_if] = ACTIONS(4792),
    [anon_sym_IF] = ACTIONS(4792),
    [anon_sym_If] = ACTIONS(4792),
    [anon_sym_else] = ACTIONS(4792),
    [anon_sym_ELSE] = ACTIONS(4792),
    [anon_sym_Else] = ACTIONS(4792),
    [anon_sym_case] = ACTIONS(4792),
    [anon_sym_CASE] = ACTIONS(4792),
    [anon_sym_Case] = ACTIONS(4792),
    [anon_sym_for] = ACTIONS(4792),
    [anon_sym_FOR] = ACTIONS(4792),
    [anon_sym_For] = ACTIONS(4792),
    [anon_sym_foreach] = ACTIONS(4792),
    [anon_sym_FOREACH] = ACTIONS(4792),
    [anon_sym_Foreach] = ACTIONS(4792),
    [anon_sym_while] = ACTIONS(4792),
    [anon_sym_WHILE] = ACTIONS(4792),
    [anon_sym_While] = ACTIONS(4792),
    [anon_sym_repeat] = ACTIONS(4792),
    [anon_sym_REPEAT] = ACTIONS(4792),
    [anon_sym_Repeat] = ACTIONS(4792),
    [anon_sym_until] = ACTIONS(4792),
    [anon_sym_UNTIL] = ACTIONS(4792),
    [anon_sym_Until] = ACTIONS(4792),
    [anon_sym_exit] = ACTIONS(4792),
    [anon_sym_EXIT] = ACTIONS(4792),
    [anon_sym_Exit] = ACTIONS(4792),
    [anon_sym_continue] = ACTIONS(4792),
    [anon_sym_CONTINUE] = ACTIONS(4792),
    [anon_sym_Continue] = ACTIONS(4792),
    [anon_sym_break] = ACTIONS(4792),
    [anon_sym_BREAK] = ACTIONS(4792),
    [anon_sym_Break] = ACTIONS(4792),
    [anon_sym_with] = ACTIONS(4792),
    [anon_sym_WITH] = ACTIONS(4792),
    [anon_sym_With] = ACTIONS(4792),
    [sym_asserterror_keyword] = ACTIONS(4794),
    [sym_page_keyword] = ACTIONS(4792),
    [anon_sym_codeunit] = ACTIONS(4792),
    [anon_sym_CODEUNIT] = ACTIONS(4792),
    [anon_sym_Codeunit] = ACTIONS(4792),
    [anon_sym_CodeUnit] = ACTIONS(4792),
    [anon_sym_COdeunit] = ACTIONS(4792),
    [anon_sym_codeUnit] = ACTIONS(4792),
    [sym_report_keyword] = ACTIONS(4792),
    [sym_query_keyword] = ACTIONS(4792),
    [anon_sym_xmlport] = ACTIONS(4792),
    [anon_sym_XMLPORT] = ACTIONS(4792),
    [anon_sym_Xmlport] = ACTIONS(4792),
    [anon_sym_XMLport] = ACTIONS(4792),
    [anon_sym_XMLPort] = ACTIONS(4792),
    [anon_sym_XmlPort] = ACTIONS(4792),
    [anon_sym_enum] = ACTIONS(4792),
    [anon_sym_ENUM] = ACTIONS(4792),
    [anon_sym_Enum] = ACTIONS(4792),
    [anon_sym_eNUM] = ACTIONS(4792),
    [anon_sym_eNum] = ACTIONS(4792),
    [anon_sym_ENum] = ACTIONS(4792),
    [sym_quoted_identifier] = ACTIONS(4794),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4794),
    [sym_integer] = ACTIONS(4792),
    [sym_continue_as_identifier] = ACTIONS(4794),
    [sym_preproc_open] = ACTIONS(4794),
  },
  [STATE(1799)] = {
    [sym_identifier] = ACTIONS(4796),
    [anon_sym_SEMI] = ACTIONS(4798),
    [anon_sym_DASH] = ACTIONS(4798),
    [aux_sym_boolean_token1] = ACTIONS(4796),
    [aux_sym_boolean_token2] = ACTIONS(4796),
    [sym_decimal] = ACTIONS(4796),
    [anon_sym_LPAREN] = ACTIONS(4798),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4796),
    [anon_sym_LBRACK] = ACTIONS(4798),
    [aux_sym_record_type_token1] = ACTIONS(4796),
    [aux_sym_basic_type_token21] = ACTIONS(4796),
    [aux_sym_basic_type_token22] = ACTIONS(4796),
    [aux_sym_basic_type_token48] = ACTIONS(4796),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4796),
    [anon_sym_POUNDif] = ACTIONS(4798),
    [anon_sym_POUNDIF] = ACTIONS(4798),
    [anon_sym_POUNDIf] = ACTIONS(4798),
    [anon_sym_not] = ACTIONS(4796),
    [anon_sym_NOT] = ACTIONS(4796),
    [anon_sym_Not] = ACTIONS(4796),
    [anon_sym_POUNDelse] = ACTIONS(4798),
    [anon_sym_POUNDELSE] = ACTIONS(4798),
    [anon_sym_POUNDElse] = ACTIONS(4798),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4796),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4796),
    [anon_sym_PLUS] = ACTIONS(4798),
    [sym_datetime_literal] = ACTIONS(4798),
    [sym_date_literal] = ACTIONS(4796),
    [sym_time_literal] = ACTIONS(4796),
    [sym_biginteger_literal] = ACTIONS(4798),
    [anon_sym_if] = ACTIONS(4796),
    [anon_sym_IF] = ACTIONS(4796),
    [anon_sym_If] = ACTIONS(4796),
    [anon_sym_else] = ACTIONS(4796),
    [anon_sym_ELSE] = ACTIONS(4796),
    [anon_sym_Else] = ACTIONS(4796),
    [anon_sym_case] = ACTIONS(4796),
    [anon_sym_CASE] = ACTIONS(4796),
    [anon_sym_Case] = ACTIONS(4796),
    [anon_sym_for] = ACTIONS(4796),
    [anon_sym_FOR] = ACTIONS(4796),
    [anon_sym_For] = ACTIONS(4796),
    [anon_sym_foreach] = ACTIONS(4796),
    [anon_sym_FOREACH] = ACTIONS(4796),
    [anon_sym_Foreach] = ACTIONS(4796),
    [anon_sym_while] = ACTIONS(4796),
    [anon_sym_WHILE] = ACTIONS(4796),
    [anon_sym_While] = ACTIONS(4796),
    [anon_sym_repeat] = ACTIONS(4796),
    [anon_sym_REPEAT] = ACTIONS(4796),
    [anon_sym_Repeat] = ACTIONS(4796),
    [anon_sym_until] = ACTIONS(4796),
    [anon_sym_UNTIL] = ACTIONS(4796),
    [anon_sym_Until] = ACTIONS(4796),
    [anon_sym_exit] = ACTIONS(4796),
    [anon_sym_EXIT] = ACTIONS(4796),
    [anon_sym_Exit] = ACTIONS(4796),
    [anon_sym_continue] = ACTIONS(4796),
    [anon_sym_CONTINUE] = ACTIONS(4796),
    [anon_sym_Continue] = ACTIONS(4796),
    [anon_sym_break] = ACTIONS(4796),
    [anon_sym_BREAK] = ACTIONS(4796),
    [anon_sym_Break] = ACTIONS(4796),
    [anon_sym_with] = ACTIONS(4796),
    [anon_sym_WITH] = ACTIONS(4796),
    [anon_sym_With] = ACTIONS(4796),
    [sym_asserterror_keyword] = ACTIONS(4798),
    [sym_page_keyword] = ACTIONS(4796),
    [anon_sym_codeunit] = ACTIONS(4796),
    [anon_sym_CODEUNIT] = ACTIONS(4796),
    [anon_sym_Codeunit] = ACTIONS(4796),
    [anon_sym_CodeUnit] = ACTIONS(4796),
    [anon_sym_COdeunit] = ACTIONS(4796),
    [anon_sym_codeUnit] = ACTIONS(4796),
    [sym_report_keyword] = ACTIONS(4796),
    [sym_query_keyword] = ACTIONS(4796),
    [anon_sym_xmlport] = ACTIONS(4796),
    [anon_sym_XMLPORT] = ACTIONS(4796),
    [anon_sym_Xmlport] = ACTIONS(4796),
    [anon_sym_XMLport] = ACTIONS(4796),
    [anon_sym_XMLPort] = ACTIONS(4796),
    [anon_sym_XmlPort] = ACTIONS(4796),
    [anon_sym_enum] = ACTIONS(4796),
    [anon_sym_ENUM] = ACTIONS(4796),
    [anon_sym_Enum] = ACTIONS(4796),
    [anon_sym_eNUM] = ACTIONS(4796),
    [anon_sym_eNum] = ACTIONS(4796),
    [anon_sym_ENum] = ACTIONS(4796),
    [sym_quoted_identifier] = ACTIONS(4798),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4798),
    [sym_integer] = ACTIONS(4796),
    [sym_continue_as_identifier] = ACTIONS(4798),
    [sym_preproc_open] = ACTIONS(4798),
  },
  [STATE(1800)] = {
    [sym_identifier] = ACTIONS(4800),
    [anon_sym_SEMI] = ACTIONS(4802),
    [anon_sym_DASH] = ACTIONS(4802),
    [aux_sym_boolean_token1] = ACTIONS(4800),
    [aux_sym_boolean_token2] = ACTIONS(4800),
    [sym_decimal] = ACTIONS(4800),
    [anon_sym_LPAREN] = ACTIONS(4802),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4800),
    [anon_sym_LBRACK] = ACTIONS(4802),
    [aux_sym_record_type_token1] = ACTIONS(4800),
    [aux_sym_basic_type_token21] = ACTIONS(4800),
    [aux_sym_basic_type_token22] = ACTIONS(4800),
    [aux_sym_basic_type_token48] = ACTIONS(4800),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4800),
    [anon_sym_POUNDif] = ACTIONS(4802),
    [anon_sym_POUNDIF] = ACTIONS(4802),
    [anon_sym_POUNDIf] = ACTIONS(4802),
    [anon_sym_not] = ACTIONS(4800),
    [anon_sym_NOT] = ACTIONS(4800),
    [anon_sym_Not] = ACTIONS(4800),
    [anon_sym_POUNDelse] = ACTIONS(4802),
    [anon_sym_POUNDELSE] = ACTIONS(4802),
    [anon_sym_POUNDElse] = ACTIONS(4802),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4800),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4800),
    [anon_sym_PLUS] = ACTIONS(4802),
    [sym_datetime_literal] = ACTIONS(4802),
    [sym_date_literal] = ACTIONS(4800),
    [sym_time_literal] = ACTIONS(4800),
    [sym_biginteger_literal] = ACTIONS(4802),
    [anon_sym_if] = ACTIONS(4800),
    [anon_sym_IF] = ACTIONS(4800),
    [anon_sym_If] = ACTIONS(4800),
    [anon_sym_else] = ACTIONS(4800),
    [anon_sym_ELSE] = ACTIONS(4800),
    [anon_sym_Else] = ACTIONS(4800),
    [anon_sym_case] = ACTIONS(4800),
    [anon_sym_CASE] = ACTIONS(4800),
    [anon_sym_Case] = ACTIONS(4800),
    [anon_sym_for] = ACTIONS(4800),
    [anon_sym_FOR] = ACTIONS(4800),
    [anon_sym_For] = ACTIONS(4800),
    [anon_sym_foreach] = ACTIONS(4800),
    [anon_sym_FOREACH] = ACTIONS(4800),
    [anon_sym_Foreach] = ACTIONS(4800),
    [anon_sym_while] = ACTIONS(4800),
    [anon_sym_WHILE] = ACTIONS(4800),
    [anon_sym_While] = ACTIONS(4800),
    [anon_sym_repeat] = ACTIONS(4800),
    [anon_sym_REPEAT] = ACTIONS(4800),
    [anon_sym_Repeat] = ACTIONS(4800),
    [anon_sym_until] = ACTIONS(4800),
    [anon_sym_UNTIL] = ACTIONS(4800),
    [anon_sym_Until] = ACTIONS(4800),
    [anon_sym_exit] = ACTIONS(4800),
    [anon_sym_EXIT] = ACTIONS(4800),
    [anon_sym_Exit] = ACTIONS(4800),
    [anon_sym_continue] = ACTIONS(4800),
    [anon_sym_CONTINUE] = ACTIONS(4800),
    [anon_sym_Continue] = ACTIONS(4800),
    [anon_sym_break] = ACTIONS(4800),
    [anon_sym_BREAK] = ACTIONS(4800),
    [anon_sym_Break] = ACTIONS(4800),
    [anon_sym_with] = ACTIONS(4800),
    [anon_sym_WITH] = ACTIONS(4800),
    [anon_sym_With] = ACTIONS(4800),
    [sym_asserterror_keyword] = ACTIONS(4802),
    [sym_page_keyword] = ACTIONS(4800),
    [anon_sym_codeunit] = ACTIONS(4800),
    [anon_sym_CODEUNIT] = ACTIONS(4800),
    [anon_sym_Codeunit] = ACTIONS(4800),
    [anon_sym_CodeUnit] = ACTIONS(4800),
    [anon_sym_COdeunit] = ACTIONS(4800),
    [anon_sym_codeUnit] = ACTIONS(4800),
    [sym_report_keyword] = ACTIONS(4800),
    [sym_query_keyword] = ACTIONS(4800),
    [anon_sym_xmlport] = ACTIONS(4800),
    [anon_sym_XMLPORT] = ACTIONS(4800),
    [anon_sym_Xmlport] = ACTIONS(4800),
    [anon_sym_XMLport] = ACTIONS(4800),
    [anon_sym_XMLPort] = ACTIONS(4800),
    [anon_sym_XmlPort] = ACTIONS(4800),
    [anon_sym_enum] = ACTIONS(4800),
    [anon_sym_ENUM] = ACTIONS(4800),
    [anon_sym_Enum] = ACTIONS(4800),
    [anon_sym_eNUM] = ACTIONS(4800),
    [anon_sym_eNum] = ACTIONS(4800),
    [anon_sym_ENum] = ACTIONS(4800),
    [sym_quoted_identifier] = ACTIONS(4802),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4802),
    [sym_integer] = ACTIONS(4800),
    [sym_continue_as_identifier] = ACTIONS(4802),
    [sym_preproc_open] = ACTIONS(4802),
  },
  [STATE(1801)] = {
    [sym_identifier] = ACTIONS(4189),
    [anon_sym_SEMI] = ACTIONS(4191),
    [anon_sym_DASH] = ACTIONS(4191),
    [aux_sym_boolean_token1] = ACTIONS(4189),
    [aux_sym_boolean_token2] = ACTIONS(4189),
    [sym_decimal] = ACTIONS(4189),
    [anon_sym_LPAREN] = ACTIONS(4191),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4189),
    [anon_sym_LBRACK] = ACTIONS(4191),
    [aux_sym_record_type_token1] = ACTIONS(4189),
    [aux_sym_basic_type_token21] = ACTIONS(4189),
    [aux_sym_basic_type_token22] = ACTIONS(4189),
    [aux_sym_basic_type_token48] = ACTIONS(4189),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4189),
    [anon_sym_POUNDif] = ACTIONS(4191),
    [anon_sym_POUNDIF] = ACTIONS(4191),
    [anon_sym_POUNDIf] = ACTIONS(4191),
    [anon_sym_not] = ACTIONS(4189),
    [anon_sym_NOT] = ACTIONS(4189),
    [anon_sym_Not] = ACTIONS(4189),
    [anon_sym_POUNDelse] = ACTIONS(4191),
    [anon_sym_POUNDELSE] = ACTIONS(4191),
    [anon_sym_POUNDElse] = ACTIONS(4191),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4189),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4189),
    [anon_sym_PLUS] = ACTIONS(4191),
    [sym_datetime_literal] = ACTIONS(4191),
    [sym_date_literal] = ACTIONS(4189),
    [sym_time_literal] = ACTIONS(4189),
    [sym_biginteger_literal] = ACTIONS(4191),
    [anon_sym_if] = ACTIONS(4189),
    [anon_sym_IF] = ACTIONS(4189),
    [anon_sym_If] = ACTIONS(4189),
    [anon_sym_else] = ACTIONS(4189),
    [anon_sym_ELSE] = ACTIONS(4189),
    [anon_sym_Else] = ACTIONS(4189),
    [anon_sym_case] = ACTIONS(4189),
    [anon_sym_CASE] = ACTIONS(4189),
    [anon_sym_Case] = ACTIONS(4189),
    [anon_sym_for] = ACTIONS(4189),
    [anon_sym_FOR] = ACTIONS(4189),
    [anon_sym_For] = ACTIONS(4189),
    [anon_sym_foreach] = ACTIONS(4189),
    [anon_sym_FOREACH] = ACTIONS(4189),
    [anon_sym_Foreach] = ACTIONS(4189),
    [anon_sym_while] = ACTIONS(4189),
    [anon_sym_WHILE] = ACTIONS(4189),
    [anon_sym_While] = ACTIONS(4189),
    [anon_sym_repeat] = ACTIONS(4189),
    [anon_sym_REPEAT] = ACTIONS(4189),
    [anon_sym_Repeat] = ACTIONS(4189),
    [anon_sym_until] = ACTIONS(4189),
    [anon_sym_UNTIL] = ACTIONS(4189),
    [anon_sym_Until] = ACTIONS(4189),
    [anon_sym_exit] = ACTIONS(4189),
    [anon_sym_EXIT] = ACTIONS(4189),
    [anon_sym_Exit] = ACTIONS(4189),
    [anon_sym_continue] = ACTIONS(4189),
    [anon_sym_CONTINUE] = ACTIONS(4189),
    [anon_sym_Continue] = ACTIONS(4189),
    [anon_sym_break] = ACTIONS(4189),
    [anon_sym_BREAK] = ACTIONS(4189),
    [anon_sym_Break] = ACTIONS(4189),
    [anon_sym_with] = ACTIONS(4189),
    [anon_sym_WITH] = ACTIONS(4189),
    [anon_sym_With] = ACTIONS(4189),
    [sym_asserterror_keyword] = ACTIONS(4191),
    [sym_page_keyword] = ACTIONS(4189),
    [anon_sym_codeunit] = ACTIONS(4189),
    [anon_sym_CODEUNIT] = ACTIONS(4189),
    [anon_sym_Codeunit] = ACTIONS(4189),
    [anon_sym_CodeUnit] = ACTIONS(4189),
    [anon_sym_COdeunit] = ACTIONS(4189),
    [anon_sym_codeUnit] = ACTIONS(4189),
    [sym_report_keyword] = ACTIONS(4189),
    [sym_query_keyword] = ACTIONS(4189),
    [anon_sym_xmlport] = ACTIONS(4189),
    [anon_sym_XMLPORT] = ACTIONS(4189),
    [anon_sym_Xmlport] = ACTIONS(4189),
    [anon_sym_XMLport] = ACTIONS(4189),
    [anon_sym_XMLPort] = ACTIONS(4189),
    [anon_sym_XmlPort] = ACTIONS(4189),
    [anon_sym_enum] = ACTIONS(4189),
    [anon_sym_ENUM] = ACTIONS(4189),
    [anon_sym_Enum] = ACTIONS(4189),
    [anon_sym_eNUM] = ACTIONS(4189),
    [anon_sym_eNum] = ACTIONS(4189),
    [anon_sym_ENum] = ACTIONS(4189),
    [sym_quoted_identifier] = ACTIONS(4191),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4191),
    [sym_integer] = ACTIONS(4189),
    [sym_continue_as_identifier] = ACTIONS(4191),
    [sym_preproc_open] = ACTIONS(4191),
  },
  [STATE(1802)] = {
    [sym_identifier] = ACTIONS(4177),
    [anon_sym_SEMI] = ACTIONS(4179),
    [anon_sym_DASH] = ACTIONS(4179),
    [aux_sym_boolean_token1] = ACTIONS(4177),
    [aux_sym_boolean_token2] = ACTIONS(4177),
    [sym_decimal] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4179),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4177),
    [anon_sym_LBRACK] = ACTIONS(4179),
    [aux_sym_record_type_token1] = ACTIONS(4177),
    [aux_sym_basic_type_token21] = ACTIONS(4177),
    [aux_sym_basic_type_token22] = ACTIONS(4177),
    [aux_sym_basic_type_token48] = ACTIONS(4177),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4177),
    [anon_sym_POUNDif] = ACTIONS(4179),
    [anon_sym_POUNDIF] = ACTIONS(4179),
    [anon_sym_POUNDIf] = ACTIONS(4179),
    [anon_sym_not] = ACTIONS(4177),
    [anon_sym_NOT] = ACTIONS(4177),
    [anon_sym_Not] = ACTIONS(4177),
    [anon_sym_POUNDelse] = ACTIONS(4179),
    [anon_sym_POUNDELSE] = ACTIONS(4179),
    [anon_sym_POUNDElse] = ACTIONS(4179),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4177),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4179),
    [sym_datetime_literal] = ACTIONS(4179),
    [sym_date_literal] = ACTIONS(4177),
    [sym_time_literal] = ACTIONS(4177),
    [sym_biginteger_literal] = ACTIONS(4179),
    [anon_sym_if] = ACTIONS(4177),
    [anon_sym_IF] = ACTIONS(4177),
    [anon_sym_If] = ACTIONS(4177),
    [anon_sym_else] = ACTIONS(4177),
    [anon_sym_ELSE] = ACTIONS(4177),
    [anon_sym_Else] = ACTIONS(4177),
    [anon_sym_case] = ACTIONS(4177),
    [anon_sym_CASE] = ACTIONS(4177),
    [anon_sym_Case] = ACTIONS(4177),
    [anon_sym_for] = ACTIONS(4177),
    [anon_sym_FOR] = ACTIONS(4177),
    [anon_sym_For] = ACTIONS(4177),
    [anon_sym_foreach] = ACTIONS(4177),
    [anon_sym_FOREACH] = ACTIONS(4177),
    [anon_sym_Foreach] = ACTIONS(4177),
    [anon_sym_while] = ACTIONS(4177),
    [anon_sym_WHILE] = ACTIONS(4177),
    [anon_sym_While] = ACTIONS(4177),
    [anon_sym_repeat] = ACTIONS(4177),
    [anon_sym_REPEAT] = ACTIONS(4177),
    [anon_sym_Repeat] = ACTIONS(4177),
    [anon_sym_until] = ACTIONS(4177),
    [anon_sym_UNTIL] = ACTIONS(4177),
    [anon_sym_Until] = ACTIONS(4177),
    [anon_sym_exit] = ACTIONS(4177),
    [anon_sym_EXIT] = ACTIONS(4177),
    [anon_sym_Exit] = ACTIONS(4177),
    [anon_sym_continue] = ACTIONS(4177),
    [anon_sym_CONTINUE] = ACTIONS(4177),
    [anon_sym_Continue] = ACTIONS(4177),
    [anon_sym_break] = ACTIONS(4177),
    [anon_sym_BREAK] = ACTIONS(4177),
    [anon_sym_Break] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4177),
    [anon_sym_WITH] = ACTIONS(4177),
    [anon_sym_With] = ACTIONS(4177),
    [sym_asserterror_keyword] = ACTIONS(4179),
    [sym_page_keyword] = ACTIONS(4177),
    [anon_sym_codeunit] = ACTIONS(4177),
    [anon_sym_CODEUNIT] = ACTIONS(4177),
    [anon_sym_Codeunit] = ACTIONS(4177),
    [anon_sym_CodeUnit] = ACTIONS(4177),
    [anon_sym_COdeunit] = ACTIONS(4177),
    [anon_sym_codeUnit] = ACTIONS(4177),
    [sym_report_keyword] = ACTIONS(4177),
    [sym_query_keyword] = ACTIONS(4177),
    [anon_sym_xmlport] = ACTIONS(4177),
    [anon_sym_XMLPORT] = ACTIONS(4177),
    [anon_sym_Xmlport] = ACTIONS(4177),
    [anon_sym_XMLport] = ACTIONS(4177),
    [anon_sym_XMLPort] = ACTIONS(4177),
    [anon_sym_XmlPort] = ACTIONS(4177),
    [anon_sym_enum] = ACTIONS(4177),
    [anon_sym_ENUM] = ACTIONS(4177),
    [anon_sym_Enum] = ACTIONS(4177),
    [anon_sym_eNUM] = ACTIONS(4177),
    [anon_sym_eNum] = ACTIONS(4177),
    [anon_sym_ENum] = ACTIONS(4177),
    [sym_quoted_identifier] = ACTIONS(4179),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4179),
    [sym_integer] = ACTIONS(4177),
    [sym_continue_as_identifier] = ACTIONS(4179),
    [sym_preproc_open] = ACTIONS(4179),
  },
  [STATE(1803)] = {
    [sym_identifier] = ACTIONS(4189),
    [anon_sym_SEMI] = ACTIONS(4191),
    [anon_sym_DASH] = ACTIONS(4191),
    [aux_sym_boolean_token1] = ACTIONS(4189),
    [aux_sym_boolean_token2] = ACTIONS(4189),
    [sym_decimal] = ACTIONS(4189),
    [anon_sym_LPAREN] = ACTIONS(4191),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4189),
    [anon_sym_LBRACK] = ACTIONS(4191),
    [aux_sym_record_type_token1] = ACTIONS(4189),
    [aux_sym_basic_type_token21] = ACTIONS(4189),
    [aux_sym_basic_type_token22] = ACTIONS(4189),
    [aux_sym_basic_type_token48] = ACTIONS(4189),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4189),
    [anon_sym_POUNDif] = ACTIONS(4191),
    [anon_sym_POUNDIF] = ACTIONS(4191),
    [anon_sym_POUNDIf] = ACTIONS(4191),
    [anon_sym_not] = ACTIONS(4189),
    [anon_sym_NOT] = ACTIONS(4189),
    [anon_sym_Not] = ACTIONS(4189),
    [anon_sym_POUNDelse] = ACTIONS(4191),
    [anon_sym_POUNDELSE] = ACTIONS(4191),
    [anon_sym_POUNDElse] = ACTIONS(4191),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4189),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4189),
    [anon_sym_PLUS] = ACTIONS(4191),
    [sym_datetime_literal] = ACTIONS(4191),
    [sym_date_literal] = ACTIONS(4189),
    [sym_time_literal] = ACTIONS(4189),
    [sym_biginteger_literal] = ACTIONS(4191),
    [anon_sym_if] = ACTIONS(4189),
    [anon_sym_IF] = ACTIONS(4189),
    [anon_sym_If] = ACTIONS(4189),
    [anon_sym_else] = ACTIONS(4189),
    [anon_sym_ELSE] = ACTIONS(4189),
    [anon_sym_Else] = ACTIONS(4189),
    [anon_sym_case] = ACTIONS(4189),
    [anon_sym_CASE] = ACTIONS(4189),
    [anon_sym_Case] = ACTIONS(4189),
    [anon_sym_for] = ACTIONS(4189),
    [anon_sym_FOR] = ACTIONS(4189),
    [anon_sym_For] = ACTIONS(4189),
    [anon_sym_foreach] = ACTIONS(4189),
    [anon_sym_FOREACH] = ACTIONS(4189),
    [anon_sym_Foreach] = ACTIONS(4189),
    [anon_sym_while] = ACTIONS(4189),
    [anon_sym_WHILE] = ACTIONS(4189),
    [anon_sym_While] = ACTIONS(4189),
    [anon_sym_repeat] = ACTIONS(4189),
    [anon_sym_REPEAT] = ACTIONS(4189),
    [anon_sym_Repeat] = ACTIONS(4189),
    [anon_sym_until] = ACTIONS(4189),
    [anon_sym_UNTIL] = ACTIONS(4189),
    [anon_sym_Until] = ACTIONS(4189),
    [anon_sym_exit] = ACTIONS(4189),
    [anon_sym_EXIT] = ACTIONS(4189),
    [anon_sym_Exit] = ACTIONS(4189),
    [anon_sym_continue] = ACTIONS(4189),
    [anon_sym_CONTINUE] = ACTIONS(4189),
    [anon_sym_Continue] = ACTIONS(4189),
    [anon_sym_break] = ACTIONS(4189),
    [anon_sym_BREAK] = ACTIONS(4189),
    [anon_sym_Break] = ACTIONS(4189),
    [anon_sym_with] = ACTIONS(4189),
    [anon_sym_WITH] = ACTIONS(4189),
    [anon_sym_With] = ACTIONS(4189),
    [sym_asserterror_keyword] = ACTIONS(4191),
    [sym_page_keyword] = ACTIONS(4189),
    [anon_sym_codeunit] = ACTIONS(4189),
    [anon_sym_CODEUNIT] = ACTIONS(4189),
    [anon_sym_Codeunit] = ACTIONS(4189),
    [anon_sym_CodeUnit] = ACTIONS(4189),
    [anon_sym_COdeunit] = ACTIONS(4189),
    [anon_sym_codeUnit] = ACTIONS(4189),
    [sym_report_keyword] = ACTIONS(4189),
    [sym_query_keyword] = ACTIONS(4189),
    [anon_sym_xmlport] = ACTIONS(4189),
    [anon_sym_XMLPORT] = ACTIONS(4189),
    [anon_sym_Xmlport] = ACTIONS(4189),
    [anon_sym_XMLport] = ACTIONS(4189),
    [anon_sym_XMLPort] = ACTIONS(4189),
    [anon_sym_XmlPort] = ACTIONS(4189),
    [anon_sym_enum] = ACTIONS(4189),
    [anon_sym_ENUM] = ACTIONS(4189),
    [anon_sym_Enum] = ACTIONS(4189),
    [anon_sym_eNUM] = ACTIONS(4189),
    [anon_sym_eNum] = ACTIONS(4189),
    [anon_sym_ENum] = ACTIONS(4189),
    [sym_quoted_identifier] = ACTIONS(4191),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4191),
    [sym_integer] = ACTIONS(4189),
    [sym_continue_as_identifier] = ACTIONS(4191),
    [sym_preproc_open] = ACTIONS(4191),
  },
  [STATE(1804)] = {
    [sym_identifier] = ACTIONS(4177),
    [anon_sym_SEMI] = ACTIONS(4179),
    [anon_sym_DASH] = ACTIONS(4179),
    [aux_sym_boolean_token1] = ACTIONS(4177),
    [aux_sym_boolean_token2] = ACTIONS(4177),
    [sym_decimal] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4179),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4177),
    [anon_sym_LBRACK] = ACTIONS(4179),
    [aux_sym_record_type_token1] = ACTIONS(4177),
    [aux_sym_basic_type_token21] = ACTIONS(4177),
    [aux_sym_basic_type_token22] = ACTIONS(4177),
    [aux_sym_basic_type_token48] = ACTIONS(4177),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4177),
    [anon_sym_POUNDif] = ACTIONS(4179),
    [anon_sym_POUNDIF] = ACTIONS(4179),
    [anon_sym_POUNDIf] = ACTIONS(4179),
    [anon_sym_not] = ACTIONS(4177),
    [anon_sym_NOT] = ACTIONS(4177),
    [anon_sym_Not] = ACTIONS(4177),
    [anon_sym_POUNDelse] = ACTIONS(4179),
    [anon_sym_POUNDELSE] = ACTIONS(4179),
    [anon_sym_POUNDElse] = ACTIONS(4179),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4177),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4179),
    [sym_datetime_literal] = ACTIONS(4179),
    [sym_date_literal] = ACTIONS(4177),
    [sym_time_literal] = ACTIONS(4177),
    [sym_biginteger_literal] = ACTIONS(4179),
    [anon_sym_if] = ACTIONS(4177),
    [anon_sym_IF] = ACTIONS(4177),
    [anon_sym_If] = ACTIONS(4177),
    [anon_sym_else] = ACTIONS(4177),
    [anon_sym_ELSE] = ACTIONS(4177),
    [anon_sym_Else] = ACTIONS(4177),
    [anon_sym_case] = ACTIONS(4177),
    [anon_sym_CASE] = ACTIONS(4177),
    [anon_sym_Case] = ACTIONS(4177),
    [anon_sym_for] = ACTIONS(4177),
    [anon_sym_FOR] = ACTIONS(4177),
    [anon_sym_For] = ACTIONS(4177),
    [anon_sym_foreach] = ACTIONS(4177),
    [anon_sym_FOREACH] = ACTIONS(4177),
    [anon_sym_Foreach] = ACTIONS(4177),
    [anon_sym_while] = ACTIONS(4177),
    [anon_sym_WHILE] = ACTIONS(4177),
    [anon_sym_While] = ACTIONS(4177),
    [anon_sym_repeat] = ACTIONS(4177),
    [anon_sym_REPEAT] = ACTIONS(4177),
    [anon_sym_Repeat] = ACTIONS(4177),
    [anon_sym_until] = ACTIONS(4177),
    [anon_sym_UNTIL] = ACTIONS(4177),
    [anon_sym_Until] = ACTIONS(4177),
    [anon_sym_exit] = ACTIONS(4177),
    [anon_sym_EXIT] = ACTIONS(4177),
    [anon_sym_Exit] = ACTIONS(4177),
    [anon_sym_continue] = ACTIONS(4177),
    [anon_sym_CONTINUE] = ACTIONS(4177),
    [anon_sym_Continue] = ACTIONS(4177),
    [anon_sym_break] = ACTIONS(4177),
    [anon_sym_BREAK] = ACTIONS(4177),
    [anon_sym_Break] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4177),
    [anon_sym_WITH] = ACTIONS(4177),
    [anon_sym_With] = ACTIONS(4177),
    [sym_asserterror_keyword] = ACTIONS(4179),
    [sym_page_keyword] = ACTIONS(4177),
    [anon_sym_codeunit] = ACTIONS(4177),
    [anon_sym_CODEUNIT] = ACTIONS(4177),
    [anon_sym_Codeunit] = ACTIONS(4177),
    [anon_sym_CodeUnit] = ACTIONS(4177),
    [anon_sym_COdeunit] = ACTIONS(4177),
    [anon_sym_codeUnit] = ACTIONS(4177),
    [sym_report_keyword] = ACTIONS(4177),
    [sym_query_keyword] = ACTIONS(4177),
    [anon_sym_xmlport] = ACTIONS(4177),
    [anon_sym_XMLPORT] = ACTIONS(4177),
    [anon_sym_Xmlport] = ACTIONS(4177),
    [anon_sym_XMLport] = ACTIONS(4177),
    [anon_sym_XMLPort] = ACTIONS(4177),
    [anon_sym_XmlPort] = ACTIONS(4177),
    [anon_sym_enum] = ACTIONS(4177),
    [anon_sym_ENUM] = ACTIONS(4177),
    [anon_sym_Enum] = ACTIONS(4177),
    [anon_sym_eNUM] = ACTIONS(4177),
    [anon_sym_eNum] = ACTIONS(4177),
    [anon_sym_ENum] = ACTIONS(4177),
    [sym_quoted_identifier] = ACTIONS(4179),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4179),
    [sym_integer] = ACTIONS(4177),
    [sym_continue_as_identifier] = ACTIONS(4179),
    [sym_preproc_open] = ACTIONS(4179),
  },
  [STATE(1805)] = {
    [sym_identifier] = ACTIONS(4185),
    [anon_sym_SEMI] = ACTIONS(4187),
    [anon_sym_DASH] = ACTIONS(4187),
    [aux_sym_boolean_token1] = ACTIONS(4185),
    [aux_sym_boolean_token2] = ACTIONS(4185),
    [sym_decimal] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4187),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4185),
    [anon_sym_LBRACK] = ACTIONS(4187),
    [aux_sym_record_type_token1] = ACTIONS(4185),
    [aux_sym_basic_type_token21] = ACTIONS(4185),
    [aux_sym_basic_type_token22] = ACTIONS(4185),
    [aux_sym_basic_type_token48] = ACTIONS(4185),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4185),
    [anon_sym_POUNDif] = ACTIONS(4187),
    [anon_sym_POUNDIF] = ACTIONS(4187),
    [anon_sym_POUNDIf] = ACTIONS(4187),
    [anon_sym_not] = ACTIONS(4185),
    [anon_sym_NOT] = ACTIONS(4185),
    [anon_sym_Not] = ACTIONS(4185),
    [anon_sym_POUNDelse] = ACTIONS(4187),
    [anon_sym_POUNDELSE] = ACTIONS(4187),
    [anon_sym_POUNDElse] = ACTIONS(4187),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4185),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4187),
    [sym_datetime_literal] = ACTIONS(4187),
    [sym_date_literal] = ACTIONS(4185),
    [sym_time_literal] = ACTIONS(4185),
    [sym_biginteger_literal] = ACTIONS(4187),
    [anon_sym_if] = ACTIONS(4185),
    [anon_sym_IF] = ACTIONS(4185),
    [anon_sym_If] = ACTIONS(4185),
    [anon_sym_else] = ACTIONS(4185),
    [anon_sym_ELSE] = ACTIONS(4185),
    [anon_sym_Else] = ACTIONS(4185),
    [anon_sym_case] = ACTIONS(4185),
    [anon_sym_CASE] = ACTIONS(4185),
    [anon_sym_Case] = ACTIONS(4185),
    [anon_sym_for] = ACTIONS(4185),
    [anon_sym_FOR] = ACTIONS(4185),
    [anon_sym_For] = ACTIONS(4185),
    [anon_sym_foreach] = ACTIONS(4185),
    [anon_sym_FOREACH] = ACTIONS(4185),
    [anon_sym_Foreach] = ACTIONS(4185),
    [anon_sym_while] = ACTIONS(4185),
    [anon_sym_WHILE] = ACTIONS(4185),
    [anon_sym_While] = ACTIONS(4185),
    [anon_sym_repeat] = ACTIONS(4185),
    [anon_sym_REPEAT] = ACTIONS(4185),
    [anon_sym_Repeat] = ACTIONS(4185),
    [anon_sym_until] = ACTIONS(4185),
    [anon_sym_UNTIL] = ACTIONS(4185),
    [anon_sym_Until] = ACTIONS(4185),
    [anon_sym_exit] = ACTIONS(4185),
    [anon_sym_EXIT] = ACTIONS(4185),
    [anon_sym_Exit] = ACTIONS(4185),
    [anon_sym_continue] = ACTIONS(4185),
    [anon_sym_CONTINUE] = ACTIONS(4185),
    [anon_sym_Continue] = ACTIONS(4185),
    [anon_sym_break] = ACTIONS(4185),
    [anon_sym_BREAK] = ACTIONS(4185),
    [anon_sym_Break] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4185),
    [anon_sym_WITH] = ACTIONS(4185),
    [anon_sym_With] = ACTIONS(4185),
    [sym_asserterror_keyword] = ACTIONS(4187),
    [sym_page_keyword] = ACTIONS(4185),
    [anon_sym_codeunit] = ACTIONS(4185),
    [anon_sym_CODEUNIT] = ACTIONS(4185),
    [anon_sym_Codeunit] = ACTIONS(4185),
    [anon_sym_CodeUnit] = ACTIONS(4185),
    [anon_sym_COdeunit] = ACTIONS(4185),
    [anon_sym_codeUnit] = ACTIONS(4185),
    [sym_report_keyword] = ACTIONS(4185),
    [sym_query_keyword] = ACTIONS(4185),
    [anon_sym_xmlport] = ACTIONS(4185),
    [anon_sym_XMLPORT] = ACTIONS(4185),
    [anon_sym_Xmlport] = ACTIONS(4185),
    [anon_sym_XMLport] = ACTIONS(4185),
    [anon_sym_XMLPort] = ACTIONS(4185),
    [anon_sym_XmlPort] = ACTIONS(4185),
    [anon_sym_enum] = ACTIONS(4185),
    [anon_sym_ENUM] = ACTIONS(4185),
    [anon_sym_Enum] = ACTIONS(4185),
    [anon_sym_eNUM] = ACTIONS(4185),
    [anon_sym_eNum] = ACTIONS(4185),
    [anon_sym_ENum] = ACTIONS(4185),
    [sym_quoted_identifier] = ACTIONS(4187),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4187),
    [sym_integer] = ACTIONS(4185),
    [sym_continue_as_identifier] = ACTIONS(4187),
    [sym_preproc_open] = ACTIONS(4187),
  },
  [STATE(1806)] = {
    [sym_identifier] = ACTIONS(4555),
    [anon_sym_SEMI] = ACTIONS(4557),
    [anon_sym_DASH] = ACTIONS(4557),
    [aux_sym_boolean_token1] = ACTIONS(4555),
    [aux_sym_boolean_token2] = ACTIONS(4555),
    [sym_decimal] = ACTIONS(4555),
    [anon_sym_LPAREN] = ACTIONS(4557),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4555),
    [anon_sym_LBRACK] = ACTIONS(4557),
    [aux_sym_record_type_token1] = ACTIONS(4555),
    [aux_sym_basic_type_token21] = ACTIONS(4555),
    [aux_sym_basic_type_token22] = ACTIONS(4555),
    [aux_sym_basic_type_token48] = ACTIONS(4555),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4555),
    [anon_sym_POUNDif] = ACTIONS(4557),
    [anon_sym_POUNDIF] = ACTIONS(4557),
    [anon_sym_POUNDIf] = ACTIONS(4557),
    [anon_sym_not] = ACTIONS(4555),
    [anon_sym_NOT] = ACTIONS(4555),
    [anon_sym_Not] = ACTIONS(4555),
    [anon_sym_POUNDelse] = ACTIONS(4557),
    [anon_sym_POUNDELSE] = ACTIONS(4557),
    [anon_sym_POUNDElse] = ACTIONS(4557),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4555),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4555),
    [anon_sym_PLUS] = ACTIONS(4557),
    [sym_datetime_literal] = ACTIONS(4557),
    [sym_date_literal] = ACTIONS(4555),
    [sym_time_literal] = ACTIONS(4555),
    [sym_biginteger_literal] = ACTIONS(4557),
    [anon_sym_if] = ACTIONS(4555),
    [anon_sym_IF] = ACTIONS(4555),
    [anon_sym_If] = ACTIONS(4555),
    [anon_sym_else] = ACTIONS(4555),
    [anon_sym_ELSE] = ACTIONS(4555),
    [anon_sym_Else] = ACTIONS(4555),
    [anon_sym_case] = ACTIONS(4555),
    [anon_sym_CASE] = ACTIONS(4555),
    [anon_sym_Case] = ACTIONS(4555),
    [anon_sym_for] = ACTIONS(4555),
    [anon_sym_FOR] = ACTIONS(4555),
    [anon_sym_For] = ACTIONS(4555),
    [anon_sym_foreach] = ACTIONS(4555),
    [anon_sym_FOREACH] = ACTIONS(4555),
    [anon_sym_Foreach] = ACTIONS(4555),
    [anon_sym_while] = ACTIONS(4555),
    [anon_sym_WHILE] = ACTIONS(4555),
    [anon_sym_While] = ACTIONS(4555),
    [anon_sym_repeat] = ACTIONS(4555),
    [anon_sym_REPEAT] = ACTIONS(4555),
    [anon_sym_Repeat] = ACTIONS(4555),
    [anon_sym_until] = ACTIONS(4555),
    [anon_sym_UNTIL] = ACTIONS(4555),
    [anon_sym_Until] = ACTIONS(4555),
    [anon_sym_exit] = ACTIONS(4555),
    [anon_sym_EXIT] = ACTIONS(4555),
    [anon_sym_Exit] = ACTIONS(4555),
    [anon_sym_continue] = ACTIONS(4555),
    [anon_sym_CONTINUE] = ACTIONS(4555),
    [anon_sym_Continue] = ACTIONS(4555),
    [anon_sym_break] = ACTIONS(4555),
    [anon_sym_BREAK] = ACTIONS(4555),
    [anon_sym_Break] = ACTIONS(4555),
    [anon_sym_with] = ACTIONS(4555),
    [anon_sym_WITH] = ACTIONS(4555),
    [anon_sym_With] = ACTIONS(4555),
    [sym_asserterror_keyword] = ACTIONS(4557),
    [sym_page_keyword] = ACTIONS(4555),
    [anon_sym_codeunit] = ACTIONS(4555),
    [anon_sym_CODEUNIT] = ACTIONS(4555),
    [anon_sym_Codeunit] = ACTIONS(4555),
    [anon_sym_CodeUnit] = ACTIONS(4555),
    [anon_sym_COdeunit] = ACTIONS(4555),
    [anon_sym_codeUnit] = ACTIONS(4555),
    [sym_report_keyword] = ACTIONS(4555),
    [sym_query_keyword] = ACTIONS(4555),
    [anon_sym_xmlport] = ACTIONS(4555),
    [anon_sym_XMLPORT] = ACTIONS(4555),
    [anon_sym_Xmlport] = ACTIONS(4555),
    [anon_sym_XMLport] = ACTIONS(4555),
    [anon_sym_XMLPort] = ACTIONS(4555),
    [anon_sym_XmlPort] = ACTIONS(4555),
    [anon_sym_enum] = ACTIONS(4555),
    [anon_sym_ENUM] = ACTIONS(4555),
    [anon_sym_Enum] = ACTIONS(4555),
    [anon_sym_eNUM] = ACTIONS(4555),
    [anon_sym_eNum] = ACTIONS(4555),
    [anon_sym_ENum] = ACTIONS(4555),
    [sym_quoted_identifier] = ACTIONS(4557),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4557),
    [sym_integer] = ACTIONS(4555),
    [sym_continue_as_identifier] = ACTIONS(4557),
    [sym_preproc_open] = ACTIONS(4557),
  },
  [STATE(1807)] = {
    [sym_identifier] = ACTIONS(4185),
    [anon_sym_SEMI] = ACTIONS(4187),
    [anon_sym_DASH] = ACTIONS(4187),
    [aux_sym_boolean_token1] = ACTIONS(4185),
    [aux_sym_boolean_token2] = ACTIONS(4185),
    [sym_decimal] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4187),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4185),
    [anon_sym_LBRACK] = ACTIONS(4187),
    [aux_sym_record_type_token1] = ACTIONS(4185),
    [aux_sym_basic_type_token21] = ACTIONS(4185),
    [aux_sym_basic_type_token22] = ACTIONS(4185),
    [aux_sym_basic_type_token48] = ACTIONS(4185),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4185),
    [anon_sym_POUNDif] = ACTIONS(4187),
    [anon_sym_POUNDIF] = ACTIONS(4187),
    [anon_sym_POUNDIf] = ACTIONS(4187),
    [anon_sym_not] = ACTIONS(4185),
    [anon_sym_NOT] = ACTIONS(4185),
    [anon_sym_Not] = ACTIONS(4185),
    [anon_sym_POUNDelse] = ACTIONS(4187),
    [anon_sym_POUNDELSE] = ACTIONS(4187),
    [anon_sym_POUNDElse] = ACTIONS(4187),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4185),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4187),
    [sym_datetime_literal] = ACTIONS(4187),
    [sym_date_literal] = ACTIONS(4185),
    [sym_time_literal] = ACTIONS(4185),
    [sym_biginteger_literal] = ACTIONS(4187),
    [anon_sym_if] = ACTIONS(4185),
    [anon_sym_IF] = ACTIONS(4185),
    [anon_sym_If] = ACTIONS(4185),
    [anon_sym_else] = ACTIONS(4185),
    [anon_sym_ELSE] = ACTIONS(4185),
    [anon_sym_Else] = ACTIONS(4185),
    [anon_sym_case] = ACTIONS(4185),
    [anon_sym_CASE] = ACTIONS(4185),
    [anon_sym_Case] = ACTIONS(4185),
    [anon_sym_for] = ACTIONS(4185),
    [anon_sym_FOR] = ACTIONS(4185),
    [anon_sym_For] = ACTIONS(4185),
    [anon_sym_foreach] = ACTIONS(4185),
    [anon_sym_FOREACH] = ACTIONS(4185),
    [anon_sym_Foreach] = ACTIONS(4185),
    [anon_sym_while] = ACTIONS(4185),
    [anon_sym_WHILE] = ACTIONS(4185),
    [anon_sym_While] = ACTIONS(4185),
    [anon_sym_repeat] = ACTIONS(4185),
    [anon_sym_REPEAT] = ACTIONS(4185),
    [anon_sym_Repeat] = ACTIONS(4185),
    [anon_sym_until] = ACTIONS(4185),
    [anon_sym_UNTIL] = ACTIONS(4185),
    [anon_sym_Until] = ACTIONS(4185),
    [anon_sym_exit] = ACTIONS(4185),
    [anon_sym_EXIT] = ACTIONS(4185),
    [anon_sym_Exit] = ACTIONS(4185),
    [anon_sym_continue] = ACTIONS(4185),
    [anon_sym_CONTINUE] = ACTIONS(4185),
    [anon_sym_Continue] = ACTIONS(4185),
    [anon_sym_break] = ACTIONS(4185),
    [anon_sym_BREAK] = ACTIONS(4185),
    [anon_sym_Break] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4185),
    [anon_sym_WITH] = ACTIONS(4185),
    [anon_sym_With] = ACTIONS(4185),
    [sym_asserterror_keyword] = ACTIONS(4187),
    [sym_page_keyword] = ACTIONS(4185),
    [anon_sym_codeunit] = ACTIONS(4185),
    [anon_sym_CODEUNIT] = ACTIONS(4185),
    [anon_sym_Codeunit] = ACTIONS(4185),
    [anon_sym_CodeUnit] = ACTIONS(4185),
    [anon_sym_COdeunit] = ACTIONS(4185),
    [anon_sym_codeUnit] = ACTIONS(4185),
    [sym_report_keyword] = ACTIONS(4185),
    [sym_query_keyword] = ACTIONS(4185),
    [anon_sym_xmlport] = ACTIONS(4185),
    [anon_sym_XMLPORT] = ACTIONS(4185),
    [anon_sym_Xmlport] = ACTIONS(4185),
    [anon_sym_XMLport] = ACTIONS(4185),
    [anon_sym_XMLPort] = ACTIONS(4185),
    [anon_sym_XmlPort] = ACTIONS(4185),
    [anon_sym_enum] = ACTIONS(4185),
    [anon_sym_ENUM] = ACTIONS(4185),
    [anon_sym_Enum] = ACTIONS(4185),
    [anon_sym_eNUM] = ACTIONS(4185),
    [anon_sym_eNum] = ACTIONS(4185),
    [anon_sym_ENum] = ACTIONS(4185),
    [sym_quoted_identifier] = ACTIONS(4187),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4187),
    [sym_integer] = ACTIONS(4185),
    [sym_continue_as_identifier] = ACTIONS(4187),
    [sym_preproc_open] = ACTIONS(4187),
  },
  [STATE(1808)] = {
    [sym_identifier] = ACTIONS(4559),
    [anon_sym_SEMI] = ACTIONS(4561),
    [anon_sym_DASH] = ACTIONS(4561),
    [aux_sym_boolean_token1] = ACTIONS(4559),
    [aux_sym_boolean_token2] = ACTIONS(4559),
    [sym_decimal] = ACTIONS(4559),
    [anon_sym_LPAREN] = ACTIONS(4561),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4559),
    [anon_sym_LBRACK] = ACTIONS(4561),
    [aux_sym_record_type_token1] = ACTIONS(4559),
    [aux_sym_basic_type_token21] = ACTIONS(4559),
    [aux_sym_basic_type_token22] = ACTIONS(4559),
    [aux_sym_basic_type_token48] = ACTIONS(4559),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4559),
    [anon_sym_POUNDif] = ACTIONS(4561),
    [anon_sym_POUNDIF] = ACTIONS(4561),
    [anon_sym_POUNDIf] = ACTIONS(4561),
    [anon_sym_not] = ACTIONS(4559),
    [anon_sym_NOT] = ACTIONS(4559),
    [anon_sym_Not] = ACTIONS(4559),
    [anon_sym_POUNDelse] = ACTIONS(4561),
    [anon_sym_POUNDELSE] = ACTIONS(4561),
    [anon_sym_POUNDElse] = ACTIONS(4561),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4559),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4559),
    [anon_sym_PLUS] = ACTIONS(4561),
    [sym_datetime_literal] = ACTIONS(4561),
    [sym_date_literal] = ACTIONS(4559),
    [sym_time_literal] = ACTIONS(4559),
    [sym_biginteger_literal] = ACTIONS(4561),
    [anon_sym_if] = ACTIONS(4559),
    [anon_sym_IF] = ACTIONS(4559),
    [anon_sym_If] = ACTIONS(4559),
    [anon_sym_else] = ACTIONS(4559),
    [anon_sym_ELSE] = ACTIONS(4559),
    [anon_sym_Else] = ACTIONS(4559),
    [anon_sym_case] = ACTIONS(4559),
    [anon_sym_CASE] = ACTIONS(4559),
    [anon_sym_Case] = ACTIONS(4559),
    [anon_sym_for] = ACTIONS(4559),
    [anon_sym_FOR] = ACTIONS(4559),
    [anon_sym_For] = ACTIONS(4559),
    [anon_sym_foreach] = ACTIONS(4559),
    [anon_sym_FOREACH] = ACTIONS(4559),
    [anon_sym_Foreach] = ACTIONS(4559),
    [anon_sym_while] = ACTIONS(4559),
    [anon_sym_WHILE] = ACTIONS(4559),
    [anon_sym_While] = ACTIONS(4559),
    [anon_sym_repeat] = ACTIONS(4559),
    [anon_sym_REPEAT] = ACTIONS(4559),
    [anon_sym_Repeat] = ACTIONS(4559),
    [anon_sym_until] = ACTIONS(4559),
    [anon_sym_UNTIL] = ACTIONS(4559),
    [anon_sym_Until] = ACTIONS(4559),
    [anon_sym_exit] = ACTIONS(4559),
    [anon_sym_EXIT] = ACTIONS(4559),
    [anon_sym_Exit] = ACTIONS(4559),
    [anon_sym_continue] = ACTIONS(4559),
    [anon_sym_CONTINUE] = ACTIONS(4559),
    [anon_sym_Continue] = ACTIONS(4559),
    [anon_sym_break] = ACTIONS(4559),
    [anon_sym_BREAK] = ACTIONS(4559),
    [anon_sym_Break] = ACTIONS(4559),
    [anon_sym_with] = ACTIONS(4559),
    [anon_sym_WITH] = ACTIONS(4559),
    [anon_sym_With] = ACTIONS(4559),
    [sym_asserterror_keyword] = ACTIONS(4561),
    [sym_page_keyword] = ACTIONS(4559),
    [anon_sym_codeunit] = ACTIONS(4559),
    [anon_sym_CODEUNIT] = ACTIONS(4559),
    [anon_sym_Codeunit] = ACTIONS(4559),
    [anon_sym_CodeUnit] = ACTIONS(4559),
    [anon_sym_COdeunit] = ACTIONS(4559),
    [anon_sym_codeUnit] = ACTIONS(4559),
    [sym_report_keyword] = ACTIONS(4559),
    [sym_query_keyword] = ACTIONS(4559),
    [anon_sym_xmlport] = ACTIONS(4559),
    [anon_sym_XMLPORT] = ACTIONS(4559),
    [anon_sym_Xmlport] = ACTIONS(4559),
    [anon_sym_XMLport] = ACTIONS(4559),
    [anon_sym_XMLPort] = ACTIONS(4559),
    [anon_sym_XmlPort] = ACTIONS(4559),
    [anon_sym_enum] = ACTIONS(4559),
    [anon_sym_ENUM] = ACTIONS(4559),
    [anon_sym_Enum] = ACTIONS(4559),
    [anon_sym_eNUM] = ACTIONS(4559),
    [anon_sym_eNum] = ACTIONS(4559),
    [anon_sym_ENum] = ACTIONS(4559),
    [sym_quoted_identifier] = ACTIONS(4561),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4561),
    [sym_integer] = ACTIONS(4559),
    [sym_continue_as_identifier] = ACTIONS(4561),
    [sym_preproc_open] = ACTIONS(4561),
  },
  [STATE(1809)] = {
    [sym_identifier] = ACTIONS(4563),
    [anon_sym_SEMI] = ACTIONS(4565),
    [anon_sym_DASH] = ACTIONS(4565),
    [aux_sym_boolean_token1] = ACTIONS(4563),
    [aux_sym_boolean_token2] = ACTIONS(4563),
    [sym_decimal] = ACTIONS(4563),
    [anon_sym_LPAREN] = ACTIONS(4565),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4563),
    [anon_sym_LBRACK] = ACTIONS(4565),
    [aux_sym_record_type_token1] = ACTIONS(4563),
    [aux_sym_basic_type_token21] = ACTIONS(4563),
    [aux_sym_basic_type_token22] = ACTIONS(4563),
    [aux_sym_basic_type_token48] = ACTIONS(4563),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4563),
    [anon_sym_POUNDif] = ACTIONS(4565),
    [anon_sym_POUNDIF] = ACTIONS(4565),
    [anon_sym_POUNDIf] = ACTIONS(4565),
    [anon_sym_not] = ACTIONS(4563),
    [anon_sym_NOT] = ACTIONS(4563),
    [anon_sym_Not] = ACTIONS(4563),
    [anon_sym_POUNDelse] = ACTIONS(4565),
    [anon_sym_POUNDELSE] = ACTIONS(4565),
    [anon_sym_POUNDElse] = ACTIONS(4565),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4563),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4563),
    [anon_sym_PLUS] = ACTIONS(4565),
    [sym_datetime_literal] = ACTIONS(4565),
    [sym_date_literal] = ACTIONS(4563),
    [sym_time_literal] = ACTIONS(4563),
    [sym_biginteger_literal] = ACTIONS(4565),
    [anon_sym_if] = ACTIONS(4563),
    [anon_sym_IF] = ACTIONS(4563),
    [anon_sym_If] = ACTIONS(4563),
    [anon_sym_else] = ACTIONS(4563),
    [anon_sym_ELSE] = ACTIONS(4563),
    [anon_sym_Else] = ACTIONS(4563),
    [anon_sym_case] = ACTIONS(4563),
    [anon_sym_CASE] = ACTIONS(4563),
    [anon_sym_Case] = ACTIONS(4563),
    [anon_sym_for] = ACTIONS(4563),
    [anon_sym_FOR] = ACTIONS(4563),
    [anon_sym_For] = ACTIONS(4563),
    [anon_sym_foreach] = ACTIONS(4563),
    [anon_sym_FOREACH] = ACTIONS(4563),
    [anon_sym_Foreach] = ACTIONS(4563),
    [anon_sym_while] = ACTIONS(4563),
    [anon_sym_WHILE] = ACTIONS(4563),
    [anon_sym_While] = ACTIONS(4563),
    [anon_sym_repeat] = ACTIONS(4563),
    [anon_sym_REPEAT] = ACTIONS(4563),
    [anon_sym_Repeat] = ACTIONS(4563),
    [anon_sym_until] = ACTIONS(4563),
    [anon_sym_UNTIL] = ACTIONS(4563),
    [anon_sym_Until] = ACTIONS(4563),
    [anon_sym_exit] = ACTIONS(4563),
    [anon_sym_EXIT] = ACTIONS(4563),
    [anon_sym_Exit] = ACTIONS(4563),
    [anon_sym_continue] = ACTIONS(4563),
    [anon_sym_CONTINUE] = ACTIONS(4563),
    [anon_sym_Continue] = ACTIONS(4563),
    [anon_sym_break] = ACTIONS(4563),
    [anon_sym_BREAK] = ACTIONS(4563),
    [anon_sym_Break] = ACTIONS(4563),
    [anon_sym_with] = ACTIONS(4563),
    [anon_sym_WITH] = ACTIONS(4563),
    [anon_sym_With] = ACTIONS(4563),
    [sym_asserterror_keyword] = ACTIONS(4565),
    [sym_page_keyword] = ACTIONS(4563),
    [anon_sym_codeunit] = ACTIONS(4563),
    [anon_sym_CODEUNIT] = ACTIONS(4563),
    [anon_sym_Codeunit] = ACTIONS(4563),
    [anon_sym_CodeUnit] = ACTIONS(4563),
    [anon_sym_COdeunit] = ACTIONS(4563),
    [anon_sym_codeUnit] = ACTIONS(4563),
    [sym_report_keyword] = ACTIONS(4563),
    [sym_query_keyword] = ACTIONS(4563),
    [anon_sym_xmlport] = ACTIONS(4563),
    [anon_sym_XMLPORT] = ACTIONS(4563),
    [anon_sym_Xmlport] = ACTIONS(4563),
    [anon_sym_XMLport] = ACTIONS(4563),
    [anon_sym_XMLPort] = ACTIONS(4563),
    [anon_sym_XmlPort] = ACTIONS(4563),
    [anon_sym_enum] = ACTIONS(4563),
    [anon_sym_ENUM] = ACTIONS(4563),
    [anon_sym_Enum] = ACTIONS(4563),
    [anon_sym_eNUM] = ACTIONS(4563),
    [anon_sym_eNum] = ACTIONS(4563),
    [anon_sym_ENum] = ACTIONS(4563),
    [sym_quoted_identifier] = ACTIONS(4565),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4565),
    [sym_integer] = ACTIONS(4563),
    [sym_continue_as_identifier] = ACTIONS(4565),
    [sym_preproc_open] = ACTIONS(4565),
  },
  [STATE(1810)] = {
    [sym_identifier] = ACTIONS(4688),
    [anon_sym_SEMI] = ACTIONS(4690),
    [anon_sym_DASH] = ACTIONS(4690),
    [aux_sym_boolean_token1] = ACTIONS(4688),
    [aux_sym_boolean_token2] = ACTIONS(4688),
    [sym_decimal] = ACTIONS(4688),
    [anon_sym_LPAREN] = ACTIONS(4690),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4688),
    [anon_sym_LBRACK] = ACTIONS(4690),
    [aux_sym_record_type_token1] = ACTIONS(4688),
    [aux_sym_basic_type_token21] = ACTIONS(4688),
    [aux_sym_basic_type_token22] = ACTIONS(4688),
    [aux_sym_basic_type_token48] = ACTIONS(4688),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4688),
    [anon_sym_POUNDif] = ACTIONS(4690),
    [anon_sym_POUNDIF] = ACTIONS(4690),
    [anon_sym_POUNDIf] = ACTIONS(4690),
    [anon_sym_not] = ACTIONS(4688),
    [anon_sym_NOT] = ACTIONS(4688),
    [anon_sym_Not] = ACTIONS(4688),
    [anon_sym_POUNDelse] = ACTIONS(4690),
    [anon_sym_POUNDELSE] = ACTIONS(4690),
    [anon_sym_POUNDElse] = ACTIONS(4690),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4688),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4688),
    [anon_sym_PLUS] = ACTIONS(4690),
    [sym_datetime_literal] = ACTIONS(4690),
    [sym_date_literal] = ACTIONS(4688),
    [sym_time_literal] = ACTIONS(4688),
    [sym_biginteger_literal] = ACTIONS(4690),
    [anon_sym_if] = ACTIONS(4688),
    [anon_sym_IF] = ACTIONS(4688),
    [anon_sym_If] = ACTIONS(4688),
    [anon_sym_else] = ACTIONS(4688),
    [anon_sym_ELSE] = ACTIONS(4688),
    [anon_sym_Else] = ACTIONS(4688),
    [anon_sym_case] = ACTIONS(4688),
    [anon_sym_CASE] = ACTIONS(4688),
    [anon_sym_Case] = ACTIONS(4688),
    [anon_sym_for] = ACTIONS(4688),
    [anon_sym_FOR] = ACTIONS(4688),
    [anon_sym_For] = ACTIONS(4688),
    [anon_sym_foreach] = ACTIONS(4688),
    [anon_sym_FOREACH] = ACTIONS(4688),
    [anon_sym_Foreach] = ACTIONS(4688),
    [anon_sym_while] = ACTIONS(4688),
    [anon_sym_WHILE] = ACTIONS(4688),
    [anon_sym_While] = ACTIONS(4688),
    [anon_sym_repeat] = ACTIONS(4688),
    [anon_sym_REPEAT] = ACTIONS(4688),
    [anon_sym_Repeat] = ACTIONS(4688),
    [anon_sym_until] = ACTIONS(4688),
    [anon_sym_UNTIL] = ACTIONS(4688),
    [anon_sym_Until] = ACTIONS(4688),
    [anon_sym_exit] = ACTIONS(4688),
    [anon_sym_EXIT] = ACTIONS(4688),
    [anon_sym_Exit] = ACTIONS(4688),
    [anon_sym_continue] = ACTIONS(4688),
    [anon_sym_CONTINUE] = ACTIONS(4688),
    [anon_sym_Continue] = ACTIONS(4688),
    [anon_sym_break] = ACTIONS(4688),
    [anon_sym_BREAK] = ACTIONS(4688),
    [anon_sym_Break] = ACTIONS(4688),
    [anon_sym_with] = ACTIONS(4688),
    [anon_sym_WITH] = ACTIONS(4688),
    [anon_sym_With] = ACTIONS(4688),
    [sym_asserterror_keyword] = ACTIONS(4690),
    [sym_page_keyword] = ACTIONS(4688),
    [anon_sym_codeunit] = ACTIONS(4688),
    [anon_sym_CODEUNIT] = ACTIONS(4688),
    [anon_sym_Codeunit] = ACTIONS(4688),
    [anon_sym_CodeUnit] = ACTIONS(4688),
    [anon_sym_COdeunit] = ACTIONS(4688),
    [anon_sym_codeUnit] = ACTIONS(4688),
    [sym_report_keyword] = ACTIONS(4688),
    [sym_query_keyword] = ACTIONS(4688),
    [anon_sym_xmlport] = ACTIONS(4688),
    [anon_sym_XMLPORT] = ACTIONS(4688),
    [anon_sym_Xmlport] = ACTIONS(4688),
    [anon_sym_XMLport] = ACTIONS(4688),
    [anon_sym_XMLPort] = ACTIONS(4688),
    [anon_sym_XmlPort] = ACTIONS(4688),
    [anon_sym_enum] = ACTIONS(4688),
    [anon_sym_ENUM] = ACTIONS(4688),
    [anon_sym_Enum] = ACTIONS(4688),
    [anon_sym_eNUM] = ACTIONS(4688),
    [anon_sym_eNum] = ACTIONS(4688),
    [anon_sym_ENum] = ACTIONS(4688),
    [sym_quoted_identifier] = ACTIONS(4690),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4690),
    [sym_integer] = ACTIONS(4688),
    [sym_continue_as_identifier] = ACTIONS(4690),
    [sym_preproc_open] = ACTIONS(4690),
  },
  [STATE(1811)] = {
    [sym_identifier] = ACTIONS(4573),
    [anon_sym_SEMI] = ACTIONS(4575),
    [anon_sym_DASH] = ACTIONS(4575),
    [aux_sym_boolean_token1] = ACTIONS(4573),
    [aux_sym_boolean_token2] = ACTIONS(4573),
    [sym_decimal] = ACTIONS(4573),
    [anon_sym_LPAREN] = ACTIONS(4575),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4573),
    [anon_sym_LBRACK] = ACTIONS(4575),
    [aux_sym_record_type_token1] = ACTIONS(4573),
    [aux_sym_basic_type_token21] = ACTIONS(4573),
    [aux_sym_basic_type_token22] = ACTIONS(4573),
    [aux_sym_basic_type_token48] = ACTIONS(4573),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4573),
    [anon_sym_POUNDif] = ACTIONS(4575),
    [anon_sym_POUNDIF] = ACTIONS(4575),
    [anon_sym_POUNDIf] = ACTIONS(4575),
    [anon_sym_not] = ACTIONS(4573),
    [anon_sym_NOT] = ACTIONS(4573),
    [anon_sym_Not] = ACTIONS(4573),
    [anon_sym_POUNDelse] = ACTIONS(4575),
    [anon_sym_POUNDELSE] = ACTIONS(4575),
    [anon_sym_POUNDElse] = ACTIONS(4575),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4573),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4573),
    [anon_sym_PLUS] = ACTIONS(4575),
    [sym_datetime_literal] = ACTIONS(4575),
    [sym_date_literal] = ACTIONS(4573),
    [sym_time_literal] = ACTIONS(4573),
    [sym_biginteger_literal] = ACTIONS(4575),
    [anon_sym_if] = ACTIONS(4573),
    [anon_sym_IF] = ACTIONS(4573),
    [anon_sym_If] = ACTIONS(4573),
    [anon_sym_else] = ACTIONS(4573),
    [anon_sym_ELSE] = ACTIONS(4573),
    [anon_sym_Else] = ACTIONS(4573),
    [anon_sym_case] = ACTIONS(4573),
    [anon_sym_CASE] = ACTIONS(4573),
    [anon_sym_Case] = ACTIONS(4573),
    [anon_sym_for] = ACTIONS(4573),
    [anon_sym_FOR] = ACTIONS(4573),
    [anon_sym_For] = ACTIONS(4573),
    [anon_sym_foreach] = ACTIONS(4573),
    [anon_sym_FOREACH] = ACTIONS(4573),
    [anon_sym_Foreach] = ACTIONS(4573),
    [anon_sym_while] = ACTIONS(4573),
    [anon_sym_WHILE] = ACTIONS(4573),
    [anon_sym_While] = ACTIONS(4573),
    [anon_sym_repeat] = ACTIONS(4573),
    [anon_sym_REPEAT] = ACTIONS(4573),
    [anon_sym_Repeat] = ACTIONS(4573),
    [anon_sym_until] = ACTIONS(4573),
    [anon_sym_UNTIL] = ACTIONS(4573),
    [anon_sym_Until] = ACTIONS(4573),
    [anon_sym_exit] = ACTIONS(4573),
    [anon_sym_EXIT] = ACTIONS(4573),
    [anon_sym_Exit] = ACTIONS(4573),
    [anon_sym_continue] = ACTIONS(4573),
    [anon_sym_CONTINUE] = ACTIONS(4573),
    [anon_sym_Continue] = ACTIONS(4573),
    [anon_sym_break] = ACTIONS(4573),
    [anon_sym_BREAK] = ACTIONS(4573),
    [anon_sym_Break] = ACTIONS(4573),
    [anon_sym_with] = ACTIONS(4573),
    [anon_sym_WITH] = ACTIONS(4573),
    [anon_sym_With] = ACTIONS(4573),
    [sym_asserterror_keyword] = ACTIONS(4575),
    [sym_page_keyword] = ACTIONS(4573),
    [anon_sym_codeunit] = ACTIONS(4573),
    [anon_sym_CODEUNIT] = ACTIONS(4573),
    [anon_sym_Codeunit] = ACTIONS(4573),
    [anon_sym_CodeUnit] = ACTIONS(4573),
    [anon_sym_COdeunit] = ACTIONS(4573),
    [anon_sym_codeUnit] = ACTIONS(4573),
    [sym_report_keyword] = ACTIONS(4573),
    [sym_query_keyword] = ACTIONS(4573),
    [anon_sym_xmlport] = ACTIONS(4573),
    [anon_sym_XMLPORT] = ACTIONS(4573),
    [anon_sym_Xmlport] = ACTIONS(4573),
    [anon_sym_XMLport] = ACTIONS(4573),
    [anon_sym_XMLPort] = ACTIONS(4573),
    [anon_sym_XmlPort] = ACTIONS(4573),
    [anon_sym_enum] = ACTIONS(4573),
    [anon_sym_ENUM] = ACTIONS(4573),
    [anon_sym_Enum] = ACTIONS(4573),
    [anon_sym_eNUM] = ACTIONS(4573),
    [anon_sym_eNum] = ACTIONS(4573),
    [anon_sym_ENum] = ACTIONS(4573),
    [sym_quoted_identifier] = ACTIONS(4575),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4575),
    [sym_integer] = ACTIONS(4573),
    [sym_continue_as_identifier] = ACTIONS(4575),
    [sym_preproc_open] = ACTIONS(4575),
  },
  [STATE(1812)] = {
    [sym_identifier] = ACTIONS(4173),
    [anon_sym_SEMI] = ACTIONS(4175),
    [anon_sym_DASH] = ACTIONS(4175),
    [aux_sym_boolean_token1] = ACTIONS(4173),
    [aux_sym_boolean_token2] = ACTIONS(4173),
    [sym_decimal] = ACTIONS(4173),
    [anon_sym_LPAREN] = ACTIONS(4175),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4173),
    [anon_sym_LBRACK] = ACTIONS(4175),
    [aux_sym_record_type_token1] = ACTIONS(4173),
    [aux_sym_basic_type_token21] = ACTIONS(4173),
    [aux_sym_basic_type_token22] = ACTIONS(4173),
    [aux_sym_basic_type_token48] = ACTIONS(4173),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4173),
    [anon_sym_POUNDif] = ACTIONS(4175),
    [anon_sym_POUNDIF] = ACTIONS(4175),
    [anon_sym_POUNDIf] = ACTIONS(4175),
    [anon_sym_not] = ACTIONS(4173),
    [anon_sym_NOT] = ACTIONS(4173),
    [anon_sym_Not] = ACTIONS(4173),
    [anon_sym_POUNDelse] = ACTIONS(4175),
    [anon_sym_POUNDELSE] = ACTIONS(4175),
    [anon_sym_POUNDElse] = ACTIONS(4175),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4173),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4173),
    [anon_sym_PLUS] = ACTIONS(4175),
    [sym_datetime_literal] = ACTIONS(4175),
    [sym_date_literal] = ACTIONS(4173),
    [sym_time_literal] = ACTIONS(4173),
    [sym_biginteger_literal] = ACTIONS(4175),
    [anon_sym_if] = ACTIONS(4173),
    [anon_sym_IF] = ACTIONS(4173),
    [anon_sym_If] = ACTIONS(4173),
    [anon_sym_else] = ACTIONS(4173),
    [anon_sym_ELSE] = ACTIONS(4173),
    [anon_sym_Else] = ACTIONS(4173),
    [anon_sym_case] = ACTIONS(4173),
    [anon_sym_CASE] = ACTIONS(4173),
    [anon_sym_Case] = ACTIONS(4173),
    [anon_sym_for] = ACTIONS(4173),
    [anon_sym_FOR] = ACTIONS(4173),
    [anon_sym_For] = ACTIONS(4173),
    [anon_sym_foreach] = ACTIONS(4173),
    [anon_sym_FOREACH] = ACTIONS(4173),
    [anon_sym_Foreach] = ACTIONS(4173),
    [anon_sym_while] = ACTIONS(4173),
    [anon_sym_WHILE] = ACTIONS(4173),
    [anon_sym_While] = ACTIONS(4173),
    [anon_sym_repeat] = ACTIONS(4173),
    [anon_sym_REPEAT] = ACTIONS(4173),
    [anon_sym_Repeat] = ACTIONS(4173),
    [anon_sym_until] = ACTIONS(4173),
    [anon_sym_UNTIL] = ACTIONS(4173),
    [anon_sym_Until] = ACTIONS(4173),
    [anon_sym_exit] = ACTIONS(4173),
    [anon_sym_EXIT] = ACTIONS(4173),
    [anon_sym_Exit] = ACTIONS(4173),
    [anon_sym_continue] = ACTIONS(4173),
    [anon_sym_CONTINUE] = ACTIONS(4173),
    [anon_sym_Continue] = ACTIONS(4173),
    [anon_sym_break] = ACTIONS(4173),
    [anon_sym_BREAK] = ACTIONS(4173),
    [anon_sym_Break] = ACTIONS(4173),
    [anon_sym_with] = ACTIONS(4173),
    [anon_sym_WITH] = ACTIONS(4173),
    [anon_sym_With] = ACTIONS(4173),
    [sym_asserterror_keyword] = ACTIONS(4175),
    [sym_page_keyword] = ACTIONS(4173),
    [anon_sym_codeunit] = ACTIONS(4173),
    [anon_sym_CODEUNIT] = ACTIONS(4173),
    [anon_sym_Codeunit] = ACTIONS(4173),
    [anon_sym_CodeUnit] = ACTIONS(4173),
    [anon_sym_COdeunit] = ACTIONS(4173),
    [anon_sym_codeUnit] = ACTIONS(4173),
    [sym_report_keyword] = ACTIONS(4173),
    [sym_query_keyword] = ACTIONS(4173),
    [anon_sym_xmlport] = ACTIONS(4173),
    [anon_sym_XMLPORT] = ACTIONS(4173),
    [anon_sym_Xmlport] = ACTIONS(4173),
    [anon_sym_XMLport] = ACTIONS(4173),
    [anon_sym_XMLPort] = ACTIONS(4173),
    [anon_sym_XmlPort] = ACTIONS(4173),
    [anon_sym_enum] = ACTIONS(4173),
    [anon_sym_ENUM] = ACTIONS(4173),
    [anon_sym_Enum] = ACTIONS(4173),
    [anon_sym_eNUM] = ACTIONS(4173),
    [anon_sym_eNum] = ACTIONS(4173),
    [anon_sym_ENum] = ACTIONS(4173),
    [sym_quoted_identifier] = ACTIONS(4175),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4175),
    [sym_integer] = ACTIONS(4173),
    [sym_continue_as_identifier] = ACTIONS(4175),
    [sym_preproc_open] = ACTIONS(4175),
  },
  [STATE(1813)] = {
    [sym_identifier] = ACTIONS(4606),
    [anon_sym_SEMI] = ACTIONS(4608),
    [anon_sym_DASH] = ACTIONS(4608),
    [aux_sym_boolean_token1] = ACTIONS(4606),
    [aux_sym_boolean_token2] = ACTIONS(4606),
    [sym_decimal] = ACTIONS(4606),
    [anon_sym_LPAREN] = ACTIONS(4608),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4606),
    [anon_sym_LBRACK] = ACTIONS(4608),
    [aux_sym_record_type_token1] = ACTIONS(4606),
    [aux_sym_basic_type_token21] = ACTIONS(4606),
    [aux_sym_basic_type_token22] = ACTIONS(4606),
    [aux_sym_basic_type_token48] = ACTIONS(4606),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4606),
    [anon_sym_POUNDif] = ACTIONS(4608),
    [anon_sym_POUNDIF] = ACTIONS(4608),
    [anon_sym_POUNDIf] = ACTIONS(4608),
    [anon_sym_not] = ACTIONS(4606),
    [anon_sym_NOT] = ACTIONS(4606),
    [anon_sym_Not] = ACTIONS(4606),
    [anon_sym_POUNDelse] = ACTIONS(4608),
    [anon_sym_POUNDELSE] = ACTIONS(4608),
    [anon_sym_POUNDElse] = ACTIONS(4608),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4606),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4606),
    [anon_sym_PLUS] = ACTIONS(4608),
    [sym_datetime_literal] = ACTIONS(4608),
    [sym_date_literal] = ACTIONS(4606),
    [sym_time_literal] = ACTIONS(4606),
    [sym_biginteger_literal] = ACTIONS(4608),
    [anon_sym_if] = ACTIONS(4606),
    [anon_sym_IF] = ACTIONS(4606),
    [anon_sym_If] = ACTIONS(4606),
    [anon_sym_else] = ACTIONS(4606),
    [anon_sym_ELSE] = ACTIONS(4606),
    [anon_sym_Else] = ACTIONS(4606),
    [anon_sym_case] = ACTIONS(4606),
    [anon_sym_CASE] = ACTIONS(4606),
    [anon_sym_Case] = ACTIONS(4606),
    [anon_sym_for] = ACTIONS(4606),
    [anon_sym_FOR] = ACTIONS(4606),
    [anon_sym_For] = ACTIONS(4606),
    [anon_sym_foreach] = ACTIONS(4606),
    [anon_sym_FOREACH] = ACTIONS(4606),
    [anon_sym_Foreach] = ACTIONS(4606),
    [anon_sym_while] = ACTIONS(4606),
    [anon_sym_WHILE] = ACTIONS(4606),
    [anon_sym_While] = ACTIONS(4606),
    [anon_sym_repeat] = ACTIONS(4606),
    [anon_sym_REPEAT] = ACTIONS(4606),
    [anon_sym_Repeat] = ACTIONS(4606),
    [anon_sym_until] = ACTIONS(4606),
    [anon_sym_UNTIL] = ACTIONS(4606),
    [anon_sym_Until] = ACTIONS(4606),
    [anon_sym_exit] = ACTIONS(4606),
    [anon_sym_EXIT] = ACTIONS(4606),
    [anon_sym_Exit] = ACTIONS(4606),
    [anon_sym_continue] = ACTIONS(4606),
    [anon_sym_CONTINUE] = ACTIONS(4606),
    [anon_sym_Continue] = ACTIONS(4606),
    [anon_sym_break] = ACTIONS(4606),
    [anon_sym_BREAK] = ACTIONS(4606),
    [anon_sym_Break] = ACTIONS(4606),
    [anon_sym_with] = ACTIONS(4606),
    [anon_sym_WITH] = ACTIONS(4606),
    [anon_sym_With] = ACTIONS(4606),
    [sym_asserterror_keyword] = ACTIONS(4608),
    [sym_page_keyword] = ACTIONS(4606),
    [anon_sym_codeunit] = ACTIONS(4606),
    [anon_sym_CODEUNIT] = ACTIONS(4606),
    [anon_sym_Codeunit] = ACTIONS(4606),
    [anon_sym_CodeUnit] = ACTIONS(4606),
    [anon_sym_COdeunit] = ACTIONS(4606),
    [anon_sym_codeUnit] = ACTIONS(4606),
    [sym_report_keyword] = ACTIONS(4606),
    [sym_query_keyword] = ACTIONS(4606),
    [anon_sym_xmlport] = ACTIONS(4606),
    [anon_sym_XMLPORT] = ACTIONS(4606),
    [anon_sym_Xmlport] = ACTIONS(4606),
    [anon_sym_XMLport] = ACTIONS(4606),
    [anon_sym_XMLPort] = ACTIONS(4606),
    [anon_sym_XmlPort] = ACTIONS(4606),
    [anon_sym_enum] = ACTIONS(4606),
    [anon_sym_ENUM] = ACTIONS(4606),
    [anon_sym_Enum] = ACTIONS(4606),
    [anon_sym_eNUM] = ACTIONS(4606),
    [anon_sym_eNum] = ACTIONS(4606),
    [anon_sym_ENum] = ACTIONS(4606),
    [sym_quoted_identifier] = ACTIONS(4608),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4608),
    [sym_integer] = ACTIONS(4606),
    [sym_continue_as_identifier] = ACTIONS(4608),
    [sym_preproc_open] = ACTIONS(4608),
  },
  [STATE(1814)] = {
    [sym_identifier] = ACTIONS(4181),
    [anon_sym_SEMI] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [aux_sym_boolean_token1] = ACTIONS(4181),
    [aux_sym_boolean_token2] = ACTIONS(4181),
    [sym_decimal] = ACTIONS(4181),
    [anon_sym_LPAREN] = ACTIONS(4183),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4181),
    [anon_sym_LBRACK] = ACTIONS(4183),
    [aux_sym_record_type_token1] = ACTIONS(4181),
    [aux_sym_basic_type_token21] = ACTIONS(4181),
    [aux_sym_basic_type_token22] = ACTIONS(4181),
    [aux_sym_basic_type_token48] = ACTIONS(4181),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4181),
    [anon_sym_POUNDif] = ACTIONS(4183),
    [anon_sym_POUNDIF] = ACTIONS(4183),
    [anon_sym_POUNDIf] = ACTIONS(4183),
    [anon_sym_not] = ACTIONS(4181),
    [anon_sym_NOT] = ACTIONS(4181),
    [anon_sym_Not] = ACTIONS(4181),
    [anon_sym_POUNDelse] = ACTIONS(4183),
    [anon_sym_POUNDELSE] = ACTIONS(4183),
    [anon_sym_POUNDElse] = ACTIONS(4183),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4181),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4181),
    [anon_sym_PLUS] = ACTIONS(4183),
    [sym_datetime_literal] = ACTIONS(4183),
    [sym_date_literal] = ACTIONS(4181),
    [sym_time_literal] = ACTIONS(4181),
    [sym_biginteger_literal] = ACTIONS(4183),
    [anon_sym_if] = ACTIONS(4181),
    [anon_sym_IF] = ACTIONS(4181),
    [anon_sym_If] = ACTIONS(4181),
    [anon_sym_else] = ACTIONS(4181),
    [anon_sym_ELSE] = ACTIONS(4181),
    [anon_sym_Else] = ACTIONS(4181),
    [anon_sym_case] = ACTIONS(4181),
    [anon_sym_CASE] = ACTIONS(4181),
    [anon_sym_Case] = ACTIONS(4181),
    [anon_sym_for] = ACTIONS(4181),
    [anon_sym_FOR] = ACTIONS(4181),
    [anon_sym_For] = ACTIONS(4181),
    [anon_sym_foreach] = ACTIONS(4181),
    [anon_sym_FOREACH] = ACTIONS(4181),
    [anon_sym_Foreach] = ACTIONS(4181),
    [anon_sym_while] = ACTIONS(4181),
    [anon_sym_WHILE] = ACTIONS(4181),
    [anon_sym_While] = ACTIONS(4181),
    [anon_sym_repeat] = ACTIONS(4181),
    [anon_sym_REPEAT] = ACTIONS(4181),
    [anon_sym_Repeat] = ACTIONS(4181),
    [anon_sym_until] = ACTIONS(4181),
    [anon_sym_UNTIL] = ACTIONS(4181),
    [anon_sym_Until] = ACTIONS(4181),
    [anon_sym_exit] = ACTIONS(4181),
    [anon_sym_EXIT] = ACTIONS(4181),
    [anon_sym_Exit] = ACTIONS(4181),
    [anon_sym_continue] = ACTIONS(4181),
    [anon_sym_CONTINUE] = ACTIONS(4181),
    [anon_sym_Continue] = ACTIONS(4181),
    [anon_sym_break] = ACTIONS(4181),
    [anon_sym_BREAK] = ACTIONS(4181),
    [anon_sym_Break] = ACTIONS(4181),
    [anon_sym_with] = ACTIONS(4181),
    [anon_sym_WITH] = ACTIONS(4181),
    [anon_sym_With] = ACTIONS(4181),
    [sym_asserterror_keyword] = ACTIONS(4183),
    [sym_page_keyword] = ACTIONS(4181),
    [anon_sym_codeunit] = ACTIONS(4181),
    [anon_sym_CODEUNIT] = ACTIONS(4181),
    [anon_sym_Codeunit] = ACTIONS(4181),
    [anon_sym_CodeUnit] = ACTIONS(4181),
    [anon_sym_COdeunit] = ACTIONS(4181),
    [anon_sym_codeUnit] = ACTIONS(4181),
    [sym_report_keyword] = ACTIONS(4181),
    [sym_query_keyword] = ACTIONS(4181),
    [anon_sym_xmlport] = ACTIONS(4181),
    [anon_sym_XMLPORT] = ACTIONS(4181),
    [anon_sym_Xmlport] = ACTIONS(4181),
    [anon_sym_XMLport] = ACTIONS(4181),
    [anon_sym_XMLPort] = ACTIONS(4181),
    [anon_sym_XmlPort] = ACTIONS(4181),
    [anon_sym_enum] = ACTIONS(4181),
    [anon_sym_ENUM] = ACTIONS(4181),
    [anon_sym_Enum] = ACTIONS(4181),
    [anon_sym_eNUM] = ACTIONS(4181),
    [anon_sym_eNum] = ACTIONS(4181),
    [anon_sym_ENum] = ACTIONS(4181),
    [sym_quoted_identifier] = ACTIONS(4183),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4183),
    [sym_integer] = ACTIONS(4181),
    [sym_continue_as_identifier] = ACTIONS(4183),
    [sym_preproc_open] = ACTIONS(4183),
  },
  [STATE(1815)] = {
    [sym_identifier] = ACTIONS(4804),
    [anon_sym_SEMI] = ACTIONS(4806),
    [anon_sym_DASH] = ACTIONS(4806),
    [aux_sym_boolean_token1] = ACTIONS(4804),
    [aux_sym_boolean_token2] = ACTIONS(4804),
    [sym_decimal] = ACTIONS(4804),
    [anon_sym_LPAREN] = ACTIONS(4806),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4804),
    [anon_sym_LBRACK] = ACTIONS(4806),
    [aux_sym_record_type_token1] = ACTIONS(4804),
    [aux_sym_basic_type_token21] = ACTIONS(4804),
    [aux_sym_basic_type_token22] = ACTIONS(4804),
    [aux_sym_basic_type_token48] = ACTIONS(4804),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4804),
    [anon_sym_POUNDif] = ACTIONS(4806),
    [anon_sym_POUNDIF] = ACTIONS(4806),
    [anon_sym_POUNDIf] = ACTIONS(4806),
    [anon_sym_not] = ACTIONS(4804),
    [anon_sym_NOT] = ACTIONS(4804),
    [anon_sym_Not] = ACTIONS(4804),
    [anon_sym_POUNDelse] = ACTIONS(4806),
    [anon_sym_POUNDELSE] = ACTIONS(4806),
    [anon_sym_POUNDElse] = ACTIONS(4806),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4804),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4804),
    [anon_sym_PLUS] = ACTIONS(4806),
    [sym_datetime_literal] = ACTIONS(4806),
    [sym_date_literal] = ACTIONS(4804),
    [sym_time_literal] = ACTIONS(4804),
    [sym_biginteger_literal] = ACTIONS(4806),
    [anon_sym_if] = ACTIONS(4804),
    [anon_sym_IF] = ACTIONS(4804),
    [anon_sym_If] = ACTIONS(4804),
    [anon_sym_else] = ACTIONS(4804),
    [anon_sym_ELSE] = ACTIONS(4804),
    [anon_sym_Else] = ACTIONS(4804),
    [anon_sym_case] = ACTIONS(4804),
    [anon_sym_CASE] = ACTIONS(4804),
    [anon_sym_Case] = ACTIONS(4804),
    [anon_sym_for] = ACTIONS(4804),
    [anon_sym_FOR] = ACTIONS(4804),
    [anon_sym_For] = ACTIONS(4804),
    [anon_sym_foreach] = ACTIONS(4804),
    [anon_sym_FOREACH] = ACTIONS(4804),
    [anon_sym_Foreach] = ACTIONS(4804),
    [anon_sym_while] = ACTIONS(4804),
    [anon_sym_WHILE] = ACTIONS(4804),
    [anon_sym_While] = ACTIONS(4804),
    [anon_sym_repeat] = ACTIONS(4804),
    [anon_sym_REPEAT] = ACTIONS(4804),
    [anon_sym_Repeat] = ACTIONS(4804),
    [anon_sym_until] = ACTIONS(4804),
    [anon_sym_UNTIL] = ACTIONS(4804),
    [anon_sym_Until] = ACTIONS(4804),
    [anon_sym_exit] = ACTIONS(4804),
    [anon_sym_EXIT] = ACTIONS(4804),
    [anon_sym_Exit] = ACTIONS(4804),
    [anon_sym_continue] = ACTIONS(4804),
    [anon_sym_CONTINUE] = ACTIONS(4804),
    [anon_sym_Continue] = ACTIONS(4804),
    [anon_sym_break] = ACTIONS(4804),
    [anon_sym_BREAK] = ACTIONS(4804),
    [anon_sym_Break] = ACTIONS(4804),
    [anon_sym_with] = ACTIONS(4804),
    [anon_sym_WITH] = ACTIONS(4804),
    [anon_sym_With] = ACTIONS(4804),
    [sym_asserterror_keyword] = ACTIONS(4806),
    [sym_page_keyword] = ACTIONS(4804),
    [anon_sym_codeunit] = ACTIONS(4804),
    [anon_sym_CODEUNIT] = ACTIONS(4804),
    [anon_sym_Codeunit] = ACTIONS(4804),
    [anon_sym_CodeUnit] = ACTIONS(4804),
    [anon_sym_COdeunit] = ACTIONS(4804),
    [anon_sym_codeUnit] = ACTIONS(4804),
    [sym_report_keyword] = ACTIONS(4804),
    [sym_query_keyword] = ACTIONS(4804),
    [anon_sym_xmlport] = ACTIONS(4804),
    [anon_sym_XMLPORT] = ACTIONS(4804),
    [anon_sym_Xmlport] = ACTIONS(4804),
    [anon_sym_XMLport] = ACTIONS(4804),
    [anon_sym_XMLPort] = ACTIONS(4804),
    [anon_sym_XmlPort] = ACTIONS(4804),
    [anon_sym_enum] = ACTIONS(4804),
    [anon_sym_ENUM] = ACTIONS(4804),
    [anon_sym_Enum] = ACTIONS(4804),
    [anon_sym_eNUM] = ACTIONS(4804),
    [anon_sym_eNum] = ACTIONS(4804),
    [anon_sym_ENum] = ACTIONS(4804),
    [sym_quoted_identifier] = ACTIONS(4806),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4806),
    [sym_integer] = ACTIONS(4804),
    [sym_continue_as_identifier] = ACTIONS(4806),
    [sym_preproc_open] = ACTIONS(4806),
  },
  [STATE(1816)] = {
    [sym_identifier] = ACTIONS(4193),
    [anon_sym_SEMI] = ACTIONS(4195),
    [anon_sym_DASH] = ACTIONS(4195),
    [aux_sym_boolean_token1] = ACTIONS(4193),
    [aux_sym_boolean_token2] = ACTIONS(4193),
    [sym_decimal] = ACTIONS(4193),
    [anon_sym_LPAREN] = ACTIONS(4195),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4193),
    [anon_sym_LBRACK] = ACTIONS(4195),
    [aux_sym_record_type_token1] = ACTIONS(4193),
    [aux_sym_basic_type_token21] = ACTIONS(4193),
    [aux_sym_basic_type_token22] = ACTIONS(4193),
    [aux_sym_basic_type_token48] = ACTIONS(4193),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4193),
    [anon_sym_POUNDif] = ACTIONS(4195),
    [anon_sym_POUNDIF] = ACTIONS(4195),
    [anon_sym_POUNDIf] = ACTIONS(4195),
    [anon_sym_not] = ACTIONS(4193),
    [anon_sym_NOT] = ACTIONS(4193),
    [anon_sym_Not] = ACTIONS(4193),
    [anon_sym_POUNDelse] = ACTIONS(4195),
    [anon_sym_POUNDELSE] = ACTIONS(4195),
    [anon_sym_POUNDElse] = ACTIONS(4195),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4193),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4193),
    [anon_sym_PLUS] = ACTIONS(4195),
    [sym_datetime_literal] = ACTIONS(4195),
    [sym_date_literal] = ACTIONS(4193),
    [sym_time_literal] = ACTIONS(4193),
    [sym_biginteger_literal] = ACTIONS(4195),
    [anon_sym_if] = ACTIONS(4193),
    [anon_sym_IF] = ACTIONS(4193),
    [anon_sym_If] = ACTIONS(4193),
    [anon_sym_else] = ACTIONS(4193),
    [anon_sym_ELSE] = ACTIONS(4193),
    [anon_sym_Else] = ACTIONS(4193),
    [anon_sym_case] = ACTIONS(4193),
    [anon_sym_CASE] = ACTIONS(4193),
    [anon_sym_Case] = ACTIONS(4193),
    [anon_sym_for] = ACTIONS(4193),
    [anon_sym_FOR] = ACTIONS(4193),
    [anon_sym_For] = ACTIONS(4193),
    [anon_sym_foreach] = ACTIONS(4193),
    [anon_sym_FOREACH] = ACTIONS(4193),
    [anon_sym_Foreach] = ACTIONS(4193),
    [anon_sym_while] = ACTIONS(4193),
    [anon_sym_WHILE] = ACTIONS(4193),
    [anon_sym_While] = ACTIONS(4193),
    [anon_sym_repeat] = ACTIONS(4193),
    [anon_sym_REPEAT] = ACTIONS(4193),
    [anon_sym_Repeat] = ACTIONS(4193),
    [anon_sym_until] = ACTIONS(4193),
    [anon_sym_UNTIL] = ACTIONS(4193),
    [anon_sym_Until] = ACTIONS(4193),
    [anon_sym_exit] = ACTIONS(4193),
    [anon_sym_EXIT] = ACTIONS(4193),
    [anon_sym_Exit] = ACTIONS(4193),
    [anon_sym_continue] = ACTIONS(4193),
    [anon_sym_CONTINUE] = ACTIONS(4193),
    [anon_sym_Continue] = ACTIONS(4193),
    [anon_sym_break] = ACTIONS(4193),
    [anon_sym_BREAK] = ACTIONS(4193),
    [anon_sym_Break] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4193),
    [anon_sym_WITH] = ACTIONS(4193),
    [anon_sym_With] = ACTIONS(4193),
    [sym_asserterror_keyword] = ACTIONS(4195),
    [sym_page_keyword] = ACTIONS(4193),
    [anon_sym_codeunit] = ACTIONS(4193),
    [anon_sym_CODEUNIT] = ACTIONS(4193),
    [anon_sym_Codeunit] = ACTIONS(4193),
    [anon_sym_CodeUnit] = ACTIONS(4193),
    [anon_sym_COdeunit] = ACTIONS(4193),
    [anon_sym_codeUnit] = ACTIONS(4193),
    [sym_report_keyword] = ACTIONS(4193),
    [sym_query_keyword] = ACTIONS(4193),
    [anon_sym_xmlport] = ACTIONS(4193),
    [anon_sym_XMLPORT] = ACTIONS(4193),
    [anon_sym_Xmlport] = ACTIONS(4193),
    [anon_sym_XMLport] = ACTIONS(4193),
    [anon_sym_XMLPort] = ACTIONS(4193),
    [anon_sym_XmlPort] = ACTIONS(4193),
    [anon_sym_enum] = ACTIONS(4193),
    [anon_sym_ENUM] = ACTIONS(4193),
    [anon_sym_Enum] = ACTIONS(4193),
    [anon_sym_eNUM] = ACTIONS(4193),
    [anon_sym_eNum] = ACTIONS(4193),
    [anon_sym_ENum] = ACTIONS(4193),
    [sym_quoted_identifier] = ACTIONS(4195),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4195),
    [sym_integer] = ACTIONS(4193),
    [sym_continue_as_identifier] = ACTIONS(4195),
    [sym_preproc_open] = ACTIONS(4195),
  },
  [STATE(1817)] = {
    [sym_identifier] = ACTIONS(4197),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_DASH] = ACTIONS(4199),
    [aux_sym_boolean_token1] = ACTIONS(4197),
    [aux_sym_boolean_token2] = ACTIONS(4197),
    [sym_decimal] = ACTIONS(4197),
    [anon_sym_LPAREN] = ACTIONS(4199),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4197),
    [anon_sym_LBRACK] = ACTIONS(4199),
    [aux_sym_record_type_token1] = ACTIONS(4197),
    [aux_sym_basic_type_token21] = ACTIONS(4197),
    [aux_sym_basic_type_token22] = ACTIONS(4197),
    [aux_sym_basic_type_token48] = ACTIONS(4197),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4197),
    [anon_sym_POUNDif] = ACTIONS(4199),
    [anon_sym_POUNDIF] = ACTIONS(4199),
    [anon_sym_POUNDIf] = ACTIONS(4199),
    [anon_sym_not] = ACTIONS(4197),
    [anon_sym_NOT] = ACTIONS(4197),
    [anon_sym_Not] = ACTIONS(4197),
    [anon_sym_POUNDelse] = ACTIONS(4199),
    [anon_sym_POUNDELSE] = ACTIONS(4199),
    [anon_sym_POUNDElse] = ACTIONS(4199),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4197),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4197),
    [anon_sym_PLUS] = ACTIONS(4199),
    [sym_datetime_literal] = ACTIONS(4199),
    [sym_date_literal] = ACTIONS(4197),
    [sym_time_literal] = ACTIONS(4197),
    [sym_biginteger_literal] = ACTIONS(4199),
    [anon_sym_if] = ACTIONS(4197),
    [anon_sym_IF] = ACTIONS(4197),
    [anon_sym_If] = ACTIONS(4197),
    [anon_sym_else] = ACTIONS(4197),
    [anon_sym_ELSE] = ACTIONS(4197),
    [anon_sym_Else] = ACTIONS(4197),
    [anon_sym_case] = ACTIONS(4197),
    [anon_sym_CASE] = ACTIONS(4197),
    [anon_sym_Case] = ACTIONS(4197),
    [anon_sym_for] = ACTIONS(4197),
    [anon_sym_FOR] = ACTIONS(4197),
    [anon_sym_For] = ACTIONS(4197),
    [anon_sym_foreach] = ACTIONS(4197),
    [anon_sym_FOREACH] = ACTIONS(4197),
    [anon_sym_Foreach] = ACTIONS(4197),
    [anon_sym_while] = ACTIONS(4197),
    [anon_sym_WHILE] = ACTIONS(4197),
    [anon_sym_While] = ACTIONS(4197),
    [anon_sym_repeat] = ACTIONS(4197),
    [anon_sym_REPEAT] = ACTIONS(4197),
    [anon_sym_Repeat] = ACTIONS(4197),
    [anon_sym_until] = ACTIONS(4197),
    [anon_sym_UNTIL] = ACTIONS(4197),
    [anon_sym_Until] = ACTIONS(4197),
    [anon_sym_exit] = ACTIONS(4197),
    [anon_sym_EXIT] = ACTIONS(4197),
    [anon_sym_Exit] = ACTIONS(4197),
    [anon_sym_continue] = ACTIONS(4197),
    [anon_sym_CONTINUE] = ACTIONS(4197),
    [anon_sym_Continue] = ACTIONS(4197),
    [anon_sym_break] = ACTIONS(4197),
    [anon_sym_BREAK] = ACTIONS(4197),
    [anon_sym_Break] = ACTIONS(4197),
    [anon_sym_with] = ACTIONS(4197),
    [anon_sym_WITH] = ACTIONS(4197),
    [anon_sym_With] = ACTIONS(4197),
    [sym_asserterror_keyword] = ACTIONS(4199),
    [sym_page_keyword] = ACTIONS(4197),
    [anon_sym_codeunit] = ACTIONS(4197),
    [anon_sym_CODEUNIT] = ACTIONS(4197),
    [anon_sym_Codeunit] = ACTIONS(4197),
    [anon_sym_CodeUnit] = ACTIONS(4197),
    [anon_sym_COdeunit] = ACTIONS(4197),
    [anon_sym_codeUnit] = ACTIONS(4197),
    [sym_report_keyword] = ACTIONS(4197),
    [sym_query_keyword] = ACTIONS(4197),
    [anon_sym_xmlport] = ACTIONS(4197),
    [anon_sym_XMLPORT] = ACTIONS(4197),
    [anon_sym_Xmlport] = ACTIONS(4197),
    [anon_sym_XMLport] = ACTIONS(4197),
    [anon_sym_XMLPort] = ACTIONS(4197),
    [anon_sym_XmlPort] = ACTIONS(4197),
    [anon_sym_enum] = ACTIONS(4197),
    [anon_sym_ENUM] = ACTIONS(4197),
    [anon_sym_Enum] = ACTIONS(4197),
    [anon_sym_eNUM] = ACTIONS(4197),
    [anon_sym_eNum] = ACTIONS(4197),
    [anon_sym_ENum] = ACTIONS(4197),
    [sym_quoted_identifier] = ACTIONS(4199),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4199),
    [sym_integer] = ACTIONS(4197),
    [sym_continue_as_identifier] = ACTIONS(4199),
    [sym_preproc_open] = ACTIONS(4199),
  },
  [STATE(1818)] = {
    [sym_identifier] = ACTIONS(4201),
    [anon_sym_SEMI] = ACTIONS(4203),
    [anon_sym_DASH] = ACTIONS(4203),
    [aux_sym_boolean_token1] = ACTIONS(4201),
    [aux_sym_boolean_token2] = ACTIONS(4201),
    [sym_decimal] = ACTIONS(4201),
    [anon_sym_LPAREN] = ACTIONS(4203),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4201),
    [anon_sym_LBRACK] = ACTIONS(4203),
    [aux_sym_record_type_token1] = ACTIONS(4201),
    [aux_sym_basic_type_token21] = ACTIONS(4201),
    [aux_sym_basic_type_token22] = ACTIONS(4201),
    [aux_sym_basic_type_token48] = ACTIONS(4201),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4201),
    [anon_sym_POUNDif] = ACTIONS(4203),
    [anon_sym_POUNDIF] = ACTIONS(4203),
    [anon_sym_POUNDIf] = ACTIONS(4203),
    [anon_sym_not] = ACTIONS(4201),
    [anon_sym_NOT] = ACTIONS(4201),
    [anon_sym_Not] = ACTIONS(4201),
    [anon_sym_POUNDelse] = ACTIONS(4203),
    [anon_sym_POUNDELSE] = ACTIONS(4203),
    [anon_sym_POUNDElse] = ACTIONS(4203),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4201),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4201),
    [anon_sym_PLUS] = ACTIONS(4203),
    [sym_datetime_literal] = ACTIONS(4203),
    [sym_date_literal] = ACTIONS(4201),
    [sym_time_literal] = ACTIONS(4201),
    [sym_biginteger_literal] = ACTIONS(4203),
    [anon_sym_if] = ACTIONS(4201),
    [anon_sym_IF] = ACTIONS(4201),
    [anon_sym_If] = ACTIONS(4201),
    [anon_sym_else] = ACTIONS(4201),
    [anon_sym_ELSE] = ACTIONS(4201),
    [anon_sym_Else] = ACTIONS(4201),
    [anon_sym_case] = ACTIONS(4201),
    [anon_sym_CASE] = ACTIONS(4201),
    [anon_sym_Case] = ACTIONS(4201),
    [anon_sym_for] = ACTIONS(4201),
    [anon_sym_FOR] = ACTIONS(4201),
    [anon_sym_For] = ACTIONS(4201),
    [anon_sym_foreach] = ACTIONS(4201),
    [anon_sym_FOREACH] = ACTIONS(4201),
    [anon_sym_Foreach] = ACTIONS(4201),
    [anon_sym_while] = ACTIONS(4201),
    [anon_sym_WHILE] = ACTIONS(4201),
    [anon_sym_While] = ACTIONS(4201),
    [anon_sym_repeat] = ACTIONS(4201),
    [anon_sym_REPEAT] = ACTIONS(4201),
    [anon_sym_Repeat] = ACTIONS(4201),
    [anon_sym_until] = ACTIONS(4201),
    [anon_sym_UNTIL] = ACTIONS(4201),
    [anon_sym_Until] = ACTIONS(4201),
    [anon_sym_exit] = ACTIONS(4201),
    [anon_sym_EXIT] = ACTIONS(4201),
    [anon_sym_Exit] = ACTIONS(4201),
    [anon_sym_continue] = ACTIONS(4201),
    [anon_sym_CONTINUE] = ACTIONS(4201),
    [anon_sym_Continue] = ACTIONS(4201),
    [anon_sym_break] = ACTIONS(4201),
    [anon_sym_BREAK] = ACTIONS(4201),
    [anon_sym_Break] = ACTIONS(4201),
    [anon_sym_with] = ACTIONS(4201),
    [anon_sym_WITH] = ACTIONS(4201),
    [anon_sym_With] = ACTIONS(4201),
    [sym_asserterror_keyword] = ACTIONS(4203),
    [sym_page_keyword] = ACTIONS(4201),
    [anon_sym_codeunit] = ACTIONS(4201),
    [anon_sym_CODEUNIT] = ACTIONS(4201),
    [anon_sym_Codeunit] = ACTIONS(4201),
    [anon_sym_CodeUnit] = ACTIONS(4201),
    [anon_sym_COdeunit] = ACTIONS(4201),
    [anon_sym_codeUnit] = ACTIONS(4201),
    [sym_report_keyword] = ACTIONS(4201),
    [sym_query_keyword] = ACTIONS(4201),
    [anon_sym_xmlport] = ACTIONS(4201),
    [anon_sym_XMLPORT] = ACTIONS(4201),
    [anon_sym_Xmlport] = ACTIONS(4201),
    [anon_sym_XMLport] = ACTIONS(4201),
    [anon_sym_XMLPort] = ACTIONS(4201),
    [anon_sym_XmlPort] = ACTIONS(4201),
    [anon_sym_enum] = ACTIONS(4201),
    [anon_sym_ENUM] = ACTIONS(4201),
    [anon_sym_Enum] = ACTIONS(4201),
    [anon_sym_eNUM] = ACTIONS(4201),
    [anon_sym_eNum] = ACTIONS(4201),
    [anon_sym_ENum] = ACTIONS(4201),
    [sym_quoted_identifier] = ACTIONS(4203),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4203),
    [sym_integer] = ACTIONS(4201),
    [sym_continue_as_identifier] = ACTIONS(4203),
    [sym_preproc_open] = ACTIONS(4203),
  },
  [STATE(1819)] = {
    [sym_identifier] = ACTIONS(4205),
    [anon_sym_SEMI] = ACTIONS(4207),
    [anon_sym_DASH] = ACTIONS(4207),
    [aux_sym_boolean_token1] = ACTIONS(4205),
    [aux_sym_boolean_token2] = ACTIONS(4205),
    [sym_decimal] = ACTIONS(4205),
    [anon_sym_LPAREN] = ACTIONS(4207),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4205),
    [anon_sym_LBRACK] = ACTIONS(4207),
    [aux_sym_record_type_token1] = ACTIONS(4205),
    [aux_sym_basic_type_token21] = ACTIONS(4205),
    [aux_sym_basic_type_token22] = ACTIONS(4205),
    [aux_sym_basic_type_token48] = ACTIONS(4205),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4205),
    [anon_sym_POUNDif] = ACTIONS(4207),
    [anon_sym_POUNDIF] = ACTIONS(4207),
    [anon_sym_POUNDIf] = ACTIONS(4207),
    [anon_sym_not] = ACTIONS(4205),
    [anon_sym_NOT] = ACTIONS(4205),
    [anon_sym_Not] = ACTIONS(4205),
    [anon_sym_POUNDelse] = ACTIONS(4207),
    [anon_sym_POUNDELSE] = ACTIONS(4207),
    [anon_sym_POUNDElse] = ACTIONS(4207),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4205),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4205),
    [anon_sym_PLUS] = ACTIONS(4207),
    [sym_datetime_literal] = ACTIONS(4207),
    [sym_date_literal] = ACTIONS(4205),
    [sym_time_literal] = ACTIONS(4205),
    [sym_biginteger_literal] = ACTIONS(4207),
    [anon_sym_if] = ACTIONS(4205),
    [anon_sym_IF] = ACTIONS(4205),
    [anon_sym_If] = ACTIONS(4205),
    [anon_sym_else] = ACTIONS(4205),
    [anon_sym_ELSE] = ACTIONS(4205),
    [anon_sym_Else] = ACTIONS(4205),
    [anon_sym_case] = ACTIONS(4205),
    [anon_sym_CASE] = ACTIONS(4205),
    [anon_sym_Case] = ACTIONS(4205),
    [anon_sym_for] = ACTIONS(4205),
    [anon_sym_FOR] = ACTIONS(4205),
    [anon_sym_For] = ACTIONS(4205),
    [anon_sym_foreach] = ACTIONS(4205),
    [anon_sym_FOREACH] = ACTIONS(4205),
    [anon_sym_Foreach] = ACTIONS(4205),
    [anon_sym_while] = ACTIONS(4205),
    [anon_sym_WHILE] = ACTIONS(4205),
    [anon_sym_While] = ACTIONS(4205),
    [anon_sym_repeat] = ACTIONS(4205),
    [anon_sym_REPEAT] = ACTIONS(4205),
    [anon_sym_Repeat] = ACTIONS(4205),
    [anon_sym_until] = ACTIONS(4205),
    [anon_sym_UNTIL] = ACTIONS(4205),
    [anon_sym_Until] = ACTIONS(4205),
    [anon_sym_exit] = ACTIONS(4205),
    [anon_sym_EXIT] = ACTIONS(4205),
    [anon_sym_Exit] = ACTIONS(4205),
    [anon_sym_continue] = ACTIONS(4205),
    [anon_sym_CONTINUE] = ACTIONS(4205),
    [anon_sym_Continue] = ACTIONS(4205),
    [anon_sym_break] = ACTIONS(4205),
    [anon_sym_BREAK] = ACTIONS(4205),
    [anon_sym_Break] = ACTIONS(4205),
    [anon_sym_with] = ACTIONS(4205),
    [anon_sym_WITH] = ACTIONS(4205),
    [anon_sym_With] = ACTIONS(4205),
    [sym_asserterror_keyword] = ACTIONS(4207),
    [sym_page_keyword] = ACTIONS(4205),
    [anon_sym_codeunit] = ACTIONS(4205),
    [anon_sym_CODEUNIT] = ACTIONS(4205),
    [anon_sym_Codeunit] = ACTIONS(4205),
    [anon_sym_CodeUnit] = ACTIONS(4205),
    [anon_sym_COdeunit] = ACTIONS(4205),
    [anon_sym_codeUnit] = ACTIONS(4205),
    [sym_report_keyword] = ACTIONS(4205),
    [sym_query_keyword] = ACTIONS(4205),
    [anon_sym_xmlport] = ACTIONS(4205),
    [anon_sym_XMLPORT] = ACTIONS(4205),
    [anon_sym_Xmlport] = ACTIONS(4205),
    [anon_sym_XMLport] = ACTIONS(4205),
    [anon_sym_XMLPort] = ACTIONS(4205),
    [anon_sym_XmlPort] = ACTIONS(4205),
    [anon_sym_enum] = ACTIONS(4205),
    [anon_sym_ENUM] = ACTIONS(4205),
    [anon_sym_Enum] = ACTIONS(4205),
    [anon_sym_eNUM] = ACTIONS(4205),
    [anon_sym_eNum] = ACTIONS(4205),
    [anon_sym_ENum] = ACTIONS(4205),
    [sym_quoted_identifier] = ACTIONS(4207),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4207),
    [sym_integer] = ACTIONS(4205),
    [sym_continue_as_identifier] = ACTIONS(4207),
    [sym_preproc_open] = ACTIONS(4207),
  },
  [STATE(1820)] = {
    [sym_identifier] = ACTIONS(4209),
    [anon_sym_SEMI] = ACTIONS(4211),
    [anon_sym_DASH] = ACTIONS(4211),
    [aux_sym_boolean_token1] = ACTIONS(4209),
    [aux_sym_boolean_token2] = ACTIONS(4209),
    [sym_decimal] = ACTIONS(4209),
    [anon_sym_LPAREN] = ACTIONS(4211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4209),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [aux_sym_record_type_token1] = ACTIONS(4209),
    [aux_sym_basic_type_token21] = ACTIONS(4209),
    [aux_sym_basic_type_token22] = ACTIONS(4209),
    [aux_sym_basic_type_token48] = ACTIONS(4209),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4209),
    [anon_sym_POUNDif] = ACTIONS(4211),
    [anon_sym_POUNDIF] = ACTIONS(4211),
    [anon_sym_POUNDIf] = ACTIONS(4211),
    [anon_sym_not] = ACTIONS(4209),
    [anon_sym_NOT] = ACTIONS(4209),
    [anon_sym_Not] = ACTIONS(4209),
    [anon_sym_POUNDelse] = ACTIONS(4211),
    [anon_sym_POUNDELSE] = ACTIONS(4211),
    [anon_sym_POUNDElse] = ACTIONS(4211),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4209),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4209),
    [anon_sym_PLUS] = ACTIONS(4211),
    [sym_datetime_literal] = ACTIONS(4211),
    [sym_date_literal] = ACTIONS(4209),
    [sym_time_literal] = ACTIONS(4209),
    [sym_biginteger_literal] = ACTIONS(4211),
    [anon_sym_if] = ACTIONS(4209),
    [anon_sym_IF] = ACTIONS(4209),
    [anon_sym_If] = ACTIONS(4209),
    [anon_sym_else] = ACTIONS(4209),
    [anon_sym_ELSE] = ACTIONS(4209),
    [anon_sym_Else] = ACTIONS(4209),
    [anon_sym_case] = ACTIONS(4209),
    [anon_sym_CASE] = ACTIONS(4209),
    [anon_sym_Case] = ACTIONS(4209),
    [anon_sym_for] = ACTIONS(4209),
    [anon_sym_FOR] = ACTIONS(4209),
    [anon_sym_For] = ACTIONS(4209),
    [anon_sym_foreach] = ACTIONS(4209),
    [anon_sym_FOREACH] = ACTIONS(4209),
    [anon_sym_Foreach] = ACTIONS(4209),
    [anon_sym_while] = ACTIONS(4209),
    [anon_sym_WHILE] = ACTIONS(4209),
    [anon_sym_While] = ACTIONS(4209),
    [anon_sym_repeat] = ACTIONS(4209),
    [anon_sym_REPEAT] = ACTIONS(4209),
    [anon_sym_Repeat] = ACTIONS(4209),
    [anon_sym_until] = ACTIONS(4209),
    [anon_sym_UNTIL] = ACTIONS(4209),
    [anon_sym_Until] = ACTIONS(4209),
    [anon_sym_exit] = ACTIONS(4209),
    [anon_sym_EXIT] = ACTIONS(4209),
    [anon_sym_Exit] = ACTIONS(4209),
    [anon_sym_continue] = ACTIONS(4209),
    [anon_sym_CONTINUE] = ACTIONS(4209),
    [anon_sym_Continue] = ACTIONS(4209),
    [anon_sym_break] = ACTIONS(4209),
    [anon_sym_BREAK] = ACTIONS(4209),
    [anon_sym_Break] = ACTIONS(4209),
    [anon_sym_with] = ACTIONS(4209),
    [anon_sym_WITH] = ACTIONS(4209),
    [anon_sym_With] = ACTIONS(4209),
    [sym_asserterror_keyword] = ACTIONS(4211),
    [sym_page_keyword] = ACTIONS(4209),
    [anon_sym_codeunit] = ACTIONS(4209),
    [anon_sym_CODEUNIT] = ACTIONS(4209),
    [anon_sym_Codeunit] = ACTIONS(4209),
    [anon_sym_CodeUnit] = ACTIONS(4209),
    [anon_sym_COdeunit] = ACTIONS(4209),
    [anon_sym_codeUnit] = ACTIONS(4209),
    [sym_report_keyword] = ACTIONS(4209),
    [sym_query_keyword] = ACTIONS(4209),
    [anon_sym_xmlport] = ACTIONS(4209),
    [anon_sym_XMLPORT] = ACTIONS(4209),
    [anon_sym_Xmlport] = ACTIONS(4209),
    [anon_sym_XMLport] = ACTIONS(4209),
    [anon_sym_XMLPort] = ACTIONS(4209),
    [anon_sym_XmlPort] = ACTIONS(4209),
    [anon_sym_enum] = ACTIONS(4209),
    [anon_sym_ENUM] = ACTIONS(4209),
    [anon_sym_Enum] = ACTIONS(4209),
    [anon_sym_eNUM] = ACTIONS(4209),
    [anon_sym_eNum] = ACTIONS(4209),
    [anon_sym_ENum] = ACTIONS(4209),
    [sym_quoted_identifier] = ACTIONS(4211),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4211),
    [sym_integer] = ACTIONS(4209),
    [sym_continue_as_identifier] = ACTIONS(4211),
    [sym_preproc_open] = ACTIONS(4211),
  },
  [STATE(1821)] = {
    [sym_identifier] = ACTIONS(4217),
    [anon_sym_SEMI] = ACTIONS(4219),
    [anon_sym_DASH] = ACTIONS(4219),
    [aux_sym_boolean_token1] = ACTIONS(4217),
    [aux_sym_boolean_token2] = ACTIONS(4217),
    [sym_decimal] = ACTIONS(4217),
    [anon_sym_LPAREN] = ACTIONS(4219),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4217),
    [anon_sym_LBRACK] = ACTIONS(4219),
    [aux_sym_record_type_token1] = ACTIONS(4217),
    [aux_sym_basic_type_token21] = ACTIONS(4217),
    [aux_sym_basic_type_token22] = ACTIONS(4217),
    [aux_sym_basic_type_token48] = ACTIONS(4217),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4217),
    [anon_sym_POUNDif] = ACTIONS(4219),
    [anon_sym_POUNDIF] = ACTIONS(4219),
    [anon_sym_POUNDIf] = ACTIONS(4219),
    [anon_sym_not] = ACTIONS(4217),
    [anon_sym_NOT] = ACTIONS(4217),
    [anon_sym_Not] = ACTIONS(4217),
    [anon_sym_POUNDelse] = ACTIONS(4219),
    [anon_sym_POUNDELSE] = ACTIONS(4219),
    [anon_sym_POUNDElse] = ACTIONS(4219),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4217),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4217),
    [anon_sym_PLUS] = ACTIONS(4219),
    [sym_datetime_literal] = ACTIONS(4219),
    [sym_date_literal] = ACTIONS(4217),
    [sym_time_literal] = ACTIONS(4217),
    [sym_biginteger_literal] = ACTIONS(4219),
    [anon_sym_if] = ACTIONS(4217),
    [anon_sym_IF] = ACTIONS(4217),
    [anon_sym_If] = ACTIONS(4217),
    [anon_sym_else] = ACTIONS(4217),
    [anon_sym_ELSE] = ACTIONS(4217),
    [anon_sym_Else] = ACTIONS(4217),
    [anon_sym_case] = ACTIONS(4217),
    [anon_sym_CASE] = ACTIONS(4217),
    [anon_sym_Case] = ACTIONS(4217),
    [anon_sym_for] = ACTIONS(4217),
    [anon_sym_FOR] = ACTIONS(4217),
    [anon_sym_For] = ACTIONS(4217),
    [anon_sym_foreach] = ACTIONS(4217),
    [anon_sym_FOREACH] = ACTIONS(4217),
    [anon_sym_Foreach] = ACTIONS(4217),
    [anon_sym_while] = ACTIONS(4217),
    [anon_sym_WHILE] = ACTIONS(4217),
    [anon_sym_While] = ACTIONS(4217),
    [anon_sym_repeat] = ACTIONS(4217),
    [anon_sym_REPEAT] = ACTIONS(4217),
    [anon_sym_Repeat] = ACTIONS(4217),
    [anon_sym_until] = ACTIONS(4217),
    [anon_sym_UNTIL] = ACTIONS(4217),
    [anon_sym_Until] = ACTIONS(4217),
    [anon_sym_exit] = ACTIONS(4217),
    [anon_sym_EXIT] = ACTIONS(4217),
    [anon_sym_Exit] = ACTIONS(4217),
    [anon_sym_continue] = ACTIONS(4217),
    [anon_sym_CONTINUE] = ACTIONS(4217),
    [anon_sym_Continue] = ACTIONS(4217),
    [anon_sym_break] = ACTIONS(4217),
    [anon_sym_BREAK] = ACTIONS(4217),
    [anon_sym_Break] = ACTIONS(4217),
    [anon_sym_with] = ACTIONS(4217),
    [anon_sym_WITH] = ACTIONS(4217),
    [anon_sym_With] = ACTIONS(4217),
    [sym_asserterror_keyword] = ACTIONS(4219),
    [sym_page_keyword] = ACTIONS(4217),
    [anon_sym_codeunit] = ACTIONS(4217),
    [anon_sym_CODEUNIT] = ACTIONS(4217),
    [anon_sym_Codeunit] = ACTIONS(4217),
    [anon_sym_CodeUnit] = ACTIONS(4217),
    [anon_sym_COdeunit] = ACTIONS(4217),
    [anon_sym_codeUnit] = ACTIONS(4217),
    [sym_report_keyword] = ACTIONS(4217),
    [sym_query_keyword] = ACTIONS(4217),
    [anon_sym_xmlport] = ACTIONS(4217),
    [anon_sym_XMLPORT] = ACTIONS(4217),
    [anon_sym_Xmlport] = ACTIONS(4217),
    [anon_sym_XMLport] = ACTIONS(4217),
    [anon_sym_XMLPort] = ACTIONS(4217),
    [anon_sym_XmlPort] = ACTIONS(4217),
    [anon_sym_enum] = ACTIONS(4217),
    [anon_sym_ENUM] = ACTIONS(4217),
    [anon_sym_Enum] = ACTIONS(4217),
    [anon_sym_eNUM] = ACTIONS(4217),
    [anon_sym_eNum] = ACTIONS(4217),
    [anon_sym_ENum] = ACTIONS(4217),
    [sym_quoted_identifier] = ACTIONS(4219),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4219),
    [sym_integer] = ACTIONS(4217),
    [sym_continue_as_identifier] = ACTIONS(4219),
    [sym_preproc_open] = ACTIONS(4219),
  },
  [STATE(1822)] = {
    [sym_identifier] = ACTIONS(4221),
    [anon_sym_SEMI] = ACTIONS(4223),
    [anon_sym_DASH] = ACTIONS(4223),
    [aux_sym_boolean_token1] = ACTIONS(4221),
    [aux_sym_boolean_token2] = ACTIONS(4221),
    [sym_decimal] = ACTIONS(4221),
    [anon_sym_LPAREN] = ACTIONS(4223),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4221),
    [anon_sym_LBRACK] = ACTIONS(4223),
    [aux_sym_record_type_token1] = ACTIONS(4221),
    [aux_sym_basic_type_token21] = ACTIONS(4221),
    [aux_sym_basic_type_token22] = ACTIONS(4221),
    [aux_sym_basic_type_token48] = ACTIONS(4221),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4221),
    [anon_sym_POUNDif] = ACTIONS(4223),
    [anon_sym_POUNDIF] = ACTIONS(4223),
    [anon_sym_POUNDIf] = ACTIONS(4223),
    [anon_sym_not] = ACTIONS(4221),
    [anon_sym_NOT] = ACTIONS(4221),
    [anon_sym_Not] = ACTIONS(4221),
    [anon_sym_POUNDelse] = ACTIONS(4223),
    [anon_sym_POUNDELSE] = ACTIONS(4223),
    [anon_sym_POUNDElse] = ACTIONS(4223),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4221),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4221),
    [anon_sym_PLUS] = ACTIONS(4223),
    [sym_datetime_literal] = ACTIONS(4223),
    [sym_date_literal] = ACTIONS(4221),
    [sym_time_literal] = ACTIONS(4221),
    [sym_biginteger_literal] = ACTIONS(4223),
    [anon_sym_if] = ACTIONS(4221),
    [anon_sym_IF] = ACTIONS(4221),
    [anon_sym_If] = ACTIONS(4221),
    [anon_sym_else] = ACTIONS(4221),
    [anon_sym_ELSE] = ACTIONS(4221),
    [anon_sym_Else] = ACTIONS(4221),
    [anon_sym_case] = ACTIONS(4221),
    [anon_sym_CASE] = ACTIONS(4221),
    [anon_sym_Case] = ACTIONS(4221),
    [anon_sym_for] = ACTIONS(4221),
    [anon_sym_FOR] = ACTIONS(4221),
    [anon_sym_For] = ACTIONS(4221),
    [anon_sym_foreach] = ACTIONS(4221),
    [anon_sym_FOREACH] = ACTIONS(4221),
    [anon_sym_Foreach] = ACTIONS(4221),
    [anon_sym_while] = ACTIONS(4221),
    [anon_sym_WHILE] = ACTIONS(4221),
    [anon_sym_While] = ACTIONS(4221),
    [anon_sym_repeat] = ACTIONS(4221),
    [anon_sym_REPEAT] = ACTIONS(4221),
    [anon_sym_Repeat] = ACTIONS(4221),
    [anon_sym_until] = ACTIONS(4221),
    [anon_sym_UNTIL] = ACTIONS(4221),
    [anon_sym_Until] = ACTIONS(4221),
    [anon_sym_exit] = ACTIONS(4221),
    [anon_sym_EXIT] = ACTIONS(4221),
    [anon_sym_Exit] = ACTIONS(4221),
    [anon_sym_continue] = ACTIONS(4221),
    [anon_sym_CONTINUE] = ACTIONS(4221),
    [anon_sym_Continue] = ACTIONS(4221),
    [anon_sym_break] = ACTIONS(4221),
    [anon_sym_BREAK] = ACTIONS(4221),
    [anon_sym_Break] = ACTIONS(4221),
    [anon_sym_with] = ACTIONS(4221),
    [anon_sym_WITH] = ACTIONS(4221),
    [anon_sym_With] = ACTIONS(4221),
    [sym_asserterror_keyword] = ACTIONS(4223),
    [sym_page_keyword] = ACTIONS(4221),
    [anon_sym_codeunit] = ACTIONS(4221),
    [anon_sym_CODEUNIT] = ACTIONS(4221),
    [anon_sym_Codeunit] = ACTIONS(4221),
    [anon_sym_CodeUnit] = ACTIONS(4221),
    [anon_sym_COdeunit] = ACTIONS(4221),
    [anon_sym_codeUnit] = ACTIONS(4221),
    [sym_report_keyword] = ACTIONS(4221),
    [sym_query_keyword] = ACTIONS(4221),
    [anon_sym_xmlport] = ACTIONS(4221),
    [anon_sym_XMLPORT] = ACTIONS(4221),
    [anon_sym_Xmlport] = ACTIONS(4221),
    [anon_sym_XMLport] = ACTIONS(4221),
    [anon_sym_XMLPort] = ACTIONS(4221),
    [anon_sym_XmlPort] = ACTIONS(4221),
    [anon_sym_enum] = ACTIONS(4221),
    [anon_sym_ENUM] = ACTIONS(4221),
    [anon_sym_Enum] = ACTIONS(4221),
    [anon_sym_eNUM] = ACTIONS(4221),
    [anon_sym_eNum] = ACTIONS(4221),
    [anon_sym_ENum] = ACTIONS(4221),
    [sym_quoted_identifier] = ACTIONS(4223),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4223),
    [sym_integer] = ACTIONS(4221),
    [sym_continue_as_identifier] = ACTIONS(4223),
    [sym_preproc_open] = ACTIONS(4223),
  },
  [STATE(1823)] = {
    [sym_identifier] = ACTIONS(4225),
    [anon_sym_SEMI] = ACTIONS(4227),
    [anon_sym_DASH] = ACTIONS(4227),
    [aux_sym_boolean_token1] = ACTIONS(4225),
    [aux_sym_boolean_token2] = ACTIONS(4225),
    [sym_decimal] = ACTIONS(4225),
    [anon_sym_LPAREN] = ACTIONS(4227),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4225),
    [anon_sym_LBRACK] = ACTIONS(4227),
    [aux_sym_record_type_token1] = ACTIONS(4225),
    [aux_sym_basic_type_token21] = ACTIONS(4225),
    [aux_sym_basic_type_token22] = ACTIONS(4225),
    [aux_sym_basic_type_token48] = ACTIONS(4225),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4225),
    [anon_sym_POUNDif] = ACTIONS(4227),
    [anon_sym_POUNDIF] = ACTIONS(4227),
    [anon_sym_POUNDIf] = ACTIONS(4227),
    [anon_sym_not] = ACTIONS(4225),
    [anon_sym_NOT] = ACTIONS(4225),
    [anon_sym_Not] = ACTIONS(4225),
    [anon_sym_POUNDelse] = ACTIONS(4227),
    [anon_sym_POUNDELSE] = ACTIONS(4227),
    [anon_sym_POUNDElse] = ACTIONS(4227),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4225),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4225),
    [anon_sym_PLUS] = ACTIONS(4227),
    [sym_datetime_literal] = ACTIONS(4227),
    [sym_date_literal] = ACTIONS(4225),
    [sym_time_literal] = ACTIONS(4225),
    [sym_biginteger_literal] = ACTIONS(4227),
    [anon_sym_if] = ACTIONS(4225),
    [anon_sym_IF] = ACTIONS(4225),
    [anon_sym_If] = ACTIONS(4225),
    [anon_sym_else] = ACTIONS(4225),
    [anon_sym_ELSE] = ACTIONS(4225),
    [anon_sym_Else] = ACTIONS(4225),
    [anon_sym_case] = ACTIONS(4225),
    [anon_sym_CASE] = ACTIONS(4225),
    [anon_sym_Case] = ACTIONS(4225),
    [anon_sym_for] = ACTIONS(4225),
    [anon_sym_FOR] = ACTIONS(4225),
    [anon_sym_For] = ACTIONS(4225),
    [anon_sym_foreach] = ACTIONS(4225),
    [anon_sym_FOREACH] = ACTIONS(4225),
    [anon_sym_Foreach] = ACTIONS(4225),
    [anon_sym_while] = ACTIONS(4225),
    [anon_sym_WHILE] = ACTIONS(4225),
    [anon_sym_While] = ACTIONS(4225),
    [anon_sym_repeat] = ACTIONS(4225),
    [anon_sym_REPEAT] = ACTIONS(4225),
    [anon_sym_Repeat] = ACTIONS(4225),
    [anon_sym_until] = ACTIONS(4225),
    [anon_sym_UNTIL] = ACTIONS(4225),
    [anon_sym_Until] = ACTIONS(4225),
    [anon_sym_exit] = ACTIONS(4225),
    [anon_sym_EXIT] = ACTIONS(4225),
    [anon_sym_Exit] = ACTIONS(4225),
    [anon_sym_continue] = ACTIONS(4225),
    [anon_sym_CONTINUE] = ACTIONS(4225),
    [anon_sym_Continue] = ACTIONS(4225),
    [anon_sym_break] = ACTIONS(4225),
    [anon_sym_BREAK] = ACTIONS(4225),
    [anon_sym_Break] = ACTIONS(4225),
    [anon_sym_with] = ACTIONS(4225),
    [anon_sym_WITH] = ACTIONS(4225),
    [anon_sym_With] = ACTIONS(4225),
    [sym_asserterror_keyword] = ACTIONS(4227),
    [sym_page_keyword] = ACTIONS(4225),
    [anon_sym_codeunit] = ACTIONS(4225),
    [anon_sym_CODEUNIT] = ACTIONS(4225),
    [anon_sym_Codeunit] = ACTIONS(4225),
    [anon_sym_CodeUnit] = ACTIONS(4225),
    [anon_sym_COdeunit] = ACTIONS(4225),
    [anon_sym_codeUnit] = ACTIONS(4225),
    [sym_report_keyword] = ACTIONS(4225),
    [sym_query_keyword] = ACTIONS(4225),
    [anon_sym_xmlport] = ACTIONS(4225),
    [anon_sym_XMLPORT] = ACTIONS(4225),
    [anon_sym_Xmlport] = ACTIONS(4225),
    [anon_sym_XMLport] = ACTIONS(4225),
    [anon_sym_XMLPort] = ACTIONS(4225),
    [anon_sym_XmlPort] = ACTIONS(4225),
    [anon_sym_enum] = ACTIONS(4225),
    [anon_sym_ENUM] = ACTIONS(4225),
    [anon_sym_Enum] = ACTIONS(4225),
    [anon_sym_eNUM] = ACTIONS(4225),
    [anon_sym_eNum] = ACTIONS(4225),
    [anon_sym_ENum] = ACTIONS(4225),
    [sym_quoted_identifier] = ACTIONS(4227),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4227),
    [sym_integer] = ACTIONS(4225),
    [sym_continue_as_identifier] = ACTIONS(4227),
    [sym_preproc_open] = ACTIONS(4227),
  },
  [STATE(1824)] = {
    [sym_identifier] = ACTIONS(4229),
    [anon_sym_SEMI] = ACTIONS(4231),
    [anon_sym_DASH] = ACTIONS(4231),
    [aux_sym_boolean_token1] = ACTIONS(4229),
    [aux_sym_boolean_token2] = ACTIONS(4229),
    [sym_decimal] = ACTIONS(4229),
    [anon_sym_LPAREN] = ACTIONS(4231),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4229),
    [anon_sym_LBRACK] = ACTIONS(4231),
    [aux_sym_record_type_token1] = ACTIONS(4229),
    [aux_sym_basic_type_token21] = ACTIONS(4229),
    [aux_sym_basic_type_token22] = ACTIONS(4229),
    [aux_sym_basic_type_token48] = ACTIONS(4229),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4229),
    [anon_sym_POUNDif] = ACTIONS(4231),
    [anon_sym_POUNDIF] = ACTIONS(4231),
    [anon_sym_POUNDIf] = ACTIONS(4231),
    [anon_sym_not] = ACTIONS(4229),
    [anon_sym_NOT] = ACTIONS(4229),
    [anon_sym_Not] = ACTIONS(4229),
    [anon_sym_POUNDelse] = ACTIONS(4231),
    [anon_sym_POUNDELSE] = ACTIONS(4231),
    [anon_sym_POUNDElse] = ACTIONS(4231),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4229),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4229),
    [anon_sym_PLUS] = ACTIONS(4231),
    [sym_datetime_literal] = ACTIONS(4231),
    [sym_date_literal] = ACTIONS(4229),
    [sym_time_literal] = ACTIONS(4229),
    [sym_biginteger_literal] = ACTIONS(4231),
    [anon_sym_if] = ACTIONS(4229),
    [anon_sym_IF] = ACTIONS(4229),
    [anon_sym_If] = ACTIONS(4229),
    [anon_sym_else] = ACTIONS(4229),
    [anon_sym_ELSE] = ACTIONS(4229),
    [anon_sym_Else] = ACTIONS(4229),
    [anon_sym_case] = ACTIONS(4229),
    [anon_sym_CASE] = ACTIONS(4229),
    [anon_sym_Case] = ACTIONS(4229),
    [anon_sym_for] = ACTIONS(4229),
    [anon_sym_FOR] = ACTIONS(4229),
    [anon_sym_For] = ACTIONS(4229),
    [anon_sym_foreach] = ACTIONS(4229),
    [anon_sym_FOREACH] = ACTIONS(4229),
    [anon_sym_Foreach] = ACTIONS(4229),
    [anon_sym_while] = ACTIONS(4229),
    [anon_sym_WHILE] = ACTIONS(4229),
    [anon_sym_While] = ACTIONS(4229),
    [anon_sym_repeat] = ACTIONS(4229),
    [anon_sym_REPEAT] = ACTIONS(4229),
    [anon_sym_Repeat] = ACTIONS(4229),
    [anon_sym_until] = ACTIONS(4229),
    [anon_sym_UNTIL] = ACTIONS(4229),
    [anon_sym_Until] = ACTIONS(4229),
    [anon_sym_exit] = ACTIONS(4229),
    [anon_sym_EXIT] = ACTIONS(4229),
    [anon_sym_Exit] = ACTIONS(4229),
    [anon_sym_continue] = ACTIONS(4229),
    [anon_sym_CONTINUE] = ACTIONS(4229),
    [anon_sym_Continue] = ACTIONS(4229),
    [anon_sym_break] = ACTIONS(4229),
    [anon_sym_BREAK] = ACTIONS(4229),
    [anon_sym_Break] = ACTIONS(4229),
    [anon_sym_with] = ACTIONS(4229),
    [anon_sym_WITH] = ACTIONS(4229),
    [anon_sym_With] = ACTIONS(4229),
    [sym_asserterror_keyword] = ACTIONS(4231),
    [sym_page_keyword] = ACTIONS(4229),
    [anon_sym_codeunit] = ACTIONS(4229),
    [anon_sym_CODEUNIT] = ACTIONS(4229),
    [anon_sym_Codeunit] = ACTIONS(4229),
    [anon_sym_CodeUnit] = ACTIONS(4229),
    [anon_sym_COdeunit] = ACTIONS(4229),
    [anon_sym_codeUnit] = ACTIONS(4229),
    [sym_report_keyword] = ACTIONS(4229),
    [sym_query_keyword] = ACTIONS(4229),
    [anon_sym_xmlport] = ACTIONS(4229),
    [anon_sym_XMLPORT] = ACTIONS(4229),
    [anon_sym_Xmlport] = ACTIONS(4229),
    [anon_sym_XMLport] = ACTIONS(4229),
    [anon_sym_XMLPort] = ACTIONS(4229),
    [anon_sym_XmlPort] = ACTIONS(4229),
    [anon_sym_enum] = ACTIONS(4229),
    [anon_sym_ENUM] = ACTIONS(4229),
    [anon_sym_Enum] = ACTIONS(4229),
    [anon_sym_eNUM] = ACTIONS(4229),
    [anon_sym_eNum] = ACTIONS(4229),
    [anon_sym_ENum] = ACTIONS(4229),
    [sym_quoted_identifier] = ACTIONS(4231),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4231),
    [sym_integer] = ACTIONS(4229),
    [sym_continue_as_identifier] = ACTIONS(4231),
    [sym_preproc_open] = ACTIONS(4231),
  },
  [STATE(1825)] = {
    [sym_identifier] = ACTIONS(4233),
    [anon_sym_SEMI] = ACTIONS(4235),
    [anon_sym_DASH] = ACTIONS(4235),
    [aux_sym_boolean_token1] = ACTIONS(4233),
    [aux_sym_boolean_token2] = ACTIONS(4233),
    [sym_decimal] = ACTIONS(4233),
    [anon_sym_LPAREN] = ACTIONS(4235),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4233),
    [anon_sym_LBRACK] = ACTIONS(4235),
    [aux_sym_record_type_token1] = ACTIONS(4233),
    [aux_sym_basic_type_token21] = ACTIONS(4233),
    [aux_sym_basic_type_token22] = ACTIONS(4233),
    [aux_sym_basic_type_token48] = ACTIONS(4233),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4233),
    [anon_sym_POUNDif] = ACTIONS(4235),
    [anon_sym_POUNDIF] = ACTIONS(4235),
    [anon_sym_POUNDIf] = ACTIONS(4235),
    [anon_sym_not] = ACTIONS(4233),
    [anon_sym_NOT] = ACTIONS(4233),
    [anon_sym_Not] = ACTIONS(4233),
    [anon_sym_POUNDelse] = ACTIONS(4235),
    [anon_sym_POUNDELSE] = ACTIONS(4235),
    [anon_sym_POUNDElse] = ACTIONS(4235),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4233),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4233),
    [anon_sym_PLUS] = ACTIONS(4235),
    [sym_datetime_literal] = ACTIONS(4235),
    [sym_date_literal] = ACTIONS(4233),
    [sym_time_literal] = ACTIONS(4233),
    [sym_biginteger_literal] = ACTIONS(4235),
    [anon_sym_if] = ACTIONS(4233),
    [anon_sym_IF] = ACTIONS(4233),
    [anon_sym_If] = ACTIONS(4233),
    [anon_sym_else] = ACTIONS(4233),
    [anon_sym_ELSE] = ACTIONS(4233),
    [anon_sym_Else] = ACTIONS(4233),
    [anon_sym_case] = ACTIONS(4233),
    [anon_sym_CASE] = ACTIONS(4233),
    [anon_sym_Case] = ACTIONS(4233),
    [anon_sym_for] = ACTIONS(4233),
    [anon_sym_FOR] = ACTIONS(4233),
    [anon_sym_For] = ACTIONS(4233),
    [anon_sym_foreach] = ACTIONS(4233),
    [anon_sym_FOREACH] = ACTIONS(4233),
    [anon_sym_Foreach] = ACTIONS(4233),
    [anon_sym_while] = ACTIONS(4233),
    [anon_sym_WHILE] = ACTIONS(4233),
    [anon_sym_While] = ACTIONS(4233),
    [anon_sym_repeat] = ACTIONS(4233),
    [anon_sym_REPEAT] = ACTIONS(4233),
    [anon_sym_Repeat] = ACTIONS(4233),
    [anon_sym_until] = ACTIONS(4233),
    [anon_sym_UNTIL] = ACTIONS(4233),
    [anon_sym_Until] = ACTIONS(4233),
    [anon_sym_exit] = ACTIONS(4233),
    [anon_sym_EXIT] = ACTIONS(4233),
    [anon_sym_Exit] = ACTIONS(4233),
    [anon_sym_continue] = ACTIONS(4233),
    [anon_sym_CONTINUE] = ACTIONS(4233),
    [anon_sym_Continue] = ACTIONS(4233),
    [anon_sym_break] = ACTIONS(4233),
    [anon_sym_BREAK] = ACTIONS(4233),
    [anon_sym_Break] = ACTIONS(4233),
    [anon_sym_with] = ACTIONS(4233),
    [anon_sym_WITH] = ACTIONS(4233),
    [anon_sym_With] = ACTIONS(4233),
    [sym_asserterror_keyword] = ACTIONS(4235),
    [sym_page_keyword] = ACTIONS(4233),
    [anon_sym_codeunit] = ACTIONS(4233),
    [anon_sym_CODEUNIT] = ACTIONS(4233),
    [anon_sym_Codeunit] = ACTIONS(4233),
    [anon_sym_CodeUnit] = ACTIONS(4233),
    [anon_sym_COdeunit] = ACTIONS(4233),
    [anon_sym_codeUnit] = ACTIONS(4233),
    [sym_report_keyword] = ACTIONS(4233),
    [sym_query_keyword] = ACTIONS(4233),
    [anon_sym_xmlport] = ACTIONS(4233),
    [anon_sym_XMLPORT] = ACTIONS(4233),
    [anon_sym_Xmlport] = ACTIONS(4233),
    [anon_sym_XMLport] = ACTIONS(4233),
    [anon_sym_XMLPort] = ACTIONS(4233),
    [anon_sym_XmlPort] = ACTIONS(4233),
    [anon_sym_enum] = ACTIONS(4233),
    [anon_sym_ENUM] = ACTIONS(4233),
    [anon_sym_Enum] = ACTIONS(4233),
    [anon_sym_eNUM] = ACTIONS(4233),
    [anon_sym_eNum] = ACTIONS(4233),
    [anon_sym_ENum] = ACTIONS(4233),
    [sym_quoted_identifier] = ACTIONS(4235),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4235),
    [sym_integer] = ACTIONS(4233),
    [sym_continue_as_identifier] = ACTIONS(4235),
    [sym_preproc_open] = ACTIONS(4235),
  },
  [STATE(1826)] = {
    [sym_identifier] = ACTIONS(4237),
    [anon_sym_SEMI] = ACTIONS(4239),
    [anon_sym_DASH] = ACTIONS(4239),
    [aux_sym_boolean_token1] = ACTIONS(4237),
    [aux_sym_boolean_token2] = ACTIONS(4237),
    [sym_decimal] = ACTIONS(4237),
    [anon_sym_LPAREN] = ACTIONS(4239),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4237),
    [anon_sym_LBRACK] = ACTIONS(4239),
    [aux_sym_record_type_token1] = ACTIONS(4237),
    [aux_sym_basic_type_token21] = ACTIONS(4237),
    [aux_sym_basic_type_token22] = ACTIONS(4237),
    [aux_sym_basic_type_token48] = ACTIONS(4237),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4237),
    [anon_sym_POUNDif] = ACTIONS(4239),
    [anon_sym_POUNDIF] = ACTIONS(4239),
    [anon_sym_POUNDIf] = ACTIONS(4239),
    [anon_sym_not] = ACTIONS(4237),
    [anon_sym_NOT] = ACTIONS(4237),
    [anon_sym_Not] = ACTIONS(4237),
    [anon_sym_POUNDelse] = ACTIONS(4239),
    [anon_sym_POUNDELSE] = ACTIONS(4239),
    [anon_sym_POUNDElse] = ACTIONS(4239),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4237),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4237),
    [anon_sym_PLUS] = ACTIONS(4239),
    [sym_datetime_literal] = ACTIONS(4239),
    [sym_date_literal] = ACTIONS(4237),
    [sym_time_literal] = ACTIONS(4237),
    [sym_biginteger_literal] = ACTIONS(4239),
    [anon_sym_if] = ACTIONS(4237),
    [anon_sym_IF] = ACTIONS(4237),
    [anon_sym_If] = ACTIONS(4237),
    [anon_sym_else] = ACTIONS(4237),
    [anon_sym_ELSE] = ACTIONS(4237),
    [anon_sym_Else] = ACTIONS(4237),
    [anon_sym_case] = ACTIONS(4237),
    [anon_sym_CASE] = ACTIONS(4237),
    [anon_sym_Case] = ACTIONS(4237),
    [anon_sym_for] = ACTIONS(4237),
    [anon_sym_FOR] = ACTIONS(4237),
    [anon_sym_For] = ACTIONS(4237),
    [anon_sym_foreach] = ACTIONS(4237),
    [anon_sym_FOREACH] = ACTIONS(4237),
    [anon_sym_Foreach] = ACTIONS(4237),
    [anon_sym_while] = ACTIONS(4237),
    [anon_sym_WHILE] = ACTIONS(4237),
    [anon_sym_While] = ACTIONS(4237),
    [anon_sym_repeat] = ACTIONS(4237),
    [anon_sym_REPEAT] = ACTIONS(4237),
    [anon_sym_Repeat] = ACTIONS(4237),
    [anon_sym_until] = ACTIONS(4237),
    [anon_sym_UNTIL] = ACTIONS(4237),
    [anon_sym_Until] = ACTIONS(4237),
    [anon_sym_exit] = ACTIONS(4237),
    [anon_sym_EXIT] = ACTIONS(4237),
    [anon_sym_Exit] = ACTIONS(4237),
    [anon_sym_continue] = ACTIONS(4237),
    [anon_sym_CONTINUE] = ACTIONS(4237),
    [anon_sym_Continue] = ACTIONS(4237),
    [anon_sym_break] = ACTIONS(4237),
    [anon_sym_BREAK] = ACTIONS(4237),
    [anon_sym_Break] = ACTIONS(4237),
    [anon_sym_with] = ACTIONS(4237),
    [anon_sym_WITH] = ACTIONS(4237),
    [anon_sym_With] = ACTIONS(4237),
    [sym_asserterror_keyword] = ACTIONS(4239),
    [sym_page_keyword] = ACTIONS(4237),
    [anon_sym_codeunit] = ACTIONS(4237),
    [anon_sym_CODEUNIT] = ACTIONS(4237),
    [anon_sym_Codeunit] = ACTIONS(4237),
    [anon_sym_CodeUnit] = ACTIONS(4237),
    [anon_sym_COdeunit] = ACTIONS(4237),
    [anon_sym_codeUnit] = ACTIONS(4237),
    [sym_report_keyword] = ACTIONS(4237),
    [sym_query_keyword] = ACTIONS(4237),
    [anon_sym_xmlport] = ACTIONS(4237),
    [anon_sym_XMLPORT] = ACTIONS(4237),
    [anon_sym_Xmlport] = ACTIONS(4237),
    [anon_sym_XMLport] = ACTIONS(4237),
    [anon_sym_XMLPort] = ACTIONS(4237),
    [anon_sym_XmlPort] = ACTIONS(4237),
    [anon_sym_enum] = ACTIONS(4237),
    [anon_sym_ENUM] = ACTIONS(4237),
    [anon_sym_Enum] = ACTIONS(4237),
    [anon_sym_eNUM] = ACTIONS(4237),
    [anon_sym_eNum] = ACTIONS(4237),
    [anon_sym_ENum] = ACTIONS(4237),
    [sym_quoted_identifier] = ACTIONS(4239),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4239),
    [sym_integer] = ACTIONS(4237),
    [sym_continue_as_identifier] = ACTIONS(4239),
    [sym_preproc_open] = ACTIONS(4239),
  },
  [STATE(1827)] = {
    [sym_identifier] = ACTIONS(4241),
    [anon_sym_SEMI] = ACTIONS(4243),
    [anon_sym_DASH] = ACTIONS(4243),
    [aux_sym_boolean_token1] = ACTIONS(4241),
    [aux_sym_boolean_token2] = ACTIONS(4241),
    [sym_decimal] = ACTIONS(4241),
    [anon_sym_LPAREN] = ACTIONS(4243),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4241),
    [anon_sym_LBRACK] = ACTIONS(4243),
    [aux_sym_record_type_token1] = ACTIONS(4241),
    [aux_sym_basic_type_token21] = ACTIONS(4241),
    [aux_sym_basic_type_token22] = ACTIONS(4241),
    [aux_sym_basic_type_token48] = ACTIONS(4241),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4241),
    [anon_sym_POUNDif] = ACTIONS(4243),
    [anon_sym_POUNDIF] = ACTIONS(4243),
    [anon_sym_POUNDIf] = ACTIONS(4243),
    [anon_sym_not] = ACTIONS(4241),
    [anon_sym_NOT] = ACTIONS(4241),
    [anon_sym_Not] = ACTIONS(4241),
    [anon_sym_POUNDelse] = ACTIONS(4243),
    [anon_sym_POUNDELSE] = ACTIONS(4243),
    [anon_sym_POUNDElse] = ACTIONS(4243),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4241),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4241),
    [anon_sym_PLUS] = ACTIONS(4243),
    [sym_datetime_literal] = ACTIONS(4243),
    [sym_date_literal] = ACTIONS(4241),
    [sym_time_literal] = ACTIONS(4241),
    [sym_biginteger_literal] = ACTIONS(4243),
    [anon_sym_if] = ACTIONS(4241),
    [anon_sym_IF] = ACTIONS(4241),
    [anon_sym_If] = ACTIONS(4241),
    [anon_sym_else] = ACTIONS(4241),
    [anon_sym_ELSE] = ACTIONS(4241),
    [anon_sym_Else] = ACTIONS(4241),
    [anon_sym_case] = ACTIONS(4241),
    [anon_sym_CASE] = ACTIONS(4241),
    [anon_sym_Case] = ACTIONS(4241),
    [anon_sym_for] = ACTIONS(4241),
    [anon_sym_FOR] = ACTIONS(4241),
    [anon_sym_For] = ACTIONS(4241),
    [anon_sym_foreach] = ACTIONS(4241),
    [anon_sym_FOREACH] = ACTIONS(4241),
    [anon_sym_Foreach] = ACTIONS(4241),
    [anon_sym_while] = ACTIONS(4241),
    [anon_sym_WHILE] = ACTIONS(4241),
    [anon_sym_While] = ACTIONS(4241),
    [anon_sym_repeat] = ACTIONS(4241),
    [anon_sym_REPEAT] = ACTIONS(4241),
    [anon_sym_Repeat] = ACTIONS(4241),
    [anon_sym_until] = ACTIONS(4241),
    [anon_sym_UNTIL] = ACTIONS(4241),
    [anon_sym_Until] = ACTIONS(4241),
    [anon_sym_exit] = ACTIONS(4241),
    [anon_sym_EXIT] = ACTIONS(4241),
    [anon_sym_Exit] = ACTIONS(4241),
    [anon_sym_continue] = ACTIONS(4241),
    [anon_sym_CONTINUE] = ACTIONS(4241),
    [anon_sym_Continue] = ACTIONS(4241),
    [anon_sym_break] = ACTIONS(4241),
    [anon_sym_BREAK] = ACTIONS(4241),
    [anon_sym_Break] = ACTIONS(4241),
    [anon_sym_with] = ACTIONS(4241),
    [anon_sym_WITH] = ACTIONS(4241),
    [anon_sym_With] = ACTIONS(4241),
    [sym_asserterror_keyword] = ACTIONS(4243),
    [sym_page_keyword] = ACTIONS(4241),
    [anon_sym_codeunit] = ACTIONS(4241),
    [anon_sym_CODEUNIT] = ACTIONS(4241),
    [anon_sym_Codeunit] = ACTIONS(4241),
    [anon_sym_CodeUnit] = ACTIONS(4241),
    [anon_sym_COdeunit] = ACTIONS(4241),
    [anon_sym_codeUnit] = ACTIONS(4241),
    [sym_report_keyword] = ACTIONS(4241),
    [sym_query_keyword] = ACTIONS(4241),
    [anon_sym_xmlport] = ACTIONS(4241),
    [anon_sym_XMLPORT] = ACTIONS(4241),
    [anon_sym_Xmlport] = ACTIONS(4241),
    [anon_sym_XMLport] = ACTIONS(4241),
    [anon_sym_XMLPort] = ACTIONS(4241),
    [anon_sym_XmlPort] = ACTIONS(4241),
    [anon_sym_enum] = ACTIONS(4241),
    [anon_sym_ENUM] = ACTIONS(4241),
    [anon_sym_Enum] = ACTIONS(4241),
    [anon_sym_eNUM] = ACTIONS(4241),
    [anon_sym_eNum] = ACTIONS(4241),
    [anon_sym_ENum] = ACTIONS(4241),
    [sym_quoted_identifier] = ACTIONS(4243),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4243),
    [sym_integer] = ACTIONS(4241),
    [sym_continue_as_identifier] = ACTIONS(4243),
    [sym_preproc_open] = ACTIONS(4243),
  },
  [STATE(1828)] = {
    [sym_identifier] = ACTIONS(4245),
    [anon_sym_SEMI] = ACTIONS(4247),
    [anon_sym_DASH] = ACTIONS(4247),
    [aux_sym_boolean_token1] = ACTIONS(4245),
    [aux_sym_boolean_token2] = ACTIONS(4245),
    [sym_decimal] = ACTIONS(4245),
    [anon_sym_LPAREN] = ACTIONS(4247),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4245),
    [anon_sym_LBRACK] = ACTIONS(4247),
    [aux_sym_record_type_token1] = ACTIONS(4245),
    [aux_sym_basic_type_token21] = ACTIONS(4245),
    [aux_sym_basic_type_token22] = ACTIONS(4245),
    [aux_sym_basic_type_token48] = ACTIONS(4245),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4245),
    [anon_sym_POUNDif] = ACTIONS(4247),
    [anon_sym_POUNDIF] = ACTIONS(4247),
    [anon_sym_POUNDIf] = ACTIONS(4247),
    [anon_sym_not] = ACTIONS(4245),
    [anon_sym_NOT] = ACTIONS(4245),
    [anon_sym_Not] = ACTIONS(4245),
    [anon_sym_POUNDelse] = ACTIONS(4247),
    [anon_sym_POUNDELSE] = ACTIONS(4247),
    [anon_sym_POUNDElse] = ACTIONS(4247),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4245),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4245),
    [anon_sym_PLUS] = ACTIONS(4247),
    [sym_datetime_literal] = ACTIONS(4247),
    [sym_date_literal] = ACTIONS(4245),
    [sym_time_literal] = ACTIONS(4245),
    [sym_biginteger_literal] = ACTIONS(4247),
    [anon_sym_if] = ACTIONS(4245),
    [anon_sym_IF] = ACTIONS(4245),
    [anon_sym_If] = ACTIONS(4245),
    [anon_sym_else] = ACTIONS(4245),
    [anon_sym_ELSE] = ACTIONS(4245),
    [anon_sym_Else] = ACTIONS(4245),
    [anon_sym_case] = ACTIONS(4245),
    [anon_sym_CASE] = ACTIONS(4245),
    [anon_sym_Case] = ACTIONS(4245),
    [anon_sym_for] = ACTIONS(4245),
    [anon_sym_FOR] = ACTIONS(4245),
    [anon_sym_For] = ACTIONS(4245),
    [anon_sym_foreach] = ACTIONS(4245),
    [anon_sym_FOREACH] = ACTIONS(4245),
    [anon_sym_Foreach] = ACTIONS(4245),
    [anon_sym_while] = ACTIONS(4245),
    [anon_sym_WHILE] = ACTIONS(4245),
    [anon_sym_While] = ACTIONS(4245),
    [anon_sym_repeat] = ACTIONS(4245),
    [anon_sym_REPEAT] = ACTIONS(4245),
    [anon_sym_Repeat] = ACTIONS(4245),
    [anon_sym_until] = ACTIONS(4245),
    [anon_sym_UNTIL] = ACTIONS(4245),
    [anon_sym_Until] = ACTIONS(4245),
    [anon_sym_exit] = ACTIONS(4245),
    [anon_sym_EXIT] = ACTIONS(4245),
    [anon_sym_Exit] = ACTIONS(4245),
    [anon_sym_continue] = ACTIONS(4245),
    [anon_sym_CONTINUE] = ACTIONS(4245),
    [anon_sym_Continue] = ACTIONS(4245),
    [anon_sym_break] = ACTIONS(4245),
    [anon_sym_BREAK] = ACTIONS(4245),
    [anon_sym_Break] = ACTIONS(4245),
    [anon_sym_with] = ACTIONS(4245),
    [anon_sym_WITH] = ACTIONS(4245),
    [anon_sym_With] = ACTIONS(4245),
    [sym_asserterror_keyword] = ACTIONS(4247),
    [sym_page_keyword] = ACTIONS(4245),
    [anon_sym_codeunit] = ACTIONS(4245),
    [anon_sym_CODEUNIT] = ACTIONS(4245),
    [anon_sym_Codeunit] = ACTIONS(4245),
    [anon_sym_CodeUnit] = ACTIONS(4245),
    [anon_sym_COdeunit] = ACTIONS(4245),
    [anon_sym_codeUnit] = ACTIONS(4245),
    [sym_report_keyword] = ACTIONS(4245),
    [sym_query_keyword] = ACTIONS(4245),
    [anon_sym_xmlport] = ACTIONS(4245),
    [anon_sym_XMLPORT] = ACTIONS(4245),
    [anon_sym_Xmlport] = ACTIONS(4245),
    [anon_sym_XMLport] = ACTIONS(4245),
    [anon_sym_XMLPort] = ACTIONS(4245),
    [anon_sym_XmlPort] = ACTIONS(4245),
    [anon_sym_enum] = ACTIONS(4245),
    [anon_sym_ENUM] = ACTIONS(4245),
    [anon_sym_Enum] = ACTIONS(4245),
    [anon_sym_eNUM] = ACTIONS(4245),
    [anon_sym_eNum] = ACTIONS(4245),
    [anon_sym_ENum] = ACTIONS(4245),
    [sym_quoted_identifier] = ACTIONS(4247),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4247),
    [sym_integer] = ACTIONS(4245),
    [sym_continue_as_identifier] = ACTIONS(4247),
    [sym_preproc_open] = ACTIONS(4247),
  },
  [STATE(1829)] = {
    [sym_identifier] = ACTIONS(4249),
    [anon_sym_SEMI] = ACTIONS(4251),
    [anon_sym_DASH] = ACTIONS(4251),
    [aux_sym_boolean_token1] = ACTIONS(4249),
    [aux_sym_boolean_token2] = ACTIONS(4249),
    [sym_decimal] = ACTIONS(4249),
    [anon_sym_LPAREN] = ACTIONS(4251),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4249),
    [anon_sym_LBRACK] = ACTIONS(4251),
    [aux_sym_record_type_token1] = ACTIONS(4249),
    [aux_sym_basic_type_token21] = ACTIONS(4249),
    [aux_sym_basic_type_token22] = ACTIONS(4249),
    [aux_sym_basic_type_token48] = ACTIONS(4249),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4249),
    [anon_sym_POUNDif] = ACTIONS(4251),
    [anon_sym_POUNDIF] = ACTIONS(4251),
    [anon_sym_POUNDIf] = ACTIONS(4251),
    [anon_sym_not] = ACTIONS(4249),
    [anon_sym_NOT] = ACTIONS(4249),
    [anon_sym_Not] = ACTIONS(4249),
    [anon_sym_POUNDelse] = ACTIONS(4251),
    [anon_sym_POUNDELSE] = ACTIONS(4251),
    [anon_sym_POUNDElse] = ACTIONS(4251),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4249),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4249),
    [anon_sym_PLUS] = ACTIONS(4251),
    [sym_datetime_literal] = ACTIONS(4251),
    [sym_date_literal] = ACTIONS(4249),
    [sym_time_literal] = ACTIONS(4249),
    [sym_biginteger_literal] = ACTIONS(4251),
    [anon_sym_if] = ACTIONS(4249),
    [anon_sym_IF] = ACTIONS(4249),
    [anon_sym_If] = ACTIONS(4249),
    [anon_sym_else] = ACTIONS(4249),
    [anon_sym_ELSE] = ACTIONS(4249),
    [anon_sym_Else] = ACTIONS(4249),
    [anon_sym_case] = ACTIONS(4249),
    [anon_sym_CASE] = ACTIONS(4249),
    [anon_sym_Case] = ACTIONS(4249),
    [anon_sym_for] = ACTIONS(4249),
    [anon_sym_FOR] = ACTIONS(4249),
    [anon_sym_For] = ACTIONS(4249),
    [anon_sym_foreach] = ACTIONS(4249),
    [anon_sym_FOREACH] = ACTIONS(4249),
    [anon_sym_Foreach] = ACTIONS(4249),
    [anon_sym_while] = ACTIONS(4249),
    [anon_sym_WHILE] = ACTIONS(4249),
    [anon_sym_While] = ACTIONS(4249),
    [anon_sym_repeat] = ACTIONS(4249),
    [anon_sym_REPEAT] = ACTIONS(4249),
    [anon_sym_Repeat] = ACTIONS(4249),
    [anon_sym_until] = ACTIONS(4249),
    [anon_sym_UNTIL] = ACTIONS(4249),
    [anon_sym_Until] = ACTIONS(4249),
    [anon_sym_exit] = ACTIONS(4249),
    [anon_sym_EXIT] = ACTIONS(4249),
    [anon_sym_Exit] = ACTIONS(4249),
    [anon_sym_continue] = ACTIONS(4249),
    [anon_sym_CONTINUE] = ACTIONS(4249),
    [anon_sym_Continue] = ACTIONS(4249),
    [anon_sym_break] = ACTIONS(4249),
    [anon_sym_BREAK] = ACTIONS(4249),
    [anon_sym_Break] = ACTIONS(4249),
    [anon_sym_with] = ACTIONS(4249),
    [anon_sym_WITH] = ACTIONS(4249),
    [anon_sym_With] = ACTIONS(4249),
    [sym_asserterror_keyword] = ACTIONS(4251),
    [sym_page_keyword] = ACTIONS(4249),
    [anon_sym_codeunit] = ACTIONS(4249),
    [anon_sym_CODEUNIT] = ACTIONS(4249),
    [anon_sym_Codeunit] = ACTIONS(4249),
    [anon_sym_CodeUnit] = ACTIONS(4249),
    [anon_sym_COdeunit] = ACTIONS(4249),
    [anon_sym_codeUnit] = ACTIONS(4249),
    [sym_report_keyword] = ACTIONS(4249),
    [sym_query_keyword] = ACTIONS(4249),
    [anon_sym_xmlport] = ACTIONS(4249),
    [anon_sym_XMLPORT] = ACTIONS(4249),
    [anon_sym_Xmlport] = ACTIONS(4249),
    [anon_sym_XMLport] = ACTIONS(4249),
    [anon_sym_XMLPort] = ACTIONS(4249),
    [anon_sym_XmlPort] = ACTIONS(4249),
    [anon_sym_enum] = ACTIONS(4249),
    [anon_sym_ENUM] = ACTIONS(4249),
    [anon_sym_Enum] = ACTIONS(4249),
    [anon_sym_eNUM] = ACTIONS(4249),
    [anon_sym_eNum] = ACTIONS(4249),
    [anon_sym_ENum] = ACTIONS(4249),
    [sym_quoted_identifier] = ACTIONS(4251),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4251),
    [sym_integer] = ACTIONS(4249),
    [sym_continue_as_identifier] = ACTIONS(4251),
    [sym_preproc_open] = ACTIONS(4251),
  },
  [STATE(1830)] = {
    [sym_identifier] = ACTIONS(4253),
    [anon_sym_SEMI] = ACTIONS(4255),
    [anon_sym_DASH] = ACTIONS(4255),
    [aux_sym_boolean_token1] = ACTIONS(4253),
    [aux_sym_boolean_token2] = ACTIONS(4253),
    [sym_decimal] = ACTIONS(4253),
    [anon_sym_LPAREN] = ACTIONS(4255),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4253),
    [anon_sym_LBRACK] = ACTIONS(4255),
    [aux_sym_record_type_token1] = ACTIONS(4253),
    [aux_sym_basic_type_token21] = ACTIONS(4253),
    [aux_sym_basic_type_token22] = ACTIONS(4253),
    [aux_sym_basic_type_token48] = ACTIONS(4253),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4253),
    [anon_sym_POUNDif] = ACTIONS(4255),
    [anon_sym_POUNDIF] = ACTIONS(4255),
    [anon_sym_POUNDIf] = ACTIONS(4255),
    [anon_sym_not] = ACTIONS(4253),
    [anon_sym_NOT] = ACTIONS(4253),
    [anon_sym_Not] = ACTIONS(4253),
    [anon_sym_POUNDelse] = ACTIONS(4255),
    [anon_sym_POUNDELSE] = ACTIONS(4255),
    [anon_sym_POUNDElse] = ACTIONS(4255),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4253),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4253),
    [anon_sym_PLUS] = ACTIONS(4255),
    [sym_datetime_literal] = ACTIONS(4255),
    [sym_date_literal] = ACTIONS(4253),
    [sym_time_literal] = ACTIONS(4253),
    [sym_biginteger_literal] = ACTIONS(4255),
    [anon_sym_if] = ACTIONS(4253),
    [anon_sym_IF] = ACTIONS(4253),
    [anon_sym_If] = ACTIONS(4253),
    [anon_sym_else] = ACTIONS(4253),
    [anon_sym_ELSE] = ACTIONS(4253),
    [anon_sym_Else] = ACTIONS(4253),
    [anon_sym_case] = ACTIONS(4253),
    [anon_sym_CASE] = ACTIONS(4253),
    [anon_sym_Case] = ACTIONS(4253),
    [anon_sym_for] = ACTIONS(4253),
    [anon_sym_FOR] = ACTIONS(4253),
    [anon_sym_For] = ACTIONS(4253),
    [anon_sym_foreach] = ACTIONS(4253),
    [anon_sym_FOREACH] = ACTIONS(4253),
    [anon_sym_Foreach] = ACTIONS(4253),
    [anon_sym_while] = ACTIONS(4253),
    [anon_sym_WHILE] = ACTIONS(4253),
    [anon_sym_While] = ACTIONS(4253),
    [anon_sym_repeat] = ACTIONS(4253),
    [anon_sym_REPEAT] = ACTIONS(4253),
    [anon_sym_Repeat] = ACTIONS(4253),
    [anon_sym_until] = ACTIONS(4253),
    [anon_sym_UNTIL] = ACTIONS(4253),
    [anon_sym_Until] = ACTIONS(4253),
    [anon_sym_exit] = ACTIONS(4253),
    [anon_sym_EXIT] = ACTIONS(4253),
    [anon_sym_Exit] = ACTIONS(4253),
    [anon_sym_continue] = ACTIONS(4253),
    [anon_sym_CONTINUE] = ACTIONS(4253),
    [anon_sym_Continue] = ACTIONS(4253),
    [anon_sym_break] = ACTIONS(4253),
    [anon_sym_BREAK] = ACTIONS(4253),
    [anon_sym_Break] = ACTIONS(4253),
    [anon_sym_with] = ACTIONS(4253),
    [anon_sym_WITH] = ACTIONS(4253),
    [anon_sym_With] = ACTIONS(4253),
    [sym_asserterror_keyword] = ACTIONS(4255),
    [sym_page_keyword] = ACTIONS(4253),
    [anon_sym_codeunit] = ACTIONS(4253),
    [anon_sym_CODEUNIT] = ACTIONS(4253),
    [anon_sym_Codeunit] = ACTIONS(4253),
    [anon_sym_CodeUnit] = ACTIONS(4253),
    [anon_sym_COdeunit] = ACTIONS(4253),
    [anon_sym_codeUnit] = ACTIONS(4253),
    [sym_report_keyword] = ACTIONS(4253),
    [sym_query_keyword] = ACTIONS(4253),
    [anon_sym_xmlport] = ACTIONS(4253),
    [anon_sym_XMLPORT] = ACTIONS(4253),
    [anon_sym_Xmlport] = ACTIONS(4253),
    [anon_sym_XMLport] = ACTIONS(4253),
    [anon_sym_XMLPort] = ACTIONS(4253),
    [anon_sym_XmlPort] = ACTIONS(4253),
    [anon_sym_enum] = ACTIONS(4253),
    [anon_sym_ENUM] = ACTIONS(4253),
    [anon_sym_Enum] = ACTIONS(4253),
    [anon_sym_eNUM] = ACTIONS(4253),
    [anon_sym_eNum] = ACTIONS(4253),
    [anon_sym_ENum] = ACTIONS(4253),
    [sym_quoted_identifier] = ACTIONS(4255),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4255),
    [sym_integer] = ACTIONS(4253),
    [sym_continue_as_identifier] = ACTIONS(4255),
    [sym_preproc_open] = ACTIONS(4255),
  },
  [STATE(1831)] = {
    [sym_identifier] = ACTIONS(4257),
    [anon_sym_SEMI] = ACTIONS(4259),
    [anon_sym_DASH] = ACTIONS(4259),
    [aux_sym_boolean_token1] = ACTIONS(4257),
    [aux_sym_boolean_token2] = ACTIONS(4257),
    [sym_decimal] = ACTIONS(4257),
    [anon_sym_LPAREN] = ACTIONS(4259),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4257),
    [anon_sym_LBRACK] = ACTIONS(4259),
    [aux_sym_record_type_token1] = ACTIONS(4257),
    [aux_sym_basic_type_token21] = ACTIONS(4257),
    [aux_sym_basic_type_token22] = ACTIONS(4257),
    [aux_sym_basic_type_token48] = ACTIONS(4257),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4257),
    [anon_sym_POUNDif] = ACTIONS(4259),
    [anon_sym_POUNDIF] = ACTIONS(4259),
    [anon_sym_POUNDIf] = ACTIONS(4259),
    [anon_sym_not] = ACTIONS(4257),
    [anon_sym_NOT] = ACTIONS(4257),
    [anon_sym_Not] = ACTIONS(4257),
    [anon_sym_POUNDelse] = ACTIONS(4259),
    [anon_sym_POUNDELSE] = ACTIONS(4259),
    [anon_sym_POUNDElse] = ACTIONS(4259),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4257),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4257),
    [anon_sym_PLUS] = ACTIONS(4259),
    [sym_datetime_literal] = ACTIONS(4259),
    [sym_date_literal] = ACTIONS(4257),
    [sym_time_literal] = ACTIONS(4257),
    [sym_biginteger_literal] = ACTIONS(4259),
    [anon_sym_if] = ACTIONS(4257),
    [anon_sym_IF] = ACTIONS(4257),
    [anon_sym_If] = ACTIONS(4257),
    [anon_sym_else] = ACTIONS(4257),
    [anon_sym_ELSE] = ACTIONS(4257),
    [anon_sym_Else] = ACTIONS(4257),
    [anon_sym_case] = ACTIONS(4257),
    [anon_sym_CASE] = ACTIONS(4257),
    [anon_sym_Case] = ACTIONS(4257),
    [anon_sym_for] = ACTIONS(4257),
    [anon_sym_FOR] = ACTIONS(4257),
    [anon_sym_For] = ACTIONS(4257),
    [anon_sym_foreach] = ACTIONS(4257),
    [anon_sym_FOREACH] = ACTIONS(4257),
    [anon_sym_Foreach] = ACTIONS(4257),
    [anon_sym_while] = ACTIONS(4257),
    [anon_sym_WHILE] = ACTIONS(4257),
    [anon_sym_While] = ACTIONS(4257),
    [anon_sym_repeat] = ACTIONS(4257),
    [anon_sym_REPEAT] = ACTIONS(4257),
    [anon_sym_Repeat] = ACTIONS(4257),
    [anon_sym_until] = ACTIONS(4257),
    [anon_sym_UNTIL] = ACTIONS(4257),
    [anon_sym_Until] = ACTIONS(4257),
    [anon_sym_exit] = ACTIONS(4257),
    [anon_sym_EXIT] = ACTIONS(4257),
    [anon_sym_Exit] = ACTIONS(4257),
    [anon_sym_continue] = ACTIONS(4257),
    [anon_sym_CONTINUE] = ACTIONS(4257),
    [anon_sym_Continue] = ACTIONS(4257),
    [anon_sym_break] = ACTIONS(4257),
    [anon_sym_BREAK] = ACTIONS(4257),
    [anon_sym_Break] = ACTIONS(4257),
    [anon_sym_with] = ACTIONS(4257),
    [anon_sym_WITH] = ACTIONS(4257),
    [anon_sym_With] = ACTIONS(4257),
    [sym_asserterror_keyword] = ACTIONS(4259),
    [sym_page_keyword] = ACTIONS(4257),
    [anon_sym_codeunit] = ACTIONS(4257),
    [anon_sym_CODEUNIT] = ACTIONS(4257),
    [anon_sym_Codeunit] = ACTIONS(4257),
    [anon_sym_CodeUnit] = ACTIONS(4257),
    [anon_sym_COdeunit] = ACTIONS(4257),
    [anon_sym_codeUnit] = ACTIONS(4257),
    [sym_report_keyword] = ACTIONS(4257),
    [sym_query_keyword] = ACTIONS(4257),
    [anon_sym_xmlport] = ACTIONS(4257),
    [anon_sym_XMLPORT] = ACTIONS(4257),
    [anon_sym_Xmlport] = ACTIONS(4257),
    [anon_sym_XMLport] = ACTIONS(4257),
    [anon_sym_XMLPort] = ACTIONS(4257),
    [anon_sym_XmlPort] = ACTIONS(4257),
    [anon_sym_enum] = ACTIONS(4257),
    [anon_sym_ENUM] = ACTIONS(4257),
    [anon_sym_Enum] = ACTIONS(4257),
    [anon_sym_eNUM] = ACTIONS(4257),
    [anon_sym_eNum] = ACTIONS(4257),
    [anon_sym_ENum] = ACTIONS(4257),
    [sym_quoted_identifier] = ACTIONS(4259),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4259),
    [sym_integer] = ACTIONS(4257),
    [sym_continue_as_identifier] = ACTIONS(4259),
    [sym_preproc_open] = ACTIONS(4259),
  },
  [STATE(1832)] = {
    [sym_identifier] = ACTIONS(4261),
    [anon_sym_SEMI] = ACTIONS(4263),
    [anon_sym_DASH] = ACTIONS(4263),
    [aux_sym_boolean_token1] = ACTIONS(4261),
    [aux_sym_boolean_token2] = ACTIONS(4261),
    [sym_decimal] = ACTIONS(4261),
    [anon_sym_LPAREN] = ACTIONS(4263),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4261),
    [anon_sym_LBRACK] = ACTIONS(4263),
    [aux_sym_record_type_token1] = ACTIONS(4261),
    [aux_sym_basic_type_token21] = ACTIONS(4261),
    [aux_sym_basic_type_token22] = ACTIONS(4261),
    [aux_sym_basic_type_token48] = ACTIONS(4261),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4261),
    [anon_sym_POUNDif] = ACTIONS(4263),
    [anon_sym_POUNDIF] = ACTIONS(4263),
    [anon_sym_POUNDIf] = ACTIONS(4263),
    [anon_sym_not] = ACTIONS(4261),
    [anon_sym_NOT] = ACTIONS(4261),
    [anon_sym_Not] = ACTIONS(4261),
    [anon_sym_POUNDelse] = ACTIONS(4263),
    [anon_sym_POUNDELSE] = ACTIONS(4263),
    [anon_sym_POUNDElse] = ACTIONS(4263),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4261),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4261),
    [anon_sym_PLUS] = ACTIONS(4263),
    [sym_datetime_literal] = ACTIONS(4263),
    [sym_date_literal] = ACTIONS(4261),
    [sym_time_literal] = ACTIONS(4261),
    [sym_biginteger_literal] = ACTIONS(4263),
    [anon_sym_if] = ACTIONS(4261),
    [anon_sym_IF] = ACTIONS(4261),
    [anon_sym_If] = ACTIONS(4261),
    [anon_sym_else] = ACTIONS(4261),
    [anon_sym_ELSE] = ACTIONS(4261),
    [anon_sym_Else] = ACTIONS(4261),
    [anon_sym_case] = ACTIONS(4261),
    [anon_sym_CASE] = ACTIONS(4261),
    [anon_sym_Case] = ACTIONS(4261),
    [anon_sym_for] = ACTIONS(4261),
    [anon_sym_FOR] = ACTIONS(4261),
    [anon_sym_For] = ACTIONS(4261),
    [anon_sym_foreach] = ACTIONS(4261),
    [anon_sym_FOREACH] = ACTIONS(4261),
    [anon_sym_Foreach] = ACTIONS(4261),
    [anon_sym_while] = ACTIONS(4261),
    [anon_sym_WHILE] = ACTIONS(4261),
    [anon_sym_While] = ACTIONS(4261),
    [anon_sym_repeat] = ACTIONS(4261),
    [anon_sym_REPEAT] = ACTIONS(4261),
    [anon_sym_Repeat] = ACTIONS(4261),
    [anon_sym_until] = ACTIONS(4261),
    [anon_sym_UNTIL] = ACTIONS(4261),
    [anon_sym_Until] = ACTIONS(4261),
    [anon_sym_exit] = ACTIONS(4261),
    [anon_sym_EXIT] = ACTIONS(4261),
    [anon_sym_Exit] = ACTIONS(4261),
    [anon_sym_continue] = ACTIONS(4261),
    [anon_sym_CONTINUE] = ACTIONS(4261),
    [anon_sym_Continue] = ACTIONS(4261),
    [anon_sym_break] = ACTIONS(4261),
    [anon_sym_BREAK] = ACTIONS(4261),
    [anon_sym_Break] = ACTIONS(4261),
    [anon_sym_with] = ACTIONS(4261),
    [anon_sym_WITH] = ACTIONS(4261),
    [anon_sym_With] = ACTIONS(4261),
    [sym_asserterror_keyword] = ACTIONS(4263),
    [sym_page_keyword] = ACTIONS(4261),
    [anon_sym_codeunit] = ACTIONS(4261),
    [anon_sym_CODEUNIT] = ACTIONS(4261),
    [anon_sym_Codeunit] = ACTIONS(4261),
    [anon_sym_CodeUnit] = ACTIONS(4261),
    [anon_sym_COdeunit] = ACTIONS(4261),
    [anon_sym_codeUnit] = ACTIONS(4261),
    [sym_report_keyword] = ACTIONS(4261),
    [sym_query_keyword] = ACTIONS(4261),
    [anon_sym_xmlport] = ACTIONS(4261),
    [anon_sym_XMLPORT] = ACTIONS(4261),
    [anon_sym_Xmlport] = ACTIONS(4261),
    [anon_sym_XMLport] = ACTIONS(4261),
    [anon_sym_XMLPort] = ACTIONS(4261),
    [anon_sym_XmlPort] = ACTIONS(4261),
    [anon_sym_enum] = ACTIONS(4261),
    [anon_sym_ENUM] = ACTIONS(4261),
    [anon_sym_Enum] = ACTIONS(4261),
    [anon_sym_eNUM] = ACTIONS(4261),
    [anon_sym_eNum] = ACTIONS(4261),
    [anon_sym_ENum] = ACTIONS(4261),
    [sym_quoted_identifier] = ACTIONS(4263),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4263),
    [sym_integer] = ACTIONS(4261),
    [sym_continue_as_identifier] = ACTIONS(4263),
    [sym_preproc_open] = ACTIONS(4263),
  },
  [STATE(1833)] = {
    [sym_identifier] = ACTIONS(4265),
    [anon_sym_SEMI] = ACTIONS(4267),
    [anon_sym_DASH] = ACTIONS(4267),
    [aux_sym_boolean_token1] = ACTIONS(4265),
    [aux_sym_boolean_token2] = ACTIONS(4265),
    [sym_decimal] = ACTIONS(4265),
    [anon_sym_LPAREN] = ACTIONS(4267),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4265),
    [anon_sym_LBRACK] = ACTIONS(4267),
    [aux_sym_record_type_token1] = ACTIONS(4265),
    [aux_sym_basic_type_token21] = ACTIONS(4265),
    [aux_sym_basic_type_token22] = ACTIONS(4265),
    [aux_sym_basic_type_token48] = ACTIONS(4265),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4265),
    [anon_sym_POUNDif] = ACTIONS(4267),
    [anon_sym_POUNDIF] = ACTIONS(4267),
    [anon_sym_POUNDIf] = ACTIONS(4267),
    [anon_sym_not] = ACTIONS(4265),
    [anon_sym_NOT] = ACTIONS(4265),
    [anon_sym_Not] = ACTIONS(4265),
    [anon_sym_POUNDelse] = ACTIONS(4267),
    [anon_sym_POUNDELSE] = ACTIONS(4267),
    [anon_sym_POUNDElse] = ACTIONS(4267),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4265),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4265),
    [anon_sym_PLUS] = ACTIONS(4267),
    [sym_datetime_literal] = ACTIONS(4267),
    [sym_date_literal] = ACTIONS(4265),
    [sym_time_literal] = ACTIONS(4265),
    [sym_biginteger_literal] = ACTIONS(4267),
    [anon_sym_if] = ACTIONS(4265),
    [anon_sym_IF] = ACTIONS(4265),
    [anon_sym_If] = ACTIONS(4265),
    [anon_sym_else] = ACTIONS(4265),
    [anon_sym_ELSE] = ACTIONS(4265),
    [anon_sym_Else] = ACTIONS(4265),
    [anon_sym_case] = ACTIONS(4265),
    [anon_sym_CASE] = ACTIONS(4265),
    [anon_sym_Case] = ACTIONS(4265),
    [anon_sym_for] = ACTIONS(4265),
    [anon_sym_FOR] = ACTIONS(4265),
    [anon_sym_For] = ACTIONS(4265),
    [anon_sym_foreach] = ACTIONS(4265),
    [anon_sym_FOREACH] = ACTIONS(4265),
    [anon_sym_Foreach] = ACTIONS(4265),
    [anon_sym_while] = ACTIONS(4265),
    [anon_sym_WHILE] = ACTIONS(4265),
    [anon_sym_While] = ACTIONS(4265),
    [anon_sym_repeat] = ACTIONS(4265),
    [anon_sym_REPEAT] = ACTIONS(4265),
    [anon_sym_Repeat] = ACTIONS(4265),
    [anon_sym_until] = ACTIONS(4265),
    [anon_sym_UNTIL] = ACTIONS(4265),
    [anon_sym_Until] = ACTIONS(4265),
    [anon_sym_exit] = ACTIONS(4265),
    [anon_sym_EXIT] = ACTIONS(4265),
    [anon_sym_Exit] = ACTIONS(4265),
    [anon_sym_continue] = ACTIONS(4265),
    [anon_sym_CONTINUE] = ACTIONS(4265),
    [anon_sym_Continue] = ACTIONS(4265),
    [anon_sym_break] = ACTIONS(4265),
    [anon_sym_BREAK] = ACTIONS(4265),
    [anon_sym_Break] = ACTIONS(4265),
    [anon_sym_with] = ACTIONS(4265),
    [anon_sym_WITH] = ACTIONS(4265),
    [anon_sym_With] = ACTIONS(4265),
    [sym_asserterror_keyword] = ACTIONS(4267),
    [sym_page_keyword] = ACTIONS(4265),
    [anon_sym_codeunit] = ACTIONS(4265),
    [anon_sym_CODEUNIT] = ACTIONS(4265),
    [anon_sym_Codeunit] = ACTIONS(4265),
    [anon_sym_CodeUnit] = ACTIONS(4265),
    [anon_sym_COdeunit] = ACTIONS(4265),
    [anon_sym_codeUnit] = ACTIONS(4265),
    [sym_report_keyword] = ACTIONS(4265),
    [sym_query_keyword] = ACTIONS(4265),
    [anon_sym_xmlport] = ACTIONS(4265),
    [anon_sym_XMLPORT] = ACTIONS(4265),
    [anon_sym_Xmlport] = ACTIONS(4265),
    [anon_sym_XMLport] = ACTIONS(4265),
    [anon_sym_XMLPort] = ACTIONS(4265),
    [anon_sym_XmlPort] = ACTIONS(4265),
    [anon_sym_enum] = ACTIONS(4265),
    [anon_sym_ENUM] = ACTIONS(4265),
    [anon_sym_Enum] = ACTIONS(4265),
    [anon_sym_eNUM] = ACTIONS(4265),
    [anon_sym_eNum] = ACTIONS(4265),
    [anon_sym_ENum] = ACTIONS(4265),
    [sym_quoted_identifier] = ACTIONS(4267),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4267),
    [sym_integer] = ACTIONS(4265),
    [sym_continue_as_identifier] = ACTIONS(4267),
    [sym_preproc_open] = ACTIONS(4267),
  },
  [STATE(1834)] = {
    [sym_identifier] = ACTIONS(4269),
    [anon_sym_SEMI] = ACTIONS(4271),
    [anon_sym_DASH] = ACTIONS(4271),
    [aux_sym_boolean_token1] = ACTIONS(4269),
    [aux_sym_boolean_token2] = ACTIONS(4269),
    [sym_decimal] = ACTIONS(4269),
    [anon_sym_LPAREN] = ACTIONS(4271),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4269),
    [anon_sym_LBRACK] = ACTIONS(4271),
    [aux_sym_record_type_token1] = ACTIONS(4269),
    [aux_sym_basic_type_token21] = ACTIONS(4269),
    [aux_sym_basic_type_token22] = ACTIONS(4269),
    [aux_sym_basic_type_token48] = ACTIONS(4269),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4269),
    [anon_sym_POUNDif] = ACTIONS(4271),
    [anon_sym_POUNDIF] = ACTIONS(4271),
    [anon_sym_POUNDIf] = ACTIONS(4271),
    [anon_sym_not] = ACTIONS(4269),
    [anon_sym_NOT] = ACTIONS(4269),
    [anon_sym_Not] = ACTIONS(4269),
    [anon_sym_POUNDelse] = ACTIONS(4271),
    [anon_sym_POUNDELSE] = ACTIONS(4271),
    [anon_sym_POUNDElse] = ACTIONS(4271),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4269),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4269),
    [anon_sym_PLUS] = ACTIONS(4271),
    [sym_datetime_literal] = ACTIONS(4271),
    [sym_date_literal] = ACTIONS(4269),
    [sym_time_literal] = ACTIONS(4269),
    [sym_biginteger_literal] = ACTIONS(4271),
    [anon_sym_if] = ACTIONS(4269),
    [anon_sym_IF] = ACTIONS(4269),
    [anon_sym_If] = ACTIONS(4269),
    [anon_sym_else] = ACTIONS(4269),
    [anon_sym_ELSE] = ACTIONS(4269),
    [anon_sym_Else] = ACTIONS(4269),
    [anon_sym_case] = ACTIONS(4269),
    [anon_sym_CASE] = ACTIONS(4269),
    [anon_sym_Case] = ACTIONS(4269),
    [anon_sym_for] = ACTIONS(4269),
    [anon_sym_FOR] = ACTIONS(4269),
    [anon_sym_For] = ACTIONS(4269),
    [anon_sym_foreach] = ACTIONS(4269),
    [anon_sym_FOREACH] = ACTIONS(4269),
    [anon_sym_Foreach] = ACTIONS(4269),
    [anon_sym_while] = ACTIONS(4269),
    [anon_sym_WHILE] = ACTIONS(4269),
    [anon_sym_While] = ACTIONS(4269),
    [anon_sym_repeat] = ACTIONS(4269),
    [anon_sym_REPEAT] = ACTIONS(4269),
    [anon_sym_Repeat] = ACTIONS(4269),
    [anon_sym_until] = ACTIONS(4269),
    [anon_sym_UNTIL] = ACTIONS(4269),
    [anon_sym_Until] = ACTIONS(4269),
    [anon_sym_exit] = ACTIONS(4269),
    [anon_sym_EXIT] = ACTIONS(4269),
    [anon_sym_Exit] = ACTIONS(4269),
    [anon_sym_continue] = ACTIONS(4269),
    [anon_sym_CONTINUE] = ACTIONS(4269),
    [anon_sym_Continue] = ACTIONS(4269),
    [anon_sym_break] = ACTIONS(4269),
    [anon_sym_BREAK] = ACTIONS(4269),
    [anon_sym_Break] = ACTIONS(4269),
    [anon_sym_with] = ACTIONS(4269),
    [anon_sym_WITH] = ACTIONS(4269),
    [anon_sym_With] = ACTIONS(4269),
    [sym_asserterror_keyword] = ACTIONS(4271),
    [sym_page_keyword] = ACTIONS(4269),
    [anon_sym_codeunit] = ACTIONS(4269),
    [anon_sym_CODEUNIT] = ACTIONS(4269),
    [anon_sym_Codeunit] = ACTIONS(4269),
    [anon_sym_CodeUnit] = ACTIONS(4269),
    [anon_sym_COdeunit] = ACTIONS(4269),
    [anon_sym_codeUnit] = ACTIONS(4269),
    [sym_report_keyword] = ACTIONS(4269),
    [sym_query_keyword] = ACTIONS(4269),
    [anon_sym_xmlport] = ACTIONS(4269),
    [anon_sym_XMLPORT] = ACTIONS(4269),
    [anon_sym_Xmlport] = ACTIONS(4269),
    [anon_sym_XMLport] = ACTIONS(4269),
    [anon_sym_XMLPort] = ACTIONS(4269),
    [anon_sym_XmlPort] = ACTIONS(4269),
    [anon_sym_enum] = ACTIONS(4269),
    [anon_sym_ENUM] = ACTIONS(4269),
    [anon_sym_Enum] = ACTIONS(4269),
    [anon_sym_eNUM] = ACTIONS(4269),
    [anon_sym_eNum] = ACTIONS(4269),
    [anon_sym_ENum] = ACTIONS(4269),
    [sym_quoted_identifier] = ACTIONS(4271),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4271),
    [sym_integer] = ACTIONS(4269),
    [sym_continue_as_identifier] = ACTIONS(4271),
    [sym_preproc_open] = ACTIONS(4271),
  },
  [STATE(1835)] = {
    [sym_identifier] = ACTIONS(4273),
    [anon_sym_SEMI] = ACTIONS(4275),
    [anon_sym_DASH] = ACTIONS(4275),
    [aux_sym_boolean_token1] = ACTIONS(4273),
    [aux_sym_boolean_token2] = ACTIONS(4273),
    [sym_decimal] = ACTIONS(4273),
    [anon_sym_LPAREN] = ACTIONS(4275),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4273),
    [anon_sym_LBRACK] = ACTIONS(4275),
    [aux_sym_record_type_token1] = ACTIONS(4273),
    [aux_sym_basic_type_token21] = ACTIONS(4273),
    [aux_sym_basic_type_token22] = ACTIONS(4273),
    [aux_sym_basic_type_token48] = ACTIONS(4273),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4273),
    [anon_sym_POUNDif] = ACTIONS(4275),
    [anon_sym_POUNDIF] = ACTIONS(4275),
    [anon_sym_POUNDIf] = ACTIONS(4275),
    [anon_sym_not] = ACTIONS(4273),
    [anon_sym_NOT] = ACTIONS(4273),
    [anon_sym_Not] = ACTIONS(4273),
    [anon_sym_POUNDelse] = ACTIONS(4275),
    [anon_sym_POUNDELSE] = ACTIONS(4275),
    [anon_sym_POUNDElse] = ACTIONS(4275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4273),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4273),
    [anon_sym_PLUS] = ACTIONS(4275),
    [sym_datetime_literal] = ACTIONS(4275),
    [sym_date_literal] = ACTIONS(4273),
    [sym_time_literal] = ACTIONS(4273),
    [sym_biginteger_literal] = ACTIONS(4275),
    [anon_sym_if] = ACTIONS(4273),
    [anon_sym_IF] = ACTIONS(4273),
    [anon_sym_If] = ACTIONS(4273),
    [anon_sym_else] = ACTIONS(4273),
    [anon_sym_ELSE] = ACTIONS(4273),
    [anon_sym_Else] = ACTIONS(4273),
    [anon_sym_case] = ACTIONS(4273),
    [anon_sym_CASE] = ACTIONS(4273),
    [anon_sym_Case] = ACTIONS(4273),
    [anon_sym_for] = ACTIONS(4273),
    [anon_sym_FOR] = ACTIONS(4273),
    [anon_sym_For] = ACTIONS(4273),
    [anon_sym_foreach] = ACTIONS(4273),
    [anon_sym_FOREACH] = ACTIONS(4273),
    [anon_sym_Foreach] = ACTIONS(4273),
    [anon_sym_while] = ACTIONS(4273),
    [anon_sym_WHILE] = ACTIONS(4273),
    [anon_sym_While] = ACTIONS(4273),
    [anon_sym_repeat] = ACTIONS(4273),
    [anon_sym_REPEAT] = ACTIONS(4273),
    [anon_sym_Repeat] = ACTIONS(4273),
    [anon_sym_until] = ACTIONS(4273),
    [anon_sym_UNTIL] = ACTIONS(4273),
    [anon_sym_Until] = ACTIONS(4273),
    [anon_sym_exit] = ACTIONS(4273),
    [anon_sym_EXIT] = ACTIONS(4273),
    [anon_sym_Exit] = ACTIONS(4273),
    [anon_sym_continue] = ACTIONS(4273),
    [anon_sym_CONTINUE] = ACTIONS(4273),
    [anon_sym_Continue] = ACTIONS(4273),
    [anon_sym_break] = ACTIONS(4273),
    [anon_sym_BREAK] = ACTIONS(4273),
    [anon_sym_Break] = ACTIONS(4273),
    [anon_sym_with] = ACTIONS(4273),
    [anon_sym_WITH] = ACTIONS(4273),
    [anon_sym_With] = ACTIONS(4273),
    [sym_asserterror_keyword] = ACTIONS(4275),
    [sym_page_keyword] = ACTIONS(4273),
    [anon_sym_codeunit] = ACTIONS(4273),
    [anon_sym_CODEUNIT] = ACTIONS(4273),
    [anon_sym_Codeunit] = ACTIONS(4273),
    [anon_sym_CodeUnit] = ACTIONS(4273),
    [anon_sym_COdeunit] = ACTIONS(4273),
    [anon_sym_codeUnit] = ACTIONS(4273),
    [sym_report_keyword] = ACTIONS(4273),
    [sym_query_keyword] = ACTIONS(4273),
    [anon_sym_xmlport] = ACTIONS(4273),
    [anon_sym_XMLPORT] = ACTIONS(4273),
    [anon_sym_Xmlport] = ACTIONS(4273),
    [anon_sym_XMLport] = ACTIONS(4273),
    [anon_sym_XMLPort] = ACTIONS(4273),
    [anon_sym_XmlPort] = ACTIONS(4273),
    [anon_sym_enum] = ACTIONS(4273),
    [anon_sym_ENUM] = ACTIONS(4273),
    [anon_sym_Enum] = ACTIONS(4273),
    [anon_sym_eNUM] = ACTIONS(4273),
    [anon_sym_eNum] = ACTIONS(4273),
    [anon_sym_ENum] = ACTIONS(4273),
    [sym_quoted_identifier] = ACTIONS(4275),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4275),
    [sym_integer] = ACTIONS(4273),
    [sym_continue_as_identifier] = ACTIONS(4275),
    [sym_preproc_open] = ACTIONS(4275),
  },
  [STATE(1836)] = {
    [sym_identifier] = ACTIONS(4277),
    [anon_sym_SEMI] = ACTIONS(4279),
    [anon_sym_DASH] = ACTIONS(4279),
    [aux_sym_boolean_token1] = ACTIONS(4277),
    [aux_sym_boolean_token2] = ACTIONS(4277),
    [sym_decimal] = ACTIONS(4277),
    [anon_sym_LPAREN] = ACTIONS(4279),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4277),
    [anon_sym_LBRACK] = ACTIONS(4279),
    [aux_sym_record_type_token1] = ACTIONS(4277),
    [aux_sym_basic_type_token21] = ACTIONS(4277),
    [aux_sym_basic_type_token22] = ACTIONS(4277),
    [aux_sym_basic_type_token48] = ACTIONS(4277),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4277),
    [anon_sym_POUNDif] = ACTIONS(4279),
    [anon_sym_POUNDIF] = ACTIONS(4279),
    [anon_sym_POUNDIf] = ACTIONS(4279),
    [anon_sym_not] = ACTIONS(4277),
    [anon_sym_NOT] = ACTIONS(4277),
    [anon_sym_Not] = ACTIONS(4277),
    [anon_sym_POUNDelse] = ACTIONS(4279),
    [anon_sym_POUNDELSE] = ACTIONS(4279),
    [anon_sym_POUNDElse] = ACTIONS(4279),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4277),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4277),
    [anon_sym_PLUS] = ACTIONS(4279),
    [sym_datetime_literal] = ACTIONS(4279),
    [sym_date_literal] = ACTIONS(4277),
    [sym_time_literal] = ACTIONS(4277),
    [sym_biginteger_literal] = ACTIONS(4279),
    [anon_sym_if] = ACTIONS(4277),
    [anon_sym_IF] = ACTIONS(4277),
    [anon_sym_If] = ACTIONS(4277),
    [anon_sym_else] = ACTIONS(4277),
    [anon_sym_ELSE] = ACTIONS(4277),
    [anon_sym_Else] = ACTIONS(4277),
    [anon_sym_case] = ACTIONS(4277),
    [anon_sym_CASE] = ACTIONS(4277),
    [anon_sym_Case] = ACTIONS(4277),
    [anon_sym_for] = ACTIONS(4277),
    [anon_sym_FOR] = ACTIONS(4277),
    [anon_sym_For] = ACTIONS(4277),
    [anon_sym_foreach] = ACTIONS(4277),
    [anon_sym_FOREACH] = ACTIONS(4277),
    [anon_sym_Foreach] = ACTIONS(4277),
    [anon_sym_while] = ACTIONS(4277),
    [anon_sym_WHILE] = ACTIONS(4277),
    [anon_sym_While] = ACTIONS(4277),
    [anon_sym_repeat] = ACTIONS(4277),
    [anon_sym_REPEAT] = ACTIONS(4277),
    [anon_sym_Repeat] = ACTIONS(4277),
    [anon_sym_until] = ACTIONS(4277),
    [anon_sym_UNTIL] = ACTIONS(4277),
    [anon_sym_Until] = ACTIONS(4277),
    [anon_sym_exit] = ACTIONS(4277),
    [anon_sym_EXIT] = ACTIONS(4277),
    [anon_sym_Exit] = ACTIONS(4277),
    [anon_sym_continue] = ACTIONS(4277),
    [anon_sym_CONTINUE] = ACTIONS(4277),
    [anon_sym_Continue] = ACTIONS(4277),
    [anon_sym_break] = ACTIONS(4277),
    [anon_sym_BREAK] = ACTIONS(4277),
    [anon_sym_Break] = ACTIONS(4277),
    [anon_sym_with] = ACTIONS(4277),
    [anon_sym_WITH] = ACTIONS(4277),
    [anon_sym_With] = ACTIONS(4277),
    [sym_asserterror_keyword] = ACTIONS(4279),
    [sym_page_keyword] = ACTIONS(4277),
    [anon_sym_codeunit] = ACTIONS(4277),
    [anon_sym_CODEUNIT] = ACTIONS(4277),
    [anon_sym_Codeunit] = ACTIONS(4277),
    [anon_sym_CodeUnit] = ACTIONS(4277),
    [anon_sym_COdeunit] = ACTIONS(4277),
    [anon_sym_codeUnit] = ACTIONS(4277),
    [sym_report_keyword] = ACTIONS(4277),
    [sym_query_keyword] = ACTIONS(4277),
    [anon_sym_xmlport] = ACTIONS(4277),
    [anon_sym_XMLPORT] = ACTIONS(4277),
    [anon_sym_Xmlport] = ACTIONS(4277),
    [anon_sym_XMLport] = ACTIONS(4277),
    [anon_sym_XMLPort] = ACTIONS(4277),
    [anon_sym_XmlPort] = ACTIONS(4277),
    [anon_sym_enum] = ACTIONS(4277),
    [anon_sym_ENUM] = ACTIONS(4277),
    [anon_sym_Enum] = ACTIONS(4277),
    [anon_sym_eNUM] = ACTIONS(4277),
    [anon_sym_eNum] = ACTIONS(4277),
    [anon_sym_ENum] = ACTIONS(4277),
    [sym_quoted_identifier] = ACTIONS(4279),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4279),
    [sym_integer] = ACTIONS(4277),
    [sym_continue_as_identifier] = ACTIONS(4279),
    [sym_preproc_open] = ACTIONS(4279),
  },
  [STATE(1837)] = {
    [sym_identifier] = ACTIONS(4281),
    [anon_sym_SEMI] = ACTIONS(4283),
    [anon_sym_DASH] = ACTIONS(4283),
    [aux_sym_boolean_token1] = ACTIONS(4281),
    [aux_sym_boolean_token2] = ACTIONS(4281),
    [sym_decimal] = ACTIONS(4281),
    [anon_sym_LPAREN] = ACTIONS(4283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4281),
    [anon_sym_LBRACK] = ACTIONS(4283),
    [aux_sym_record_type_token1] = ACTIONS(4281),
    [aux_sym_basic_type_token21] = ACTIONS(4281),
    [aux_sym_basic_type_token22] = ACTIONS(4281),
    [aux_sym_basic_type_token48] = ACTIONS(4281),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4281),
    [anon_sym_POUNDif] = ACTIONS(4283),
    [anon_sym_POUNDIF] = ACTIONS(4283),
    [anon_sym_POUNDIf] = ACTIONS(4283),
    [anon_sym_not] = ACTIONS(4281),
    [anon_sym_NOT] = ACTIONS(4281),
    [anon_sym_Not] = ACTIONS(4281),
    [anon_sym_POUNDelse] = ACTIONS(4283),
    [anon_sym_POUNDELSE] = ACTIONS(4283),
    [anon_sym_POUNDElse] = ACTIONS(4283),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4281),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4281),
    [anon_sym_PLUS] = ACTIONS(4283),
    [sym_datetime_literal] = ACTIONS(4283),
    [sym_date_literal] = ACTIONS(4281),
    [sym_time_literal] = ACTIONS(4281),
    [sym_biginteger_literal] = ACTIONS(4283),
    [anon_sym_if] = ACTIONS(4281),
    [anon_sym_IF] = ACTIONS(4281),
    [anon_sym_If] = ACTIONS(4281),
    [anon_sym_else] = ACTIONS(4281),
    [anon_sym_ELSE] = ACTIONS(4281),
    [anon_sym_Else] = ACTIONS(4281),
    [anon_sym_case] = ACTIONS(4281),
    [anon_sym_CASE] = ACTIONS(4281),
    [anon_sym_Case] = ACTIONS(4281),
    [anon_sym_for] = ACTIONS(4281),
    [anon_sym_FOR] = ACTIONS(4281),
    [anon_sym_For] = ACTIONS(4281),
    [anon_sym_foreach] = ACTIONS(4281),
    [anon_sym_FOREACH] = ACTIONS(4281),
    [anon_sym_Foreach] = ACTIONS(4281),
    [anon_sym_while] = ACTIONS(4281),
    [anon_sym_WHILE] = ACTIONS(4281),
    [anon_sym_While] = ACTIONS(4281),
    [anon_sym_repeat] = ACTIONS(4281),
    [anon_sym_REPEAT] = ACTIONS(4281),
    [anon_sym_Repeat] = ACTIONS(4281),
    [anon_sym_until] = ACTIONS(4281),
    [anon_sym_UNTIL] = ACTIONS(4281),
    [anon_sym_Until] = ACTIONS(4281),
    [anon_sym_exit] = ACTIONS(4281),
    [anon_sym_EXIT] = ACTIONS(4281),
    [anon_sym_Exit] = ACTIONS(4281),
    [anon_sym_continue] = ACTIONS(4281),
    [anon_sym_CONTINUE] = ACTIONS(4281),
    [anon_sym_Continue] = ACTIONS(4281),
    [anon_sym_break] = ACTIONS(4281),
    [anon_sym_BREAK] = ACTIONS(4281),
    [anon_sym_Break] = ACTIONS(4281),
    [anon_sym_with] = ACTIONS(4281),
    [anon_sym_WITH] = ACTIONS(4281),
    [anon_sym_With] = ACTIONS(4281),
    [sym_asserterror_keyword] = ACTIONS(4283),
    [sym_page_keyword] = ACTIONS(4281),
    [anon_sym_codeunit] = ACTIONS(4281),
    [anon_sym_CODEUNIT] = ACTIONS(4281),
    [anon_sym_Codeunit] = ACTIONS(4281),
    [anon_sym_CodeUnit] = ACTIONS(4281),
    [anon_sym_COdeunit] = ACTIONS(4281),
    [anon_sym_codeUnit] = ACTIONS(4281),
    [sym_report_keyword] = ACTIONS(4281),
    [sym_query_keyword] = ACTIONS(4281),
    [anon_sym_xmlport] = ACTIONS(4281),
    [anon_sym_XMLPORT] = ACTIONS(4281),
    [anon_sym_Xmlport] = ACTIONS(4281),
    [anon_sym_XMLport] = ACTIONS(4281),
    [anon_sym_XMLPort] = ACTIONS(4281),
    [anon_sym_XmlPort] = ACTIONS(4281),
    [anon_sym_enum] = ACTIONS(4281),
    [anon_sym_ENUM] = ACTIONS(4281),
    [anon_sym_Enum] = ACTIONS(4281),
    [anon_sym_eNUM] = ACTIONS(4281),
    [anon_sym_eNum] = ACTIONS(4281),
    [anon_sym_ENum] = ACTIONS(4281),
    [sym_quoted_identifier] = ACTIONS(4283),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4283),
    [sym_integer] = ACTIONS(4281),
    [sym_continue_as_identifier] = ACTIONS(4283),
    [sym_preproc_open] = ACTIONS(4283),
  },
  [STATE(1838)] = {
    [sym_identifier] = ACTIONS(4373),
    [anon_sym_SEMI] = ACTIONS(4878),
    [anon_sym_DASH] = ACTIONS(4377),
    [aux_sym_boolean_token1] = ACTIONS(4373),
    [aux_sym_boolean_token2] = ACTIONS(4373),
    [sym_decimal] = ACTIONS(4373),
    [anon_sym_LPAREN] = ACTIONS(4377),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4373),
    [anon_sym_LBRACK] = ACTIONS(4377),
    [aux_sym_record_type_token1] = ACTIONS(4373),
    [aux_sym_basic_type_token21] = ACTIONS(4373),
    [aux_sym_basic_type_token22] = ACTIONS(4373),
    [aux_sym_basic_type_token48] = ACTIONS(4373),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4373),
    [anon_sym_POUNDif] = ACTIONS(4377),
    [anon_sym_POUNDIF] = ACTIONS(4377),
    [anon_sym_POUNDIf] = ACTIONS(4377),
    [anon_sym_not] = ACTIONS(4373),
    [anon_sym_NOT] = ACTIONS(4373),
    [anon_sym_Not] = ACTIONS(4373),
    [anon_sym_POUNDelse] = ACTIONS(4377),
    [anon_sym_POUNDELSE] = ACTIONS(4377),
    [anon_sym_POUNDElse] = ACTIONS(4377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4373),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4373),
    [anon_sym_PLUS] = ACTIONS(4377),
    [sym_datetime_literal] = ACTIONS(4377),
    [sym_date_literal] = ACTIONS(4373),
    [sym_time_literal] = ACTIONS(4373),
    [sym_biginteger_literal] = ACTIONS(4377),
    [anon_sym_if] = ACTIONS(4373),
    [anon_sym_IF] = ACTIONS(4373),
    [anon_sym_If] = ACTIONS(4373),
    [anon_sym_else] = ACTIONS(4373),
    [anon_sym_ELSE] = ACTIONS(4373),
    [anon_sym_Else] = ACTIONS(4373),
    [anon_sym_case] = ACTIONS(4373),
    [anon_sym_CASE] = ACTIONS(4373),
    [anon_sym_Case] = ACTIONS(4373),
    [anon_sym_for] = ACTIONS(4373),
    [anon_sym_FOR] = ACTIONS(4373),
    [anon_sym_For] = ACTIONS(4373),
    [anon_sym_foreach] = ACTIONS(4373),
    [anon_sym_FOREACH] = ACTIONS(4373),
    [anon_sym_Foreach] = ACTIONS(4373),
    [anon_sym_while] = ACTIONS(4373),
    [anon_sym_WHILE] = ACTIONS(4373),
    [anon_sym_While] = ACTIONS(4373),
    [anon_sym_repeat] = ACTIONS(4373),
    [anon_sym_REPEAT] = ACTIONS(4373),
    [anon_sym_Repeat] = ACTIONS(4373),
    [anon_sym_until] = ACTIONS(4373),
    [anon_sym_UNTIL] = ACTIONS(4373),
    [anon_sym_Until] = ACTIONS(4373),
    [anon_sym_exit] = ACTIONS(4373),
    [anon_sym_EXIT] = ACTIONS(4373),
    [anon_sym_Exit] = ACTIONS(4373),
    [anon_sym_continue] = ACTIONS(4373),
    [anon_sym_CONTINUE] = ACTIONS(4373),
    [anon_sym_Continue] = ACTIONS(4373),
    [anon_sym_break] = ACTIONS(4373),
    [anon_sym_BREAK] = ACTIONS(4373),
    [anon_sym_Break] = ACTIONS(4373),
    [anon_sym_with] = ACTIONS(4373),
    [anon_sym_WITH] = ACTIONS(4373),
    [anon_sym_With] = ACTIONS(4373),
    [sym_asserterror_keyword] = ACTIONS(4377),
    [sym_page_keyword] = ACTIONS(4373),
    [anon_sym_codeunit] = ACTIONS(4373),
    [anon_sym_CODEUNIT] = ACTIONS(4373),
    [anon_sym_Codeunit] = ACTIONS(4373),
    [anon_sym_CodeUnit] = ACTIONS(4373),
    [anon_sym_COdeunit] = ACTIONS(4373),
    [anon_sym_codeUnit] = ACTIONS(4373),
    [sym_report_keyword] = ACTIONS(4373),
    [sym_query_keyword] = ACTIONS(4373),
    [anon_sym_xmlport] = ACTIONS(4373),
    [anon_sym_XMLPORT] = ACTIONS(4373),
    [anon_sym_Xmlport] = ACTIONS(4373),
    [anon_sym_XMLport] = ACTIONS(4373),
    [anon_sym_XMLPort] = ACTIONS(4373),
    [anon_sym_XmlPort] = ACTIONS(4373),
    [anon_sym_enum] = ACTIONS(4373),
    [anon_sym_ENUM] = ACTIONS(4373),
    [anon_sym_Enum] = ACTIONS(4373),
    [anon_sym_eNUM] = ACTIONS(4373),
    [anon_sym_eNum] = ACTIONS(4373),
    [anon_sym_ENum] = ACTIONS(4373),
    [sym_quoted_identifier] = ACTIONS(4377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4377),
    [sym_integer] = ACTIONS(4373),
    [sym_continue_as_identifier] = ACTIONS(4377),
    [sym_preproc_open] = ACTIONS(4377),
  },
  [STATE(1839)] = {
    [sym_identifier] = ACTIONS(4373),
    [anon_sym_SEMI] = ACTIONS(4377),
    [anon_sym_DASH] = ACTIONS(4377),
    [aux_sym_boolean_token1] = ACTIONS(4373),
    [aux_sym_boolean_token2] = ACTIONS(4373),
    [sym_decimal] = ACTIONS(4373),
    [anon_sym_LPAREN] = ACTIONS(4377),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4373),
    [anon_sym_LBRACK] = ACTIONS(4377),
    [aux_sym_record_type_token1] = ACTIONS(4373),
    [aux_sym_basic_type_token21] = ACTIONS(4373),
    [aux_sym_basic_type_token22] = ACTIONS(4373),
    [aux_sym_basic_type_token48] = ACTIONS(4373),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4373),
    [anon_sym_POUNDif] = ACTIONS(4377),
    [anon_sym_POUNDIF] = ACTIONS(4377),
    [anon_sym_POUNDIf] = ACTIONS(4377),
    [anon_sym_not] = ACTIONS(4373),
    [anon_sym_NOT] = ACTIONS(4373),
    [anon_sym_Not] = ACTIONS(4373),
    [anon_sym_POUNDelse] = ACTIONS(4377),
    [anon_sym_POUNDELSE] = ACTIONS(4377),
    [anon_sym_POUNDElse] = ACTIONS(4377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4373),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4373),
    [anon_sym_PLUS] = ACTIONS(4377),
    [sym_datetime_literal] = ACTIONS(4377),
    [sym_date_literal] = ACTIONS(4373),
    [sym_time_literal] = ACTIONS(4373),
    [sym_biginteger_literal] = ACTIONS(4377),
    [anon_sym_if] = ACTIONS(4373),
    [anon_sym_IF] = ACTIONS(4373),
    [anon_sym_If] = ACTIONS(4373),
    [anon_sym_else] = ACTIONS(4373),
    [anon_sym_ELSE] = ACTIONS(4373),
    [anon_sym_Else] = ACTIONS(4373),
    [anon_sym_case] = ACTIONS(4373),
    [anon_sym_CASE] = ACTIONS(4373),
    [anon_sym_Case] = ACTIONS(4373),
    [anon_sym_for] = ACTIONS(4373),
    [anon_sym_FOR] = ACTIONS(4373),
    [anon_sym_For] = ACTIONS(4373),
    [anon_sym_foreach] = ACTIONS(4373),
    [anon_sym_FOREACH] = ACTIONS(4373),
    [anon_sym_Foreach] = ACTIONS(4373),
    [anon_sym_while] = ACTIONS(4373),
    [anon_sym_WHILE] = ACTIONS(4373),
    [anon_sym_While] = ACTIONS(4373),
    [anon_sym_repeat] = ACTIONS(4373),
    [anon_sym_REPEAT] = ACTIONS(4373),
    [anon_sym_Repeat] = ACTIONS(4373),
    [anon_sym_until] = ACTIONS(4373),
    [anon_sym_UNTIL] = ACTIONS(4373),
    [anon_sym_Until] = ACTIONS(4373),
    [anon_sym_exit] = ACTIONS(4373),
    [anon_sym_EXIT] = ACTIONS(4373),
    [anon_sym_Exit] = ACTIONS(4373),
    [anon_sym_continue] = ACTIONS(4373),
    [anon_sym_CONTINUE] = ACTIONS(4373),
    [anon_sym_Continue] = ACTIONS(4373),
    [anon_sym_break] = ACTIONS(4373),
    [anon_sym_BREAK] = ACTIONS(4373),
    [anon_sym_Break] = ACTIONS(4373),
    [anon_sym_with] = ACTIONS(4373),
    [anon_sym_WITH] = ACTIONS(4373),
    [anon_sym_With] = ACTIONS(4373),
    [sym_asserterror_keyword] = ACTIONS(4377),
    [sym_page_keyword] = ACTIONS(4373),
    [anon_sym_codeunit] = ACTIONS(4373),
    [anon_sym_CODEUNIT] = ACTIONS(4373),
    [anon_sym_Codeunit] = ACTIONS(4373),
    [anon_sym_CodeUnit] = ACTIONS(4373),
    [anon_sym_COdeunit] = ACTIONS(4373),
    [anon_sym_codeUnit] = ACTIONS(4373),
    [sym_report_keyword] = ACTIONS(4373),
    [sym_query_keyword] = ACTIONS(4373),
    [anon_sym_xmlport] = ACTIONS(4373),
    [anon_sym_XMLPORT] = ACTIONS(4373),
    [anon_sym_Xmlport] = ACTIONS(4373),
    [anon_sym_XMLport] = ACTIONS(4373),
    [anon_sym_XMLPort] = ACTIONS(4373),
    [anon_sym_XmlPort] = ACTIONS(4373),
    [anon_sym_enum] = ACTIONS(4373),
    [anon_sym_ENUM] = ACTIONS(4373),
    [anon_sym_Enum] = ACTIONS(4373),
    [anon_sym_eNUM] = ACTIONS(4373),
    [anon_sym_eNum] = ACTIONS(4373),
    [anon_sym_ENum] = ACTIONS(4373),
    [sym_quoted_identifier] = ACTIONS(4377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4377),
    [sym_integer] = ACTIONS(4373),
    [sym_continue_as_identifier] = ACTIONS(4377),
    [sym_preproc_open] = ACTIONS(4377),
  },
  [STATE(1840)] = {
    [sym_identifier] = ACTIONS(4379),
    [anon_sym_SEMI] = ACTIONS(4381),
    [anon_sym_DASH] = ACTIONS(4381),
    [aux_sym_boolean_token1] = ACTIONS(4379),
    [aux_sym_boolean_token2] = ACTIONS(4379),
    [sym_decimal] = ACTIONS(4379),
    [anon_sym_LPAREN] = ACTIONS(4381),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4379),
    [anon_sym_LBRACK] = ACTIONS(4381),
    [aux_sym_record_type_token1] = ACTIONS(4379),
    [aux_sym_basic_type_token21] = ACTIONS(4379),
    [aux_sym_basic_type_token22] = ACTIONS(4379),
    [aux_sym_basic_type_token48] = ACTIONS(4379),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4379),
    [anon_sym_POUNDif] = ACTIONS(4381),
    [anon_sym_POUNDIF] = ACTIONS(4381),
    [anon_sym_POUNDIf] = ACTIONS(4381),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelse] = ACTIONS(4381),
    [anon_sym_POUNDELSE] = ACTIONS(4381),
    [anon_sym_POUNDElse] = ACTIONS(4381),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4379),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4379),
    [anon_sym_PLUS] = ACTIONS(4381),
    [sym_datetime_literal] = ACTIONS(4381),
    [sym_date_literal] = ACTIONS(4379),
    [sym_time_literal] = ACTIONS(4379),
    [sym_biginteger_literal] = ACTIONS(4381),
    [anon_sym_if] = ACTIONS(4379),
    [anon_sym_IF] = ACTIONS(4379),
    [anon_sym_If] = ACTIONS(4379),
    [anon_sym_else] = ACTIONS(4379),
    [anon_sym_ELSE] = ACTIONS(4379),
    [anon_sym_Else] = ACTIONS(4379),
    [anon_sym_case] = ACTIONS(4379),
    [anon_sym_CASE] = ACTIONS(4379),
    [anon_sym_Case] = ACTIONS(4379),
    [anon_sym_for] = ACTIONS(4379),
    [anon_sym_FOR] = ACTIONS(4379),
    [anon_sym_For] = ACTIONS(4379),
    [anon_sym_foreach] = ACTIONS(4379),
    [anon_sym_FOREACH] = ACTIONS(4379),
    [anon_sym_Foreach] = ACTIONS(4379),
    [anon_sym_while] = ACTIONS(4379),
    [anon_sym_WHILE] = ACTIONS(4379),
    [anon_sym_While] = ACTIONS(4379),
    [anon_sym_repeat] = ACTIONS(4379),
    [anon_sym_REPEAT] = ACTIONS(4379),
    [anon_sym_Repeat] = ACTIONS(4379),
    [anon_sym_until] = ACTIONS(4379),
    [anon_sym_UNTIL] = ACTIONS(4379),
    [anon_sym_Until] = ACTIONS(4379),
    [anon_sym_exit] = ACTIONS(4379),
    [anon_sym_EXIT] = ACTIONS(4379),
    [anon_sym_Exit] = ACTIONS(4379),
    [anon_sym_continue] = ACTIONS(4379),
    [anon_sym_CONTINUE] = ACTIONS(4379),
    [anon_sym_Continue] = ACTIONS(4379),
    [anon_sym_break] = ACTIONS(4379),
    [anon_sym_BREAK] = ACTIONS(4379),
    [anon_sym_Break] = ACTIONS(4379),
    [anon_sym_with] = ACTIONS(4379),
    [anon_sym_WITH] = ACTIONS(4379),
    [anon_sym_With] = ACTIONS(4379),
    [sym_asserterror_keyword] = ACTIONS(4381),
    [sym_page_keyword] = ACTIONS(4379),
    [anon_sym_codeunit] = ACTIONS(4379),
    [anon_sym_CODEUNIT] = ACTIONS(4379),
    [anon_sym_Codeunit] = ACTIONS(4379),
    [anon_sym_CodeUnit] = ACTIONS(4379),
    [anon_sym_COdeunit] = ACTIONS(4379),
    [anon_sym_codeUnit] = ACTIONS(4379),
    [sym_report_keyword] = ACTIONS(4379),
    [sym_query_keyword] = ACTIONS(4379),
    [anon_sym_xmlport] = ACTIONS(4379),
    [anon_sym_XMLPORT] = ACTIONS(4379),
    [anon_sym_Xmlport] = ACTIONS(4379),
    [anon_sym_XMLport] = ACTIONS(4379),
    [anon_sym_XMLPort] = ACTIONS(4379),
    [anon_sym_XmlPort] = ACTIONS(4379),
    [anon_sym_enum] = ACTIONS(4379),
    [anon_sym_ENUM] = ACTIONS(4379),
    [anon_sym_Enum] = ACTIONS(4379),
    [anon_sym_eNUM] = ACTIONS(4379),
    [anon_sym_eNum] = ACTIONS(4379),
    [anon_sym_ENum] = ACTIONS(4379),
    [sym_quoted_identifier] = ACTIONS(4381),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4381),
    [sym_integer] = ACTIONS(4379),
    [sym_continue_as_identifier] = ACTIONS(4381),
    [sym_preproc_open] = ACTIONS(4381),
  },
  [STATE(1841)] = {
    [sym_identifier] = ACTIONS(4383),
    [anon_sym_SEMI] = ACTIONS(4880),
    [anon_sym_DASH] = ACTIONS(4387),
    [aux_sym_boolean_token1] = ACTIONS(4383),
    [aux_sym_boolean_token2] = ACTIONS(4383),
    [sym_decimal] = ACTIONS(4383),
    [anon_sym_LPAREN] = ACTIONS(4387),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4383),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_record_type_token1] = ACTIONS(4383),
    [aux_sym_basic_type_token21] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_basic_type_token48] = ACTIONS(4383),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4383),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [anon_sym_not] = ACTIONS(4383),
    [anon_sym_NOT] = ACTIONS(4383),
    [anon_sym_Not] = ACTIONS(4383),
    [anon_sym_POUNDelse] = ACTIONS(4387),
    [anon_sym_POUNDELSE] = ACTIONS(4387),
    [anon_sym_POUNDElse] = ACTIONS(4387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4383),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4383),
    [anon_sym_PLUS] = ACTIONS(4387),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4383),
    [sym_time_literal] = ACTIONS(4383),
    [sym_biginteger_literal] = ACTIONS(4387),
    [anon_sym_if] = ACTIONS(4383),
    [anon_sym_IF] = ACTIONS(4383),
    [anon_sym_If] = ACTIONS(4383),
    [anon_sym_else] = ACTIONS(4383),
    [anon_sym_ELSE] = ACTIONS(4383),
    [anon_sym_Else] = ACTIONS(4383),
    [anon_sym_case] = ACTIONS(4383),
    [anon_sym_CASE] = ACTIONS(4383),
    [anon_sym_Case] = ACTIONS(4383),
    [anon_sym_for] = ACTIONS(4383),
    [anon_sym_FOR] = ACTIONS(4383),
    [anon_sym_For] = ACTIONS(4383),
    [anon_sym_foreach] = ACTIONS(4383),
    [anon_sym_FOREACH] = ACTIONS(4383),
    [anon_sym_Foreach] = ACTIONS(4383),
    [anon_sym_while] = ACTIONS(4383),
    [anon_sym_WHILE] = ACTIONS(4383),
    [anon_sym_While] = ACTIONS(4383),
    [anon_sym_repeat] = ACTIONS(4383),
    [anon_sym_REPEAT] = ACTIONS(4383),
    [anon_sym_Repeat] = ACTIONS(4383),
    [anon_sym_until] = ACTIONS(4383),
    [anon_sym_UNTIL] = ACTIONS(4383),
    [anon_sym_Until] = ACTIONS(4383),
    [anon_sym_exit] = ACTIONS(4383),
    [anon_sym_EXIT] = ACTIONS(4383),
    [anon_sym_Exit] = ACTIONS(4383),
    [anon_sym_continue] = ACTIONS(4383),
    [anon_sym_CONTINUE] = ACTIONS(4383),
    [anon_sym_Continue] = ACTIONS(4383),
    [anon_sym_break] = ACTIONS(4383),
    [anon_sym_BREAK] = ACTIONS(4383),
    [anon_sym_Break] = ACTIONS(4383),
    [anon_sym_with] = ACTIONS(4383),
    [anon_sym_WITH] = ACTIONS(4383),
    [anon_sym_With] = ACTIONS(4383),
    [sym_asserterror_keyword] = ACTIONS(4387),
    [sym_page_keyword] = ACTIONS(4383),
    [anon_sym_codeunit] = ACTIONS(4383),
    [anon_sym_CODEUNIT] = ACTIONS(4383),
    [anon_sym_Codeunit] = ACTIONS(4383),
    [anon_sym_CodeUnit] = ACTIONS(4383),
    [anon_sym_COdeunit] = ACTIONS(4383),
    [anon_sym_codeUnit] = ACTIONS(4383),
    [sym_report_keyword] = ACTIONS(4383),
    [sym_query_keyword] = ACTIONS(4383),
    [anon_sym_xmlport] = ACTIONS(4383),
    [anon_sym_XMLPORT] = ACTIONS(4383),
    [anon_sym_Xmlport] = ACTIONS(4383),
    [anon_sym_XMLport] = ACTIONS(4383),
    [anon_sym_XMLPort] = ACTIONS(4383),
    [anon_sym_XmlPort] = ACTIONS(4383),
    [anon_sym_enum] = ACTIONS(4383),
    [anon_sym_ENUM] = ACTIONS(4383),
    [anon_sym_Enum] = ACTIONS(4383),
    [anon_sym_eNUM] = ACTIONS(4383),
    [anon_sym_eNum] = ACTIONS(4383),
    [anon_sym_ENum] = ACTIONS(4383),
    [sym_quoted_identifier] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4383),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
  },
  [STATE(1842)] = {
    [sym_identifier] = ACTIONS(4383),
    [anon_sym_SEMI] = ACTIONS(4882),
    [anon_sym_DASH] = ACTIONS(4387),
    [aux_sym_boolean_token1] = ACTIONS(4383),
    [aux_sym_boolean_token2] = ACTIONS(4383),
    [sym_decimal] = ACTIONS(4383),
    [anon_sym_LPAREN] = ACTIONS(4387),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4383),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_record_type_token1] = ACTIONS(4383),
    [aux_sym_basic_type_token21] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_basic_type_token48] = ACTIONS(4383),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4383),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [anon_sym_not] = ACTIONS(4383),
    [anon_sym_NOT] = ACTIONS(4383),
    [anon_sym_Not] = ACTIONS(4383),
    [anon_sym_POUNDelse] = ACTIONS(4387),
    [anon_sym_POUNDELSE] = ACTIONS(4387),
    [anon_sym_POUNDElse] = ACTIONS(4387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4383),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4383),
    [anon_sym_PLUS] = ACTIONS(4387),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4383),
    [sym_time_literal] = ACTIONS(4383),
    [sym_biginteger_literal] = ACTIONS(4387),
    [anon_sym_if] = ACTIONS(4383),
    [anon_sym_IF] = ACTIONS(4383),
    [anon_sym_If] = ACTIONS(4383),
    [anon_sym_else] = ACTIONS(4383),
    [anon_sym_ELSE] = ACTIONS(4383),
    [anon_sym_Else] = ACTIONS(4383),
    [anon_sym_case] = ACTIONS(4383),
    [anon_sym_CASE] = ACTIONS(4383),
    [anon_sym_Case] = ACTIONS(4383),
    [anon_sym_for] = ACTIONS(4383),
    [anon_sym_FOR] = ACTIONS(4383),
    [anon_sym_For] = ACTIONS(4383),
    [anon_sym_foreach] = ACTIONS(4383),
    [anon_sym_FOREACH] = ACTIONS(4383),
    [anon_sym_Foreach] = ACTIONS(4383),
    [anon_sym_while] = ACTIONS(4383),
    [anon_sym_WHILE] = ACTIONS(4383),
    [anon_sym_While] = ACTIONS(4383),
    [anon_sym_repeat] = ACTIONS(4383),
    [anon_sym_REPEAT] = ACTIONS(4383),
    [anon_sym_Repeat] = ACTIONS(4383),
    [anon_sym_until] = ACTIONS(4383),
    [anon_sym_UNTIL] = ACTIONS(4383),
    [anon_sym_Until] = ACTIONS(4383),
    [anon_sym_exit] = ACTIONS(4383),
    [anon_sym_EXIT] = ACTIONS(4383),
    [anon_sym_Exit] = ACTIONS(4383),
    [anon_sym_continue] = ACTIONS(4383),
    [anon_sym_CONTINUE] = ACTIONS(4383),
    [anon_sym_Continue] = ACTIONS(4383),
    [anon_sym_break] = ACTIONS(4383),
    [anon_sym_BREAK] = ACTIONS(4383),
    [anon_sym_Break] = ACTIONS(4383),
    [anon_sym_with] = ACTIONS(4383),
    [anon_sym_WITH] = ACTIONS(4383),
    [anon_sym_With] = ACTIONS(4383),
    [sym_asserterror_keyword] = ACTIONS(4387),
    [sym_page_keyword] = ACTIONS(4383),
    [anon_sym_codeunit] = ACTIONS(4383),
    [anon_sym_CODEUNIT] = ACTIONS(4383),
    [anon_sym_Codeunit] = ACTIONS(4383),
    [anon_sym_CodeUnit] = ACTIONS(4383),
    [anon_sym_COdeunit] = ACTIONS(4383),
    [anon_sym_codeUnit] = ACTIONS(4383),
    [sym_report_keyword] = ACTIONS(4383),
    [sym_query_keyword] = ACTIONS(4383),
    [anon_sym_xmlport] = ACTIONS(4383),
    [anon_sym_XMLPORT] = ACTIONS(4383),
    [anon_sym_Xmlport] = ACTIONS(4383),
    [anon_sym_XMLport] = ACTIONS(4383),
    [anon_sym_XMLPort] = ACTIONS(4383),
    [anon_sym_XmlPort] = ACTIONS(4383),
    [anon_sym_enum] = ACTIONS(4383),
    [anon_sym_ENUM] = ACTIONS(4383),
    [anon_sym_Enum] = ACTIONS(4383),
    [anon_sym_eNUM] = ACTIONS(4383),
    [anon_sym_eNum] = ACTIONS(4383),
    [anon_sym_ENum] = ACTIONS(4383),
    [sym_quoted_identifier] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4383),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
  },
  [STATE(1843)] = {
    [sym_identifier] = ACTIONS(4383),
    [anon_sym_SEMI] = ACTIONS(4387),
    [anon_sym_DASH] = ACTIONS(4387),
    [aux_sym_boolean_token1] = ACTIONS(4383),
    [aux_sym_boolean_token2] = ACTIONS(4383),
    [sym_decimal] = ACTIONS(4383),
    [anon_sym_LPAREN] = ACTIONS(4387),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4383),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_record_type_token1] = ACTIONS(4383),
    [aux_sym_basic_type_token21] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_basic_type_token48] = ACTIONS(4383),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4383),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [anon_sym_not] = ACTIONS(4383),
    [anon_sym_NOT] = ACTIONS(4383),
    [anon_sym_Not] = ACTIONS(4383),
    [anon_sym_POUNDelse] = ACTIONS(4387),
    [anon_sym_POUNDELSE] = ACTIONS(4387),
    [anon_sym_POUNDElse] = ACTIONS(4387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4383),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4383),
    [anon_sym_PLUS] = ACTIONS(4387),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4383),
    [sym_time_literal] = ACTIONS(4383),
    [sym_biginteger_literal] = ACTIONS(4387),
    [anon_sym_if] = ACTIONS(4383),
    [anon_sym_IF] = ACTIONS(4383),
    [anon_sym_If] = ACTIONS(4383),
    [anon_sym_else] = ACTIONS(4383),
    [anon_sym_ELSE] = ACTIONS(4383),
    [anon_sym_Else] = ACTIONS(4383),
    [anon_sym_case] = ACTIONS(4383),
    [anon_sym_CASE] = ACTIONS(4383),
    [anon_sym_Case] = ACTIONS(4383),
    [anon_sym_for] = ACTIONS(4383),
    [anon_sym_FOR] = ACTIONS(4383),
    [anon_sym_For] = ACTIONS(4383),
    [anon_sym_foreach] = ACTIONS(4383),
    [anon_sym_FOREACH] = ACTIONS(4383),
    [anon_sym_Foreach] = ACTIONS(4383),
    [anon_sym_while] = ACTIONS(4383),
    [anon_sym_WHILE] = ACTIONS(4383),
    [anon_sym_While] = ACTIONS(4383),
    [anon_sym_repeat] = ACTIONS(4383),
    [anon_sym_REPEAT] = ACTIONS(4383),
    [anon_sym_Repeat] = ACTIONS(4383),
    [anon_sym_until] = ACTIONS(4383),
    [anon_sym_UNTIL] = ACTIONS(4383),
    [anon_sym_Until] = ACTIONS(4383),
    [anon_sym_exit] = ACTIONS(4383),
    [anon_sym_EXIT] = ACTIONS(4383),
    [anon_sym_Exit] = ACTIONS(4383),
    [anon_sym_continue] = ACTIONS(4383),
    [anon_sym_CONTINUE] = ACTIONS(4383),
    [anon_sym_Continue] = ACTIONS(4383),
    [anon_sym_break] = ACTIONS(4383),
    [anon_sym_BREAK] = ACTIONS(4383),
    [anon_sym_Break] = ACTIONS(4383),
    [anon_sym_with] = ACTIONS(4383),
    [anon_sym_WITH] = ACTIONS(4383),
    [anon_sym_With] = ACTIONS(4383),
    [sym_asserterror_keyword] = ACTIONS(4387),
    [sym_page_keyword] = ACTIONS(4383),
    [anon_sym_codeunit] = ACTIONS(4383),
    [anon_sym_CODEUNIT] = ACTIONS(4383),
    [anon_sym_Codeunit] = ACTIONS(4383),
    [anon_sym_CodeUnit] = ACTIONS(4383),
    [anon_sym_COdeunit] = ACTIONS(4383),
    [anon_sym_codeUnit] = ACTIONS(4383),
    [sym_report_keyword] = ACTIONS(4383),
    [sym_query_keyword] = ACTIONS(4383),
    [anon_sym_xmlport] = ACTIONS(4383),
    [anon_sym_XMLPORT] = ACTIONS(4383),
    [anon_sym_Xmlport] = ACTIONS(4383),
    [anon_sym_XMLport] = ACTIONS(4383),
    [anon_sym_XMLPort] = ACTIONS(4383),
    [anon_sym_XmlPort] = ACTIONS(4383),
    [anon_sym_enum] = ACTIONS(4383),
    [anon_sym_ENUM] = ACTIONS(4383),
    [anon_sym_Enum] = ACTIONS(4383),
    [anon_sym_eNUM] = ACTIONS(4383),
    [anon_sym_eNum] = ACTIONS(4383),
    [anon_sym_ENum] = ACTIONS(4383),
    [sym_quoted_identifier] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4383),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
  },
  [STATE(1844)] = {
    [sym_identifier] = ACTIONS(4395),
    [anon_sym_SEMI] = ACTIONS(4397),
    [anon_sym_DASH] = ACTIONS(4397),
    [aux_sym_boolean_token1] = ACTIONS(4395),
    [aux_sym_boolean_token2] = ACTIONS(4395),
    [sym_decimal] = ACTIONS(4395),
    [anon_sym_LPAREN] = ACTIONS(4397),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4395),
    [anon_sym_LBRACK] = ACTIONS(4397),
    [aux_sym_record_type_token1] = ACTIONS(4395),
    [aux_sym_basic_type_token21] = ACTIONS(4395),
    [aux_sym_basic_type_token22] = ACTIONS(4395),
    [aux_sym_basic_type_token48] = ACTIONS(4395),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4395),
    [anon_sym_POUNDif] = ACTIONS(4397),
    [anon_sym_POUNDIF] = ACTIONS(4397),
    [anon_sym_POUNDIf] = ACTIONS(4397),
    [anon_sym_not] = ACTIONS(4395),
    [anon_sym_NOT] = ACTIONS(4395),
    [anon_sym_Not] = ACTIONS(4395),
    [anon_sym_POUNDelse] = ACTIONS(4397),
    [anon_sym_POUNDELSE] = ACTIONS(4397),
    [anon_sym_POUNDElse] = ACTIONS(4397),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4395),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4395),
    [anon_sym_PLUS] = ACTIONS(4397),
    [sym_datetime_literal] = ACTIONS(4397),
    [sym_date_literal] = ACTIONS(4395),
    [sym_time_literal] = ACTIONS(4395),
    [sym_biginteger_literal] = ACTIONS(4397),
    [anon_sym_if] = ACTIONS(4395),
    [anon_sym_IF] = ACTIONS(4395),
    [anon_sym_If] = ACTIONS(4395),
    [anon_sym_else] = ACTIONS(4395),
    [anon_sym_ELSE] = ACTIONS(4395),
    [anon_sym_Else] = ACTIONS(4395),
    [anon_sym_case] = ACTIONS(4395),
    [anon_sym_CASE] = ACTIONS(4395),
    [anon_sym_Case] = ACTIONS(4395),
    [anon_sym_for] = ACTIONS(4395),
    [anon_sym_FOR] = ACTIONS(4395),
    [anon_sym_For] = ACTIONS(4395),
    [anon_sym_foreach] = ACTIONS(4395),
    [anon_sym_FOREACH] = ACTIONS(4395),
    [anon_sym_Foreach] = ACTIONS(4395),
    [anon_sym_while] = ACTIONS(4395),
    [anon_sym_WHILE] = ACTIONS(4395),
    [anon_sym_While] = ACTIONS(4395),
    [anon_sym_repeat] = ACTIONS(4395),
    [anon_sym_REPEAT] = ACTIONS(4395),
    [anon_sym_Repeat] = ACTIONS(4395),
    [anon_sym_until] = ACTIONS(4395),
    [anon_sym_UNTIL] = ACTIONS(4395),
    [anon_sym_Until] = ACTIONS(4395),
    [anon_sym_exit] = ACTIONS(4395),
    [anon_sym_EXIT] = ACTIONS(4395),
    [anon_sym_Exit] = ACTIONS(4395),
    [anon_sym_continue] = ACTIONS(4395),
    [anon_sym_CONTINUE] = ACTIONS(4395),
    [anon_sym_Continue] = ACTIONS(4395),
    [anon_sym_break] = ACTIONS(4395),
    [anon_sym_BREAK] = ACTIONS(4395),
    [anon_sym_Break] = ACTIONS(4395),
    [anon_sym_with] = ACTIONS(4395),
    [anon_sym_WITH] = ACTIONS(4395),
    [anon_sym_With] = ACTIONS(4395),
    [sym_asserterror_keyword] = ACTIONS(4397),
    [sym_page_keyword] = ACTIONS(4395),
    [anon_sym_codeunit] = ACTIONS(4395),
    [anon_sym_CODEUNIT] = ACTIONS(4395),
    [anon_sym_Codeunit] = ACTIONS(4395),
    [anon_sym_CodeUnit] = ACTIONS(4395),
    [anon_sym_COdeunit] = ACTIONS(4395),
    [anon_sym_codeUnit] = ACTIONS(4395),
    [sym_report_keyword] = ACTIONS(4395),
    [sym_query_keyword] = ACTIONS(4395),
    [anon_sym_xmlport] = ACTIONS(4395),
    [anon_sym_XMLPORT] = ACTIONS(4395),
    [anon_sym_Xmlport] = ACTIONS(4395),
    [anon_sym_XMLport] = ACTIONS(4395),
    [anon_sym_XMLPort] = ACTIONS(4395),
    [anon_sym_XmlPort] = ACTIONS(4395),
    [anon_sym_enum] = ACTIONS(4395),
    [anon_sym_ENUM] = ACTIONS(4395),
    [anon_sym_Enum] = ACTIONS(4395),
    [anon_sym_eNUM] = ACTIONS(4395),
    [anon_sym_eNum] = ACTIONS(4395),
    [anon_sym_ENum] = ACTIONS(4395),
    [sym_quoted_identifier] = ACTIONS(4397),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4397),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4397),
    [sym_preproc_open] = ACTIONS(4397),
  },
  [STATE(1845)] = {
    [sym_identifier] = ACTIONS(4395),
    [anon_sym_SEMI] = ACTIONS(4397),
    [anon_sym_DASH] = ACTIONS(4397),
    [aux_sym_boolean_token1] = ACTIONS(4395),
    [aux_sym_boolean_token2] = ACTIONS(4395),
    [sym_decimal] = ACTIONS(4395),
    [anon_sym_LPAREN] = ACTIONS(4397),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4395),
    [anon_sym_LBRACK] = ACTIONS(4397),
    [aux_sym_record_type_token1] = ACTIONS(4395),
    [aux_sym_basic_type_token21] = ACTIONS(4395),
    [aux_sym_basic_type_token22] = ACTIONS(4395),
    [aux_sym_basic_type_token48] = ACTIONS(4395),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4395),
    [anon_sym_POUNDif] = ACTIONS(4397),
    [anon_sym_POUNDIF] = ACTIONS(4397),
    [anon_sym_POUNDIf] = ACTIONS(4397),
    [anon_sym_not] = ACTIONS(4395),
    [anon_sym_NOT] = ACTIONS(4395),
    [anon_sym_Not] = ACTIONS(4395),
    [anon_sym_POUNDelse] = ACTIONS(4397),
    [anon_sym_POUNDELSE] = ACTIONS(4397),
    [anon_sym_POUNDElse] = ACTIONS(4397),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4395),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4395),
    [anon_sym_PLUS] = ACTIONS(4397),
    [sym_datetime_literal] = ACTIONS(4397),
    [sym_date_literal] = ACTIONS(4395),
    [sym_time_literal] = ACTIONS(4395),
    [sym_biginteger_literal] = ACTIONS(4397),
    [anon_sym_if] = ACTIONS(4395),
    [anon_sym_IF] = ACTIONS(4395),
    [anon_sym_If] = ACTIONS(4395),
    [anon_sym_else] = ACTIONS(4395),
    [anon_sym_ELSE] = ACTIONS(4395),
    [anon_sym_Else] = ACTIONS(4395),
    [anon_sym_case] = ACTIONS(4395),
    [anon_sym_CASE] = ACTIONS(4395),
    [anon_sym_Case] = ACTIONS(4395),
    [anon_sym_for] = ACTIONS(4395),
    [anon_sym_FOR] = ACTIONS(4395),
    [anon_sym_For] = ACTIONS(4395),
    [anon_sym_foreach] = ACTIONS(4395),
    [anon_sym_FOREACH] = ACTIONS(4395),
    [anon_sym_Foreach] = ACTIONS(4395),
    [anon_sym_while] = ACTIONS(4395),
    [anon_sym_WHILE] = ACTIONS(4395),
    [anon_sym_While] = ACTIONS(4395),
    [anon_sym_repeat] = ACTIONS(4395),
    [anon_sym_REPEAT] = ACTIONS(4395),
    [anon_sym_Repeat] = ACTIONS(4395),
    [anon_sym_until] = ACTIONS(4395),
    [anon_sym_UNTIL] = ACTIONS(4395),
    [anon_sym_Until] = ACTIONS(4395),
    [anon_sym_exit] = ACTIONS(4395),
    [anon_sym_EXIT] = ACTIONS(4395),
    [anon_sym_Exit] = ACTIONS(4395),
    [anon_sym_continue] = ACTIONS(4395),
    [anon_sym_CONTINUE] = ACTIONS(4395),
    [anon_sym_Continue] = ACTIONS(4395),
    [anon_sym_break] = ACTIONS(4395),
    [anon_sym_BREAK] = ACTIONS(4395),
    [anon_sym_Break] = ACTIONS(4395),
    [anon_sym_with] = ACTIONS(4395),
    [anon_sym_WITH] = ACTIONS(4395),
    [anon_sym_With] = ACTIONS(4395),
    [sym_asserterror_keyword] = ACTIONS(4397),
    [sym_page_keyword] = ACTIONS(4395),
    [anon_sym_codeunit] = ACTIONS(4395),
    [anon_sym_CODEUNIT] = ACTIONS(4395),
    [anon_sym_Codeunit] = ACTIONS(4395),
    [anon_sym_CodeUnit] = ACTIONS(4395),
    [anon_sym_COdeunit] = ACTIONS(4395),
    [anon_sym_codeUnit] = ACTIONS(4395),
    [sym_report_keyword] = ACTIONS(4395),
    [sym_query_keyword] = ACTIONS(4395),
    [anon_sym_xmlport] = ACTIONS(4395),
    [anon_sym_XMLPORT] = ACTIONS(4395),
    [anon_sym_Xmlport] = ACTIONS(4395),
    [anon_sym_XMLport] = ACTIONS(4395),
    [anon_sym_XMLPort] = ACTIONS(4395),
    [anon_sym_XmlPort] = ACTIONS(4395),
    [anon_sym_enum] = ACTIONS(4395),
    [anon_sym_ENUM] = ACTIONS(4395),
    [anon_sym_Enum] = ACTIONS(4395),
    [anon_sym_eNUM] = ACTIONS(4395),
    [anon_sym_eNum] = ACTIONS(4395),
    [anon_sym_ENum] = ACTIONS(4395),
    [sym_quoted_identifier] = ACTIONS(4397),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4397),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4397),
    [sym_preproc_open] = ACTIONS(4397),
  },
  [STATE(1846)] = {
    [sym_identifier] = ACTIONS(4399),
    [anon_sym_SEMI] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [aux_sym_boolean_token1] = ACTIONS(4399),
    [aux_sym_boolean_token2] = ACTIONS(4399),
    [sym_decimal] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4401),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4399),
    [anon_sym_LBRACK] = ACTIONS(4401),
    [aux_sym_record_type_token1] = ACTIONS(4399),
    [aux_sym_basic_type_token21] = ACTIONS(4399),
    [aux_sym_basic_type_token22] = ACTIONS(4399),
    [aux_sym_basic_type_token48] = ACTIONS(4399),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4399),
    [anon_sym_POUNDif] = ACTIONS(4401),
    [anon_sym_POUNDIF] = ACTIONS(4401),
    [anon_sym_POUNDIf] = ACTIONS(4401),
    [anon_sym_not] = ACTIONS(4399),
    [anon_sym_NOT] = ACTIONS(4399),
    [anon_sym_Not] = ACTIONS(4399),
    [anon_sym_POUNDelse] = ACTIONS(4401),
    [anon_sym_POUNDELSE] = ACTIONS(4401),
    [anon_sym_POUNDElse] = ACTIONS(4401),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4399),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [sym_datetime_literal] = ACTIONS(4401),
    [sym_date_literal] = ACTIONS(4399),
    [sym_time_literal] = ACTIONS(4399),
    [sym_biginteger_literal] = ACTIONS(4401),
    [anon_sym_if] = ACTIONS(4399),
    [anon_sym_IF] = ACTIONS(4399),
    [anon_sym_If] = ACTIONS(4399),
    [anon_sym_else] = ACTIONS(4399),
    [anon_sym_ELSE] = ACTIONS(4399),
    [anon_sym_Else] = ACTIONS(4399),
    [anon_sym_case] = ACTIONS(4399),
    [anon_sym_CASE] = ACTIONS(4399),
    [anon_sym_Case] = ACTIONS(4399),
    [anon_sym_for] = ACTIONS(4399),
    [anon_sym_FOR] = ACTIONS(4399),
    [anon_sym_For] = ACTIONS(4399),
    [anon_sym_foreach] = ACTIONS(4399),
    [anon_sym_FOREACH] = ACTIONS(4399),
    [anon_sym_Foreach] = ACTIONS(4399),
    [anon_sym_while] = ACTIONS(4399),
    [anon_sym_WHILE] = ACTIONS(4399),
    [anon_sym_While] = ACTIONS(4399),
    [anon_sym_repeat] = ACTIONS(4399),
    [anon_sym_REPEAT] = ACTIONS(4399),
    [anon_sym_Repeat] = ACTIONS(4399),
    [anon_sym_until] = ACTIONS(4399),
    [anon_sym_UNTIL] = ACTIONS(4399),
    [anon_sym_Until] = ACTIONS(4399),
    [anon_sym_exit] = ACTIONS(4399),
    [anon_sym_EXIT] = ACTIONS(4399),
    [anon_sym_Exit] = ACTIONS(4399),
    [anon_sym_continue] = ACTIONS(4399),
    [anon_sym_CONTINUE] = ACTIONS(4399),
    [anon_sym_Continue] = ACTIONS(4399),
    [anon_sym_break] = ACTIONS(4399),
    [anon_sym_BREAK] = ACTIONS(4399),
    [anon_sym_Break] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4399),
    [anon_sym_WITH] = ACTIONS(4399),
    [anon_sym_With] = ACTIONS(4399),
    [sym_asserterror_keyword] = ACTIONS(4401),
    [sym_page_keyword] = ACTIONS(4399),
    [anon_sym_codeunit] = ACTIONS(4399),
    [anon_sym_CODEUNIT] = ACTIONS(4399),
    [anon_sym_Codeunit] = ACTIONS(4399),
    [anon_sym_CodeUnit] = ACTIONS(4399),
    [anon_sym_COdeunit] = ACTIONS(4399),
    [anon_sym_codeUnit] = ACTIONS(4399),
    [sym_report_keyword] = ACTIONS(4399),
    [sym_query_keyword] = ACTIONS(4399),
    [anon_sym_xmlport] = ACTIONS(4399),
    [anon_sym_XMLPORT] = ACTIONS(4399),
    [anon_sym_Xmlport] = ACTIONS(4399),
    [anon_sym_XMLport] = ACTIONS(4399),
    [anon_sym_XMLPort] = ACTIONS(4399),
    [anon_sym_XmlPort] = ACTIONS(4399),
    [anon_sym_enum] = ACTIONS(4399),
    [anon_sym_ENUM] = ACTIONS(4399),
    [anon_sym_Enum] = ACTIONS(4399),
    [anon_sym_eNUM] = ACTIONS(4399),
    [anon_sym_eNum] = ACTIONS(4399),
    [anon_sym_ENum] = ACTIONS(4399),
    [sym_quoted_identifier] = ACTIONS(4401),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4401),
    [sym_integer] = ACTIONS(4399),
    [sym_continue_as_identifier] = ACTIONS(4401),
    [sym_preproc_open] = ACTIONS(4401),
  },
  [STATE(1847)] = {
    [sym_identifier] = ACTIONS(4403),
    [anon_sym_SEMI] = ACTIONS(4405),
    [anon_sym_DASH] = ACTIONS(4405),
    [aux_sym_boolean_token1] = ACTIONS(4403),
    [aux_sym_boolean_token2] = ACTIONS(4403),
    [sym_decimal] = ACTIONS(4403),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4403),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [aux_sym_record_type_token1] = ACTIONS(4403),
    [aux_sym_basic_type_token21] = ACTIONS(4403),
    [aux_sym_basic_type_token22] = ACTIONS(4403),
    [aux_sym_basic_type_token48] = ACTIONS(4403),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4403),
    [anon_sym_POUNDif] = ACTIONS(4405),
    [anon_sym_POUNDIF] = ACTIONS(4405),
    [anon_sym_POUNDIf] = ACTIONS(4405),
    [anon_sym_not] = ACTIONS(4403),
    [anon_sym_NOT] = ACTIONS(4403),
    [anon_sym_Not] = ACTIONS(4403),
    [anon_sym_POUNDelse] = ACTIONS(4405),
    [anon_sym_POUNDELSE] = ACTIONS(4405),
    [anon_sym_POUNDElse] = ACTIONS(4405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4403),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4403),
    [anon_sym_PLUS] = ACTIONS(4405),
    [sym_datetime_literal] = ACTIONS(4405),
    [sym_date_literal] = ACTIONS(4403),
    [sym_time_literal] = ACTIONS(4403),
    [sym_biginteger_literal] = ACTIONS(4405),
    [anon_sym_if] = ACTIONS(4403),
    [anon_sym_IF] = ACTIONS(4403),
    [anon_sym_If] = ACTIONS(4403),
    [anon_sym_else] = ACTIONS(4403),
    [anon_sym_ELSE] = ACTIONS(4403),
    [anon_sym_Else] = ACTIONS(4403),
    [anon_sym_case] = ACTIONS(4403),
    [anon_sym_CASE] = ACTIONS(4403),
    [anon_sym_Case] = ACTIONS(4403),
    [anon_sym_for] = ACTIONS(4403),
    [anon_sym_FOR] = ACTIONS(4403),
    [anon_sym_For] = ACTIONS(4403),
    [anon_sym_foreach] = ACTIONS(4403),
    [anon_sym_FOREACH] = ACTIONS(4403),
    [anon_sym_Foreach] = ACTIONS(4403),
    [anon_sym_while] = ACTIONS(4403),
    [anon_sym_WHILE] = ACTIONS(4403),
    [anon_sym_While] = ACTIONS(4403),
    [anon_sym_repeat] = ACTIONS(4403),
    [anon_sym_REPEAT] = ACTIONS(4403),
    [anon_sym_Repeat] = ACTIONS(4403),
    [anon_sym_until] = ACTIONS(4403),
    [anon_sym_UNTIL] = ACTIONS(4403),
    [anon_sym_Until] = ACTIONS(4403),
    [anon_sym_exit] = ACTIONS(4403),
    [anon_sym_EXIT] = ACTIONS(4403),
    [anon_sym_Exit] = ACTIONS(4403),
    [anon_sym_continue] = ACTIONS(4403),
    [anon_sym_CONTINUE] = ACTIONS(4403),
    [anon_sym_Continue] = ACTIONS(4403),
    [anon_sym_break] = ACTIONS(4403),
    [anon_sym_BREAK] = ACTIONS(4403),
    [anon_sym_Break] = ACTIONS(4403),
    [anon_sym_with] = ACTIONS(4403),
    [anon_sym_WITH] = ACTIONS(4403),
    [anon_sym_With] = ACTIONS(4403),
    [sym_asserterror_keyword] = ACTIONS(4405),
    [sym_page_keyword] = ACTIONS(4403),
    [anon_sym_codeunit] = ACTIONS(4403),
    [anon_sym_CODEUNIT] = ACTIONS(4403),
    [anon_sym_Codeunit] = ACTIONS(4403),
    [anon_sym_CodeUnit] = ACTIONS(4403),
    [anon_sym_COdeunit] = ACTIONS(4403),
    [anon_sym_codeUnit] = ACTIONS(4403),
    [sym_report_keyword] = ACTIONS(4403),
    [sym_query_keyword] = ACTIONS(4403),
    [anon_sym_xmlport] = ACTIONS(4403),
    [anon_sym_XMLPORT] = ACTIONS(4403),
    [anon_sym_Xmlport] = ACTIONS(4403),
    [anon_sym_XMLport] = ACTIONS(4403),
    [anon_sym_XMLPort] = ACTIONS(4403),
    [anon_sym_XmlPort] = ACTIONS(4403),
    [anon_sym_enum] = ACTIONS(4403),
    [anon_sym_ENUM] = ACTIONS(4403),
    [anon_sym_Enum] = ACTIONS(4403),
    [anon_sym_eNUM] = ACTIONS(4403),
    [anon_sym_eNum] = ACTIONS(4403),
    [anon_sym_ENum] = ACTIONS(4403),
    [sym_quoted_identifier] = ACTIONS(4405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4405),
    [sym_integer] = ACTIONS(4403),
    [sym_continue_as_identifier] = ACTIONS(4405),
    [sym_preproc_open] = ACTIONS(4405),
  },
  [STATE(1848)] = {
    [sym_identifier] = ACTIONS(4407),
    [anon_sym_SEMI] = ACTIONS(4409),
    [anon_sym_DASH] = ACTIONS(4409),
    [aux_sym_boolean_token1] = ACTIONS(4407),
    [aux_sym_boolean_token2] = ACTIONS(4407),
    [sym_decimal] = ACTIONS(4407),
    [anon_sym_LPAREN] = ACTIONS(4409),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4407),
    [anon_sym_LBRACK] = ACTIONS(4409),
    [aux_sym_record_type_token1] = ACTIONS(4407),
    [aux_sym_basic_type_token21] = ACTIONS(4407),
    [aux_sym_basic_type_token22] = ACTIONS(4407),
    [aux_sym_basic_type_token48] = ACTIONS(4407),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4407),
    [anon_sym_POUNDif] = ACTIONS(4409),
    [anon_sym_POUNDIF] = ACTIONS(4409),
    [anon_sym_POUNDIf] = ACTIONS(4409),
    [anon_sym_not] = ACTIONS(4407),
    [anon_sym_NOT] = ACTIONS(4407),
    [anon_sym_Not] = ACTIONS(4407),
    [anon_sym_POUNDelse] = ACTIONS(4409),
    [anon_sym_POUNDELSE] = ACTIONS(4409),
    [anon_sym_POUNDElse] = ACTIONS(4409),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4407),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4407),
    [anon_sym_PLUS] = ACTIONS(4409),
    [sym_datetime_literal] = ACTIONS(4409),
    [sym_date_literal] = ACTIONS(4407),
    [sym_time_literal] = ACTIONS(4407),
    [sym_biginteger_literal] = ACTIONS(4409),
    [anon_sym_if] = ACTIONS(4407),
    [anon_sym_IF] = ACTIONS(4407),
    [anon_sym_If] = ACTIONS(4407),
    [anon_sym_else] = ACTIONS(4407),
    [anon_sym_ELSE] = ACTIONS(4407),
    [anon_sym_Else] = ACTIONS(4407),
    [anon_sym_case] = ACTIONS(4407),
    [anon_sym_CASE] = ACTIONS(4407),
    [anon_sym_Case] = ACTIONS(4407),
    [anon_sym_for] = ACTIONS(4407),
    [anon_sym_FOR] = ACTIONS(4407),
    [anon_sym_For] = ACTIONS(4407),
    [anon_sym_foreach] = ACTIONS(4407),
    [anon_sym_FOREACH] = ACTIONS(4407),
    [anon_sym_Foreach] = ACTIONS(4407),
    [anon_sym_while] = ACTIONS(4407),
    [anon_sym_WHILE] = ACTIONS(4407),
    [anon_sym_While] = ACTIONS(4407),
    [anon_sym_repeat] = ACTIONS(4407),
    [anon_sym_REPEAT] = ACTIONS(4407),
    [anon_sym_Repeat] = ACTIONS(4407),
    [anon_sym_until] = ACTIONS(4407),
    [anon_sym_UNTIL] = ACTIONS(4407),
    [anon_sym_Until] = ACTIONS(4407),
    [anon_sym_exit] = ACTIONS(4407),
    [anon_sym_EXIT] = ACTIONS(4407),
    [anon_sym_Exit] = ACTIONS(4407),
    [anon_sym_continue] = ACTIONS(4407),
    [anon_sym_CONTINUE] = ACTIONS(4407),
    [anon_sym_Continue] = ACTIONS(4407),
    [anon_sym_break] = ACTIONS(4407),
    [anon_sym_BREAK] = ACTIONS(4407),
    [anon_sym_Break] = ACTIONS(4407),
    [anon_sym_with] = ACTIONS(4407),
    [anon_sym_WITH] = ACTIONS(4407),
    [anon_sym_With] = ACTIONS(4407),
    [sym_asserterror_keyword] = ACTIONS(4409),
    [sym_page_keyword] = ACTIONS(4407),
    [anon_sym_codeunit] = ACTIONS(4407),
    [anon_sym_CODEUNIT] = ACTIONS(4407),
    [anon_sym_Codeunit] = ACTIONS(4407),
    [anon_sym_CodeUnit] = ACTIONS(4407),
    [anon_sym_COdeunit] = ACTIONS(4407),
    [anon_sym_codeUnit] = ACTIONS(4407),
    [sym_report_keyword] = ACTIONS(4407),
    [sym_query_keyword] = ACTIONS(4407),
    [anon_sym_xmlport] = ACTIONS(4407),
    [anon_sym_XMLPORT] = ACTIONS(4407),
    [anon_sym_Xmlport] = ACTIONS(4407),
    [anon_sym_XMLport] = ACTIONS(4407),
    [anon_sym_XMLPort] = ACTIONS(4407),
    [anon_sym_XmlPort] = ACTIONS(4407),
    [anon_sym_enum] = ACTIONS(4407),
    [anon_sym_ENUM] = ACTIONS(4407),
    [anon_sym_Enum] = ACTIONS(4407),
    [anon_sym_eNUM] = ACTIONS(4407),
    [anon_sym_eNum] = ACTIONS(4407),
    [anon_sym_ENum] = ACTIONS(4407),
    [sym_quoted_identifier] = ACTIONS(4409),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4409),
    [sym_integer] = ACTIONS(4407),
    [sym_continue_as_identifier] = ACTIONS(4409),
    [sym_preproc_open] = ACTIONS(4409),
  },
  [STATE(1849)] = {
    [sym_identifier] = ACTIONS(4411),
    [anon_sym_SEMI] = ACTIONS(4413),
    [anon_sym_DASH] = ACTIONS(4413),
    [aux_sym_boolean_token1] = ACTIONS(4411),
    [aux_sym_boolean_token2] = ACTIONS(4411),
    [sym_decimal] = ACTIONS(4411),
    [anon_sym_LPAREN] = ACTIONS(4413),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4411),
    [anon_sym_LBRACK] = ACTIONS(4413),
    [aux_sym_record_type_token1] = ACTIONS(4411),
    [aux_sym_basic_type_token21] = ACTIONS(4411),
    [aux_sym_basic_type_token22] = ACTIONS(4411),
    [aux_sym_basic_type_token48] = ACTIONS(4411),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4411),
    [anon_sym_POUNDif] = ACTIONS(4413),
    [anon_sym_POUNDIF] = ACTIONS(4413),
    [anon_sym_POUNDIf] = ACTIONS(4413),
    [anon_sym_not] = ACTIONS(4411),
    [anon_sym_NOT] = ACTIONS(4411),
    [anon_sym_Not] = ACTIONS(4411),
    [anon_sym_POUNDelse] = ACTIONS(4413),
    [anon_sym_POUNDELSE] = ACTIONS(4413),
    [anon_sym_POUNDElse] = ACTIONS(4413),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4411),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4411),
    [anon_sym_PLUS] = ACTIONS(4413),
    [sym_datetime_literal] = ACTIONS(4413),
    [sym_date_literal] = ACTIONS(4411),
    [sym_time_literal] = ACTIONS(4411),
    [sym_biginteger_literal] = ACTIONS(4413),
    [anon_sym_if] = ACTIONS(4411),
    [anon_sym_IF] = ACTIONS(4411),
    [anon_sym_If] = ACTIONS(4411),
    [anon_sym_else] = ACTIONS(4411),
    [anon_sym_ELSE] = ACTIONS(4411),
    [anon_sym_Else] = ACTIONS(4411),
    [anon_sym_case] = ACTIONS(4411),
    [anon_sym_CASE] = ACTIONS(4411),
    [anon_sym_Case] = ACTIONS(4411),
    [anon_sym_for] = ACTIONS(4411),
    [anon_sym_FOR] = ACTIONS(4411),
    [anon_sym_For] = ACTIONS(4411),
    [anon_sym_foreach] = ACTIONS(4411),
    [anon_sym_FOREACH] = ACTIONS(4411),
    [anon_sym_Foreach] = ACTIONS(4411),
    [anon_sym_while] = ACTIONS(4411),
    [anon_sym_WHILE] = ACTIONS(4411),
    [anon_sym_While] = ACTIONS(4411),
    [anon_sym_repeat] = ACTIONS(4411),
    [anon_sym_REPEAT] = ACTIONS(4411),
    [anon_sym_Repeat] = ACTIONS(4411),
    [anon_sym_until] = ACTIONS(4411),
    [anon_sym_UNTIL] = ACTIONS(4411),
    [anon_sym_Until] = ACTIONS(4411),
    [anon_sym_exit] = ACTIONS(4411),
    [anon_sym_EXIT] = ACTIONS(4411),
    [anon_sym_Exit] = ACTIONS(4411),
    [anon_sym_continue] = ACTIONS(4411),
    [anon_sym_CONTINUE] = ACTIONS(4411),
    [anon_sym_Continue] = ACTIONS(4411),
    [anon_sym_break] = ACTIONS(4411),
    [anon_sym_BREAK] = ACTIONS(4411),
    [anon_sym_Break] = ACTIONS(4411),
    [anon_sym_with] = ACTIONS(4411),
    [anon_sym_WITH] = ACTIONS(4411),
    [anon_sym_With] = ACTIONS(4411),
    [sym_asserterror_keyword] = ACTIONS(4413),
    [sym_page_keyword] = ACTIONS(4411),
    [anon_sym_codeunit] = ACTIONS(4411),
    [anon_sym_CODEUNIT] = ACTIONS(4411),
    [anon_sym_Codeunit] = ACTIONS(4411),
    [anon_sym_CodeUnit] = ACTIONS(4411),
    [anon_sym_COdeunit] = ACTIONS(4411),
    [anon_sym_codeUnit] = ACTIONS(4411),
    [sym_report_keyword] = ACTIONS(4411),
    [sym_query_keyword] = ACTIONS(4411),
    [anon_sym_xmlport] = ACTIONS(4411),
    [anon_sym_XMLPORT] = ACTIONS(4411),
    [anon_sym_Xmlport] = ACTIONS(4411),
    [anon_sym_XMLport] = ACTIONS(4411),
    [anon_sym_XMLPort] = ACTIONS(4411),
    [anon_sym_XmlPort] = ACTIONS(4411),
    [anon_sym_enum] = ACTIONS(4411),
    [anon_sym_ENUM] = ACTIONS(4411),
    [anon_sym_Enum] = ACTIONS(4411),
    [anon_sym_eNUM] = ACTIONS(4411),
    [anon_sym_eNum] = ACTIONS(4411),
    [anon_sym_ENum] = ACTIONS(4411),
    [sym_quoted_identifier] = ACTIONS(4413),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4413),
    [sym_integer] = ACTIONS(4411),
    [sym_continue_as_identifier] = ACTIONS(4413),
    [sym_preproc_open] = ACTIONS(4413),
  },
  [STATE(1850)] = {
    [sym_identifier] = ACTIONS(4415),
    [anon_sym_SEMI] = ACTIONS(4417),
    [anon_sym_DASH] = ACTIONS(4417),
    [aux_sym_boolean_token1] = ACTIONS(4415),
    [aux_sym_boolean_token2] = ACTIONS(4415),
    [sym_decimal] = ACTIONS(4415),
    [anon_sym_LPAREN] = ACTIONS(4417),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4415),
    [anon_sym_LBRACK] = ACTIONS(4417),
    [aux_sym_record_type_token1] = ACTIONS(4415),
    [aux_sym_basic_type_token21] = ACTIONS(4415),
    [aux_sym_basic_type_token22] = ACTIONS(4415),
    [aux_sym_basic_type_token48] = ACTIONS(4415),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4415),
    [anon_sym_POUNDif] = ACTIONS(4417),
    [anon_sym_POUNDIF] = ACTIONS(4417),
    [anon_sym_POUNDIf] = ACTIONS(4417),
    [anon_sym_not] = ACTIONS(4415),
    [anon_sym_NOT] = ACTIONS(4415),
    [anon_sym_Not] = ACTIONS(4415),
    [anon_sym_POUNDelse] = ACTIONS(4417),
    [anon_sym_POUNDELSE] = ACTIONS(4417),
    [anon_sym_POUNDElse] = ACTIONS(4417),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4415),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4415),
    [anon_sym_PLUS] = ACTIONS(4417),
    [sym_datetime_literal] = ACTIONS(4417),
    [sym_date_literal] = ACTIONS(4415),
    [sym_time_literal] = ACTIONS(4415),
    [sym_biginteger_literal] = ACTIONS(4417),
    [anon_sym_if] = ACTIONS(4415),
    [anon_sym_IF] = ACTIONS(4415),
    [anon_sym_If] = ACTIONS(4415),
    [anon_sym_else] = ACTIONS(4415),
    [anon_sym_ELSE] = ACTIONS(4415),
    [anon_sym_Else] = ACTIONS(4415),
    [anon_sym_case] = ACTIONS(4415),
    [anon_sym_CASE] = ACTIONS(4415),
    [anon_sym_Case] = ACTIONS(4415),
    [anon_sym_for] = ACTIONS(4415),
    [anon_sym_FOR] = ACTIONS(4415),
    [anon_sym_For] = ACTIONS(4415),
    [anon_sym_foreach] = ACTIONS(4415),
    [anon_sym_FOREACH] = ACTIONS(4415),
    [anon_sym_Foreach] = ACTIONS(4415),
    [anon_sym_while] = ACTIONS(4415),
    [anon_sym_WHILE] = ACTIONS(4415),
    [anon_sym_While] = ACTIONS(4415),
    [anon_sym_repeat] = ACTIONS(4415),
    [anon_sym_REPEAT] = ACTIONS(4415),
    [anon_sym_Repeat] = ACTIONS(4415),
    [anon_sym_until] = ACTIONS(4415),
    [anon_sym_UNTIL] = ACTIONS(4415),
    [anon_sym_Until] = ACTIONS(4415),
    [anon_sym_exit] = ACTIONS(4415),
    [anon_sym_EXIT] = ACTIONS(4415),
    [anon_sym_Exit] = ACTIONS(4415),
    [anon_sym_continue] = ACTIONS(4415),
    [anon_sym_CONTINUE] = ACTIONS(4415),
    [anon_sym_Continue] = ACTIONS(4415),
    [anon_sym_break] = ACTIONS(4415),
    [anon_sym_BREAK] = ACTIONS(4415),
    [anon_sym_Break] = ACTIONS(4415),
    [anon_sym_with] = ACTIONS(4415),
    [anon_sym_WITH] = ACTIONS(4415),
    [anon_sym_With] = ACTIONS(4415),
    [sym_asserterror_keyword] = ACTIONS(4417),
    [sym_page_keyword] = ACTIONS(4415),
    [anon_sym_codeunit] = ACTIONS(4415),
    [anon_sym_CODEUNIT] = ACTIONS(4415),
    [anon_sym_Codeunit] = ACTIONS(4415),
    [anon_sym_CodeUnit] = ACTIONS(4415),
    [anon_sym_COdeunit] = ACTIONS(4415),
    [anon_sym_codeUnit] = ACTIONS(4415),
    [sym_report_keyword] = ACTIONS(4415),
    [sym_query_keyword] = ACTIONS(4415),
    [anon_sym_xmlport] = ACTIONS(4415),
    [anon_sym_XMLPORT] = ACTIONS(4415),
    [anon_sym_Xmlport] = ACTIONS(4415),
    [anon_sym_XMLport] = ACTIONS(4415),
    [anon_sym_XMLPort] = ACTIONS(4415),
    [anon_sym_XmlPort] = ACTIONS(4415),
    [anon_sym_enum] = ACTIONS(4415),
    [anon_sym_ENUM] = ACTIONS(4415),
    [anon_sym_Enum] = ACTIONS(4415),
    [anon_sym_eNUM] = ACTIONS(4415),
    [anon_sym_eNum] = ACTIONS(4415),
    [anon_sym_ENum] = ACTIONS(4415),
    [sym_quoted_identifier] = ACTIONS(4417),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4417),
    [sym_integer] = ACTIONS(4415),
    [sym_continue_as_identifier] = ACTIONS(4417),
    [sym_preproc_open] = ACTIONS(4417),
  },
  [STATE(1851)] = {
    [sym_identifier] = ACTIONS(4419),
    [anon_sym_SEMI] = ACTIONS(4421),
    [anon_sym_DASH] = ACTIONS(4421),
    [aux_sym_boolean_token1] = ACTIONS(4419),
    [aux_sym_boolean_token2] = ACTIONS(4419),
    [sym_decimal] = ACTIONS(4419),
    [anon_sym_LPAREN] = ACTIONS(4421),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4419),
    [anon_sym_LBRACK] = ACTIONS(4421),
    [aux_sym_record_type_token1] = ACTIONS(4419),
    [aux_sym_basic_type_token21] = ACTIONS(4419),
    [aux_sym_basic_type_token22] = ACTIONS(4419),
    [aux_sym_basic_type_token48] = ACTIONS(4419),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4419),
    [anon_sym_POUNDif] = ACTIONS(4421),
    [anon_sym_POUNDIF] = ACTIONS(4421),
    [anon_sym_POUNDIf] = ACTIONS(4421),
    [anon_sym_not] = ACTIONS(4419),
    [anon_sym_NOT] = ACTIONS(4419),
    [anon_sym_Not] = ACTIONS(4419),
    [anon_sym_POUNDelse] = ACTIONS(4421),
    [anon_sym_POUNDELSE] = ACTIONS(4421),
    [anon_sym_POUNDElse] = ACTIONS(4421),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4419),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4419),
    [anon_sym_PLUS] = ACTIONS(4421),
    [sym_datetime_literal] = ACTIONS(4421),
    [sym_date_literal] = ACTIONS(4419),
    [sym_time_literal] = ACTIONS(4419),
    [sym_biginteger_literal] = ACTIONS(4421),
    [anon_sym_if] = ACTIONS(4419),
    [anon_sym_IF] = ACTIONS(4419),
    [anon_sym_If] = ACTIONS(4419),
    [anon_sym_else] = ACTIONS(4419),
    [anon_sym_ELSE] = ACTIONS(4419),
    [anon_sym_Else] = ACTIONS(4419),
    [anon_sym_case] = ACTIONS(4419),
    [anon_sym_CASE] = ACTIONS(4419),
    [anon_sym_Case] = ACTIONS(4419),
    [anon_sym_for] = ACTIONS(4419),
    [anon_sym_FOR] = ACTIONS(4419),
    [anon_sym_For] = ACTIONS(4419),
    [anon_sym_foreach] = ACTIONS(4419),
    [anon_sym_FOREACH] = ACTIONS(4419),
    [anon_sym_Foreach] = ACTIONS(4419),
    [anon_sym_while] = ACTIONS(4419),
    [anon_sym_WHILE] = ACTIONS(4419),
    [anon_sym_While] = ACTIONS(4419),
    [anon_sym_repeat] = ACTIONS(4419),
    [anon_sym_REPEAT] = ACTIONS(4419),
    [anon_sym_Repeat] = ACTIONS(4419),
    [anon_sym_until] = ACTIONS(4419),
    [anon_sym_UNTIL] = ACTIONS(4419),
    [anon_sym_Until] = ACTIONS(4419),
    [anon_sym_exit] = ACTIONS(4419),
    [anon_sym_EXIT] = ACTIONS(4419),
    [anon_sym_Exit] = ACTIONS(4419),
    [anon_sym_continue] = ACTIONS(4419),
    [anon_sym_CONTINUE] = ACTIONS(4419),
    [anon_sym_Continue] = ACTIONS(4419),
    [anon_sym_break] = ACTIONS(4419),
    [anon_sym_BREAK] = ACTIONS(4419),
    [anon_sym_Break] = ACTIONS(4419),
    [anon_sym_with] = ACTIONS(4419),
    [anon_sym_WITH] = ACTIONS(4419),
    [anon_sym_With] = ACTIONS(4419),
    [sym_asserterror_keyword] = ACTIONS(4421),
    [sym_page_keyword] = ACTIONS(4419),
    [anon_sym_codeunit] = ACTIONS(4419),
    [anon_sym_CODEUNIT] = ACTIONS(4419),
    [anon_sym_Codeunit] = ACTIONS(4419),
    [anon_sym_CodeUnit] = ACTIONS(4419),
    [anon_sym_COdeunit] = ACTIONS(4419),
    [anon_sym_codeUnit] = ACTIONS(4419),
    [sym_report_keyword] = ACTIONS(4419),
    [sym_query_keyword] = ACTIONS(4419),
    [anon_sym_xmlport] = ACTIONS(4419),
    [anon_sym_XMLPORT] = ACTIONS(4419),
    [anon_sym_Xmlport] = ACTIONS(4419),
    [anon_sym_XMLport] = ACTIONS(4419),
    [anon_sym_XMLPort] = ACTIONS(4419),
    [anon_sym_XmlPort] = ACTIONS(4419),
    [anon_sym_enum] = ACTIONS(4419),
    [anon_sym_ENUM] = ACTIONS(4419),
    [anon_sym_Enum] = ACTIONS(4419),
    [anon_sym_eNUM] = ACTIONS(4419),
    [anon_sym_eNum] = ACTIONS(4419),
    [anon_sym_ENum] = ACTIONS(4419),
    [sym_quoted_identifier] = ACTIONS(4421),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4421),
    [sym_integer] = ACTIONS(4419),
    [sym_continue_as_identifier] = ACTIONS(4421),
    [sym_preproc_open] = ACTIONS(4421),
  },
  [STATE(1852)] = {
    [sym_identifier] = ACTIONS(4423),
    [anon_sym_SEMI] = ACTIONS(4425),
    [anon_sym_DASH] = ACTIONS(4425),
    [aux_sym_boolean_token1] = ACTIONS(4423),
    [aux_sym_boolean_token2] = ACTIONS(4423),
    [sym_decimal] = ACTIONS(4423),
    [anon_sym_LPAREN] = ACTIONS(4425),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4423),
    [anon_sym_LBRACK] = ACTIONS(4425),
    [aux_sym_record_type_token1] = ACTIONS(4423),
    [aux_sym_basic_type_token21] = ACTIONS(4423),
    [aux_sym_basic_type_token22] = ACTIONS(4423),
    [aux_sym_basic_type_token48] = ACTIONS(4423),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4423),
    [anon_sym_POUNDif] = ACTIONS(4425),
    [anon_sym_POUNDIF] = ACTIONS(4425),
    [anon_sym_POUNDIf] = ACTIONS(4425),
    [anon_sym_not] = ACTIONS(4423),
    [anon_sym_NOT] = ACTIONS(4423),
    [anon_sym_Not] = ACTIONS(4423),
    [anon_sym_POUNDelse] = ACTIONS(4425),
    [anon_sym_POUNDELSE] = ACTIONS(4425),
    [anon_sym_POUNDElse] = ACTIONS(4425),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4423),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4423),
    [anon_sym_PLUS] = ACTIONS(4425),
    [sym_datetime_literal] = ACTIONS(4425),
    [sym_date_literal] = ACTIONS(4423),
    [sym_time_literal] = ACTIONS(4423),
    [sym_biginteger_literal] = ACTIONS(4425),
    [anon_sym_if] = ACTIONS(4423),
    [anon_sym_IF] = ACTIONS(4423),
    [anon_sym_If] = ACTIONS(4423),
    [anon_sym_else] = ACTIONS(4423),
    [anon_sym_ELSE] = ACTIONS(4423),
    [anon_sym_Else] = ACTIONS(4423),
    [anon_sym_case] = ACTIONS(4423),
    [anon_sym_CASE] = ACTIONS(4423),
    [anon_sym_Case] = ACTIONS(4423),
    [anon_sym_for] = ACTIONS(4423),
    [anon_sym_FOR] = ACTIONS(4423),
    [anon_sym_For] = ACTIONS(4423),
    [anon_sym_foreach] = ACTIONS(4423),
    [anon_sym_FOREACH] = ACTIONS(4423),
    [anon_sym_Foreach] = ACTIONS(4423),
    [anon_sym_while] = ACTIONS(4423),
    [anon_sym_WHILE] = ACTIONS(4423),
    [anon_sym_While] = ACTIONS(4423),
    [anon_sym_repeat] = ACTIONS(4423),
    [anon_sym_REPEAT] = ACTIONS(4423),
    [anon_sym_Repeat] = ACTIONS(4423),
    [anon_sym_until] = ACTIONS(4423),
    [anon_sym_UNTIL] = ACTIONS(4423),
    [anon_sym_Until] = ACTIONS(4423),
    [anon_sym_exit] = ACTIONS(4423),
    [anon_sym_EXIT] = ACTIONS(4423),
    [anon_sym_Exit] = ACTIONS(4423),
    [anon_sym_continue] = ACTIONS(4423),
    [anon_sym_CONTINUE] = ACTIONS(4423),
    [anon_sym_Continue] = ACTIONS(4423),
    [anon_sym_break] = ACTIONS(4423),
    [anon_sym_BREAK] = ACTIONS(4423),
    [anon_sym_Break] = ACTIONS(4423),
    [anon_sym_with] = ACTIONS(4423),
    [anon_sym_WITH] = ACTIONS(4423),
    [anon_sym_With] = ACTIONS(4423),
    [sym_asserterror_keyword] = ACTIONS(4425),
    [sym_page_keyword] = ACTIONS(4423),
    [anon_sym_codeunit] = ACTIONS(4423),
    [anon_sym_CODEUNIT] = ACTIONS(4423),
    [anon_sym_Codeunit] = ACTIONS(4423),
    [anon_sym_CodeUnit] = ACTIONS(4423),
    [anon_sym_COdeunit] = ACTIONS(4423),
    [anon_sym_codeUnit] = ACTIONS(4423),
    [sym_report_keyword] = ACTIONS(4423),
    [sym_query_keyword] = ACTIONS(4423),
    [anon_sym_xmlport] = ACTIONS(4423),
    [anon_sym_XMLPORT] = ACTIONS(4423),
    [anon_sym_Xmlport] = ACTIONS(4423),
    [anon_sym_XMLport] = ACTIONS(4423),
    [anon_sym_XMLPort] = ACTIONS(4423),
    [anon_sym_XmlPort] = ACTIONS(4423),
    [anon_sym_enum] = ACTIONS(4423),
    [anon_sym_ENUM] = ACTIONS(4423),
    [anon_sym_Enum] = ACTIONS(4423),
    [anon_sym_eNUM] = ACTIONS(4423),
    [anon_sym_eNum] = ACTIONS(4423),
    [anon_sym_ENum] = ACTIONS(4423),
    [sym_quoted_identifier] = ACTIONS(4425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4425),
    [sym_integer] = ACTIONS(4423),
    [sym_continue_as_identifier] = ACTIONS(4425),
    [sym_preproc_open] = ACTIONS(4425),
  },
  [STATE(1853)] = {
    [sym_identifier] = ACTIONS(4427),
    [anon_sym_SEMI] = ACTIONS(4429),
    [anon_sym_DASH] = ACTIONS(4429),
    [aux_sym_boolean_token1] = ACTIONS(4427),
    [aux_sym_boolean_token2] = ACTIONS(4427),
    [sym_decimal] = ACTIONS(4427),
    [anon_sym_LPAREN] = ACTIONS(4429),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4427),
    [anon_sym_LBRACK] = ACTIONS(4429),
    [aux_sym_record_type_token1] = ACTIONS(4427),
    [aux_sym_basic_type_token21] = ACTIONS(4427),
    [aux_sym_basic_type_token22] = ACTIONS(4427),
    [aux_sym_basic_type_token48] = ACTIONS(4427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4427),
    [anon_sym_POUNDif] = ACTIONS(4429),
    [anon_sym_POUNDIF] = ACTIONS(4429),
    [anon_sym_POUNDIf] = ACTIONS(4429),
    [anon_sym_not] = ACTIONS(4427),
    [anon_sym_NOT] = ACTIONS(4427),
    [anon_sym_Not] = ACTIONS(4427),
    [anon_sym_POUNDelse] = ACTIONS(4429),
    [anon_sym_POUNDELSE] = ACTIONS(4429),
    [anon_sym_POUNDElse] = ACTIONS(4429),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4427),
    [anon_sym_PLUS] = ACTIONS(4429),
    [sym_datetime_literal] = ACTIONS(4429),
    [sym_date_literal] = ACTIONS(4427),
    [sym_time_literal] = ACTIONS(4427),
    [sym_biginteger_literal] = ACTIONS(4429),
    [anon_sym_if] = ACTIONS(4427),
    [anon_sym_IF] = ACTIONS(4427),
    [anon_sym_If] = ACTIONS(4427),
    [anon_sym_else] = ACTIONS(4427),
    [anon_sym_ELSE] = ACTIONS(4427),
    [anon_sym_Else] = ACTIONS(4427),
    [anon_sym_case] = ACTIONS(4427),
    [anon_sym_CASE] = ACTIONS(4427),
    [anon_sym_Case] = ACTIONS(4427),
    [anon_sym_for] = ACTIONS(4427),
    [anon_sym_FOR] = ACTIONS(4427),
    [anon_sym_For] = ACTIONS(4427),
    [anon_sym_foreach] = ACTIONS(4427),
    [anon_sym_FOREACH] = ACTIONS(4427),
    [anon_sym_Foreach] = ACTIONS(4427),
    [anon_sym_while] = ACTIONS(4427),
    [anon_sym_WHILE] = ACTIONS(4427),
    [anon_sym_While] = ACTIONS(4427),
    [anon_sym_repeat] = ACTIONS(4427),
    [anon_sym_REPEAT] = ACTIONS(4427),
    [anon_sym_Repeat] = ACTIONS(4427),
    [anon_sym_until] = ACTIONS(4427),
    [anon_sym_UNTIL] = ACTIONS(4427),
    [anon_sym_Until] = ACTIONS(4427),
    [anon_sym_exit] = ACTIONS(4427),
    [anon_sym_EXIT] = ACTIONS(4427),
    [anon_sym_Exit] = ACTIONS(4427),
    [anon_sym_continue] = ACTIONS(4427),
    [anon_sym_CONTINUE] = ACTIONS(4427),
    [anon_sym_Continue] = ACTIONS(4427),
    [anon_sym_break] = ACTIONS(4427),
    [anon_sym_BREAK] = ACTIONS(4427),
    [anon_sym_Break] = ACTIONS(4427),
    [anon_sym_with] = ACTIONS(4427),
    [anon_sym_WITH] = ACTIONS(4427),
    [anon_sym_With] = ACTIONS(4427),
    [sym_asserterror_keyword] = ACTIONS(4429),
    [sym_page_keyword] = ACTIONS(4427),
    [anon_sym_codeunit] = ACTIONS(4427),
    [anon_sym_CODEUNIT] = ACTIONS(4427),
    [anon_sym_Codeunit] = ACTIONS(4427),
    [anon_sym_CodeUnit] = ACTIONS(4427),
    [anon_sym_COdeunit] = ACTIONS(4427),
    [anon_sym_codeUnit] = ACTIONS(4427),
    [sym_report_keyword] = ACTIONS(4427),
    [sym_query_keyword] = ACTIONS(4427),
    [anon_sym_xmlport] = ACTIONS(4427),
    [anon_sym_XMLPORT] = ACTIONS(4427),
    [anon_sym_Xmlport] = ACTIONS(4427),
    [anon_sym_XMLport] = ACTIONS(4427),
    [anon_sym_XMLPort] = ACTIONS(4427),
    [anon_sym_XmlPort] = ACTIONS(4427),
    [anon_sym_enum] = ACTIONS(4427),
    [anon_sym_ENUM] = ACTIONS(4427),
    [anon_sym_Enum] = ACTIONS(4427),
    [anon_sym_eNUM] = ACTIONS(4427),
    [anon_sym_eNum] = ACTIONS(4427),
    [anon_sym_ENum] = ACTIONS(4427),
    [sym_quoted_identifier] = ACTIONS(4429),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4429),
    [sym_integer] = ACTIONS(4427),
    [sym_continue_as_identifier] = ACTIONS(4429),
    [sym_preproc_open] = ACTIONS(4429),
  },
  [STATE(1854)] = {
    [sym_identifier] = ACTIONS(4431),
    [anon_sym_SEMI] = ACTIONS(4433),
    [anon_sym_DASH] = ACTIONS(4433),
    [aux_sym_boolean_token1] = ACTIONS(4431),
    [aux_sym_boolean_token2] = ACTIONS(4431),
    [sym_decimal] = ACTIONS(4431),
    [anon_sym_LPAREN] = ACTIONS(4433),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4431),
    [anon_sym_LBRACK] = ACTIONS(4433),
    [aux_sym_record_type_token1] = ACTIONS(4431),
    [aux_sym_basic_type_token21] = ACTIONS(4431),
    [aux_sym_basic_type_token22] = ACTIONS(4431),
    [aux_sym_basic_type_token48] = ACTIONS(4431),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4431),
    [anon_sym_POUNDif] = ACTIONS(4433),
    [anon_sym_POUNDIF] = ACTIONS(4433),
    [anon_sym_POUNDIf] = ACTIONS(4433),
    [anon_sym_not] = ACTIONS(4431),
    [anon_sym_NOT] = ACTIONS(4431),
    [anon_sym_Not] = ACTIONS(4431),
    [anon_sym_POUNDelse] = ACTIONS(4433),
    [anon_sym_POUNDELSE] = ACTIONS(4433),
    [anon_sym_POUNDElse] = ACTIONS(4433),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4431),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4431),
    [anon_sym_PLUS] = ACTIONS(4433),
    [sym_datetime_literal] = ACTIONS(4433),
    [sym_date_literal] = ACTIONS(4431),
    [sym_time_literal] = ACTIONS(4431),
    [sym_biginteger_literal] = ACTIONS(4433),
    [anon_sym_if] = ACTIONS(4431),
    [anon_sym_IF] = ACTIONS(4431),
    [anon_sym_If] = ACTIONS(4431),
    [anon_sym_else] = ACTIONS(4431),
    [anon_sym_ELSE] = ACTIONS(4431),
    [anon_sym_Else] = ACTIONS(4431),
    [anon_sym_case] = ACTIONS(4431),
    [anon_sym_CASE] = ACTIONS(4431),
    [anon_sym_Case] = ACTIONS(4431),
    [anon_sym_for] = ACTIONS(4431),
    [anon_sym_FOR] = ACTIONS(4431),
    [anon_sym_For] = ACTIONS(4431),
    [anon_sym_foreach] = ACTIONS(4431),
    [anon_sym_FOREACH] = ACTIONS(4431),
    [anon_sym_Foreach] = ACTIONS(4431),
    [anon_sym_while] = ACTIONS(4431),
    [anon_sym_WHILE] = ACTIONS(4431),
    [anon_sym_While] = ACTIONS(4431),
    [anon_sym_repeat] = ACTIONS(4431),
    [anon_sym_REPEAT] = ACTIONS(4431),
    [anon_sym_Repeat] = ACTIONS(4431),
    [anon_sym_until] = ACTIONS(4431),
    [anon_sym_UNTIL] = ACTIONS(4431),
    [anon_sym_Until] = ACTIONS(4431),
    [anon_sym_exit] = ACTIONS(4431),
    [anon_sym_EXIT] = ACTIONS(4431),
    [anon_sym_Exit] = ACTIONS(4431),
    [anon_sym_continue] = ACTIONS(4431),
    [anon_sym_CONTINUE] = ACTIONS(4431),
    [anon_sym_Continue] = ACTIONS(4431),
    [anon_sym_break] = ACTIONS(4431),
    [anon_sym_BREAK] = ACTIONS(4431),
    [anon_sym_Break] = ACTIONS(4431),
    [anon_sym_with] = ACTIONS(4431),
    [anon_sym_WITH] = ACTIONS(4431),
    [anon_sym_With] = ACTIONS(4431),
    [sym_asserterror_keyword] = ACTIONS(4433),
    [sym_page_keyword] = ACTIONS(4431),
    [anon_sym_codeunit] = ACTIONS(4431),
    [anon_sym_CODEUNIT] = ACTIONS(4431),
    [anon_sym_Codeunit] = ACTIONS(4431),
    [anon_sym_CodeUnit] = ACTIONS(4431),
    [anon_sym_COdeunit] = ACTIONS(4431),
    [anon_sym_codeUnit] = ACTIONS(4431),
    [sym_report_keyword] = ACTIONS(4431),
    [sym_query_keyword] = ACTIONS(4431),
    [anon_sym_xmlport] = ACTIONS(4431),
    [anon_sym_XMLPORT] = ACTIONS(4431),
    [anon_sym_Xmlport] = ACTIONS(4431),
    [anon_sym_XMLport] = ACTIONS(4431),
    [anon_sym_XMLPort] = ACTIONS(4431),
    [anon_sym_XmlPort] = ACTIONS(4431),
    [anon_sym_enum] = ACTIONS(4431),
    [anon_sym_ENUM] = ACTIONS(4431),
    [anon_sym_Enum] = ACTIONS(4431),
    [anon_sym_eNUM] = ACTIONS(4431),
    [anon_sym_eNum] = ACTIONS(4431),
    [anon_sym_ENum] = ACTIONS(4431),
    [sym_quoted_identifier] = ACTIONS(4433),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4433),
    [sym_integer] = ACTIONS(4431),
    [sym_continue_as_identifier] = ACTIONS(4433),
    [sym_preproc_open] = ACTIONS(4433),
  },
  [STATE(1855)] = {
    [sym_identifier] = ACTIONS(4435),
    [anon_sym_SEMI] = ACTIONS(4437),
    [anon_sym_DASH] = ACTIONS(4437),
    [aux_sym_boolean_token1] = ACTIONS(4435),
    [aux_sym_boolean_token2] = ACTIONS(4435),
    [sym_decimal] = ACTIONS(4435),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4435),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [aux_sym_record_type_token1] = ACTIONS(4435),
    [aux_sym_basic_type_token21] = ACTIONS(4435),
    [aux_sym_basic_type_token22] = ACTIONS(4435),
    [aux_sym_basic_type_token48] = ACTIONS(4435),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4435),
    [anon_sym_POUNDif] = ACTIONS(4437),
    [anon_sym_POUNDIF] = ACTIONS(4437),
    [anon_sym_POUNDIf] = ACTIONS(4437),
    [anon_sym_not] = ACTIONS(4435),
    [anon_sym_NOT] = ACTIONS(4435),
    [anon_sym_Not] = ACTIONS(4435),
    [anon_sym_POUNDelse] = ACTIONS(4437),
    [anon_sym_POUNDELSE] = ACTIONS(4437),
    [anon_sym_POUNDElse] = ACTIONS(4437),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4435),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4435),
    [anon_sym_PLUS] = ACTIONS(4437),
    [sym_datetime_literal] = ACTIONS(4437),
    [sym_date_literal] = ACTIONS(4435),
    [sym_time_literal] = ACTIONS(4435),
    [sym_biginteger_literal] = ACTIONS(4437),
    [anon_sym_if] = ACTIONS(4435),
    [anon_sym_IF] = ACTIONS(4435),
    [anon_sym_If] = ACTIONS(4435),
    [anon_sym_else] = ACTIONS(4435),
    [anon_sym_ELSE] = ACTIONS(4435),
    [anon_sym_Else] = ACTIONS(4435),
    [anon_sym_case] = ACTIONS(4435),
    [anon_sym_CASE] = ACTIONS(4435),
    [anon_sym_Case] = ACTIONS(4435),
    [anon_sym_for] = ACTIONS(4435),
    [anon_sym_FOR] = ACTIONS(4435),
    [anon_sym_For] = ACTIONS(4435),
    [anon_sym_foreach] = ACTIONS(4435),
    [anon_sym_FOREACH] = ACTIONS(4435),
    [anon_sym_Foreach] = ACTIONS(4435),
    [anon_sym_while] = ACTIONS(4435),
    [anon_sym_WHILE] = ACTIONS(4435),
    [anon_sym_While] = ACTIONS(4435),
    [anon_sym_repeat] = ACTIONS(4435),
    [anon_sym_REPEAT] = ACTIONS(4435),
    [anon_sym_Repeat] = ACTIONS(4435),
    [anon_sym_until] = ACTIONS(4435),
    [anon_sym_UNTIL] = ACTIONS(4435),
    [anon_sym_Until] = ACTIONS(4435),
    [anon_sym_exit] = ACTIONS(4435),
    [anon_sym_EXIT] = ACTIONS(4435),
    [anon_sym_Exit] = ACTIONS(4435),
    [anon_sym_continue] = ACTIONS(4435),
    [anon_sym_CONTINUE] = ACTIONS(4435),
    [anon_sym_Continue] = ACTIONS(4435),
    [anon_sym_break] = ACTIONS(4435),
    [anon_sym_BREAK] = ACTIONS(4435),
    [anon_sym_Break] = ACTIONS(4435),
    [anon_sym_with] = ACTIONS(4435),
    [anon_sym_WITH] = ACTIONS(4435),
    [anon_sym_With] = ACTIONS(4435),
    [sym_asserterror_keyword] = ACTIONS(4437),
    [sym_page_keyword] = ACTIONS(4435),
    [anon_sym_codeunit] = ACTIONS(4435),
    [anon_sym_CODEUNIT] = ACTIONS(4435),
    [anon_sym_Codeunit] = ACTIONS(4435),
    [anon_sym_CodeUnit] = ACTIONS(4435),
    [anon_sym_COdeunit] = ACTIONS(4435),
    [anon_sym_codeUnit] = ACTIONS(4435),
    [sym_report_keyword] = ACTIONS(4435),
    [sym_query_keyword] = ACTIONS(4435),
    [anon_sym_xmlport] = ACTIONS(4435),
    [anon_sym_XMLPORT] = ACTIONS(4435),
    [anon_sym_Xmlport] = ACTIONS(4435),
    [anon_sym_XMLport] = ACTIONS(4435),
    [anon_sym_XMLPort] = ACTIONS(4435),
    [anon_sym_XmlPort] = ACTIONS(4435),
    [anon_sym_enum] = ACTIONS(4435),
    [anon_sym_ENUM] = ACTIONS(4435),
    [anon_sym_Enum] = ACTIONS(4435),
    [anon_sym_eNUM] = ACTIONS(4435),
    [anon_sym_eNum] = ACTIONS(4435),
    [anon_sym_ENum] = ACTIONS(4435),
    [sym_quoted_identifier] = ACTIONS(4437),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4437),
    [sym_integer] = ACTIONS(4435),
    [sym_continue_as_identifier] = ACTIONS(4437),
    [sym_preproc_open] = ACTIONS(4437),
  },
  [STATE(1856)] = {
    [sym_identifier] = ACTIONS(4439),
    [anon_sym_SEMI] = ACTIONS(4441),
    [anon_sym_DASH] = ACTIONS(4441),
    [aux_sym_boolean_token1] = ACTIONS(4439),
    [aux_sym_boolean_token2] = ACTIONS(4439),
    [sym_decimal] = ACTIONS(4439),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4439),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [aux_sym_record_type_token1] = ACTIONS(4439),
    [aux_sym_basic_type_token21] = ACTIONS(4439),
    [aux_sym_basic_type_token22] = ACTIONS(4439),
    [aux_sym_basic_type_token48] = ACTIONS(4439),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4439),
    [anon_sym_POUNDif] = ACTIONS(4441),
    [anon_sym_POUNDIF] = ACTIONS(4441),
    [anon_sym_POUNDIf] = ACTIONS(4441),
    [anon_sym_not] = ACTIONS(4439),
    [anon_sym_NOT] = ACTIONS(4439),
    [anon_sym_Not] = ACTIONS(4439),
    [anon_sym_POUNDelse] = ACTIONS(4441),
    [anon_sym_POUNDELSE] = ACTIONS(4441),
    [anon_sym_POUNDElse] = ACTIONS(4441),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4439),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4439),
    [anon_sym_PLUS] = ACTIONS(4441),
    [sym_datetime_literal] = ACTIONS(4441),
    [sym_date_literal] = ACTIONS(4439),
    [sym_time_literal] = ACTIONS(4439),
    [sym_biginteger_literal] = ACTIONS(4441),
    [anon_sym_if] = ACTIONS(4439),
    [anon_sym_IF] = ACTIONS(4439),
    [anon_sym_If] = ACTIONS(4439),
    [anon_sym_else] = ACTIONS(4439),
    [anon_sym_ELSE] = ACTIONS(4439),
    [anon_sym_Else] = ACTIONS(4439),
    [anon_sym_case] = ACTIONS(4439),
    [anon_sym_CASE] = ACTIONS(4439),
    [anon_sym_Case] = ACTIONS(4439),
    [anon_sym_for] = ACTIONS(4439),
    [anon_sym_FOR] = ACTIONS(4439),
    [anon_sym_For] = ACTIONS(4439),
    [anon_sym_foreach] = ACTIONS(4439),
    [anon_sym_FOREACH] = ACTIONS(4439),
    [anon_sym_Foreach] = ACTIONS(4439),
    [anon_sym_while] = ACTIONS(4439),
    [anon_sym_WHILE] = ACTIONS(4439),
    [anon_sym_While] = ACTIONS(4439),
    [anon_sym_repeat] = ACTIONS(4439),
    [anon_sym_REPEAT] = ACTIONS(4439),
    [anon_sym_Repeat] = ACTIONS(4439),
    [anon_sym_until] = ACTIONS(4439),
    [anon_sym_UNTIL] = ACTIONS(4439),
    [anon_sym_Until] = ACTIONS(4439),
    [anon_sym_exit] = ACTIONS(4439),
    [anon_sym_EXIT] = ACTIONS(4439),
    [anon_sym_Exit] = ACTIONS(4439),
    [anon_sym_continue] = ACTIONS(4439),
    [anon_sym_CONTINUE] = ACTIONS(4439),
    [anon_sym_Continue] = ACTIONS(4439),
    [anon_sym_break] = ACTIONS(4439),
    [anon_sym_BREAK] = ACTIONS(4439),
    [anon_sym_Break] = ACTIONS(4439),
    [anon_sym_with] = ACTIONS(4439),
    [anon_sym_WITH] = ACTIONS(4439),
    [anon_sym_With] = ACTIONS(4439),
    [sym_asserterror_keyword] = ACTIONS(4441),
    [sym_page_keyword] = ACTIONS(4439),
    [anon_sym_codeunit] = ACTIONS(4439),
    [anon_sym_CODEUNIT] = ACTIONS(4439),
    [anon_sym_Codeunit] = ACTIONS(4439),
    [anon_sym_CodeUnit] = ACTIONS(4439),
    [anon_sym_COdeunit] = ACTIONS(4439),
    [anon_sym_codeUnit] = ACTIONS(4439),
    [sym_report_keyword] = ACTIONS(4439),
    [sym_query_keyword] = ACTIONS(4439),
    [anon_sym_xmlport] = ACTIONS(4439),
    [anon_sym_XMLPORT] = ACTIONS(4439),
    [anon_sym_Xmlport] = ACTIONS(4439),
    [anon_sym_XMLport] = ACTIONS(4439),
    [anon_sym_XMLPort] = ACTIONS(4439),
    [anon_sym_XmlPort] = ACTIONS(4439),
    [anon_sym_enum] = ACTIONS(4439),
    [anon_sym_ENUM] = ACTIONS(4439),
    [anon_sym_Enum] = ACTIONS(4439),
    [anon_sym_eNUM] = ACTIONS(4439),
    [anon_sym_eNum] = ACTIONS(4439),
    [anon_sym_ENum] = ACTIONS(4439),
    [sym_quoted_identifier] = ACTIONS(4441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4441),
    [sym_integer] = ACTIONS(4439),
    [sym_continue_as_identifier] = ACTIONS(4441),
    [sym_preproc_open] = ACTIONS(4441),
  },
  [STATE(1857)] = {
    [sym_identifier] = ACTIONS(4443),
    [anon_sym_SEMI] = ACTIONS(4445),
    [anon_sym_DASH] = ACTIONS(4445),
    [aux_sym_boolean_token1] = ACTIONS(4443),
    [aux_sym_boolean_token2] = ACTIONS(4443),
    [sym_decimal] = ACTIONS(4443),
    [anon_sym_LPAREN] = ACTIONS(4445),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4443),
    [anon_sym_LBRACK] = ACTIONS(4445),
    [aux_sym_record_type_token1] = ACTIONS(4443),
    [aux_sym_basic_type_token21] = ACTIONS(4443),
    [aux_sym_basic_type_token22] = ACTIONS(4443),
    [aux_sym_basic_type_token48] = ACTIONS(4443),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4443),
    [anon_sym_POUNDif] = ACTIONS(4445),
    [anon_sym_POUNDIF] = ACTIONS(4445),
    [anon_sym_POUNDIf] = ACTIONS(4445),
    [anon_sym_not] = ACTIONS(4443),
    [anon_sym_NOT] = ACTIONS(4443),
    [anon_sym_Not] = ACTIONS(4443),
    [anon_sym_POUNDelse] = ACTIONS(4445),
    [anon_sym_POUNDELSE] = ACTIONS(4445),
    [anon_sym_POUNDElse] = ACTIONS(4445),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4443),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4443),
    [anon_sym_PLUS] = ACTIONS(4445),
    [sym_datetime_literal] = ACTIONS(4445),
    [sym_date_literal] = ACTIONS(4443),
    [sym_time_literal] = ACTIONS(4443),
    [sym_biginteger_literal] = ACTIONS(4445),
    [anon_sym_if] = ACTIONS(4443),
    [anon_sym_IF] = ACTIONS(4443),
    [anon_sym_If] = ACTIONS(4443),
    [anon_sym_else] = ACTIONS(4443),
    [anon_sym_ELSE] = ACTIONS(4443),
    [anon_sym_Else] = ACTIONS(4443),
    [anon_sym_case] = ACTIONS(4443),
    [anon_sym_CASE] = ACTIONS(4443),
    [anon_sym_Case] = ACTIONS(4443),
    [anon_sym_for] = ACTIONS(4443),
    [anon_sym_FOR] = ACTIONS(4443),
    [anon_sym_For] = ACTIONS(4443),
    [anon_sym_foreach] = ACTIONS(4443),
    [anon_sym_FOREACH] = ACTIONS(4443),
    [anon_sym_Foreach] = ACTIONS(4443),
    [anon_sym_while] = ACTIONS(4443),
    [anon_sym_WHILE] = ACTIONS(4443),
    [anon_sym_While] = ACTIONS(4443),
    [anon_sym_repeat] = ACTIONS(4443),
    [anon_sym_REPEAT] = ACTIONS(4443),
    [anon_sym_Repeat] = ACTIONS(4443),
    [anon_sym_until] = ACTIONS(4443),
    [anon_sym_UNTIL] = ACTIONS(4443),
    [anon_sym_Until] = ACTIONS(4443),
    [anon_sym_exit] = ACTIONS(4443),
    [anon_sym_EXIT] = ACTIONS(4443),
    [anon_sym_Exit] = ACTIONS(4443),
    [anon_sym_continue] = ACTIONS(4443),
    [anon_sym_CONTINUE] = ACTIONS(4443),
    [anon_sym_Continue] = ACTIONS(4443),
    [anon_sym_break] = ACTIONS(4443),
    [anon_sym_BREAK] = ACTIONS(4443),
    [anon_sym_Break] = ACTIONS(4443),
    [anon_sym_with] = ACTIONS(4443),
    [anon_sym_WITH] = ACTIONS(4443),
    [anon_sym_With] = ACTIONS(4443),
    [sym_asserterror_keyword] = ACTIONS(4445),
    [sym_page_keyword] = ACTIONS(4443),
    [anon_sym_codeunit] = ACTIONS(4443),
    [anon_sym_CODEUNIT] = ACTIONS(4443),
    [anon_sym_Codeunit] = ACTIONS(4443),
    [anon_sym_CodeUnit] = ACTIONS(4443),
    [anon_sym_COdeunit] = ACTIONS(4443),
    [anon_sym_codeUnit] = ACTIONS(4443),
    [sym_report_keyword] = ACTIONS(4443),
    [sym_query_keyword] = ACTIONS(4443),
    [anon_sym_xmlport] = ACTIONS(4443),
    [anon_sym_XMLPORT] = ACTIONS(4443),
    [anon_sym_Xmlport] = ACTIONS(4443),
    [anon_sym_XMLport] = ACTIONS(4443),
    [anon_sym_XMLPort] = ACTIONS(4443),
    [anon_sym_XmlPort] = ACTIONS(4443),
    [anon_sym_enum] = ACTIONS(4443),
    [anon_sym_ENUM] = ACTIONS(4443),
    [anon_sym_Enum] = ACTIONS(4443),
    [anon_sym_eNUM] = ACTIONS(4443),
    [anon_sym_eNum] = ACTIONS(4443),
    [anon_sym_ENum] = ACTIONS(4443),
    [sym_quoted_identifier] = ACTIONS(4445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4445),
    [sym_integer] = ACTIONS(4443),
    [sym_continue_as_identifier] = ACTIONS(4445),
    [sym_preproc_open] = ACTIONS(4445),
  },
  [STATE(1858)] = {
    [sym_identifier] = ACTIONS(4447),
    [anon_sym_SEMI] = ACTIONS(4449),
    [anon_sym_DASH] = ACTIONS(4449),
    [aux_sym_boolean_token1] = ACTIONS(4447),
    [aux_sym_boolean_token2] = ACTIONS(4447),
    [sym_decimal] = ACTIONS(4447),
    [anon_sym_LPAREN] = ACTIONS(4449),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4447),
    [anon_sym_LBRACK] = ACTIONS(4449),
    [aux_sym_record_type_token1] = ACTIONS(4447),
    [aux_sym_basic_type_token21] = ACTIONS(4447),
    [aux_sym_basic_type_token22] = ACTIONS(4447),
    [aux_sym_basic_type_token48] = ACTIONS(4447),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4447),
    [anon_sym_POUNDif] = ACTIONS(4449),
    [anon_sym_POUNDIF] = ACTIONS(4449),
    [anon_sym_POUNDIf] = ACTIONS(4449),
    [anon_sym_not] = ACTIONS(4447),
    [anon_sym_NOT] = ACTIONS(4447),
    [anon_sym_Not] = ACTIONS(4447),
    [anon_sym_POUNDelse] = ACTIONS(4449),
    [anon_sym_POUNDELSE] = ACTIONS(4449),
    [anon_sym_POUNDElse] = ACTIONS(4449),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4447),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4447),
    [anon_sym_PLUS] = ACTIONS(4449),
    [sym_datetime_literal] = ACTIONS(4449),
    [sym_date_literal] = ACTIONS(4447),
    [sym_time_literal] = ACTIONS(4447),
    [sym_biginteger_literal] = ACTIONS(4449),
    [anon_sym_if] = ACTIONS(4447),
    [anon_sym_IF] = ACTIONS(4447),
    [anon_sym_If] = ACTIONS(4447),
    [anon_sym_else] = ACTIONS(4447),
    [anon_sym_ELSE] = ACTIONS(4447),
    [anon_sym_Else] = ACTIONS(4447),
    [anon_sym_case] = ACTIONS(4447),
    [anon_sym_CASE] = ACTIONS(4447),
    [anon_sym_Case] = ACTIONS(4447),
    [anon_sym_for] = ACTIONS(4447),
    [anon_sym_FOR] = ACTIONS(4447),
    [anon_sym_For] = ACTIONS(4447),
    [anon_sym_foreach] = ACTIONS(4447),
    [anon_sym_FOREACH] = ACTIONS(4447),
    [anon_sym_Foreach] = ACTIONS(4447),
    [anon_sym_while] = ACTIONS(4447),
    [anon_sym_WHILE] = ACTIONS(4447),
    [anon_sym_While] = ACTIONS(4447),
    [anon_sym_repeat] = ACTIONS(4447),
    [anon_sym_REPEAT] = ACTIONS(4447),
    [anon_sym_Repeat] = ACTIONS(4447),
    [anon_sym_until] = ACTIONS(4447),
    [anon_sym_UNTIL] = ACTIONS(4447),
    [anon_sym_Until] = ACTIONS(4447),
    [anon_sym_exit] = ACTIONS(4447),
    [anon_sym_EXIT] = ACTIONS(4447),
    [anon_sym_Exit] = ACTIONS(4447),
    [anon_sym_continue] = ACTIONS(4447),
    [anon_sym_CONTINUE] = ACTIONS(4447),
    [anon_sym_Continue] = ACTIONS(4447),
    [anon_sym_break] = ACTIONS(4447),
    [anon_sym_BREAK] = ACTIONS(4447),
    [anon_sym_Break] = ACTIONS(4447),
    [anon_sym_with] = ACTIONS(4447),
    [anon_sym_WITH] = ACTIONS(4447),
    [anon_sym_With] = ACTIONS(4447),
    [sym_asserterror_keyword] = ACTIONS(4449),
    [sym_page_keyword] = ACTIONS(4447),
    [anon_sym_codeunit] = ACTIONS(4447),
    [anon_sym_CODEUNIT] = ACTIONS(4447),
    [anon_sym_Codeunit] = ACTIONS(4447),
    [anon_sym_CodeUnit] = ACTIONS(4447),
    [anon_sym_COdeunit] = ACTIONS(4447),
    [anon_sym_codeUnit] = ACTIONS(4447),
    [sym_report_keyword] = ACTIONS(4447),
    [sym_query_keyword] = ACTIONS(4447),
    [anon_sym_xmlport] = ACTIONS(4447),
    [anon_sym_XMLPORT] = ACTIONS(4447),
    [anon_sym_Xmlport] = ACTIONS(4447),
    [anon_sym_XMLport] = ACTIONS(4447),
    [anon_sym_XMLPort] = ACTIONS(4447),
    [anon_sym_XmlPort] = ACTIONS(4447),
    [anon_sym_enum] = ACTIONS(4447),
    [anon_sym_ENUM] = ACTIONS(4447),
    [anon_sym_Enum] = ACTIONS(4447),
    [anon_sym_eNUM] = ACTIONS(4447),
    [anon_sym_eNum] = ACTIONS(4447),
    [anon_sym_ENum] = ACTIONS(4447),
    [sym_quoted_identifier] = ACTIONS(4449),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4449),
    [sym_integer] = ACTIONS(4447),
    [sym_continue_as_identifier] = ACTIONS(4449),
    [sym_preproc_open] = ACTIONS(4449),
  },
  [STATE(1859)] = {
    [sym_identifier] = ACTIONS(4451),
    [anon_sym_SEMI] = ACTIONS(4453),
    [anon_sym_DASH] = ACTIONS(4453),
    [aux_sym_boolean_token1] = ACTIONS(4451),
    [aux_sym_boolean_token2] = ACTIONS(4451),
    [sym_decimal] = ACTIONS(4451),
    [anon_sym_LPAREN] = ACTIONS(4453),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4451),
    [anon_sym_LBRACK] = ACTIONS(4453),
    [aux_sym_record_type_token1] = ACTIONS(4451),
    [aux_sym_basic_type_token21] = ACTIONS(4451),
    [aux_sym_basic_type_token22] = ACTIONS(4451),
    [aux_sym_basic_type_token48] = ACTIONS(4451),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4451),
    [anon_sym_POUNDif] = ACTIONS(4453),
    [anon_sym_POUNDIF] = ACTIONS(4453),
    [anon_sym_POUNDIf] = ACTIONS(4453),
    [anon_sym_not] = ACTIONS(4451),
    [anon_sym_NOT] = ACTIONS(4451),
    [anon_sym_Not] = ACTIONS(4451),
    [anon_sym_POUNDelse] = ACTIONS(4453),
    [anon_sym_POUNDELSE] = ACTIONS(4453),
    [anon_sym_POUNDElse] = ACTIONS(4453),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4451),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4451),
    [anon_sym_PLUS] = ACTIONS(4453),
    [sym_datetime_literal] = ACTIONS(4453),
    [sym_date_literal] = ACTIONS(4451),
    [sym_time_literal] = ACTIONS(4451),
    [sym_biginteger_literal] = ACTIONS(4453),
    [anon_sym_if] = ACTIONS(4451),
    [anon_sym_IF] = ACTIONS(4451),
    [anon_sym_If] = ACTIONS(4451),
    [anon_sym_else] = ACTIONS(4451),
    [anon_sym_ELSE] = ACTIONS(4451),
    [anon_sym_Else] = ACTIONS(4451),
    [anon_sym_case] = ACTIONS(4451),
    [anon_sym_CASE] = ACTIONS(4451),
    [anon_sym_Case] = ACTIONS(4451),
    [anon_sym_for] = ACTIONS(4451),
    [anon_sym_FOR] = ACTIONS(4451),
    [anon_sym_For] = ACTIONS(4451),
    [anon_sym_foreach] = ACTIONS(4451),
    [anon_sym_FOREACH] = ACTIONS(4451),
    [anon_sym_Foreach] = ACTIONS(4451),
    [anon_sym_while] = ACTIONS(4451),
    [anon_sym_WHILE] = ACTIONS(4451),
    [anon_sym_While] = ACTIONS(4451),
    [anon_sym_repeat] = ACTIONS(4451),
    [anon_sym_REPEAT] = ACTIONS(4451),
    [anon_sym_Repeat] = ACTIONS(4451),
    [anon_sym_until] = ACTIONS(4451),
    [anon_sym_UNTIL] = ACTIONS(4451),
    [anon_sym_Until] = ACTIONS(4451),
    [anon_sym_exit] = ACTIONS(4451),
    [anon_sym_EXIT] = ACTIONS(4451),
    [anon_sym_Exit] = ACTIONS(4451),
    [anon_sym_continue] = ACTIONS(4451),
    [anon_sym_CONTINUE] = ACTIONS(4451),
    [anon_sym_Continue] = ACTIONS(4451),
    [anon_sym_break] = ACTIONS(4451),
    [anon_sym_BREAK] = ACTIONS(4451),
    [anon_sym_Break] = ACTIONS(4451),
    [anon_sym_with] = ACTIONS(4451),
    [anon_sym_WITH] = ACTIONS(4451),
    [anon_sym_With] = ACTIONS(4451),
    [sym_asserterror_keyword] = ACTIONS(4453),
    [sym_page_keyword] = ACTIONS(4451),
    [anon_sym_codeunit] = ACTIONS(4451),
    [anon_sym_CODEUNIT] = ACTIONS(4451),
    [anon_sym_Codeunit] = ACTIONS(4451),
    [anon_sym_CodeUnit] = ACTIONS(4451),
    [anon_sym_COdeunit] = ACTIONS(4451),
    [anon_sym_codeUnit] = ACTIONS(4451),
    [sym_report_keyword] = ACTIONS(4451),
    [sym_query_keyword] = ACTIONS(4451),
    [anon_sym_xmlport] = ACTIONS(4451),
    [anon_sym_XMLPORT] = ACTIONS(4451),
    [anon_sym_Xmlport] = ACTIONS(4451),
    [anon_sym_XMLport] = ACTIONS(4451),
    [anon_sym_XMLPort] = ACTIONS(4451),
    [anon_sym_XmlPort] = ACTIONS(4451),
    [anon_sym_enum] = ACTIONS(4451),
    [anon_sym_ENUM] = ACTIONS(4451),
    [anon_sym_Enum] = ACTIONS(4451),
    [anon_sym_eNUM] = ACTIONS(4451),
    [anon_sym_eNum] = ACTIONS(4451),
    [anon_sym_ENum] = ACTIONS(4451),
    [sym_quoted_identifier] = ACTIONS(4453),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4453),
    [sym_integer] = ACTIONS(4451),
    [sym_continue_as_identifier] = ACTIONS(4453),
    [sym_preproc_open] = ACTIONS(4453),
  },
  [STATE(1860)] = {
    [sym_identifier] = ACTIONS(4455),
    [anon_sym_SEMI] = ACTIONS(4457),
    [anon_sym_DASH] = ACTIONS(4457),
    [aux_sym_boolean_token1] = ACTIONS(4455),
    [aux_sym_boolean_token2] = ACTIONS(4455),
    [sym_decimal] = ACTIONS(4455),
    [anon_sym_LPAREN] = ACTIONS(4457),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4455),
    [anon_sym_LBRACK] = ACTIONS(4457),
    [aux_sym_record_type_token1] = ACTIONS(4455),
    [aux_sym_basic_type_token21] = ACTIONS(4455),
    [aux_sym_basic_type_token22] = ACTIONS(4455),
    [aux_sym_basic_type_token48] = ACTIONS(4455),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(4457),
    [anon_sym_POUNDIF] = ACTIONS(4457),
    [anon_sym_POUNDIf] = ACTIONS(4457),
    [anon_sym_not] = ACTIONS(4455),
    [anon_sym_NOT] = ACTIONS(4455),
    [anon_sym_Not] = ACTIONS(4455),
    [anon_sym_POUNDelse] = ACTIONS(4457),
    [anon_sym_POUNDELSE] = ACTIONS(4457),
    [anon_sym_POUNDElse] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4455),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4455),
    [anon_sym_PLUS] = ACTIONS(4457),
    [sym_datetime_literal] = ACTIONS(4457),
    [sym_date_literal] = ACTIONS(4455),
    [sym_time_literal] = ACTIONS(4455),
    [sym_biginteger_literal] = ACTIONS(4457),
    [anon_sym_if] = ACTIONS(4455),
    [anon_sym_IF] = ACTIONS(4455),
    [anon_sym_If] = ACTIONS(4455),
    [anon_sym_else] = ACTIONS(4455),
    [anon_sym_ELSE] = ACTIONS(4455),
    [anon_sym_Else] = ACTIONS(4455),
    [anon_sym_case] = ACTIONS(4455),
    [anon_sym_CASE] = ACTIONS(4455),
    [anon_sym_Case] = ACTIONS(4455),
    [anon_sym_for] = ACTIONS(4455),
    [anon_sym_FOR] = ACTIONS(4455),
    [anon_sym_For] = ACTIONS(4455),
    [anon_sym_foreach] = ACTIONS(4455),
    [anon_sym_FOREACH] = ACTIONS(4455),
    [anon_sym_Foreach] = ACTIONS(4455),
    [anon_sym_while] = ACTIONS(4455),
    [anon_sym_WHILE] = ACTIONS(4455),
    [anon_sym_While] = ACTIONS(4455),
    [anon_sym_repeat] = ACTIONS(4455),
    [anon_sym_REPEAT] = ACTIONS(4455),
    [anon_sym_Repeat] = ACTIONS(4455),
    [anon_sym_until] = ACTIONS(4455),
    [anon_sym_UNTIL] = ACTIONS(4455),
    [anon_sym_Until] = ACTIONS(4455),
    [anon_sym_exit] = ACTIONS(4455),
    [anon_sym_EXIT] = ACTIONS(4455),
    [anon_sym_Exit] = ACTIONS(4455),
    [anon_sym_continue] = ACTIONS(4455),
    [anon_sym_CONTINUE] = ACTIONS(4455),
    [anon_sym_Continue] = ACTIONS(4455),
    [anon_sym_break] = ACTIONS(4455),
    [anon_sym_BREAK] = ACTIONS(4455),
    [anon_sym_Break] = ACTIONS(4455),
    [anon_sym_with] = ACTIONS(4455),
    [anon_sym_WITH] = ACTIONS(4455),
    [anon_sym_With] = ACTIONS(4455),
    [sym_asserterror_keyword] = ACTIONS(4457),
    [sym_page_keyword] = ACTIONS(4455),
    [anon_sym_codeunit] = ACTIONS(4455),
    [anon_sym_CODEUNIT] = ACTIONS(4455),
    [anon_sym_Codeunit] = ACTIONS(4455),
    [anon_sym_CodeUnit] = ACTIONS(4455),
    [anon_sym_COdeunit] = ACTIONS(4455),
    [anon_sym_codeUnit] = ACTIONS(4455),
    [sym_report_keyword] = ACTIONS(4455),
    [sym_query_keyword] = ACTIONS(4455),
    [anon_sym_xmlport] = ACTIONS(4455),
    [anon_sym_XMLPORT] = ACTIONS(4455),
    [anon_sym_Xmlport] = ACTIONS(4455),
    [anon_sym_XMLport] = ACTIONS(4455),
    [anon_sym_XMLPort] = ACTIONS(4455),
    [anon_sym_XmlPort] = ACTIONS(4455),
    [anon_sym_enum] = ACTIONS(4455),
    [anon_sym_ENUM] = ACTIONS(4455),
    [anon_sym_Enum] = ACTIONS(4455),
    [anon_sym_eNUM] = ACTIONS(4455),
    [anon_sym_eNum] = ACTIONS(4455),
    [anon_sym_ENum] = ACTIONS(4455),
    [sym_quoted_identifier] = ACTIONS(4457),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4457),
    [sym_integer] = ACTIONS(4455),
    [sym_continue_as_identifier] = ACTIONS(4457),
    [sym_preproc_open] = ACTIONS(4457),
  },
  [STATE(1861)] = {
    [sym_identifier] = ACTIONS(4285),
    [anon_sym_SEMI] = ACTIONS(4287),
    [anon_sym_DASH] = ACTIONS(4287),
    [aux_sym_boolean_token1] = ACTIONS(4285),
    [aux_sym_boolean_token2] = ACTIONS(4285),
    [sym_decimal] = ACTIONS(4285),
    [anon_sym_LPAREN] = ACTIONS(4287),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4285),
    [anon_sym_LBRACK] = ACTIONS(4287),
    [aux_sym_record_type_token1] = ACTIONS(4285),
    [aux_sym_basic_type_token21] = ACTIONS(4285),
    [aux_sym_basic_type_token22] = ACTIONS(4285),
    [aux_sym_basic_type_token48] = ACTIONS(4285),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4285),
    [anon_sym_POUNDif] = ACTIONS(4287),
    [anon_sym_POUNDIF] = ACTIONS(4287),
    [anon_sym_POUNDIf] = ACTIONS(4287),
    [anon_sym_not] = ACTIONS(4285),
    [anon_sym_NOT] = ACTIONS(4285),
    [anon_sym_Not] = ACTIONS(4285),
    [anon_sym_POUNDelse] = ACTIONS(4287),
    [anon_sym_POUNDELSE] = ACTIONS(4287),
    [anon_sym_POUNDElse] = ACTIONS(4287),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4285),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4285),
    [anon_sym_PLUS] = ACTIONS(4287),
    [sym_datetime_literal] = ACTIONS(4287),
    [sym_date_literal] = ACTIONS(4285),
    [sym_time_literal] = ACTIONS(4285),
    [sym_biginteger_literal] = ACTIONS(4287),
    [anon_sym_if] = ACTIONS(4285),
    [anon_sym_IF] = ACTIONS(4285),
    [anon_sym_If] = ACTIONS(4285),
    [anon_sym_else] = ACTIONS(4285),
    [anon_sym_ELSE] = ACTIONS(4285),
    [anon_sym_Else] = ACTIONS(4285),
    [anon_sym_case] = ACTIONS(4285),
    [anon_sym_CASE] = ACTIONS(4285),
    [anon_sym_Case] = ACTIONS(4285),
    [anon_sym_for] = ACTIONS(4285),
    [anon_sym_FOR] = ACTIONS(4285),
    [anon_sym_For] = ACTIONS(4285),
    [anon_sym_foreach] = ACTIONS(4285),
    [anon_sym_FOREACH] = ACTIONS(4285),
    [anon_sym_Foreach] = ACTIONS(4285),
    [anon_sym_while] = ACTIONS(4285),
    [anon_sym_WHILE] = ACTIONS(4285),
    [anon_sym_While] = ACTIONS(4285),
    [anon_sym_repeat] = ACTIONS(4285),
    [anon_sym_REPEAT] = ACTIONS(4285),
    [anon_sym_Repeat] = ACTIONS(4285),
    [anon_sym_until] = ACTIONS(4285),
    [anon_sym_UNTIL] = ACTIONS(4285),
    [anon_sym_Until] = ACTIONS(4285),
    [anon_sym_exit] = ACTIONS(4285),
    [anon_sym_EXIT] = ACTIONS(4285),
    [anon_sym_Exit] = ACTIONS(4285),
    [anon_sym_continue] = ACTIONS(4285),
    [anon_sym_CONTINUE] = ACTIONS(4285),
    [anon_sym_Continue] = ACTIONS(4285),
    [anon_sym_break] = ACTIONS(4285),
    [anon_sym_BREAK] = ACTIONS(4285),
    [anon_sym_Break] = ACTIONS(4285),
    [anon_sym_with] = ACTIONS(4285),
    [anon_sym_WITH] = ACTIONS(4285),
    [anon_sym_With] = ACTIONS(4285),
    [sym_asserterror_keyword] = ACTIONS(4287),
    [sym_page_keyword] = ACTIONS(4285),
    [anon_sym_codeunit] = ACTIONS(4285),
    [anon_sym_CODEUNIT] = ACTIONS(4285),
    [anon_sym_Codeunit] = ACTIONS(4285),
    [anon_sym_CodeUnit] = ACTIONS(4285),
    [anon_sym_COdeunit] = ACTIONS(4285),
    [anon_sym_codeUnit] = ACTIONS(4285),
    [sym_report_keyword] = ACTIONS(4285),
    [sym_query_keyword] = ACTIONS(4285),
    [anon_sym_xmlport] = ACTIONS(4285),
    [anon_sym_XMLPORT] = ACTIONS(4285),
    [anon_sym_Xmlport] = ACTIONS(4285),
    [anon_sym_XMLport] = ACTIONS(4285),
    [anon_sym_XMLPort] = ACTIONS(4285),
    [anon_sym_XmlPort] = ACTIONS(4285),
    [anon_sym_enum] = ACTIONS(4285),
    [anon_sym_ENUM] = ACTIONS(4285),
    [anon_sym_Enum] = ACTIONS(4285),
    [anon_sym_eNUM] = ACTIONS(4285),
    [anon_sym_eNum] = ACTIONS(4285),
    [anon_sym_ENum] = ACTIONS(4285),
    [sym_quoted_identifier] = ACTIONS(4287),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4287),
    [sym_integer] = ACTIONS(4285),
    [sym_continue_as_identifier] = ACTIONS(4287),
    [sym_preproc_open] = ACTIONS(4287),
  },
  [STATE(1862)] = {
    [sym_identifier] = ACTIONS(4692),
    [anon_sym_SEMI] = ACTIONS(4694),
    [anon_sym_DASH] = ACTIONS(4694),
    [aux_sym_boolean_token1] = ACTIONS(4692),
    [aux_sym_boolean_token2] = ACTIONS(4692),
    [sym_decimal] = ACTIONS(4692),
    [anon_sym_LPAREN] = ACTIONS(4694),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4692),
    [anon_sym_LBRACK] = ACTIONS(4694),
    [aux_sym_record_type_token1] = ACTIONS(4692),
    [aux_sym_basic_type_token21] = ACTIONS(4692),
    [aux_sym_basic_type_token22] = ACTIONS(4692),
    [aux_sym_basic_type_token48] = ACTIONS(4692),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4692),
    [anon_sym_POUNDif] = ACTIONS(4694),
    [anon_sym_POUNDIF] = ACTIONS(4694),
    [anon_sym_POUNDIf] = ACTIONS(4694),
    [anon_sym_not] = ACTIONS(4692),
    [anon_sym_NOT] = ACTIONS(4692),
    [anon_sym_Not] = ACTIONS(4692),
    [anon_sym_POUNDelse] = ACTIONS(4694),
    [anon_sym_POUNDELSE] = ACTIONS(4694),
    [anon_sym_POUNDElse] = ACTIONS(4694),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4692),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4692),
    [anon_sym_PLUS] = ACTIONS(4694),
    [sym_datetime_literal] = ACTIONS(4694),
    [sym_date_literal] = ACTIONS(4692),
    [sym_time_literal] = ACTIONS(4692),
    [sym_biginteger_literal] = ACTIONS(4694),
    [anon_sym_if] = ACTIONS(4692),
    [anon_sym_IF] = ACTIONS(4692),
    [anon_sym_If] = ACTIONS(4692),
    [anon_sym_else] = ACTIONS(4692),
    [anon_sym_ELSE] = ACTIONS(4692),
    [anon_sym_Else] = ACTIONS(4692),
    [anon_sym_case] = ACTIONS(4692),
    [anon_sym_CASE] = ACTIONS(4692),
    [anon_sym_Case] = ACTIONS(4692),
    [anon_sym_for] = ACTIONS(4692),
    [anon_sym_FOR] = ACTIONS(4692),
    [anon_sym_For] = ACTIONS(4692),
    [anon_sym_foreach] = ACTIONS(4692),
    [anon_sym_FOREACH] = ACTIONS(4692),
    [anon_sym_Foreach] = ACTIONS(4692),
    [anon_sym_while] = ACTIONS(4692),
    [anon_sym_WHILE] = ACTIONS(4692),
    [anon_sym_While] = ACTIONS(4692),
    [anon_sym_repeat] = ACTIONS(4692),
    [anon_sym_REPEAT] = ACTIONS(4692),
    [anon_sym_Repeat] = ACTIONS(4692),
    [anon_sym_until] = ACTIONS(4692),
    [anon_sym_UNTIL] = ACTIONS(4692),
    [anon_sym_Until] = ACTIONS(4692),
    [anon_sym_exit] = ACTIONS(4692),
    [anon_sym_EXIT] = ACTIONS(4692),
    [anon_sym_Exit] = ACTIONS(4692),
    [anon_sym_continue] = ACTIONS(4692),
    [anon_sym_CONTINUE] = ACTIONS(4692),
    [anon_sym_Continue] = ACTIONS(4692),
    [anon_sym_break] = ACTIONS(4692),
    [anon_sym_BREAK] = ACTIONS(4692),
    [anon_sym_Break] = ACTIONS(4692),
    [anon_sym_with] = ACTIONS(4692),
    [anon_sym_WITH] = ACTIONS(4692),
    [anon_sym_With] = ACTIONS(4692),
    [sym_asserterror_keyword] = ACTIONS(4694),
    [sym_page_keyword] = ACTIONS(4692),
    [anon_sym_codeunit] = ACTIONS(4692),
    [anon_sym_CODEUNIT] = ACTIONS(4692),
    [anon_sym_Codeunit] = ACTIONS(4692),
    [anon_sym_CodeUnit] = ACTIONS(4692),
    [anon_sym_COdeunit] = ACTIONS(4692),
    [anon_sym_codeUnit] = ACTIONS(4692),
    [sym_report_keyword] = ACTIONS(4692),
    [sym_query_keyword] = ACTIONS(4692),
    [anon_sym_xmlport] = ACTIONS(4692),
    [anon_sym_XMLPORT] = ACTIONS(4692),
    [anon_sym_Xmlport] = ACTIONS(4692),
    [anon_sym_XMLport] = ACTIONS(4692),
    [anon_sym_XMLPort] = ACTIONS(4692),
    [anon_sym_XmlPort] = ACTIONS(4692),
    [anon_sym_enum] = ACTIONS(4692),
    [anon_sym_ENUM] = ACTIONS(4692),
    [anon_sym_Enum] = ACTIONS(4692),
    [anon_sym_eNUM] = ACTIONS(4692),
    [anon_sym_eNum] = ACTIONS(4692),
    [anon_sym_ENum] = ACTIONS(4692),
    [sym_quoted_identifier] = ACTIONS(4694),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4694),
    [sym_integer] = ACTIONS(4692),
    [sym_continue_as_identifier] = ACTIONS(4694),
    [sym_preproc_open] = ACTIONS(4694),
  },
  [STATE(1863)] = {
    [sym_identifier] = ACTIONS(4289),
    [anon_sym_SEMI] = ACTIONS(4291),
    [anon_sym_DASH] = ACTIONS(4291),
    [aux_sym_boolean_token1] = ACTIONS(4289),
    [aux_sym_boolean_token2] = ACTIONS(4289),
    [sym_decimal] = ACTIONS(4289),
    [anon_sym_LPAREN] = ACTIONS(4291),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4289),
    [anon_sym_LBRACK] = ACTIONS(4291),
    [aux_sym_record_type_token1] = ACTIONS(4289),
    [aux_sym_basic_type_token21] = ACTIONS(4289),
    [aux_sym_basic_type_token22] = ACTIONS(4289),
    [aux_sym_basic_type_token48] = ACTIONS(4289),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4289),
    [anon_sym_POUNDif] = ACTIONS(4291),
    [anon_sym_POUNDIF] = ACTIONS(4291),
    [anon_sym_POUNDIf] = ACTIONS(4291),
    [anon_sym_not] = ACTIONS(4289),
    [anon_sym_NOT] = ACTIONS(4289),
    [anon_sym_Not] = ACTIONS(4289),
    [anon_sym_POUNDelse] = ACTIONS(4291),
    [anon_sym_POUNDELSE] = ACTIONS(4291),
    [anon_sym_POUNDElse] = ACTIONS(4291),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4289),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4289),
    [anon_sym_PLUS] = ACTIONS(4291),
    [sym_datetime_literal] = ACTIONS(4291),
    [sym_date_literal] = ACTIONS(4289),
    [sym_time_literal] = ACTIONS(4289),
    [sym_biginteger_literal] = ACTIONS(4291),
    [anon_sym_if] = ACTIONS(4289),
    [anon_sym_IF] = ACTIONS(4289),
    [anon_sym_If] = ACTIONS(4289),
    [anon_sym_else] = ACTIONS(4289),
    [anon_sym_ELSE] = ACTIONS(4289),
    [anon_sym_Else] = ACTIONS(4289),
    [anon_sym_case] = ACTIONS(4289),
    [anon_sym_CASE] = ACTIONS(4289),
    [anon_sym_Case] = ACTIONS(4289),
    [anon_sym_for] = ACTIONS(4289),
    [anon_sym_FOR] = ACTIONS(4289),
    [anon_sym_For] = ACTIONS(4289),
    [anon_sym_foreach] = ACTIONS(4289),
    [anon_sym_FOREACH] = ACTIONS(4289),
    [anon_sym_Foreach] = ACTIONS(4289),
    [anon_sym_while] = ACTIONS(4289),
    [anon_sym_WHILE] = ACTIONS(4289),
    [anon_sym_While] = ACTIONS(4289),
    [anon_sym_repeat] = ACTIONS(4289),
    [anon_sym_REPEAT] = ACTIONS(4289),
    [anon_sym_Repeat] = ACTIONS(4289),
    [anon_sym_until] = ACTIONS(4289),
    [anon_sym_UNTIL] = ACTIONS(4289),
    [anon_sym_Until] = ACTIONS(4289),
    [anon_sym_exit] = ACTIONS(4289),
    [anon_sym_EXIT] = ACTIONS(4289),
    [anon_sym_Exit] = ACTIONS(4289),
    [anon_sym_continue] = ACTIONS(4289),
    [anon_sym_CONTINUE] = ACTIONS(4289),
    [anon_sym_Continue] = ACTIONS(4289),
    [anon_sym_break] = ACTIONS(4289),
    [anon_sym_BREAK] = ACTIONS(4289),
    [anon_sym_Break] = ACTIONS(4289),
    [anon_sym_with] = ACTIONS(4289),
    [anon_sym_WITH] = ACTIONS(4289),
    [anon_sym_With] = ACTIONS(4289),
    [sym_asserterror_keyword] = ACTIONS(4291),
    [sym_page_keyword] = ACTIONS(4289),
    [anon_sym_codeunit] = ACTIONS(4289),
    [anon_sym_CODEUNIT] = ACTIONS(4289),
    [anon_sym_Codeunit] = ACTIONS(4289),
    [anon_sym_CodeUnit] = ACTIONS(4289),
    [anon_sym_COdeunit] = ACTIONS(4289),
    [anon_sym_codeUnit] = ACTIONS(4289),
    [sym_report_keyword] = ACTIONS(4289),
    [sym_query_keyword] = ACTIONS(4289),
    [anon_sym_xmlport] = ACTIONS(4289),
    [anon_sym_XMLPORT] = ACTIONS(4289),
    [anon_sym_Xmlport] = ACTIONS(4289),
    [anon_sym_XMLport] = ACTIONS(4289),
    [anon_sym_XMLPort] = ACTIONS(4289),
    [anon_sym_XmlPort] = ACTIONS(4289),
    [anon_sym_enum] = ACTIONS(4289),
    [anon_sym_ENUM] = ACTIONS(4289),
    [anon_sym_Enum] = ACTIONS(4289),
    [anon_sym_eNUM] = ACTIONS(4289),
    [anon_sym_eNum] = ACTIONS(4289),
    [anon_sym_ENum] = ACTIONS(4289),
    [sym_quoted_identifier] = ACTIONS(4291),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4291),
    [sym_integer] = ACTIONS(4289),
    [sym_continue_as_identifier] = ACTIONS(4291),
    [sym_preproc_open] = ACTIONS(4291),
  },
  [STATE(1864)] = {
    [sym_identifier] = ACTIONS(4293),
    [anon_sym_SEMI] = ACTIONS(4295),
    [anon_sym_DASH] = ACTIONS(4295),
    [aux_sym_boolean_token1] = ACTIONS(4293),
    [aux_sym_boolean_token2] = ACTIONS(4293),
    [sym_decimal] = ACTIONS(4293),
    [anon_sym_LPAREN] = ACTIONS(4295),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4293),
    [anon_sym_LBRACK] = ACTIONS(4295),
    [aux_sym_record_type_token1] = ACTIONS(4293),
    [aux_sym_basic_type_token21] = ACTIONS(4293),
    [aux_sym_basic_type_token22] = ACTIONS(4293),
    [aux_sym_basic_type_token48] = ACTIONS(4293),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4293),
    [anon_sym_POUNDif] = ACTIONS(4295),
    [anon_sym_POUNDIF] = ACTIONS(4295),
    [anon_sym_POUNDIf] = ACTIONS(4295),
    [anon_sym_not] = ACTIONS(4293),
    [anon_sym_NOT] = ACTIONS(4293),
    [anon_sym_Not] = ACTIONS(4293),
    [anon_sym_POUNDelse] = ACTIONS(4295),
    [anon_sym_POUNDELSE] = ACTIONS(4295),
    [anon_sym_POUNDElse] = ACTIONS(4295),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4293),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4293),
    [anon_sym_PLUS] = ACTIONS(4295),
    [sym_datetime_literal] = ACTIONS(4295),
    [sym_date_literal] = ACTIONS(4293),
    [sym_time_literal] = ACTIONS(4293),
    [sym_biginteger_literal] = ACTIONS(4295),
    [anon_sym_if] = ACTIONS(4293),
    [anon_sym_IF] = ACTIONS(4293),
    [anon_sym_If] = ACTIONS(4293),
    [anon_sym_else] = ACTIONS(4293),
    [anon_sym_ELSE] = ACTIONS(4293),
    [anon_sym_Else] = ACTIONS(4293),
    [anon_sym_case] = ACTIONS(4293),
    [anon_sym_CASE] = ACTIONS(4293),
    [anon_sym_Case] = ACTIONS(4293),
    [anon_sym_for] = ACTIONS(4293),
    [anon_sym_FOR] = ACTIONS(4293),
    [anon_sym_For] = ACTIONS(4293),
    [anon_sym_foreach] = ACTIONS(4293),
    [anon_sym_FOREACH] = ACTIONS(4293),
    [anon_sym_Foreach] = ACTIONS(4293),
    [anon_sym_while] = ACTIONS(4293),
    [anon_sym_WHILE] = ACTIONS(4293),
    [anon_sym_While] = ACTIONS(4293),
    [anon_sym_repeat] = ACTIONS(4293),
    [anon_sym_REPEAT] = ACTIONS(4293),
    [anon_sym_Repeat] = ACTIONS(4293),
    [anon_sym_until] = ACTIONS(4293),
    [anon_sym_UNTIL] = ACTIONS(4293),
    [anon_sym_Until] = ACTIONS(4293),
    [anon_sym_exit] = ACTIONS(4293),
    [anon_sym_EXIT] = ACTIONS(4293),
    [anon_sym_Exit] = ACTIONS(4293),
    [anon_sym_continue] = ACTIONS(4293),
    [anon_sym_CONTINUE] = ACTIONS(4293),
    [anon_sym_Continue] = ACTIONS(4293),
    [anon_sym_break] = ACTIONS(4293),
    [anon_sym_BREAK] = ACTIONS(4293),
    [anon_sym_Break] = ACTIONS(4293),
    [anon_sym_with] = ACTIONS(4293),
    [anon_sym_WITH] = ACTIONS(4293),
    [anon_sym_With] = ACTIONS(4293),
    [sym_asserterror_keyword] = ACTIONS(4295),
    [sym_page_keyword] = ACTIONS(4293),
    [anon_sym_codeunit] = ACTIONS(4293),
    [anon_sym_CODEUNIT] = ACTIONS(4293),
    [anon_sym_Codeunit] = ACTIONS(4293),
    [anon_sym_CodeUnit] = ACTIONS(4293),
    [anon_sym_COdeunit] = ACTIONS(4293),
    [anon_sym_codeUnit] = ACTIONS(4293),
    [sym_report_keyword] = ACTIONS(4293),
    [sym_query_keyword] = ACTIONS(4293),
    [anon_sym_xmlport] = ACTIONS(4293),
    [anon_sym_XMLPORT] = ACTIONS(4293),
    [anon_sym_Xmlport] = ACTIONS(4293),
    [anon_sym_XMLport] = ACTIONS(4293),
    [anon_sym_XMLPort] = ACTIONS(4293),
    [anon_sym_XmlPort] = ACTIONS(4293),
    [anon_sym_enum] = ACTIONS(4293),
    [anon_sym_ENUM] = ACTIONS(4293),
    [anon_sym_Enum] = ACTIONS(4293),
    [anon_sym_eNUM] = ACTIONS(4293),
    [anon_sym_eNum] = ACTIONS(4293),
    [anon_sym_ENum] = ACTIONS(4293),
    [sym_quoted_identifier] = ACTIONS(4295),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4295),
    [sym_integer] = ACTIONS(4293),
    [sym_continue_as_identifier] = ACTIONS(4295),
    [sym_preproc_open] = ACTIONS(4295),
  },
  [STATE(1865)] = {
    [sym_identifier] = ACTIONS(4297),
    [anon_sym_SEMI] = ACTIONS(4299),
    [anon_sym_DASH] = ACTIONS(4299),
    [aux_sym_boolean_token1] = ACTIONS(4297),
    [aux_sym_boolean_token2] = ACTIONS(4297),
    [sym_decimal] = ACTIONS(4297),
    [anon_sym_LPAREN] = ACTIONS(4299),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4297),
    [anon_sym_LBRACK] = ACTIONS(4299),
    [aux_sym_record_type_token1] = ACTIONS(4297),
    [aux_sym_basic_type_token21] = ACTIONS(4297),
    [aux_sym_basic_type_token22] = ACTIONS(4297),
    [aux_sym_basic_type_token48] = ACTIONS(4297),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4297),
    [anon_sym_POUNDif] = ACTIONS(4299),
    [anon_sym_POUNDIF] = ACTIONS(4299),
    [anon_sym_POUNDIf] = ACTIONS(4299),
    [anon_sym_not] = ACTIONS(4297),
    [anon_sym_NOT] = ACTIONS(4297),
    [anon_sym_Not] = ACTIONS(4297),
    [anon_sym_POUNDelse] = ACTIONS(4299),
    [anon_sym_POUNDELSE] = ACTIONS(4299),
    [anon_sym_POUNDElse] = ACTIONS(4299),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4297),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4297),
    [anon_sym_PLUS] = ACTIONS(4299),
    [sym_datetime_literal] = ACTIONS(4299),
    [sym_date_literal] = ACTIONS(4297),
    [sym_time_literal] = ACTIONS(4297),
    [sym_biginteger_literal] = ACTIONS(4299),
    [anon_sym_if] = ACTIONS(4297),
    [anon_sym_IF] = ACTIONS(4297),
    [anon_sym_If] = ACTIONS(4297),
    [anon_sym_else] = ACTIONS(4297),
    [anon_sym_ELSE] = ACTIONS(4297),
    [anon_sym_Else] = ACTIONS(4297),
    [anon_sym_case] = ACTIONS(4297),
    [anon_sym_CASE] = ACTIONS(4297),
    [anon_sym_Case] = ACTIONS(4297),
    [anon_sym_for] = ACTIONS(4297),
    [anon_sym_FOR] = ACTIONS(4297),
    [anon_sym_For] = ACTIONS(4297),
    [anon_sym_foreach] = ACTIONS(4297),
    [anon_sym_FOREACH] = ACTIONS(4297),
    [anon_sym_Foreach] = ACTIONS(4297),
    [anon_sym_while] = ACTIONS(4297),
    [anon_sym_WHILE] = ACTIONS(4297),
    [anon_sym_While] = ACTIONS(4297),
    [anon_sym_repeat] = ACTIONS(4297),
    [anon_sym_REPEAT] = ACTIONS(4297),
    [anon_sym_Repeat] = ACTIONS(4297),
    [anon_sym_until] = ACTIONS(4297),
    [anon_sym_UNTIL] = ACTIONS(4297),
    [anon_sym_Until] = ACTIONS(4297),
    [anon_sym_exit] = ACTIONS(4297),
    [anon_sym_EXIT] = ACTIONS(4297),
    [anon_sym_Exit] = ACTIONS(4297),
    [anon_sym_continue] = ACTIONS(4297),
    [anon_sym_CONTINUE] = ACTIONS(4297),
    [anon_sym_Continue] = ACTIONS(4297),
    [anon_sym_break] = ACTIONS(4297),
    [anon_sym_BREAK] = ACTIONS(4297),
    [anon_sym_Break] = ACTIONS(4297),
    [anon_sym_with] = ACTIONS(4297),
    [anon_sym_WITH] = ACTIONS(4297),
    [anon_sym_With] = ACTIONS(4297),
    [sym_asserterror_keyword] = ACTIONS(4299),
    [sym_page_keyword] = ACTIONS(4297),
    [anon_sym_codeunit] = ACTIONS(4297),
    [anon_sym_CODEUNIT] = ACTIONS(4297),
    [anon_sym_Codeunit] = ACTIONS(4297),
    [anon_sym_CodeUnit] = ACTIONS(4297),
    [anon_sym_COdeunit] = ACTIONS(4297),
    [anon_sym_codeUnit] = ACTIONS(4297),
    [sym_report_keyword] = ACTIONS(4297),
    [sym_query_keyword] = ACTIONS(4297),
    [anon_sym_xmlport] = ACTIONS(4297),
    [anon_sym_XMLPORT] = ACTIONS(4297),
    [anon_sym_Xmlport] = ACTIONS(4297),
    [anon_sym_XMLport] = ACTIONS(4297),
    [anon_sym_XMLPort] = ACTIONS(4297),
    [anon_sym_XmlPort] = ACTIONS(4297),
    [anon_sym_enum] = ACTIONS(4297),
    [anon_sym_ENUM] = ACTIONS(4297),
    [anon_sym_Enum] = ACTIONS(4297),
    [anon_sym_eNUM] = ACTIONS(4297),
    [anon_sym_eNum] = ACTIONS(4297),
    [anon_sym_ENum] = ACTIONS(4297),
    [sym_quoted_identifier] = ACTIONS(4299),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4299),
    [sym_integer] = ACTIONS(4297),
    [sym_continue_as_identifier] = ACTIONS(4299),
    [sym_preproc_open] = ACTIONS(4299),
  },
  [STATE(1866)] = {
    [sym_identifier] = ACTIONS(4301),
    [anon_sym_SEMI] = ACTIONS(4303),
    [anon_sym_DASH] = ACTIONS(4303),
    [aux_sym_boolean_token1] = ACTIONS(4301),
    [aux_sym_boolean_token2] = ACTIONS(4301),
    [sym_decimal] = ACTIONS(4301),
    [anon_sym_LPAREN] = ACTIONS(4303),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4301),
    [anon_sym_LBRACK] = ACTIONS(4303),
    [aux_sym_record_type_token1] = ACTIONS(4301),
    [aux_sym_basic_type_token21] = ACTIONS(4301),
    [aux_sym_basic_type_token22] = ACTIONS(4301),
    [aux_sym_basic_type_token48] = ACTIONS(4301),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4301),
    [anon_sym_POUNDif] = ACTIONS(4303),
    [anon_sym_POUNDIF] = ACTIONS(4303),
    [anon_sym_POUNDIf] = ACTIONS(4303),
    [anon_sym_not] = ACTIONS(4301),
    [anon_sym_NOT] = ACTIONS(4301),
    [anon_sym_Not] = ACTIONS(4301),
    [anon_sym_POUNDelse] = ACTIONS(4303),
    [anon_sym_POUNDELSE] = ACTIONS(4303),
    [anon_sym_POUNDElse] = ACTIONS(4303),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4301),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4301),
    [anon_sym_PLUS] = ACTIONS(4303),
    [sym_datetime_literal] = ACTIONS(4303),
    [sym_date_literal] = ACTIONS(4301),
    [sym_time_literal] = ACTIONS(4301),
    [sym_biginteger_literal] = ACTIONS(4303),
    [anon_sym_if] = ACTIONS(4301),
    [anon_sym_IF] = ACTIONS(4301),
    [anon_sym_If] = ACTIONS(4301),
    [anon_sym_else] = ACTIONS(4301),
    [anon_sym_ELSE] = ACTIONS(4301),
    [anon_sym_Else] = ACTIONS(4301),
    [anon_sym_case] = ACTIONS(4301),
    [anon_sym_CASE] = ACTIONS(4301),
    [anon_sym_Case] = ACTIONS(4301),
    [anon_sym_for] = ACTIONS(4301),
    [anon_sym_FOR] = ACTIONS(4301),
    [anon_sym_For] = ACTIONS(4301),
    [anon_sym_foreach] = ACTIONS(4301),
    [anon_sym_FOREACH] = ACTIONS(4301),
    [anon_sym_Foreach] = ACTIONS(4301),
    [anon_sym_while] = ACTIONS(4301),
    [anon_sym_WHILE] = ACTIONS(4301),
    [anon_sym_While] = ACTIONS(4301),
    [anon_sym_repeat] = ACTIONS(4301),
    [anon_sym_REPEAT] = ACTIONS(4301),
    [anon_sym_Repeat] = ACTIONS(4301),
    [anon_sym_until] = ACTIONS(4301),
    [anon_sym_UNTIL] = ACTIONS(4301),
    [anon_sym_Until] = ACTIONS(4301),
    [anon_sym_exit] = ACTIONS(4301),
    [anon_sym_EXIT] = ACTIONS(4301),
    [anon_sym_Exit] = ACTIONS(4301),
    [anon_sym_continue] = ACTIONS(4301),
    [anon_sym_CONTINUE] = ACTIONS(4301),
    [anon_sym_Continue] = ACTIONS(4301),
    [anon_sym_break] = ACTIONS(4301),
    [anon_sym_BREAK] = ACTIONS(4301),
    [anon_sym_Break] = ACTIONS(4301),
    [anon_sym_with] = ACTIONS(4301),
    [anon_sym_WITH] = ACTIONS(4301),
    [anon_sym_With] = ACTIONS(4301),
    [sym_asserterror_keyword] = ACTIONS(4303),
    [sym_page_keyword] = ACTIONS(4301),
    [anon_sym_codeunit] = ACTIONS(4301),
    [anon_sym_CODEUNIT] = ACTIONS(4301),
    [anon_sym_Codeunit] = ACTIONS(4301),
    [anon_sym_CodeUnit] = ACTIONS(4301),
    [anon_sym_COdeunit] = ACTIONS(4301),
    [anon_sym_codeUnit] = ACTIONS(4301),
    [sym_report_keyword] = ACTIONS(4301),
    [sym_query_keyword] = ACTIONS(4301),
    [anon_sym_xmlport] = ACTIONS(4301),
    [anon_sym_XMLPORT] = ACTIONS(4301),
    [anon_sym_Xmlport] = ACTIONS(4301),
    [anon_sym_XMLport] = ACTIONS(4301),
    [anon_sym_XMLPort] = ACTIONS(4301),
    [anon_sym_XmlPort] = ACTIONS(4301),
    [anon_sym_enum] = ACTIONS(4301),
    [anon_sym_ENUM] = ACTIONS(4301),
    [anon_sym_Enum] = ACTIONS(4301),
    [anon_sym_eNUM] = ACTIONS(4301),
    [anon_sym_eNum] = ACTIONS(4301),
    [anon_sym_ENum] = ACTIONS(4301),
    [sym_quoted_identifier] = ACTIONS(4303),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4303),
    [sym_integer] = ACTIONS(4301),
    [sym_continue_as_identifier] = ACTIONS(4303),
    [sym_preproc_open] = ACTIONS(4303),
  },
  [STATE(1867)] = {
    [sym_identifier] = ACTIONS(4305),
    [anon_sym_SEMI] = ACTIONS(4307),
    [anon_sym_DASH] = ACTIONS(4307),
    [aux_sym_boolean_token1] = ACTIONS(4305),
    [aux_sym_boolean_token2] = ACTIONS(4305),
    [sym_decimal] = ACTIONS(4305),
    [anon_sym_LPAREN] = ACTIONS(4307),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4305),
    [anon_sym_LBRACK] = ACTIONS(4307),
    [aux_sym_record_type_token1] = ACTIONS(4305),
    [aux_sym_basic_type_token21] = ACTIONS(4305),
    [aux_sym_basic_type_token22] = ACTIONS(4305),
    [aux_sym_basic_type_token48] = ACTIONS(4305),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4305),
    [anon_sym_POUNDif] = ACTIONS(4307),
    [anon_sym_POUNDIF] = ACTIONS(4307),
    [anon_sym_POUNDIf] = ACTIONS(4307),
    [anon_sym_not] = ACTIONS(4305),
    [anon_sym_NOT] = ACTIONS(4305),
    [anon_sym_Not] = ACTIONS(4305),
    [anon_sym_POUNDelse] = ACTIONS(4307),
    [anon_sym_POUNDELSE] = ACTIONS(4307),
    [anon_sym_POUNDElse] = ACTIONS(4307),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4305),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4305),
    [anon_sym_PLUS] = ACTIONS(4307),
    [sym_datetime_literal] = ACTIONS(4307),
    [sym_date_literal] = ACTIONS(4305),
    [sym_time_literal] = ACTIONS(4305),
    [sym_biginteger_literal] = ACTIONS(4307),
    [anon_sym_if] = ACTIONS(4305),
    [anon_sym_IF] = ACTIONS(4305),
    [anon_sym_If] = ACTIONS(4305),
    [anon_sym_else] = ACTIONS(4305),
    [anon_sym_ELSE] = ACTIONS(4305),
    [anon_sym_Else] = ACTIONS(4305),
    [anon_sym_case] = ACTIONS(4305),
    [anon_sym_CASE] = ACTIONS(4305),
    [anon_sym_Case] = ACTIONS(4305),
    [anon_sym_for] = ACTIONS(4305),
    [anon_sym_FOR] = ACTIONS(4305),
    [anon_sym_For] = ACTIONS(4305),
    [anon_sym_foreach] = ACTIONS(4305),
    [anon_sym_FOREACH] = ACTIONS(4305),
    [anon_sym_Foreach] = ACTIONS(4305),
    [anon_sym_while] = ACTIONS(4305),
    [anon_sym_WHILE] = ACTIONS(4305),
    [anon_sym_While] = ACTIONS(4305),
    [anon_sym_repeat] = ACTIONS(4305),
    [anon_sym_REPEAT] = ACTIONS(4305),
    [anon_sym_Repeat] = ACTIONS(4305),
    [anon_sym_until] = ACTIONS(4305),
    [anon_sym_UNTIL] = ACTIONS(4305),
    [anon_sym_Until] = ACTIONS(4305),
    [anon_sym_exit] = ACTIONS(4305),
    [anon_sym_EXIT] = ACTIONS(4305),
    [anon_sym_Exit] = ACTIONS(4305),
    [anon_sym_continue] = ACTIONS(4305),
    [anon_sym_CONTINUE] = ACTIONS(4305),
    [anon_sym_Continue] = ACTIONS(4305),
    [anon_sym_break] = ACTIONS(4305),
    [anon_sym_BREAK] = ACTIONS(4305),
    [anon_sym_Break] = ACTIONS(4305),
    [anon_sym_with] = ACTIONS(4305),
    [anon_sym_WITH] = ACTIONS(4305),
    [anon_sym_With] = ACTIONS(4305),
    [sym_asserterror_keyword] = ACTIONS(4307),
    [sym_page_keyword] = ACTIONS(4305),
    [anon_sym_codeunit] = ACTIONS(4305),
    [anon_sym_CODEUNIT] = ACTIONS(4305),
    [anon_sym_Codeunit] = ACTIONS(4305),
    [anon_sym_CodeUnit] = ACTIONS(4305),
    [anon_sym_COdeunit] = ACTIONS(4305),
    [anon_sym_codeUnit] = ACTIONS(4305),
    [sym_report_keyword] = ACTIONS(4305),
    [sym_query_keyword] = ACTIONS(4305),
    [anon_sym_xmlport] = ACTIONS(4305),
    [anon_sym_XMLPORT] = ACTIONS(4305),
    [anon_sym_Xmlport] = ACTIONS(4305),
    [anon_sym_XMLport] = ACTIONS(4305),
    [anon_sym_XMLPort] = ACTIONS(4305),
    [anon_sym_XmlPort] = ACTIONS(4305),
    [anon_sym_enum] = ACTIONS(4305),
    [anon_sym_ENUM] = ACTIONS(4305),
    [anon_sym_Enum] = ACTIONS(4305),
    [anon_sym_eNUM] = ACTIONS(4305),
    [anon_sym_eNum] = ACTIONS(4305),
    [anon_sym_ENum] = ACTIONS(4305),
    [sym_quoted_identifier] = ACTIONS(4307),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4307),
    [sym_integer] = ACTIONS(4305),
    [sym_continue_as_identifier] = ACTIONS(4307),
    [sym_preproc_open] = ACTIONS(4307),
  },
  [STATE(1868)] = {
    [sym_identifier] = ACTIONS(4309),
    [anon_sym_SEMI] = ACTIONS(4311),
    [anon_sym_DASH] = ACTIONS(4311),
    [aux_sym_boolean_token1] = ACTIONS(4309),
    [aux_sym_boolean_token2] = ACTIONS(4309),
    [sym_decimal] = ACTIONS(4309),
    [anon_sym_LPAREN] = ACTIONS(4311),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4309),
    [anon_sym_LBRACK] = ACTIONS(4311),
    [aux_sym_record_type_token1] = ACTIONS(4309),
    [aux_sym_basic_type_token21] = ACTIONS(4309),
    [aux_sym_basic_type_token22] = ACTIONS(4309),
    [aux_sym_basic_type_token48] = ACTIONS(4309),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4309),
    [anon_sym_POUNDif] = ACTIONS(4311),
    [anon_sym_POUNDIF] = ACTIONS(4311),
    [anon_sym_POUNDIf] = ACTIONS(4311),
    [anon_sym_not] = ACTIONS(4309),
    [anon_sym_NOT] = ACTIONS(4309),
    [anon_sym_Not] = ACTIONS(4309),
    [anon_sym_POUNDelse] = ACTIONS(4311),
    [anon_sym_POUNDELSE] = ACTIONS(4311),
    [anon_sym_POUNDElse] = ACTIONS(4311),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4309),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4309),
    [anon_sym_PLUS] = ACTIONS(4311),
    [sym_datetime_literal] = ACTIONS(4311),
    [sym_date_literal] = ACTIONS(4309),
    [sym_time_literal] = ACTIONS(4309),
    [sym_biginteger_literal] = ACTIONS(4311),
    [anon_sym_if] = ACTIONS(4309),
    [anon_sym_IF] = ACTIONS(4309),
    [anon_sym_If] = ACTIONS(4309),
    [anon_sym_else] = ACTIONS(4309),
    [anon_sym_ELSE] = ACTIONS(4309),
    [anon_sym_Else] = ACTIONS(4309),
    [anon_sym_case] = ACTIONS(4309),
    [anon_sym_CASE] = ACTIONS(4309),
    [anon_sym_Case] = ACTIONS(4309),
    [anon_sym_for] = ACTIONS(4309),
    [anon_sym_FOR] = ACTIONS(4309),
    [anon_sym_For] = ACTIONS(4309),
    [anon_sym_foreach] = ACTIONS(4309),
    [anon_sym_FOREACH] = ACTIONS(4309),
    [anon_sym_Foreach] = ACTIONS(4309),
    [anon_sym_while] = ACTIONS(4309),
    [anon_sym_WHILE] = ACTIONS(4309),
    [anon_sym_While] = ACTIONS(4309),
    [anon_sym_repeat] = ACTIONS(4309),
    [anon_sym_REPEAT] = ACTIONS(4309),
    [anon_sym_Repeat] = ACTIONS(4309),
    [anon_sym_until] = ACTIONS(4309),
    [anon_sym_UNTIL] = ACTIONS(4309),
    [anon_sym_Until] = ACTIONS(4309),
    [anon_sym_exit] = ACTIONS(4309),
    [anon_sym_EXIT] = ACTIONS(4309),
    [anon_sym_Exit] = ACTIONS(4309),
    [anon_sym_continue] = ACTIONS(4309),
    [anon_sym_CONTINUE] = ACTIONS(4309),
    [anon_sym_Continue] = ACTIONS(4309),
    [anon_sym_break] = ACTIONS(4309),
    [anon_sym_BREAK] = ACTIONS(4309),
    [anon_sym_Break] = ACTIONS(4309),
    [anon_sym_with] = ACTIONS(4309),
    [anon_sym_WITH] = ACTIONS(4309),
    [anon_sym_With] = ACTIONS(4309),
    [sym_asserterror_keyword] = ACTIONS(4311),
    [sym_page_keyword] = ACTIONS(4309),
    [anon_sym_codeunit] = ACTIONS(4309),
    [anon_sym_CODEUNIT] = ACTIONS(4309),
    [anon_sym_Codeunit] = ACTIONS(4309),
    [anon_sym_CodeUnit] = ACTIONS(4309),
    [anon_sym_COdeunit] = ACTIONS(4309),
    [anon_sym_codeUnit] = ACTIONS(4309),
    [sym_report_keyword] = ACTIONS(4309),
    [sym_query_keyword] = ACTIONS(4309),
    [anon_sym_xmlport] = ACTIONS(4309),
    [anon_sym_XMLPORT] = ACTIONS(4309),
    [anon_sym_Xmlport] = ACTIONS(4309),
    [anon_sym_XMLport] = ACTIONS(4309),
    [anon_sym_XMLPort] = ACTIONS(4309),
    [anon_sym_XmlPort] = ACTIONS(4309),
    [anon_sym_enum] = ACTIONS(4309),
    [anon_sym_ENUM] = ACTIONS(4309),
    [anon_sym_Enum] = ACTIONS(4309),
    [anon_sym_eNUM] = ACTIONS(4309),
    [anon_sym_eNum] = ACTIONS(4309),
    [anon_sym_ENum] = ACTIONS(4309),
    [sym_quoted_identifier] = ACTIONS(4311),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4311),
    [sym_integer] = ACTIONS(4309),
    [sym_continue_as_identifier] = ACTIONS(4311),
    [sym_preproc_open] = ACTIONS(4311),
  },
  [STATE(1869)] = {
    [sym_identifier] = ACTIONS(4313),
    [anon_sym_SEMI] = ACTIONS(4315),
    [anon_sym_DASH] = ACTIONS(4315),
    [aux_sym_boolean_token1] = ACTIONS(4313),
    [aux_sym_boolean_token2] = ACTIONS(4313),
    [sym_decimal] = ACTIONS(4313),
    [anon_sym_LPAREN] = ACTIONS(4315),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4313),
    [anon_sym_LBRACK] = ACTIONS(4315),
    [aux_sym_record_type_token1] = ACTIONS(4313),
    [aux_sym_basic_type_token21] = ACTIONS(4313),
    [aux_sym_basic_type_token22] = ACTIONS(4313),
    [aux_sym_basic_type_token48] = ACTIONS(4313),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4313),
    [anon_sym_POUNDif] = ACTIONS(4315),
    [anon_sym_POUNDIF] = ACTIONS(4315),
    [anon_sym_POUNDIf] = ACTIONS(4315),
    [anon_sym_not] = ACTIONS(4313),
    [anon_sym_NOT] = ACTIONS(4313),
    [anon_sym_Not] = ACTIONS(4313),
    [anon_sym_POUNDelse] = ACTIONS(4315),
    [anon_sym_POUNDELSE] = ACTIONS(4315),
    [anon_sym_POUNDElse] = ACTIONS(4315),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4313),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4313),
    [anon_sym_PLUS] = ACTIONS(4315),
    [sym_datetime_literal] = ACTIONS(4315),
    [sym_date_literal] = ACTIONS(4313),
    [sym_time_literal] = ACTIONS(4313),
    [sym_biginteger_literal] = ACTIONS(4315),
    [anon_sym_if] = ACTIONS(4313),
    [anon_sym_IF] = ACTIONS(4313),
    [anon_sym_If] = ACTIONS(4313),
    [anon_sym_else] = ACTIONS(4313),
    [anon_sym_ELSE] = ACTIONS(4313),
    [anon_sym_Else] = ACTIONS(4313),
    [anon_sym_case] = ACTIONS(4313),
    [anon_sym_CASE] = ACTIONS(4313),
    [anon_sym_Case] = ACTIONS(4313),
    [anon_sym_for] = ACTIONS(4313),
    [anon_sym_FOR] = ACTIONS(4313),
    [anon_sym_For] = ACTIONS(4313),
    [anon_sym_foreach] = ACTIONS(4313),
    [anon_sym_FOREACH] = ACTIONS(4313),
    [anon_sym_Foreach] = ACTIONS(4313),
    [anon_sym_while] = ACTIONS(4313),
    [anon_sym_WHILE] = ACTIONS(4313),
    [anon_sym_While] = ACTIONS(4313),
    [anon_sym_repeat] = ACTIONS(4313),
    [anon_sym_REPEAT] = ACTIONS(4313),
    [anon_sym_Repeat] = ACTIONS(4313),
    [anon_sym_until] = ACTIONS(4313),
    [anon_sym_UNTIL] = ACTIONS(4313),
    [anon_sym_Until] = ACTIONS(4313),
    [anon_sym_exit] = ACTIONS(4313),
    [anon_sym_EXIT] = ACTIONS(4313),
    [anon_sym_Exit] = ACTIONS(4313),
    [anon_sym_continue] = ACTIONS(4313),
    [anon_sym_CONTINUE] = ACTIONS(4313),
    [anon_sym_Continue] = ACTIONS(4313),
    [anon_sym_break] = ACTIONS(4313),
    [anon_sym_BREAK] = ACTIONS(4313),
    [anon_sym_Break] = ACTIONS(4313),
    [anon_sym_with] = ACTIONS(4313),
    [anon_sym_WITH] = ACTIONS(4313),
    [anon_sym_With] = ACTIONS(4313),
    [sym_asserterror_keyword] = ACTIONS(4315),
    [sym_page_keyword] = ACTIONS(4313),
    [anon_sym_codeunit] = ACTIONS(4313),
    [anon_sym_CODEUNIT] = ACTIONS(4313),
    [anon_sym_Codeunit] = ACTIONS(4313),
    [anon_sym_CodeUnit] = ACTIONS(4313),
    [anon_sym_COdeunit] = ACTIONS(4313),
    [anon_sym_codeUnit] = ACTIONS(4313),
    [sym_report_keyword] = ACTIONS(4313),
    [sym_query_keyword] = ACTIONS(4313),
    [anon_sym_xmlport] = ACTIONS(4313),
    [anon_sym_XMLPORT] = ACTIONS(4313),
    [anon_sym_Xmlport] = ACTIONS(4313),
    [anon_sym_XMLport] = ACTIONS(4313),
    [anon_sym_XMLPort] = ACTIONS(4313),
    [anon_sym_XmlPort] = ACTIONS(4313),
    [anon_sym_enum] = ACTIONS(4313),
    [anon_sym_ENUM] = ACTIONS(4313),
    [anon_sym_Enum] = ACTIONS(4313),
    [anon_sym_eNUM] = ACTIONS(4313),
    [anon_sym_eNum] = ACTIONS(4313),
    [anon_sym_ENum] = ACTIONS(4313),
    [sym_quoted_identifier] = ACTIONS(4315),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4315),
    [sym_integer] = ACTIONS(4313),
    [sym_continue_as_identifier] = ACTIONS(4315),
    [sym_preproc_open] = ACTIONS(4315),
  },
  [STATE(1870)] = {
    [sym_identifier] = ACTIONS(4317),
    [anon_sym_SEMI] = ACTIONS(4319),
    [anon_sym_DASH] = ACTIONS(4319),
    [aux_sym_boolean_token1] = ACTIONS(4317),
    [aux_sym_boolean_token2] = ACTIONS(4317),
    [sym_decimal] = ACTIONS(4317),
    [anon_sym_LPAREN] = ACTIONS(4319),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4317),
    [anon_sym_LBRACK] = ACTIONS(4319),
    [aux_sym_record_type_token1] = ACTIONS(4317),
    [aux_sym_basic_type_token21] = ACTIONS(4317),
    [aux_sym_basic_type_token22] = ACTIONS(4317),
    [aux_sym_basic_type_token48] = ACTIONS(4317),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4317),
    [anon_sym_POUNDif] = ACTIONS(4319),
    [anon_sym_POUNDIF] = ACTIONS(4319),
    [anon_sym_POUNDIf] = ACTIONS(4319),
    [anon_sym_not] = ACTIONS(4317),
    [anon_sym_NOT] = ACTIONS(4317),
    [anon_sym_Not] = ACTIONS(4317),
    [anon_sym_POUNDelse] = ACTIONS(4319),
    [anon_sym_POUNDELSE] = ACTIONS(4319),
    [anon_sym_POUNDElse] = ACTIONS(4319),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4317),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4317),
    [anon_sym_PLUS] = ACTIONS(4319),
    [sym_datetime_literal] = ACTIONS(4319),
    [sym_date_literal] = ACTIONS(4317),
    [sym_time_literal] = ACTIONS(4317),
    [sym_biginteger_literal] = ACTIONS(4319),
    [anon_sym_if] = ACTIONS(4317),
    [anon_sym_IF] = ACTIONS(4317),
    [anon_sym_If] = ACTIONS(4317),
    [anon_sym_else] = ACTIONS(4317),
    [anon_sym_ELSE] = ACTIONS(4317),
    [anon_sym_Else] = ACTIONS(4317),
    [anon_sym_case] = ACTIONS(4317),
    [anon_sym_CASE] = ACTIONS(4317),
    [anon_sym_Case] = ACTIONS(4317),
    [anon_sym_for] = ACTIONS(4317),
    [anon_sym_FOR] = ACTIONS(4317),
    [anon_sym_For] = ACTIONS(4317),
    [anon_sym_foreach] = ACTIONS(4317),
    [anon_sym_FOREACH] = ACTIONS(4317),
    [anon_sym_Foreach] = ACTIONS(4317),
    [anon_sym_while] = ACTIONS(4317),
    [anon_sym_WHILE] = ACTIONS(4317),
    [anon_sym_While] = ACTIONS(4317),
    [anon_sym_repeat] = ACTIONS(4317),
    [anon_sym_REPEAT] = ACTIONS(4317),
    [anon_sym_Repeat] = ACTIONS(4317),
    [anon_sym_until] = ACTIONS(4317),
    [anon_sym_UNTIL] = ACTIONS(4317),
    [anon_sym_Until] = ACTIONS(4317),
    [anon_sym_exit] = ACTIONS(4317),
    [anon_sym_EXIT] = ACTIONS(4317),
    [anon_sym_Exit] = ACTIONS(4317),
    [anon_sym_continue] = ACTIONS(4317),
    [anon_sym_CONTINUE] = ACTIONS(4317),
    [anon_sym_Continue] = ACTIONS(4317),
    [anon_sym_break] = ACTIONS(4317),
    [anon_sym_BREAK] = ACTIONS(4317),
    [anon_sym_Break] = ACTIONS(4317),
    [anon_sym_with] = ACTIONS(4317),
    [anon_sym_WITH] = ACTIONS(4317),
    [anon_sym_With] = ACTIONS(4317),
    [sym_asserterror_keyword] = ACTIONS(4319),
    [sym_page_keyword] = ACTIONS(4317),
    [anon_sym_codeunit] = ACTIONS(4317),
    [anon_sym_CODEUNIT] = ACTIONS(4317),
    [anon_sym_Codeunit] = ACTIONS(4317),
    [anon_sym_CodeUnit] = ACTIONS(4317),
    [anon_sym_COdeunit] = ACTIONS(4317),
    [anon_sym_codeUnit] = ACTIONS(4317),
    [sym_report_keyword] = ACTIONS(4317),
    [sym_query_keyword] = ACTIONS(4317),
    [anon_sym_xmlport] = ACTIONS(4317),
    [anon_sym_XMLPORT] = ACTIONS(4317),
    [anon_sym_Xmlport] = ACTIONS(4317),
    [anon_sym_XMLport] = ACTIONS(4317),
    [anon_sym_XMLPort] = ACTIONS(4317),
    [anon_sym_XmlPort] = ACTIONS(4317),
    [anon_sym_enum] = ACTIONS(4317),
    [anon_sym_ENUM] = ACTIONS(4317),
    [anon_sym_Enum] = ACTIONS(4317),
    [anon_sym_eNUM] = ACTIONS(4317),
    [anon_sym_eNum] = ACTIONS(4317),
    [anon_sym_ENum] = ACTIONS(4317),
    [sym_quoted_identifier] = ACTIONS(4319),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4319),
    [sym_integer] = ACTIONS(4317),
    [sym_continue_as_identifier] = ACTIONS(4319),
    [sym_preproc_open] = ACTIONS(4319),
  },
  [STATE(1871)] = {
    [sym_identifier] = ACTIONS(4321),
    [anon_sym_SEMI] = ACTIONS(4323),
    [anon_sym_DASH] = ACTIONS(4323),
    [aux_sym_boolean_token1] = ACTIONS(4321),
    [aux_sym_boolean_token2] = ACTIONS(4321),
    [sym_decimal] = ACTIONS(4321),
    [anon_sym_LPAREN] = ACTIONS(4323),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4321),
    [anon_sym_LBRACK] = ACTIONS(4323),
    [aux_sym_record_type_token1] = ACTIONS(4321),
    [aux_sym_basic_type_token21] = ACTIONS(4321),
    [aux_sym_basic_type_token22] = ACTIONS(4321),
    [aux_sym_basic_type_token48] = ACTIONS(4321),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4321),
    [anon_sym_POUNDif] = ACTIONS(4323),
    [anon_sym_POUNDIF] = ACTIONS(4323),
    [anon_sym_POUNDIf] = ACTIONS(4323),
    [anon_sym_not] = ACTIONS(4321),
    [anon_sym_NOT] = ACTIONS(4321),
    [anon_sym_Not] = ACTIONS(4321),
    [anon_sym_POUNDelse] = ACTIONS(4323),
    [anon_sym_POUNDELSE] = ACTIONS(4323),
    [anon_sym_POUNDElse] = ACTIONS(4323),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4321),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4321),
    [anon_sym_PLUS] = ACTIONS(4323),
    [sym_datetime_literal] = ACTIONS(4323),
    [sym_date_literal] = ACTIONS(4321),
    [sym_time_literal] = ACTIONS(4321),
    [sym_biginteger_literal] = ACTIONS(4323),
    [anon_sym_if] = ACTIONS(4321),
    [anon_sym_IF] = ACTIONS(4321),
    [anon_sym_If] = ACTIONS(4321),
    [anon_sym_else] = ACTIONS(4321),
    [anon_sym_ELSE] = ACTIONS(4321),
    [anon_sym_Else] = ACTIONS(4321),
    [anon_sym_case] = ACTIONS(4321),
    [anon_sym_CASE] = ACTIONS(4321),
    [anon_sym_Case] = ACTIONS(4321),
    [anon_sym_for] = ACTIONS(4321),
    [anon_sym_FOR] = ACTIONS(4321),
    [anon_sym_For] = ACTIONS(4321),
    [anon_sym_foreach] = ACTIONS(4321),
    [anon_sym_FOREACH] = ACTIONS(4321),
    [anon_sym_Foreach] = ACTIONS(4321),
    [anon_sym_while] = ACTIONS(4321),
    [anon_sym_WHILE] = ACTIONS(4321),
    [anon_sym_While] = ACTIONS(4321),
    [anon_sym_repeat] = ACTIONS(4321),
    [anon_sym_REPEAT] = ACTIONS(4321),
    [anon_sym_Repeat] = ACTIONS(4321),
    [anon_sym_until] = ACTIONS(4321),
    [anon_sym_UNTIL] = ACTIONS(4321),
    [anon_sym_Until] = ACTIONS(4321),
    [anon_sym_exit] = ACTIONS(4321),
    [anon_sym_EXIT] = ACTIONS(4321),
    [anon_sym_Exit] = ACTIONS(4321),
    [anon_sym_continue] = ACTIONS(4321),
    [anon_sym_CONTINUE] = ACTIONS(4321),
    [anon_sym_Continue] = ACTIONS(4321),
    [anon_sym_break] = ACTIONS(4321),
    [anon_sym_BREAK] = ACTIONS(4321),
    [anon_sym_Break] = ACTIONS(4321),
    [anon_sym_with] = ACTIONS(4321),
    [anon_sym_WITH] = ACTIONS(4321),
    [anon_sym_With] = ACTIONS(4321),
    [sym_asserterror_keyword] = ACTIONS(4323),
    [sym_page_keyword] = ACTIONS(4321),
    [anon_sym_codeunit] = ACTIONS(4321),
    [anon_sym_CODEUNIT] = ACTIONS(4321),
    [anon_sym_Codeunit] = ACTIONS(4321),
    [anon_sym_CodeUnit] = ACTIONS(4321),
    [anon_sym_COdeunit] = ACTIONS(4321),
    [anon_sym_codeUnit] = ACTIONS(4321),
    [sym_report_keyword] = ACTIONS(4321),
    [sym_query_keyword] = ACTIONS(4321),
    [anon_sym_xmlport] = ACTIONS(4321),
    [anon_sym_XMLPORT] = ACTIONS(4321),
    [anon_sym_Xmlport] = ACTIONS(4321),
    [anon_sym_XMLport] = ACTIONS(4321),
    [anon_sym_XMLPort] = ACTIONS(4321),
    [anon_sym_XmlPort] = ACTIONS(4321),
    [anon_sym_enum] = ACTIONS(4321),
    [anon_sym_ENUM] = ACTIONS(4321),
    [anon_sym_Enum] = ACTIONS(4321),
    [anon_sym_eNUM] = ACTIONS(4321),
    [anon_sym_eNum] = ACTIONS(4321),
    [anon_sym_ENum] = ACTIONS(4321),
    [sym_quoted_identifier] = ACTIONS(4323),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4323),
    [sym_integer] = ACTIONS(4321),
    [sym_continue_as_identifier] = ACTIONS(4323),
    [sym_preproc_open] = ACTIONS(4323),
  },
  [STATE(1872)] = {
    [sym_identifier] = ACTIONS(4325),
    [anon_sym_SEMI] = ACTIONS(4327),
    [anon_sym_DASH] = ACTIONS(4327),
    [aux_sym_boolean_token1] = ACTIONS(4325),
    [aux_sym_boolean_token2] = ACTIONS(4325),
    [sym_decimal] = ACTIONS(4325),
    [anon_sym_LPAREN] = ACTIONS(4327),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4325),
    [anon_sym_LBRACK] = ACTIONS(4327),
    [aux_sym_record_type_token1] = ACTIONS(4325),
    [aux_sym_basic_type_token21] = ACTIONS(4325),
    [aux_sym_basic_type_token22] = ACTIONS(4325),
    [aux_sym_basic_type_token48] = ACTIONS(4325),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4325),
    [anon_sym_POUNDif] = ACTIONS(4327),
    [anon_sym_POUNDIF] = ACTIONS(4327),
    [anon_sym_POUNDIf] = ACTIONS(4327),
    [anon_sym_not] = ACTIONS(4325),
    [anon_sym_NOT] = ACTIONS(4325),
    [anon_sym_Not] = ACTIONS(4325),
    [anon_sym_POUNDelse] = ACTIONS(4327),
    [anon_sym_POUNDELSE] = ACTIONS(4327),
    [anon_sym_POUNDElse] = ACTIONS(4327),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4325),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4325),
    [anon_sym_PLUS] = ACTIONS(4327),
    [sym_datetime_literal] = ACTIONS(4327),
    [sym_date_literal] = ACTIONS(4325),
    [sym_time_literal] = ACTIONS(4325),
    [sym_biginteger_literal] = ACTIONS(4327),
    [anon_sym_if] = ACTIONS(4325),
    [anon_sym_IF] = ACTIONS(4325),
    [anon_sym_If] = ACTIONS(4325),
    [anon_sym_else] = ACTIONS(4325),
    [anon_sym_ELSE] = ACTIONS(4325),
    [anon_sym_Else] = ACTIONS(4325),
    [anon_sym_case] = ACTIONS(4325),
    [anon_sym_CASE] = ACTIONS(4325),
    [anon_sym_Case] = ACTIONS(4325),
    [anon_sym_for] = ACTIONS(4325),
    [anon_sym_FOR] = ACTIONS(4325),
    [anon_sym_For] = ACTIONS(4325),
    [anon_sym_foreach] = ACTIONS(4325),
    [anon_sym_FOREACH] = ACTIONS(4325),
    [anon_sym_Foreach] = ACTIONS(4325),
    [anon_sym_while] = ACTIONS(4325),
    [anon_sym_WHILE] = ACTIONS(4325),
    [anon_sym_While] = ACTIONS(4325),
    [anon_sym_repeat] = ACTIONS(4325),
    [anon_sym_REPEAT] = ACTIONS(4325),
    [anon_sym_Repeat] = ACTIONS(4325),
    [anon_sym_until] = ACTIONS(4325),
    [anon_sym_UNTIL] = ACTIONS(4325),
    [anon_sym_Until] = ACTIONS(4325),
    [anon_sym_exit] = ACTIONS(4325),
    [anon_sym_EXIT] = ACTIONS(4325),
    [anon_sym_Exit] = ACTIONS(4325),
    [anon_sym_continue] = ACTIONS(4325),
    [anon_sym_CONTINUE] = ACTIONS(4325),
    [anon_sym_Continue] = ACTIONS(4325),
    [anon_sym_break] = ACTIONS(4325),
    [anon_sym_BREAK] = ACTIONS(4325),
    [anon_sym_Break] = ACTIONS(4325),
    [anon_sym_with] = ACTIONS(4325),
    [anon_sym_WITH] = ACTIONS(4325),
    [anon_sym_With] = ACTIONS(4325),
    [sym_asserterror_keyword] = ACTIONS(4327),
    [sym_page_keyword] = ACTIONS(4325),
    [anon_sym_codeunit] = ACTIONS(4325),
    [anon_sym_CODEUNIT] = ACTIONS(4325),
    [anon_sym_Codeunit] = ACTIONS(4325),
    [anon_sym_CodeUnit] = ACTIONS(4325),
    [anon_sym_COdeunit] = ACTIONS(4325),
    [anon_sym_codeUnit] = ACTIONS(4325),
    [sym_report_keyword] = ACTIONS(4325),
    [sym_query_keyword] = ACTIONS(4325),
    [anon_sym_xmlport] = ACTIONS(4325),
    [anon_sym_XMLPORT] = ACTIONS(4325),
    [anon_sym_Xmlport] = ACTIONS(4325),
    [anon_sym_XMLport] = ACTIONS(4325),
    [anon_sym_XMLPort] = ACTIONS(4325),
    [anon_sym_XmlPort] = ACTIONS(4325),
    [anon_sym_enum] = ACTIONS(4325),
    [anon_sym_ENUM] = ACTIONS(4325),
    [anon_sym_Enum] = ACTIONS(4325),
    [anon_sym_eNUM] = ACTIONS(4325),
    [anon_sym_eNum] = ACTIONS(4325),
    [anon_sym_ENum] = ACTIONS(4325),
    [sym_quoted_identifier] = ACTIONS(4327),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4327),
    [sym_integer] = ACTIONS(4325),
    [sym_continue_as_identifier] = ACTIONS(4327),
    [sym_preproc_open] = ACTIONS(4327),
  },
  [STATE(1873)] = {
    [sym_boolean] = STATE(5949),
    [sym_option_member] = STATE(5986),
    [sym_keyword_identifier] = STATE(5949),
    [sym_codeunit_keyword] = STATE(5754),
    [sym_xmlport_keyword] = STATE(5754),
    [sym_enum_keyword] = STATE(5754),
    [sym_keyword_as_identifier] = STATE(5949),
    [sym_identifier] = ACTIONS(4836),
    [anon_sym_DOT] = ACTIONS(391),
    [anon_sym_EQ] = ACTIONS(389),
    [anon_sym_COMMA] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(4884),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [aux_sym_where_condition_token1] = ACTIONS(4844),
    [anon_sym_DOT_DOT] = ACTIONS(389),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_STAR] = ACTIONS(391),
    [anon_sym_LBRACK] = ACTIONS(389),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4848),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [aux_sym_basic_type_token53] = ACTIONS(4844),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4844),
    [aux_sym_separator_action_token1] = ACTIONS(4844),
    [aux_sym_type_declaration_token1] = ACTIONS(4844),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(389),
    [aux_sym__expression_token1] = ACTIONS(389),
    [aux_sym__expression_token2] = ACTIONS(389),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4846),
    [anon_sym_SLASH] = ACTIONS(391),
    [anon_sym_div] = ACTIONS(391),
    [anon_sym_DIV] = ACTIONS(391),
    [anon_sym_Div] = ACTIONS(391),
    [anon_sym_mod] = ACTIONS(391),
    [anon_sym_MOD] = ACTIONS(391),
    [anon_sym_Mod] = ACTIONS(391),
    [anon_sym_PLUS] = ACTIONS(391),
    [anon_sym_GT_EQ] = ACTIONS(389),
    [anon_sym_LT_EQ] = ACTIONS(389),
    [anon_sym_GT] = ACTIONS(391),
    [anon_sym_LT] = ACTIONS(391),
    [anon_sym_LT_GT] = ACTIONS(389),
    [anon_sym_and] = ACTIONS(391),
    [anon_sym_AND] = ACTIONS(391),
    [anon_sym_And] = ACTIONS(391),
    [anon_sym_or] = ACTIONS(391),
    [anon_sym_OR] = ACTIONS(391),
    [anon_sym_Or] = ACTIONS(391),
    [anon_sym_xor] = ACTIONS(391),
    [anon_sym_XOR] = ACTIONS(391),
    [anon_sym_Xor] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(389),
    [anon_sym_in] = ACTIONS(391),
    [anon_sym_IN] = ACTIONS(391),
    [anon_sym_In] = ACTIONS(391),
    [anon_sym_to] = ACTIONS(391),
    [anon_sym_TO] = ACTIONS(391),
    [anon_sym_To] = ACTIONS(391),
    [anon_sym_downto] = ACTIONS(391),
    [anon_sym_DOWNTO] = ACTIONS(391),
    [anon_sym_Downto] = ACTIONS(391),
    [sym_page_keyword] = ACTIONS(4846),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(4846),
    [sym_query_keyword] = ACTIONS(4846),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_local_keyword] = ACTIONS(4836),
    [sym_internal_keyword] = ACTIONS(4836),
    [sym_protected_keyword] = ACTIONS(4836),
    [sym_key_keyword] = ACTIONS(4844),
    [sym_dataset_keyword] = ACTIONS(4844),
    [sym_quoted_identifier] = ACTIONS(4856),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4856),
    [sym_integer] = ACTIONS(4856),
  },
  [STATE(1874)] = {
    [sym_identifier] = ACTIONS(4329),
    [anon_sym_SEMI] = ACTIONS(4331),
    [anon_sym_DASH] = ACTIONS(4331),
    [aux_sym_boolean_token1] = ACTIONS(4329),
    [aux_sym_boolean_token2] = ACTIONS(4329),
    [sym_decimal] = ACTIONS(4329),
    [anon_sym_LPAREN] = ACTIONS(4331),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4329),
    [anon_sym_LBRACK] = ACTIONS(4331),
    [aux_sym_record_type_token1] = ACTIONS(4329),
    [aux_sym_basic_type_token21] = ACTIONS(4329),
    [aux_sym_basic_type_token22] = ACTIONS(4329),
    [aux_sym_basic_type_token48] = ACTIONS(4329),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4329),
    [anon_sym_POUNDif] = ACTIONS(4331),
    [anon_sym_POUNDIF] = ACTIONS(4331),
    [anon_sym_POUNDIf] = ACTIONS(4331),
    [anon_sym_not] = ACTIONS(4329),
    [anon_sym_NOT] = ACTIONS(4329),
    [anon_sym_Not] = ACTIONS(4329),
    [anon_sym_POUNDelse] = ACTIONS(4331),
    [anon_sym_POUNDELSE] = ACTIONS(4331),
    [anon_sym_POUNDElse] = ACTIONS(4331),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4329),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4329),
    [anon_sym_PLUS] = ACTIONS(4331),
    [sym_datetime_literal] = ACTIONS(4331),
    [sym_date_literal] = ACTIONS(4329),
    [sym_time_literal] = ACTIONS(4329),
    [sym_biginteger_literal] = ACTIONS(4331),
    [anon_sym_if] = ACTIONS(4329),
    [anon_sym_IF] = ACTIONS(4329),
    [anon_sym_If] = ACTIONS(4329),
    [anon_sym_else] = ACTIONS(4329),
    [anon_sym_ELSE] = ACTIONS(4329),
    [anon_sym_Else] = ACTIONS(4329),
    [anon_sym_case] = ACTIONS(4329),
    [anon_sym_CASE] = ACTIONS(4329),
    [anon_sym_Case] = ACTIONS(4329),
    [anon_sym_for] = ACTIONS(4329),
    [anon_sym_FOR] = ACTIONS(4329),
    [anon_sym_For] = ACTIONS(4329),
    [anon_sym_foreach] = ACTIONS(4329),
    [anon_sym_FOREACH] = ACTIONS(4329),
    [anon_sym_Foreach] = ACTIONS(4329),
    [anon_sym_while] = ACTIONS(4329),
    [anon_sym_WHILE] = ACTIONS(4329),
    [anon_sym_While] = ACTIONS(4329),
    [anon_sym_repeat] = ACTIONS(4329),
    [anon_sym_REPEAT] = ACTIONS(4329),
    [anon_sym_Repeat] = ACTIONS(4329),
    [anon_sym_until] = ACTIONS(4329),
    [anon_sym_UNTIL] = ACTIONS(4329),
    [anon_sym_Until] = ACTIONS(4329),
    [anon_sym_exit] = ACTIONS(4329),
    [anon_sym_EXIT] = ACTIONS(4329),
    [anon_sym_Exit] = ACTIONS(4329),
    [anon_sym_continue] = ACTIONS(4329),
    [anon_sym_CONTINUE] = ACTIONS(4329),
    [anon_sym_Continue] = ACTIONS(4329),
    [anon_sym_break] = ACTIONS(4329),
    [anon_sym_BREAK] = ACTIONS(4329),
    [anon_sym_Break] = ACTIONS(4329),
    [anon_sym_with] = ACTIONS(4329),
    [anon_sym_WITH] = ACTIONS(4329),
    [anon_sym_With] = ACTIONS(4329),
    [sym_asserterror_keyword] = ACTIONS(4331),
    [sym_page_keyword] = ACTIONS(4329),
    [anon_sym_codeunit] = ACTIONS(4329),
    [anon_sym_CODEUNIT] = ACTIONS(4329),
    [anon_sym_Codeunit] = ACTIONS(4329),
    [anon_sym_CodeUnit] = ACTIONS(4329),
    [anon_sym_COdeunit] = ACTIONS(4329),
    [anon_sym_codeUnit] = ACTIONS(4329),
    [sym_report_keyword] = ACTIONS(4329),
    [sym_query_keyword] = ACTIONS(4329),
    [anon_sym_xmlport] = ACTIONS(4329),
    [anon_sym_XMLPORT] = ACTIONS(4329),
    [anon_sym_Xmlport] = ACTIONS(4329),
    [anon_sym_XMLport] = ACTIONS(4329),
    [anon_sym_XMLPort] = ACTIONS(4329),
    [anon_sym_XmlPort] = ACTIONS(4329),
    [anon_sym_enum] = ACTIONS(4329),
    [anon_sym_ENUM] = ACTIONS(4329),
    [anon_sym_Enum] = ACTIONS(4329),
    [anon_sym_eNUM] = ACTIONS(4329),
    [anon_sym_eNum] = ACTIONS(4329),
    [anon_sym_ENum] = ACTIONS(4329),
    [sym_quoted_identifier] = ACTIONS(4331),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4331),
    [sym_integer] = ACTIONS(4329),
    [sym_continue_as_identifier] = ACTIONS(4331),
    [sym_preproc_open] = ACTIONS(4331),
  },
  [STATE(1875)] = {
    [sym_identifier] = ACTIONS(4333),
    [anon_sym_SEMI] = ACTIONS(4335),
    [anon_sym_DASH] = ACTIONS(4335),
    [aux_sym_boolean_token1] = ACTIONS(4333),
    [aux_sym_boolean_token2] = ACTIONS(4333),
    [sym_decimal] = ACTIONS(4333),
    [anon_sym_LPAREN] = ACTIONS(4335),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4333),
    [anon_sym_LBRACK] = ACTIONS(4335),
    [aux_sym_record_type_token1] = ACTIONS(4333),
    [aux_sym_basic_type_token21] = ACTIONS(4333),
    [aux_sym_basic_type_token22] = ACTIONS(4333),
    [aux_sym_basic_type_token48] = ACTIONS(4333),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4333),
    [anon_sym_POUNDif] = ACTIONS(4335),
    [anon_sym_POUNDIF] = ACTIONS(4335),
    [anon_sym_POUNDIf] = ACTIONS(4335),
    [anon_sym_not] = ACTIONS(4333),
    [anon_sym_NOT] = ACTIONS(4333),
    [anon_sym_Not] = ACTIONS(4333),
    [anon_sym_POUNDelse] = ACTIONS(4335),
    [anon_sym_POUNDELSE] = ACTIONS(4335),
    [anon_sym_POUNDElse] = ACTIONS(4335),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4333),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4333),
    [anon_sym_PLUS] = ACTIONS(4335),
    [sym_datetime_literal] = ACTIONS(4335),
    [sym_date_literal] = ACTIONS(4333),
    [sym_time_literal] = ACTIONS(4333),
    [sym_biginteger_literal] = ACTIONS(4335),
    [anon_sym_if] = ACTIONS(4333),
    [anon_sym_IF] = ACTIONS(4333),
    [anon_sym_If] = ACTIONS(4333),
    [anon_sym_else] = ACTIONS(4333),
    [anon_sym_ELSE] = ACTIONS(4333),
    [anon_sym_Else] = ACTIONS(4333),
    [anon_sym_case] = ACTIONS(4333),
    [anon_sym_CASE] = ACTIONS(4333),
    [anon_sym_Case] = ACTIONS(4333),
    [anon_sym_for] = ACTIONS(4333),
    [anon_sym_FOR] = ACTIONS(4333),
    [anon_sym_For] = ACTIONS(4333),
    [anon_sym_foreach] = ACTIONS(4333),
    [anon_sym_FOREACH] = ACTIONS(4333),
    [anon_sym_Foreach] = ACTIONS(4333),
    [anon_sym_while] = ACTIONS(4333),
    [anon_sym_WHILE] = ACTIONS(4333),
    [anon_sym_While] = ACTIONS(4333),
    [anon_sym_repeat] = ACTIONS(4333),
    [anon_sym_REPEAT] = ACTIONS(4333),
    [anon_sym_Repeat] = ACTIONS(4333),
    [anon_sym_until] = ACTIONS(4333),
    [anon_sym_UNTIL] = ACTIONS(4333),
    [anon_sym_Until] = ACTIONS(4333),
    [anon_sym_exit] = ACTIONS(4333),
    [anon_sym_EXIT] = ACTIONS(4333),
    [anon_sym_Exit] = ACTIONS(4333),
    [anon_sym_continue] = ACTIONS(4333),
    [anon_sym_CONTINUE] = ACTIONS(4333),
    [anon_sym_Continue] = ACTIONS(4333),
    [anon_sym_break] = ACTIONS(4333),
    [anon_sym_BREAK] = ACTIONS(4333),
    [anon_sym_Break] = ACTIONS(4333),
    [anon_sym_with] = ACTIONS(4333),
    [anon_sym_WITH] = ACTIONS(4333),
    [anon_sym_With] = ACTIONS(4333),
    [sym_asserterror_keyword] = ACTIONS(4335),
    [sym_page_keyword] = ACTIONS(4333),
    [anon_sym_codeunit] = ACTIONS(4333),
    [anon_sym_CODEUNIT] = ACTIONS(4333),
    [anon_sym_Codeunit] = ACTIONS(4333),
    [anon_sym_CodeUnit] = ACTIONS(4333),
    [anon_sym_COdeunit] = ACTIONS(4333),
    [anon_sym_codeUnit] = ACTIONS(4333),
    [sym_report_keyword] = ACTIONS(4333),
    [sym_query_keyword] = ACTIONS(4333),
    [anon_sym_xmlport] = ACTIONS(4333),
    [anon_sym_XMLPORT] = ACTIONS(4333),
    [anon_sym_Xmlport] = ACTIONS(4333),
    [anon_sym_XMLport] = ACTIONS(4333),
    [anon_sym_XMLPort] = ACTIONS(4333),
    [anon_sym_XmlPort] = ACTIONS(4333),
    [anon_sym_enum] = ACTIONS(4333),
    [anon_sym_ENUM] = ACTIONS(4333),
    [anon_sym_Enum] = ACTIONS(4333),
    [anon_sym_eNUM] = ACTIONS(4333),
    [anon_sym_eNum] = ACTIONS(4333),
    [anon_sym_ENum] = ACTIONS(4333),
    [sym_quoted_identifier] = ACTIONS(4335),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4335),
    [sym_integer] = ACTIONS(4333),
    [sym_continue_as_identifier] = ACTIONS(4335),
    [sym_preproc_open] = ACTIONS(4335),
  },
  [STATE(1876)] = {
    [sym_identifier] = ACTIONS(4700),
    [anon_sym_SEMI] = ACTIONS(4702),
    [anon_sym_DASH] = ACTIONS(4702),
    [aux_sym_boolean_token1] = ACTIONS(4700),
    [aux_sym_boolean_token2] = ACTIONS(4700),
    [sym_decimal] = ACTIONS(4700),
    [anon_sym_LPAREN] = ACTIONS(4702),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4700),
    [anon_sym_LBRACK] = ACTIONS(4702),
    [aux_sym_record_type_token1] = ACTIONS(4700),
    [aux_sym_basic_type_token21] = ACTIONS(4700),
    [aux_sym_basic_type_token22] = ACTIONS(4700),
    [aux_sym_basic_type_token48] = ACTIONS(4700),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4700),
    [anon_sym_POUNDif] = ACTIONS(4702),
    [anon_sym_POUNDIF] = ACTIONS(4702),
    [anon_sym_POUNDIf] = ACTIONS(4702),
    [anon_sym_not] = ACTIONS(4700),
    [anon_sym_NOT] = ACTIONS(4700),
    [anon_sym_Not] = ACTIONS(4700),
    [anon_sym_POUNDelse] = ACTIONS(4702),
    [anon_sym_POUNDELSE] = ACTIONS(4702),
    [anon_sym_POUNDElse] = ACTIONS(4702),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4700),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4700),
    [anon_sym_PLUS] = ACTIONS(4702),
    [sym_datetime_literal] = ACTIONS(4702),
    [sym_date_literal] = ACTIONS(4700),
    [sym_time_literal] = ACTIONS(4700),
    [sym_biginteger_literal] = ACTIONS(4702),
    [anon_sym_if] = ACTIONS(4700),
    [anon_sym_IF] = ACTIONS(4700),
    [anon_sym_If] = ACTIONS(4700),
    [anon_sym_else] = ACTIONS(4700),
    [anon_sym_ELSE] = ACTIONS(4700),
    [anon_sym_Else] = ACTIONS(4700),
    [anon_sym_case] = ACTIONS(4700),
    [anon_sym_CASE] = ACTIONS(4700),
    [anon_sym_Case] = ACTIONS(4700),
    [anon_sym_for] = ACTIONS(4700),
    [anon_sym_FOR] = ACTIONS(4700),
    [anon_sym_For] = ACTIONS(4700),
    [anon_sym_foreach] = ACTIONS(4700),
    [anon_sym_FOREACH] = ACTIONS(4700),
    [anon_sym_Foreach] = ACTIONS(4700),
    [anon_sym_while] = ACTIONS(4700),
    [anon_sym_WHILE] = ACTIONS(4700),
    [anon_sym_While] = ACTIONS(4700),
    [anon_sym_repeat] = ACTIONS(4700),
    [anon_sym_REPEAT] = ACTIONS(4700),
    [anon_sym_Repeat] = ACTIONS(4700),
    [anon_sym_until] = ACTIONS(4700),
    [anon_sym_UNTIL] = ACTIONS(4700),
    [anon_sym_Until] = ACTIONS(4700),
    [anon_sym_exit] = ACTIONS(4700),
    [anon_sym_EXIT] = ACTIONS(4700),
    [anon_sym_Exit] = ACTIONS(4700),
    [anon_sym_continue] = ACTIONS(4700),
    [anon_sym_CONTINUE] = ACTIONS(4700),
    [anon_sym_Continue] = ACTIONS(4700),
    [anon_sym_break] = ACTIONS(4700),
    [anon_sym_BREAK] = ACTIONS(4700),
    [anon_sym_Break] = ACTIONS(4700),
    [anon_sym_with] = ACTIONS(4700),
    [anon_sym_WITH] = ACTIONS(4700),
    [anon_sym_With] = ACTIONS(4700),
    [sym_asserterror_keyword] = ACTIONS(4702),
    [sym_page_keyword] = ACTIONS(4700),
    [anon_sym_codeunit] = ACTIONS(4700),
    [anon_sym_CODEUNIT] = ACTIONS(4700),
    [anon_sym_Codeunit] = ACTIONS(4700),
    [anon_sym_CodeUnit] = ACTIONS(4700),
    [anon_sym_COdeunit] = ACTIONS(4700),
    [anon_sym_codeUnit] = ACTIONS(4700),
    [sym_report_keyword] = ACTIONS(4700),
    [sym_query_keyword] = ACTIONS(4700),
    [anon_sym_xmlport] = ACTIONS(4700),
    [anon_sym_XMLPORT] = ACTIONS(4700),
    [anon_sym_Xmlport] = ACTIONS(4700),
    [anon_sym_XMLport] = ACTIONS(4700),
    [anon_sym_XMLPort] = ACTIONS(4700),
    [anon_sym_XmlPort] = ACTIONS(4700),
    [anon_sym_enum] = ACTIONS(4700),
    [anon_sym_ENUM] = ACTIONS(4700),
    [anon_sym_Enum] = ACTIONS(4700),
    [anon_sym_eNUM] = ACTIONS(4700),
    [anon_sym_eNum] = ACTIONS(4700),
    [anon_sym_ENum] = ACTIONS(4700),
    [sym_quoted_identifier] = ACTIONS(4702),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4702),
    [sym_integer] = ACTIONS(4700),
    [sym_continue_as_identifier] = ACTIONS(4702),
    [sym_preproc_open] = ACTIONS(4702),
  },
  [STATE(1877)] = {
    [sym_identifier] = ACTIONS(4337),
    [anon_sym_SEMI] = ACTIONS(4339),
    [anon_sym_DASH] = ACTIONS(4339),
    [aux_sym_boolean_token1] = ACTIONS(4337),
    [aux_sym_boolean_token2] = ACTIONS(4337),
    [sym_decimal] = ACTIONS(4337),
    [anon_sym_LPAREN] = ACTIONS(4339),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4337),
    [anon_sym_LBRACK] = ACTIONS(4339),
    [aux_sym_record_type_token1] = ACTIONS(4337),
    [aux_sym_basic_type_token21] = ACTIONS(4337),
    [aux_sym_basic_type_token22] = ACTIONS(4337),
    [aux_sym_basic_type_token48] = ACTIONS(4337),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4337),
    [anon_sym_POUNDif] = ACTIONS(4339),
    [anon_sym_POUNDIF] = ACTIONS(4339),
    [anon_sym_POUNDIf] = ACTIONS(4339),
    [anon_sym_not] = ACTIONS(4337),
    [anon_sym_NOT] = ACTIONS(4337),
    [anon_sym_Not] = ACTIONS(4337),
    [anon_sym_POUNDelse] = ACTIONS(4339),
    [anon_sym_POUNDELSE] = ACTIONS(4339),
    [anon_sym_POUNDElse] = ACTIONS(4339),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4337),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4337),
    [anon_sym_PLUS] = ACTIONS(4339),
    [sym_datetime_literal] = ACTIONS(4339),
    [sym_date_literal] = ACTIONS(4337),
    [sym_time_literal] = ACTIONS(4337),
    [sym_biginteger_literal] = ACTIONS(4339),
    [anon_sym_if] = ACTIONS(4337),
    [anon_sym_IF] = ACTIONS(4337),
    [anon_sym_If] = ACTIONS(4337),
    [anon_sym_else] = ACTIONS(4337),
    [anon_sym_ELSE] = ACTIONS(4337),
    [anon_sym_Else] = ACTIONS(4337),
    [anon_sym_case] = ACTIONS(4337),
    [anon_sym_CASE] = ACTIONS(4337),
    [anon_sym_Case] = ACTIONS(4337),
    [anon_sym_for] = ACTIONS(4337),
    [anon_sym_FOR] = ACTIONS(4337),
    [anon_sym_For] = ACTIONS(4337),
    [anon_sym_foreach] = ACTIONS(4337),
    [anon_sym_FOREACH] = ACTIONS(4337),
    [anon_sym_Foreach] = ACTIONS(4337),
    [anon_sym_while] = ACTIONS(4337),
    [anon_sym_WHILE] = ACTIONS(4337),
    [anon_sym_While] = ACTIONS(4337),
    [anon_sym_repeat] = ACTIONS(4337),
    [anon_sym_REPEAT] = ACTIONS(4337),
    [anon_sym_Repeat] = ACTIONS(4337),
    [anon_sym_until] = ACTIONS(4337),
    [anon_sym_UNTIL] = ACTIONS(4337),
    [anon_sym_Until] = ACTIONS(4337),
    [anon_sym_exit] = ACTIONS(4337),
    [anon_sym_EXIT] = ACTIONS(4337),
    [anon_sym_Exit] = ACTIONS(4337),
    [anon_sym_continue] = ACTIONS(4337),
    [anon_sym_CONTINUE] = ACTIONS(4337),
    [anon_sym_Continue] = ACTIONS(4337),
    [anon_sym_break] = ACTIONS(4337),
    [anon_sym_BREAK] = ACTIONS(4337),
    [anon_sym_Break] = ACTIONS(4337),
    [anon_sym_with] = ACTIONS(4337),
    [anon_sym_WITH] = ACTIONS(4337),
    [anon_sym_With] = ACTIONS(4337),
    [sym_asserterror_keyword] = ACTIONS(4339),
    [sym_page_keyword] = ACTIONS(4337),
    [anon_sym_codeunit] = ACTIONS(4337),
    [anon_sym_CODEUNIT] = ACTIONS(4337),
    [anon_sym_Codeunit] = ACTIONS(4337),
    [anon_sym_CodeUnit] = ACTIONS(4337),
    [anon_sym_COdeunit] = ACTIONS(4337),
    [anon_sym_codeUnit] = ACTIONS(4337),
    [sym_report_keyword] = ACTIONS(4337),
    [sym_query_keyword] = ACTIONS(4337),
    [anon_sym_xmlport] = ACTIONS(4337),
    [anon_sym_XMLPORT] = ACTIONS(4337),
    [anon_sym_Xmlport] = ACTIONS(4337),
    [anon_sym_XMLport] = ACTIONS(4337),
    [anon_sym_XMLPort] = ACTIONS(4337),
    [anon_sym_XmlPort] = ACTIONS(4337),
    [anon_sym_enum] = ACTIONS(4337),
    [anon_sym_ENUM] = ACTIONS(4337),
    [anon_sym_Enum] = ACTIONS(4337),
    [anon_sym_eNUM] = ACTIONS(4337),
    [anon_sym_eNum] = ACTIONS(4337),
    [anon_sym_ENum] = ACTIONS(4337),
    [sym_quoted_identifier] = ACTIONS(4339),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4339),
    [sym_integer] = ACTIONS(4337),
    [sym_continue_as_identifier] = ACTIONS(4339),
    [sym_preproc_open] = ACTIONS(4339),
  },
  [STATE(1878)] = {
    [sym_identifier] = ACTIONS(4341),
    [anon_sym_SEMI] = ACTIONS(4343),
    [anon_sym_DASH] = ACTIONS(4343),
    [aux_sym_boolean_token1] = ACTIONS(4341),
    [aux_sym_boolean_token2] = ACTIONS(4341),
    [sym_decimal] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4343),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4341),
    [anon_sym_LBRACK] = ACTIONS(4343),
    [aux_sym_record_type_token1] = ACTIONS(4341),
    [aux_sym_basic_type_token21] = ACTIONS(4341),
    [aux_sym_basic_type_token22] = ACTIONS(4341),
    [aux_sym_basic_type_token48] = ACTIONS(4341),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4341),
    [anon_sym_POUNDif] = ACTIONS(4343),
    [anon_sym_POUNDIF] = ACTIONS(4343),
    [anon_sym_POUNDIf] = ACTIONS(4343),
    [anon_sym_not] = ACTIONS(4341),
    [anon_sym_NOT] = ACTIONS(4341),
    [anon_sym_Not] = ACTIONS(4341),
    [anon_sym_POUNDelse] = ACTIONS(4343),
    [anon_sym_POUNDELSE] = ACTIONS(4343),
    [anon_sym_POUNDElse] = ACTIONS(4343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4341),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4343),
    [sym_datetime_literal] = ACTIONS(4343),
    [sym_date_literal] = ACTIONS(4341),
    [sym_time_literal] = ACTIONS(4341),
    [sym_biginteger_literal] = ACTIONS(4343),
    [anon_sym_if] = ACTIONS(4341),
    [anon_sym_IF] = ACTIONS(4341),
    [anon_sym_If] = ACTIONS(4341),
    [anon_sym_else] = ACTIONS(4341),
    [anon_sym_ELSE] = ACTIONS(4341),
    [anon_sym_Else] = ACTIONS(4341),
    [anon_sym_case] = ACTIONS(4341),
    [anon_sym_CASE] = ACTIONS(4341),
    [anon_sym_Case] = ACTIONS(4341),
    [anon_sym_for] = ACTIONS(4341),
    [anon_sym_FOR] = ACTIONS(4341),
    [anon_sym_For] = ACTIONS(4341),
    [anon_sym_foreach] = ACTIONS(4341),
    [anon_sym_FOREACH] = ACTIONS(4341),
    [anon_sym_Foreach] = ACTIONS(4341),
    [anon_sym_while] = ACTIONS(4341),
    [anon_sym_WHILE] = ACTIONS(4341),
    [anon_sym_While] = ACTIONS(4341),
    [anon_sym_repeat] = ACTIONS(4341),
    [anon_sym_REPEAT] = ACTIONS(4341),
    [anon_sym_Repeat] = ACTIONS(4341),
    [anon_sym_until] = ACTIONS(4341),
    [anon_sym_UNTIL] = ACTIONS(4341),
    [anon_sym_Until] = ACTIONS(4341),
    [anon_sym_exit] = ACTIONS(4341),
    [anon_sym_EXIT] = ACTIONS(4341),
    [anon_sym_Exit] = ACTIONS(4341),
    [anon_sym_continue] = ACTIONS(4341),
    [anon_sym_CONTINUE] = ACTIONS(4341),
    [anon_sym_Continue] = ACTIONS(4341),
    [anon_sym_break] = ACTIONS(4341),
    [anon_sym_BREAK] = ACTIONS(4341),
    [anon_sym_Break] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4341),
    [anon_sym_WITH] = ACTIONS(4341),
    [anon_sym_With] = ACTIONS(4341),
    [sym_asserterror_keyword] = ACTIONS(4343),
    [sym_page_keyword] = ACTIONS(4341),
    [anon_sym_codeunit] = ACTIONS(4341),
    [anon_sym_CODEUNIT] = ACTIONS(4341),
    [anon_sym_Codeunit] = ACTIONS(4341),
    [anon_sym_CodeUnit] = ACTIONS(4341),
    [anon_sym_COdeunit] = ACTIONS(4341),
    [anon_sym_codeUnit] = ACTIONS(4341),
    [sym_report_keyword] = ACTIONS(4341),
    [sym_query_keyword] = ACTIONS(4341),
    [anon_sym_xmlport] = ACTIONS(4341),
    [anon_sym_XMLPORT] = ACTIONS(4341),
    [anon_sym_Xmlport] = ACTIONS(4341),
    [anon_sym_XMLport] = ACTIONS(4341),
    [anon_sym_XMLPort] = ACTIONS(4341),
    [anon_sym_XmlPort] = ACTIONS(4341),
    [anon_sym_enum] = ACTIONS(4341),
    [anon_sym_ENUM] = ACTIONS(4341),
    [anon_sym_Enum] = ACTIONS(4341),
    [anon_sym_eNUM] = ACTIONS(4341),
    [anon_sym_eNum] = ACTIONS(4341),
    [anon_sym_ENum] = ACTIONS(4341),
    [sym_quoted_identifier] = ACTIONS(4343),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4343),
    [sym_integer] = ACTIONS(4341),
    [sym_continue_as_identifier] = ACTIONS(4343),
    [sym_preproc_open] = ACTIONS(4343),
  },
  [STATE(1879)] = {
    [sym_identifier] = ACTIONS(4345),
    [anon_sym_SEMI] = ACTIONS(4347),
    [anon_sym_DASH] = ACTIONS(4347),
    [aux_sym_boolean_token1] = ACTIONS(4345),
    [aux_sym_boolean_token2] = ACTIONS(4345),
    [sym_decimal] = ACTIONS(4345),
    [anon_sym_LPAREN] = ACTIONS(4347),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4345),
    [anon_sym_LBRACK] = ACTIONS(4347),
    [aux_sym_record_type_token1] = ACTIONS(4345),
    [aux_sym_basic_type_token21] = ACTIONS(4345),
    [aux_sym_basic_type_token22] = ACTIONS(4345),
    [aux_sym_basic_type_token48] = ACTIONS(4345),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4345),
    [anon_sym_POUNDif] = ACTIONS(4347),
    [anon_sym_POUNDIF] = ACTIONS(4347),
    [anon_sym_POUNDIf] = ACTIONS(4347),
    [anon_sym_not] = ACTIONS(4345),
    [anon_sym_NOT] = ACTIONS(4345),
    [anon_sym_Not] = ACTIONS(4345),
    [anon_sym_POUNDelse] = ACTIONS(4347),
    [anon_sym_POUNDELSE] = ACTIONS(4347),
    [anon_sym_POUNDElse] = ACTIONS(4347),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4345),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4345),
    [anon_sym_PLUS] = ACTIONS(4347),
    [sym_datetime_literal] = ACTIONS(4347),
    [sym_date_literal] = ACTIONS(4345),
    [sym_time_literal] = ACTIONS(4345),
    [sym_biginteger_literal] = ACTIONS(4347),
    [anon_sym_if] = ACTIONS(4345),
    [anon_sym_IF] = ACTIONS(4345),
    [anon_sym_If] = ACTIONS(4345),
    [anon_sym_else] = ACTIONS(4345),
    [anon_sym_ELSE] = ACTIONS(4345),
    [anon_sym_Else] = ACTIONS(4345),
    [anon_sym_case] = ACTIONS(4345),
    [anon_sym_CASE] = ACTIONS(4345),
    [anon_sym_Case] = ACTIONS(4345),
    [anon_sym_for] = ACTIONS(4345),
    [anon_sym_FOR] = ACTIONS(4345),
    [anon_sym_For] = ACTIONS(4345),
    [anon_sym_foreach] = ACTIONS(4345),
    [anon_sym_FOREACH] = ACTIONS(4345),
    [anon_sym_Foreach] = ACTIONS(4345),
    [anon_sym_while] = ACTIONS(4345),
    [anon_sym_WHILE] = ACTIONS(4345),
    [anon_sym_While] = ACTIONS(4345),
    [anon_sym_repeat] = ACTIONS(4345),
    [anon_sym_REPEAT] = ACTIONS(4345),
    [anon_sym_Repeat] = ACTIONS(4345),
    [anon_sym_until] = ACTIONS(4345),
    [anon_sym_UNTIL] = ACTIONS(4345),
    [anon_sym_Until] = ACTIONS(4345),
    [anon_sym_exit] = ACTIONS(4345),
    [anon_sym_EXIT] = ACTIONS(4345),
    [anon_sym_Exit] = ACTIONS(4345),
    [anon_sym_continue] = ACTIONS(4345),
    [anon_sym_CONTINUE] = ACTIONS(4345),
    [anon_sym_Continue] = ACTIONS(4345),
    [anon_sym_break] = ACTIONS(4345),
    [anon_sym_BREAK] = ACTIONS(4345),
    [anon_sym_Break] = ACTIONS(4345),
    [anon_sym_with] = ACTIONS(4345),
    [anon_sym_WITH] = ACTIONS(4345),
    [anon_sym_With] = ACTIONS(4345),
    [sym_asserterror_keyword] = ACTIONS(4347),
    [sym_page_keyword] = ACTIONS(4345),
    [anon_sym_codeunit] = ACTIONS(4345),
    [anon_sym_CODEUNIT] = ACTIONS(4345),
    [anon_sym_Codeunit] = ACTIONS(4345),
    [anon_sym_CodeUnit] = ACTIONS(4345),
    [anon_sym_COdeunit] = ACTIONS(4345),
    [anon_sym_codeUnit] = ACTIONS(4345),
    [sym_report_keyword] = ACTIONS(4345),
    [sym_query_keyword] = ACTIONS(4345),
    [anon_sym_xmlport] = ACTIONS(4345),
    [anon_sym_XMLPORT] = ACTIONS(4345),
    [anon_sym_Xmlport] = ACTIONS(4345),
    [anon_sym_XMLport] = ACTIONS(4345),
    [anon_sym_XMLPort] = ACTIONS(4345),
    [anon_sym_XmlPort] = ACTIONS(4345),
    [anon_sym_enum] = ACTIONS(4345),
    [anon_sym_ENUM] = ACTIONS(4345),
    [anon_sym_Enum] = ACTIONS(4345),
    [anon_sym_eNUM] = ACTIONS(4345),
    [anon_sym_eNum] = ACTIONS(4345),
    [anon_sym_ENum] = ACTIONS(4345),
    [sym_quoted_identifier] = ACTIONS(4347),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4347),
    [sym_integer] = ACTIONS(4345),
    [sym_continue_as_identifier] = ACTIONS(4347),
    [sym_preproc_open] = ACTIONS(4347),
  },
  [STATE(1880)] = {
    [sym_identifier] = ACTIONS(4349),
    [anon_sym_SEMI] = ACTIONS(4351),
    [anon_sym_DASH] = ACTIONS(4351),
    [aux_sym_boolean_token1] = ACTIONS(4349),
    [aux_sym_boolean_token2] = ACTIONS(4349),
    [sym_decimal] = ACTIONS(4349),
    [anon_sym_LPAREN] = ACTIONS(4351),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4349),
    [anon_sym_LBRACK] = ACTIONS(4351),
    [aux_sym_record_type_token1] = ACTIONS(4349),
    [aux_sym_basic_type_token21] = ACTIONS(4349),
    [aux_sym_basic_type_token22] = ACTIONS(4349),
    [aux_sym_basic_type_token48] = ACTIONS(4349),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4349),
    [anon_sym_POUNDif] = ACTIONS(4351),
    [anon_sym_POUNDIF] = ACTIONS(4351),
    [anon_sym_POUNDIf] = ACTIONS(4351),
    [anon_sym_not] = ACTIONS(4349),
    [anon_sym_NOT] = ACTIONS(4349),
    [anon_sym_Not] = ACTIONS(4349),
    [anon_sym_POUNDelse] = ACTIONS(4351),
    [anon_sym_POUNDELSE] = ACTIONS(4351),
    [anon_sym_POUNDElse] = ACTIONS(4351),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4349),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4349),
    [anon_sym_PLUS] = ACTIONS(4351),
    [sym_datetime_literal] = ACTIONS(4351),
    [sym_date_literal] = ACTIONS(4349),
    [sym_time_literal] = ACTIONS(4349),
    [sym_biginteger_literal] = ACTIONS(4351),
    [anon_sym_if] = ACTIONS(4349),
    [anon_sym_IF] = ACTIONS(4349),
    [anon_sym_If] = ACTIONS(4349),
    [anon_sym_else] = ACTIONS(4349),
    [anon_sym_ELSE] = ACTIONS(4349),
    [anon_sym_Else] = ACTIONS(4349),
    [anon_sym_case] = ACTIONS(4349),
    [anon_sym_CASE] = ACTIONS(4349),
    [anon_sym_Case] = ACTIONS(4349),
    [anon_sym_for] = ACTIONS(4349),
    [anon_sym_FOR] = ACTIONS(4349),
    [anon_sym_For] = ACTIONS(4349),
    [anon_sym_foreach] = ACTIONS(4349),
    [anon_sym_FOREACH] = ACTIONS(4349),
    [anon_sym_Foreach] = ACTIONS(4349),
    [anon_sym_while] = ACTIONS(4349),
    [anon_sym_WHILE] = ACTIONS(4349),
    [anon_sym_While] = ACTIONS(4349),
    [anon_sym_repeat] = ACTIONS(4349),
    [anon_sym_REPEAT] = ACTIONS(4349),
    [anon_sym_Repeat] = ACTIONS(4349),
    [anon_sym_until] = ACTIONS(4349),
    [anon_sym_UNTIL] = ACTIONS(4349),
    [anon_sym_Until] = ACTIONS(4349),
    [anon_sym_exit] = ACTIONS(4349),
    [anon_sym_EXIT] = ACTIONS(4349),
    [anon_sym_Exit] = ACTIONS(4349),
    [anon_sym_continue] = ACTIONS(4349),
    [anon_sym_CONTINUE] = ACTIONS(4349),
    [anon_sym_Continue] = ACTIONS(4349),
    [anon_sym_break] = ACTIONS(4349),
    [anon_sym_BREAK] = ACTIONS(4349),
    [anon_sym_Break] = ACTIONS(4349),
    [anon_sym_with] = ACTIONS(4349),
    [anon_sym_WITH] = ACTIONS(4349),
    [anon_sym_With] = ACTIONS(4349),
    [sym_asserterror_keyword] = ACTIONS(4351),
    [sym_page_keyword] = ACTIONS(4349),
    [anon_sym_codeunit] = ACTIONS(4349),
    [anon_sym_CODEUNIT] = ACTIONS(4349),
    [anon_sym_Codeunit] = ACTIONS(4349),
    [anon_sym_CodeUnit] = ACTIONS(4349),
    [anon_sym_COdeunit] = ACTIONS(4349),
    [anon_sym_codeUnit] = ACTIONS(4349),
    [sym_report_keyword] = ACTIONS(4349),
    [sym_query_keyword] = ACTIONS(4349),
    [anon_sym_xmlport] = ACTIONS(4349),
    [anon_sym_XMLPORT] = ACTIONS(4349),
    [anon_sym_Xmlport] = ACTIONS(4349),
    [anon_sym_XMLport] = ACTIONS(4349),
    [anon_sym_XMLPort] = ACTIONS(4349),
    [anon_sym_XmlPort] = ACTIONS(4349),
    [anon_sym_enum] = ACTIONS(4349),
    [anon_sym_ENUM] = ACTIONS(4349),
    [anon_sym_Enum] = ACTIONS(4349),
    [anon_sym_eNUM] = ACTIONS(4349),
    [anon_sym_eNum] = ACTIONS(4349),
    [anon_sym_ENum] = ACTIONS(4349),
    [sym_quoted_identifier] = ACTIONS(4351),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4351),
    [sym_integer] = ACTIONS(4349),
    [sym_continue_as_identifier] = ACTIONS(4351),
    [sym_preproc_open] = ACTIONS(4351),
  },
  [STATE(1881)] = {
    [sym_identifier] = ACTIONS(4353),
    [anon_sym_SEMI] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [aux_sym_boolean_token1] = ACTIONS(4353),
    [aux_sym_boolean_token2] = ACTIONS(4353),
    [sym_decimal] = ACTIONS(4353),
    [anon_sym_LPAREN] = ACTIONS(4355),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4353),
    [anon_sym_LBRACK] = ACTIONS(4355),
    [aux_sym_record_type_token1] = ACTIONS(4353),
    [aux_sym_basic_type_token21] = ACTIONS(4353),
    [aux_sym_basic_type_token22] = ACTIONS(4353),
    [aux_sym_basic_type_token48] = ACTIONS(4353),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4353),
    [anon_sym_POUNDif] = ACTIONS(4355),
    [anon_sym_POUNDIF] = ACTIONS(4355),
    [anon_sym_POUNDIf] = ACTIONS(4355),
    [anon_sym_not] = ACTIONS(4353),
    [anon_sym_NOT] = ACTIONS(4353),
    [anon_sym_Not] = ACTIONS(4353),
    [anon_sym_POUNDelse] = ACTIONS(4355),
    [anon_sym_POUNDELSE] = ACTIONS(4355),
    [anon_sym_POUNDElse] = ACTIONS(4355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4353),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4353),
    [anon_sym_PLUS] = ACTIONS(4355),
    [sym_datetime_literal] = ACTIONS(4355),
    [sym_date_literal] = ACTIONS(4353),
    [sym_time_literal] = ACTIONS(4353),
    [sym_biginteger_literal] = ACTIONS(4355),
    [anon_sym_if] = ACTIONS(4353),
    [anon_sym_IF] = ACTIONS(4353),
    [anon_sym_If] = ACTIONS(4353),
    [anon_sym_else] = ACTIONS(4353),
    [anon_sym_ELSE] = ACTIONS(4353),
    [anon_sym_Else] = ACTIONS(4353),
    [anon_sym_case] = ACTIONS(4353),
    [anon_sym_CASE] = ACTIONS(4353),
    [anon_sym_Case] = ACTIONS(4353),
    [anon_sym_for] = ACTIONS(4353),
    [anon_sym_FOR] = ACTIONS(4353),
    [anon_sym_For] = ACTIONS(4353),
    [anon_sym_foreach] = ACTIONS(4353),
    [anon_sym_FOREACH] = ACTIONS(4353),
    [anon_sym_Foreach] = ACTIONS(4353),
    [anon_sym_while] = ACTIONS(4353),
    [anon_sym_WHILE] = ACTIONS(4353),
    [anon_sym_While] = ACTIONS(4353),
    [anon_sym_repeat] = ACTIONS(4353),
    [anon_sym_REPEAT] = ACTIONS(4353),
    [anon_sym_Repeat] = ACTIONS(4353),
    [anon_sym_until] = ACTIONS(4353),
    [anon_sym_UNTIL] = ACTIONS(4353),
    [anon_sym_Until] = ACTIONS(4353),
    [anon_sym_exit] = ACTIONS(4353),
    [anon_sym_EXIT] = ACTIONS(4353),
    [anon_sym_Exit] = ACTIONS(4353),
    [anon_sym_continue] = ACTIONS(4353),
    [anon_sym_CONTINUE] = ACTIONS(4353),
    [anon_sym_Continue] = ACTIONS(4353),
    [anon_sym_break] = ACTIONS(4353),
    [anon_sym_BREAK] = ACTIONS(4353),
    [anon_sym_Break] = ACTIONS(4353),
    [anon_sym_with] = ACTIONS(4353),
    [anon_sym_WITH] = ACTIONS(4353),
    [anon_sym_With] = ACTIONS(4353),
    [sym_asserterror_keyword] = ACTIONS(4355),
    [sym_page_keyword] = ACTIONS(4353),
    [anon_sym_codeunit] = ACTIONS(4353),
    [anon_sym_CODEUNIT] = ACTIONS(4353),
    [anon_sym_Codeunit] = ACTIONS(4353),
    [anon_sym_CodeUnit] = ACTIONS(4353),
    [anon_sym_COdeunit] = ACTIONS(4353),
    [anon_sym_codeUnit] = ACTIONS(4353),
    [sym_report_keyword] = ACTIONS(4353),
    [sym_query_keyword] = ACTIONS(4353),
    [anon_sym_xmlport] = ACTIONS(4353),
    [anon_sym_XMLPORT] = ACTIONS(4353),
    [anon_sym_Xmlport] = ACTIONS(4353),
    [anon_sym_XMLport] = ACTIONS(4353),
    [anon_sym_XMLPort] = ACTIONS(4353),
    [anon_sym_XmlPort] = ACTIONS(4353),
    [anon_sym_enum] = ACTIONS(4353),
    [anon_sym_ENUM] = ACTIONS(4353),
    [anon_sym_Enum] = ACTIONS(4353),
    [anon_sym_eNUM] = ACTIONS(4353),
    [anon_sym_eNum] = ACTIONS(4353),
    [anon_sym_ENum] = ACTIONS(4353),
    [sym_quoted_identifier] = ACTIONS(4355),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4355),
    [sym_integer] = ACTIONS(4353),
    [sym_continue_as_identifier] = ACTIONS(4355),
    [sym_preproc_open] = ACTIONS(4355),
  },
  [STATE(1882)] = {
    [sym_identifier] = ACTIONS(4357),
    [anon_sym_SEMI] = ACTIONS(4359),
    [anon_sym_DASH] = ACTIONS(4359),
    [aux_sym_boolean_token1] = ACTIONS(4357),
    [aux_sym_boolean_token2] = ACTIONS(4357),
    [sym_decimal] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4359),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4357),
    [anon_sym_LBRACK] = ACTIONS(4359),
    [aux_sym_record_type_token1] = ACTIONS(4357),
    [aux_sym_basic_type_token21] = ACTIONS(4357),
    [aux_sym_basic_type_token22] = ACTIONS(4357),
    [aux_sym_basic_type_token48] = ACTIONS(4357),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4357),
    [anon_sym_POUNDif] = ACTIONS(4359),
    [anon_sym_POUNDIF] = ACTIONS(4359),
    [anon_sym_POUNDIf] = ACTIONS(4359),
    [anon_sym_not] = ACTIONS(4357),
    [anon_sym_NOT] = ACTIONS(4357),
    [anon_sym_Not] = ACTIONS(4357),
    [anon_sym_POUNDelse] = ACTIONS(4359),
    [anon_sym_POUNDELSE] = ACTIONS(4359),
    [anon_sym_POUNDElse] = ACTIONS(4359),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4357),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4359),
    [sym_datetime_literal] = ACTIONS(4359),
    [sym_date_literal] = ACTIONS(4357),
    [sym_time_literal] = ACTIONS(4357),
    [sym_biginteger_literal] = ACTIONS(4359),
    [anon_sym_if] = ACTIONS(4357),
    [anon_sym_IF] = ACTIONS(4357),
    [anon_sym_If] = ACTIONS(4357),
    [anon_sym_else] = ACTIONS(4357),
    [anon_sym_ELSE] = ACTIONS(4357),
    [anon_sym_Else] = ACTIONS(4357),
    [anon_sym_case] = ACTIONS(4357),
    [anon_sym_CASE] = ACTIONS(4357),
    [anon_sym_Case] = ACTIONS(4357),
    [anon_sym_for] = ACTIONS(4357),
    [anon_sym_FOR] = ACTIONS(4357),
    [anon_sym_For] = ACTIONS(4357),
    [anon_sym_foreach] = ACTIONS(4357),
    [anon_sym_FOREACH] = ACTIONS(4357),
    [anon_sym_Foreach] = ACTIONS(4357),
    [anon_sym_while] = ACTIONS(4357),
    [anon_sym_WHILE] = ACTIONS(4357),
    [anon_sym_While] = ACTIONS(4357),
    [anon_sym_repeat] = ACTIONS(4357),
    [anon_sym_REPEAT] = ACTIONS(4357),
    [anon_sym_Repeat] = ACTIONS(4357),
    [anon_sym_until] = ACTIONS(4357),
    [anon_sym_UNTIL] = ACTIONS(4357),
    [anon_sym_Until] = ACTIONS(4357),
    [anon_sym_exit] = ACTIONS(4357),
    [anon_sym_EXIT] = ACTIONS(4357),
    [anon_sym_Exit] = ACTIONS(4357),
    [anon_sym_continue] = ACTIONS(4357),
    [anon_sym_CONTINUE] = ACTIONS(4357),
    [anon_sym_Continue] = ACTIONS(4357),
    [anon_sym_break] = ACTIONS(4357),
    [anon_sym_BREAK] = ACTIONS(4357),
    [anon_sym_Break] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4357),
    [anon_sym_WITH] = ACTIONS(4357),
    [anon_sym_With] = ACTIONS(4357),
    [sym_asserterror_keyword] = ACTIONS(4359),
    [sym_page_keyword] = ACTIONS(4357),
    [anon_sym_codeunit] = ACTIONS(4357),
    [anon_sym_CODEUNIT] = ACTIONS(4357),
    [anon_sym_Codeunit] = ACTIONS(4357),
    [anon_sym_CodeUnit] = ACTIONS(4357),
    [anon_sym_COdeunit] = ACTIONS(4357),
    [anon_sym_codeUnit] = ACTIONS(4357),
    [sym_report_keyword] = ACTIONS(4357),
    [sym_query_keyword] = ACTIONS(4357),
    [anon_sym_xmlport] = ACTIONS(4357),
    [anon_sym_XMLPORT] = ACTIONS(4357),
    [anon_sym_Xmlport] = ACTIONS(4357),
    [anon_sym_XMLport] = ACTIONS(4357),
    [anon_sym_XMLPort] = ACTIONS(4357),
    [anon_sym_XmlPort] = ACTIONS(4357),
    [anon_sym_enum] = ACTIONS(4357),
    [anon_sym_ENUM] = ACTIONS(4357),
    [anon_sym_Enum] = ACTIONS(4357),
    [anon_sym_eNUM] = ACTIONS(4357),
    [anon_sym_eNum] = ACTIONS(4357),
    [anon_sym_ENum] = ACTIONS(4357),
    [sym_quoted_identifier] = ACTIONS(4359),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4359),
    [sym_integer] = ACTIONS(4357),
    [sym_continue_as_identifier] = ACTIONS(4359),
    [sym_preproc_open] = ACTIONS(4359),
  },
  [STATE(1883)] = {
    [sym_identifier] = ACTIONS(4361),
    [anon_sym_SEMI] = ACTIONS(4363),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(4361),
    [aux_sym_boolean_token2] = ACTIONS(4361),
    [sym_decimal] = ACTIONS(4361),
    [anon_sym_LPAREN] = ACTIONS(4363),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4361),
    [anon_sym_LBRACK] = ACTIONS(4363),
    [aux_sym_record_type_token1] = ACTIONS(4361),
    [aux_sym_basic_type_token21] = ACTIONS(4361),
    [aux_sym_basic_type_token22] = ACTIONS(4361),
    [aux_sym_basic_type_token48] = ACTIONS(4361),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4361),
    [anon_sym_POUNDif] = ACTIONS(4363),
    [anon_sym_POUNDIF] = ACTIONS(4363),
    [anon_sym_POUNDIf] = ACTIONS(4363),
    [anon_sym_not] = ACTIONS(4361),
    [anon_sym_NOT] = ACTIONS(4361),
    [anon_sym_Not] = ACTIONS(4361),
    [anon_sym_POUNDelse] = ACTIONS(4363),
    [anon_sym_POUNDELSE] = ACTIONS(4363),
    [anon_sym_POUNDElse] = ACTIONS(4363),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4361),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4361),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4363),
    [sym_date_literal] = ACTIONS(4361),
    [sym_time_literal] = ACTIONS(4361),
    [sym_biginteger_literal] = ACTIONS(4363),
    [anon_sym_if] = ACTIONS(4361),
    [anon_sym_IF] = ACTIONS(4361),
    [anon_sym_If] = ACTIONS(4361),
    [anon_sym_else] = ACTIONS(4361),
    [anon_sym_ELSE] = ACTIONS(4361),
    [anon_sym_Else] = ACTIONS(4361),
    [anon_sym_case] = ACTIONS(4361),
    [anon_sym_CASE] = ACTIONS(4361),
    [anon_sym_Case] = ACTIONS(4361),
    [anon_sym_for] = ACTIONS(4361),
    [anon_sym_FOR] = ACTIONS(4361),
    [anon_sym_For] = ACTIONS(4361),
    [anon_sym_foreach] = ACTIONS(4361),
    [anon_sym_FOREACH] = ACTIONS(4361),
    [anon_sym_Foreach] = ACTIONS(4361),
    [anon_sym_while] = ACTIONS(4361),
    [anon_sym_WHILE] = ACTIONS(4361),
    [anon_sym_While] = ACTIONS(4361),
    [anon_sym_repeat] = ACTIONS(4361),
    [anon_sym_REPEAT] = ACTIONS(4361),
    [anon_sym_Repeat] = ACTIONS(4361),
    [anon_sym_until] = ACTIONS(4361),
    [anon_sym_UNTIL] = ACTIONS(4361),
    [anon_sym_Until] = ACTIONS(4361),
    [anon_sym_exit] = ACTIONS(4361),
    [anon_sym_EXIT] = ACTIONS(4361),
    [anon_sym_Exit] = ACTIONS(4361),
    [anon_sym_continue] = ACTIONS(4361),
    [anon_sym_CONTINUE] = ACTIONS(4361),
    [anon_sym_Continue] = ACTIONS(4361),
    [anon_sym_break] = ACTIONS(4361),
    [anon_sym_BREAK] = ACTIONS(4361),
    [anon_sym_Break] = ACTIONS(4361),
    [anon_sym_with] = ACTIONS(4361),
    [anon_sym_WITH] = ACTIONS(4361),
    [anon_sym_With] = ACTIONS(4361),
    [sym_asserterror_keyword] = ACTIONS(4363),
    [sym_page_keyword] = ACTIONS(4361),
    [anon_sym_codeunit] = ACTIONS(4361),
    [anon_sym_CODEUNIT] = ACTIONS(4361),
    [anon_sym_Codeunit] = ACTIONS(4361),
    [anon_sym_CodeUnit] = ACTIONS(4361),
    [anon_sym_COdeunit] = ACTIONS(4361),
    [anon_sym_codeUnit] = ACTIONS(4361),
    [sym_report_keyword] = ACTIONS(4361),
    [sym_query_keyword] = ACTIONS(4361),
    [anon_sym_xmlport] = ACTIONS(4361),
    [anon_sym_XMLPORT] = ACTIONS(4361),
    [anon_sym_Xmlport] = ACTIONS(4361),
    [anon_sym_XMLport] = ACTIONS(4361),
    [anon_sym_XMLPort] = ACTIONS(4361),
    [anon_sym_XmlPort] = ACTIONS(4361),
    [anon_sym_enum] = ACTIONS(4361),
    [anon_sym_ENUM] = ACTIONS(4361),
    [anon_sym_Enum] = ACTIONS(4361),
    [anon_sym_eNUM] = ACTIONS(4361),
    [anon_sym_eNum] = ACTIONS(4361),
    [anon_sym_ENum] = ACTIONS(4361),
    [sym_quoted_identifier] = ACTIONS(4363),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4363),
    [sym_integer] = ACTIONS(4361),
    [sym_continue_as_identifier] = ACTIONS(4363),
    [sym_preproc_open] = ACTIONS(4363),
  },
  [STATE(1884)] = {
    [sym_identifier] = ACTIONS(4365),
    [anon_sym_SEMI] = ACTIONS(4367),
    [anon_sym_DASH] = ACTIONS(4367),
    [aux_sym_boolean_token1] = ACTIONS(4365),
    [aux_sym_boolean_token2] = ACTIONS(4365),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4365),
    [anon_sym_LBRACK] = ACTIONS(4367),
    [aux_sym_record_type_token1] = ACTIONS(4365),
    [aux_sym_basic_type_token21] = ACTIONS(4365),
    [aux_sym_basic_type_token22] = ACTIONS(4365),
    [aux_sym_basic_type_token48] = ACTIONS(4365),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4365),
    [anon_sym_POUNDif] = ACTIONS(4367),
    [anon_sym_POUNDIF] = ACTIONS(4367),
    [anon_sym_POUNDIf] = ACTIONS(4367),
    [anon_sym_not] = ACTIONS(4365),
    [anon_sym_NOT] = ACTIONS(4365),
    [anon_sym_Not] = ACTIONS(4365),
    [anon_sym_POUNDelse] = ACTIONS(4367),
    [anon_sym_POUNDELSE] = ACTIONS(4367),
    [anon_sym_POUNDElse] = ACTIONS(4367),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4365),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4365),
    [anon_sym_PLUS] = ACTIONS(4367),
    [sym_datetime_literal] = ACTIONS(4367),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4367),
    [anon_sym_if] = ACTIONS(4365),
    [anon_sym_IF] = ACTIONS(4365),
    [anon_sym_If] = ACTIONS(4365),
    [anon_sym_else] = ACTIONS(4365),
    [anon_sym_ELSE] = ACTIONS(4365),
    [anon_sym_Else] = ACTIONS(4365),
    [anon_sym_case] = ACTIONS(4365),
    [anon_sym_CASE] = ACTIONS(4365),
    [anon_sym_Case] = ACTIONS(4365),
    [anon_sym_for] = ACTIONS(4365),
    [anon_sym_FOR] = ACTIONS(4365),
    [anon_sym_For] = ACTIONS(4365),
    [anon_sym_foreach] = ACTIONS(4365),
    [anon_sym_FOREACH] = ACTIONS(4365),
    [anon_sym_Foreach] = ACTIONS(4365),
    [anon_sym_while] = ACTIONS(4365),
    [anon_sym_WHILE] = ACTIONS(4365),
    [anon_sym_While] = ACTIONS(4365),
    [anon_sym_repeat] = ACTIONS(4365),
    [anon_sym_REPEAT] = ACTIONS(4365),
    [anon_sym_Repeat] = ACTIONS(4365),
    [anon_sym_until] = ACTIONS(4365),
    [anon_sym_UNTIL] = ACTIONS(4365),
    [anon_sym_Until] = ACTIONS(4365),
    [anon_sym_exit] = ACTIONS(4365),
    [anon_sym_EXIT] = ACTIONS(4365),
    [anon_sym_Exit] = ACTIONS(4365),
    [anon_sym_continue] = ACTIONS(4365),
    [anon_sym_CONTINUE] = ACTIONS(4365),
    [anon_sym_Continue] = ACTIONS(4365),
    [anon_sym_break] = ACTIONS(4365),
    [anon_sym_BREAK] = ACTIONS(4365),
    [anon_sym_Break] = ACTIONS(4365),
    [anon_sym_with] = ACTIONS(4365),
    [anon_sym_WITH] = ACTIONS(4365),
    [anon_sym_With] = ACTIONS(4365),
    [sym_asserterror_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(4365),
    [anon_sym_codeunit] = ACTIONS(4365),
    [anon_sym_CODEUNIT] = ACTIONS(4365),
    [anon_sym_Codeunit] = ACTIONS(4365),
    [anon_sym_CodeUnit] = ACTIONS(4365),
    [anon_sym_COdeunit] = ACTIONS(4365),
    [anon_sym_codeUnit] = ACTIONS(4365),
    [sym_report_keyword] = ACTIONS(4365),
    [sym_query_keyword] = ACTIONS(4365),
    [anon_sym_xmlport] = ACTIONS(4365),
    [anon_sym_XMLPORT] = ACTIONS(4365),
    [anon_sym_Xmlport] = ACTIONS(4365),
    [anon_sym_XMLport] = ACTIONS(4365),
    [anon_sym_XMLPort] = ACTIONS(4365),
    [anon_sym_XmlPort] = ACTIONS(4365),
    [anon_sym_enum] = ACTIONS(4365),
    [anon_sym_ENUM] = ACTIONS(4365),
    [anon_sym_Enum] = ACTIONS(4365),
    [anon_sym_eNUM] = ACTIONS(4365),
    [anon_sym_eNum] = ACTIONS(4365),
    [anon_sym_ENum] = ACTIONS(4365),
    [sym_quoted_identifier] = ACTIONS(4367),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4367),
    [sym_integer] = ACTIONS(4365),
    [sym_continue_as_identifier] = ACTIONS(4367),
    [sym_preproc_open] = ACTIONS(4367),
  },
  [STATE(1885)] = {
    [sym_identifier] = ACTIONS(4369),
    [anon_sym_SEMI] = ACTIONS(4371),
    [anon_sym_DASH] = ACTIONS(4371),
    [aux_sym_boolean_token1] = ACTIONS(4369),
    [aux_sym_boolean_token2] = ACTIONS(4369),
    [sym_decimal] = ACTIONS(4369),
    [anon_sym_LPAREN] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4369),
    [anon_sym_LBRACK] = ACTIONS(4371),
    [aux_sym_record_type_token1] = ACTIONS(4369),
    [aux_sym_basic_type_token21] = ACTIONS(4369),
    [aux_sym_basic_type_token22] = ACTIONS(4369),
    [aux_sym_basic_type_token48] = ACTIONS(4369),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4369),
    [anon_sym_POUNDif] = ACTIONS(4371),
    [anon_sym_POUNDIF] = ACTIONS(4371),
    [anon_sym_POUNDIf] = ACTIONS(4371),
    [anon_sym_not] = ACTIONS(4369),
    [anon_sym_NOT] = ACTIONS(4369),
    [anon_sym_Not] = ACTIONS(4369),
    [anon_sym_POUNDelse] = ACTIONS(4371),
    [anon_sym_POUNDELSE] = ACTIONS(4371),
    [anon_sym_POUNDElse] = ACTIONS(4371),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4369),
    [anon_sym_PLUS] = ACTIONS(4371),
    [sym_datetime_literal] = ACTIONS(4371),
    [sym_date_literal] = ACTIONS(4369),
    [sym_time_literal] = ACTIONS(4369),
    [sym_biginteger_literal] = ACTIONS(4371),
    [anon_sym_if] = ACTIONS(4369),
    [anon_sym_IF] = ACTIONS(4369),
    [anon_sym_If] = ACTIONS(4369),
    [anon_sym_else] = ACTIONS(4369),
    [anon_sym_ELSE] = ACTIONS(4369),
    [anon_sym_Else] = ACTIONS(4369),
    [anon_sym_case] = ACTIONS(4369),
    [anon_sym_CASE] = ACTIONS(4369),
    [anon_sym_Case] = ACTIONS(4369),
    [anon_sym_for] = ACTIONS(4369),
    [anon_sym_FOR] = ACTIONS(4369),
    [anon_sym_For] = ACTIONS(4369),
    [anon_sym_foreach] = ACTIONS(4369),
    [anon_sym_FOREACH] = ACTIONS(4369),
    [anon_sym_Foreach] = ACTIONS(4369),
    [anon_sym_while] = ACTIONS(4369),
    [anon_sym_WHILE] = ACTIONS(4369),
    [anon_sym_While] = ACTIONS(4369),
    [anon_sym_repeat] = ACTIONS(4369),
    [anon_sym_REPEAT] = ACTIONS(4369),
    [anon_sym_Repeat] = ACTIONS(4369),
    [anon_sym_until] = ACTIONS(4369),
    [anon_sym_UNTIL] = ACTIONS(4369),
    [anon_sym_Until] = ACTIONS(4369),
    [anon_sym_exit] = ACTIONS(4369),
    [anon_sym_EXIT] = ACTIONS(4369),
    [anon_sym_Exit] = ACTIONS(4369),
    [anon_sym_continue] = ACTIONS(4369),
    [anon_sym_CONTINUE] = ACTIONS(4369),
    [anon_sym_Continue] = ACTIONS(4369),
    [anon_sym_break] = ACTIONS(4369),
    [anon_sym_BREAK] = ACTIONS(4369),
    [anon_sym_Break] = ACTIONS(4369),
    [anon_sym_with] = ACTIONS(4369),
    [anon_sym_WITH] = ACTIONS(4369),
    [anon_sym_With] = ACTIONS(4369),
    [sym_asserterror_keyword] = ACTIONS(4371),
    [sym_page_keyword] = ACTIONS(4369),
    [anon_sym_codeunit] = ACTIONS(4369),
    [anon_sym_CODEUNIT] = ACTIONS(4369),
    [anon_sym_Codeunit] = ACTIONS(4369),
    [anon_sym_CodeUnit] = ACTIONS(4369),
    [anon_sym_COdeunit] = ACTIONS(4369),
    [anon_sym_codeUnit] = ACTIONS(4369),
    [sym_report_keyword] = ACTIONS(4369),
    [sym_query_keyword] = ACTIONS(4369),
    [anon_sym_xmlport] = ACTIONS(4369),
    [anon_sym_XMLPORT] = ACTIONS(4369),
    [anon_sym_Xmlport] = ACTIONS(4369),
    [anon_sym_XMLport] = ACTIONS(4369),
    [anon_sym_XMLPort] = ACTIONS(4369),
    [anon_sym_XmlPort] = ACTIONS(4369),
    [anon_sym_enum] = ACTIONS(4369),
    [anon_sym_ENUM] = ACTIONS(4369),
    [anon_sym_Enum] = ACTIONS(4369),
    [anon_sym_eNUM] = ACTIONS(4369),
    [anon_sym_eNum] = ACTIONS(4369),
    [anon_sym_ENum] = ACTIONS(4369),
    [sym_quoted_identifier] = ACTIONS(4371),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4371),
    [sym_integer] = ACTIONS(4369),
    [sym_continue_as_identifier] = ACTIONS(4371),
    [sym_preproc_open] = ACTIONS(4371),
  },
  [STATE(1886)] = {
    [anon_sym_POUNDif] = ACTIONS(2841),
    [anon_sym_POUNDIF] = ACTIONS(2841),
    [anon_sym_POUNDIf] = ACTIONS(2841),
    [anon_sym_POUNDelif] = ACTIONS(2841),
    [anon_sym_POUNDELIF] = ACTIONS(2841),
    [anon_sym_POUNDElif] = ACTIONS(2841),
    [anon_sym_POUNDelse] = ACTIONS(2841),
    [anon_sym_POUNDELSE] = ACTIONS(2841),
    [anon_sym_POUNDElse] = ACTIONS(2841),
    [anon_sym_POUNDendif] = ACTIONS(2841),
    [anon_sym_POUNDENDIF] = ACTIONS(2841),
    [anon_sym_POUNDEndif] = ACTIONS(2841),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(2843),
    [anon_sym_tableextension] = ACTIONS(2841),
    [anon_sym_TABLEEXTENSION] = ACTIONS(2841),
    [anon_sym_Tableextension] = ACTIONS(2841),
    [anon_sym_TableExtension] = ACTIONS(2841),
    [anon_sym_tableExtension] = ACTIONS(2841),
    [sym_page_keyword] = ACTIONS(2843),
    [anon_sym_pageextension] = ACTIONS(2841),
    [anon_sym_PAGEEXTENSION] = ACTIONS(2841),
    [anon_sym_Pageextension] = ACTIONS(2841),
    [anon_sym_PageExtension] = ACTIONS(2841),
    [anon_sym_pageExtension] = ACTIONS(2841),
    [anon_sym_codeunit] = ACTIONS(2841),
    [anon_sym_CODEUNIT] = ACTIONS(2841),
    [anon_sym_Codeunit] = ACTIONS(2841),
    [anon_sym_CodeUnit] = ACTIONS(2841),
    [anon_sym_COdeunit] = ACTIONS(2841),
    [anon_sym_codeUnit] = ACTIONS(2841),
    [sym_report_keyword] = ACTIONS(2843),
    [anon_sym_reportextension] = ACTIONS(2841),
    [anon_sym_REPORTEXTENSION] = ACTIONS(2841),
    [anon_sym_Reportextension] = ACTIONS(2841),
    [anon_sym_ReportExtension] = ACTIONS(2841),
    [anon_sym_reportExtension] = ACTIONS(2841),
    [sym_query_keyword] = ACTIONS(2841),
    [anon_sym_xmlport] = ACTIONS(2841),
    [anon_sym_XMLPORT] = ACTIONS(2841),
    [anon_sym_Xmlport] = ACTIONS(2841),
    [anon_sym_XMLport] = ACTIONS(2841),
    [anon_sym_XMLPort] = ACTIONS(2841),
    [anon_sym_XmlPort] = ACTIONS(2841),
    [anon_sym_enum] = ACTIONS(2843),
    [anon_sym_ENUM] = ACTIONS(2843),
    [anon_sym_Enum] = ACTIONS(2843),
    [anon_sym_eNUM] = ACTIONS(2841),
    [anon_sym_eNum] = ACTIONS(2841),
    [anon_sym_ENum] = ACTIONS(2841),
    [anon_sym_enumextension] = ACTIONS(2841),
    [anon_sym_ENUMEXTENSION] = ACTIONS(2841),
    [anon_sym_Enumextension] = ACTIONS(2841),
    [anon_sym_EnumExtension] = ACTIONS(2841),
    [anon_sym_enumExtension] = ACTIONS(2841),
    [sym_interface_keyword] = ACTIONS(2841),
    [anon_sym_controladdin] = ACTIONS(2841),
    [anon_sym_CONTROLADDIN] = ACTIONS(2841),
    [anon_sym_Controladdin] = ACTIONS(2841),
    [anon_sym_ControlAddIn] = ACTIONS(2841),
    [anon_sym_ControlAddin] = ACTIONS(2841),
    [anon_sym_controlAddIn] = ACTIONS(2841),
    [anon_sym_controlAddin] = ACTIONS(2841),
    [anon_sym_dotnet] = ACTIONS(2841),
    [anon_sym_DOTNET] = ACTIONS(2841),
    [anon_sym_Dotnet] = ACTIONS(2841),
    [anon_sym_DotNet] = ACTIONS(2841),
    [anon_sym_dotNet] = ACTIONS(2841),
    [sym_profile_keyword] = ACTIONS(2843),
    [anon_sym_profileextension] = ACTIONS(2841),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(2841),
    [anon_sym_Profileextension] = ACTIONS(2841),
    [anon_sym_ProfileExtension] = ACTIONS(2841),
    [anon_sym_profileExtension] = ACTIONS(2841),
    [anon_sym_permissionset] = ACTIONS(2843),
    [anon_sym_PERMISSIONSET] = ACTIONS(2843),
    [anon_sym_Permissionset] = ACTIONS(2843),
    [anon_sym_PermissionSet] = ACTIONS(2843),
    [anon_sym_permissionSet] = ACTIONS(2843),
    [anon_sym_permissionsetextension] = ACTIONS(2841),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(2841),
    [anon_sym_Permissionsetextension] = ACTIONS(2841),
    [anon_sym_PermissionSetExtension] = ACTIONS(2841),
    [anon_sym_permissionSetExtension] = ACTIONS(2841),
    [sym_entitlement_keyword] = ACTIONS(2841),
    [anon_sym_pagecustomization] = ACTIONS(2841),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(2841),
    [anon_sym_Pagecustomization] = ACTIONS(2841),
    [anon_sym_PageCustomization] = ACTIONS(2841),
    [anon_sym_pageCustomization] = ACTIONS(2841),
    [sym_using_keyword] = ACTIONS(2841),
    [sym_fieldgroup_keyword] = ACTIONS(2841),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(2841),
    [sym_preproc_close] = ACTIONS(2841),
  },
  [STATE(1887)] = {
    [sym_identifier] = ACTIONS(4391),
    [anon_sym_SEMI] = ACTIONS(4393),
    [anon_sym_DASH] = ACTIONS(4393),
    [aux_sym_boolean_token1] = ACTIONS(4391),
    [aux_sym_boolean_token2] = ACTIONS(4391),
    [sym_decimal] = ACTIONS(4391),
    [anon_sym_LPAREN] = ACTIONS(4393),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4391),
    [anon_sym_LBRACK] = ACTIONS(4393),
    [aux_sym_record_type_token1] = ACTIONS(4391),
    [aux_sym_basic_type_token21] = ACTIONS(4391),
    [aux_sym_basic_type_token22] = ACTIONS(4391),
    [aux_sym_basic_type_token48] = ACTIONS(4391),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4391),
    [anon_sym_POUNDif] = ACTIONS(4393),
    [anon_sym_POUNDIF] = ACTIONS(4393),
    [anon_sym_POUNDIf] = ACTIONS(4393),
    [anon_sym_not] = ACTIONS(4391),
    [anon_sym_NOT] = ACTIONS(4391),
    [anon_sym_Not] = ACTIONS(4391),
    [anon_sym_POUNDelse] = ACTIONS(4393),
    [anon_sym_POUNDELSE] = ACTIONS(4393),
    [anon_sym_POUNDElse] = ACTIONS(4393),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4391),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4391),
    [anon_sym_PLUS] = ACTIONS(4393),
    [sym_datetime_literal] = ACTIONS(4393),
    [sym_date_literal] = ACTIONS(4391),
    [sym_time_literal] = ACTIONS(4391),
    [sym_biginteger_literal] = ACTIONS(4393),
    [anon_sym_if] = ACTIONS(4391),
    [anon_sym_IF] = ACTIONS(4391),
    [anon_sym_If] = ACTIONS(4391),
    [anon_sym_else] = ACTIONS(4391),
    [anon_sym_ELSE] = ACTIONS(4391),
    [anon_sym_Else] = ACTIONS(4391),
    [anon_sym_case] = ACTIONS(4391),
    [anon_sym_CASE] = ACTIONS(4391),
    [anon_sym_Case] = ACTIONS(4391),
    [anon_sym_for] = ACTIONS(4391),
    [anon_sym_FOR] = ACTIONS(4391),
    [anon_sym_For] = ACTIONS(4391),
    [anon_sym_foreach] = ACTIONS(4391),
    [anon_sym_FOREACH] = ACTIONS(4391),
    [anon_sym_Foreach] = ACTIONS(4391),
    [anon_sym_while] = ACTIONS(4391),
    [anon_sym_WHILE] = ACTIONS(4391),
    [anon_sym_While] = ACTIONS(4391),
    [anon_sym_repeat] = ACTIONS(4391),
    [anon_sym_REPEAT] = ACTIONS(4391),
    [anon_sym_Repeat] = ACTIONS(4391),
    [anon_sym_until] = ACTIONS(4391),
    [anon_sym_UNTIL] = ACTIONS(4391),
    [anon_sym_Until] = ACTIONS(4391),
    [anon_sym_exit] = ACTIONS(4391),
    [anon_sym_EXIT] = ACTIONS(4391),
    [anon_sym_Exit] = ACTIONS(4391),
    [anon_sym_continue] = ACTIONS(4391),
    [anon_sym_CONTINUE] = ACTIONS(4391),
    [anon_sym_Continue] = ACTIONS(4391),
    [anon_sym_break] = ACTIONS(4391),
    [anon_sym_BREAK] = ACTIONS(4391),
    [anon_sym_Break] = ACTIONS(4391),
    [anon_sym_with] = ACTIONS(4391),
    [anon_sym_WITH] = ACTIONS(4391),
    [anon_sym_With] = ACTIONS(4391),
    [sym_asserterror_keyword] = ACTIONS(4393),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(4391),
    [anon_sym_CODEUNIT] = ACTIONS(4391),
    [anon_sym_Codeunit] = ACTIONS(4391),
    [anon_sym_CodeUnit] = ACTIONS(4391),
    [anon_sym_COdeunit] = ACTIONS(4391),
    [anon_sym_codeUnit] = ACTIONS(4391),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(4391),
    [anon_sym_XMLPORT] = ACTIONS(4391),
    [anon_sym_Xmlport] = ACTIONS(4391),
    [anon_sym_XMLport] = ACTIONS(4391),
    [anon_sym_XMLPort] = ACTIONS(4391),
    [anon_sym_XmlPort] = ACTIONS(4391),
    [anon_sym_enum] = ACTIONS(4391),
    [anon_sym_ENUM] = ACTIONS(4391),
    [anon_sym_Enum] = ACTIONS(4391),
    [anon_sym_eNUM] = ACTIONS(4391),
    [anon_sym_eNum] = ACTIONS(4391),
    [anon_sym_ENum] = ACTIONS(4391),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4393),
    [sym_integer] = ACTIONS(4391),
    [sym_continue_as_identifier] = ACTIONS(4393),
    [sym_preproc_open] = ACTIONS(4393),
  },
  [STATE(1888)] = {
    [sym_identifier] = ACTIONS(4459),
    [anon_sym_SEMI] = ACTIONS(4461),
    [anon_sym_DASH] = ACTIONS(4461),
    [aux_sym_boolean_token1] = ACTIONS(4459),
    [aux_sym_boolean_token2] = ACTIONS(4459),
    [sym_decimal] = ACTIONS(4459),
    [anon_sym_LPAREN] = ACTIONS(4461),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4459),
    [anon_sym_LBRACK] = ACTIONS(4461),
    [aux_sym_record_type_token1] = ACTIONS(4459),
    [aux_sym_basic_type_token21] = ACTIONS(4459),
    [aux_sym_basic_type_token22] = ACTIONS(4459),
    [aux_sym_basic_type_token48] = ACTIONS(4459),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4459),
    [anon_sym_POUNDif] = ACTIONS(4461),
    [anon_sym_POUNDIF] = ACTIONS(4461),
    [anon_sym_POUNDIf] = ACTIONS(4461),
    [anon_sym_not] = ACTIONS(4459),
    [anon_sym_NOT] = ACTIONS(4459),
    [anon_sym_Not] = ACTIONS(4459),
    [anon_sym_POUNDelse] = ACTIONS(4461),
    [anon_sym_POUNDELSE] = ACTIONS(4461),
    [anon_sym_POUNDElse] = ACTIONS(4461),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4459),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4459),
    [anon_sym_PLUS] = ACTIONS(4461),
    [sym_datetime_literal] = ACTIONS(4461),
    [sym_date_literal] = ACTIONS(4459),
    [sym_time_literal] = ACTIONS(4459),
    [sym_biginteger_literal] = ACTIONS(4461),
    [anon_sym_if] = ACTIONS(4459),
    [anon_sym_IF] = ACTIONS(4459),
    [anon_sym_If] = ACTIONS(4459),
    [anon_sym_else] = ACTIONS(4459),
    [anon_sym_ELSE] = ACTIONS(4459),
    [anon_sym_Else] = ACTIONS(4459),
    [anon_sym_case] = ACTIONS(4459),
    [anon_sym_CASE] = ACTIONS(4459),
    [anon_sym_Case] = ACTIONS(4459),
    [anon_sym_for] = ACTIONS(4459),
    [anon_sym_FOR] = ACTIONS(4459),
    [anon_sym_For] = ACTIONS(4459),
    [anon_sym_foreach] = ACTIONS(4459),
    [anon_sym_FOREACH] = ACTIONS(4459),
    [anon_sym_Foreach] = ACTIONS(4459),
    [anon_sym_while] = ACTIONS(4459),
    [anon_sym_WHILE] = ACTIONS(4459),
    [anon_sym_While] = ACTIONS(4459),
    [anon_sym_repeat] = ACTIONS(4459),
    [anon_sym_REPEAT] = ACTIONS(4459),
    [anon_sym_Repeat] = ACTIONS(4459),
    [anon_sym_until] = ACTIONS(4459),
    [anon_sym_UNTIL] = ACTIONS(4459),
    [anon_sym_Until] = ACTIONS(4459),
    [anon_sym_exit] = ACTIONS(4459),
    [anon_sym_EXIT] = ACTIONS(4459),
    [anon_sym_Exit] = ACTIONS(4459),
    [anon_sym_continue] = ACTIONS(4459),
    [anon_sym_CONTINUE] = ACTIONS(4459),
    [anon_sym_Continue] = ACTIONS(4459),
    [anon_sym_break] = ACTIONS(4459),
    [anon_sym_BREAK] = ACTIONS(4459),
    [anon_sym_Break] = ACTIONS(4459),
    [anon_sym_with] = ACTIONS(4459),
    [anon_sym_WITH] = ACTIONS(4459),
    [anon_sym_With] = ACTIONS(4459),
    [sym_asserterror_keyword] = ACTIONS(4461),
    [sym_page_keyword] = ACTIONS(4459),
    [anon_sym_codeunit] = ACTIONS(4459),
    [anon_sym_CODEUNIT] = ACTIONS(4459),
    [anon_sym_Codeunit] = ACTIONS(4459),
    [anon_sym_CodeUnit] = ACTIONS(4459),
    [anon_sym_COdeunit] = ACTIONS(4459),
    [anon_sym_codeUnit] = ACTIONS(4459),
    [sym_report_keyword] = ACTIONS(4459),
    [sym_query_keyword] = ACTIONS(4459),
    [anon_sym_xmlport] = ACTIONS(4459),
    [anon_sym_XMLPORT] = ACTIONS(4459),
    [anon_sym_Xmlport] = ACTIONS(4459),
    [anon_sym_XMLport] = ACTIONS(4459),
    [anon_sym_XMLPort] = ACTIONS(4459),
    [anon_sym_XmlPort] = ACTIONS(4459),
    [anon_sym_enum] = ACTIONS(4459),
    [anon_sym_ENUM] = ACTIONS(4459),
    [anon_sym_Enum] = ACTIONS(4459),
    [anon_sym_eNUM] = ACTIONS(4459),
    [anon_sym_eNum] = ACTIONS(4459),
    [anon_sym_ENum] = ACTIONS(4459),
    [sym_quoted_identifier] = ACTIONS(4461),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4461),
    [sym_integer] = ACTIONS(4459),
    [sym_continue_as_identifier] = ACTIONS(4461),
    [sym_preproc_open] = ACTIONS(4461),
  },
  [STATE(1889)] = {
    [sym_identifier] = ACTIONS(4471),
    [anon_sym_SEMI] = ACTIONS(4473),
    [anon_sym_DASH] = ACTIONS(4473),
    [aux_sym_boolean_token1] = ACTIONS(4471),
    [aux_sym_boolean_token2] = ACTIONS(4471),
    [sym_decimal] = ACTIONS(4471),
    [anon_sym_LPAREN] = ACTIONS(4473),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4471),
    [anon_sym_LBRACK] = ACTIONS(4473),
    [aux_sym_record_type_token1] = ACTIONS(4471),
    [aux_sym_basic_type_token21] = ACTIONS(4471),
    [aux_sym_basic_type_token22] = ACTIONS(4471),
    [aux_sym_basic_type_token48] = ACTIONS(4471),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4471),
    [anon_sym_POUNDif] = ACTIONS(4473),
    [anon_sym_POUNDIF] = ACTIONS(4473),
    [anon_sym_POUNDIf] = ACTIONS(4473),
    [anon_sym_not] = ACTIONS(4471),
    [anon_sym_NOT] = ACTIONS(4471),
    [anon_sym_Not] = ACTIONS(4471),
    [anon_sym_POUNDelse] = ACTIONS(4473),
    [anon_sym_POUNDELSE] = ACTIONS(4473),
    [anon_sym_POUNDElse] = ACTIONS(4473),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4471),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4471),
    [anon_sym_PLUS] = ACTIONS(4473),
    [sym_datetime_literal] = ACTIONS(4473),
    [sym_date_literal] = ACTIONS(4471),
    [sym_time_literal] = ACTIONS(4471),
    [sym_biginteger_literal] = ACTIONS(4473),
    [anon_sym_if] = ACTIONS(4471),
    [anon_sym_IF] = ACTIONS(4471),
    [anon_sym_If] = ACTIONS(4471),
    [anon_sym_else] = ACTIONS(4471),
    [anon_sym_ELSE] = ACTIONS(4471),
    [anon_sym_Else] = ACTIONS(4471),
    [anon_sym_case] = ACTIONS(4471),
    [anon_sym_CASE] = ACTIONS(4471),
    [anon_sym_Case] = ACTIONS(4471),
    [anon_sym_for] = ACTIONS(4471),
    [anon_sym_FOR] = ACTIONS(4471),
    [anon_sym_For] = ACTIONS(4471),
    [anon_sym_foreach] = ACTIONS(4471),
    [anon_sym_FOREACH] = ACTIONS(4471),
    [anon_sym_Foreach] = ACTIONS(4471),
    [anon_sym_while] = ACTIONS(4471),
    [anon_sym_WHILE] = ACTIONS(4471),
    [anon_sym_While] = ACTIONS(4471),
    [anon_sym_repeat] = ACTIONS(4471),
    [anon_sym_REPEAT] = ACTIONS(4471),
    [anon_sym_Repeat] = ACTIONS(4471),
    [anon_sym_until] = ACTIONS(4471),
    [anon_sym_UNTIL] = ACTIONS(4471),
    [anon_sym_Until] = ACTIONS(4471),
    [anon_sym_exit] = ACTIONS(4471),
    [anon_sym_EXIT] = ACTIONS(4471),
    [anon_sym_Exit] = ACTIONS(4471),
    [anon_sym_continue] = ACTIONS(4471),
    [anon_sym_CONTINUE] = ACTIONS(4471),
    [anon_sym_Continue] = ACTIONS(4471),
    [anon_sym_break] = ACTIONS(4471),
    [anon_sym_BREAK] = ACTIONS(4471),
    [anon_sym_Break] = ACTIONS(4471),
    [anon_sym_with] = ACTIONS(4471),
    [anon_sym_WITH] = ACTIONS(4471),
    [anon_sym_With] = ACTIONS(4471),
    [sym_asserterror_keyword] = ACTIONS(4473),
    [sym_page_keyword] = ACTIONS(4471),
    [anon_sym_codeunit] = ACTIONS(4471),
    [anon_sym_CODEUNIT] = ACTIONS(4471),
    [anon_sym_Codeunit] = ACTIONS(4471),
    [anon_sym_CodeUnit] = ACTIONS(4471),
    [anon_sym_COdeunit] = ACTIONS(4471),
    [anon_sym_codeUnit] = ACTIONS(4471),
    [sym_report_keyword] = ACTIONS(4471),
    [sym_query_keyword] = ACTIONS(4471),
    [anon_sym_xmlport] = ACTIONS(4471),
    [anon_sym_XMLPORT] = ACTIONS(4471),
    [anon_sym_Xmlport] = ACTIONS(4471),
    [anon_sym_XMLport] = ACTIONS(4471),
    [anon_sym_XMLPort] = ACTIONS(4471),
    [anon_sym_XmlPort] = ACTIONS(4471),
    [anon_sym_enum] = ACTIONS(4471),
    [anon_sym_ENUM] = ACTIONS(4471),
    [anon_sym_Enum] = ACTIONS(4471),
    [anon_sym_eNUM] = ACTIONS(4471),
    [anon_sym_eNum] = ACTIONS(4471),
    [anon_sym_ENum] = ACTIONS(4471),
    [sym_quoted_identifier] = ACTIONS(4473),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4473),
    [sym_integer] = ACTIONS(4471),
    [sym_continue_as_identifier] = ACTIONS(4473),
    [sym_preproc_open] = ACTIONS(4473),
  },
  [STATE(1890)] = {
    [sym_identifier] = ACTIONS(4475),
    [anon_sym_SEMI] = ACTIONS(4477),
    [anon_sym_DASH] = ACTIONS(4477),
    [aux_sym_boolean_token1] = ACTIONS(4475),
    [aux_sym_boolean_token2] = ACTIONS(4475),
    [sym_decimal] = ACTIONS(4475),
    [anon_sym_LPAREN] = ACTIONS(4477),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4475),
    [anon_sym_LBRACK] = ACTIONS(4477),
    [aux_sym_record_type_token1] = ACTIONS(4475),
    [aux_sym_basic_type_token21] = ACTIONS(4475),
    [aux_sym_basic_type_token22] = ACTIONS(4475),
    [aux_sym_basic_type_token48] = ACTIONS(4475),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4475),
    [anon_sym_POUNDif] = ACTIONS(4477),
    [anon_sym_POUNDIF] = ACTIONS(4477),
    [anon_sym_POUNDIf] = ACTIONS(4477),
    [anon_sym_not] = ACTIONS(4475),
    [anon_sym_NOT] = ACTIONS(4475),
    [anon_sym_Not] = ACTIONS(4475),
    [anon_sym_POUNDelse] = ACTIONS(4477),
    [anon_sym_POUNDELSE] = ACTIONS(4477),
    [anon_sym_POUNDElse] = ACTIONS(4477),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4475),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4475),
    [anon_sym_PLUS] = ACTIONS(4477),
    [sym_datetime_literal] = ACTIONS(4477),
    [sym_date_literal] = ACTIONS(4475),
    [sym_time_literal] = ACTIONS(4475),
    [sym_biginteger_literal] = ACTIONS(4477),
    [anon_sym_if] = ACTIONS(4475),
    [anon_sym_IF] = ACTIONS(4475),
    [anon_sym_If] = ACTIONS(4475),
    [anon_sym_else] = ACTIONS(4475),
    [anon_sym_ELSE] = ACTIONS(4475),
    [anon_sym_Else] = ACTIONS(4475),
    [anon_sym_case] = ACTIONS(4475),
    [anon_sym_CASE] = ACTIONS(4475),
    [anon_sym_Case] = ACTIONS(4475),
    [anon_sym_for] = ACTIONS(4475),
    [anon_sym_FOR] = ACTIONS(4475),
    [anon_sym_For] = ACTIONS(4475),
    [anon_sym_foreach] = ACTIONS(4475),
    [anon_sym_FOREACH] = ACTIONS(4475),
    [anon_sym_Foreach] = ACTIONS(4475),
    [anon_sym_while] = ACTIONS(4475),
    [anon_sym_WHILE] = ACTIONS(4475),
    [anon_sym_While] = ACTIONS(4475),
    [anon_sym_repeat] = ACTIONS(4475),
    [anon_sym_REPEAT] = ACTIONS(4475),
    [anon_sym_Repeat] = ACTIONS(4475),
    [anon_sym_until] = ACTIONS(4475),
    [anon_sym_UNTIL] = ACTIONS(4475),
    [anon_sym_Until] = ACTIONS(4475),
    [anon_sym_exit] = ACTIONS(4475),
    [anon_sym_EXIT] = ACTIONS(4475),
    [anon_sym_Exit] = ACTIONS(4475),
    [anon_sym_continue] = ACTIONS(4475),
    [anon_sym_CONTINUE] = ACTIONS(4475),
    [anon_sym_Continue] = ACTIONS(4475),
    [anon_sym_break] = ACTIONS(4475),
    [anon_sym_BREAK] = ACTIONS(4475),
    [anon_sym_Break] = ACTIONS(4475),
    [anon_sym_with] = ACTIONS(4475),
    [anon_sym_WITH] = ACTIONS(4475),
    [anon_sym_With] = ACTIONS(4475),
    [sym_asserterror_keyword] = ACTIONS(4477),
    [sym_page_keyword] = ACTIONS(4475),
    [anon_sym_codeunit] = ACTIONS(4475),
    [anon_sym_CODEUNIT] = ACTIONS(4475),
    [anon_sym_Codeunit] = ACTIONS(4475),
    [anon_sym_CodeUnit] = ACTIONS(4475),
    [anon_sym_COdeunit] = ACTIONS(4475),
    [anon_sym_codeUnit] = ACTIONS(4475),
    [sym_report_keyword] = ACTIONS(4475),
    [sym_query_keyword] = ACTIONS(4475),
    [anon_sym_xmlport] = ACTIONS(4475),
    [anon_sym_XMLPORT] = ACTIONS(4475),
    [anon_sym_Xmlport] = ACTIONS(4475),
    [anon_sym_XMLport] = ACTIONS(4475),
    [anon_sym_XMLPort] = ACTIONS(4475),
    [anon_sym_XmlPort] = ACTIONS(4475),
    [anon_sym_enum] = ACTIONS(4475),
    [anon_sym_ENUM] = ACTIONS(4475),
    [anon_sym_Enum] = ACTIONS(4475),
    [anon_sym_eNUM] = ACTIONS(4475),
    [anon_sym_eNum] = ACTIONS(4475),
    [anon_sym_ENum] = ACTIONS(4475),
    [sym_quoted_identifier] = ACTIONS(4477),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4477),
    [sym_integer] = ACTIONS(4475),
    [sym_continue_as_identifier] = ACTIONS(4477),
    [sym_preproc_open] = ACTIONS(4477),
  },
  [STATE(1891)] = {
    [sym_identifier] = ACTIONS(4479),
    [anon_sym_SEMI] = ACTIONS(4481),
    [anon_sym_DASH] = ACTIONS(4481),
    [aux_sym_boolean_token1] = ACTIONS(4479),
    [aux_sym_boolean_token2] = ACTIONS(4479),
    [sym_decimal] = ACTIONS(4479),
    [anon_sym_LPAREN] = ACTIONS(4481),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4479),
    [anon_sym_LBRACK] = ACTIONS(4481),
    [aux_sym_record_type_token1] = ACTIONS(4479),
    [aux_sym_basic_type_token21] = ACTIONS(4479),
    [aux_sym_basic_type_token22] = ACTIONS(4479),
    [aux_sym_basic_type_token48] = ACTIONS(4479),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4479),
    [anon_sym_POUNDif] = ACTIONS(4481),
    [anon_sym_POUNDIF] = ACTIONS(4481),
    [anon_sym_POUNDIf] = ACTIONS(4481),
    [anon_sym_not] = ACTIONS(4479),
    [anon_sym_NOT] = ACTIONS(4479),
    [anon_sym_Not] = ACTIONS(4479),
    [anon_sym_POUNDelse] = ACTIONS(4481),
    [anon_sym_POUNDELSE] = ACTIONS(4481),
    [anon_sym_POUNDElse] = ACTIONS(4481),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4479),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4479),
    [anon_sym_PLUS] = ACTIONS(4481),
    [sym_datetime_literal] = ACTIONS(4481),
    [sym_date_literal] = ACTIONS(4479),
    [sym_time_literal] = ACTIONS(4479),
    [sym_biginteger_literal] = ACTIONS(4481),
    [anon_sym_if] = ACTIONS(4479),
    [anon_sym_IF] = ACTIONS(4479),
    [anon_sym_If] = ACTIONS(4479),
    [anon_sym_else] = ACTIONS(4479),
    [anon_sym_ELSE] = ACTIONS(4479),
    [anon_sym_Else] = ACTIONS(4479),
    [anon_sym_case] = ACTIONS(4479),
    [anon_sym_CASE] = ACTIONS(4479),
    [anon_sym_Case] = ACTIONS(4479),
    [anon_sym_for] = ACTIONS(4479),
    [anon_sym_FOR] = ACTIONS(4479),
    [anon_sym_For] = ACTIONS(4479),
    [anon_sym_foreach] = ACTIONS(4479),
    [anon_sym_FOREACH] = ACTIONS(4479),
    [anon_sym_Foreach] = ACTIONS(4479),
    [anon_sym_while] = ACTIONS(4479),
    [anon_sym_WHILE] = ACTIONS(4479),
    [anon_sym_While] = ACTIONS(4479),
    [anon_sym_repeat] = ACTIONS(4479),
    [anon_sym_REPEAT] = ACTIONS(4479),
    [anon_sym_Repeat] = ACTIONS(4479),
    [anon_sym_until] = ACTIONS(4479),
    [anon_sym_UNTIL] = ACTIONS(4479),
    [anon_sym_Until] = ACTIONS(4479),
    [anon_sym_exit] = ACTIONS(4479),
    [anon_sym_EXIT] = ACTIONS(4479),
    [anon_sym_Exit] = ACTIONS(4479),
    [anon_sym_continue] = ACTIONS(4479),
    [anon_sym_CONTINUE] = ACTIONS(4479),
    [anon_sym_Continue] = ACTIONS(4479),
    [anon_sym_break] = ACTIONS(4479),
    [anon_sym_BREAK] = ACTIONS(4479),
    [anon_sym_Break] = ACTIONS(4479),
    [anon_sym_with] = ACTIONS(4479),
    [anon_sym_WITH] = ACTIONS(4479),
    [anon_sym_With] = ACTIONS(4479),
    [sym_asserterror_keyword] = ACTIONS(4481),
    [sym_page_keyword] = ACTIONS(4479),
    [anon_sym_codeunit] = ACTIONS(4479),
    [anon_sym_CODEUNIT] = ACTIONS(4479),
    [anon_sym_Codeunit] = ACTIONS(4479),
    [anon_sym_CodeUnit] = ACTIONS(4479),
    [anon_sym_COdeunit] = ACTIONS(4479),
    [anon_sym_codeUnit] = ACTIONS(4479),
    [sym_report_keyword] = ACTIONS(4479),
    [sym_query_keyword] = ACTIONS(4479),
    [anon_sym_xmlport] = ACTIONS(4479),
    [anon_sym_XMLPORT] = ACTIONS(4479),
    [anon_sym_Xmlport] = ACTIONS(4479),
    [anon_sym_XMLport] = ACTIONS(4479),
    [anon_sym_XMLPort] = ACTIONS(4479),
    [anon_sym_XmlPort] = ACTIONS(4479),
    [anon_sym_enum] = ACTIONS(4479),
    [anon_sym_ENUM] = ACTIONS(4479),
    [anon_sym_Enum] = ACTIONS(4479),
    [anon_sym_eNUM] = ACTIONS(4479),
    [anon_sym_eNum] = ACTIONS(4479),
    [anon_sym_ENum] = ACTIONS(4479),
    [sym_quoted_identifier] = ACTIONS(4481),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4481),
    [sym_integer] = ACTIONS(4479),
    [sym_continue_as_identifier] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4481),
  },
  [STATE(1892)] = {
    [sym_boolean] = STATE(4795),
    [sym_option_member_list] = STATE(4805),
    [sym_option_member] = STATE(6181),
    [sym_keyword_identifier] = STATE(4795),
    [sym_codeunit_keyword] = STATE(4642),
    [sym_xmlport_keyword] = STATE(4642),
    [sym_enum_keyword] = STATE(4642),
    [sym_keyword_as_identifier] = STATE(4795),
    [aux_sym_option_member_list_repeat2] = STATE(2016),
    [sym_identifier] = ACTIONS(2239),
    [anon_sym_SEMI] = ACTIONS(275),
    [anon_sym_DOT] = ACTIONS(277),
    [anon_sym_EQ] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(4887),
    [anon_sym_DASH] = ACTIONS(3704),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [aux_sym_where_condition_token1] = ACTIONS(4844),
    [anon_sym_DOT_DOT] = ACTIONS(275),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(275),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(2221),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(4844),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4844),
    [aux_sym_separator_action_token1] = ACTIONS(4844),
    [aux_sym_type_declaration_token1] = ACTIONS(4844),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(275),
    [aux_sym__expression_token1] = ACTIONS(275),
    [aux_sym__expression_token2] = ACTIONS(275),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(917),
    [anon_sym_SLASH] = ACTIONS(277),
    [anon_sym_div] = ACTIONS(277),
    [anon_sym_DIV] = ACTIONS(277),
    [anon_sym_Div] = ACTIONS(277),
    [anon_sym_mod] = ACTIONS(277),
    [anon_sym_MOD] = ACTIONS(277),
    [anon_sym_Mod] = ACTIONS(277),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(275),
    [anon_sym_LT_EQ] = ACTIONS(275),
    [anon_sym_GT] = ACTIONS(277),
    [anon_sym_LT] = ACTIONS(277),
    [anon_sym_LT_GT] = ACTIONS(275),
    [anon_sym_and] = ACTIONS(277),
    [anon_sym_AND] = ACTIONS(277),
    [anon_sym_And] = ACTIONS(277),
    [anon_sym_or] = ACTIONS(277),
    [anon_sym_OR] = ACTIONS(277),
    [anon_sym_Or] = ACTIONS(277),
    [anon_sym_xor] = ACTIONS(277),
    [anon_sym_XOR] = ACTIONS(277),
    [anon_sym_Xor] = ACTIONS(277),
    [anon_sym_QMARK] = ACTIONS(275),
    [anon_sym_else] = ACTIONS(277),
    [anon_sym_ELSE] = ACTIONS(277),
    [anon_sym_Else] = ACTIONS(277),
    [anon_sym_in] = ACTIONS(277),
    [anon_sym_IN] = ACTIONS(277),
    [anon_sym_In] = ACTIONS(277),
    [sym_page_keyword] = ACTIONS(917),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(917),
    [sym_query_keyword] = ACTIONS(917),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(2239),
    [sym_internal_keyword] = ACTIONS(2239),
    [sym_protected_keyword] = ACTIONS(2239),
    [sym_key_keyword] = ACTIONS(4844),
    [sym_dataset_keyword] = ACTIONS(4844),
    [sym_quoted_identifier] = ACTIONS(3706),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3706),
    [sym_integer] = ACTIONS(3706),
  },
  [STATE(1893)] = {
    [sym_identifier] = ACTIONS(4483),
    [anon_sym_SEMI] = ACTIONS(4485),
    [anon_sym_DASH] = ACTIONS(4485),
    [aux_sym_boolean_token1] = ACTIONS(4483),
    [aux_sym_boolean_token2] = ACTIONS(4483),
    [sym_decimal] = ACTIONS(4483),
    [anon_sym_LPAREN] = ACTIONS(4485),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4483),
    [anon_sym_LBRACK] = ACTIONS(4485),
    [aux_sym_record_type_token1] = ACTIONS(4483),
    [aux_sym_basic_type_token21] = ACTIONS(4483),
    [aux_sym_basic_type_token22] = ACTIONS(4483),
    [aux_sym_basic_type_token48] = ACTIONS(4483),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4483),
    [anon_sym_POUNDif] = ACTIONS(4485),
    [anon_sym_POUNDIF] = ACTIONS(4485),
    [anon_sym_POUNDIf] = ACTIONS(4485),
    [anon_sym_not] = ACTIONS(4483),
    [anon_sym_NOT] = ACTIONS(4483),
    [anon_sym_Not] = ACTIONS(4483),
    [anon_sym_POUNDelse] = ACTIONS(4485),
    [anon_sym_POUNDELSE] = ACTIONS(4485),
    [anon_sym_POUNDElse] = ACTIONS(4485),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4483),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4483),
    [anon_sym_PLUS] = ACTIONS(4485),
    [sym_datetime_literal] = ACTIONS(4485),
    [sym_date_literal] = ACTIONS(4483),
    [sym_time_literal] = ACTIONS(4483),
    [sym_biginteger_literal] = ACTIONS(4485),
    [anon_sym_if] = ACTIONS(4483),
    [anon_sym_IF] = ACTIONS(4483),
    [anon_sym_If] = ACTIONS(4483),
    [anon_sym_else] = ACTIONS(4483),
    [anon_sym_ELSE] = ACTIONS(4483),
    [anon_sym_Else] = ACTIONS(4483),
    [anon_sym_case] = ACTIONS(4483),
    [anon_sym_CASE] = ACTIONS(4483),
    [anon_sym_Case] = ACTIONS(4483),
    [anon_sym_for] = ACTIONS(4483),
    [anon_sym_FOR] = ACTIONS(4483),
    [anon_sym_For] = ACTIONS(4483),
    [anon_sym_foreach] = ACTIONS(4483),
    [anon_sym_FOREACH] = ACTIONS(4483),
    [anon_sym_Foreach] = ACTIONS(4483),
    [anon_sym_while] = ACTIONS(4483),
    [anon_sym_WHILE] = ACTIONS(4483),
    [anon_sym_While] = ACTIONS(4483),
    [anon_sym_repeat] = ACTIONS(4483),
    [anon_sym_REPEAT] = ACTIONS(4483),
    [anon_sym_Repeat] = ACTIONS(4483),
    [anon_sym_until] = ACTIONS(4483),
    [anon_sym_UNTIL] = ACTIONS(4483),
    [anon_sym_Until] = ACTIONS(4483),
    [anon_sym_exit] = ACTIONS(4483),
    [anon_sym_EXIT] = ACTIONS(4483),
    [anon_sym_Exit] = ACTIONS(4483),
    [anon_sym_continue] = ACTIONS(4483),
    [anon_sym_CONTINUE] = ACTIONS(4483),
    [anon_sym_Continue] = ACTIONS(4483),
    [anon_sym_break] = ACTIONS(4483),
    [anon_sym_BREAK] = ACTIONS(4483),
    [anon_sym_Break] = ACTIONS(4483),
    [anon_sym_with] = ACTIONS(4483),
    [anon_sym_WITH] = ACTIONS(4483),
    [anon_sym_With] = ACTIONS(4483),
    [sym_asserterror_keyword] = ACTIONS(4485),
    [sym_page_keyword] = ACTIONS(4483),
    [anon_sym_codeunit] = ACTIONS(4483),
    [anon_sym_CODEUNIT] = ACTIONS(4483),
    [anon_sym_Codeunit] = ACTIONS(4483),
    [anon_sym_CodeUnit] = ACTIONS(4483),
    [anon_sym_COdeunit] = ACTIONS(4483),
    [anon_sym_codeUnit] = ACTIONS(4483),
    [sym_report_keyword] = ACTIONS(4483),
    [sym_query_keyword] = ACTIONS(4483),
    [anon_sym_xmlport] = ACTIONS(4483),
    [anon_sym_XMLPORT] = ACTIONS(4483),
    [anon_sym_Xmlport] = ACTIONS(4483),
    [anon_sym_XMLport] = ACTIONS(4483),
    [anon_sym_XMLPort] = ACTIONS(4483),
    [anon_sym_XmlPort] = ACTIONS(4483),
    [anon_sym_enum] = ACTIONS(4483),
    [anon_sym_ENUM] = ACTIONS(4483),
    [anon_sym_Enum] = ACTIONS(4483),
    [anon_sym_eNUM] = ACTIONS(4483),
    [anon_sym_eNum] = ACTIONS(4483),
    [anon_sym_ENum] = ACTIONS(4483),
    [sym_quoted_identifier] = ACTIONS(4485),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4485),
    [sym_integer] = ACTIONS(4483),
    [sym_continue_as_identifier] = ACTIONS(4485),
    [sym_preproc_open] = ACTIONS(4485),
  },
  [STATE(1894)] = {
    [sym_identifier] = ACTIONS(4487),
    [anon_sym_SEMI] = ACTIONS(4489),
    [anon_sym_DASH] = ACTIONS(4489),
    [aux_sym_boolean_token1] = ACTIONS(4487),
    [aux_sym_boolean_token2] = ACTIONS(4487),
    [sym_decimal] = ACTIONS(4487),
    [anon_sym_LPAREN] = ACTIONS(4489),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4487),
    [anon_sym_LBRACK] = ACTIONS(4489),
    [aux_sym_record_type_token1] = ACTIONS(4487),
    [aux_sym_basic_type_token21] = ACTIONS(4487),
    [aux_sym_basic_type_token22] = ACTIONS(4487),
    [aux_sym_basic_type_token48] = ACTIONS(4487),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4487),
    [anon_sym_POUNDif] = ACTIONS(4489),
    [anon_sym_POUNDIF] = ACTIONS(4489),
    [anon_sym_POUNDIf] = ACTIONS(4489),
    [anon_sym_not] = ACTIONS(4487),
    [anon_sym_NOT] = ACTIONS(4487),
    [anon_sym_Not] = ACTIONS(4487),
    [anon_sym_POUNDelse] = ACTIONS(4489),
    [anon_sym_POUNDELSE] = ACTIONS(4489),
    [anon_sym_POUNDElse] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4487),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4487),
    [anon_sym_PLUS] = ACTIONS(4489),
    [sym_datetime_literal] = ACTIONS(4489),
    [sym_date_literal] = ACTIONS(4487),
    [sym_time_literal] = ACTIONS(4487),
    [sym_biginteger_literal] = ACTIONS(4489),
    [anon_sym_if] = ACTIONS(4487),
    [anon_sym_IF] = ACTIONS(4487),
    [anon_sym_If] = ACTIONS(4487),
    [anon_sym_else] = ACTIONS(4487),
    [anon_sym_ELSE] = ACTIONS(4487),
    [anon_sym_Else] = ACTIONS(4487),
    [anon_sym_case] = ACTIONS(4487),
    [anon_sym_CASE] = ACTIONS(4487),
    [anon_sym_Case] = ACTIONS(4487),
    [anon_sym_for] = ACTIONS(4487),
    [anon_sym_FOR] = ACTIONS(4487),
    [anon_sym_For] = ACTIONS(4487),
    [anon_sym_foreach] = ACTIONS(4487),
    [anon_sym_FOREACH] = ACTIONS(4487),
    [anon_sym_Foreach] = ACTIONS(4487),
    [anon_sym_while] = ACTIONS(4487),
    [anon_sym_WHILE] = ACTIONS(4487),
    [anon_sym_While] = ACTIONS(4487),
    [anon_sym_repeat] = ACTIONS(4487),
    [anon_sym_REPEAT] = ACTIONS(4487),
    [anon_sym_Repeat] = ACTIONS(4487),
    [anon_sym_until] = ACTIONS(4487),
    [anon_sym_UNTIL] = ACTIONS(4487),
    [anon_sym_Until] = ACTIONS(4487),
    [anon_sym_exit] = ACTIONS(4487),
    [anon_sym_EXIT] = ACTIONS(4487),
    [anon_sym_Exit] = ACTIONS(4487),
    [anon_sym_continue] = ACTIONS(4487),
    [anon_sym_CONTINUE] = ACTIONS(4487),
    [anon_sym_Continue] = ACTIONS(4487),
    [anon_sym_break] = ACTIONS(4487),
    [anon_sym_BREAK] = ACTIONS(4487),
    [anon_sym_Break] = ACTIONS(4487),
    [anon_sym_with] = ACTIONS(4487),
    [anon_sym_WITH] = ACTIONS(4487),
    [anon_sym_With] = ACTIONS(4487),
    [sym_asserterror_keyword] = ACTIONS(4489),
    [sym_page_keyword] = ACTIONS(4487),
    [anon_sym_codeunit] = ACTIONS(4487),
    [anon_sym_CODEUNIT] = ACTIONS(4487),
    [anon_sym_Codeunit] = ACTIONS(4487),
    [anon_sym_CodeUnit] = ACTIONS(4487),
    [anon_sym_COdeunit] = ACTIONS(4487),
    [anon_sym_codeUnit] = ACTIONS(4487),
    [sym_report_keyword] = ACTIONS(4487),
    [sym_query_keyword] = ACTIONS(4487),
    [anon_sym_xmlport] = ACTIONS(4487),
    [anon_sym_XMLPORT] = ACTIONS(4487),
    [anon_sym_Xmlport] = ACTIONS(4487),
    [anon_sym_XMLport] = ACTIONS(4487),
    [anon_sym_XMLPort] = ACTIONS(4487),
    [anon_sym_XmlPort] = ACTIONS(4487),
    [anon_sym_enum] = ACTIONS(4487),
    [anon_sym_ENUM] = ACTIONS(4487),
    [anon_sym_Enum] = ACTIONS(4487),
    [anon_sym_eNUM] = ACTIONS(4487),
    [anon_sym_eNum] = ACTIONS(4487),
    [anon_sym_ENum] = ACTIONS(4487),
    [sym_quoted_identifier] = ACTIONS(4489),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4489),
    [sym_integer] = ACTIONS(4487),
    [sym_continue_as_identifier] = ACTIONS(4489),
    [sym_preproc_open] = ACTIONS(4489),
  },
  [STATE(1895)] = {
    [sym_identifier] = ACTIONS(4491),
    [anon_sym_SEMI] = ACTIONS(4493),
    [anon_sym_DASH] = ACTIONS(4493),
    [aux_sym_boolean_token1] = ACTIONS(4491),
    [aux_sym_boolean_token2] = ACTIONS(4491),
    [sym_decimal] = ACTIONS(4491),
    [anon_sym_LPAREN] = ACTIONS(4493),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4491),
    [anon_sym_LBRACK] = ACTIONS(4493),
    [aux_sym_record_type_token1] = ACTIONS(4491),
    [aux_sym_basic_type_token21] = ACTIONS(4491),
    [aux_sym_basic_type_token22] = ACTIONS(4491),
    [aux_sym_basic_type_token48] = ACTIONS(4491),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4491),
    [anon_sym_POUNDif] = ACTIONS(4493),
    [anon_sym_POUNDIF] = ACTIONS(4493),
    [anon_sym_POUNDIf] = ACTIONS(4493),
    [anon_sym_not] = ACTIONS(4491),
    [anon_sym_NOT] = ACTIONS(4491),
    [anon_sym_Not] = ACTIONS(4491),
    [anon_sym_POUNDelse] = ACTIONS(4493),
    [anon_sym_POUNDELSE] = ACTIONS(4493),
    [anon_sym_POUNDElse] = ACTIONS(4493),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4491),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4491),
    [anon_sym_PLUS] = ACTIONS(4493),
    [sym_datetime_literal] = ACTIONS(4493),
    [sym_date_literal] = ACTIONS(4491),
    [sym_time_literal] = ACTIONS(4491),
    [sym_biginteger_literal] = ACTIONS(4493),
    [anon_sym_if] = ACTIONS(4491),
    [anon_sym_IF] = ACTIONS(4491),
    [anon_sym_If] = ACTIONS(4491),
    [anon_sym_else] = ACTIONS(4491),
    [anon_sym_ELSE] = ACTIONS(4491),
    [anon_sym_Else] = ACTIONS(4491),
    [anon_sym_case] = ACTIONS(4491),
    [anon_sym_CASE] = ACTIONS(4491),
    [anon_sym_Case] = ACTIONS(4491),
    [anon_sym_for] = ACTIONS(4491),
    [anon_sym_FOR] = ACTIONS(4491),
    [anon_sym_For] = ACTIONS(4491),
    [anon_sym_foreach] = ACTIONS(4491),
    [anon_sym_FOREACH] = ACTIONS(4491),
    [anon_sym_Foreach] = ACTIONS(4491),
    [anon_sym_while] = ACTIONS(4491),
    [anon_sym_WHILE] = ACTIONS(4491),
    [anon_sym_While] = ACTIONS(4491),
    [anon_sym_repeat] = ACTIONS(4491),
    [anon_sym_REPEAT] = ACTIONS(4491),
    [anon_sym_Repeat] = ACTIONS(4491),
    [anon_sym_until] = ACTIONS(4491),
    [anon_sym_UNTIL] = ACTIONS(4491),
    [anon_sym_Until] = ACTIONS(4491),
    [anon_sym_exit] = ACTIONS(4491),
    [anon_sym_EXIT] = ACTIONS(4491),
    [anon_sym_Exit] = ACTIONS(4491),
    [anon_sym_continue] = ACTIONS(4491),
    [anon_sym_CONTINUE] = ACTIONS(4491),
    [anon_sym_Continue] = ACTIONS(4491),
    [anon_sym_break] = ACTIONS(4491),
    [anon_sym_BREAK] = ACTIONS(4491),
    [anon_sym_Break] = ACTIONS(4491),
    [anon_sym_with] = ACTIONS(4491),
    [anon_sym_WITH] = ACTIONS(4491),
    [anon_sym_With] = ACTIONS(4491),
    [sym_asserterror_keyword] = ACTIONS(4493),
    [sym_page_keyword] = ACTIONS(4491),
    [anon_sym_codeunit] = ACTIONS(4491),
    [anon_sym_CODEUNIT] = ACTIONS(4491),
    [anon_sym_Codeunit] = ACTIONS(4491),
    [anon_sym_CodeUnit] = ACTIONS(4491),
    [anon_sym_COdeunit] = ACTIONS(4491),
    [anon_sym_codeUnit] = ACTIONS(4491),
    [sym_report_keyword] = ACTIONS(4491),
    [sym_query_keyword] = ACTIONS(4491),
    [anon_sym_xmlport] = ACTIONS(4491),
    [anon_sym_XMLPORT] = ACTIONS(4491),
    [anon_sym_Xmlport] = ACTIONS(4491),
    [anon_sym_XMLport] = ACTIONS(4491),
    [anon_sym_XMLPort] = ACTIONS(4491),
    [anon_sym_XmlPort] = ACTIONS(4491),
    [anon_sym_enum] = ACTIONS(4491),
    [anon_sym_ENUM] = ACTIONS(4491),
    [anon_sym_Enum] = ACTIONS(4491),
    [anon_sym_eNUM] = ACTIONS(4491),
    [anon_sym_eNum] = ACTIONS(4491),
    [anon_sym_ENum] = ACTIONS(4491),
    [sym_quoted_identifier] = ACTIONS(4493),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4493),
    [sym_integer] = ACTIONS(4491),
    [sym_continue_as_identifier] = ACTIONS(4493),
    [sym_preproc_open] = ACTIONS(4493),
  },
  [STATE(1896)] = {
    [sym_identifier] = ACTIONS(4495),
    [anon_sym_SEMI] = ACTIONS(4497),
    [anon_sym_DASH] = ACTIONS(4497),
    [aux_sym_boolean_token1] = ACTIONS(4495),
    [aux_sym_boolean_token2] = ACTIONS(4495),
    [sym_decimal] = ACTIONS(4495),
    [anon_sym_LPAREN] = ACTIONS(4497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4495),
    [anon_sym_LBRACK] = ACTIONS(4497),
    [aux_sym_record_type_token1] = ACTIONS(4495),
    [aux_sym_basic_type_token21] = ACTIONS(4495),
    [aux_sym_basic_type_token22] = ACTIONS(4495),
    [aux_sym_basic_type_token48] = ACTIONS(4495),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4495),
    [anon_sym_POUNDif] = ACTIONS(4497),
    [anon_sym_POUNDIF] = ACTIONS(4497),
    [anon_sym_POUNDIf] = ACTIONS(4497),
    [anon_sym_not] = ACTIONS(4495),
    [anon_sym_NOT] = ACTIONS(4495),
    [anon_sym_Not] = ACTIONS(4495),
    [anon_sym_POUNDelse] = ACTIONS(4497),
    [anon_sym_POUNDELSE] = ACTIONS(4497),
    [anon_sym_POUNDElse] = ACTIONS(4497),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4495),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4495),
    [anon_sym_PLUS] = ACTIONS(4497),
    [sym_datetime_literal] = ACTIONS(4497),
    [sym_date_literal] = ACTIONS(4495),
    [sym_time_literal] = ACTIONS(4495),
    [sym_biginteger_literal] = ACTIONS(4497),
    [anon_sym_if] = ACTIONS(4495),
    [anon_sym_IF] = ACTIONS(4495),
    [anon_sym_If] = ACTIONS(4495),
    [anon_sym_else] = ACTIONS(4495),
    [anon_sym_ELSE] = ACTIONS(4495),
    [anon_sym_Else] = ACTIONS(4495),
    [anon_sym_case] = ACTIONS(4495),
    [anon_sym_CASE] = ACTIONS(4495),
    [anon_sym_Case] = ACTIONS(4495),
    [anon_sym_for] = ACTIONS(4495),
    [anon_sym_FOR] = ACTIONS(4495),
    [anon_sym_For] = ACTIONS(4495),
    [anon_sym_foreach] = ACTIONS(4495),
    [anon_sym_FOREACH] = ACTIONS(4495),
    [anon_sym_Foreach] = ACTIONS(4495),
    [anon_sym_while] = ACTIONS(4495),
    [anon_sym_WHILE] = ACTIONS(4495),
    [anon_sym_While] = ACTIONS(4495),
    [anon_sym_repeat] = ACTIONS(4495),
    [anon_sym_REPEAT] = ACTIONS(4495),
    [anon_sym_Repeat] = ACTIONS(4495),
    [anon_sym_until] = ACTIONS(4495),
    [anon_sym_UNTIL] = ACTIONS(4495),
    [anon_sym_Until] = ACTIONS(4495),
    [anon_sym_exit] = ACTIONS(4495),
    [anon_sym_EXIT] = ACTIONS(4495),
    [anon_sym_Exit] = ACTIONS(4495),
    [anon_sym_continue] = ACTIONS(4495),
    [anon_sym_CONTINUE] = ACTIONS(4495),
    [anon_sym_Continue] = ACTIONS(4495),
    [anon_sym_break] = ACTIONS(4495),
    [anon_sym_BREAK] = ACTIONS(4495),
    [anon_sym_Break] = ACTIONS(4495),
    [anon_sym_with] = ACTIONS(4495),
    [anon_sym_WITH] = ACTIONS(4495),
    [anon_sym_With] = ACTIONS(4495),
    [sym_asserterror_keyword] = ACTIONS(4497),
    [sym_page_keyword] = ACTIONS(4495),
    [anon_sym_codeunit] = ACTIONS(4495),
    [anon_sym_CODEUNIT] = ACTIONS(4495),
    [anon_sym_Codeunit] = ACTIONS(4495),
    [anon_sym_CodeUnit] = ACTIONS(4495),
    [anon_sym_COdeunit] = ACTIONS(4495),
    [anon_sym_codeUnit] = ACTIONS(4495),
    [sym_report_keyword] = ACTIONS(4495),
    [sym_query_keyword] = ACTIONS(4495),
    [anon_sym_xmlport] = ACTIONS(4495),
    [anon_sym_XMLPORT] = ACTIONS(4495),
    [anon_sym_Xmlport] = ACTIONS(4495),
    [anon_sym_XMLport] = ACTIONS(4495),
    [anon_sym_XMLPort] = ACTIONS(4495),
    [anon_sym_XmlPort] = ACTIONS(4495),
    [anon_sym_enum] = ACTIONS(4495),
    [anon_sym_ENUM] = ACTIONS(4495),
    [anon_sym_Enum] = ACTIONS(4495),
    [anon_sym_eNUM] = ACTIONS(4495),
    [anon_sym_eNum] = ACTIONS(4495),
    [anon_sym_ENum] = ACTIONS(4495),
    [sym_quoted_identifier] = ACTIONS(4497),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4497),
    [sym_integer] = ACTIONS(4495),
    [sym_continue_as_identifier] = ACTIONS(4497),
    [sym_preproc_open] = ACTIONS(4497),
  },
  [STATE(1897)] = {
    [sym_identifier] = ACTIONS(4499),
    [anon_sym_SEMI] = ACTIONS(4501),
    [anon_sym_DASH] = ACTIONS(4501),
    [aux_sym_boolean_token1] = ACTIONS(4499),
    [aux_sym_boolean_token2] = ACTIONS(4499),
    [sym_decimal] = ACTIONS(4499),
    [anon_sym_LPAREN] = ACTIONS(4501),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4499),
    [anon_sym_LBRACK] = ACTIONS(4501),
    [aux_sym_record_type_token1] = ACTIONS(4499),
    [aux_sym_basic_type_token21] = ACTIONS(4499),
    [aux_sym_basic_type_token22] = ACTIONS(4499),
    [aux_sym_basic_type_token48] = ACTIONS(4499),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4499),
    [anon_sym_POUNDif] = ACTIONS(4501),
    [anon_sym_POUNDIF] = ACTIONS(4501),
    [anon_sym_POUNDIf] = ACTIONS(4501),
    [anon_sym_not] = ACTIONS(4499),
    [anon_sym_NOT] = ACTIONS(4499),
    [anon_sym_Not] = ACTIONS(4499),
    [anon_sym_POUNDelse] = ACTIONS(4501),
    [anon_sym_POUNDELSE] = ACTIONS(4501),
    [anon_sym_POUNDElse] = ACTIONS(4501),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4499),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4499),
    [anon_sym_PLUS] = ACTIONS(4501),
    [sym_datetime_literal] = ACTIONS(4501),
    [sym_date_literal] = ACTIONS(4499),
    [sym_time_literal] = ACTIONS(4499),
    [sym_biginteger_literal] = ACTIONS(4501),
    [anon_sym_if] = ACTIONS(4499),
    [anon_sym_IF] = ACTIONS(4499),
    [anon_sym_If] = ACTIONS(4499),
    [anon_sym_else] = ACTIONS(4499),
    [anon_sym_ELSE] = ACTIONS(4499),
    [anon_sym_Else] = ACTIONS(4499),
    [anon_sym_case] = ACTIONS(4499),
    [anon_sym_CASE] = ACTIONS(4499),
    [anon_sym_Case] = ACTIONS(4499),
    [anon_sym_for] = ACTIONS(4499),
    [anon_sym_FOR] = ACTIONS(4499),
    [anon_sym_For] = ACTIONS(4499),
    [anon_sym_foreach] = ACTIONS(4499),
    [anon_sym_FOREACH] = ACTIONS(4499),
    [anon_sym_Foreach] = ACTIONS(4499),
    [anon_sym_while] = ACTIONS(4499),
    [anon_sym_WHILE] = ACTIONS(4499),
    [anon_sym_While] = ACTIONS(4499),
    [anon_sym_repeat] = ACTIONS(4499),
    [anon_sym_REPEAT] = ACTIONS(4499),
    [anon_sym_Repeat] = ACTIONS(4499),
    [anon_sym_until] = ACTIONS(4499),
    [anon_sym_UNTIL] = ACTIONS(4499),
    [anon_sym_Until] = ACTIONS(4499),
    [anon_sym_exit] = ACTIONS(4499),
    [anon_sym_EXIT] = ACTIONS(4499),
    [anon_sym_Exit] = ACTIONS(4499),
    [anon_sym_continue] = ACTIONS(4499),
    [anon_sym_CONTINUE] = ACTIONS(4499),
    [anon_sym_Continue] = ACTIONS(4499),
    [anon_sym_break] = ACTIONS(4499),
    [anon_sym_BREAK] = ACTIONS(4499),
    [anon_sym_Break] = ACTIONS(4499),
    [anon_sym_with] = ACTIONS(4499),
    [anon_sym_WITH] = ACTIONS(4499),
    [anon_sym_With] = ACTIONS(4499),
    [sym_asserterror_keyword] = ACTIONS(4501),
    [sym_page_keyword] = ACTIONS(4499),
    [anon_sym_codeunit] = ACTIONS(4499),
    [anon_sym_CODEUNIT] = ACTIONS(4499),
    [anon_sym_Codeunit] = ACTIONS(4499),
    [anon_sym_CodeUnit] = ACTIONS(4499),
    [anon_sym_COdeunit] = ACTIONS(4499),
    [anon_sym_codeUnit] = ACTIONS(4499),
    [sym_report_keyword] = ACTIONS(4499),
    [sym_query_keyword] = ACTIONS(4499),
    [anon_sym_xmlport] = ACTIONS(4499),
    [anon_sym_XMLPORT] = ACTIONS(4499),
    [anon_sym_Xmlport] = ACTIONS(4499),
    [anon_sym_XMLport] = ACTIONS(4499),
    [anon_sym_XMLPort] = ACTIONS(4499),
    [anon_sym_XmlPort] = ACTIONS(4499),
    [anon_sym_enum] = ACTIONS(4499),
    [anon_sym_ENUM] = ACTIONS(4499),
    [anon_sym_Enum] = ACTIONS(4499),
    [anon_sym_eNUM] = ACTIONS(4499),
    [anon_sym_eNum] = ACTIONS(4499),
    [anon_sym_ENum] = ACTIONS(4499),
    [sym_quoted_identifier] = ACTIONS(4501),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4501),
    [sym_integer] = ACTIONS(4499),
    [sym_continue_as_identifier] = ACTIONS(4501),
    [sym_preproc_open] = ACTIONS(4501),
  },
  [STATE(1898)] = {
    [sym_identifier] = ACTIONS(4503),
    [anon_sym_SEMI] = ACTIONS(4505),
    [anon_sym_DASH] = ACTIONS(4505),
    [aux_sym_boolean_token1] = ACTIONS(4503),
    [aux_sym_boolean_token2] = ACTIONS(4503),
    [sym_decimal] = ACTIONS(4503),
    [anon_sym_LPAREN] = ACTIONS(4505),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4503),
    [anon_sym_LBRACK] = ACTIONS(4505),
    [aux_sym_record_type_token1] = ACTIONS(4503),
    [aux_sym_basic_type_token21] = ACTIONS(4503),
    [aux_sym_basic_type_token22] = ACTIONS(4503),
    [aux_sym_basic_type_token48] = ACTIONS(4503),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4503),
    [anon_sym_POUNDif] = ACTIONS(4505),
    [anon_sym_POUNDIF] = ACTIONS(4505),
    [anon_sym_POUNDIf] = ACTIONS(4505),
    [anon_sym_not] = ACTIONS(4503),
    [anon_sym_NOT] = ACTIONS(4503),
    [anon_sym_Not] = ACTIONS(4503),
    [anon_sym_POUNDelse] = ACTIONS(4505),
    [anon_sym_POUNDELSE] = ACTIONS(4505),
    [anon_sym_POUNDElse] = ACTIONS(4505),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4503),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4503),
    [anon_sym_PLUS] = ACTIONS(4505),
    [sym_datetime_literal] = ACTIONS(4505),
    [sym_date_literal] = ACTIONS(4503),
    [sym_time_literal] = ACTIONS(4503),
    [sym_biginteger_literal] = ACTIONS(4505),
    [anon_sym_if] = ACTIONS(4503),
    [anon_sym_IF] = ACTIONS(4503),
    [anon_sym_If] = ACTIONS(4503),
    [anon_sym_else] = ACTIONS(4503),
    [anon_sym_ELSE] = ACTIONS(4503),
    [anon_sym_Else] = ACTIONS(4503),
    [anon_sym_case] = ACTIONS(4503),
    [anon_sym_CASE] = ACTIONS(4503),
    [anon_sym_Case] = ACTIONS(4503),
    [anon_sym_for] = ACTIONS(4503),
    [anon_sym_FOR] = ACTIONS(4503),
    [anon_sym_For] = ACTIONS(4503),
    [anon_sym_foreach] = ACTIONS(4503),
    [anon_sym_FOREACH] = ACTIONS(4503),
    [anon_sym_Foreach] = ACTIONS(4503),
    [anon_sym_while] = ACTIONS(4503),
    [anon_sym_WHILE] = ACTIONS(4503),
    [anon_sym_While] = ACTIONS(4503),
    [anon_sym_repeat] = ACTIONS(4503),
    [anon_sym_REPEAT] = ACTIONS(4503),
    [anon_sym_Repeat] = ACTIONS(4503),
    [anon_sym_until] = ACTIONS(4503),
    [anon_sym_UNTIL] = ACTIONS(4503),
    [anon_sym_Until] = ACTIONS(4503),
    [anon_sym_exit] = ACTIONS(4503),
    [anon_sym_EXIT] = ACTIONS(4503),
    [anon_sym_Exit] = ACTIONS(4503),
    [anon_sym_continue] = ACTIONS(4503),
    [anon_sym_CONTINUE] = ACTIONS(4503),
    [anon_sym_Continue] = ACTIONS(4503),
    [anon_sym_break] = ACTIONS(4503),
    [anon_sym_BREAK] = ACTIONS(4503),
    [anon_sym_Break] = ACTIONS(4503),
    [anon_sym_with] = ACTIONS(4503),
    [anon_sym_WITH] = ACTIONS(4503),
    [anon_sym_With] = ACTIONS(4503),
    [sym_asserterror_keyword] = ACTIONS(4505),
    [sym_page_keyword] = ACTIONS(4503),
    [anon_sym_codeunit] = ACTIONS(4503),
    [anon_sym_CODEUNIT] = ACTIONS(4503),
    [anon_sym_Codeunit] = ACTIONS(4503),
    [anon_sym_CodeUnit] = ACTIONS(4503),
    [anon_sym_COdeunit] = ACTIONS(4503),
    [anon_sym_codeUnit] = ACTIONS(4503),
    [sym_report_keyword] = ACTIONS(4503),
    [sym_query_keyword] = ACTIONS(4503),
    [anon_sym_xmlport] = ACTIONS(4503),
    [anon_sym_XMLPORT] = ACTIONS(4503),
    [anon_sym_Xmlport] = ACTIONS(4503),
    [anon_sym_XMLport] = ACTIONS(4503),
    [anon_sym_XMLPort] = ACTIONS(4503),
    [anon_sym_XmlPort] = ACTIONS(4503),
    [anon_sym_enum] = ACTIONS(4503),
    [anon_sym_ENUM] = ACTIONS(4503),
    [anon_sym_Enum] = ACTIONS(4503),
    [anon_sym_eNUM] = ACTIONS(4503),
    [anon_sym_eNum] = ACTIONS(4503),
    [anon_sym_ENum] = ACTIONS(4503),
    [sym_quoted_identifier] = ACTIONS(4505),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4505),
    [sym_integer] = ACTIONS(4503),
    [sym_continue_as_identifier] = ACTIONS(4505),
    [sym_preproc_open] = ACTIONS(4505),
  },
  [STATE(1899)] = {
    [sym_identifier] = ACTIONS(4507),
    [anon_sym_SEMI] = ACTIONS(4509),
    [anon_sym_DASH] = ACTIONS(4509),
    [aux_sym_boolean_token1] = ACTIONS(4507),
    [aux_sym_boolean_token2] = ACTIONS(4507),
    [sym_decimal] = ACTIONS(4507),
    [anon_sym_LPAREN] = ACTIONS(4509),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4507),
    [anon_sym_LBRACK] = ACTIONS(4509),
    [aux_sym_record_type_token1] = ACTIONS(4507),
    [aux_sym_basic_type_token21] = ACTIONS(4507),
    [aux_sym_basic_type_token22] = ACTIONS(4507),
    [aux_sym_basic_type_token48] = ACTIONS(4507),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4507),
    [anon_sym_POUNDif] = ACTIONS(4509),
    [anon_sym_POUNDIF] = ACTIONS(4509),
    [anon_sym_POUNDIf] = ACTIONS(4509),
    [anon_sym_not] = ACTIONS(4507),
    [anon_sym_NOT] = ACTIONS(4507),
    [anon_sym_Not] = ACTIONS(4507),
    [anon_sym_POUNDelse] = ACTIONS(4509),
    [anon_sym_POUNDELSE] = ACTIONS(4509),
    [anon_sym_POUNDElse] = ACTIONS(4509),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4507),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4507),
    [anon_sym_PLUS] = ACTIONS(4509),
    [sym_datetime_literal] = ACTIONS(4509),
    [sym_date_literal] = ACTIONS(4507),
    [sym_time_literal] = ACTIONS(4507),
    [sym_biginteger_literal] = ACTIONS(4509),
    [anon_sym_if] = ACTIONS(4507),
    [anon_sym_IF] = ACTIONS(4507),
    [anon_sym_If] = ACTIONS(4507),
    [anon_sym_else] = ACTIONS(4507),
    [anon_sym_ELSE] = ACTIONS(4507),
    [anon_sym_Else] = ACTIONS(4507),
    [anon_sym_case] = ACTIONS(4507),
    [anon_sym_CASE] = ACTIONS(4507),
    [anon_sym_Case] = ACTIONS(4507),
    [anon_sym_for] = ACTIONS(4507),
    [anon_sym_FOR] = ACTIONS(4507),
    [anon_sym_For] = ACTIONS(4507),
    [anon_sym_foreach] = ACTIONS(4507),
    [anon_sym_FOREACH] = ACTIONS(4507),
    [anon_sym_Foreach] = ACTIONS(4507),
    [anon_sym_while] = ACTIONS(4507),
    [anon_sym_WHILE] = ACTIONS(4507),
    [anon_sym_While] = ACTIONS(4507),
    [anon_sym_repeat] = ACTIONS(4507),
    [anon_sym_REPEAT] = ACTIONS(4507),
    [anon_sym_Repeat] = ACTIONS(4507),
    [anon_sym_until] = ACTIONS(4507),
    [anon_sym_UNTIL] = ACTIONS(4507),
    [anon_sym_Until] = ACTIONS(4507),
    [anon_sym_exit] = ACTIONS(4507),
    [anon_sym_EXIT] = ACTIONS(4507),
    [anon_sym_Exit] = ACTIONS(4507),
    [anon_sym_continue] = ACTIONS(4507),
    [anon_sym_CONTINUE] = ACTIONS(4507),
    [anon_sym_Continue] = ACTIONS(4507),
    [anon_sym_break] = ACTIONS(4507),
    [anon_sym_BREAK] = ACTIONS(4507),
    [anon_sym_Break] = ACTIONS(4507),
    [anon_sym_with] = ACTIONS(4507),
    [anon_sym_WITH] = ACTIONS(4507),
    [anon_sym_With] = ACTIONS(4507),
    [sym_asserterror_keyword] = ACTIONS(4509),
    [sym_page_keyword] = ACTIONS(4507),
    [anon_sym_codeunit] = ACTIONS(4507),
    [anon_sym_CODEUNIT] = ACTIONS(4507),
    [anon_sym_Codeunit] = ACTIONS(4507),
    [anon_sym_CodeUnit] = ACTIONS(4507),
    [anon_sym_COdeunit] = ACTIONS(4507),
    [anon_sym_codeUnit] = ACTIONS(4507),
    [sym_report_keyword] = ACTIONS(4507),
    [sym_query_keyword] = ACTIONS(4507),
    [anon_sym_xmlport] = ACTIONS(4507),
    [anon_sym_XMLPORT] = ACTIONS(4507),
    [anon_sym_Xmlport] = ACTIONS(4507),
    [anon_sym_XMLport] = ACTIONS(4507),
    [anon_sym_XMLPort] = ACTIONS(4507),
    [anon_sym_XmlPort] = ACTIONS(4507),
    [anon_sym_enum] = ACTIONS(4507),
    [anon_sym_ENUM] = ACTIONS(4507),
    [anon_sym_Enum] = ACTIONS(4507),
    [anon_sym_eNUM] = ACTIONS(4507),
    [anon_sym_eNum] = ACTIONS(4507),
    [anon_sym_ENum] = ACTIONS(4507),
    [sym_quoted_identifier] = ACTIONS(4509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4509),
    [sym_integer] = ACTIONS(4507),
    [sym_continue_as_identifier] = ACTIONS(4509),
    [sym_preproc_open] = ACTIONS(4509),
  },
  [STATE(1900)] = {
    [sym_identifier] = ACTIONS(4584),
    [anon_sym_SEMI] = ACTIONS(4586),
    [anon_sym_DASH] = ACTIONS(4586),
    [aux_sym_boolean_token1] = ACTIONS(4584),
    [aux_sym_boolean_token2] = ACTIONS(4584),
    [sym_decimal] = ACTIONS(4584),
    [anon_sym_LPAREN] = ACTIONS(4586),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4584),
    [anon_sym_LBRACK] = ACTIONS(4586),
    [aux_sym_record_type_token1] = ACTIONS(4584),
    [aux_sym_basic_type_token21] = ACTIONS(4584),
    [aux_sym_basic_type_token22] = ACTIONS(4584),
    [aux_sym_basic_type_token48] = ACTIONS(4584),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4584),
    [anon_sym_POUNDif] = ACTIONS(4586),
    [anon_sym_POUNDIF] = ACTIONS(4586),
    [anon_sym_POUNDIf] = ACTIONS(4586),
    [anon_sym_not] = ACTIONS(4584),
    [anon_sym_NOT] = ACTIONS(4584),
    [anon_sym_Not] = ACTIONS(4584),
    [anon_sym_POUNDelse] = ACTIONS(4586),
    [anon_sym_POUNDELSE] = ACTIONS(4586),
    [anon_sym_POUNDElse] = ACTIONS(4586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4584),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4584),
    [anon_sym_PLUS] = ACTIONS(4586),
    [sym_datetime_literal] = ACTIONS(4586),
    [sym_date_literal] = ACTIONS(4584),
    [sym_time_literal] = ACTIONS(4584),
    [sym_biginteger_literal] = ACTIONS(4586),
    [anon_sym_if] = ACTIONS(4584),
    [anon_sym_IF] = ACTIONS(4584),
    [anon_sym_If] = ACTIONS(4584),
    [anon_sym_else] = ACTIONS(4584),
    [anon_sym_ELSE] = ACTIONS(4584),
    [anon_sym_Else] = ACTIONS(4584),
    [anon_sym_case] = ACTIONS(4584),
    [anon_sym_CASE] = ACTIONS(4584),
    [anon_sym_Case] = ACTIONS(4584),
    [anon_sym_for] = ACTIONS(4584),
    [anon_sym_FOR] = ACTIONS(4584),
    [anon_sym_For] = ACTIONS(4584),
    [anon_sym_foreach] = ACTIONS(4584),
    [anon_sym_FOREACH] = ACTIONS(4584),
    [anon_sym_Foreach] = ACTIONS(4584),
    [anon_sym_while] = ACTIONS(4584),
    [anon_sym_WHILE] = ACTIONS(4584),
    [anon_sym_While] = ACTIONS(4584),
    [anon_sym_repeat] = ACTIONS(4584),
    [anon_sym_REPEAT] = ACTIONS(4584),
    [anon_sym_Repeat] = ACTIONS(4584),
    [anon_sym_until] = ACTIONS(4584),
    [anon_sym_UNTIL] = ACTIONS(4584),
    [anon_sym_Until] = ACTIONS(4584),
    [anon_sym_exit] = ACTIONS(4584),
    [anon_sym_EXIT] = ACTIONS(4584),
    [anon_sym_Exit] = ACTIONS(4584),
    [anon_sym_continue] = ACTIONS(4584),
    [anon_sym_CONTINUE] = ACTIONS(4584),
    [anon_sym_Continue] = ACTIONS(4584),
    [anon_sym_break] = ACTIONS(4584),
    [anon_sym_BREAK] = ACTIONS(4584),
    [anon_sym_Break] = ACTIONS(4584),
    [anon_sym_with] = ACTIONS(4584),
    [anon_sym_WITH] = ACTIONS(4584),
    [anon_sym_With] = ACTIONS(4584),
    [sym_asserterror_keyword] = ACTIONS(4586),
    [sym_page_keyword] = ACTIONS(4584),
    [anon_sym_codeunit] = ACTIONS(4584),
    [anon_sym_CODEUNIT] = ACTIONS(4584),
    [anon_sym_Codeunit] = ACTIONS(4584),
    [anon_sym_CodeUnit] = ACTIONS(4584),
    [anon_sym_COdeunit] = ACTIONS(4584),
    [anon_sym_codeUnit] = ACTIONS(4584),
    [sym_report_keyword] = ACTIONS(4584),
    [sym_query_keyword] = ACTIONS(4584),
    [anon_sym_xmlport] = ACTIONS(4584),
    [anon_sym_XMLPORT] = ACTIONS(4584),
    [anon_sym_Xmlport] = ACTIONS(4584),
    [anon_sym_XMLport] = ACTIONS(4584),
    [anon_sym_XMLPort] = ACTIONS(4584),
    [anon_sym_XmlPort] = ACTIONS(4584),
    [anon_sym_enum] = ACTIONS(4584),
    [anon_sym_ENUM] = ACTIONS(4584),
    [anon_sym_Enum] = ACTIONS(4584),
    [anon_sym_eNUM] = ACTIONS(4584),
    [anon_sym_eNum] = ACTIONS(4584),
    [anon_sym_ENum] = ACTIONS(4584),
    [sym_quoted_identifier] = ACTIONS(4586),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4586),
    [sym_integer] = ACTIONS(4584),
    [sym_continue_as_identifier] = ACTIONS(4586),
    [sym_preproc_open] = ACTIONS(4586),
  },
  [STATE(1901)] = {
    [sym_identifier] = ACTIONS(4588),
    [anon_sym_SEMI] = ACTIONS(4590),
    [anon_sym_DASH] = ACTIONS(4590),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(4588),
    [anon_sym_LPAREN] = ACTIONS(4590),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4588),
    [anon_sym_LBRACK] = ACTIONS(4590),
    [aux_sym_record_type_token1] = ACTIONS(4588),
    [aux_sym_basic_type_token21] = ACTIONS(4588),
    [aux_sym_basic_type_token22] = ACTIONS(4588),
    [aux_sym_basic_type_token48] = ACTIONS(4588),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4588),
    [anon_sym_POUNDif] = ACTIONS(4590),
    [anon_sym_POUNDIF] = ACTIONS(4590),
    [anon_sym_POUNDIf] = ACTIONS(4590),
    [anon_sym_not] = ACTIONS(4588),
    [anon_sym_NOT] = ACTIONS(4588),
    [anon_sym_Not] = ACTIONS(4588),
    [anon_sym_POUNDelse] = ACTIONS(4590),
    [anon_sym_POUNDELSE] = ACTIONS(4590),
    [anon_sym_POUNDElse] = ACTIONS(4590),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4588),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4588),
    [anon_sym_PLUS] = ACTIONS(4590),
    [sym_datetime_literal] = ACTIONS(4590),
    [sym_date_literal] = ACTIONS(4588),
    [sym_time_literal] = ACTIONS(4588),
    [sym_biginteger_literal] = ACTIONS(4590),
    [anon_sym_if] = ACTIONS(4588),
    [anon_sym_IF] = ACTIONS(4588),
    [anon_sym_If] = ACTIONS(4588),
    [anon_sym_else] = ACTIONS(4588),
    [anon_sym_ELSE] = ACTIONS(4588),
    [anon_sym_Else] = ACTIONS(4588),
    [anon_sym_case] = ACTIONS(4588),
    [anon_sym_CASE] = ACTIONS(4588),
    [anon_sym_Case] = ACTIONS(4588),
    [anon_sym_for] = ACTIONS(4588),
    [anon_sym_FOR] = ACTIONS(4588),
    [anon_sym_For] = ACTIONS(4588),
    [anon_sym_foreach] = ACTIONS(4588),
    [anon_sym_FOREACH] = ACTIONS(4588),
    [anon_sym_Foreach] = ACTIONS(4588),
    [anon_sym_while] = ACTIONS(4588),
    [anon_sym_WHILE] = ACTIONS(4588),
    [anon_sym_While] = ACTIONS(4588),
    [anon_sym_repeat] = ACTIONS(4588),
    [anon_sym_REPEAT] = ACTIONS(4588),
    [anon_sym_Repeat] = ACTIONS(4588),
    [anon_sym_until] = ACTIONS(4588),
    [anon_sym_UNTIL] = ACTIONS(4588),
    [anon_sym_Until] = ACTIONS(4588),
    [anon_sym_exit] = ACTIONS(4588),
    [anon_sym_EXIT] = ACTIONS(4588),
    [anon_sym_Exit] = ACTIONS(4588),
    [anon_sym_continue] = ACTIONS(4588),
    [anon_sym_CONTINUE] = ACTIONS(4588),
    [anon_sym_Continue] = ACTIONS(4588),
    [anon_sym_break] = ACTIONS(4588),
    [anon_sym_BREAK] = ACTIONS(4588),
    [anon_sym_Break] = ACTIONS(4588),
    [anon_sym_with] = ACTIONS(4588),
    [anon_sym_WITH] = ACTIONS(4588),
    [anon_sym_With] = ACTIONS(4588),
    [sym_asserterror_keyword] = ACTIONS(4590),
    [sym_page_keyword] = ACTIONS(4588),
    [anon_sym_codeunit] = ACTIONS(4588),
    [anon_sym_CODEUNIT] = ACTIONS(4588),
    [anon_sym_Codeunit] = ACTIONS(4588),
    [anon_sym_CodeUnit] = ACTIONS(4588),
    [anon_sym_COdeunit] = ACTIONS(4588),
    [anon_sym_codeUnit] = ACTIONS(4588),
    [sym_report_keyword] = ACTIONS(4588),
    [sym_query_keyword] = ACTIONS(4588),
    [anon_sym_xmlport] = ACTIONS(4588),
    [anon_sym_XMLPORT] = ACTIONS(4588),
    [anon_sym_Xmlport] = ACTIONS(4588),
    [anon_sym_XMLport] = ACTIONS(4588),
    [anon_sym_XMLPort] = ACTIONS(4588),
    [anon_sym_XmlPort] = ACTIONS(4588),
    [anon_sym_enum] = ACTIONS(4588),
    [anon_sym_ENUM] = ACTIONS(4588),
    [anon_sym_Enum] = ACTIONS(4588),
    [anon_sym_eNUM] = ACTIONS(4588),
    [anon_sym_eNum] = ACTIONS(4588),
    [anon_sym_ENum] = ACTIONS(4588),
    [sym_quoted_identifier] = ACTIONS(4590),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4590),
    [sym_integer] = ACTIONS(4588),
    [sym_continue_as_identifier] = ACTIONS(4590),
    [sym_preproc_open] = ACTIONS(4590),
  },
  [STATE(1902)] = {
    [sym_identifier] = ACTIONS(4592),
    [anon_sym_SEMI] = ACTIONS(4889),
    [anon_sym_DASH] = ACTIONS(4596),
    [aux_sym_boolean_token1] = ACTIONS(4592),
    [aux_sym_boolean_token2] = ACTIONS(4592),
    [sym_decimal] = ACTIONS(4592),
    [anon_sym_LPAREN] = ACTIONS(4596),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(4596),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4592),
    [anon_sym_POUNDif] = ACTIONS(4596),
    [anon_sym_POUNDIF] = ACTIONS(4596),
    [anon_sym_POUNDIf] = ACTIONS(4596),
    [anon_sym_not] = ACTIONS(4592),
    [anon_sym_NOT] = ACTIONS(4592),
    [anon_sym_Not] = ACTIONS(4592),
    [anon_sym_POUNDelse] = ACTIONS(4596),
    [anon_sym_POUNDELSE] = ACTIONS(4596),
    [anon_sym_POUNDElse] = ACTIONS(4596),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4592),
    [anon_sym_PLUS] = ACTIONS(4596),
    [sym_datetime_literal] = ACTIONS(4596),
    [sym_date_literal] = ACTIONS(4592),
    [sym_time_literal] = ACTIONS(4592),
    [sym_biginteger_literal] = ACTIONS(4596),
    [anon_sym_if] = ACTIONS(4592),
    [anon_sym_IF] = ACTIONS(4592),
    [anon_sym_If] = ACTIONS(4592),
    [anon_sym_else] = ACTIONS(4592),
    [anon_sym_ELSE] = ACTIONS(4592),
    [anon_sym_Else] = ACTIONS(4592),
    [anon_sym_case] = ACTIONS(4592),
    [anon_sym_CASE] = ACTIONS(4592),
    [anon_sym_Case] = ACTIONS(4592),
    [anon_sym_for] = ACTIONS(4592),
    [anon_sym_FOR] = ACTIONS(4592),
    [anon_sym_For] = ACTIONS(4592),
    [anon_sym_foreach] = ACTIONS(4592),
    [anon_sym_FOREACH] = ACTIONS(4592),
    [anon_sym_Foreach] = ACTIONS(4592),
    [anon_sym_while] = ACTIONS(4592),
    [anon_sym_WHILE] = ACTIONS(4592),
    [anon_sym_While] = ACTIONS(4592),
    [anon_sym_repeat] = ACTIONS(4592),
    [anon_sym_REPEAT] = ACTIONS(4592),
    [anon_sym_Repeat] = ACTIONS(4592),
    [anon_sym_until] = ACTIONS(4592),
    [anon_sym_UNTIL] = ACTIONS(4592),
    [anon_sym_Until] = ACTIONS(4592),
    [anon_sym_exit] = ACTIONS(4592),
    [anon_sym_EXIT] = ACTIONS(4592),
    [anon_sym_Exit] = ACTIONS(4592),
    [anon_sym_continue] = ACTIONS(4592),
    [anon_sym_CONTINUE] = ACTIONS(4592),
    [anon_sym_Continue] = ACTIONS(4592),
    [anon_sym_break] = ACTIONS(4592),
    [anon_sym_BREAK] = ACTIONS(4592),
    [anon_sym_Break] = ACTIONS(4592),
    [anon_sym_with] = ACTIONS(4592),
    [anon_sym_WITH] = ACTIONS(4592),
    [anon_sym_With] = ACTIONS(4592),
    [sym_asserterror_keyword] = ACTIONS(4596),
    [sym_page_keyword] = ACTIONS(4592),
    [anon_sym_codeunit] = ACTIONS(4592),
    [anon_sym_CODEUNIT] = ACTIONS(4592),
    [anon_sym_Codeunit] = ACTIONS(4592),
    [anon_sym_CodeUnit] = ACTIONS(4592),
    [anon_sym_COdeunit] = ACTIONS(4592),
    [anon_sym_codeUnit] = ACTIONS(4592),
    [sym_report_keyword] = ACTIONS(4592),
    [sym_query_keyword] = ACTIONS(4592),
    [anon_sym_xmlport] = ACTIONS(4592),
    [anon_sym_XMLPORT] = ACTIONS(4592),
    [anon_sym_Xmlport] = ACTIONS(4592),
    [anon_sym_XMLport] = ACTIONS(4592),
    [anon_sym_XMLPort] = ACTIONS(4592),
    [anon_sym_XmlPort] = ACTIONS(4592),
    [anon_sym_enum] = ACTIONS(4592),
    [anon_sym_ENUM] = ACTIONS(4592),
    [anon_sym_Enum] = ACTIONS(4592),
    [anon_sym_eNUM] = ACTIONS(4592),
    [anon_sym_eNum] = ACTIONS(4592),
    [anon_sym_ENum] = ACTIONS(4592),
    [sym_quoted_identifier] = ACTIONS(4596),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4596),
    [sym_integer] = ACTIONS(4592),
    [sym_continue_as_identifier] = ACTIONS(4596),
    [sym_preproc_open] = ACTIONS(4596),
  },
  [STATE(1903)] = {
    [sym_identifier] = ACTIONS(4511),
    [anon_sym_SEMI] = ACTIONS(4513),
    [anon_sym_DASH] = ACTIONS(4513),
    [aux_sym_boolean_token1] = ACTIONS(4511),
    [aux_sym_boolean_token2] = ACTIONS(4511),
    [sym_decimal] = ACTIONS(4511),
    [anon_sym_LPAREN] = ACTIONS(4513),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4511),
    [anon_sym_LBRACK] = ACTIONS(4513),
    [aux_sym_record_type_token1] = ACTIONS(4511),
    [aux_sym_basic_type_token21] = ACTIONS(4511),
    [aux_sym_basic_type_token22] = ACTIONS(4511),
    [aux_sym_basic_type_token48] = ACTIONS(4511),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4511),
    [anon_sym_POUNDif] = ACTIONS(4513),
    [anon_sym_POUNDIF] = ACTIONS(4513),
    [anon_sym_POUNDIf] = ACTIONS(4513),
    [anon_sym_not] = ACTIONS(4511),
    [anon_sym_NOT] = ACTIONS(4511),
    [anon_sym_Not] = ACTIONS(4511),
    [anon_sym_POUNDelse] = ACTIONS(4513),
    [anon_sym_POUNDELSE] = ACTIONS(4513),
    [anon_sym_POUNDElse] = ACTIONS(4513),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4511),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4511),
    [anon_sym_PLUS] = ACTIONS(4513),
    [sym_datetime_literal] = ACTIONS(4513),
    [sym_date_literal] = ACTIONS(4511),
    [sym_time_literal] = ACTIONS(4511),
    [sym_biginteger_literal] = ACTIONS(4513),
    [anon_sym_if] = ACTIONS(4511),
    [anon_sym_IF] = ACTIONS(4511),
    [anon_sym_If] = ACTIONS(4511),
    [anon_sym_else] = ACTIONS(4511),
    [anon_sym_ELSE] = ACTIONS(4511),
    [anon_sym_Else] = ACTIONS(4511),
    [anon_sym_case] = ACTIONS(4511),
    [anon_sym_CASE] = ACTIONS(4511),
    [anon_sym_Case] = ACTIONS(4511),
    [anon_sym_for] = ACTIONS(4511),
    [anon_sym_FOR] = ACTIONS(4511),
    [anon_sym_For] = ACTIONS(4511),
    [anon_sym_foreach] = ACTIONS(4511),
    [anon_sym_FOREACH] = ACTIONS(4511),
    [anon_sym_Foreach] = ACTIONS(4511),
    [anon_sym_while] = ACTIONS(4511),
    [anon_sym_WHILE] = ACTIONS(4511),
    [anon_sym_While] = ACTIONS(4511),
    [anon_sym_repeat] = ACTIONS(4511),
    [anon_sym_REPEAT] = ACTIONS(4511),
    [anon_sym_Repeat] = ACTIONS(4511),
    [anon_sym_until] = ACTIONS(4511),
    [anon_sym_UNTIL] = ACTIONS(4511),
    [anon_sym_Until] = ACTIONS(4511),
    [anon_sym_exit] = ACTIONS(4511),
    [anon_sym_EXIT] = ACTIONS(4511),
    [anon_sym_Exit] = ACTIONS(4511),
    [anon_sym_continue] = ACTIONS(4511),
    [anon_sym_CONTINUE] = ACTIONS(4511),
    [anon_sym_Continue] = ACTIONS(4511),
    [anon_sym_break] = ACTIONS(4511),
    [anon_sym_BREAK] = ACTIONS(4511),
    [anon_sym_Break] = ACTIONS(4511),
    [anon_sym_with] = ACTIONS(4511),
    [anon_sym_WITH] = ACTIONS(4511),
    [anon_sym_With] = ACTIONS(4511),
    [sym_asserterror_keyword] = ACTIONS(4513),
    [sym_page_keyword] = ACTIONS(4511),
    [anon_sym_codeunit] = ACTIONS(4511),
    [anon_sym_CODEUNIT] = ACTIONS(4511),
    [anon_sym_Codeunit] = ACTIONS(4511),
    [anon_sym_CodeUnit] = ACTIONS(4511),
    [anon_sym_COdeunit] = ACTIONS(4511),
    [anon_sym_codeUnit] = ACTIONS(4511),
    [sym_report_keyword] = ACTIONS(4511),
    [sym_query_keyword] = ACTIONS(4511),
    [anon_sym_xmlport] = ACTIONS(4511),
    [anon_sym_XMLPORT] = ACTIONS(4511),
    [anon_sym_Xmlport] = ACTIONS(4511),
    [anon_sym_XMLport] = ACTIONS(4511),
    [anon_sym_XMLPort] = ACTIONS(4511),
    [anon_sym_XmlPort] = ACTIONS(4511),
    [anon_sym_enum] = ACTIONS(4511),
    [anon_sym_ENUM] = ACTIONS(4511),
    [anon_sym_Enum] = ACTIONS(4511),
    [anon_sym_eNUM] = ACTIONS(4511),
    [anon_sym_eNum] = ACTIONS(4511),
    [anon_sym_ENum] = ACTIONS(4511),
    [sym_quoted_identifier] = ACTIONS(4513),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4513),
    [sym_integer] = ACTIONS(4511),
    [sym_continue_as_identifier] = ACTIONS(4513),
    [sym_preproc_open] = ACTIONS(4513),
  },
  [STATE(1904)] = {
    [sym_identifier] = ACTIONS(4515),
    [anon_sym_SEMI] = ACTIONS(4517),
    [anon_sym_DASH] = ACTIONS(4517),
    [aux_sym_boolean_token1] = ACTIONS(4515),
    [aux_sym_boolean_token2] = ACTIONS(4515),
    [sym_decimal] = ACTIONS(4515),
    [anon_sym_LPAREN] = ACTIONS(4517),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4515),
    [anon_sym_LBRACK] = ACTIONS(4517),
    [aux_sym_record_type_token1] = ACTIONS(4515),
    [aux_sym_basic_type_token21] = ACTIONS(4515),
    [aux_sym_basic_type_token22] = ACTIONS(4515),
    [aux_sym_basic_type_token48] = ACTIONS(4515),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4515),
    [anon_sym_POUNDif] = ACTIONS(4517),
    [anon_sym_POUNDIF] = ACTIONS(4517),
    [anon_sym_POUNDIf] = ACTIONS(4517),
    [anon_sym_not] = ACTIONS(4515),
    [anon_sym_NOT] = ACTIONS(4515),
    [anon_sym_Not] = ACTIONS(4515),
    [anon_sym_POUNDelse] = ACTIONS(4517),
    [anon_sym_POUNDELSE] = ACTIONS(4517),
    [anon_sym_POUNDElse] = ACTIONS(4517),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4515),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4515),
    [anon_sym_PLUS] = ACTIONS(4517),
    [sym_datetime_literal] = ACTIONS(4517),
    [sym_date_literal] = ACTIONS(4515),
    [sym_time_literal] = ACTIONS(4515),
    [sym_biginteger_literal] = ACTIONS(4517),
    [anon_sym_if] = ACTIONS(4515),
    [anon_sym_IF] = ACTIONS(4515),
    [anon_sym_If] = ACTIONS(4515),
    [anon_sym_else] = ACTIONS(4515),
    [anon_sym_ELSE] = ACTIONS(4515),
    [anon_sym_Else] = ACTIONS(4515),
    [anon_sym_case] = ACTIONS(4515),
    [anon_sym_CASE] = ACTIONS(4515),
    [anon_sym_Case] = ACTIONS(4515),
    [anon_sym_for] = ACTIONS(4515),
    [anon_sym_FOR] = ACTIONS(4515),
    [anon_sym_For] = ACTIONS(4515),
    [anon_sym_foreach] = ACTIONS(4515),
    [anon_sym_FOREACH] = ACTIONS(4515),
    [anon_sym_Foreach] = ACTIONS(4515),
    [anon_sym_while] = ACTIONS(4515),
    [anon_sym_WHILE] = ACTIONS(4515),
    [anon_sym_While] = ACTIONS(4515),
    [anon_sym_repeat] = ACTIONS(4515),
    [anon_sym_REPEAT] = ACTIONS(4515),
    [anon_sym_Repeat] = ACTIONS(4515),
    [anon_sym_until] = ACTIONS(4515),
    [anon_sym_UNTIL] = ACTIONS(4515),
    [anon_sym_Until] = ACTIONS(4515),
    [anon_sym_exit] = ACTIONS(4515),
    [anon_sym_EXIT] = ACTIONS(4515),
    [anon_sym_Exit] = ACTIONS(4515),
    [anon_sym_continue] = ACTIONS(4515),
    [anon_sym_CONTINUE] = ACTIONS(4515),
    [anon_sym_Continue] = ACTIONS(4515),
    [anon_sym_break] = ACTIONS(4515),
    [anon_sym_BREAK] = ACTIONS(4515),
    [anon_sym_Break] = ACTIONS(4515),
    [anon_sym_with] = ACTIONS(4515),
    [anon_sym_WITH] = ACTIONS(4515),
    [anon_sym_With] = ACTIONS(4515),
    [sym_asserterror_keyword] = ACTIONS(4517),
    [sym_page_keyword] = ACTIONS(4515),
    [anon_sym_codeunit] = ACTIONS(4515),
    [anon_sym_CODEUNIT] = ACTIONS(4515),
    [anon_sym_Codeunit] = ACTIONS(4515),
    [anon_sym_CodeUnit] = ACTIONS(4515),
    [anon_sym_COdeunit] = ACTIONS(4515),
    [anon_sym_codeUnit] = ACTIONS(4515),
    [sym_report_keyword] = ACTIONS(4515),
    [sym_query_keyword] = ACTIONS(4515),
    [anon_sym_xmlport] = ACTIONS(4515),
    [anon_sym_XMLPORT] = ACTIONS(4515),
    [anon_sym_Xmlport] = ACTIONS(4515),
    [anon_sym_XMLport] = ACTIONS(4515),
    [anon_sym_XMLPort] = ACTIONS(4515),
    [anon_sym_XmlPort] = ACTIONS(4515),
    [anon_sym_enum] = ACTIONS(4515),
    [anon_sym_ENUM] = ACTIONS(4515),
    [anon_sym_Enum] = ACTIONS(4515),
    [anon_sym_eNUM] = ACTIONS(4515),
    [anon_sym_eNum] = ACTIONS(4515),
    [anon_sym_ENum] = ACTIONS(4515),
    [sym_quoted_identifier] = ACTIONS(4517),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4517),
    [sym_integer] = ACTIONS(4515),
    [sym_continue_as_identifier] = ACTIONS(4517),
    [sym_preproc_open] = ACTIONS(4517),
  },
  [STATE(1905)] = {
    [sym_identifier] = ACTIONS(4519),
    [anon_sym_SEMI] = ACTIONS(4521),
    [anon_sym_DASH] = ACTIONS(4521),
    [aux_sym_boolean_token1] = ACTIONS(4519),
    [aux_sym_boolean_token2] = ACTIONS(4519),
    [sym_decimal] = ACTIONS(4519),
    [anon_sym_LPAREN] = ACTIONS(4521),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4521),
    [aux_sym_record_type_token1] = ACTIONS(4519),
    [aux_sym_basic_type_token21] = ACTIONS(4519),
    [aux_sym_basic_type_token22] = ACTIONS(4519),
    [aux_sym_basic_type_token48] = ACTIONS(4519),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4519),
    [anon_sym_POUNDif] = ACTIONS(4521),
    [anon_sym_POUNDIF] = ACTIONS(4521),
    [anon_sym_POUNDIf] = ACTIONS(4521),
    [anon_sym_not] = ACTIONS(4519),
    [anon_sym_NOT] = ACTIONS(4519),
    [anon_sym_Not] = ACTIONS(4519),
    [anon_sym_POUNDelse] = ACTIONS(4521),
    [anon_sym_POUNDELSE] = ACTIONS(4521),
    [anon_sym_POUNDElse] = ACTIONS(4521),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4519),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4519),
    [anon_sym_PLUS] = ACTIONS(4521),
    [sym_datetime_literal] = ACTIONS(4521),
    [sym_date_literal] = ACTIONS(4519),
    [sym_time_literal] = ACTIONS(4519),
    [sym_biginteger_literal] = ACTIONS(4521),
    [anon_sym_if] = ACTIONS(4519),
    [anon_sym_IF] = ACTIONS(4519),
    [anon_sym_If] = ACTIONS(4519),
    [anon_sym_else] = ACTIONS(4519),
    [anon_sym_ELSE] = ACTIONS(4519),
    [anon_sym_Else] = ACTIONS(4519),
    [anon_sym_case] = ACTIONS(4519),
    [anon_sym_CASE] = ACTIONS(4519),
    [anon_sym_Case] = ACTIONS(4519),
    [anon_sym_for] = ACTIONS(4519),
    [anon_sym_FOR] = ACTIONS(4519),
    [anon_sym_For] = ACTIONS(4519),
    [anon_sym_foreach] = ACTIONS(4519),
    [anon_sym_FOREACH] = ACTIONS(4519),
    [anon_sym_Foreach] = ACTIONS(4519),
    [anon_sym_while] = ACTIONS(4519),
    [anon_sym_WHILE] = ACTIONS(4519),
    [anon_sym_While] = ACTIONS(4519),
    [anon_sym_repeat] = ACTIONS(4519),
    [anon_sym_REPEAT] = ACTIONS(4519),
    [anon_sym_Repeat] = ACTIONS(4519),
    [anon_sym_until] = ACTIONS(4519),
    [anon_sym_UNTIL] = ACTIONS(4519),
    [anon_sym_Until] = ACTIONS(4519),
    [anon_sym_exit] = ACTIONS(4519),
    [anon_sym_EXIT] = ACTIONS(4519),
    [anon_sym_Exit] = ACTIONS(4519),
    [anon_sym_continue] = ACTIONS(4519),
    [anon_sym_CONTINUE] = ACTIONS(4519),
    [anon_sym_Continue] = ACTIONS(4519),
    [anon_sym_break] = ACTIONS(4519),
    [anon_sym_BREAK] = ACTIONS(4519),
    [anon_sym_Break] = ACTIONS(4519),
    [anon_sym_with] = ACTIONS(4519),
    [anon_sym_WITH] = ACTIONS(4519),
    [anon_sym_With] = ACTIONS(4519),
    [sym_asserterror_keyword] = ACTIONS(4521),
    [sym_page_keyword] = ACTIONS(4519),
    [anon_sym_codeunit] = ACTIONS(4519),
    [anon_sym_CODEUNIT] = ACTIONS(4519),
    [anon_sym_Codeunit] = ACTIONS(4519),
    [anon_sym_CodeUnit] = ACTIONS(4519),
    [anon_sym_COdeunit] = ACTIONS(4519),
    [anon_sym_codeUnit] = ACTIONS(4519),
    [sym_report_keyword] = ACTIONS(4519),
    [sym_query_keyword] = ACTIONS(4519),
    [anon_sym_xmlport] = ACTIONS(4519),
    [anon_sym_XMLPORT] = ACTIONS(4519),
    [anon_sym_Xmlport] = ACTIONS(4519),
    [anon_sym_XMLport] = ACTIONS(4519),
    [anon_sym_XMLPort] = ACTIONS(4519),
    [anon_sym_XmlPort] = ACTIONS(4519),
    [anon_sym_enum] = ACTIONS(4519),
    [anon_sym_ENUM] = ACTIONS(4519),
    [anon_sym_Enum] = ACTIONS(4519),
    [anon_sym_eNUM] = ACTIONS(4519),
    [anon_sym_eNum] = ACTIONS(4519),
    [anon_sym_ENum] = ACTIONS(4519),
    [sym_quoted_identifier] = ACTIONS(4521),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4521),
    [sym_integer] = ACTIONS(4519),
    [sym_continue_as_identifier] = ACTIONS(4521),
    [sym_preproc_open] = ACTIONS(4521),
  },
  [STATE(1906)] = {
    [sym_identifier] = ACTIONS(4523),
    [anon_sym_SEMI] = ACTIONS(4525),
    [anon_sym_DASH] = ACTIONS(4525),
    [aux_sym_boolean_token1] = ACTIONS(4523),
    [aux_sym_boolean_token2] = ACTIONS(4523),
    [sym_decimal] = ACTIONS(4523),
    [anon_sym_LPAREN] = ACTIONS(4525),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4523),
    [anon_sym_LBRACK] = ACTIONS(4525),
    [aux_sym_record_type_token1] = ACTIONS(4523),
    [aux_sym_basic_type_token21] = ACTIONS(4523),
    [aux_sym_basic_type_token22] = ACTIONS(4523),
    [aux_sym_basic_type_token48] = ACTIONS(4523),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4523),
    [anon_sym_POUNDif] = ACTIONS(4525),
    [anon_sym_POUNDIF] = ACTIONS(4525),
    [anon_sym_POUNDIf] = ACTIONS(4525),
    [anon_sym_not] = ACTIONS(4523),
    [anon_sym_NOT] = ACTIONS(4523),
    [anon_sym_Not] = ACTIONS(4523),
    [anon_sym_POUNDelse] = ACTIONS(4525),
    [anon_sym_POUNDELSE] = ACTIONS(4525),
    [anon_sym_POUNDElse] = ACTIONS(4525),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4523),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4523),
    [anon_sym_PLUS] = ACTIONS(4525),
    [sym_datetime_literal] = ACTIONS(4525),
    [sym_date_literal] = ACTIONS(4523),
    [sym_time_literal] = ACTIONS(4523),
    [sym_biginteger_literal] = ACTIONS(4525),
    [anon_sym_if] = ACTIONS(4523),
    [anon_sym_IF] = ACTIONS(4523),
    [anon_sym_If] = ACTIONS(4523),
    [anon_sym_else] = ACTIONS(4523),
    [anon_sym_ELSE] = ACTIONS(4523),
    [anon_sym_Else] = ACTIONS(4523),
    [anon_sym_case] = ACTIONS(4523),
    [anon_sym_CASE] = ACTIONS(4523),
    [anon_sym_Case] = ACTIONS(4523),
    [anon_sym_for] = ACTIONS(4523),
    [anon_sym_FOR] = ACTIONS(4523),
    [anon_sym_For] = ACTIONS(4523),
    [anon_sym_foreach] = ACTIONS(4523),
    [anon_sym_FOREACH] = ACTIONS(4523),
    [anon_sym_Foreach] = ACTIONS(4523),
    [anon_sym_while] = ACTIONS(4523),
    [anon_sym_WHILE] = ACTIONS(4523),
    [anon_sym_While] = ACTIONS(4523),
    [anon_sym_repeat] = ACTIONS(4523),
    [anon_sym_REPEAT] = ACTIONS(4523),
    [anon_sym_Repeat] = ACTIONS(4523),
    [anon_sym_until] = ACTIONS(4523),
    [anon_sym_UNTIL] = ACTIONS(4523),
    [anon_sym_Until] = ACTIONS(4523),
    [anon_sym_exit] = ACTIONS(4523),
    [anon_sym_EXIT] = ACTIONS(4523),
    [anon_sym_Exit] = ACTIONS(4523),
    [anon_sym_continue] = ACTIONS(4523),
    [anon_sym_CONTINUE] = ACTIONS(4523),
    [anon_sym_Continue] = ACTIONS(4523),
    [anon_sym_break] = ACTIONS(4523),
    [anon_sym_BREAK] = ACTIONS(4523),
    [anon_sym_Break] = ACTIONS(4523),
    [anon_sym_with] = ACTIONS(4523),
    [anon_sym_WITH] = ACTIONS(4523),
    [anon_sym_With] = ACTIONS(4523),
    [sym_asserterror_keyword] = ACTIONS(4525),
    [sym_page_keyword] = ACTIONS(4523),
    [anon_sym_codeunit] = ACTIONS(4523),
    [anon_sym_CODEUNIT] = ACTIONS(4523),
    [anon_sym_Codeunit] = ACTIONS(4523),
    [anon_sym_CodeUnit] = ACTIONS(4523),
    [anon_sym_COdeunit] = ACTIONS(4523),
    [anon_sym_codeUnit] = ACTIONS(4523),
    [sym_report_keyword] = ACTIONS(4523),
    [sym_query_keyword] = ACTIONS(4523),
    [anon_sym_xmlport] = ACTIONS(4523),
    [anon_sym_XMLPORT] = ACTIONS(4523),
    [anon_sym_Xmlport] = ACTIONS(4523),
    [anon_sym_XMLport] = ACTIONS(4523),
    [anon_sym_XMLPort] = ACTIONS(4523),
    [anon_sym_XmlPort] = ACTIONS(4523),
    [anon_sym_enum] = ACTIONS(4523),
    [anon_sym_ENUM] = ACTIONS(4523),
    [anon_sym_Enum] = ACTIONS(4523),
    [anon_sym_eNUM] = ACTIONS(4523),
    [anon_sym_eNum] = ACTIONS(4523),
    [anon_sym_ENum] = ACTIONS(4523),
    [sym_quoted_identifier] = ACTIONS(4525),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4525),
    [sym_integer] = ACTIONS(4523),
    [sym_continue_as_identifier] = ACTIONS(4525),
    [sym_preproc_open] = ACTIONS(4525),
  },
  [STATE(1907)] = {
    [sym_identifier] = ACTIONS(4598),
    [anon_sym_SEMI] = ACTIONS(4600),
    [anon_sym_DASH] = ACTIONS(4600),
    [aux_sym_boolean_token1] = ACTIONS(4598),
    [aux_sym_boolean_token2] = ACTIONS(4598),
    [sym_decimal] = ACTIONS(4598),
    [anon_sym_LPAREN] = ACTIONS(4600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4598),
    [anon_sym_LBRACK] = ACTIONS(4600),
    [aux_sym_record_type_token1] = ACTIONS(4598),
    [aux_sym_basic_type_token21] = ACTIONS(4598),
    [aux_sym_basic_type_token22] = ACTIONS(4598),
    [aux_sym_basic_type_token48] = ACTIONS(4598),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4598),
    [anon_sym_POUNDif] = ACTIONS(4600),
    [anon_sym_POUNDIF] = ACTIONS(4600),
    [anon_sym_POUNDIf] = ACTIONS(4600),
    [anon_sym_not] = ACTIONS(4598),
    [anon_sym_NOT] = ACTIONS(4598),
    [anon_sym_Not] = ACTIONS(4598),
    [anon_sym_POUNDelse] = ACTIONS(4600),
    [anon_sym_POUNDELSE] = ACTIONS(4600),
    [anon_sym_POUNDElse] = ACTIONS(4600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4598),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4598),
    [anon_sym_PLUS] = ACTIONS(4600),
    [sym_datetime_literal] = ACTIONS(4600),
    [sym_date_literal] = ACTIONS(4598),
    [sym_time_literal] = ACTIONS(4598),
    [sym_biginteger_literal] = ACTIONS(4600),
    [anon_sym_if] = ACTIONS(4598),
    [anon_sym_IF] = ACTIONS(4598),
    [anon_sym_If] = ACTIONS(4598),
    [anon_sym_else] = ACTIONS(4598),
    [anon_sym_ELSE] = ACTIONS(4598),
    [anon_sym_Else] = ACTIONS(4598),
    [anon_sym_case] = ACTIONS(4598),
    [anon_sym_CASE] = ACTIONS(4598),
    [anon_sym_Case] = ACTIONS(4598),
    [anon_sym_for] = ACTIONS(4598),
    [anon_sym_FOR] = ACTIONS(4598),
    [anon_sym_For] = ACTIONS(4598),
    [anon_sym_foreach] = ACTIONS(4598),
    [anon_sym_FOREACH] = ACTIONS(4598),
    [anon_sym_Foreach] = ACTIONS(4598),
    [anon_sym_while] = ACTIONS(4598),
    [anon_sym_WHILE] = ACTIONS(4598),
    [anon_sym_While] = ACTIONS(4598),
    [anon_sym_repeat] = ACTIONS(4598),
    [anon_sym_REPEAT] = ACTIONS(4598),
    [anon_sym_Repeat] = ACTIONS(4598),
    [anon_sym_until] = ACTIONS(4598),
    [anon_sym_UNTIL] = ACTIONS(4598),
    [anon_sym_Until] = ACTIONS(4598),
    [anon_sym_exit] = ACTIONS(4598),
    [anon_sym_EXIT] = ACTIONS(4598),
    [anon_sym_Exit] = ACTIONS(4598),
    [anon_sym_continue] = ACTIONS(4598),
    [anon_sym_CONTINUE] = ACTIONS(4598),
    [anon_sym_Continue] = ACTIONS(4598),
    [anon_sym_break] = ACTIONS(4598),
    [anon_sym_BREAK] = ACTIONS(4598),
    [anon_sym_Break] = ACTIONS(4598),
    [anon_sym_with] = ACTIONS(4598),
    [anon_sym_WITH] = ACTIONS(4598),
    [anon_sym_With] = ACTIONS(4598),
    [sym_asserterror_keyword] = ACTIONS(4600),
    [sym_page_keyword] = ACTIONS(4598),
    [anon_sym_codeunit] = ACTIONS(4598),
    [anon_sym_CODEUNIT] = ACTIONS(4598),
    [anon_sym_Codeunit] = ACTIONS(4598),
    [anon_sym_CodeUnit] = ACTIONS(4598),
    [anon_sym_COdeunit] = ACTIONS(4598),
    [anon_sym_codeUnit] = ACTIONS(4598),
    [sym_report_keyword] = ACTIONS(4598),
    [sym_query_keyword] = ACTIONS(4598),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4598),
    [anon_sym_ENUM] = ACTIONS(4598),
    [anon_sym_Enum] = ACTIONS(4598),
    [anon_sym_eNUM] = ACTIONS(4598),
    [anon_sym_eNum] = ACTIONS(4598),
    [anon_sym_ENum] = ACTIONS(4598),
    [sym_quoted_identifier] = ACTIONS(4600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4600),
    [sym_integer] = ACTIONS(4598),
    [sym_continue_as_identifier] = ACTIONS(4600),
    [sym_preproc_open] = ACTIONS(4600),
  },
  [STATE(1908)] = {
    [sym_identifier] = ACTIONS(4527),
    [anon_sym_SEMI] = ACTIONS(4529),
    [anon_sym_DASH] = ACTIONS(4529),
    [aux_sym_boolean_token1] = ACTIONS(4527),
    [aux_sym_boolean_token2] = ACTIONS(4527),
    [sym_decimal] = ACTIONS(4527),
    [anon_sym_LPAREN] = ACTIONS(4529),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4527),
    [anon_sym_LBRACK] = ACTIONS(4529),
    [aux_sym_record_type_token1] = ACTIONS(4527),
    [aux_sym_basic_type_token21] = ACTIONS(4527),
    [aux_sym_basic_type_token22] = ACTIONS(4527),
    [aux_sym_basic_type_token48] = ACTIONS(4527),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4527),
    [anon_sym_POUNDif] = ACTIONS(4529),
    [anon_sym_POUNDIF] = ACTIONS(4529),
    [anon_sym_POUNDIf] = ACTIONS(4529),
    [anon_sym_not] = ACTIONS(4527),
    [anon_sym_NOT] = ACTIONS(4527),
    [anon_sym_Not] = ACTIONS(4527),
    [anon_sym_POUNDelse] = ACTIONS(4529),
    [anon_sym_POUNDELSE] = ACTIONS(4529),
    [anon_sym_POUNDElse] = ACTIONS(4529),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4527),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4527),
    [anon_sym_PLUS] = ACTIONS(4529),
    [sym_datetime_literal] = ACTIONS(4529),
    [sym_date_literal] = ACTIONS(4527),
    [sym_time_literal] = ACTIONS(4527),
    [sym_biginteger_literal] = ACTIONS(4529),
    [anon_sym_if] = ACTIONS(4527),
    [anon_sym_IF] = ACTIONS(4527),
    [anon_sym_If] = ACTIONS(4527),
    [anon_sym_else] = ACTIONS(4527),
    [anon_sym_ELSE] = ACTIONS(4527),
    [anon_sym_Else] = ACTIONS(4527),
    [anon_sym_case] = ACTIONS(4527),
    [anon_sym_CASE] = ACTIONS(4527),
    [anon_sym_Case] = ACTIONS(4527),
    [anon_sym_for] = ACTIONS(4527),
    [anon_sym_FOR] = ACTIONS(4527),
    [anon_sym_For] = ACTIONS(4527),
    [anon_sym_foreach] = ACTIONS(4527),
    [anon_sym_FOREACH] = ACTIONS(4527),
    [anon_sym_Foreach] = ACTIONS(4527),
    [anon_sym_while] = ACTIONS(4527),
    [anon_sym_WHILE] = ACTIONS(4527),
    [anon_sym_While] = ACTIONS(4527),
    [anon_sym_repeat] = ACTIONS(4527),
    [anon_sym_REPEAT] = ACTIONS(4527),
    [anon_sym_Repeat] = ACTIONS(4527),
    [anon_sym_until] = ACTIONS(4527),
    [anon_sym_UNTIL] = ACTIONS(4527),
    [anon_sym_Until] = ACTIONS(4527),
    [anon_sym_exit] = ACTIONS(4527),
    [anon_sym_EXIT] = ACTIONS(4527),
    [anon_sym_Exit] = ACTIONS(4527),
    [anon_sym_continue] = ACTIONS(4527),
    [anon_sym_CONTINUE] = ACTIONS(4527),
    [anon_sym_Continue] = ACTIONS(4527),
    [anon_sym_break] = ACTIONS(4527),
    [anon_sym_BREAK] = ACTIONS(4527),
    [anon_sym_Break] = ACTIONS(4527),
    [anon_sym_with] = ACTIONS(4527),
    [anon_sym_WITH] = ACTIONS(4527),
    [anon_sym_With] = ACTIONS(4527),
    [sym_asserterror_keyword] = ACTIONS(4529),
    [sym_page_keyword] = ACTIONS(4527),
    [anon_sym_codeunit] = ACTIONS(4527),
    [anon_sym_CODEUNIT] = ACTIONS(4527),
    [anon_sym_Codeunit] = ACTIONS(4527),
    [anon_sym_CodeUnit] = ACTIONS(4527),
    [anon_sym_COdeunit] = ACTIONS(4527),
    [anon_sym_codeUnit] = ACTIONS(4527),
    [sym_report_keyword] = ACTIONS(4527),
    [sym_query_keyword] = ACTIONS(4527),
    [anon_sym_xmlport] = ACTIONS(4527),
    [anon_sym_XMLPORT] = ACTIONS(4527),
    [anon_sym_Xmlport] = ACTIONS(4527),
    [anon_sym_XMLport] = ACTIONS(4527),
    [anon_sym_XMLPort] = ACTIONS(4527),
    [anon_sym_XmlPort] = ACTIONS(4527),
    [anon_sym_enum] = ACTIONS(4527),
    [anon_sym_ENUM] = ACTIONS(4527),
    [anon_sym_Enum] = ACTIONS(4527),
    [anon_sym_eNUM] = ACTIONS(4527),
    [anon_sym_eNum] = ACTIONS(4527),
    [anon_sym_ENum] = ACTIONS(4527),
    [sym_quoted_identifier] = ACTIONS(4529),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4529),
    [sym_integer] = ACTIONS(4527),
    [sym_continue_as_identifier] = ACTIONS(4529),
    [sym_preproc_open] = ACTIONS(4529),
  },
  [STATE(1909)] = {
    [sym_identifier] = ACTIONS(4602),
    [anon_sym_SEMI] = ACTIONS(4604),
    [anon_sym_DASH] = ACTIONS(4604),
    [aux_sym_boolean_token1] = ACTIONS(4602),
    [aux_sym_boolean_token2] = ACTIONS(4602),
    [sym_decimal] = ACTIONS(4602),
    [anon_sym_LPAREN] = ACTIONS(4604),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4602),
    [anon_sym_LBRACK] = ACTIONS(4604),
    [aux_sym_record_type_token1] = ACTIONS(4602),
    [aux_sym_basic_type_token21] = ACTIONS(4602),
    [aux_sym_basic_type_token22] = ACTIONS(4602),
    [aux_sym_basic_type_token48] = ACTIONS(4602),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4602),
    [anon_sym_POUNDif] = ACTIONS(4604),
    [anon_sym_POUNDIF] = ACTIONS(4604),
    [anon_sym_POUNDIf] = ACTIONS(4604),
    [anon_sym_not] = ACTIONS(4602),
    [anon_sym_NOT] = ACTIONS(4602),
    [anon_sym_Not] = ACTIONS(4602),
    [anon_sym_POUNDelse] = ACTIONS(4604),
    [anon_sym_POUNDELSE] = ACTIONS(4604),
    [anon_sym_POUNDElse] = ACTIONS(4604),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4602),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4602),
    [anon_sym_PLUS] = ACTIONS(4604),
    [sym_datetime_literal] = ACTIONS(4604),
    [sym_date_literal] = ACTIONS(4602),
    [sym_time_literal] = ACTIONS(4602),
    [sym_biginteger_literal] = ACTIONS(4604),
    [anon_sym_if] = ACTIONS(4602),
    [anon_sym_IF] = ACTIONS(4602),
    [anon_sym_If] = ACTIONS(4602),
    [anon_sym_else] = ACTIONS(4602),
    [anon_sym_ELSE] = ACTIONS(4602),
    [anon_sym_Else] = ACTIONS(4602),
    [anon_sym_case] = ACTIONS(4602),
    [anon_sym_CASE] = ACTIONS(4602),
    [anon_sym_Case] = ACTIONS(4602),
    [anon_sym_for] = ACTIONS(4602),
    [anon_sym_FOR] = ACTIONS(4602),
    [anon_sym_For] = ACTIONS(4602),
    [anon_sym_foreach] = ACTIONS(4602),
    [anon_sym_FOREACH] = ACTIONS(4602),
    [anon_sym_Foreach] = ACTIONS(4602),
    [anon_sym_while] = ACTIONS(4602),
    [anon_sym_WHILE] = ACTIONS(4602),
    [anon_sym_While] = ACTIONS(4602),
    [anon_sym_repeat] = ACTIONS(4602),
    [anon_sym_REPEAT] = ACTIONS(4602),
    [anon_sym_Repeat] = ACTIONS(4602),
    [anon_sym_until] = ACTIONS(4602),
    [anon_sym_UNTIL] = ACTIONS(4602),
    [anon_sym_Until] = ACTIONS(4602),
    [anon_sym_exit] = ACTIONS(4602),
    [anon_sym_EXIT] = ACTIONS(4602),
    [anon_sym_Exit] = ACTIONS(4602),
    [anon_sym_continue] = ACTIONS(4602),
    [anon_sym_CONTINUE] = ACTIONS(4602),
    [anon_sym_Continue] = ACTIONS(4602),
    [anon_sym_break] = ACTIONS(4602),
    [anon_sym_BREAK] = ACTIONS(4602),
    [anon_sym_Break] = ACTIONS(4602),
    [anon_sym_with] = ACTIONS(4602),
    [anon_sym_WITH] = ACTIONS(4602),
    [anon_sym_With] = ACTIONS(4602),
    [sym_asserterror_keyword] = ACTIONS(4604),
    [sym_page_keyword] = ACTIONS(4602),
    [anon_sym_codeunit] = ACTIONS(4602),
    [anon_sym_CODEUNIT] = ACTIONS(4602),
    [anon_sym_Codeunit] = ACTIONS(4602),
    [anon_sym_CodeUnit] = ACTIONS(4602),
    [anon_sym_COdeunit] = ACTIONS(4602),
    [anon_sym_codeUnit] = ACTIONS(4602),
    [sym_report_keyword] = ACTIONS(4602),
    [sym_query_keyword] = ACTIONS(4602),
    [anon_sym_xmlport] = ACTIONS(4602),
    [anon_sym_XMLPORT] = ACTIONS(4602),
    [anon_sym_Xmlport] = ACTIONS(4602),
    [anon_sym_XMLport] = ACTIONS(4602),
    [anon_sym_XMLPort] = ACTIONS(4602),
    [anon_sym_XmlPort] = ACTIONS(4602),
    [anon_sym_enum] = ACTIONS(4602),
    [anon_sym_ENUM] = ACTIONS(4602),
    [anon_sym_Enum] = ACTIONS(4602),
    [anon_sym_eNUM] = ACTIONS(4602),
    [anon_sym_eNum] = ACTIONS(4602),
    [anon_sym_ENum] = ACTIONS(4602),
    [sym_quoted_identifier] = ACTIONS(4604),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4604),
    [sym_integer] = ACTIONS(4602),
    [sym_continue_as_identifier] = ACTIONS(4604),
    [sym_preproc_open] = ACTIONS(4604),
  },
  [STATE(1910)] = {
    [sym_identifier] = ACTIONS(4610),
    [anon_sym_SEMI] = ACTIONS(4612),
    [anon_sym_DASH] = ACTIONS(4612),
    [aux_sym_boolean_token1] = ACTIONS(4610),
    [aux_sym_boolean_token2] = ACTIONS(4610),
    [sym_decimal] = ACTIONS(4610),
    [anon_sym_LPAREN] = ACTIONS(4612),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4610),
    [anon_sym_LBRACK] = ACTIONS(4612),
    [aux_sym_record_type_token1] = ACTIONS(4610),
    [aux_sym_basic_type_token21] = ACTIONS(4610),
    [aux_sym_basic_type_token22] = ACTIONS(4610),
    [aux_sym_basic_type_token48] = ACTIONS(4610),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4610),
    [anon_sym_POUNDif] = ACTIONS(4612),
    [anon_sym_POUNDIF] = ACTIONS(4612),
    [anon_sym_POUNDIf] = ACTIONS(4612),
    [anon_sym_not] = ACTIONS(4610),
    [anon_sym_NOT] = ACTIONS(4610),
    [anon_sym_Not] = ACTIONS(4610),
    [anon_sym_POUNDelse] = ACTIONS(4612),
    [anon_sym_POUNDELSE] = ACTIONS(4612),
    [anon_sym_POUNDElse] = ACTIONS(4612),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4610),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4610),
    [anon_sym_PLUS] = ACTIONS(4612),
    [sym_datetime_literal] = ACTIONS(4612),
    [sym_date_literal] = ACTIONS(4610),
    [sym_time_literal] = ACTIONS(4610),
    [sym_biginteger_literal] = ACTIONS(4612),
    [anon_sym_if] = ACTIONS(4610),
    [anon_sym_IF] = ACTIONS(4610),
    [anon_sym_If] = ACTIONS(4610),
    [anon_sym_else] = ACTIONS(4610),
    [anon_sym_ELSE] = ACTIONS(4610),
    [anon_sym_Else] = ACTIONS(4610),
    [anon_sym_case] = ACTIONS(4610),
    [anon_sym_CASE] = ACTIONS(4610),
    [anon_sym_Case] = ACTIONS(4610),
    [anon_sym_for] = ACTIONS(4610),
    [anon_sym_FOR] = ACTIONS(4610),
    [anon_sym_For] = ACTIONS(4610),
    [anon_sym_foreach] = ACTIONS(4610),
    [anon_sym_FOREACH] = ACTIONS(4610),
    [anon_sym_Foreach] = ACTIONS(4610),
    [anon_sym_while] = ACTIONS(4610),
    [anon_sym_WHILE] = ACTIONS(4610),
    [anon_sym_While] = ACTIONS(4610),
    [anon_sym_repeat] = ACTIONS(4610),
    [anon_sym_REPEAT] = ACTIONS(4610),
    [anon_sym_Repeat] = ACTIONS(4610),
    [anon_sym_until] = ACTIONS(4610),
    [anon_sym_UNTIL] = ACTIONS(4610),
    [anon_sym_Until] = ACTIONS(4610),
    [anon_sym_exit] = ACTIONS(4610),
    [anon_sym_EXIT] = ACTIONS(4610),
    [anon_sym_Exit] = ACTIONS(4610),
    [anon_sym_continue] = ACTIONS(4610),
    [anon_sym_CONTINUE] = ACTIONS(4610),
    [anon_sym_Continue] = ACTIONS(4610),
    [anon_sym_break] = ACTIONS(4610),
    [anon_sym_BREAK] = ACTIONS(4610),
    [anon_sym_Break] = ACTIONS(4610),
    [anon_sym_with] = ACTIONS(4610),
    [anon_sym_WITH] = ACTIONS(4610),
    [anon_sym_With] = ACTIONS(4610),
    [sym_asserterror_keyword] = ACTIONS(4612),
    [sym_page_keyword] = ACTIONS(4610),
    [anon_sym_codeunit] = ACTIONS(4610),
    [anon_sym_CODEUNIT] = ACTIONS(4610),
    [anon_sym_Codeunit] = ACTIONS(4610),
    [anon_sym_CodeUnit] = ACTIONS(4610),
    [anon_sym_COdeunit] = ACTIONS(4610),
    [anon_sym_codeUnit] = ACTIONS(4610),
    [sym_report_keyword] = ACTIONS(4610),
    [sym_query_keyword] = ACTIONS(4610),
    [anon_sym_xmlport] = ACTIONS(4610),
    [anon_sym_XMLPORT] = ACTIONS(4610),
    [anon_sym_Xmlport] = ACTIONS(4610),
    [anon_sym_XMLport] = ACTIONS(4610),
    [anon_sym_XMLPort] = ACTIONS(4610),
    [anon_sym_XmlPort] = ACTIONS(4610),
    [anon_sym_enum] = ACTIONS(4610),
    [anon_sym_ENUM] = ACTIONS(4610),
    [anon_sym_Enum] = ACTIONS(4610),
    [anon_sym_eNUM] = ACTIONS(4610),
    [anon_sym_eNum] = ACTIONS(4610),
    [anon_sym_ENum] = ACTIONS(4610),
    [sym_quoted_identifier] = ACTIONS(4612),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4612),
    [sym_integer] = ACTIONS(4610),
    [sym_continue_as_identifier] = ACTIONS(4612),
    [sym_preproc_open] = ACTIONS(4612),
  },
  [STATE(1911)] = {
    [sym_identifier] = ACTIONS(4614),
    [anon_sym_SEMI] = ACTIONS(4616),
    [anon_sym_DASH] = ACTIONS(4616),
    [aux_sym_boolean_token1] = ACTIONS(4614),
    [aux_sym_boolean_token2] = ACTIONS(4614),
    [sym_decimal] = ACTIONS(4614),
    [anon_sym_LPAREN] = ACTIONS(4616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4614),
    [anon_sym_LBRACK] = ACTIONS(4616),
    [aux_sym_record_type_token1] = ACTIONS(4614),
    [aux_sym_basic_type_token21] = ACTIONS(4614),
    [aux_sym_basic_type_token22] = ACTIONS(4614),
    [aux_sym_basic_type_token48] = ACTIONS(4614),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4614),
    [anon_sym_POUNDif] = ACTIONS(4616),
    [anon_sym_POUNDIF] = ACTIONS(4616),
    [anon_sym_POUNDIf] = ACTIONS(4616),
    [anon_sym_not] = ACTIONS(4614),
    [anon_sym_NOT] = ACTIONS(4614),
    [anon_sym_Not] = ACTIONS(4614),
    [anon_sym_POUNDelse] = ACTIONS(4616),
    [anon_sym_POUNDELSE] = ACTIONS(4616),
    [anon_sym_POUNDElse] = ACTIONS(4616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4614),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4614),
    [anon_sym_PLUS] = ACTIONS(4616),
    [sym_datetime_literal] = ACTIONS(4616),
    [sym_date_literal] = ACTIONS(4614),
    [sym_time_literal] = ACTIONS(4614),
    [sym_biginteger_literal] = ACTIONS(4616),
    [anon_sym_if] = ACTIONS(4614),
    [anon_sym_IF] = ACTIONS(4614),
    [anon_sym_If] = ACTIONS(4614),
    [anon_sym_else] = ACTIONS(4614),
    [anon_sym_ELSE] = ACTIONS(4614),
    [anon_sym_Else] = ACTIONS(4614),
    [anon_sym_case] = ACTIONS(4614),
    [anon_sym_CASE] = ACTIONS(4614),
    [anon_sym_Case] = ACTIONS(4614),
    [anon_sym_for] = ACTIONS(4614),
    [anon_sym_FOR] = ACTIONS(4614),
    [anon_sym_For] = ACTIONS(4614),
    [anon_sym_foreach] = ACTIONS(4614),
    [anon_sym_FOREACH] = ACTIONS(4614),
    [anon_sym_Foreach] = ACTIONS(4614),
    [anon_sym_while] = ACTIONS(4614),
    [anon_sym_WHILE] = ACTIONS(4614),
    [anon_sym_While] = ACTIONS(4614),
    [anon_sym_repeat] = ACTIONS(4614),
    [anon_sym_REPEAT] = ACTIONS(4614),
    [anon_sym_Repeat] = ACTIONS(4614),
    [anon_sym_until] = ACTIONS(4614),
    [anon_sym_UNTIL] = ACTIONS(4614),
    [anon_sym_Until] = ACTIONS(4614),
    [anon_sym_exit] = ACTIONS(4614),
    [anon_sym_EXIT] = ACTIONS(4614),
    [anon_sym_Exit] = ACTIONS(4614),
    [anon_sym_continue] = ACTIONS(4614),
    [anon_sym_CONTINUE] = ACTIONS(4614),
    [anon_sym_Continue] = ACTIONS(4614),
    [anon_sym_break] = ACTIONS(4614),
    [anon_sym_BREAK] = ACTIONS(4614),
    [anon_sym_Break] = ACTIONS(4614),
    [anon_sym_with] = ACTIONS(4614),
    [anon_sym_WITH] = ACTIONS(4614),
    [anon_sym_With] = ACTIONS(4614),
    [sym_asserterror_keyword] = ACTIONS(4616),
    [sym_page_keyword] = ACTIONS(4614),
    [anon_sym_codeunit] = ACTIONS(4614),
    [anon_sym_CODEUNIT] = ACTIONS(4614),
    [anon_sym_Codeunit] = ACTIONS(4614),
    [anon_sym_CodeUnit] = ACTIONS(4614),
    [anon_sym_COdeunit] = ACTIONS(4614),
    [anon_sym_codeUnit] = ACTIONS(4614),
    [sym_report_keyword] = ACTIONS(4614),
    [sym_query_keyword] = ACTIONS(4614),
    [anon_sym_xmlport] = ACTIONS(4614),
    [anon_sym_XMLPORT] = ACTIONS(4614),
    [anon_sym_Xmlport] = ACTIONS(4614),
    [anon_sym_XMLport] = ACTIONS(4614),
    [anon_sym_XMLPort] = ACTIONS(4614),
    [anon_sym_XmlPort] = ACTIONS(4614),
    [anon_sym_enum] = ACTIONS(4614),
    [anon_sym_ENUM] = ACTIONS(4614),
    [anon_sym_Enum] = ACTIONS(4614),
    [anon_sym_eNUM] = ACTIONS(4614),
    [anon_sym_eNum] = ACTIONS(4614),
    [anon_sym_ENum] = ACTIONS(4614),
    [sym_quoted_identifier] = ACTIONS(4616),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4616),
    [sym_integer] = ACTIONS(4614),
    [sym_continue_as_identifier] = ACTIONS(4616),
    [sym_preproc_open] = ACTIONS(4616),
  },
  [STATE(1912)] = {
    [sym_identifier] = ACTIONS(4618),
    [anon_sym_SEMI] = ACTIONS(4620),
    [anon_sym_DASH] = ACTIONS(4620),
    [aux_sym_boolean_token1] = ACTIONS(4618),
    [aux_sym_boolean_token2] = ACTIONS(4618),
    [sym_decimal] = ACTIONS(4618),
    [anon_sym_LPAREN] = ACTIONS(4620),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4618),
    [anon_sym_LBRACK] = ACTIONS(4620),
    [aux_sym_record_type_token1] = ACTIONS(4618),
    [aux_sym_basic_type_token21] = ACTIONS(4618),
    [aux_sym_basic_type_token22] = ACTIONS(4618),
    [aux_sym_basic_type_token48] = ACTIONS(4618),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4618),
    [anon_sym_POUNDif] = ACTIONS(4620),
    [anon_sym_POUNDIF] = ACTIONS(4620),
    [anon_sym_POUNDIf] = ACTIONS(4620),
    [anon_sym_not] = ACTIONS(4618),
    [anon_sym_NOT] = ACTIONS(4618),
    [anon_sym_Not] = ACTIONS(4618),
    [anon_sym_POUNDelse] = ACTIONS(4620),
    [anon_sym_POUNDELSE] = ACTIONS(4620),
    [anon_sym_POUNDElse] = ACTIONS(4620),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4618),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4618),
    [anon_sym_PLUS] = ACTIONS(4620),
    [sym_datetime_literal] = ACTIONS(4620),
    [sym_date_literal] = ACTIONS(4618),
    [sym_time_literal] = ACTIONS(4618),
    [sym_biginteger_literal] = ACTIONS(4620),
    [anon_sym_if] = ACTIONS(4618),
    [anon_sym_IF] = ACTIONS(4618),
    [anon_sym_If] = ACTIONS(4618),
    [anon_sym_else] = ACTIONS(4618),
    [anon_sym_ELSE] = ACTIONS(4618),
    [anon_sym_Else] = ACTIONS(4618),
    [anon_sym_case] = ACTIONS(4618),
    [anon_sym_CASE] = ACTIONS(4618),
    [anon_sym_Case] = ACTIONS(4618),
    [anon_sym_for] = ACTIONS(4618),
    [anon_sym_FOR] = ACTIONS(4618),
    [anon_sym_For] = ACTIONS(4618),
    [anon_sym_foreach] = ACTIONS(4618),
    [anon_sym_FOREACH] = ACTIONS(4618),
    [anon_sym_Foreach] = ACTIONS(4618),
    [anon_sym_while] = ACTIONS(4618),
    [anon_sym_WHILE] = ACTIONS(4618),
    [anon_sym_While] = ACTIONS(4618),
    [anon_sym_repeat] = ACTIONS(4618),
    [anon_sym_REPEAT] = ACTIONS(4618),
    [anon_sym_Repeat] = ACTIONS(4618),
    [anon_sym_until] = ACTIONS(4618),
    [anon_sym_UNTIL] = ACTIONS(4618),
    [anon_sym_Until] = ACTIONS(4618),
    [anon_sym_exit] = ACTIONS(4618),
    [anon_sym_EXIT] = ACTIONS(4618),
    [anon_sym_Exit] = ACTIONS(4618),
    [anon_sym_continue] = ACTIONS(4618),
    [anon_sym_CONTINUE] = ACTIONS(4618),
    [anon_sym_Continue] = ACTIONS(4618),
    [anon_sym_break] = ACTIONS(4618),
    [anon_sym_BREAK] = ACTIONS(4618),
    [anon_sym_Break] = ACTIONS(4618),
    [anon_sym_with] = ACTIONS(4618),
    [anon_sym_WITH] = ACTIONS(4618),
    [anon_sym_With] = ACTIONS(4618),
    [sym_asserterror_keyword] = ACTIONS(4620),
    [sym_page_keyword] = ACTIONS(4618),
    [anon_sym_codeunit] = ACTIONS(4618),
    [anon_sym_CODEUNIT] = ACTIONS(4618),
    [anon_sym_Codeunit] = ACTIONS(4618),
    [anon_sym_CodeUnit] = ACTIONS(4618),
    [anon_sym_COdeunit] = ACTIONS(4618),
    [anon_sym_codeUnit] = ACTIONS(4618),
    [sym_report_keyword] = ACTIONS(4618),
    [sym_query_keyword] = ACTIONS(4618),
    [anon_sym_xmlport] = ACTIONS(4618),
    [anon_sym_XMLPORT] = ACTIONS(4618),
    [anon_sym_Xmlport] = ACTIONS(4618),
    [anon_sym_XMLport] = ACTIONS(4618),
    [anon_sym_XMLPort] = ACTIONS(4618),
    [anon_sym_XmlPort] = ACTIONS(4618),
    [anon_sym_enum] = ACTIONS(4618),
    [anon_sym_ENUM] = ACTIONS(4618),
    [anon_sym_Enum] = ACTIONS(4618),
    [anon_sym_eNUM] = ACTIONS(4618),
    [anon_sym_eNum] = ACTIONS(4618),
    [anon_sym_ENum] = ACTIONS(4618),
    [sym_quoted_identifier] = ACTIONS(4620),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4620),
    [sym_integer] = ACTIONS(4618),
    [sym_continue_as_identifier] = ACTIONS(4620),
    [sym_preproc_open] = ACTIONS(4620),
  },
  [STATE(1913)] = {
    [sym_identifier] = ACTIONS(4531),
    [anon_sym_SEMI] = ACTIONS(4533),
    [anon_sym_DASH] = ACTIONS(4533),
    [aux_sym_boolean_token1] = ACTIONS(4531),
    [aux_sym_boolean_token2] = ACTIONS(4531),
    [sym_decimal] = ACTIONS(4531),
    [anon_sym_LPAREN] = ACTIONS(4533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4531),
    [anon_sym_LBRACK] = ACTIONS(4533),
    [aux_sym_record_type_token1] = ACTIONS(4531),
    [aux_sym_basic_type_token21] = ACTIONS(4531),
    [aux_sym_basic_type_token22] = ACTIONS(4531),
    [aux_sym_basic_type_token48] = ACTIONS(4531),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4531),
    [anon_sym_POUNDif] = ACTIONS(4533),
    [anon_sym_POUNDIF] = ACTIONS(4533),
    [anon_sym_POUNDIf] = ACTIONS(4533),
    [anon_sym_not] = ACTIONS(4531),
    [anon_sym_NOT] = ACTIONS(4531),
    [anon_sym_Not] = ACTIONS(4531),
    [anon_sym_POUNDelse] = ACTIONS(4533),
    [anon_sym_POUNDELSE] = ACTIONS(4533),
    [anon_sym_POUNDElse] = ACTIONS(4533),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4531),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4531),
    [anon_sym_PLUS] = ACTIONS(4533),
    [sym_datetime_literal] = ACTIONS(4533),
    [sym_date_literal] = ACTIONS(4531),
    [sym_time_literal] = ACTIONS(4531),
    [sym_biginteger_literal] = ACTIONS(4533),
    [anon_sym_if] = ACTIONS(4531),
    [anon_sym_IF] = ACTIONS(4531),
    [anon_sym_If] = ACTIONS(4531),
    [anon_sym_else] = ACTIONS(4531),
    [anon_sym_ELSE] = ACTIONS(4531),
    [anon_sym_Else] = ACTIONS(4531),
    [anon_sym_case] = ACTIONS(4531),
    [anon_sym_CASE] = ACTIONS(4531),
    [anon_sym_Case] = ACTIONS(4531),
    [anon_sym_for] = ACTIONS(4531),
    [anon_sym_FOR] = ACTIONS(4531),
    [anon_sym_For] = ACTIONS(4531),
    [anon_sym_foreach] = ACTIONS(4531),
    [anon_sym_FOREACH] = ACTIONS(4531),
    [anon_sym_Foreach] = ACTIONS(4531),
    [anon_sym_while] = ACTIONS(4531),
    [anon_sym_WHILE] = ACTIONS(4531),
    [anon_sym_While] = ACTIONS(4531),
    [anon_sym_repeat] = ACTIONS(4531),
    [anon_sym_REPEAT] = ACTIONS(4531),
    [anon_sym_Repeat] = ACTIONS(4531),
    [anon_sym_until] = ACTIONS(4531),
    [anon_sym_UNTIL] = ACTIONS(4531),
    [anon_sym_Until] = ACTIONS(4531),
    [anon_sym_exit] = ACTIONS(4531),
    [anon_sym_EXIT] = ACTIONS(4531),
    [anon_sym_Exit] = ACTIONS(4531),
    [anon_sym_continue] = ACTIONS(4531),
    [anon_sym_CONTINUE] = ACTIONS(4531),
    [anon_sym_Continue] = ACTIONS(4531),
    [anon_sym_break] = ACTIONS(4531),
    [anon_sym_BREAK] = ACTIONS(4531),
    [anon_sym_Break] = ACTIONS(4531),
    [anon_sym_with] = ACTIONS(4531),
    [anon_sym_WITH] = ACTIONS(4531),
    [anon_sym_With] = ACTIONS(4531),
    [sym_asserterror_keyword] = ACTIONS(4533),
    [sym_page_keyword] = ACTIONS(4531),
    [anon_sym_codeunit] = ACTIONS(4531),
    [anon_sym_CODEUNIT] = ACTIONS(4531),
    [anon_sym_Codeunit] = ACTIONS(4531),
    [anon_sym_CodeUnit] = ACTIONS(4531),
    [anon_sym_COdeunit] = ACTIONS(4531),
    [anon_sym_codeUnit] = ACTIONS(4531),
    [sym_report_keyword] = ACTIONS(4531),
    [sym_query_keyword] = ACTIONS(4531),
    [anon_sym_xmlport] = ACTIONS(4531),
    [anon_sym_XMLPORT] = ACTIONS(4531),
    [anon_sym_Xmlport] = ACTIONS(4531),
    [anon_sym_XMLport] = ACTIONS(4531),
    [anon_sym_XMLPort] = ACTIONS(4531),
    [anon_sym_XmlPort] = ACTIONS(4531),
    [anon_sym_enum] = ACTIONS(4531),
    [anon_sym_ENUM] = ACTIONS(4531),
    [anon_sym_Enum] = ACTIONS(4531),
    [anon_sym_eNUM] = ACTIONS(4531),
    [anon_sym_eNum] = ACTIONS(4531),
    [anon_sym_ENum] = ACTIONS(4531),
    [sym_quoted_identifier] = ACTIONS(4533),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4533),
    [sym_integer] = ACTIONS(4531),
    [sym_continue_as_identifier] = ACTIONS(4533),
    [sym_preproc_open] = ACTIONS(4533),
  },
  [STATE(1914)] = {
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_SEMI] = ACTIONS(4537),
    [anon_sym_DASH] = ACTIONS(4537),
    [aux_sym_boolean_token1] = ACTIONS(4535),
    [aux_sym_boolean_token2] = ACTIONS(4535),
    [sym_decimal] = ACTIONS(4535),
    [anon_sym_LPAREN] = ACTIONS(4537),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4535),
    [anon_sym_LBRACK] = ACTIONS(4537),
    [aux_sym_record_type_token1] = ACTIONS(4535),
    [aux_sym_basic_type_token21] = ACTIONS(4535),
    [aux_sym_basic_type_token22] = ACTIONS(4535),
    [aux_sym_basic_type_token48] = ACTIONS(4535),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4535),
    [anon_sym_POUNDif] = ACTIONS(4537),
    [anon_sym_POUNDIF] = ACTIONS(4537),
    [anon_sym_POUNDIf] = ACTIONS(4537),
    [anon_sym_not] = ACTIONS(4535),
    [anon_sym_NOT] = ACTIONS(4535),
    [anon_sym_Not] = ACTIONS(4535),
    [anon_sym_POUNDelse] = ACTIONS(4537),
    [anon_sym_POUNDELSE] = ACTIONS(4537),
    [anon_sym_POUNDElse] = ACTIONS(4537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4535),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4535),
    [anon_sym_PLUS] = ACTIONS(4537),
    [sym_datetime_literal] = ACTIONS(4537),
    [sym_date_literal] = ACTIONS(4535),
    [sym_time_literal] = ACTIONS(4535),
    [sym_biginteger_literal] = ACTIONS(4537),
    [anon_sym_if] = ACTIONS(4535),
    [anon_sym_IF] = ACTIONS(4535),
    [anon_sym_If] = ACTIONS(4535),
    [anon_sym_else] = ACTIONS(4535),
    [anon_sym_ELSE] = ACTIONS(4535),
    [anon_sym_Else] = ACTIONS(4535),
    [anon_sym_case] = ACTIONS(4535),
    [anon_sym_CASE] = ACTIONS(4535),
    [anon_sym_Case] = ACTIONS(4535),
    [anon_sym_for] = ACTIONS(4535),
    [anon_sym_FOR] = ACTIONS(4535),
    [anon_sym_For] = ACTIONS(4535),
    [anon_sym_foreach] = ACTIONS(4535),
    [anon_sym_FOREACH] = ACTIONS(4535),
    [anon_sym_Foreach] = ACTIONS(4535),
    [anon_sym_while] = ACTIONS(4535),
    [anon_sym_WHILE] = ACTIONS(4535),
    [anon_sym_While] = ACTIONS(4535),
    [anon_sym_repeat] = ACTIONS(4535),
    [anon_sym_REPEAT] = ACTIONS(4535),
    [anon_sym_Repeat] = ACTIONS(4535),
    [anon_sym_until] = ACTIONS(4535),
    [anon_sym_UNTIL] = ACTIONS(4535),
    [anon_sym_Until] = ACTIONS(4535),
    [anon_sym_exit] = ACTIONS(4535),
    [anon_sym_EXIT] = ACTIONS(4535),
    [anon_sym_Exit] = ACTIONS(4535),
    [anon_sym_continue] = ACTIONS(4535),
    [anon_sym_CONTINUE] = ACTIONS(4535),
    [anon_sym_Continue] = ACTIONS(4535),
    [anon_sym_break] = ACTIONS(4535),
    [anon_sym_BREAK] = ACTIONS(4535),
    [anon_sym_Break] = ACTIONS(4535),
    [anon_sym_with] = ACTIONS(4535),
    [anon_sym_WITH] = ACTIONS(4535),
    [anon_sym_With] = ACTIONS(4535),
    [sym_asserterror_keyword] = ACTIONS(4537),
    [sym_page_keyword] = ACTIONS(4535),
    [anon_sym_codeunit] = ACTIONS(4535),
    [anon_sym_CODEUNIT] = ACTIONS(4535),
    [anon_sym_Codeunit] = ACTIONS(4535),
    [anon_sym_CodeUnit] = ACTIONS(4535),
    [anon_sym_COdeunit] = ACTIONS(4535),
    [anon_sym_codeUnit] = ACTIONS(4535),
    [sym_report_keyword] = ACTIONS(4535),
    [sym_query_keyword] = ACTIONS(4535),
    [anon_sym_xmlport] = ACTIONS(4535),
    [anon_sym_XMLPORT] = ACTIONS(4535),
    [anon_sym_Xmlport] = ACTIONS(4535),
    [anon_sym_XMLport] = ACTIONS(4535),
    [anon_sym_XMLPort] = ACTIONS(4535),
    [anon_sym_XmlPort] = ACTIONS(4535),
    [anon_sym_enum] = ACTIONS(4535),
    [anon_sym_ENUM] = ACTIONS(4535),
    [anon_sym_Enum] = ACTIONS(4535),
    [anon_sym_eNUM] = ACTIONS(4535),
    [anon_sym_eNum] = ACTIONS(4535),
    [anon_sym_ENum] = ACTIONS(4535),
    [sym_quoted_identifier] = ACTIONS(4537),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4537),
    [sym_integer] = ACTIONS(4535),
    [sym_continue_as_identifier] = ACTIONS(4537),
    [sym_preproc_open] = ACTIONS(4537),
  },
  [STATE(1915)] = {
    [sym_identifier] = ACTIONS(4622),
    [anon_sym_SEMI] = ACTIONS(4624),
    [anon_sym_DASH] = ACTIONS(4624),
    [aux_sym_boolean_token1] = ACTIONS(4622),
    [aux_sym_boolean_token2] = ACTIONS(4622),
    [sym_decimal] = ACTIONS(4622),
    [anon_sym_LPAREN] = ACTIONS(4624),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4622),
    [anon_sym_LBRACK] = ACTIONS(4624),
    [aux_sym_record_type_token1] = ACTIONS(4622),
    [aux_sym_basic_type_token21] = ACTIONS(4622),
    [aux_sym_basic_type_token22] = ACTIONS(4622),
    [aux_sym_basic_type_token48] = ACTIONS(4622),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4622),
    [anon_sym_POUNDif] = ACTIONS(4624),
    [anon_sym_POUNDIF] = ACTIONS(4624),
    [anon_sym_POUNDIf] = ACTIONS(4624),
    [anon_sym_not] = ACTIONS(4622),
    [anon_sym_NOT] = ACTIONS(4622),
    [anon_sym_Not] = ACTIONS(4622),
    [anon_sym_POUNDelse] = ACTIONS(4624),
    [anon_sym_POUNDELSE] = ACTIONS(4624),
    [anon_sym_POUNDElse] = ACTIONS(4624),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4622),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4622),
    [anon_sym_PLUS] = ACTIONS(4624),
    [sym_datetime_literal] = ACTIONS(4624),
    [sym_date_literal] = ACTIONS(4622),
    [sym_time_literal] = ACTIONS(4622),
    [sym_biginteger_literal] = ACTIONS(4624),
    [anon_sym_if] = ACTIONS(4622),
    [anon_sym_IF] = ACTIONS(4622),
    [anon_sym_If] = ACTIONS(4622),
    [anon_sym_else] = ACTIONS(4622),
    [anon_sym_ELSE] = ACTIONS(4622),
    [anon_sym_Else] = ACTIONS(4622),
    [anon_sym_case] = ACTIONS(4622),
    [anon_sym_CASE] = ACTIONS(4622),
    [anon_sym_Case] = ACTIONS(4622),
    [anon_sym_for] = ACTIONS(4622),
    [anon_sym_FOR] = ACTIONS(4622),
    [anon_sym_For] = ACTIONS(4622),
    [anon_sym_foreach] = ACTIONS(4622),
    [anon_sym_FOREACH] = ACTIONS(4622),
    [anon_sym_Foreach] = ACTIONS(4622),
    [anon_sym_while] = ACTIONS(4622),
    [anon_sym_WHILE] = ACTIONS(4622),
    [anon_sym_While] = ACTIONS(4622),
    [anon_sym_repeat] = ACTIONS(4622),
    [anon_sym_REPEAT] = ACTIONS(4622),
    [anon_sym_Repeat] = ACTIONS(4622),
    [anon_sym_until] = ACTIONS(4622),
    [anon_sym_UNTIL] = ACTIONS(4622),
    [anon_sym_Until] = ACTIONS(4622),
    [anon_sym_exit] = ACTIONS(4622),
    [anon_sym_EXIT] = ACTIONS(4622),
    [anon_sym_Exit] = ACTIONS(4622),
    [anon_sym_continue] = ACTIONS(4622),
    [anon_sym_CONTINUE] = ACTIONS(4622),
    [anon_sym_Continue] = ACTIONS(4622),
    [anon_sym_break] = ACTIONS(4622),
    [anon_sym_BREAK] = ACTIONS(4622),
    [anon_sym_Break] = ACTIONS(4622),
    [anon_sym_with] = ACTIONS(4622),
    [anon_sym_WITH] = ACTIONS(4622),
    [anon_sym_With] = ACTIONS(4622),
    [sym_asserterror_keyword] = ACTIONS(4624),
    [sym_page_keyword] = ACTIONS(4622),
    [anon_sym_codeunit] = ACTIONS(4622),
    [anon_sym_CODEUNIT] = ACTIONS(4622),
    [anon_sym_Codeunit] = ACTIONS(4622),
    [anon_sym_CodeUnit] = ACTIONS(4622),
    [anon_sym_COdeunit] = ACTIONS(4622),
    [anon_sym_codeUnit] = ACTIONS(4622),
    [sym_report_keyword] = ACTIONS(4622),
    [sym_query_keyword] = ACTIONS(4622),
    [anon_sym_xmlport] = ACTIONS(4622),
    [anon_sym_XMLPORT] = ACTIONS(4622),
    [anon_sym_Xmlport] = ACTIONS(4622),
    [anon_sym_XMLport] = ACTIONS(4622),
    [anon_sym_XMLPort] = ACTIONS(4622),
    [anon_sym_XmlPort] = ACTIONS(4622),
    [anon_sym_enum] = ACTIONS(4622),
    [anon_sym_ENUM] = ACTIONS(4622),
    [anon_sym_Enum] = ACTIONS(4622),
    [anon_sym_eNUM] = ACTIONS(4622),
    [anon_sym_eNum] = ACTIONS(4622),
    [anon_sym_ENum] = ACTIONS(4622),
    [sym_quoted_identifier] = ACTIONS(4624),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4624),
    [sym_integer] = ACTIONS(4622),
    [sym_continue_as_identifier] = ACTIONS(4624),
    [sym_preproc_open] = ACTIONS(4624),
  },
  [STATE(1916)] = {
    [sym_identifier] = ACTIONS(4626),
    [anon_sym_SEMI] = ACTIONS(4628),
    [anon_sym_DASH] = ACTIONS(4628),
    [aux_sym_boolean_token1] = ACTIONS(4626),
    [aux_sym_boolean_token2] = ACTIONS(4626),
    [sym_decimal] = ACTIONS(4626),
    [anon_sym_LPAREN] = ACTIONS(4628),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4626),
    [anon_sym_LBRACK] = ACTIONS(4628),
    [aux_sym_record_type_token1] = ACTIONS(4626),
    [aux_sym_basic_type_token21] = ACTIONS(4626),
    [aux_sym_basic_type_token22] = ACTIONS(4626),
    [aux_sym_basic_type_token48] = ACTIONS(4626),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4626),
    [anon_sym_POUNDif] = ACTIONS(4628),
    [anon_sym_POUNDIF] = ACTIONS(4628),
    [anon_sym_POUNDIf] = ACTIONS(4628),
    [anon_sym_not] = ACTIONS(4626),
    [anon_sym_NOT] = ACTIONS(4626),
    [anon_sym_Not] = ACTIONS(4626),
    [anon_sym_POUNDelse] = ACTIONS(4628),
    [anon_sym_POUNDELSE] = ACTIONS(4628),
    [anon_sym_POUNDElse] = ACTIONS(4628),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4626),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4626),
    [anon_sym_PLUS] = ACTIONS(4628),
    [sym_datetime_literal] = ACTIONS(4628),
    [sym_date_literal] = ACTIONS(4626),
    [sym_time_literal] = ACTIONS(4626),
    [sym_biginteger_literal] = ACTIONS(4628),
    [anon_sym_if] = ACTIONS(4626),
    [anon_sym_IF] = ACTIONS(4626),
    [anon_sym_If] = ACTIONS(4626),
    [anon_sym_else] = ACTIONS(4626),
    [anon_sym_ELSE] = ACTIONS(4626),
    [anon_sym_Else] = ACTIONS(4626),
    [anon_sym_case] = ACTIONS(4626),
    [anon_sym_CASE] = ACTIONS(4626),
    [anon_sym_Case] = ACTIONS(4626),
    [anon_sym_for] = ACTIONS(4626),
    [anon_sym_FOR] = ACTIONS(4626),
    [anon_sym_For] = ACTIONS(4626),
    [anon_sym_foreach] = ACTIONS(4626),
    [anon_sym_FOREACH] = ACTIONS(4626),
    [anon_sym_Foreach] = ACTIONS(4626),
    [anon_sym_while] = ACTIONS(4626),
    [anon_sym_WHILE] = ACTIONS(4626),
    [anon_sym_While] = ACTIONS(4626),
    [anon_sym_repeat] = ACTIONS(4626),
    [anon_sym_REPEAT] = ACTIONS(4626),
    [anon_sym_Repeat] = ACTIONS(4626),
    [anon_sym_until] = ACTIONS(4626),
    [anon_sym_UNTIL] = ACTIONS(4626),
    [anon_sym_Until] = ACTIONS(4626),
    [anon_sym_exit] = ACTIONS(4626),
    [anon_sym_EXIT] = ACTIONS(4626),
    [anon_sym_Exit] = ACTIONS(4626),
    [anon_sym_continue] = ACTIONS(4626),
    [anon_sym_CONTINUE] = ACTIONS(4626),
    [anon_sym_Continue] = ACTIONS(4626),
    [anon_sym_break] = ACTIONS(4626),
    [anon_sym_BREAK] = ACTIONS(4626),
    [anon_sym_Break] = ACTIONS(4626),
    [anon_sym_with] = ACTIONS(4626),
    [anon_sym_WITH] = ACTIONS(4626),
    [anon_sym_With] = ACTIONS(4626),
    [sym_asserterror_keyword] = ACTIONS(4628),
    [sym_page_keyword] = ACTIONS(4626),
    [anon_sym_codeunit] = ACTIONS(4626),
    [anon_sym_CODEUNIT] = ACTIONS(4626),
    [anon_sym_Codeunit] = ACTIONS(4626),
    [anon_sym_CodeUnit] = ACTIONS(4626),
    [anon_sym_COdeunit] = ACTIONS(4626),
    [anon_sym_codeUnit] = ACTIONS(4626),
    [sym_report_keyword] = ACTIONS(4626),
    [sym_query_keyword] = ACTIONS(4626),
    [anon_sym_xmlport] = ACTIONS(4626),
    [anon_sym_XMLPORT] = ACTIONS(4626),
    [anon_sym_Xmlport] = ACTIONS(4626),
    [anon_sym_XMLport] = ACTIONS(4626),
    [anon_sym_XMLPort] = ACTIONS(4626),
    [anon_sym_XmlPort] = ACTIONS(4626),
    [anon_sym_enum] = ACTIONS(4626),
    [anon_sym_ENUM] = ACTIONS(4626),
    [anon_sym_Enum] = ACTIONS(4626),
    [anon_sym_eNUM] = ACTIONS(4626),
    [anon_sym_eNum] = ACTIONS(4626),
    [anon_sym_ENum] = ACTIONS(4626),
    [sym_quoted_identifier] = ACTIONS(4628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4628),
    [sym_integer] = ACTIONS(4626),
    [sym_continue_as_identifier] = ACTIONS(4628),
    [sym_preproc_open] = ACTIONS(4628),
  },
  [STATE(1917)] = {
    [sym_identifier] = ACTIONS(4626),
    [anon_sym_SEMI] = ACTIONS(4628),
    [anon_sym_DASH] = ACTIONS(4628),
    [aux_sym_boolean_token1] = ACTIONS(4626),
    [aux_sym_boolean_token2] = ACTIONS(4626),
    [sym_decimal] = ACTIONS(4626),
    [anon_sym_LPAREN] = ACTIONS(4628),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4626),
    [anon_sym_LBRACK] = ACTIONS(4628),
    [aux_sym_record_type_token1] = ACTIONS(4626),
    [aux_sym_basic_type_token21] = ACTIONS(4626),
    [aux_sym_basic_type_token22] = ACTIONS(4626),
    [aux_sym_basic_type_token48] = ACTIONS(4626),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4626),
    [anon_sym_POUNDif] = ACTIONS(4628),
    [anon_sym_POUNDIF] = ACTIONS(4628),
    [anon_sym_POUNDIf] = ACTIONS(4628),
    [anon_sym_not] = ACTIONS(4626),
    [anon_sym_NOT] = ACTIONS(4626),
    [anon_sym_Not] = ACTIONS(4626),
    [anon_sym_POUNDelse] = ACTIONS(4628),
    [anon_sym_POUNDELSE] = ACTIONS(4628),
    [anon_sym_POUNDElse] = ACTIONS(4628),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4626),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4626),
    [anon_sym_PLUS] = ACTIONS(4628),
    [sym_datetime_literal] = ACTIONS(4628),
    [sym_date_literal] = ACTIONS(4626),
    [sym_time_literal] = ACTIONS(4626),
    [sym_biginteger_literal] = ACTIONS(4628),
    [anon_sym_if] = ACTIONS(4626),
    [anon_sym_IF] = ACTIONS(4626),
    [anon_sym_If] = ACTIONS(4626),
    [anon_sym_else] = ACTIONS(4626),
    [anon_sym_ELSE] = ACTIONS(4626),
    [anon_sym_Else] = ACTIONS(4626),
    [anon_sym_case] = ACTIONS(4626),
    [anon_sym_CASE] = ACTIONS(4626),
    [anon_sym_Case] = ACTIONS(4626),
    [anon_sym_for] = ACTIONS(4626),
    [anon_sym_FOR] = ACTIONS(4626),
    [anon_sym_For] = ACTIONS(4626),
    [anon_sym_foreach] = ACTIONS(4626),
    [anon_sym_FOREACH] = ACTIONS(4626),
    [anon_sym_Foreach] = ACTIONS(4626),
    [anon_sym_while] = ACTIONS(4626),
    [anon_sym_WHILE] = ACTIONS(4626),
    [anon_sym_While] = ACTIONS(4626),
    [anon_sym_repeat] = ACTIONS(4626),
    [anon_sym_REPEAT] = ACTIONS(4626),
    [anon_sym_Repeat] = ACTIONS(4626),
    [anon_sym_until] = ACTIONS(4626),
    [anon_sym_UNTIL] = ACTIONS(4626),
    [anon_sym_Until] = ACTIONS(4626),
    [anon_sym_exit] = ACTIONS(4626),
    [anon_sym_EXIT] = ACTIONS(4626),
    [anon_sym_Exit] = ACTIONS(4626),
    [anon_sym_continue] = ACTIONS(4626),
    [anon_sym_CONTINUE] = ACTIONS(4626),
    [anon_sym_Continue] = ACTIONS(4626),
    [anon_sym_break] = ACTIONS(4626),
    [anon_sym_BREAK] = ACTIONS(4626),
    [anon_sym_Break] = ACTIONS(4626),
    [anon_sym_with] = ACTIONS(4626),
    [anon_sym_WITH] = ACTIONS(4626),
    [anon_sym_With] = ACTIONS(4626),
    [sym_asserterror_keyword] = ACTIONS(4628),
    [sym_page_keyword] = ACTIONS(4626),
    [anon_sym_codeunit] = ACTIONS(4626),
    [anon_sym_CODEUNIT] = ACTIONS(4626),
    [anon_sym_Codeunit] = ACTIONS(4626),
    [anon_sym_CodeUnit] = ACTIONS(4626),
    [anon_sym_COdeunit] = ACTIONS(4626),
    [anon_sym_codeUnit] = ACTIONS(4626),
    [sym_report_keyword] = ACTIONS(4626),
    [sym_query_keyword] = ACTIONS(4626),
    [anon_sym_xmlport] = ACTIONS(4626),
    [anon_sym_XMLPORT] = ACTIONS(4626),
    [anon_sym_Xmlport] = ACTIONS(4626),
    [anon_sym_XMLport] = ACTIONS(4626),
    [anon_sym_XMLPort] = ACTIONS(4626),
    [anon_sym_XmlPort] = ACTIONS(4626),
    [anon_sym_enum] = ACTIONS(4626),
    [anon_sym_ENUM] = ACTIONS(4626),
    [anon_sym_Enum] = ACTIONS(4626),
    [anon_sym_eNUM] = ACTIONS(4626),
    [anon_sym_eNum] = ACTIONS(4626),
    [anon_sym_ENum] = ACTIONS(4626),
    [sym_quoted_identifier] = ACTIONS(4628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4628),
    [sym_integer] = ACTIONS(4626),
    [sym_continue_as_identifier] = ACTIONS(4628),
    [sym_preproc_open] = ACTIONS(4628),
  },
  [STATE(1918)] = {
    [sym_identifier] = ACTIONS(4630),
    [anon_sym_SEMI] = ACTIONS(4632),
    [anon_sym_DASH] = ACTIONS(4632),
    [aux_sym_boolean_token1] = ACTIONS(4630),
    [aux_sym_boolean_token2] = ACTIONS(4630),
    [sym_decimal] = ACTIONS(4630),
    [anon_sym_LPAREN] = ACTIONS(4632),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4630),
    [anon_sym_LBRACK] = ACTIONS(4632),
    [aux_sym_record_type_token1] = ACTIONS(4630),
    [aux_sym_basic_type_token21] = ACTIONS(4630),
    [aux_sym_basic_type_token22] = ACTIONS(4630),
    [aux_sym_basic_type_token48] = ACTIONS(4630),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4630),
    [anon_sym_POUNDif] = ACTIONS(4632),
    [anon_sym_POUNDIF] = ACTIONS(4632),
    [anon_sym_POUNDIf] = ACTIONS(4632),
    [anon_sym_not] = ACTIONS(4630),
    [anon_sym_NOT] = ACTIONS(4630),
    [anon_sym_Not] = ACTIONS(4630),
    [anon_sym_POUNDelse] = ACTIONS(4632),
    [anon_sym_POUNDELSE] = ACTIONS(4632),
    [anon_sym_POUNDElse] = ACTIONS(4632),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4630),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4630),
    [anon_sym_PLUS] = ACTIONS(4632),
    [sym_datetime_literal] = ACTIONS(4632),
    [sym_date_literal] = ACTIONS(4630),
    [sym_time_literal] = ACTIONS(4630),
    [sym_biginteger_literal] = ACTIONS(4632),
    [anon_sym_if] = ACTIONS(4630),
    [anon_sym_IF] = ACTIONS(4630),
    [anon_sym_If] = ACTIONS(4630),
    [anon_sym_else] = ACTIONS(4630),
    [anon_sym_ELSE] = ACTIONS(4630),
    [anon_sym_Else] = ACTIONS(4630),
    [anon_sym_case] = ACTIONS(4630),
    [anon_sym_CASE] = ACTIONS(4630),
    [anon_sym_Case] = ACTIONS(4630),
    [anon_sym_for] = ACTIONS(4630),
    [anon_sym_FOR] = ACTIONS(4630),
    [anon_sym_For] = ACTIONS(4630),
    [anon_sym_foreach] = ACTIONS(4630),
    [anon_sym_FOREACH] = ACTIONS(4630),
    [anon_sym_Foreach] = ACTIONS(4630),
    [anon_sym_while] = ACTIONS(4630),
    [anon_sym_WHILE] = ACTIONS(4630),
    [anon_sym_While] = ACTIONS(4630),
    [anon_sym_repeat] = ACTIONS(4630),
    [anon_sym_REPEAT] = ACTIONS(4630),
    [anon_sym_Repeat] = ACTIONS(4630),
    [anon_sym_until] = ACTIONS(4630),
    [anon_sym_UNTIL] = ACTIONS(4630),
    [anon_sym_Until] = ACTIONS(4630),
    [anon_sym_exit] = ACTIONS(4630),
    [anon_sym_EXIT] = ACTIONS(4630),
    [anon_sym_Exit] = ACTIONS(4630),
    [anon_sym_continue] = ACTIONS(4630),
    [anon_sym_CONTINUE] = ACTIONS(4630),
    [anon_sym_Continue] = ACTIONS(4630),
    [anon_sym_break] = ACTIONS(4630),
    [anon_sym_BREAK] = ACTIONS(4630),
    [anon_sym_Break] = ACTIONS(4630),
    [anon_sym_with] = ACTIONS(4630),
    [anon_sym_WITH] = ACTIONS(4630),
    [anon_sym_With] = ACTIONS(4630),
    [sym_asserterror_keyword] = ACTIONS(4632),
    [sym_page_keyword] = ACTIONS(4630),
    [anon_sym_codeunit] = ACTIONS(4630),
    [anon_sym_CODEUNIT] = ACTIONS(4630),
    [anon_sym_Codeunit] = ACTIONS(4630),
    [anon_sym_CodeUnit] = ACTIONS(4630),
    [anon_sym_COdeunit] = ACTIONS(4630),
    [anon_sym_codeUnit] = ACTIONS(4630),
    [sym_report_keyword] = ACTIONS(4630),
    [sym_query_keyword] = ACTIONS(4630),
    [anon_sym_xmlport] = ACTIONS(4630),
    [anon_sym_XMLPORT] = ACTIONS(4630),
    [anon_sym_Xmlport] = ACTIONS(4630),
    [anon_sym_XMLport] = ACTIONS(4630),
    [anon_sym_XMLPort] = ACTIONS(4630),
    [anon_sym_XmlPort] = ACTIONS(4630),
    [anon_sym_enum] = ACTIONS(4630),
    [anon_sym_ENUM] = ACTIONS(4630),
    [anon_sym_Enum] = ACTIONS(4630),
    [anon_sym_eNUM] = ACTIONS(4630),
    [anon_sym_eNum] = ACTIONS(4630),
    [anon_sym_ENum] = ACTIONS(4630),
    [sym_quoted_identifier] = ACTIONS(4632),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4632),
    [sym_integer] = ACTIONS(4630),
    [sym_continue_as_identifier] = ACTIONS(4632),
    [sym_preproc_open] = ACTIONS(4632),
  },
  [STATE(1919)] = {
    [sym_identifier] = ACTIONS(4634),
    [anon_sym_SEMI] = ACTIONS(4636),
    [anon_sym_DASH] = ACTIONS(4636),
    [aux_sym_boolean_token1] = ACTIONS(4634),
    [aux_sym_boolean_token2] = ACTIONS(4634),
    [sym_decimal] = ACTIONS(4634),
    [anon_sym_LPAREN] = ACTIONS(4636),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4634),
    [anon_sym_LBRACK] = ACTIONS(4636),
    [aux_sym_record_type_token1] = ACTIONS(4634),
    [aux_sym_basic_type_token21] = ACTIONS(4634),
    [aux_sym_basic_type_token22] = ACTIONS(4634),
    [aux_sym_basic_type_token48] = ACTIONS(4634),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4634),
    [anon_sym_POUNDif] = ACTIONS(4636),
    [anon_sym_POUNDIF] = ACTIONS(4636),
    [anon_sym_POUNDIf] = ACTIONS(4636),
    [anon_sym_not] = ACTIONS(4634),
    [anon_sym_NOT] = ACTIONS(4634),
    [anon_sym_Not] = ACTIONS(4634),
    [anon_sym_POUNDelse] = ACTIONS(4636),
    [anon_sym_POUNDELSE] = ACTIONS(4636),
    [anon_sym_POUNDElse] = ACTIONS(4636),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4634),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4634),
    [anon_sym_PLUS] = ACTIONS(4636),
    [sym_datetime_literal] = ACTIONS(4636),
    [sym_date_literal] = ACTIONS(4634),
    [sym_time_literal] = ACTIONS(4634),
    [sym_biginteger_literal] = ACTIONS(4636),
    [anon_sym_if] = ACTIONS(4634),
    [anon_sym_IF] = ACTIONS(4634),
    [anon_sym_If] = ACTIONS(4634),
    [anon_sym_else] = ACTIONS(4634),
    [anon_sym_ELSE] = ACTIONS(4634),
    [anon_sym_Else] = ACTIONS(4634),
    [anon_sym_case] = ACTIONS(4634),
    [anon_sym_CASE] = ACTIONS(4634),
    [anon_sym_Case] = ACTIONS(4634),
    [anon_sym_for] = ACTIONS(4634),
    [anon_sym_FOR] = ACTIONS(4634),
    [anon_sym_For] = ACTIONS(4634),
    [anon_sym_foreach] = ACTIONS(4634),
    [anon_sym_FOREACH] = ACTIONS(4634),
    [anon_sym_Foreach] = ACTIONS(4634),
    [anon_sym_while] = ACTIONS(4634),
    [anon_sym_WHILE] = ACTIONS(4634),
    [anon_sym_While] = ACTIONS(4634),
    [anon_sym_repeat] = ACTIONS(4634),
    [anon_sym_REPEAT] = ACTIONS(4634),
    [anon_sym_Repeat] = ACTIONS(4634),
    [anon_sym_until] = ACTIONS(4634),
    [anon_sym_UNTIL] = ACTIONS(4634),
    [anon_sym_Until] = ACTIONS(4634),
    [anon_sym_exit] = ACTIONS(4634),
    [anon_sym_EXIT] = ACTIONS(4634),
    [anon_sym_Exit] = ACTIONS(4634),
    [anon_sym_continue] = ACTIONS(4634),
    [anon_sym_CONTINUE] = ACTIONS(4634),
    [anon_sym_Continue] = ACTIONS(4634),
    [anon_sym_break] = ACTIONS(4634),
    [anon_sym_BREAK] = ACTIONS(4634),
    [anon_sym_Break] = ACTIONS(4634),
    [anon_sym_with] = ACTIONS(4634),
    [anon_sym_WITH] = ACTIONS(4634),
    [anon_sym_With] = ACTIONS(4634),
    [sym_asserterror_keyword] = ACTIONS(4636),
    [sym_page_keyword] = ACTIONS(4634),
    [anon_sym_codeunit] = ACTIONS(4634),
    [anon_sym_CODEUNIT] = ACTIONS(4634),
    [anon_sym_Codeunit] = ACTIONS(4634),
    [anon_sym_CodeUnit] = ACTIONS(4634),
    [anon_sym_COdeunit] = ACTIONS(4634),
    [anon_sym_codeUnit] = ACTIONS(4634),
    [sym_report_keyword] = ACTIONS(4634),
    [sym_query_keyword] = ACTIONS(4634),
    [anon_sym_xmlport] = ACTIONS(4634),
    [anon_sym_XMLPORT] = ACTIONS(4634),
    [anon_sym_Xmlport] = ACTIONS(4634),
    [anon_sym_XMLport] = ACTIONS(4634),
    [anon_sym_XMLPort] = ACTIONS(4634),
    [anon_sym_XmlPort] = ACTIONS(4634),
    [anon_sym_enum] = ACTIONS(4634),
    [anon_sym_ENUM] = ACTIONS(4634),
    [anon_sym_Enum] = ACTIONS(4634),
    [anon_sym_eNUM] = ACTIONS(4634),
    [anon_sym_eNum] = ACTIONS(4634),
    [anon_sym_ENum] = ACTIONS(4634),
    [sym_quoted_identifier] = ACTIONS(4636),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4636),
    [sym_integer] = ACTIONS(4634),
    [sym_continue_as_identifier] = ACTIONS(4636),
    [sym_preproc_open] = ACTIONS(4636),
  },
  [STATE(1920)] = {
    [sym_identifier] = ACTIONS(4539),
    [anon_sym_SEMI] = ACTIONS(4541),
    [anon_sym_DASH] = ACTIONS(4541),
    [aux_sym_boolean_token1] = ACTIONS(4539),
    [aux_sym_boolean_token2] = ACTIONS(4539),
    [sym_decimal] = ACTIONS(4539),
    [anon_sym_LPAREN] = ACTIONS(4541),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4539),
    [anon_sym_LBRACK] = ACTIONS(4541),
    [aux_sym_record_type_token1] = ACTIONS(4539),
    [aux_sym_basic_type_token21] = ACTIONS(4539),
    [aux_sym_basic_type_token22] = ACTIONS(4539),
    [aux_sym_basic_type_token48] = ACTIONS(4539),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4539),
    [anon_sym_POUNDif] = ACTIONS(4541),
    [anon_sym_POUNDIF] = ACTIONS(4541),
    [anon_sym_POUNDIf] = ACTIONS(4541),
    [anon_sym_not] = ACTIONS(4539),
    [anon_sym_NOT] = ACTIONS(4539),
    [anon_sym_Not] = ACTIONS(4539),
    [anon_sym_POUNDelse] = ACTIONS(4541),
    [anon_sym_POUNDELSE] = ACTIONS(4541),
    [anon_sym_POUNDElse] = ACTIONS(4541),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4539),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4539),
    [anon_sym_PLUS] = ACTIONS(4541),
    [sym_datetime_literal] = ACTIONS(4541),
    [sym_date_literal] = ACTIONS(4539),
    [sym_time_literal] = ACTIONS(4539),
    [sym_biginteger_literal] = ACTIONS(4541),
    [anon_sym_if] = ACTIONS(4539),
    [anon_sym_IF] = ACTIONS(4539),
    [anon_sym_If] = ACTIONS(4539),
    [anon_sym_else] = ACTIONS(4539),
    [anon_sym_ELSE] = ACTIONS(4539),
    [anon_sym_Else] = ACTIONS(4539),
    [anon_sym_case] = ACTIONS(4539),
    [anon_sym_CASE] = ACTIONS(4539),
    [anon_sym_Case] = ACTIONS(4539),
    [anon_sym_for] = ACTIONS(4539),
    [anon_sym_FOR] = ACTIONS(4539),
    [anon_sym_For] = ACTIONS(4539),
    [anon_sym_foreach] = ACTIONS(4539),
    [anon_sym_FOREACH] = ACTIONS(4539),
    [anon_sym_Foreach] = ACTIONS(4539),
    [anon_sym_while] = ACTIONS(4539),
    [anon_sym_WHILE] = ACTIONS(4539),
    [anon_sym_While] = ACTIONS(4539),
    [anon_sym_repeat] = ACTIONS(4539),
    [anon_sym_REPEAT] = ACTIONS(4539),
    [anon_sym_Repeat] = ACTIONS(4539),
    [anon_sym_until] = ACTIONS(4539),
    [anon_sym_UNTIL] = ACTIONS(4539),
    [anon_sym_Until] = ACTIONS(4539),
    [anon_sym_exit] = ACTIONS(4539),
    [anon_sym_EXIT] = ACTIONS(4539),
    [anon_sym_Exit] = ACTIONS(4539),
    [anon_sym_continue] = ACTIONS(4539),
    [anon_sym_CONTINUE] = ACTIONS(4539),
    [anon_sym_Continue] = ACTIONS(4539),
    [anon_sym_break] = ACTIONS(4539),
    [anon_sym_BREAK] = ACTIONS(4539),
    [anon_sym_Break] = ACTIONS(4539),
    [anon_sym_with] = ACTIONS(4539),
    [anon_sym_WITH] = ACTIONS(4539),
    [anon_sym_With] = ACTIONS(4539),
    [sym_asserterror_keyword] = ACTIONS(4541),
    [sym_page_keyword] = ACTIONS(4539),
    [anon_sym_codeunit] = ACTIONS(4539),
    [anon_sym_CODEUNIT] = ACTIONS(4539),
    [anon_sym_Codeunit] = ACTIONS(4539),
    [anon_sym_CodeUnit] = ACTIONS(4539),
    [anon_sym_COdeunit] = ACTIONS(4539),
    [anon_sym_codeUnit] = ACTIONS(4539),
    [sym_report_keyword] = ACTIONS(4539),
    [sym_query_keyword] = ACTIONS(4539),
    [anon_sym_xmlport] = ACTIONS(4539),
    [anon_sym_XMLPORT] = ACTIONS(4539),
    [anon_sym_Xmlport] = ACTIONS(4539),
    [anon_sym_XMLport] = ACTIONS(4539),
    [anon_sym_XMLPort] = ACTIONS(4539),
    [anon_sym_XmlPort] = ACTIONS(4539),
    [anon_sym_enum] = ACTIONS(4539),
    [anon_sym_ENUM] = ACTIONS(4539),
    [anon_sym_Enum] = ACTIONS(4539),
    [anon_sym_eNUM] = ACTIONS(4539),
    [anon_sym_eNum] = ACTIONS(4539),
    [anon_sym_ENum] = ACTIONS(4539),
    [sym_quoted_identifier] = ACTIONS(4541),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4541),
    [sym_integer] = ACTIONS(4539),
    [sym_continue_as_identifier] = ACTIONS(4541),
    [sym_preproc_open] = ACTIONS(4541),
  },
  [STATE(1921)] = {
    [sym_identifier] = ACTIONS(4543),
    [anon_sym_SEMI] = ACTIONS(4545),
    [anon_sym_DASH] = ACTIONS(4545),
    [aux_sym_boolean_token1] = ACTIONS(4543),
    [aux_sym_boolean_token2] = ACTIONS(4543),
    [sym_decimal] = ACTIONS(4543),
    [anon_sym_LPAREN] = ACTIONS(4545),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4543),
    [anon_sym_LBRACK] = ACTIONS(4545),
    [aux_sym_record_type_token1] = ACTIONS(4543),
    [aux_sym_basic_type_token21] = ACTIONS(4543),
    [aux_sym_basic_type_token22] = ACTIONS(4543),
    [aux_sym_basic_type_token48] = ACTIONS(4543),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4543),
    [anon_sym_POUNDif] = ACTIONS(4545),
    [anon_sym_POUNDIF] = ACTIONS(4545),
    [anon_sym_POUNDIf] = ACTIONS(4545),
    [anon_sym_not] = ACTIONS(4543),
    [anon_sym_NOT] = ACTIONS(4543),
    [anon_sym_Not] = ACTIONS(4543),
    [anon_sym_POUNDelse] = ACTIONS(4545),
    [anon_sym_POUNDELSE] = ACTIONS(4545),
    [anon_sym_POUNDElse] = ACTIONS(4545),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4543),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4543),
    [anon_sym_PLUS] = ACTIONS(4545),
    [sym_datetime_literal] = ACTIONS(4545),
    [sym_date_literal] = ACTIONS(4543),
    [sym_time_literal] = ACTIONS(4543),
    [sym_biginteger_literal] = ACTIONS(4545),
    [anon_sym_if] = ACTIONS(4543),
    [anon_sym_IF] = ACTIONS(4543),
    [anon_sym_If] = ACTIONS(4543),
    [anon_sym_else] = ACTIONS(4543),
    [anon_sym_ELSE] = ACTIONS(4543),
    [anon_sym_Else] = ACTIONS(4543),
    [anon_sym_case] = ACTIONS(4543),
    [anon_sym_CASE] = ACTIONS(4543),
    [anon_sym_Case] = ACTIONS(4543),
    [anon_sym_for] = ACTIONS(4543),
    [anon_sym_FOR] = ACTIONS(4543),
    [anon_sym_For] = ACTIONS(4543),
    [anon_sym_foreach] = ACTIONS(4543),
    [anon_sym_FOREACH] = ACTIONS(4543),
    [anon_sym_Foreach] = ACTIONS(4543),
    [anon_sym_while] = ACTIONS(4543),
    [anon_sym_WHILE] = ACTIONS(4543),
    [anon_sym_While] = ACTIONS(4543),
    [anon_sym_repeat] = ACTIONS(4543),
    [anon_sym_REPEAT] = ACTIONS(4543),
    [anon_sym_Repeat] = ACTIONS(4543),
    [anon_sym_until] = ACTIONS(4543),
    [anon_sym_UNTIL] = ACTIONS(4543),
    [anon_sym_Until] = ACTIONS(4543),
    [anon_sym_exit] = ACTIONS(4543),
    [anon_sym_EXIT] = ACTIONS(4543),
    [anon_sym_Exit] = ACTIONS(4543),
    [anon_sym_continue] = ACTIONS(4543),
    [anon_sym_CONTINUE] = ACTIONS(4543),
    [anon_sym_Continue] = ACTIONS(4543),
    [anon_sym_break] = ACTIONS(4543),
    [anon_sym_BREAK] = ACTIONS(4543),
    [anon_sym_Break] = ACTIONS(4543),
    [anon_sym_with] = ACTIONS(4543),
    [anon_sym_WITH] = ACTIONS(4543),
    [anon_sym_With] = ACTIONS(4543),
    [sym_asserterror_keyword] = ACTIONS(4545),
    [sym_page_keyword] = ACTIONS(4543),
    [anon_sym_codeunit] = ACTIONS(4543),
    [anon_sym_CODEUNIT] = ACTIONS(4543),
    [anon_sym_Codeunit] = ACTIONS(4543),
    [anon_sym_CodeUnit] = ACTIONS(4543),
    [anon_sym_COdeunit] = ACTIONS(4543),
    [anon_sym_codeUnit] = ACTIONS(4543),
    [sym_report_keyword] = ACTIONS(4543),
    [sym_query_keyword] = ACTIONS(4543),
    [anon_sym_xmlport] = ACTIONS(4543),
    [anon_sym_XMLPORT] = ACTIONS(4543),
    [anon_sym_Xmlport] = ACTIONS(4543),
    [anon_sym_XMLport] = ACTIONS(4543),
    [anon_sym_XMLPort] = ACTIONS(4543),
    [anon_sym_XmlPort] = ACTIONS(4543),
    [anon_sym_enum] = ACTIONS(4543),
    [anon_sym_ENUM] = ACTIONS(4543),
    [anon_sym_Enum] = ACTIONS(4543),
    [anon_sym_eNUM] = ACTIONS(4543),
    [anon_sym_eNum] = ACTIONS(4543),
    [anon_sym_ENum] = ACTIONS(4543),
    [sym_quoted_identifier] = ACTIONS(4545),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4545),
    [sym_integer] = ACTIONS(4543),
    [sym_continue_as_identifier] = ACTIONS(4545),
    [sym_preproc_open] = ACTIONS(4545),
  },
  [STATE(1922)] = {
    [sym_identifier] = ACTIONS(4638),
    [anon_sym_SEMI] = ACTIONS(4640),
    [anon_sym_DASH] = ACTIONS(4640),
    [aux_sym_boolean_token1] = ACTIONS(4638),
    [aux_sym_boolean_token2] = ACTIONS(4638),
    [sym_decimal] = ACTIONS(4638),
    [anon_sym_LPAREN] = ACTIONS(4640),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4638),
    [anon_sym_LBRACK] = ACTIONS(4640),
    [aux_sym_record_type_token1] = ACTIONS(4638),
    [aux_sym_basic_type_token21] = ACTIONS(4638),
    [aux_sym_basic_type_token22] = ACTIONS(4638),
    [aux_sym_basic_type_token48] = ACTIONS(4638),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4638),
    [anon_sym_POUNDif] = ACTIONS(4640),
    [anon_sym_POUNDIF] = ACTIONS(4640),
    [anon_sym_POUNDIf] = ACTIONS(4640),
    [anon_sym_not] = ACTIONS(4638),
    [anon_sym_NOT] = ACTIONS(4638),
    [anon_sym_Not] = ACTIONS(4638),
    [anon_sym_POUNDelse] = ACTIONS(4640),
    [anon_sym_POUNDELSE] = ACTIONS(4640),
    [anon_sym_POUNDElse] = ACTIONS(4640),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4638),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4638),
    [anon_sym_PLUS] = ACTIONS(4640),
    [sym_datetime_literal] = ACTIONS(4640),
    [sym_date_literal] = ACTIONS(4638),
    [sym_time_literal] = ACTIONS(4638),
    [sym_biginteger_literal] = ACTIONS(4640),
    [anon_sym_if] = ACTIONS(4638),
    [anon_sym_IF] = ACTIONS(4638),
    [anon_sym_If] = ACTIONS(4638),
    [anon_sym_else] = ACTIONS(4638),
    [anon_sym_ELSE] = ACTIONS(4638),
    [anon_sym_Else] = ACTIONS(4638),
    [anon_sym_case] = ACTIONS(4638),
    [anon_sym_CASE] = ACTIONS(4638),
    [anon_sym_Case] = ACTIONS(4638),
    [anon_sym_for] = ACTIONS(4638),
    [anon_sym_FOR] = ACTIONS(4638),
    [anon_sym_For] = ACTIONS(4638),
    [anon_sym_foreach] = ACTIONS(4638),
    [anon_sym_FOREACH] = ACTIONS(4638),
    [anon_sym_Foreach] = ACTIONS(4638),
    [anon_sym_while] = ACTIONS(4638),
    [anon_sym_WHILE] = ACTIONS(4638),
    [anon_sym_While] = ACTIONS(4638),
    [anon_sym_repeat] = ACTIONS(4638),
    [anon_sym_REPEAT] = ACTIONS(4638),
    [anon_sym_Repeat] = ACTIONS(4638),
    [anon_sym_until] = ACTIONS(4638),
    [anon_sym_UNTIL] = ACTIONS(4638),
    [anon_sym_Until] = ACTIONS(4638),
    [anon_sym_exit] = ACTIONS(4638),
    [anon_sym_EXIT] = ACTIONS(4638),
    [anon_sym_Exit] = ACTIONS(4638),
    [anon_sym_continue] = ACTIONS(4638),
    [anon_sym_CONTINUE] = ACTIONS(4638),
    [anon_sym_Continue] = ACTIONS(4638),
    [anon_sym_break] = ACTIONS(4638),
    [anon_sym_BREAK] = ACTIONS(4638),
    [anon_sym_Break] = ACTIONS(4638),
    [anon_sym_with] = ACTIONS(4638),
    [anon_sym_WITH] = ACTIONS(4638),
    [anon_sym_With] = ACTIONS(4638),
    [sym_asserterror_keyword] = ACTIONS(4640),
    [sym_page_keyword] = ACTIONS(4638),
    [anon_sym_codeunit] = ACTIONS(4638),
    [anon_sym_CODEUNIT] = ACTIONS(4638),
    [anon_sym_Codeunit] = ACTIONS(4638),
    [anon_sym_CodeUnit] = ACTIONS(4638),
    [anon_sym_COdeunit] = ACTIONS(4638),
    [anon_sym_codeUnit] = ACTIONS(4638),
    [sym_report_keyword] = ACTIONS(4638),
    [sym_query_keyword] = ACTIONS(4638),
    [anon_sym_xmlport] = ACTIONS(4638),
    [anon_sym_XMLPORT] = ACTIONS(4638),
    [anon_sym_Xmlport] = ACTIONS(4638),
    [anon_sym_XMLport] = ACTIONS(4638),
    [anon_sym_XMLPort] = ACTIONS(4638),
    [anon_sym_XmlPort] = ACTIONS(4638),
    [anon_sym_enum] = ACTIONS(4638),
    [anon_sym_ENUM] = ACTIONS(4638),
    [anon_sym_Enum] = ACTIONS(4638),
    [anon_sym_eNUM] = ACTIONS(4638),
    [anon_sym_eNum] = ACTIONS(4638),
    [anon_sym_ENum] = ACTIONS(4638),
    [sym_quoted_identifier] = ACTIONS(4640),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4640),
    [sym_integer] = ACTIONS(4638),
    [sym_continue_as_identifier] = ACTIONS(4640),
    [sym_preproc_open] = ACTIONS(4640),
  },
  [STATE(1923)] = {
    [sym_identifier] = ACTIONS(4642),
    [anon_sym_SEMI] = ACTIONS(4644),
    [anon_sym_DASH] = ACTIONS(4644),
    [aux_sym_boolean_token1] = ACTIONS(4642),
    [aux_sym_boolean_token2] = ACTIONS(4642),
    [sym_decimal] = ACTIONS(4642),
    [anon_sym_LPAREN] = ACTIONS(4644),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4642),
    [anon_sym_LBRACK] = ACTIONS(4644),
    [aux_sym_record_type_token1] = ACTIONS(4642),
    [aux_sym_basic_type_token21] = ACTIONS(4642),
    [aux_sym_basic_type_token22] = ACTIONS(4642),
    [aux_sym_basic_type_token48] = ACTIONS(4642),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4642),
    [anon_sym_POUNDif] = ACTIONS(4644),
    [anon_sym_POUNDIF] = ACTIONS(4644),
    [anon_sym_POUNDIf] = ACTIONS(4644),
    [anon_sym_not] = ACTIONS(4642),
    [anon_sym_NOT] = ACTIONS(4642),
    [anon_sym_Not] = ACTIONS(4642),
    [anon_sym_POUNDelse] = ACTIONS(4644),
    [anon_sym_POUNDELSE] = ACTIONS(4644),
    [anon_sym_POUNDElse] = ACTIONS(4644),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4642),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4642),
    [anon_sym_PLUS] = ACTIONS(4644),
    [sym_datetime_literal] = ACTIONS(4644),
    [sym_date_literal] = ACTIONS(4642),
    [sym_time_literal] = ACTIONS(4642),
    [sym_biginteger_literal] = ACTIONS(4644),
    [anon_sym_if] = ACTIONS(4642),
    [anon_sym_IF] = ACTIONS(4642),
    [anon_sym_If] = ACTIONS(4642),
    [anon_sym_else] = ACTIONS(4642),
    [anon_sym_ELSE] = ACTIONS(4642),
    [anon_sym_Else] = ACTIONS(4642),
    [anon_sym_case] = ACTIONS(4642),
    [anon_sym_CASE] = ACTIONS(4642),
    [anon_sym_Case] = ACTIONS(4642),
    [anon_sym_for] = ACTIONS(4642),
    [anon_sym_FOR] = ACTIONS(4642),
    [anon_sym_For] = ACTIONS(4642),
    [anon_sym_foreach] = ACTIONS(4642),
    [anon_sym_FOREACH] = ACTIONS(4642),
    [anon_sym_Foreach] = ACTIONS(4642),
    [anon_sym_while] = ACTIONS(4642),
    [anon_sym_WHILE] = ACTIONS(4642),
    [anon_sym_While] = ACTIONS(4642),
    [anon_sym_repeat] = ACTIONS(4642),
    [anon_sym_REPEAT] = ACTIONS(4642),
    [anon_sym_Repeat] = ACTIONS(4642),
    [anon_sym_until] = ACTIONS(4642),
    [anon_sym_UNTIL] = ACTIONS(4642),
    [anon_sym_Until] = ACTIONS(4642),
    [anon_sym_exit] = ACTIONS(4642),
    [anon_sym_EXIT] = ACTIONS(4642),
    [anon_sym_Exit] = ACTIONS(4642),
    [anon_sym_continue] = ACTIONS(4642),
    [anon_sym_CONTINUE] = ACTIONS(4642),
    [anon_sym_Continue] = ACTIONS(4642),
    [anon_sym_break] = ACTIONS(4642),
    [anon_sym_BREAK] = ACTIONS(4642),
    [anon_sym_Break] = ACTIONS(4642),
    [anon_sym_with] = ACTIONS(4642),
    [anon_sym_WITH] = ACTIONS(4642),
    [anon_sym_With] = ACTIONS(4642),
    [sym_asserterror_keyword] = ACTIONS(4644),
    [sym_page_keyword] = ACTIONS(4642),
    [anon_sym_codeunit] = ACTIONS(4642),
    [anon_sym_CODEUNIT] = ACTIONS(4642),
    [anon_sym_Codeunit] = ACTIONS(4642),
    [anon_sym_CodeUnit] = ACTIONS(4642),
    [anon_sym_COdeunit] = ACTIONS(4642),
    [anon_sym_codeUnit] = ACTIONS(4642),
    [sym_report_keyword] = ACTIONS(4642),
    [sym_query_keyword] = ACTIONS(4642),
    [anon_sym_xmlport] = ACTIONS(4642),
    [anon_sym_XMLPORT] = ACTIONS(4642),
    [anon_sym_Xmlport] = ACTIONS(4642),
    [anon_sym_XMLport] = ACTIONS(4642),
    [anon_sym_XMLPort] = ACTIONS(4642),
    [anon_sym_XmlPort] = ACTIONS(4642),
    [anon_sym_enum] = ACTIONS(4642),
    [anon_sym_ENUM] = ACTIONS(4642),
    [anon_sym_Enum] = ACTIONS(4642),
    [anon_sym_eNUM] = ACTIONS(4642),
    [anon_sym_eNum] = ACTIONS(4642),
    [anon_sym_ENum] = ACTIONS(4642),
    [sym_quoted_identifier] = ACTIONS(4644),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4644),
    [sym_integer] = ACTIONS(4642),
    [sym_continue_as_identifier] = ACTIONS(4644),
    [sym_preproc_open] = ACTIONS(4644),
  },
  [STATE(1924)] = {
    [sym_identifier] = ACTIONS(4547),
    [anon_sym_SEMI] = ACTIONS(4549),
    [anon_sym_DASH] = ACTIONS(4549),
    [aux_sym_boolean_token1] = ACTIONS(4547),
    [aux_sym_boolean_token2] = ACTIONS(4547),
    [sym_decimal] = ACTIONS(4547),
    [anon_sym_LPAREN] = ACTIONS(4549),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4547),
    [anon_sym_LBRACK] = ACTIONS(4549),
    [aux_sym_record_type_token1] = ACTIONS(4547),
    [aux_sym_basic_type_token21] = ACTIONS(4547),
    [aux_sym_basic_type_token22] = ACTIONS(4547),
    [aux_sym_basic_type_token48] = ACTIONS(4547),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4547),
    [anon_sym_POUNDif] = ACTIONS(4549),
    [anon_sym_POUNDIF] = ACTIONS(4549),
    [anon_sym_POUNDIf] = ACTIONS(4549),
    [anon_sym_not] = ACTIONS(4547),
    [anon_sym_NOT] = ACTIONS(4547),
    [anon_sym_Not] = ACTIONS(4547),
    [anon_sym_POUNDelse] = ACTIONS(4549),
    [anon_sym_POUNDELSE] = ACTIONS(4549),
    [anon_sym_POUNDElse] = ACTIONS(4549),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4547),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4547),
    [anon_sym_PLUS] = ACTIONS(4549),
    [sym_datetime_literal] = ACTIONS(4549),
    [sym_date_literal] = ACTIONS(4547),
    [sym_time_literal] = ACTIONS(4547),
    [sym_biginteger_literal] = ACTIONS(4549),
    [anon_sym_if] = ACTIONS(4547),
    [anon_sym_IF] = ACTIONS(4547),
    [anon_sym_If] = ACTIONS(4547),
    [anon_sym_else] = ACTIONS(4547),
    [anon_sym_ELSE] = ACTIONS(4547),
    [anon_sym_Else] = ACTIONS(4547),
    [anon_sym_case] = ACTIONS(4547),
    [anon_sym_CASE] = ACTIONS(4547),
    [anon_sym_Case] = ACTIONS(4547),
    [anon_sym_for] = ACTIONS(4547),
    [anon_sym_FOR] = ACTIONS(4547),
    [anon_sym_For] = ACTIONS(4547),
    [anon_sym_foreach] = ACTIONS(4547),
    [anon_sym_FOREACH] = ACTIONS(4547),
    [anon_sym_Foreach] = ACTIONS(4547),
    [anon_sym_while] = ACTIONS(4547),
    [anon_sym_WHILE] = ACTIONS(4547),
    [anon_sym_While] = ACTIONS(4547),
    [anon_sym_repeat] = ACTIONS(4547),
    [anon_sym_REPEAT] = ACTIONS(4547),
    [anon_sym_Repeat] = ACTIONS(4547),
    [anon_sym_until] = ACTIONS(4547),
    [anon_sym_UNTIL] = ACTIONS(4547),
    [anon_sym_Until] = ACTIONS(4547),
    [anon_sym_exit] = ACTIONS(4547),
    [anon_sym_EXIT] = ACTIONS(4547),
    [anon_sym_Exit] = ACTIONS(4547),
    [anon_sym_continue] = ACTIONS(4547),
    [anon_sym_CONTINUE] = ACTIONS(4547),
    [anon_sym_Continue] = ACTIONS(4547),
    [anon_sym_break] = ACTIONS(4547),
    [anon_sym_BREAK] = ACTIONS(4547),
    [anon_sym_Break] = ACTIONS(4547),
    [anon_sym_with] = ACTIONS(4547),
    [anon_sym_WITH] = ACTIONS(4547),
    [anon_sym_With] = ACTIONS(4547),
    [sym_asserterror_keyword] = ACTIONS(4549),
    [sym_page_keyword] = ACTIONS(4547),
    [anon_sym_codeunit] = ACTIONS(4547),
    [anon_sym_CODEUNIT] = ACTIONS(4547),
    [anon_sym_Codeunit] = ACTIONS(4547),
    [anon_sym_CodeUnit] = ACTIONS(4547),
    [anon_sym_COdeunit] = ACTIONS(4547),
    [anon_sym_codeUnit] = ACTIONS(4547),
    [sym_report_keyword] = ACTIONS(4547),
    [sym_query_keyword] = ACTIONS(4547),
    [anon_sym_xmlport] = ACTIONS(4547),
    [anon_sym_XMLPORT] = ACTIONS(4547),
    [anon_sym_Xmlport] = ACTIONS(4547),
    [anon_sym_XMLport] = ACTIONS(4547),
    [anon_sym_XMLPort] = ACTIONS(4547),
    [anon_sym_XmlPort] = ACTIONS(4547),
    [anon_sym_enum] = ACTIONS(4547),
    [anon_sym_ENUM] = ACTIONS(4547),
    [anon_sym_Enum] = ACTIONS(4547),
    [anon_sym_eNUM] = ACTIONS(4547),
    [anon_sym_eNum] = ACTIONS(4547),
    [anon_sym_ENum] = ACTIONS(4547),
    [sym_quoted_identifier] = ACTIONS(4549),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4549),
    [sym_integer] = ACTIONS(4547),
    [sym_continue_as_identifier] = ACTIONS(4549),
    [sym_preproc_open] = ACTIONS(4549),
  },
  [STATE(1925)] = {
    [sym_identifier] = ACTIONS(4551),
    [anon_sym_SEMI] = ACTIONS(4553),
    [anon_sym_DASH] = ACTIONS(4553),
    [aux_sym_boolean_token1] = ACTIONS(4551),
    [aux_sym_boolean_token2] = ACTIONS(4551),
    [sym_decimal] = ACTIONS(4551),
    [anon_sym_LPAREN] = ACTIONS(4553),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4551),
    [anon_sym_LBRACK] = ACTIONS(4553),
    [aux_sym_record_type_token1] = ACTIONS(4551),
    [aux_sym_basic_type_token21] = ACTIONS(4551),
    [aux_sym_basic_type_token22] = ACTIONS(4551),
    [aux_sym_basic_type_token48] = ACTIONS(4551),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4551),
    [anon_sym_POUNDif] = ACTIONS(4553),
    [anon_sym_POUNDIF] = ACTIONS(4553),
    [anon_sym_POUNDIf] = ACTIONS(4553),
    [anon_sym_not] = ACTIONS(4551),
    [anon_sym_NOT] = ACTIONS(4551),
    [anon_sym_Not] = ACTIONS(4551),
    [anon_sym_POUNDelse] = ACTIONS(4553),
    [anon_sym_POUNDELSE] = ACTIONS(4553),
    [anon_sym_POUNDElse] = ACTIONS(4553),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4551),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4551),
    [anon_sym_PLUS] = ACTIONS(4553),
    [sym_datetime_literal] = ACTIONS(4553),
    [sym_date_literal] = ACTIONS(4551),
    [sym_time_literal] = ACTIONS(4551),
    [sym_biginteger_literal] = ACTIONS(4553),
    [anon_sym_if] = ACTIONS(4551),
    [anon_sym_IF] = ACTIONS(4551),
    [anon_sym_If] = ACTIONS(4551),
    [anon_sym_else] = ACTIONS(4551),
    [anon_sym_ELSE] = ACTIONS(4551),
    [anon_sym_Else] = ACTIONS(4551),
    [anon_sym_case] = ACTIONS(4551),
    [anon_sym_CASE] = ACTIONS(4551),
    [anon_sym_Case] = ACTIONS(4551),
    [anon_sym_for] = ACTIONS(4551),
    [anon_sym_FOR] = ACTIONS(4551),
    [anon_sym_For] = ACTIONS(4551),
    [anon_sym_foreach] = ACTIONS(4551),
    [anon_sym_FOREACH] = ACTIONS(4551),
    [anon_sym_Foreach] = ACTIONS(4551),
    [anon_sym_while] = ACTIONS(4551),
    [anon_sym_WHILE] = ACTIONS(4551),
    [anon_sym_While] = ACTIONS(4551),
    [anon_sym_repeat] = ACTIONS(4551),
    [anon_sym_REPEAT] = ACTIONS(4551),
    [anon_sym_Repeat] = ACTIONS(4551),
    [anon_sym_until] = ACTIONS(4551),
    [anon_sym_UNTIL] = ACTIONS(4551),
    [anon_sym_Until] = ACTIONS(4551),
    [anon_sym_exit] = ACTIONS(4551),
    [anon_sym_EXIT] = ACTIONS(4551),
    [anon_sym_Exit] = ACTIONS(4551),
    [anon_sym_continue] = ACTIONS(4551),
    [anon_sym_CONTINUE] = ACTIONS(4551),
    [anon_sym_Continue] = ACTIONS(4551),
    [anon_sym_break] = ACTIONS(4551),
    [anon_sym_BREAK] = ACTIONS(4551),
    [anon_sym_Break] = ACTIONS(4551),
    [anon_sym_with] = ACTIONS(4551),
    [anon_sym_WITH] = ACTIONS(4551),
    [anon_sym_With] = ACTIONS(4551),
    [sym_asserterror_keyword] = ACTIONS(4553),
    [sym_page_keyword] = ACTIONS(4551),
    [anon_sym_codeunit] = ACTIONS(4551),
    [anon_sym_CODEUNIT] = ACTIONS(4551),
    [anon_sym_Codeunit] = ACTIONS(4551),
    [anon_sym_CodeUnit] = ACTIONS(4551),
    [anon_sym_COdeunit] = ACTIONS(4551),
    [anon_sym_codeUnit] = ACTIONS(4551),
    [sym_report_keyword] = ACTIONS(4551),
    [sym_query_keyword] = ACTIONS(4551),
    [anon_sym_xmlport] = ACTIONS(4551),
    [anon_sym_XMLPORT] = ACTIONS(4551),
    [anon_sym_Xmlport] = ACTIONS(4551),
    [anon_sym_XMLport] = ACTIONS(4551),
    [anon_sym_XMLPort] = ACTIONS(4551),
    [anon_sym_XmlPort] = ACTIONS(4551),
    [anon_sym_enum] = ACTIONS(4551),
    [anon_sym_ENUM] = ACTIONS(4551),
    [anon_sym_Enum] = ACTIONS(4551),
    [anon_sym_eNUM] = ACTIONS(4551),
    [anon_sym_eNum] = ACTIONS(4551),
    [anon_sym_ENum] = ACTIONS(4551),
    [sym_quoted_identifier] = ACTIONS(4553),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4553),
    [sym_integer] = ACTIONS(4551),
    [sym_continue_as_identifier] = ACTIONS(4553),
    [sym_preproc_open] = ACTIONS(4553),
  },
  [STATE(1926)] = {
    [sym_identifier] = ACTIONS(4704),
    [anon_sym_SEMI] = ACTIONS(4706),
    [anon_sym_DASH] = ACTIONS(4706),
    [aux_sym_boolean_token1] = ACTIONS(4704),
    [aux_sym_boolean_token2] = ACTIONS(4704),
    [sym_decimal] = ACTIONS(4704),
    [anon_sym_LPAREN] = ACTIONS(4706),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4704),
    [anon_sym_LBRACK] = ACTIONS(4706),
    [aux_sym_record_type_token1] = ACTIONS(4704),
    [aux_sym_basic_type_token21] = ACTIONS(4704),
    [aux_sym_basic_type_token22] = ACTIONS(4704),
    [aux_sym_basic_type_token48] = ACTIONS(4704),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4704),
    [anon_sym_POUNDif] = ACTIONS(4706),
    [anon_sym_POUNDIF] = ACTIONS(4706),
    [anon_sym_POUNDIf] = ACTIONS(4706),
    [anon_sym_not] = ACTIONS(4704),
    [anon_sym_NOT] = ACTIONS(4704),
    [anon_sym_Not] = ACTIONS(4704),
    [anon_sym_POUNDelse] = ACTIONS(4706),
    [anon_sym_POUNDELSE] = ACTIONS(4706),
    [anon_sym_POUNDElse] = ACTIONS(4706),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4704),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4704),
    [anon_sym_PLUS] = ACTIONS(4706),
    [sym_datetime_literal] = ACTIONS(4706),
    [sym_date_literal] = ACTIONS(4704),
    [sym_time_literal] = ACTIONS(4704),
    [sym_biginteger_literal] = ACTIONS(4706),
    [anon_sym_if] = ACTIONS(4704),
    [anon_sym_IF] = ACTIONS(4704),
    [anon_sym_If] = ACTIONS(4704),
    [anon_sym_else] = ACTIONS(4704),
    [anon_sym_ELSE] = ACTIONS(4704),
    [anon_sym_Else] = ACTIONS(4704),
    [anon_sym_case] = ACTIONS(4704),
    [anon_sym_CASE] = ACTIONS(4704),
    [anon_sym_Case] = ACTIONS(4704),
    [anon_sym_for] = ACTIONS(4704),
    [anon_sym_FOR] = ACTIONS(4704),
    [anon_sym_For] = ACTIONS(4704),
    [anon_sym_foreach] = ACTIONS(4704),
    [anon_sym_FOREACH] = ACTIONS(4704),
    [anon_sym_Foreach] = ACTIONS(4704),
    [anon_sym_while] = ACTIONS(4704),
    [anon_sym_WHILE] = ACTIONS(4704),
    [anon_sym_While] = ACTIONS(4704),
    [anon_sym_repeat] = ACTIONS(4704),
    [anon_sym_REPEAT] = ACTIONS(4704),
    [anon_sym_Repeat] = ACTIONS(4704),
    [anon_sym_until] = ACTIONS(4704),
    [anon_sym_UNTIL] = ACTIONS(4704),
    [anon_sym_Until] = ACTIONS(4704),
    [anon_sym_exit] = ACTIONS(4704),
    [anon_sym_EXIT] = ACTIONS(4704),
    [anon_sym_Exit] = ACTIONS(4704),
    [anon_sym_continue] = ACTIONS(4704),
    [anon_sym_CONTINUE] = ACTIONS(4704),
    [anon_sym_Continue] = ACTIONS(4704),
    [anon_sym_break] = ACTIONS(4704),
    [anon_sym_BREAK] = ACTIONS(4704),
    [anon_sym_Break] = ACTIONS(4704),
    [anon_sym_with] = ACTIONS(4704),
    [anon_sym_WITH] = ACTIONS(4704),
    [anon_sym_With] = ACTIONS(4704),
    [sym_asserterror_keyword] = ACTIONS(4706),
    [sym_page_keyword] = ACTIONS(4704),
    [anon_sym_codeunit] = ACTIONS(4704),
    [anon_sym_CODEUNIT] = ACTIONS(4704),
    [anon_sym_Codeunit] = ACTIONS(4704),
    [anon_sym_CodeUnit] = ACTIONS(4704),
    [anon_sym_COdeunit] = ACTIONS(4704),
    [anon_sym_codeUnit] = ACTIONS(4704),
    [sym_report_keyword] = ACTIONS(4704),
    [sym_query_keyword] = ACTIONS(4704),
    [anon_sym_xmlport] = ACTIONS(4704),
    [anon_sym_XMLPORT] = ACTIONS(4704),
    [anon_sym_Xmlport] = ACTIONS(4704),
    [anon_sym_XMLport] = ACTIONS(4704),
    [anon_sym_XMLPort] = ACTIONS(4704),
    [anon_sym_XmlPort] = ACTIONS(4704),
    [anon_sym_enum] = ACTIONS(4704),
    [anon_sym_ENUM] = ACTIONS(4704),
    [anon_sym_Enum] = ACTIONS(4704),
    [anon_sym_eNUM] = ACTIONS(4704),
    [anon_sym_eNum] = ACTIONS(4704),
    [anon_sym_ENum] = ACTIONS(4704),
    [sym_quoted_identifier] = ACTIONS(4706),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4706),
    [sym_integer] = ACTIONS(4704),
    [sym_continue_as_identifier] = ACTIONS(4706),
    [sym_preproc_open] = ACTIONS(4706),
  },
  [STATE(1927)] = {
    [sym_identifier] = ACTIONS(4646),
    [anon_sym_SEMI] = ACTIONS(4648),
    [anon_sym_DASH] = ACTIONS(4648),
    [aux_sym_boolean_token1] = ACTIONS(4646),
    [aux_sym_boolean_token2] = ACTIONS(4646),
    [sym_decimal] = ACTIONS(4646),
    [anon_sym_LPAREN] = ACTIONS(4648),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4646),
    [anon_sym_LBRACK] = ACTIONS(4648),
    [aux_sym_record_type_token1] = ACTIONS(4646),
    [aux_sym_basic_type_token21] = ACTIONS(4646),
    [aux_sym_basic_type_token22] = ACTIONS(4646),
    [aux_sym_basic_type_token48] = ACTIONS(4646),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4646),
    [anon_sym_POUNDif] = ACTIONS(4648),
    [anon_sym_POUNDIF] = ACTIONS(4648),
    [anon_sym_POUNDIf] = ACTIONS(4648),
    [anon_sym_not] = ACTIONS(4646),
    [anon_sym_NOT] = ACTIONS(4646),
    [anon_sym_Not] = ACTIONS(4646),
    [anon_sym_POUNDelse] = ACTIONS(4648),
    [anon_sym_POUNDELSE] = ACTIONS(4648),
    [anon_sym_POUNDElse] = ACTIONS(4648),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4646),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4646),
    [anon_sym_PLUS] = ACTIONS(4648),
    [sym_datetime_literal] = ACTIONS(4648),
    [sym_date_literal] = ACTIONS(4646),
    [sym_time_literal] = ACTIONS(4646),
    [sym_biginteger_literal] = ACTIONS(4648),
    [anon_sym_if] = ACTIONS(4646),
    [anon_sym_IF] = ACTIONS(4646),
    [anon_sym_If] = ACTIONS(4646),
    [anon_sym_else] = ACTIONS(4646),
    [anon_sym_ELSE] = ACTIONS(4646),
    [anon_sym_Else] = ACTIONS(4646),
    [anon_sym_case] = ACTIONS(4646),
    [anon_sym_CASE] = ACTIONS(4646),
    [anon_sym_Case] = ACTIONS(4646),
    [anon_sym_for] = ACTIONS(4646),
    [anon_sym_FOR] = ACTIONS(4646),
    [anon_sym_For] = ACTIONS(4646),
    [anon_sym_foreach] = ACTIONS(4646),
    [anon_sym_FOREACH] = ACTIONS(4646),
    [anon_sym_Foreach] = ACTIONS(4646),
    [anon_sym_while] = ACTIONS(4646),
    [anon_sym_WHILE] = ACTIONS(4646),
    [anon_sym_While] = ACTIONS(4646),
    [anon_sym_repeat] = ACTIONS(4646),
    [anon_sym_REPEAT] = ACTIONS(4646),
    [anon_sym_Repeat] = ACTIONS(4646),
    [anon_sym_until] = ACTIONS(4646),
    [anon_sym_UNTIL] = ACTIONS(4646),
    [anon_sym_Until] = ACTIONS(4646),
    [anon_sym_exit] = ACTIONS(4646),
    [anon_sym_EXIT] = ACTIONS(4646),
    [anon_sym_Exit] = ACTIONS(4646),
    [anon_sym_continue] = ACTIONS(4646),
    [anon_sym_CONTINUE] = ACTIONS(4646),
    [anon_sym_Continue] = ACTIONS(4646),
    [anon_sym_break] = ACTIONS(4646),
    [anon_sym_BREAK] = ACTIONS(4646),
    [anon_sym_Break] = ACTIONS(4646),
    [anon_sym_with] = ACTIONS(4646),
    [anon_sym_WITH] = ACTIONS(4646),
    [anon_sym_With] = ACTIONS(4646),
    [sym_asserterror_keyword] = ACTIONS(4648),
    [sym_page_keyword] = ACTIONS(4646),
    [anon_sym_codeunit] = ACTIONS(4646),
    [anon_sym_CODEUNIT] = ACTIONS(4646),
    [anon_sym_Codeunit] = ACTIONS(4646),
    [anon_sym_CodeUnit] = ACTIONS(4646),
    [anon_sym_COdeunit] = ACTIONS(4646),
    [anon_sym_codeUnit] = ACTIONS(4646),
    [sym_report_keyword] = ACTIONS(4646),
    [sym_query_keyword] = ACTIONS(4646),
    [anon_sym_xmlport] = ACTIONS(4646),
    [anon_sym_XMLPORT] = ACTIONS(4646),
    [anon_sym_Xmlport] = ACTIONS(4646),
    [anon_sym_XMLport] = ACTIONS(4646),
    [anon_sym_XMLPort] = ACTIONS(4646),
    [anon_sym_XmlPort] = ACTIONS(4646),
    [anon_sym_enum] = ACTIONS(4646),
    [anon_sym_ENUM] = ACTIONS(4646),
    [anon_sym_Enum] = ACTIONS(4646),
    [anon_sym_eNUM] = ACTIONS(4646),
    [anon_sym_eNum] = ACTIONS(4646),
    [anon_sym_ENum] = ACTIONS(4646),
    [sym_quoted_identifier] = ACTIONS(4648),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4648),
    [sym_integer] = ACTIONS(4646),
    [sym_continue_as_identifier] = ACTIONS(4648),
    [sym_preproc_open] = ACTIONS(4648),
  },
  [STATE(1928)] = {
    [sym_identifier] = ACTIONS(4700),
    [anon_sym_SEMI] = ACTIONS(4702),
    [anon_sym_DASH] = ACTIONS(4702),
    [aux_sym_boolean_token1] = ACTIONS(4700),
    [aux_sym_boolean_token2] = ACTIONS(4700),
    [sym_decimal] = ACTIONS(4700),
    [anon_sym_LPAREN] = ACTIONS(4702),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4700),
    [anon_sym_LBRACK] = ACTIONS(4702),
    [aux_sym_record_type_token1] = ACTIONS(4700),
    [aux_sym_basic_type_token21] = ACTIONS(4700),
    [aux_sym_basic_type_token22] = ACTIONS(4700),
    [aux_sym_basic_type_token48] = ACTIONS(4700),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4700),
    [anon_sym_POUNDif] = ACTIONS(4702),
    [anon_sym_POUNDIF] = ACTIONS(4702),
    [anon_sym_POUNDIf] = ACTIONS(4702),
    [anon_sym_not] = ACTIONS(4700),
    [anon_sym_NOT] = ACTIONS(4700),
    [anon_sym_Not] = ACTIONS(4700),
    [anon_sym_POUNDelse] = ACTIONS(4702),
    [anon_sym_POUNDELSE] = ACTIONS(4702),
    [anon_sym_POUNDElse] = ACTIONS(4702),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4700),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4700),
    [anon_sym_PLUS] = ACTIONS(4702),
    [sym_datetime_literal] = ACTIONS(4702),
    [sym_date_literal] = ACTIONS(4700),
    [sym_time_literal] = ACTIONS(4700),
    [sym_biginteger_literal] = ACTIONS(4702),
    [anon_sym_if] = ACTIONS(4700),
    [anon_sym_IF] = ACTIONS(4700),
    [anon_sym_If] = ACTIONS(4700),
    [anon_sym_else] = ACTIONS(4700),
    [anon_sym_ELSE] = ACTIONS(4700),
    [anon_sym_Else] = ACTIONS(4700),
    [anon_sym_case] = ACTIONS(4700),
    [anon_sym_CASE] = ACTIONS(4700),
    [anon_sym_Case] = ACTIONS(4700),
    [anon_sym_for] = ACTIONS(4700),
    [anon_sym_FOR] = ACTIONS(4700),
    [anon_sym_For] = ACTIONS(4700),
    [anon_sym_foreach] = ACTIONS(4700),
    [anon_sym_FOREACH] = ACTIONS(4700),
    [anon_sym_Foreach] = ACTIONS(4700),
    [anon_sym_while] = ACTIONS(4700),
    [anon_sym_WHILE] = ACTIONS(4700),
    [anon_sym_While] = ACTIONS(4700),
    [anon_sym_repeat] = ACTIONS(4700),
    [anon_sym_REPEAT] = ACTIONS(4700),
    [anon_sym_Repeat] = ACTIONS(4700),
    [anon_sym_until] = ACTIONS(4700),
    [anon_sym_UNTIL] = ACTIONS(4700),
    [anon_sym_Until] = ACTIONS(4700),
    [anon_sym_exit] = ACTIONS(4700),
    [anon_sym_EXIT] = ACTIONS(4700),
    [anon_sym_Exit] = ACTIONS(4700),
    [anon_sym_continue] = ACTIONS(4700),
    [anon_sym_CONTINUE] = ACTIONS(4700),
    [anon_sym_Continue] = ACTIONS(4700),
    [anon_sym_break] = ACTIONS(4700),
    [anon_sym_BREAK] = ACTIONS(4700),
    [anon_sym_Break] = ACTIONS(4700),
    [anon_sym_with] = ACTIONS(4700),
    [anon_sym_WITH] = ACTIONS(4700),
    [anon_sym_With] = ACTIONS(4700),
    [sym_asserterror_keyword] = ACTIONS(4702),
    [sym_page_keyword] = ACTIONS(4700),
    [anon_sym_codeunit] = ACTIONS(4700),
    [anon_sym_CODEUNIT] = ACTIONS(4700),
    [anon_sym_Codeunit] = ACTIONS(4700),
    [anon_sym_CodeUnit] = ACTIONS(4700),
    [anon_sym_COdeunit] = ACTIONS(4700),
    [anon_sym_codeUnit] = ACTIONS(4700),
    [sym_report_keyword] = ACTIONS(4700),
    [sym_query_keyword] = ACTIONS(4700),
    [anon_sym_xmlport] = ACTIONS(4700),
    [anon_sym_XMLPORT] = ACTIONS(4700),
    [anon_sym_Xmlport] = ACTIONS(4700),
    [anon_sym_XMLport] = ACTIONS(4700),
    [anon_sym_XMLPort] = ACTIONS(4700),
    [anon_sym_XmlPort] = ACTIONS(4700),
    [anon_sym_enum] = ACTIONS(4700),
    [anon_sym_ENUM] = ACTIONS(4700),
    [anon_sym_Enum] = ACTIONS(4700),
    [anon_sym_eNUM] = ACTIONS(4700),
    [anon_sym_eNum] = ACTIONS(4700),
    [anon_sym_ENum] = ACTIONS(4700),
    [sym_quoted_identifier] = ACTIONS(4702),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4702),
    [sym_integer] = ACTIONS(4700),
    [sym_continue_as_identifier] = ACTIONS(4702),
    [sym_preproc_open] = ACTIONS(4702),
  },
  [STATE(1929)] = {
    [sym_identifier] = ACTIONS(4567),
    [anon_sym_SEMI] = ACTIONS(4891),
    [anon_sym_DASH] = ACTIONS(4571),
    [aux_sym_boolean_token1] = ACTIONS(4567),
    [aux_sym_boolean_token2] = ACTIONS(4567),
    [sym_decimal] = ACTIONS(4567),
    [anon_sym_LPAREN] = ACTIONS(4571),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4567),
    [anon_sym_LBRACK] = ACTIONS(4571),
    [aux_sym_record_type_token1] = ACTIONS(4567),
    [aux_sym_basic_type_token21] = ACTIONS(4567),
    [aux_sym_basic_type_token22] = ACTIONS(4567),
    [aux_sym_basic_type_token48] = ACTIONS(4567),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4567),
    [anon_sym_POUNDif] = ACTIONS(4571),
    [anon_sym_POUNDIF] = ACTIONS(4571),
    [anon_sym_POUNDIf] = ACTIONS(4571),
    [anon_sym_not] = ACTIONS(4567),
    [anon_sym_NOT] = ACTIONS(4567),
    [anon_sym_Not] = ACTIONS(4567),
    [anon_sym_POUNDelse] = ACTIONS(4571),
    [anon_sym_POUNDELSE] = ACTIONS(4571),
    [anon_sym_POUNDElse] = ACTIONS(4571),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4567),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4567),
    [anon_sym_PLUS] = ACTIONS(4571),
    [sym_datetime_literal] = ACTIONS(4571),
    [sym_date_literal] = ACTIONS(4567),
    [sym_time_literal] = ACTIONS(4567),
    [sym_biginteger_literal] = ACTIONS(4571),
    [anon_sym_if] = ACTIONS(4567),
    [anon_sym_IF] = ACTIONS(4567),
    [anon_sym_If] = ACTIONS(4567),
    [anon_sym_else] = ACTIONS(4567),
    [anon_sym_ELSE] = ACTIONS(4567),
    [anon_sym_Else] = ACTIONS(4567),
    [anon_sym_case] = ACTIONS(4567),
    [anon_sym_CASE] = ACTIONS(4567),
    [anon_sym_Case] = ACTIONS(4567),
    [anon_sym_for] = ACTIONS(4567),
    [anon_sym_FOR] = ACTIONS(4567),
    [anon_sym_For] = ACTIONS(4567),
    [anon_sym_foreach] = ACTIONS(4567),
    [anon_sym_FOREACH] = ACTIONS(4567),
    [anon_sym_Foreach] = ACTIONS(4567),
    [anon_sym_while] = ACTIONS(4567),
    [anon_sym_WHILE] = ACTIONS(4567),
    [anon_sym_While] = ACTIONS(4567),
    [anon_sym_repeat] = ACTIONS(4567),
    [anon_sym_REPEAT] = ACTIONS(4567),
    [anon_sym_Repeat] = ACTIONS(4567),
    [anon_sym_until] = ACTIONS(4567),
    [anon_sym_UNTIL] = ACTIONS(4567),
    [anon_sym_Until] = ACTIONS(4567),
    [anon_sym_exit] = ACTIONS(4567),
    [anon_sym_EXIT] = ACTIONS(4567),
    [anon_sym_Exit] = ACTIONS(4567),
    [anon_sym_continue] = ACTIONS(4567),
    [anon_sym_CONTINUE] = ACTIONS(4567),
    [anon_sym_Continue] = ACTIONS(4567),
    [anon_sym_break] = ACTIONS(4567),
    [anon_sym_BREAK] = ACTIONS(4567),
    [anon_sym_Break] = ACTIONS(4567),
    [anon_sym_with] = ACTIONS(4567),
    [anon_sym_WITH] = ACTIONS(4567),
    [anon_sym_With] = ACTIONS(4567),
    [sym_asserterror_keyword] = ACTIONS(4571),
    [sym_page_keyword] = ACTIONS(4567),
    [anon_sym_codeunit] = ACTIONS(4567),
    [anon_sym_CODEUNIT] = ACTIONS(4567),
    [anon_sym_Codeunit] = ACTIONS(4567),
    [anon_sym_CodeUnit] = ACTIONS(4567),
    [anon_sym_COdeunit] = ACTIONS(4567),
    [anon_sym_codeUnit] = ACTIONS(4567),
    [sym_report_keyword] = ACTIONS(4567),
    [sym_query_keyword] = ACTIONS(4567),
    [anon_sym_xmlport] = ACTIONS(4567),
    [anon_sym_XMLPORT] = ACTIONS(4567),
    [anon_sym_Xmlport] = ACTIONS(4567),
    [anon_sym_XMLport] = ACTIONS(4567),
    [anon_sym_XMLPort] = ACTIONS(4567),
    [anon_sym_XmlPort] = ACTIONS(4567),
    [anon_sym_enum] = ACTIONS(4567),
    [anon_sym_ENUM] = ACTIONS(4567),
    [anon_sym_Enum] = ACTIONS(4567),
    [anon_sym_eNUM] = ACTIONS(4567),
    [anon_sym_eNum] = ACTIONS(4567),
    [anon_sym_ENum] = ACTIONS(4567),
    [sym_quoted_identifier] = ACTIONS(4571),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4571),
    [sym_integer] = ACTIONS(4567),
    [sym_continue_as_identifier] = ACTIONS(4571),
    [sym_preproc_open] = ACTIONS(4571),
  },
  [STATE(1930)] = {
    [sym_identifier] = ACTIONS(4650),
    [anon_sym_SEMI] = ACTIONS(4652),
    [anon_sym_DASH] = ACTIONS(4652),
    [aux_sym_boolean_token1] = ACTIONS(4650),
    [aux_sym_boolean_token2] = ACTIONS(4650),
    [sym_decimal] = ACTIONS(4650),
    [anon_sym_LPAREN] = ACTIONS(4652),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4650),
    [anon_sym_LBRACK] = ACTIONS(4652),
    [aux_sym_record_type_token1] = ACTIONS(4650),
    [aux_sym_basic_type_token21] = ACTIONS(4650),
    [aux_sym_basic_type_token22] = ACTIONS(4650),
    [aux_sym_basic_type_token48] = ACTIONS(4650),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4650),
    [anon_sym_POUNDif] = ACTIONS(4652),
    [anon_sym_POUNDIF] = ACTIONS(4652),
    [anon_sym_POUNDIf] = ACTIONS(4652),
    [anon_sym_not] = ACTIONS(4650),
    [anon_sym_NOT] = ACTIONS(4650),
    [anon_sym_Not] = ACTIONS(4650),
    [anon_sym_POUNDelse] = ACTIONS(4652),
    [anon_sym_POUNDELSE] = ACTIONS(4652),
    [anon_sym_POUNDElse] = ACTIONS(4652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4650),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4650),
    [anon_sym_PLUS] = ACTIONS(4652),
    [sym_datetime_literal] = ACTIONS(4652),
    [sym_date_literal] = ACTIONS(4650),
    [sym_time_literal] = ACTIONS(4650),
    [sym_biginteger_literal] = ACTIONS(4652),
    [anon_sym_if] = ACTIONS(4650),
    [anon_sym_IF] = ACTIONS(4650),
    [anon_sym_If] = ACTIONS(4650),
    [anon_sym_else] = ACTIONS(4650),
    [anon_sym_ELSE] = ACTIONS(4650),
    [anon_sym_Else] = ACTIONS(4650),
    [anon_sym_case] = ACTIONS(4650),
    [anon_sym_CASE] = ACTIONS(4650),
    [anon_sym_Case] = ACTIONS(4650),
    [anon_sym_for] = ACTIONS(4650),
    [anon_sym_FOR] = ACTIONS(4650),
    [anon_sym_For] = ACTIONS(4650),
    [anon_sym_foreach] = ACTIONS(4650),
    [anon_sym_FOREACH] = ACTIONS(4650),
    [anon_sym_Foreach] = ACTIONS(4650),
    [anon_sym_while] = ACTIONS(4650),
    [anon_sym_WHILE] = ACTIONS(4650),
    [anon_sym_While] = ACTIONS(4650),
    [anon_sym_repeat] = ACTIONS(4650),
    [anon_sym_REPEAT] = ACTIONS(4650),
    [anon_sym_Repeat] = ACTIONS(4650),
    [anon_sym_until] = ACTIONS(4650),
    [anon_sym_UNTIL] = ACTIONS(4650),
    [anon_sym_Until] = ACTIONS(4650),
    [anon_sym_exit] = ACTIONS(4650),
    [anon_sym_EXIT] = ACTIONS(4650),
    [anon_sym_Exit] = ACTIONS(4650),
    [anon_sym_continue] = ACTIONS(4650),
    [anon_sym_CONTINUE] = ACTIONS(4650),
    [anon_sym_Continue] = ACTIONS(4650),
    [anon_sym_break] = ACTIONS(4650),
    [anon_sym_BREAK] = ACTIONS(4650),
    [anon_sym_Break] = ACTIONS(4650),
    [anon_sym_with] = ACTIONS(4650),
    [anon_sym_WITH] = ACTIONS(4650),
    [anon_sym_With] = ACTIONS(4650),
    [sym_asserterror_keyword] = ACTIONS(4652),
    [sym_page_keyword] = ACTIONS(4650),
    [anon_sym_codeunit] = ACTIONS(4650),
    [anon_sym_CODEUNIT] = ACTIONS(4650),
    [anon_sym_Codeunit] = ACTIONS(4650),
    [anon_sym_CodeUnit] = ACTIONS(4650),
    [anon_sym_COdeunit] = ACTIONS(4650),
    [anon_sym_codeUnit] = ACTIONS(4650),
    [sym_report_keyword] = ACTIONS(4650),
    [sym_query_keyword] = ACTIONS(4650),
    [anon_sym_xmlport] = ACTIONS(4650),
    [anon_sym_XMLPORT] = ACTIONS(4650),
    [anon_sym_Xmlport] = ACTIONS(4650),
    [anon_sym_XMLport] = ACTIONS(4650),
    [anon_sym_XMLPort] = ACTIONS(4650),
    [anon_sym_XmlPort] = ACTIONS(4650),
    [anon_sym_enum] = ACTIONS(4650),
    [anon_sym_ENUM] = ACTIONS(4650),
    [anon_sym_Enum] = ACTIONS(4650),
    [anon_sym_eNUM] = ACTIONS(4650),
    [anon_sym_eNum] = ACTIONS(4650),
    [anon_sym_ENum] = ACTIONS(4650),
    [sym_quoted_identifier] = ACTIONS(4652),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4652),
    [sym_integer] = ACTIONS(4650),
    [sym_continue_as_identifier] = ACTIONS(4652),
    [sym_preproc_open] = ACTIONS(4652),
  },
  [STATE(1931)] = {
    [sym_identifier] = ACTIONS(4646),
    [anon_sym_SEMI] = ACTIONS(4648),
    [anon_sym_DASH] = ACTIONS(4648),
    [aux_sym_boolean_token1] = ACTIONS(4646),
    [aux_sym_boolean_token2] = ACTIONS(4646),
    [sym_decimal] = ACTIONS(4646),
    [anon_sym_LPAREN] = ACTIONS(4648),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4646),
    [anon_sym_LBRACK] = ACTIONS(4648),
    [aux_sym_record_type_token1] = ACTIONS(4646),
    [aux_sym_basic_type_token21] = ACTIONS(4646),
    [aux_sym_basic_type_token22] = ACTIONS(4646),
    [aux_sym_basic_type_token48] = ACTIONS(4646),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4646),
    [anon_sym_POUNDif] = ACTIONS(4648),
    [anon_sym_POUNDIF] = ACTIONS(4648),
    [anon_sym_POUNDIf] = ACTIONS(4648),
    [anon_sym_not] = ACTIONS(4646),
    [anon_sym_NOT] = ACTIONS(4646),
    [anon_sym_Not] = ACTIONS(4646),
    [anon_sym_POUNDelse] = ACTIONS(4648),
    [anon_sym_POUNDELSE] = ACTIONS(4648),
    [anon_sym_POUNDElse] = ACTIONS(4648),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4646),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4646),
    [anon_sym_PLUS] = ACTIONS(4648),
    [sym_datetime_literal] = ACTIONS(4648),
    [sym_date_literal] = ACTIONS(4646),
    [sym_time_literal] = ACTIONS(4646),
    [sym_biginteger_literal] = ACTIONS(4648),
    [anon_sym_if] = ACTIONS(4646),
    [anon_sym_IF] = ACTIONS(4646),
    [anon_sym_If] = ACTIONS(4646),
    [anon_sym_else] = ACTIONS(4646),
    [anon_sym_ELSE] = ACTIONS(4646),
    [anon_sym_Else] = ACTIONS(4646),
    [anon_sym_case] = ACTIONS(4646),
    [anon_sym_CASE] = ACTIONS(4646),
    [anon_sym_Case] = ACTIONS(4646),
    [anon_sym_for] = ACTIONS(4646),
    [anon_sym_FOR] = ACTIONS(4646),
    [anon_sym_For] = ACTIONS(4646),
    [anon_sym_foreach] = ACTIONS(4646),
    [anon_sym_FOREACH] = ACTIONS(4646),
    [anon_sym_Foreach] = ACTIONS(4646),
    [anon_sym_while] = ACTIONS(4646),
    [anon_sym_WHILE] = ACTIONS(4646),
    [anon_sym_While] = ACTIONS(4646),
    [anon_sym_repeat] = ACTIONS(4646),
    [anon_sym_REPEAT] = ACTIONS(4646),
    [anon_sym_Repeat] = ACTIONS(4646),
    [anon_sym_until] = ACTIONS(4646),
    [anon_sym_UNTIL] = ACTIONS(4646),
    [anon_sym_Until] = ACTIONS(4646),
    [anon_sym_exit] = ACTIONS(4646),
    [anon_sym_EXIT] = ACTIONS(4646),
    [anon_sym_Exit] = ACTIONS(4646),
    [anon_sym_continue] = ACTIONS(4646),
    [anon_sym_CONTINUE] = ACTIONS(4646),
    [anon_sym_Continue] = ACTIONS(4646),
    [anon_sym_break] = ACTIONS(4646),
    [anon_sym_BREAK] = ACTIONS(4646),
    [anon_sym_Break] = ACTIONS(4646),
    [anon_sym_with] = ACTIONS(4646),
    [anon_sym_WITH] = ACTIONS(4646),
    [anon_sym_With] = ACTIONS(4646),
    [sym_asserterror_keyword] = ACTIONS(4648),
    [sym_page_keyword] = ACTIONS(4646),
    [anon_sym_codeunit] = ACTIONS(4646),
    [anon_sym_CODEUNIT] = ACTIONS(4646),
    [anon_sym_Codeunit] = ACTIONS(4646),
    [anon_sym_CodeUnit] = ACTIONS(4646),
    [anon_sym_COdeunit] = ACTIONS(4646),
    [anon_sym_codeUnit] = ACTIONS(4646),
    [sym_report_keyword] = ACTIONS(4646),
    [sym_query_keyword] = ACTIONS(4646),
    [anon_sym_xmlport] = ACTIONS(4646),
    [anon_sym_XMLPORT] = ACTIONS(4646),
    [anon_sym_Xmlport] = ACTIONS(4646),
    [anon_sym_XMLport] = ACTIONS(4646),
    [anon_sym_XMLPort] = ACTIONS(4646),
    [anon_sym_XmlPort] = ACTIONS(4646),
    [anon_sym_enum] = ACTIONS(4646),
    [anon_sym_ENUM] = ACTIONS(4646),
    [anon_sym_Enum] = ACTIONS(4646),
    [anon_sym_eNUM] = ACTIONS(4646),
    [anon_sym_eNum] = ACTIONS(4646),
    [anon_sym_ENum] = ACTIONS(4646),
    [sym_quoted_identifier] = ACTIONS(4648),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4648),
    [sym_integer] = ACTIONS(4646),
    [sym_continue_as_identifier] = ACTIONS(4648),
    [sym_preproc_open] = ACTIONS(4648),
  },
  [STATE(1932)] = {
    [sym_identifier] = ACTIONS(4708),
    [anon_sym_SEMI] = ACTIONS(4710),
    [anon_sym_DASH] = ACTIONS(4710),
    [aux_sym_boolean_token1] = ACTIONS(4708),
    [aux_sym_boolean_token2] = ACTIONS(4708),
    [sym_decimal] = ACTIONS(4708),
    [anon_sym_LPAREN] = ACTIONS(4710),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4708),
    [anon_sym_LBRACK] = ACTIONS(4710),
    [aux_sym_record_type_token1] = ACTIONS(4708),
    [aux_sym_basic_type_token21] = ACTIONS(4708),
    [aux_sym_basic_type_token22] = ACTIONS(4708),
    [aux_sym_basic_type_token48] = ACTIONS(4708),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4708),
    [anon_sym_POUNDif] = ACTIONS(4710),
    [anon_sym_POUNDIF] = ACTIONS(4710),
    [anon_sym_POUNDIf] = ACTIONS(4710),
    [anon_sym_not] = ACTIONS(4708),
    [anon_sym_NOT] = ACTIONS(4708),
    [anon_sym_Not] = ACTIONS(4708),
    [anon_sym_POUNDelse] = ACTIONS(4710),
    [anon_sym_POUNDELSE] = ACTIONS(4710),
    [anon_sym_POUNDElse] = ACTIONS(4710),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4708),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4708),
    [anon_sym_PLUS] = ACTIONS(4710),
    [sym_datetime_literal] = ACTIONS(4710),
    [sym_date_literal] = ACTIONS(4708),
    [sym_time_literal] = ACTIONS(4708),
    [sym_biginteger_literal] = ACTIONS(4710),
    [anon_sym_if] = ACTIONS(4708),
    [anon_sym_IF] = ACTIONS(4708),
    [anon_sym_If] = ACTIONS(4708),
    [anon_sym_else] = ACTIONS(4708),
    [anon_sym_ELSE] = ACTIONS(4708),
    [anon_sym_Else] = ACTIONS(4708),
    [anon_sym_case] = ACTIONS(4708),
    [anon_sym_CASE] = ACTIONS(4708),
    [anon_sym_Case] = ACTIONS(4708),
    [anon_sym_for] = ACTIONS(4708),
    [anon_sym_FOR] = ACTIONS(4708),
    [anon_sym_For] = ACTIONS(4708),
    [anon_sym_foreach] = ACTIONS(4708),
    [anon_sym_FOREACH] = ACTIONS(4708),
    [anon_sym_Foreach] = ACTIONS(4708),
    [anon_sym_while] = ACTIONS(4708),
    [anon_sym_WHILE] = ACTIONS(4708),
    [anon_sym_While] = ACTIONS(4708),
    [anon_sym_repeat] = ACTIONS(4708),
    [anon_sym_REPEAT] = ACTIONS(4708),
    [anon_sym_Repeat] = ACTIONS(4708),
    [anon_sym_until] = ACTIONS(4708),
    [anon_sym_UNTIL] = ACTIONS(4708),
    [anon_sym_Until] = ACTIONS(4708),
    [anon_sym_exit] = ACTIONS(4708),
    [anon_sym_EXIT] = ACTIONS(4708),
    [anon_sym_Exit] = ACTIONS(4708),
    [anon_sym_continue] = ACTIONS(4708),
    [anon_sym_CONTINUE] = ACTIONS(4708),
    [anon_sym_Continue] = ACTIONS(4708),
    [anon_sym_break] = ACTIONS(4708),
    [anon_sym_BREAK] = ACTIONS(4708),
    [anon_sym_Break] = ACTIONS(4708),
    [anon_sym_with] = ACTIONS(4708),
    [anon_sym_WITH] = ACTIONS(4708),
    [anon_sym_With] = ACTIONS(4708),
    [sym_asserterror_keyword] = ACTIONS(4710),
    [sym_page_keyword] = ACTIONS(4708),
    [anon_sym_codeunit] = ACTIONS(4708),
    [anon_sym_CODEUNIT] = ACTIONS(4708),
    [anon_sym_Codeunit] = ACTIONS(4708),
    [anon_sym_CodeUnit] = ACTIONS(4708),
    [anon_sym_COdeunit] = ACTIONS(4708),
    [anon_sym_codeUnit] = ACTIONS(4708),
    [sym_report_keyword] = ACTIONS(4708),
    [sym_query_keyword] = ACTIONS(4708),
    [anon_sym_xmlport] = ACTIONS(4708),
    [anon_sym_XMLPORT] = ACTIONS(4708),
    [anon_sym_Xmlport] = ACTIONS(4708),
    [anon_sym_XMLport] = ACTIONS(4708),
    [anon_sym_XMLPort] = ACTIONS(4708),
    [anon_sym_XmlPort] = ACTIONS(4708),
    [anon_sym_enum] = ACTIONS(4708),
    [anon_sym_ENUM] = ACTIONS(4708),
    [anon_sym_Enum] = ACTIONS(4708),
    [anon_sym_eNUM] = ACTIONS(4708),
    [anon_sym_eNum] = ACTIONS(4708),
    [anon_sym_ENum] = ACTIONS(4708),
    [sym_quoted_identifier] = ACTIONS(4710),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4710),
    [sym_integer] = ACTIONS(4708),
    [sym_continue_as_identifier] = ACTIONS(4710),
    [sym_preproc_open] = ACTIONS(4710),
  },
  [STATE(1933)] = {
    [sym_identifier] = ACTIONS(4654),
    [anon_sym_SEMI] = ACTIONS(4656),
    [anon_sym_DASH] = ACTIONS(4656),
    [aux_sym_boolean_token1] = ACTIONS(4654),
    [aux_sym_boolean_token2] = ACTIONS(4654),
    [sym_decimal] = ACTIONS(4654),
    [anon_sym_LPAREN] = ACTIONS(4656),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4654),
    [anon_sym_LBRACK] = ACTIONS(4656),
    [aux_sym_record_type_token1] = ACTIONS(4654),
    [aux_sym_basic_type_token21] = ACTIONS(4654),
    [aux_sym_basic_type_token22] = ACTIONS(4654),
    [aux_sym_basic_type_token48] = ACTIONS(4654),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4654),
    [anon_sym_POUNDif] = ACTIONS(4656),
    [anon_sym_POUNDIF] = ACTIONS(4656),
    [anon_sym_POUNDIf] = ACTIONS(4656),
    [anon_sym_not] = ACTIONS(4654),
    [anon_sym_NOT] = ACTIONS(4654),
    [anon_sym_Not] = ACTIONS(4654),
    [anon_sym_POUNDelse] = ACTIONS(4656),
    [anon_sym_POUNDELSE] = ACTIONS(4656),
    [anon_sym_POUNDElse] = ACTIONS(4656),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4654),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4654),
    [anon_sym_PLUS] = ACTIONS(4656),
    [sym_datetime_literal] = ACTIONS(4656),
    [sym_date_literal] = ACTIONS(4654),
    [sym_time_literal] = ACTIONS(4654),
    [sym_biginteger_literal] = ACTIONS(4656),
    [anon_sym_if] = ACTIONS(4654),
    [anon_sym_IF] = ACTIONS(4654),
    [anon_sym_If] = ACTIONS(4654),
    [anon_sym_else] = ACTIONS(4654),
    [anon_sym_ELSE] = ACTIONS(4654),
    [anon_sym_Else] = ACTIONS(4654),
    [anon_sym_case] = ACTIONS(4654),
    [anon_sym_CASE] = ACTIONS(4654),
    [anon_sym_Case] = ACTIONS(4654),
    [anon_sym_for] = ACTIONS(4654),
    [anon_sym_FOR] = ACTIONS(4654),
    [anon_sym_For] = ACTIONS(4654),
    [anon_sym_foreach] = ACTIONS(4654),
    [anon_sym_FOREACH] = ACTIONS(4654),
    [anon_sym_Foreach] = ACTIONS(4654),
    [anon_sym_while] = ACTIONS(4654),
    [anon_sym_WHILE] = ACTIONS(4654),
    [anon_sym_While] = ACTIONS(4654),
    [anon_sym_repeat] = ACTIONS(4654),
    [anon_sym_REPEAT] = ACTIONS(4654),
    [anon_sym_Repeat] = ACTIONS(4654),
    [anon_sym_until] = ACTIONS(4654),
    [anon_sym_UNTIL] = ACTIONS(4654),
    [anon_sym_Until] = ACTIONS(4654),
    [anon_sym_exit] = ACTIONS(4654),
    [anon_sym_EXIT] = ACTIONS(4654),
    [anon_sym_Exit] = ACTIONS(4654),
    [anon_sym_continue] = ACTIONS(4654),
    [anon_sym_CONTINUE] = ACTIONS(4654),
    [anon_sym_Continue] = ACTIONS(4654),
    [anon_sym_break] = ACTIONS(4654),
    [anon_sym_BREAK] = ACTIONS(4654),
    [anon_sym_Break] = ACTIONS(4654),
    [anon_sym_with] = ACTIONS(4654),
    [anon_sym_WITH] = ACTIONS(4654),
    [anon_sym_With] = ACTIONS(4654),
    [sym_asserterror_keyword] = ACTIONS(4656),
    [sym_page_keyword] = ACTIONS(4654),
    [anon_sym_codeunit] = ACTIONS(4654),
    [anon_sym_CODEUNIT] = ACTIONS(4654),
    [anon_sym_Codeunit] = ACTIONS(4654),
    [anon_sym_CodeUnit] = ACTIONS(4654),
    [anon_sym_COdeunit] = ACTIONS(4654),
    [anon_sym_codeUnit] = ACTIONS(4654),
    [sym_report_keyword] = ACTIONS(4654),
    [sym_query_keyword] = ACTIONS(4654),
    [anon_sym_xmlport] = ACTIONS(4654),
    [anon_sym_XMLPORT] = ACTIONS(4654),
    [anon_sym_Xmlport] = ACTIONS(4654),
    [anon_sym_XMLport] = ACTIONS(4654),
    [anon_sym_XMLPort] = ACTIONS(4654),
    [anon_sym_XmlPort] = ACTIONS(4654),
    [anon_sym_enum] = ACTIONS(4654),
    [anon_sym_ENUM] = ACTIONS(4654),
    [anon_sym_Enum] = ACTIONS(4654),
    [anon_sym_eNUM] = ACTIONS(4654),
    [anon_sym_eNum] = ACTIONS(4654),
    [anon_sym_ENum] = ACTIONS(4654),
    [sym_quoted_identifier] = ACTIONS(4656),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4656),
    [sym_integer] = ACTIONS(4654),
    [sym_continue_as_identifier] = ACTIONS(4656),
    [sym_preproc_open] = ACTIONS(4656),
  },
  [STATE(1934)] = {
    [sym_identifier] = ACTIONS(4577),
    [anon_sym_SEMI] = ACTIONS(4579),
    [anon_sym_DASH] = ACTIONS(4579),
    [aux_sym_boolean_token1] = ACTIONS(4577),
    [aux_sym_boolean_token2] = ACTIONS(4577),
    [sym_decimal] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(4579),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4579),
    [aux_sym_record_type_token1] = ACTIONS(4577),
    [aux_sym_basic_type_token21] = ACTIONS(4577),
    [aux_sym_basic_type_token22] = ACTIONS(4577),
    [aux_sym_basic_type_token48] = ACTIONS(4577),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4577),
    [anon_sym_POUNDif] = ACTIONS(4579),
    [anon_sym_POUNDIF] = ACTIONS(4579),
    [anon_sym_POUNDIf] = ACTIONS(4579),
    [anon_sym_not] = ACTIONS(4577),
    [anon_sym_NOT] = ACTIONS(4577),
    [anon_sym_Not] = ACTIONS(4577),
    [anon_sym_POUNDelse] = ACTIONS(4579),
    [anon_sym_POUNDELSE] = ACTIONS(4579),
    [anon_sym_POUNDElse] = ACTIONS(4579),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4577),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4577),
    [anon_sym_PLUS] = ACTIONS(4579),
    [sym_datetime_literal] = ACTIONS(4579),
    [sym_date_literal] = ACTIONS(4577),
    [sym_time_literal] = ACTIONS(4577),
    [sym_biginteger_literal] = ACTIONS(4579),
    [anon_sym_if] = ACTIONS(4577),
    [anon_sym_IF] = ACTIONS(4577),
    [anon_sym_If] = ACTIONS(4577),
    [anon_sym_else] = ACTIONS(4577),
    [anon_sym_ELSE] = ACTIONS(4577),
    [anon_sym_Else] = ACTIONS(4577),
    [anon_sym_case] = ACTIONS(4577),
    [anon_sym_CASE] = ACTIONS(4577),
    [anon_sym_Case] = ACTIONS(4577),
    [anon_sym_for] = ACTIONS(4577),
    [anon_sym_FOR] = ACTIONS(4577),
    [anon_sym_For] = ACTIONS(4577),
    [anon_sym_foreach] = ACTIONS(4577),
    [anon_sym_FOREACH] = ACTIONS(4577),
    [anon_sym_Foreach] = ACTIONS(4577),
    [anon_sym_while] = ACTIONS(4577),
    [anon_sym_WHILE] = ACTIONS(4577),
    [anon_sym_While] = ACTIONS(4577),
    [anon_sym_repeat] = ACTIONS(4577),
    [anon_sym_REPEAT] = ACTIONS(4577),
    [anon_sym_Repeat] = ACTIONS(4577),
    [anon_sym_until] = ACTIONS(4577),
    [anon_sym_UNTIL] = ACTIONS(4577),
    [anon_sym_Until] = ACTIONS(4577),
    [anon_sym_exit] = ACTIONS(4577),
    [anon_sym_EXIT] = ACTIONS(4577),
    [anon_sym_Exit] = ACTIONS(4577),
    [anon_sym_continue] = ACTIONS(4577),
    [anon_sym_CONTINUE] = ACTIONS(4577),
    [anon_sym_Continue] = ACTIONS(4577),
    [anon_sym_break] = ACTIONS(4577),
    [anon_sym_BREAK] = ACTIONS(4577),
    [anon_sym_Break] = ACTIONS(4577),
    [anon_sym_with] = ACTIONS(4577),
    [anon_sym_WITH] = ACTIONS(4577),
    [anon_sym_With] = ACTIONS(4577),
    [sym_asserterror_keyword] = ACTIONS(4579),
    [sym_page_keyword] = ACTIONS(4577),
    [anon_sym_codeunit] = ACTIONS(4577),
    [anon_sym_CODEUNIT] = ACTIONS(4577),
    [anon_sym_Codeunit] = ACTIONS(4577),
    [anon_sym_CodeUnit] = ACTIONS(4577),
    [anon_sym_COdeunit] = ACTIONS(4577),
    [anon_sym_codeUnit] = ACTIONS(4577),
    [sym_report_keyword] = ACTIONS(4577),
    [sym_query_keyword] = ACTIONS(4577),
    [anon_sym_xmlport] = ACTIONS(4577),
    [anon_sym_XMLPORT] = ACTIONS(4577),
    [anon_sym_Xmlport] = ACTIONS(4577),
    [anon_sym_XMLport] = ACTIONS(4577),
    [anon_sym_XMLPort] = ACTIONS(4577),
    [anon_sym_XmlPort] = ACTIONS(4577),
    [anon_sym_enum] = ACTIONS(4577),
    [anon_sym_ENUM] = ACTIONS(4577),
    [anon_sym_Enum] = ACTIONS(4577),
    [anon_sym_eNUM] = ACTIONS(4577),
    [anon_sym_eNum] = ACTIONS(4577),
    [anon_sym_ENum] = ACTIONS(4577),
    [sym_quoted_identifier] = ACTIONS(4579),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4579),
    [sym_integer] = ACTIONS(4577),
    [sym_continue_as_identifier] = ACTIONS(4579),
    [sym_preproc_open] = ACTIONS(4579),
  },
  [STATE(1935)] = {
    [sym_identifier] = ACTIONS(4712),
    [anon_sym_SEMI] = ACTIONS(4714),
    [anon_sym_DASH] = ACTIONS(4714),
    [aux_sym_boolean_token1] = ACTIONS(4712),
    [aux_sym_boolean_token2] = ACTIONS(4712),
    [sym_decimal] = ACTIONS(4712),
    [anon_sym_LPAREN] = ACTIONS(4714),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4712),
    [anon_sym_LBRACK] = ACTIONS(4714),
    [aux_sym_record_type_token1] = ACTIONS(4712),
    [aux_sym_basic_type_token21] = ACTIONS(4712),
    [aux_sym_basic_type_token22] = ACTIONS(4712),
    [aux_sym_basic_type_token48] = ACTIONS(4712),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4712),
    [anon_sym_POUNDif] = ACTIONS(4714),
    [anon_sym_POUNDIF] = ACTIONS(4714),
    [anon_sym_POUNDIf] = ACTIONS(4714),
    [anon_sym_not] = ACTIONS(4712),
    [anon_sym_NOT] = ACTIONS(4712),
    [anon_sym_Not] = ACTIONS(4712),
    [anon_sym_POUNDelse] = ACTIONS(4714),
    [anon_sym_POUNDELSE] = ACTIONS(4714),
    [anon_sym_POUNDElse] = ACTIONS(4714),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4712),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4712),
    [anon_sym_PLUS] = ACTIONS(4714),
    [sym_datetime_literal] = ACTIONS(4714),
    [sym_date_literal] = ACTIONS(4712),
    [sym_time_literal] = ACTIONS(4712),
    [sym_biginteger_literal] = ACTIONS(4714),
    [anon_sym_if] = ACTIONS(4712),
    [anon_sym_IF] = ACTIONS(4712),
    [anon_sym_If] = ACTIONS(4712),
    [anon_sym_else] = ACTIONS(4712),
    [anon_sym_ELSE] = ACTIONS(4712),
    [anon_sym_Else] = ACTIONS(4712),
    [anon_sym_case] = ACTIONS(4712),
    [anon_sym_CASE] = ACTIONS(4712),
    [anon_sym_Case] = ACTIONS(4712),
    [anon_sym_for] = ACTIONS(4712),
    [anon_sym_FOR] = ACTIONS(4712),
    [anon_sym_For] = ACTIONS(4712),
    [anon_sym_foreach] = ACTIONS(4712),
    [anon_sym_FOREACH] = ACTIONS(4712),
    [anon_sym_Foreach] = ACTIONS(4712),
    [anon_sym_while] = ACTIONS(4712),
    [anon_sym_WHILE] = ACTIONS(4712),
    [anon_sym_While] = ACTIONS(4712),
    [anon_sym_repeat] = ACTIONS(4712),
    [anon_sym_REPEAT] = ACTIONS(4712),
    [anon_sym_Repeat] = ACTIONS(4712),
    [anon_sym_until] = ACTIONS(4712),
    [anon_sym_UNTIL] = ACTIONS(4712),
    [anon_sym_Until] = ACTIONS(4712),
    [anon_sym_exit] = ACTIONS(4712),
    [anon_sym_EXIT] = ACTIONS(4712),
    [anon_sym_Exit] = ACTIONS(4712),
    [anon_sym_continue] = ACTIONS(4712),
    [anon_sym_CONTINUE] = ACTIONS(4712),
    [anon_sym_Continue] = ACTIONS(4712),
    [anon_sym_break] = ACTIONS(4712),
    [anon_sym_BREAK] = ACTIONS(4712),
    [anon_sym_Break] = ACTIONS(4712),
    [anon_sym_with] = ACTIONS(4712),
    [anon_sym_WITH] = ACTIONS(4712),
    [anon_sym_With] = ACTIONS(4712),
    [sym_asserterror_keyword] = ACTIONS(4714),
    [sym_page_keyword] = ACTIONS(4712),
    [anon_sym_codeunit] = ACTIONS(4712),
    [anon_sym_CODEUNIT] = ACTIONS(4712),
    [anon_sym_Codeunit] = ACTIONS(4712),
    [anon_sym_CodeUnit] = ACTIONS(4712),
    [anon_sym_COdeunit] = ACTIONS(4712),
    [anon_sym_codeUnit] = ACTIONS(4712),
    [sym_report_keyword] = ACTIONS(4712),
    [sym_query_keyword] = ACTIONS(4712),
    [anon_sym_xmlport] = ACTIONS(4712),
    [anon_sym_XMLPORT] = ACTIONS(4712),
    [anon_sym_Xmlport] = ACTIONS(4712),
    [anon_sym_XMLport] = ACTIONS(4712),
    [anon_sym_XMLPort] = ACTIONS(4712),
    [anon_sym_XmlPort] = ACTIONS(4712),
    [anon_sym_enum] = ACTIONS(4712),
    [anon_sym_ENUM] = ACTIONS(4712),
    [anon_sym_Enum] = ACTIONS(4712),
    [anon_sym_eNUM] = ACTIONS(4712),
    [anon_sym_eNum] = ACTIONS(4712),
    [anon_sym_ENum] = ACTIONS(4712),
    [sym_quoted_identifier] = ACTIONS(4714),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4714),
    [sym_integer] = ACTIONS(4712),
    [sym_continue_as_identifier] = ACTIONS(4714),
    [sym_preproc_open] = ACTIONS(4714),
  },
  [STATE(1936)] = {
    [sym_identifier] = ACTIONS(4668),
    [anon_sym_SEMI] = ACTIONS(4670),
    [anon_sym_DASH] = ACTIONS(4670),
    [aux_sym_boolean_token1] = ACTIONS(4668),
    [aux_sym_boolean_token2] = ACTIONS(4668),
    [sym_decimal] = ACTIONS(4668),
    [anon_sym_LPAREN] = ACTIONS(4670),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4668),
    [anon_sym_LBRACK] = ACTIONS(4670),
    [aux_sym_record_type_token1] = ACTIONS(4668),
    [aux_sym_basic_type_token21] = ACTIONS(4668),
    [aux_sym_basic_type_token22] = ACTIONS(4668),
    [aux_sym_basic_type_token48] = ACTIONS(4668),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4668),
    [anon_sym_POUNDif] = ACTIONS(4670),
    [anon_sym_POUNDIF] = ACTIONS(4670),
    [anon_sym_POUNDIf] = ACTIONS(4670),
    [anon_sym_not] = ACTIONS(4668),
    [anon_sym_NOT] = ACTIONS(4668),
    [anon_sym_Not] = ACTIONS(4668),
    [anon_sym_POUNDelse] = ACTIONS(4670),
    [anon_sym_POUNDELSE] = ACTIONS(4670),
    [anon_sym_POUNDElse] = ACTIONS(4670),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4668),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4668),
    [anon_sym_PLUS] = ACTIONS(4670),
    [sym_datetime_literal] = ACTIONS(4670),
    [sym_date_literal] = ACTIONS(4668),
    [sym_time_literal] = ACTIONS(4668),
    [sym_biginteger_literal] = ACTIONS(4670),
    [anon_sym_if] = ACTIONS(4668),
    [anon_sym_IF] = ACTIONS(4668),
    [anon_sym_If] = ACTIONS(4668),
    [anon_sym_else] = ACTIONS(4668),
    [anon_sym_ELSE] = ACTIONS(4668),
    [anon_sym_Else] = ACTIONS(4668),
    [anon_sym_case] = ACTIONS(4668),
    [anon_sym_CASE] = ACTIONS(4668),
    [anon_sym_Case] = ACTIONS(4668),
    [anon_sym_for] = ACTIONS(4668),
    [anon_sym_FOR] = ACTIONS(4668),
    [anon_sym_For] = ACTIONS(4668),
    [anon_sym_foreach] = ACTIONS(4668),
    [anon_sym_FOREACH] = ACTIONS(4668),
    [anon_sym_Foreach] = ACTIONS(4668),
    [anon_sym_while] = ACTIONS(4668),
    [anon_sym_WHILE] = ACTIONS(4668),
    [anon_sym_While] = ACTIONS(4668),
    [anon_sym_repeat] = ACTIONS(4668),
    [anon_sym_REPEAT] = ACTIONS(4668),
    [anon_sym_Repeat] = ACTIONS(4668),
    [anon_sym_until] = ACTIONS(4668),
    [anon_sym_UNTIL] = ACTIONS(4668),
    [anon_sym_Until] = ACTIONS(4668),
    [anon_sym_exit] = ACTIONS(4668),
    [anon_sym_EXIT] = ACTIONS(4668),
    [anon_sym_Exit] = ACTIONS(4668),
    [anon_sym_continue] = ACTIONS(4668),
    [anon_sym_CONTINUE] = ACTIONS(4668),
    [anon_sym_Continue] = ACTIONS(4668),
    [anon_sym_break] = ACTIONS(4668),
    [anon_sym_BREAK] = ACTIONS(4668),
    [anon_sym_Break] = ACTIONS(4668),
    [anon_sym_with] = ACTIONS(4668),
    [anon_sym_WITH] = ACTIONS(4668),
    [anon_sym_With] = ACTIONS(4668),
    [sym_asserterror_keyword] = ACTIONS(4670),
    [sym_page_keyword] = ACTIONS(4668),
    [anon_sym_codeunit] = ACTIONS(4668),
    [anon_sym_CODEUNIT] = ACTIONS(4668),
    [anon_sym_Codeunit] = ACTIONS(4668),
    [anon_sym_CodeUnit] = ACTIONS(4668),
    [anon_sym_COdeunit] = ACTIONS(4668),
    [anon_sym_codeUnit] = ACTIONS(4668),
    [sym_report_keyword] = ACTIONS(4668),
    [sym_query_keyword] = ACTIONS(4668),
    [anon_sym_xmlport] = ACTIONS(4668),
    [anon_sym_XMLPORT] = ACTIONS(4668),
    [anon_sym_Xmlport] = ACTIONS(4668),
    [anon_sym_XMLport] = ACTIONS(4668),
    [anon_sym_XMLPort] = ACTIONS(4668),
    [anon_sym_XmlPort] = ACTIONS(4668),
    [anon_sym_enum] = ACTIONS(4668),
    [anon_sym_ENUM] = ACTIONS(4668),
    [anon_sym_Enum] = ACTIONS(4668),
    [anon_sym_eNUM] = ACTIONS(4668),
    [anon_sym_eNum] = ACTIONS(4668),
    [anon_sym_ENum] = ACTIONS(4668),
    [sym_quoted_identifier] = ACTIONS(4670),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4670),
    [sym_integer] = ACTIONS(4668),
    [sym_continue_as_identifier] = ACTIONS(4670),
    [sym_preproc_open] = ACTIONS(4670),
  },
  [STATE(1937)] = {
    [sym_identifier] = ACTIONS(4708),
    [anon_sym_SEMI] = ACTIONS(4710),
    [anon_sym_DASH] = ACTIONS(4710),
    [aux_sym_boolean_token1] = ACTIONS(4708),
    [aux_sym_boolean_token2] = ACTIONS(4708),
    [sym_decimal] = ACTIONS(4708),
    [anon_sym_LPAREN] = ACTIONS(4710),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4708),
    [anon_sym_LBRACK] = ACTIONS(4710),
    [aux_sym_record_type_token1] = ACTIONS(4708),
    [aux_sym_basic_type_token21] = ACTIONS(4708),
    [aux_sym_basic_type_token22] = ACTIONS(4708),
    [aux_sym_basic_type_token48] = ACTIONS(4708),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4708),
    [anon_sym_POUNDif] = ACTIONS(4710),
    [anon_sym_POUNDIF] = ACTIONS(4710),
    [anon_sym_POUNDIf] = ACTIONS(4710),
    [anon_sym_not] = ACTIONS(4708),
    [anon_sym_NOT] = ACTIONS(4708),
    [anon_sym_Not] = ACTIONS(4708),
    [anon_sym_POUNDelse] = ACTIONS(4710),
    [anon_sym_POUNDELSE] = ACTIONS(4710),
    [anon_sym_POUNDElse] = ACTIONS(4710),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4708),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4708),
    [anon_sym_PLUS] = ACTIONS(4710),
    [sym_datetime_literal] = ACTIONS(4710),
    [sym_date_literal] = ACTIONS(4708),
    [sym_time_literal] = ACTIONS(4708),
    [sym_biginteger_literal] = ACTIONS(4710),
    [anon_sym_if] = ACTIONS(4708),
    [anon_sym_IF] = ACTIONS(4708),
    [anon_sym_If] = ACTIONS(4708),
    [anon_sym_else] = ACTIONS(4708),
    [anon_sym_ELSE] = ACTIONS(4708),
    [anon_sym_Else] = ACTIONS(4708),
    [anon_sym_case] = ACTIONS(4708),
    [anon_sym_CASE] = ACTIONS(4708),
    [anon_sym_Case] = ACTIONS(4708),
    [anon_sym_for] = ACTIONS(4708),
    [anon_sym_FOR] = ACTIONS(4708),
    [anon_sym_For] = ACTIONS(4708),
    [anon_sym_foreach] = ACTIONS(4708),
    [anon_sym_FOREACH] = ACTIONS(4708),
    [anon_sym_Foreach] = ACTIONS(4708),
    [anon_sym_while] = ACTIONS(4708),
    [anon_sym_WHILE] = ACTIONS(4708),
    [anon_sym_While] = ACTIONS(4708),
    [anon_sym_repeat] = ACTIONS(4708),
    [anon_sym_REPEAT] = ACTIONS(4708),
    [anon_sym_Repeat] = ACTIONS(4708),
    [anon_sym_until] = ACTIONS(4708),
    [anon_sym_UNTIL] = ACTIONS(4708),
    [anon_sym_Until] = ACTIONS(4708),
    [anon_sym_exit] = ACTIONS(4708),
    [anon_sym_EXIT] = ACTIONS(4708),
    [anon_sym_Exit] = ACTIONS(4708),
    [anon_sym_continue] = ACTIONS(4708),
    [anon_sym_CONTINUE] = ACTIONS(4708),
    [anon_sym_Continue] = ACTIONS(4708),
    [anon_sym_break] = ACTIONS(4708),
    [anon_sym_BREAK] = ACTIONS(4708),
    [anon_sym_Break] = ACTIONS(4708),
    [anon_sym_with] = ACTIONS(4708),
    [anon_sym_WITH] = ACTIONS(4708),
    [anon_sym_With] = ACTIONS(4708),
    [sym_asserterror_keyword] = ACTIONS(4710),
    [sym_page_keyword] = ACTIONS(4708),
    [anon_sym_codeunit] = ACTIONS(4708),
    [anon_sym_CODEUNIT] = ACTIONS(4708),
    [anon_sym_Codeunit] = ACTIONS(4708),
    [anon_sym_CodeUnit] = ACTIONS(4708),
    [anon_sym_COdeunit] = ACTIONS(4708),
    [anon_sym_codeUnit] = ACTIONS(4708),
    [sym_report_keyword] = ACTIONS(4708),
    [sym_query_keyword] = ACTIONS(4708),
    [anon_sym_xmlport] = ACTIONS(4708),
    [anon_sym_XMLPORT] = ACTIONS(4708),
    [anon_sym_Xmlport] = ACTIONS(4708),
    [anon_sym_XMLport] = ACTIONS(4708),
    [anon_sym_XMLPort] = ACTIONS(4708),
    [anon_sym_XmlPort] = ACTIONS(4708),
    [anon_sym_enum] = ACTIONS(4708),
    [anon_sym_ENUM] = ACTIONS(4708),
    [anon_sym_Enum] = ACTIONS(4708),
    [anon_sym_eNUM] = ACTIONS(4708),
    [anon_sym_eNum] = ACTIONS(4708),
    [anon_sym_ENum] = ACTIONS(4708),
    [sym_quoted_identifier] = ACTIONS(4710),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4710),
    [sym_integer] = ACTIONS(4708),
    [sym_continue_as_identifier] = ACTIONS(4710),
    [sym_preproc_open] = ACTIONS(4710),
  },
  [STATE(1938)] = {
    [sym_identifier] = ACTIONS(4688),
    [anon_sym_SEMI] = ACTIONS(4690),
    [anon_sym_DASH] = ACTIONS(4690),
    [aux_sym_boolean_token1] = ACTIONS(4688),
    [aux_sym_boolean_token2] = ACTIONS(4688),
    [sym_decimal] = ACTIONS(4688),
    [anon_sym_LPAREN] = ACTIONS(4690),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4688),
    [anon_sym_LBRACK] = ACTIONS(4690),
    [aux_sym_record_type_token1] = ACTIONS(4688),
    [aux_sym_basic_type_token21] = ACTIONS(4688),
    [aux_sym_basic_type_token22] = ACTIONS(4688),
    [aux_sym_basic_type_token48] = ACTIONS(4688),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4688),
    [anon_sym_POUNDif] = ACTIONS(4690),
    [anon_sym_POUNDIF] = ACTIONS(4690),
    [anon_sym_POUNDIf] = ACTIONS(4690),
    [anon_sym_not] = ACTIONS(4688),
    [anon_sym_NOT] = ACTIONS(4688),
    [anon_sym_Not] = ACTIONS(4688),
    [anon_sym_POUNDelse] = ACTIONS(4690),
    [anon_sym_POUNDELSE] = ACTIONS(4690),
    [anon_sym_POUNDElse] = ACTIONS(4690),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4688),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4688),
    [anon_sym_PLUS] = ACTIONS(4690),
    [sym_datetime_literal] = ACTIONS(4690),
    [sym_date_literal] = ACTIONS(4688),
    [sym_time_literal] = ACTIONS(4688),
    [sym_biginteger_literal] = ACTIONS(4690),
    [anon_sym_if] = ACTIONS(4688),
    [anon_sym_IF] = ACTIONS(4688),
    [anon_sym_If] = ACTIONS(4688),
    [anon_sym_else] = ACTIONS(4688),
    [anon_sym_ELSE] = ACTIONS(4688),
    [anon_sym_Else] = ACTIONS(4688),
    [anon_sym_case] = ACTIONS(4688),
    [anon_sym_CASE] = ACTIONS(4688),
    [anon_sym_Case] = ACTIONS(4688),
    [anon_sym_for] = ACTIONS(4688),
    [anon_sym_FOR] = ACTIONS(4688),
    [anon_sym_For] = ACTIONS(4688),
    [anon_sym_foreach] = ACTIONS(4688),
    [anon_sym_FOREACH] = ACTIONS(4688),
    [anon_sym_Foreach] = ACTIONS(4688),
    [anon_sym_while] = ACTIONS(4688),
    [anon_sym_WHILE] = ACTIONS(4688),
    [anon_sym_While] = ACTIONS(4688),
    [anon_sym_repeat] = ACTIONS(4688),
    [anon_sym_REPEAT] = ACTIONS(4688),
    [anon_sym_Repeat] = ACTIONS(4688),
    [anon_sym_until] = ACTIONS(4688),
    [anon_sym_UNTIL] = ACTIONS(4688),
    [anon_sym_Until] = ACTIONS(4688),
    [anon_sym_exit] = ACTIONS(4688),
    [anon_sym_EXIT] = ACTIONS(4688),
    [anon_sym_Exit] = ACTIONS(4688),
    [anon_sym_continue] = ACTIONS(4688),
    [anon_sym_CONTINUE] = ACTIONS(4688),
    [anon_sym_Continue] = ACTIONS(4688),
    [anon_sym_break] = ACTIONS(4688),
    [anon_sym_BREAK] = ACTIONS(4688),
    [anon_sym_Break] = ACTIONS(4688),
    [anon_sym_with] = ACTIONS(4688),
    [anon_sym_WITH] = ACTIONS(4688),
    [anon_sym_With] = ACTIONS(4688),
    [sym_asserterror_keyword] = ACTIONS(4690),
    [sym_page_keyword] = ACTIONS(4688),
    [anon_sym_codeunit] = ACTIONS(4688),
    [anon_sym_CODEUNIT] = ACTIONS(4688),
    [anon_sym_Codeunit] = ACTIONS(4688),
    [anon_sym_CodeUnit] = ACTIONS(4688),
    [anon_sym_COdeunit] = ACTIONS(4688),
    [anon_sym_codeUnit] = ACTIONS(4688),
    [sym_report_keyword] = ACTIONS(4688),
    [sym_query_keyword] = ACTIONS(4688),
    [anon_sym_xmlport] = ACTIONS(4688),
    [anon_sym_XMLPORT] = ACTIONS(4688),
    [anon_sym_Xmlport] = ACTIONS(4688),
    [anon_sym_XMLport] = ACTIONS(4688),
    [anon_sym_XMLPort] = ACTIONS(4688),
    [anon_sym_XmlPort] = ACTIONS(4688),
    [anon_sym_enum] = ACTIONS(4688),
    [anon_sym_ENUM] = ACTIONS(4688),
    [anon_sym_Enum] = ACTIONS(4688),
    [anon_sym_eNUM] = ACTIONS(4688),
    [anon_sym_eNum] = ACTIONS(4688),
    [anon_sym_ENum] = ACTIONS(4688),
    [sym_quoted_identifier] = ACTIONS(4690),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4690),
    [sym_integer] = ACTIONS(4688),
    [sym_continue_as_identifier] = ACTIONS(4690),
    [sym_preproc_open] = ACTIONS(4690),
  },
  [STATE(1939)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2441),
    [sym_assignment_expression] = STATE(6338),
    [sym_case_branch] = STATE(1939),
    [sym_preproc_split_case_branch] = STATE(3395),
    [aux_sym__case_pattern] = STATE(2579),
    [sym_preproc_conditional_case_patterns] = STATE(2579),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(1939),
    [sym_identifier] = ACTIONS(4893),
    [anon_sym_DASH] = ACTIONS(4896),
    [aux_sym_boolean_token1] = ACTIONS(4899),
    [aux_sym_boolean_token2] = ACTIONS(4899),
    [sym_decimal] = ACTIONS(4902),
    [anon_sym_LPAREN] = ACTIONS(4905),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4908),
    [anon_sym_LBRACK] = ACTIONS(4911),
    [aux_sym_record_type_token1] = ACTIONS(4908),
    [aux_sym_basic_type_token21] = ACTIONS(4908),
    [aux_sym_basic_type_token22] = ACTIONS(4908),
    [aux_sym_basic_type_token48] = ACTIONS(4908),
    [anon_sym_POUNDif] = ACTIONS(4914),
    [anon_sym_POUNDIF] = ACTIONS(4914),
    [anon_sym_POUNDIf] = ACTIONS(4914),
    [anon_sym_not] = ACTIONS(4917),
    [anon_sym_NOT] = ACTIONS(4917),
    [anon_sym_Not] = ACTIONS(4917),
    [anon_sym_POUNDelif] = ACTIONS(4920),
    [anon_sym_POUNDELIF] = ACTIONS(4920),
    [anon_sym_POUNDElif] = ACTIONS(4920),
    [anon_sym_POUNDelse] = ACTIONS(4920),
    [anon_sym_POUNDELSE] = ACTIONS(4920),
    [anon_sym_POUNDElse] = ACTIONS(4920),
    [anon_sym_POUNDendif] = ACTIONS(4920),
    [anon_sym_POUNDENDIF] = ACTIONS(4920),
    [anon_sym_POUNDEndif] = ACTIONS(4920),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4908),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4922),
    [anon_sym_PLUS] = ACTIONS(4896),
    [sym_datetime_literal] = ACTIONS(4925),
    [sym_date_literal] = ACTIONS(4902),
    [sym_time_literal] = ACTIONS(4902),
    [sym_biginteger_literal] = ACTIONS(4925),
    [anon_sym_else] = ACTIONS(4928),
    [anon_sym_ELSE] = ACTIONS(4928),
    [anon_sym_Else] = ACTIONS(4928),
    [sym_page_keyword] = ACTIONS(4922),
    [anon_sym_codeunit] = ACTIONS(4930),
    [anon_sym_CODEUNIT] = ACTIONS(4930),
    [anon_sym_Codeunit] = ACTIONS(4930),
    [anon_sym_CodeUnit] = ACTIONS(4930),
    [anon_sym_COdeunit] = ACTIONS(4930),
    [anon_sym_codeUnit] = ACTIONS(4930),
    [sym_report_keyword] = ACTIONS(4922),
    [sym_query_keyword] = ACTIONS(4922),
    [anon_sym_xmlport] = ACTIONS(4933),
    [anon_sym_XMLPORT] = ACTIONS(4933),
    [anon_sym_Xmlport] = ACTIONS(4933),
    [anon_sym_XMLport] = ACTIONS(4933),
    [anon_sym_XMLPort] = ACTIONS(4933),
    [anon_sym_XmlPort] = ACTIONS(4933),
    [anon_sym_enum] = ACTIONS(4936),
    [anon_sym_ENUM] = ACTIONS(4936),
    [anon_sym_Enum] = ACTIONS(4936),
    [anon_sym_eNUM] = ACTIONS(4936),
    [anon_sym_eNum] = ACTIONS(4936),
    [anon_sym_ENum] = ACTIONS(4936),
    [sym_quoted_identifier] = ACTIONS(4939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4925),
    [sym_integer] = ACTIONS(4902),
    [sym_continue_as_identifier] = ACTIONS(4942),
    [sym_preproc_open] = ACTIONS(4914),
    [sym_preproc_close] = ACTIONS(4920),
  },
  [STATE(1940)] = {
    [sym_identifier] = ACTIONS(4672),
    [anon_sym_SEMI] = ACTIONS(4674),
    [anon_sym_DASH] = ACTIONS(4674),
    [aux_sym_boolean_token1] = ACTIONS(4672),
    [aux_sym_boolean_token2] = ACTIONS(4672),
    [sym_decimal] = ACTIONS(4672),
    [anon_sym_LPAREN] = ACTIONS(4674),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4672),
    [anon_sym_LBRACK] = ACTIONS(4674),
    [aux_sym_record_type_token1] = ACTIONS(4672),
    [aux_sym_basic_type_token21] = ACTIONS(4672),
    [aux_sym_basic_type_token22] = ACTIONS(4672),
    [aux_sym_basic_type_token48] = ACTIONS(4672),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4672),
    [anon_sym_POUNDif] = ACTIONS(4674),
    [anon_sym_POUNDIF] = ACTIONS(4674),
    [anon_sym_POUNDIf] = ACTIONS(4674),
    [anon_sym_not] = ACTIONS(4672),
    [anon_sym_NOT] = ACTIONS(4672),
    [anon_sym_Not] = ACTIONS(4672),
    [anon_sym_POUNDelse] = ACTIONS(4674),
    [anon_sym_POUNDELSE] = ACTIONS(4674),
    [anon_sym_POUNDElse] = ACTIONS(4674),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4672),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4672),
    [anon_sym_PLUS] = ACTIONS(4674),
    [sym_datetime_literal] = ACTIONS(4674),
    [sym_date_literal] = ACTIONS(4672),
    [sym_time_literal] = ACTIONS(4672),
    [sym_biginteger_literal] = ACTIONS(4674),
    [anon_sym_if] = ACTIONS(4672),
    [anon_sym_IF] = ACTIONS(4672),
    [anon_sym_If] = ACTIONS(4672),
    [anon_sym_else] = ACTIONS(4672),
    [anon_sym_ELSE] = ACTIONS(4672),
    [anon_sym_Else] = ACTIONS(4672),
    [anon_sym_case] = ACTIONS(4672),
    [anon_sym_CASE] = ACTIONS(4672),
    [anon_sym_Case] = ACTIONS(4672),
    [anon_sym_for] = ACTIONS(4672),
    [anon_sym_FOR] = ACTIONS(4672),
    [anon_sym_For] = ACTIONS(4672),
    [anon_sym_foreach] = ACTIONS(4672),
    [anon_sym_FOREACH] = ACTIONS(4672),
    [anon_sym_Foreach] = ACTIONS(4672),
    [anon_sym_while] = ACTIONS(4672),
    [anon_sym_WHILE] = ACTIONS(4672),
    [anon_sym_While] = ACTIONS(4672),
    [anon_sym_repeat] = ACTIONS(4672),
    [anon_sym_REPEAT] = ACTIONS(4672),
    [anon_sym_Repeat] = ACTIONS(4672),
    [anon_sym_until] = ACTIONS(4672),
    [anon_sym_UNTIL] = ACTIONS(4672),
    [anon_sym_Until] = ACTIONS(4672),
    [anon_sym_exit] = ACTIONS(4672),
    [anon_sym_EXIT] = ACTIONS(4672),
    [anon_sym_Exit] = ACTIONS(4672),
    [anon_sym_continue] = ACTIONS(4672),
    [anon_sym_CONTINUE] = ACTIONS(4672),
    [anon_sym_Continue] = ACTIONS(4672),
    [anon_sym_break] = ACTIONS(4672),
    [anon_sym_BREAK] = ACTIONS(4672),
    [anon_sym_Break] = ACTIONS(4672),
    [anon_sym_with] = ACTIONS(4672),
    [anon_sym_WITH] = ACTIONS(4672),
    [anon_sym_With] = ACTIONS(4672),
    [sym_asserterror_keyword] = ACTIONS(4674),
    [sym_page_keyword] = ACTIONS(4672),
    [anon_sym_codeunit] = ACTIONS(4672),
    [anon_sym_CODEUNIT] = ACTIONS(4672),
    [anon_sym_Codeunit] = ACTIONS(4672),
    [anon_sym_CodeUnit] = ACTIONS(4672),
    [anon_sym_COdeunit] = ACTIONS(4672),
    [anon_sym_codeUnit] = ACTIONS(4672),
    [sym_report_keyword] = ACTIONS(4672),
    [sym_query_keyword] = ACTIONS(4672),
    [anon_sym_xmlport] = ACTIONS(4672),
    [anon_sym_XMLPORT] = ACTIONS(4672),
    [anon_sym_Xmlport] = ACTIONS(4672),
    [anon_sym_XMLport] = ACTIONS(4672),
    [anon_sym_XMLPort] = ACTIONS(4672),
    [anon_sym_XmlPort] = ACTIONS(4672),
    [anon_sym_enum] = ACTIONS(4672),
    [anon_sym_ENUM] = ACTIONS(4672),
    [anon_sym_Enum] = ACTIONS(4672),
    [anon_sym_eNUM] = ACTIONS(4672),
    [anon_sym_eNum] = ACTIONS(4672),
    [anon_sym_ENum] = ACTIONS(4672),
    [sym_quoted_identifier] = ACTIONS(4674),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4674),
    [sym_integer] = ACTIONS(4672),
    [sym_continue_as_identifier] = ACTIONS(4674),
    [sym_preproc_open] = ACTIONS(4674),
  },
  [STATE(1941)] = {
    [sym_identifier] = ACTIONS(4676),
    [anon_sym_SEMI] = ACTIONS(4678),
    [anon_sym_DASH] = ACTIONS(4678),
    [aux_sym_boolean_token1] = ACTIONS(4676),
    [aux_sym_boolean_token2] = ACTIONS(4676),
    [sym_decimal] = ACTIONS(4676),
    [anon_sym_LPAREN] = ACTIONS(4678),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4676),
    [anon_sym_LBRACK] = ACTIONS(4678),
    [aux_sym_record_type_token1] = ACTIONS(4676),
    [aux_sym_basic_type_token21] = ACTIONS(4676),
    [aux_sym_basic_type_token22] = ACTIONS(4676),
    [aux_sym_basic_type_token48] = ACTIONS(4676),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4676),
    [anon_sym_POUNDif] = ACTIONS(4678),
    [anon_sym_POUNDIF] = ACTIONS(4678),
    [anon_sym_POUNDIf] = ACTIONS(4678),
    [anon_sym_not] = ACTIONS(4676),
    [anon_sym_NOT] = ACTIONS(4676),
    [anon_sym_Not] = ACTIONS(4676),
    [anon_sym_POUNDelse] = ACTIONS(4678),
    [anon_sym_POUNDELSE] = ACTIONS(4678),
    [anon_sym_POUNDElse] = ACTIONS(4678),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4676),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4676),
    [anon_sym_PLUS] = ACTIONS(4678),
    [sym_datetime_literal] = ACTIONS(4678),
    [sym_date_literal] = ACTIONS(4676),
    [sym_time_literal] = ACTIONS(4676),
    [sym_biginteger_literal] = ACTIONS(4678),
    [anon_sym_if] = ACTIONS(4676),
    [anon_sym_IF] = ACTIONS(4676),
    [anon_sym_If] = ACTIONS(4676),
    [anon_sym_else] = ACTIONS(4676),
    [anon_sym_ELSE] = ACTIONS(4676),
    [anon_sym_Else] = ACTIONS(4676),
    [anon_sym_case] = ACTIONS(4676),
    [anon_sym_CASE] = ACTIONS(4676),
    [anon_sym_Case] = ACTIONS(4676),
    [anon_sym_for] = ACTIONS(4676),
    [anon_sym_FOR] = ACTIONS(4676),
    [anon_sym_For] = ACTIONS(4676),
    [anon_sym_foreach] = ACTIONS(4676),
    [anon_sym_FOREACH] = ACTIONS(4676),
    [anon_sym_Foreach] = ACTIONS(4676),
    [anon_sym_while] = ACTIONS(4676),
    [anon_sym_WHILE] = ACTIONS(4676),
    [anon_sym_While] = ACTIONS(4676),
    [anon_sym_repeat] = ACTIONS(4676),
    [anon_sym_REPEAT] = ACTIONS(4676),
    [anon_sym_Repeat] = ACTIONS(4676),
    [anon_sym_until] = ACTIONS(4676),
    [anon_sym_UNTIL] = ACTIONS(4676),
    [anon_sym_Until] = ACTIONS(4676),
    [anon_sym_exit] = ACTIONS(4676),
    [anon_sym_EXIT] = ACTIONS(4676),
    [anon_sym_Exit] = ACTIONS(4676),
    [anon_sym_continue] = ACTIONS(4676),
    [anon_sym_CONTINUE] = ACTIONS(4676),
    [anon_sym_Continue] = ACTIONS(4676),
    [anon_sym_break] = ACTIONS(4676),
    [anon_sym_BREAK] = ACTIONS(4676),
    [anon_sym_Break] = ACTIONS(4676),
    [anon_sym_with] = ACTIONS(4676),
    [anon_sym_WITH] = ACTIONS(4676),
    [anon_sym_With] = ACTIONS(4676),
    [sym_asserterror_keyword] = ACTIONS(4678),
    [sym_page_keyword] = ACTIONS(4676),
    [anon_sym_codeunit] = ACTIONS(4676),
    [anon_sym_CODEUNIT] = ACTIONS(4676),
    [anon_sym_Codeunit] = ACTIONS(4676),
    [anon_sym_CodeUnit] = ACTIONS(4676),
    [anon_sym_COdeunit] = ACTIONS(4676),
    [anon_sym_codeUnit] = ACTIONS(4676),
    [sym_report_keyword] = ACTIONS(4676),
    [sym_query_keyword] = ACTIONS(4676),
    [anon_sym_xmlport] = ACTIONS(4676),
    [anon_sym_XMLPORT] = ACTIONS(4676),
    [anon_sym_Xmlport] = ACTIONS(4676),
    [anon_sym_XMLport] = ACTIONS(4676),
    [anon_sym_XMLPort] = ACTIONS(4676),
    [anon_sym_XmlPort] = ACTIONS(4676),
    [anon_sym_enum] = ACTIONS(4676),
    [anon_sym_ENUM] = ACTIONS(4676),
    [anon_sym_Enum] = ACTIONS(4676),
    [anon_sym_eNUM] = ACTIONS(4676),
    [anon_sym_eNum] = ACTIONS(4676),
    [anon_sym_ENum] = ACTIONS(4676),
    [sym_quoted_identifier] = ACTIONS(4678),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4678),
    [sym_integer] = ACTIONS(4676),
    [sym_continue_as_identifier] = ACTIONS(4678),
    [sym_preproc_open] = ACTIONS(4678),
  },
  [STATE(1942)] = {
    [sym_identifier] = ACTIONS(4680),
    [anon_sym_SEMI] = ACTIONS(4682),
    [anon_sym_DASH] = ACTIONS(4682),
    [aux_sym_boolean_token1] = ACTIONS(4680),
    [aux_sym_boolean_token2] = ACTIONS(4680),
    [sym_decimal] = ACTIONS(4680),
    [anon_sym_LPAREN] = ACTIONS(4682),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4680),
    [anon_sym_LBRACK] = ACTIONS(4682),
    [aux_sym_record_type_token1] = ACTIONS(4680),
    [aux_sym_basic_type_token21] = ACTIONS(4680),
    [aux_sym_basic_type_token22] = ACTIONS(4680),
    [aux_sym_basic_type_token48] = ACTIONS(4680),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4680),
    [anon_sym_POUNDif] = ACTIONS(4682),
    [anon_sym_POUNDIF] = ACTIONS(4682),
    [anon_sym_POUNDIf] = ACTIONS(4682),
    [anon_sym_not] = ACTIONS(4680),
    [anon_sym_NOT] = ACTIONS(4680),
    [anon_sym_Not] = ACTIONS(4680),
    [anon_sym_POUNDelse] = ACTIONS(4682),
    [anon_sym_POUNDELSE] = ACTIONS(4682),
    [anon_sym_POUNDElse] = ACTIONS(4682),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4680),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4680),
    [anon_sym_PLUS] = ACTIONS(4682),
    [sym_datetime_literal] = ACTIONS(4682),
    [sym_date_literal] = ACTIONS(4680),
    [sym_time_literal] = ACTIONS(4680),
    [sym_biginteger_literal] = ACTIONS(4682),
    [anon_sym_if] = ACTIONS(4680),
    [anon_sym_IF] = ACTIONS(4680),
    [anon_sym_If] = ACTIONS(4680),
    [anon_sym_else] = ACTIONS(4680),
    [anon_sym_ELSE] = ACTIONS(4680),
    [anon_sym_Else] = ACTIONS(4680),
    [anon_sym_case] = ACTIONS(4680),
    [anon_sym_CASE] = ACTIONS(4680),
    [anon_sym_Case] = ACTIONS(4680),
    [anon_sym_for] = ACTIONS(4680),
    [anon_sym_FOR] = ACTIONS(4680),
    [anon_sym_For] = ACTIONS(4680),
    [anon_sym_foreach] = ACTIONS(4680),
    [anon_sym_FOREACH] = ACTIONS(4680),
    [anon_sym_Foreach] = ACTIONS(4680),
    [anon_sym_while] = ACTIONS(4680),
    [anon_sym_WHILE] = ACTIONS(4680),
    [anon_sym_While] = ACTIONS(4680),
    [anon_sym_repeat] = ACTIONS(4680),
    [anon_sym_REPEAT] = ACTIONS(4680),
    [anon_sym_Repeat] = ACTIONS(4680),
    [anon_sym_until] = ACTIONS(4680),
    [anon_sym_UNTIL] = ACTIONS(4680),
    [anon_sym_Until] = ACTIONS(4680),
    [anon_sym_exit] = ACTIONS(4680),
    [anon_sym_EXIT] = ACTIONS(4680),
    [anon_sym_Exit] = ACTIONS(4680),
    [anon_sym_continue] = ACTIONS(4680),
    [anon_sym_CONTINUE] = ACTIONS(4680),
    [anon_sym_Continue] = ACTIONS(4680),
    [anon_sym_break] = ACTIONS(4680),
    [anon_sym_BREAK] = ACTIONS(4680),
    [anon_sym_Break] = ACTIONS(4680),
    [anon_sym_with] = ACTIONS(4680),
    [anon_sym_WITH] = ACTIONS(4680),
    [anon_sym_With] = ACTIONS(4680),
    [sym_asserterror_keyword] = ACTIONS(4682),
    [sym_page_keyword] = ACTIONS(4680),
    [anon_sym_codeunit] = ACTIONS(4680),
    [anon_sym_CODEUNIT] = ACTIONS(4680),
    [anon_sym_Codeunit] = ACTIONS(4680),
    [anon_sym_CodeUnit] = ACTIONS(4680),
    [anon_sym_COdeunit] = ACTIONS(4680),
    [anon_sym_codeUnit] = ACTIONS(4680),
    [sym_report_keyword] = ACTIONS(4680),
    [sym_query_keyword] = ACTIONS(4680),
    [anon_sym_xmlport] = ACTIONS(4680),
    [anon_sym_XMLPORT] = ACTIONS(4680),
    [anon_sym_Xmlport] = ACTIONS(4680),
    [anon_sym_XMLport] = ACTIONS(4680),
    [anon_sym_XMLPort] = ACTIONS(4680),
    [anon_sym_XmlPort] = ACTIONS(4680),
    [anon_sym_enum] = ACTIONS(4680),
    [anon_sym_ENUM] = ACTIONS(4680),
    [anon_sym_Enum] = ACTIONS(4680),
    [anon_sym_eNUM] = ACTIONS(4680),
    [anon_sym_eNum] = ACTIONS(4680),
    [anon_sym_ENum] = ACTIONS(4680),
    [sym_quoted_identifier] = ACTIONS(4682),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4682),
    [sym_integer] = ACTIONS(4680),
    [sym_continue_as_identifier] = ACTIONS(4682),
    [sym_preproc_open] = ACTIONS(4682),
  },
  [STATE(1943)] = {
    [sym_identifier] = ACTIONS(4684),
    [anon_sym_SEMI] = ACTIONS(4686),
    [anon_sym_DASH] = ACTIONS(4686),
    [aux_sym_boolean_token1] = ACTIONS(4684),
    [aux_sym_boolean_token2] = ACTIONS(4684),
    [sym_decimal] = ACTIONS(4684),
    [anon_sym_LPAREN] = ACTIONS(4686),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4686),
    [aux_sym_record_type_token1] = ACTIONS(4684),
    [aux_sym_basic_type_token21] = ACTIONS(4684),
    [aux_sym_basic_type_token22] = ACTIONS(4684),
    [aux_sym_basic_type_token48] = ACTIONS(4684),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4684),
    [anon_sym_POUNDif] = ACTIONS(4686),
    [anon_sym_POUNDIF] = ACTIONS(4686),
    [anon_sym_POUNDIf] = ACTIONS(4686),
    [anon_sym_not] = ACTIONS(4684),
    [anon_sym_NOT] = ACTIONS(4684),
    [anon_sym_Not] = ACTIONS(4684),
    [anon_sym_POUNDelse] = ACTIONS(4686),
    [anon_sym_POUNDELSE] = ACTIONS(4686),
    [anon_sym_POUNDElse] = ACTIONS(4686),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4684),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4684),
    [anon_sym_PLUS] = ACTIONS(4686),
    [sym_datetime_literal] = ACTIONS(4686),
    [sym_date_literal] = ACTIONS(4684),
    [sym_time_literal] = ACTIONS(4684),
    [sym_biginteger_literal] = ACTIONS(4686),
    [anon_sym_if] = ACTIONS(4684),
    [anon_sym_IF] = ACTIONS(4684),
    [anon_sym_If] = ACTIONS(4684),
    [anon_sym_else] = ACTIONS(4684),
    [anon_sym_ELSE] = ACTIONS(4684),
    [anon_sym_Else] = ACTIONS(4684),
    [anon_sym_case] = ACTIONS(4684),
    [anon_sym_CASE] = ACTIONS(4684),
    [anon_sym_Case] = ACTIONS(4684),
    [anon_sym_for] = ACTIONS(4684),
    [anon_sym_FOR] = ACTIONS(4684),
    [anon_sym_For] = ACTIONS(4684),
    [anon_sym_foreach] = ACTIONS(4684),
    [anon_sym_FOREACH] = ACTIONS(4684),
    [anon_sym_Foreach] = ACTIONS(4684),
    [anon_sym_while] = ACTIONS(4684),
    [anon_sym_WHILE] = ACTIONS(4684),
    [anon_sym_While] = ACTIONS(4684),
    [anon_sym_repeat] = ACTIONS(4684),
    [anon_sym_REPEAT] = ACTIONS(4684),
    [anon_sym_Repeat] = ACTIONS(4684),
    [anon_sym_until] = ACTIONS(4684),
    [anon_sym_UNTIL] = ACTIONS(4684),
    [anon_sym_Until] = ACTIONS(4684),
    [anon_sym_exit] = ACTIONS(4684),
    [anon_sym_EXIT] = ACTIONS(4684),
    [anon_sym_Exit] = ACTIONS(4684),
    [anon_sym_continue] = ACTIONS(4684),
    [anon_sym_CONTINUE] = ACTIONS(4684),
    [anon_sym_Continue] = ACTIONS(4684),
    [anon_sym_break] = ACTIONS(4684),
    [anon_sym_BREAK] = ACTIONS(4684),
    [anon_sym_Break] = ACTIONS(4684),
    [anon_sym_with] = ACTIONS(4684),
    [anon_sym_WITH] = ACTIONS(4684),
    [anon_sym_With] = ACTIONS(4684),
    [sym_asserterror_keyword] = ACTIONS(4686),
    [sym_page_keyword] = ACTIONS(4684),
    [anon_sym_codeunit] = ACTIONS(4684),
    [anon_sym_CODEUNIT] = ACTIONS(4684),
    [anon_sym_Codeunit] = ACTIONS(4684),
    [anon_sym_CodeUnit] = ACTIONS(4684),
    [anon_sym_COdeunit] = ACTIONS(4684),
    [anon_sym_codeUnit] = ACTIONS(4684),
    [sym_report_keyword] = ACTIONS(4684),
    [sym_query_keyword] = ACTIONS(4684),
    [anon_sym_xmlport] = ACTIONS(4684),
    [anon_sym_XMLPORT] = ACTIONS(4684),
    [anon_sym_Xmlport] = ACTIONS(4684),
    [anon_sym_XMLport] = ACTIONS(4684),
    [anon_sym_XMLPort] = ACTIONS(4684),
    [anon_sym_XmlPort] = ACTIONS(4684),
    [anon_sym_enum] = ACTIONS(4684),
    [anon_sym_ENUM] = ACTIONS(4684),
    [anon_sym_Enum] = ACTIONS(4684),
    [anon_sym_eNUM] = ACTIONS(4684),
    [anon_sym_eNum] = ACTIONS(4684),
    [anon_sym_ENum] = ACTIONS(4684),
    [sym_quoted_identifier] = ACTIONS(4686),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4686),
    [sym_integer] = ACTIONS(4684),
    [sym_continue_as_identifier] = ACTIONS(4686),
    [sym_preproc_open] = ACTIONS(4686),
  },
  [STATE(1944)] = {
    [sym_identifier] = ACTIONS(4716),
    [anon_sym_SEMI] = ACTIONS(4718),
    [anon_sym_DASH] = ACTIONS(4718),
    [aux_sym_boolean_token1] = ACTIONS(4716),
    [aux_sym_boolean_token2] = ACTIONS(4716),
    [sym_decimal] = ACTIONS(4716),
    [anon_sym_LPAREN] = ACTIONS(4718),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4716),
    [anon_sym_LBRACK] = ACTIONS(4718),
    [aux_sym_record_type_token1] = ACTIONS(4716),
    [aux_sym_basic_type_token21] = ACTIONS(4716),
    [aux_sym_basic_type_token22] = ACTIONS(4716),
    [aux_sym_basic_type_token48] = ACTIONS(4716),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4716),
    [anon_sym_POUNDif] = ACTIONS(4718),
    [anon_sym_POUNDIF] = ACTIONS(4718),
    [anon_sym_POUNDIf] = ACTIONS(4718),
    [anon_sym_not] = ACTIONS(4716),
    [anon_sym_NOT] = ACTIONS(4716),
    [anon_sym_Not] = ACTIONS(4716),
    [anon_sym_POUNDelse] = ACTIONS(4718),
    [anon_sym_POUNDELSE] = ACTIONS(4718),
    [anon_sym_POUNDElse] = ACTIONS(4718),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4716),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4716),
    [anon_sym_PLUS] = ACTIONS(4718),
    [sym_datetime_literal] = ACTIONS(4718),
    [sym_date_literal] = ACTIONS(4716),
    [sym_time_literal] = ACTIONS(4716),
    [sym_biginteger_literal] = ACTIONS(4718),
    [anon_sym_if] = ACTIONS(4716),
    [anon_sym_IF] = ACTIONS(4716),
    [anon_sym_If] = ACTIONS(4716),
    [anon_sym_else] = ACTIONS(4716),
    [anon_sym_ELSE] = ACTIONS(4716),
    [anon_sym_Else] = ACTIONS(4716),
    [anon_sym_case] = ACTIONS(4716),
    [anon_sym_CASE] = ACTIONS(4716),
    [anon_sym_Case] = ACTIONS(4716),
    [anon_sym_for] = ACTIONS(4716),
    [anon_sym_FOR] = ACTIONS(4716),
    [anon_sym_For] = ACTIONS(4716),
    [anon_sym_foreach] = ACTIONS(4716),
    [anon_sym_FOREACH] = ACTIONS(4716),
    [anon_sym_Foreach] = ACTIONS(4716),
    [anon_sym_while] = ACTIONS(4716),
    [anon_sym_WHILE] = ACTIONS(4716),
    [anon_sym_While] = ACTIONS(4716),
    [anon_sym_repeat] = ACTIONS(4716),
    [anon_sym_REPEAT] = ACTIONS(4716),
    [anon_sym_Repeat] = ACTIONS(4716),
    [anon_sym_until] = ACTIONS(4716),
    [anon_sym_UNTIL] = ACTIONS(4716),
    [anon_sym_Until] = ACTIONS(4716),
    [anon_sym_exit] = ACTIONS(4716),
    [anon_sym_EXIT] = ACTIONS(4716),
    [anon_sym_Exit] = ACTIONS(4716),
    [anon_sym_continue] = ACTIONS(4716),
    [anon_sym_CONTINUE] = ACTIONS(4716),
    [anon_sym_Continue] = ACTIONS(4716),
    [anon_sym_break] = ACTIONS(4716),
    [anon_sym_BREAK] = ACTIONS(4716),
    [anon_sym_Break] = ACTIONS(4716),
    [anon_sym_with] = ACTIONS(4716),
    [anon_sym_WITH] = ACTIONS(4716),
    [anon_sym_With] = ACTIONS(4716),
    [sym_asserterror_keyword] = ACTIONS(4718),
    [sym_page_keyword] = ACTIONS(4716),
    [anon_sym_codeunit] = ACTIONS(4716),
    [anon_sym_CODEUNIT] = ACTIONS(4716),
    [anon_sym_Codeunit] = ACTIONS(4716),
    [anon_sym_CodeUnit] = ACTIONS(4716),
    [anon_sym_COdeunit] = ACTIONS(4716),
    [anon_sym_codeUnit] = ACTIONS(4716),
    [sym_report_keyword] = ACTIONS(4716),
    [sym_query_keyword] = ACTIONS(4716),
    [anon_sym_xmlport] = ACTIONS(4716),
    [anon_sym_XMLPORT] = ACTIONS(4716),
    [anon_sym_Xmlport] = ACTIONS(4716),
    [anon_sym_XMLport] = ACTIONS(4716),
    [anon_sym_XMLPort] = ACTIONS(4716),
    [anon_sym_XmlPort] = ACTIONS(4716),
    [anon_sym_enum] = ACTIONS(4716),
    [anon_sym_ENUM] = ACTIONS(4716),
    [anon_sym_Enum] = ACTIONS(4716),
    [anon_sym_eNUM] = ACTIONS(4716),
    [anon_sym_eNum] = ACTIONS(4716),
    [anon_sym_ENum] = ACTIONS(4716),
    [sym_quoted_identifier] = ACTIONS(4718),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4718),
    [sym_integer] = ACTIONS(4716),
    [sym_continue_as_identifier] = ACTIONS(4718),
    [sym_preproc_open] = ACTIONS(4718),
  },
  [STATE(1945)] = {
    [sym_identifier] = ACTIONS(4720),
    [anon_sym_SEMI] = ACTIONS(4722),
    [anon_sym_DASH] = ACTIONS(4722),
    [aux_sym_boolean_token1] = ACTIONS(4720),
    [aux_sym_boolean_token2] = ACTIONS(4720),
    [sym_decimal] = ACTIONS(4720),
    [anon_sym_LPAREN] = ACTIONS(4722),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4720),
    [anon_sym_LBRACK] = ACTIONS(4722),
    [aux_sym_record_type_token1] = ACTIONS(4720),
    [aux_sym_basic_type_token21] = ACTIONS(4720),
    [aux_sym_basic_type_token22] = ACTIONS(4720),
    [aux_sym_basic_type_token48] = ACTIONS(4720),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4720),
    [anon_sym_POUNDif] = ACTIONS(4722),
    [anon_sym_POUNDIF] = ACTIONS(4722),
    [anon_sym_POUNDIf] = ACTIONS(4722),
    [anon_sym_not] = ACTIONS(4720),
    [anon_sym_NOT] = ACTIONS(4720),
    [anon_sym_Not] = ACTIONS(4720),
    [anon_sym_POUNDelse] = ACTIONS(4722),
    [anon_sym_POUNDELSE] = ACTIONS(4722),
    [anon_sym_POUNDElse] = ACTIONS(4722),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4720),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4720),
    [anon_sym_PLUS] = ACTIONS(4722),
    [sym_datetime_literal] = ACTIONS(4722),
    [sym_date_literal] = ACTIONS(4720),
    [sym_time_literal] = ACTIONS(4720),
    [sym_biginteger_literal] = ACTIONS(4722),
    [anon_sym_if] = ACTIONS(4720),
    [anon_sym_IF] = ACTIONS(4720),
    [anon_sym_If] = ACTIONS(4720),
    [anon_sym_else] = ACTIONS(4720),
    [anon_sym_ELSE] = ACTIONS(4720),
    [anon_sym_Else] = ACTIONS(4720),
    [anon_sym_case] = ACTIONS(4720),
    [anon_sym_CASE] = ACTIONS(4720),
    [anon_sym_Case] = ACTIONS(4720),
    [anon_sym_for] = ACTIONS(4720),
    [anon_sym_FOR] = ACTIONS(4720),
    [anon_sym_For] = ACTIONS(4720),
    [anon_sym_foreach] = ACTIONS(4720),
    [anon_sym_FOREACH] = ACTIONS(4720),
    [anon_sym_Foreach] = ACTIONS(4720),
    [anon_sym_while] = ACTIONS(4720),
    [anon_sym_WHILE] = ACTIONS(4720),
    [anon_sym_While] = ACTIONS(4720),
    [anon_sym_repeat] = ACTIONS(4720),
    [anon_sym_REPEAT] = ACTIONS(4720),
    [anon_sym_Repeat] = ACTIONS(4720),
    [anon_sym_until] = ACTIONS(4720),
    [anon_sym_UNTIL] = ACTIONS(4720),
    [anon_sym_Until] = ACTIONS(4720),
    [anon_sym_exit] = ACTIONS(4720),
    [anon_sym_EXIT] = ACTIONS(4720),
    [anon_sym_Exit] = ACTIONS(4720),
    [anon_sym_continue] = ACTIONS(4720),
    [anon_sym_CONTINUE] = ACTIONS(4720),
    [anon_sym_Continue] = ACTIONS(4720),
    [anon_sym_break] = ACTIONS(4720),
    [anon_sym_BREAK] = ACTIONS(4720),
    [anon_sym_Break] = ACTIONS(4720),
    [anon_sym_with] = ACTIONS(4720),
    [anon_sym_WITH] = ACTIONS(4720),
    [anon_sym_With] = ACTIONS(4720),
    [sym_asserterror_keyword] = ACTIONS(4722),
    [sym_page_keyword] = ACTIONS(4720),
    [anon_sym_codeunit] = ACTIONS(4720),
    [anon_sym_CODEUNIT] = ACTIONS(4720),
    [anon_sym_Codeunit] = ACTIONS(4720),
    [anon_sym_CodeUnit] = ACTIONS(4720),
    [anon_sym_COdeunit] = ACTIONS(4720),
    [anon_sym_codeUnit] = ACTIONS(4720),
    [sym_report_keyword] = ACTIONS(4720),
    [sym_query_keyword] = ACTIONS(4720),
    [anon_sym_xmlport] = ACTIONS(4720),
    [anon_sym_XMLPORT] = ACTIONS(4720),
    [anon_sym_Xmlport] = ACTIONS(4720),
    [anon_sym_XMLport] = ACTIONS(4720),
    [anon_sym_XMLPort] = ACTIONS(4720),
    [anon_sym_XmlPort] = ACTIONS(4720),
    [anon_sym_enum] = ACTIONS(4720),
    [anon_sym_ENUM] = ACTIONS(4720),
    [anon_sym_Enum] = ACTIONS(4720),
    [anon_sym_eNUM] = ACTIONS(4720),
    [anon_sym_eNum] = ACTIONS(4720),
    [anon_sym_ENum] = ACTIONS(4720),
    [sym_quoted_identifier] = ACTIONS(4722),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4722),
    [sym_integer] = ACTIONS(4720),
    [sym_continue_as_identifier] = ACTIONS(4722),
    [sym_preproc_open] = ACTIONS(4722),
  },
  [STATE(1946)] = {
    [sym_identifier] = ACTIONS(4724),
    [anon_sym_SEMI] = ACTIONS(4726),
    [anon_sym_DASH] = ACTIONS(4726),
    [aux_sym_boolean_token1] = ACTIONS(4724),
    [aux_sym_boolean_token2] = ACTIONS(4724),
    [sym_decimal] = ACTIONS(4724),
    [anon_sym_LPAREN] = ACTIONS(4726),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4724),
    [anon_sym_LBRACK] = ACTIONS(4726),
    [aux_sym_record_type_token1] = ACTIONS(4724),
    [aux_sym_basic_type_token21] = ACTIONS(4724),
    [aux_sym_basic_type_token22] = ACTIONS(4724),
    [aux_sym_basic_type_token48] = ACTIONS(4724),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4724),
    [anon_sym_POUNDif] = ACTIONS(4726),
    [anon_sym_POUNDIF] = ACTIONS(4726),
    [anon_sym_POUNDIf] = ACTIONS(4726),
    [anon_sym_not] = ACTIONS(4724),
    [anon_sym_NOT] = ACTIONS(4724),
    [anon_sym_Not] = ACTIONS(4724),
    [anon_sym_POUNDelse] = ACTIONS(4726),
    [anon_sym_POUNDELSE] = ACTIONS(4726),
    [anon_sym_POUNDElse] = ACTIONS(4726),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4724),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4724),
    [anon_sym_PLUS] = ACTIONS(4726),
    [sym_datetime_literal] = ACTIONS(4726),
    [sym_date_literal] = ACTIONS(4724),
    [sym_time_literal] = ACTIONS(4724),
    [sym_biginteger_literal] = ACTIONS(4726),
    [anon_sym_if] = ACTIONS(4724),
    [anon_sym_IF] = ACTIONS(4724),
    [anon_sym_If] = ACTIONS(4724),
    [anon_sym_else] = ACTIONS(4724),
    [anon_sym_ELSE] = ACTIONS(4724),
    [anon_sym_Else] = ACTIONS(4724),
    [anon_sym_case] = ACTIONS(4724),
    [anon_sym_CASE] = ACTIONS(4724),
    [anon_sym_Case] = ACTIONS(4724),
    [anon_sym_for] = ACTIONS(4724),
    [anon_sym_FOR] = ACTIONS(4724),
    [anon_sym_For] = ACTIONS(4724),
    [anon_sym_foreach] = ACTIONS(4724),
    [anon_sym_FOREACH] = ACTIONS(4724),
    [anon_sym_Foreach] = ACTIONS(4724),
    [anon_sym_while] = ACTIONS(4724),
    [anon_sym_WHILE] = ACTIONS(4724),
    [anon_sym_While] = ACTIONS(4724),
    [anon_sym_repeat] = ACTIONS(4724),
    [anon_sym_REPEAT] = ACTIONS(4724),
    [anon_sym_Repeat] = ACTIONS(4724),
    [anon_sym_until] = ACTIONS(4724),
    [anon_sym_UNTIL] = ACTIONS(4724),
    [anon_sym_Until] = ACTIONS(4724),
    [anon_sym_exit] = ACTIONS(4724),
    [anon_sym_EXIT] = ACTIONS(4724),
    [anon_sym_Exit] = ACTIONS(4724),
    [anon_sym_continue] = ACTIONS(4724),
    [anon_sym_CONTINUE] = ACTIONS(4724),
    [anon_sym_Continue] = ACTIONS(4724),
    [anon_sym_break] = ACTIONS(4724),
    [anon_sym_BREAK] = ACTIONS(4724),
    [anon_sym_Break] = ACTIONS(4724),
    [anon_sym_with] = ACTIONS(4724),
    [anon_sym_WITH] = ACTIONS(4724),
    [anon_sym_With] = ACTIONS(4724),
    [sym_asserterror_keyword] = ACTIONS(4726),
    [sym_page_keyword] = ACTIONS(4724),
    [anon_sym_codeunit] = ACTIONS(4724),
    [anon_sym_CODEUNIT] = ACTIONS(4724),
    [anon_sym_Codeunit] = ACTIONS(4724),
    [anon_sym_CodeUnit] = ACTIONS(4724),
    [anon_sym_COdeunit] = ACTIONS(4724),
    [anon_sym_codeUnit] = ACTIONS(4724),
    [sym_report_keyword] = ACTIONS(4724),
    [sym_query_keyword] = ACTIONS(4724),
    [anon_sym_xmlport] = ACTIONS(4724),
    [anon_sym_XMLPORT] = ACTIONS(4724),
    [anon_sym_Xmlport] = ACTIONS(4724),
    [anon_sym_XMLport] = ACTIONS(4724),
    [anon_sym_XMLPort] = ACTIONS(4724),
    [anon_sym_XmlPort] = ACTIONS(4724),
    [anon_sym_enum] = ACTIONS(4724),
    [anon_sym_ENUM] = ACTIONS(4724),
    [anon_sym_Enum] = ACTIONS(4724),
    [anon_sym_eNUM] = ACTIONS(4724),
    [anon_sym_eNum] = ACTIONS(4724),
    [anon_sym_ENum] = ACTIONS(4724),
    [sym_quoted_identifier] = ACTIONS(4726),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4726),
    [sym_integer] = ACTIONS(4724),
    [sym_continue_as_identifier] = ACTIONS(4726),
    [sym_preproc_open] = ACTIONS(4726),
  },
  [STATE(1947)] = {
    [sym_identifier] = ACTIONS(4764),
    [anon_sym_SEMI] = ACTIONS(4766),
    [anon_sym_DASH] = ACTIONS(4766),
    [aux_sym_boolean_token1] = ACTIONS(4764),
    [aux_sym_boolean_token2] = ACTIONS(4764),
    [sym_decimal] = ACTIONS(4764),
    [anon_sym_LPAREN] = ACTIONS(4766),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4764),
    [anon_sym_LBRACK] = ACTIONS(4766),
    [aux_sym_record_type_token1] = ACTIONS(4764),
    [aux_sym_basic_type_token21] = ACTIONS(4764),
    [aux_sym_basic_type_token22] = ACTIONS(4764),
    [aux_sym_basic_type_token48] = ACTIONS(4764),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4764),
    [anon_sym_POUNDif] = ACTIONS(4766),
    [anon_sym_POUNDIF] = ACTIONS(4766),
    [anon_sym_POUNDIf] = ACTIONS(4766),
    [anon_sym_not] = ACTIONS(4764),
    [anon_sym_NOT] = ACTIONS(4764),
    [anon_sym_Not] = ACTIONS(4764),
    [anon_sym_POUNDelse] = ACTIONS(4766),
    [anon_sym_POUNDELSE] = ACTIONS(4766),
    [anon_sym_POUNDElse] = ACTIONS(4766),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4764),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4764),
    [anon_sym_PLUS] = ACTIONS(4766),
    [sym_datetime_literal] = ACTIONS(4766),
    [sym_date_literal] = ACTIONS(4764),
    [sym_time_literal] = ACTIONS(4764),
    [sym_biginteger_literal] = ACTIONS(4766),
    [anon_sym_if] = ACTIONS(4764),
    [anon_sym_IF] = ACTIONS(4764),
    [anon_sym_If] = ACTIONS(4764),
    [anon_sym_else] = ACTIONS(4764),
    [anon_sym_ELSE] = ACTIONS(4764),
    [anon_sym_Else] = ACTIONS(4764),
    [anon_sym_case] = ACTIONS(4764),
    [anon_sym_CASE] = ACTIONS(4764),
    [anon_sym_Case] = ACTIONS(4764),
    [anon_sym_for] = ACTIONS(4764),
    [anon_sym_FOR] = ACTIONS(4764),
    [anon_sym_For] = ACTIONS(4764),
    [anon_sym_foreach] = ACTIONS(4764),
    [anon_sym_FOREACH] = ACTIONS(4764),
    [anon_sym_Foreach] = ACTIONS(4764),
    [anon_sym_while] = ACTIONS(4764),
    [anon_sym_WHILE] = ACTIONS(4764),
    [anon_sym_While] = ACTIONS(4764),
    [anon_sym_repeat] = ACTIONS(4764),
    [anon_sym_REPEAT] = ACTIONS(4764),
    [anon_sym_Repeat] = ACTIONS(4764),
    [anon_sym_until] = ACTIONS(4764),
    [anon_sym_UNTIL] = ACTIONS(4764),
    [anon_sym_Until] = ACTIONS(4764),
    [anon_sym_exit] = ACTIONS(4764),
    [anon_sym_EXIT] = ACTIONS(4764),
    [anon_sym_Exit] = ACTIONS(4764),
    [anon_sym_continue] = ACTIONS(4764),
    [anon_sym_CONTINUE] = ACTIONS(4764),
    [anon_sym_Continue] = ACTIONS(4764),
    [anon_sym_break] = ACTIONS(4764),
    [anon_sym_BREAK] = ACTIONS(4764),
    [anon_sym_Break] = ACTIONS(4764),
    [anon_sym_with] = ACTIONS(4764),
    [anon_sym_WITH] = ACTIONS(4764),
    [anon_sym_With] = ACTIONS(4764),
    [sym_asserterror_keyword] = ACTIONS(4766),
    [sym_page_keyword] = ACTIONS(4764),
    [anon_sym_codeunit] = ACTIONS(4764),
    [anon_sym_CODEUNIT] = ACTIONS(4764),
    [anon_sym_Codeunit] = ACTIONS(4764),
    [anon_sym_CodeUnit] = ACTIONS(4764),
    [anon_sym_COdeunit] = ACTIONS(4764),
    [anon_sym_codeUnit] = ACTIONS(4764),
    [sym_report_keyword] = ACTIONS(4764),
    [sym_query_keyword] = ACTIONS(4764),
    [anon_sym_xmlport] = ACTIONS(4764),
    [anon_sym_XMLPORT] = ACTIONS(4764),
    [anon_sym_Xmlport] = ACTIONS(4764),
    [anon_sym_XMLport] = ACTIONS(4764),
    [anon_sym_XMLPort] = ACTIONS(4764),
    [anon_sym_XmlPort] = ACTIONS(4764),
    [anon_sym_enum] = ACTIONS(4764),
    [anon_sym_ENUM] = ACTIONS(4764),
    [anon_sym_Enum] = ACTIONS(4764),
    [anon_sym_eNUM] = ACTIONS(4764),
    [anon_sym_eNum] = ACTIONS(4764),
    [anon_sym_ENum] = ACTIONS(4764),
    [sym_quoted_identifier] = ACTIONS(4766),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4766),
    [sym_integer] = ACTIONS(4764),
    [sym_continue_as_identifier] = ACTIONS(4766),
    [sym_preproc_open] = ACTIONS(4766),
  },
  [STATE(1948)] = {
    [anon_sym_POUNDif] = ACTIONS(4945),
    [anon_sym_POUNDIF] = ACTIONS(4945),
    [anon_sym_POUNDIf] = ACTIONS(4945),
    [anon_sym_POUNDelif] = ACTIONS(4945),
    [anon_sym_POUNDELIF] = ACTIONS(4945),
    [anon_sym_POUNDElif] = ACTIONS(4945),
    [anon_sym_POUNDelse] = ACTIONS(4945),
    [anon_sym_POUNDELSE] = ACTIONS(4945),
    [anon_sym_POUNDElse] = ACTIONS(4945),
    [anon_sym_POUNDendif] = ACTIONS(4945),
    [anon_sym_POUNDENDIF] = ACTIONS(4945),
    [anon_sym_POUNDEndif] = ACTIONS(4945),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4947),
    [anon_sym_tableextension] = ACTIONS(4945),
    [anon_sym_TABLEEXTENSION] = ACTIONS(4945),
    [anon_sym_Tableextension] = ACTIONS(4945),
    [anon_sym_TableExtension] = ACTIONS(4945),
    [anon_sym_tableExtension] = ACTIONS(4945),
    [sym_page_keyword] = ACTIONS(4947),
    [anon_sym_pageextension] = ACTIONS(4945),
    [anon_sym_PAGEEXTENSION] = ACTIONS(4945),
    [anon_sym_Pageextension] = ACTIONS(4945),
    [anon_sym_PageExtension] = ACTIONS(4945),
    [anon_sym_pageExtension] = ACTIONS(4945),
    [anon_sym_codeunit] = ACTIONS(4945),
    [anon_sym_CODEUNIT] = ACTIONS(4945),
    [anon_sym_Codeunit] = ACTIONS(4945),
    [anon_sym_CodeUnit] = ACTIONS(4945),
    [anon_sym_COdeunit] = ACTIONS(4945),
    [anon_sym_codeUnit] = ACTIONS(4945),
    [sym_report_keyword] = ACTIONS(4947),
    [anon_sym_reportextension] = ACTIONS(4945),
    [anon_sym_REPORTEXTENSION] = ACTIONS(4945),
    [anon_sym_Reportextension] = ACTIONS(4945),
    [anon_sym_ReportExtension] = ACTIONS(4945),
    [anon_sym_reportExtension] = ACTIONS(4945),
    [sym_query_keyword] = ACTIONS(4945),
    [anon_sym_xmlport] = ACTIONS(4945),
    [anon_sym_XMLPORT] = ACTIONS(4945),
    [anon_sym_Xmlport] = ACTIONS(4945),
    [anon_sym_XMLport] = ACTIONS(4945),
    [anon_sym_XMLPort] = ACTIONS(4945),
    [anon_sym_XmlPort] = ACTIONS(4945),
    [anon_sym_enum] = ACTIONS(4947),
    [anon_sym_ENUM] = ACTIONS(4947),
    [anon_sym_Enum] = ACTIONS(4947),
    [anon_sym_eNUM] = ACTIONS(4945),
    [anon_sym_eNum] = ACTIONS(4945),
    [anon_sym_ENum] = ACTIONS(4945),
    [anon_sym_enumextension] = ACTIONS(4945),
    [anon_sym_ENUMEXTENSION] = ACTIONS(4945),
    [anon_sym_Enumextension] = ACTIONS(4945),
    [anon_sym_EnumExtension] = ACTIONS(4945),
    [anon_sym_enumExtension] = ACTIONS(4945),
    [sym_interface_keyword] = ACTIONS(4945),
    [anon_sym_controladdin] = ACTIONS(4945),
    [anon_sym_CONTROLADDIN] = ACTIONS(4945),
    [anon_sym_Controladdin] = ACTIONS(4945),
    [anon_sym_ControlAddIn] = ACTIONS(4945),
    [anon_sym_ControlAddin] = ACTIONS(4945),
    [anon_sym_controlAddIn] = ACTIONS(4945),
    [anon_sym_controlAddin] = ACTIONS(4945),
    [anon_sym_dotnet] = ACTIONS(4945),
    [anon_sym_DOTNET] = ACTIONS(4945),
    [anon_sym_Dotnet] = ACTIONS(4945),
    [anon_sym_DotNet] = ACTIONS(4945),
    [anon_sym_dotNet] = ACTIONS(4945),
    [sym_profile_keyword] = ACTIONS(4947),
    [anon_sym_profileextension] = ACTIONS(4945),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(4945),
    [anon_sym_Profileextension] = ACTIONS(4945),
    [anon_sym_ProfileExtension] = ACTIONS(4945),
    [anon_sym_profileExtension] = ACTIONS(4945),
    [anon_sym_permissionset] = ACTIONS(4947),
    [anon_sym_PERMISSIONSET] = ACTIONS(4947),
    [anon_sym_Permissionset] = ACTIONS(4947),
    [anon_sym_PermissionSet] = ACTIONS(4947),
    [anon_sym_permissionSet] = ACTIONS(4947),
    [anon_sym_permissionsetextension] = ACTIONS(4945),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(4945),
    [anon_sym_Permissionsetextension] = ACTIONS(4945),
    [anon_sym_PermissionSetExtension] = ACTIONS(4945),
    [anon_sym_permissionSetExtension] = ACTIONS(4945),
    [sym_entitlement_keyword] = ACTIONS(4945),
    [anon_sym_pagecustomization] = ACTIONS(4945),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(4945),
    [anon_sym_Pagecustomization] = ACTIONS(4945),
    [anon_sym_PageCustomization] = ACTIONS(4945),
    [anon_sym_pageCustomization] = ACTIONS(4945),
    [sym_using_keyword] = ACTIONS(4945),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(4945),
    [sym_preproc_close] = ACTIONS(4945),
  },
  [STATE(1949)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_DASH] = ACTIONS(4951),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(4959),
    [aux_sym__expression_token2] = ACTIONS(4961),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(4963),
    [anon_sym_div] = ACTIONS(4965),
    [anon_sym_DIV] = ACTIONS(4967),
    [anon_sym_Div] = ACTIONS(4969),
    [anon_sym_mod] = ACTIONS(4971),
    [anon_sym_MOD] = ACTIONS(4973),
    [anon_sym_Mod] = ACTIONS(4975),
    [anon_sym_PLUS] = ACTIONS(4977),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(4979),
    [anon_sym_AND] = ACTIONS(4981),
    [anon_sym_And] = ACTIONS(4983),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(1950)] = {
    [anon_sym_POUNDif] = ACTIONS(4985),
    [anon_sym_POUNDIF] = ACTIONS(4985),
    [anon_sym_POUNDIf] = ACTIONS(4985),
    [anon_sym_POUNDelif] = ACTIONS(4985),
    [anon_sym_POUNDELIF] = ACTIONS(4985),
    [anon_sym_POUNDElif] = ACTIONS(4985),
    [anon_sym_POUNDelse] = ACTIONS(4985),
    [anon_sym_POUNDELSE] = ACTIONS(4985),
    [anon_sym_POUNDElse] = ACTIONS(4985),
    [anon_sym_POUNDendif] = ACTIONS(4985),
    [anon_sym_POUNDENDIF] = ACTIONS(4985),
    [anon_sym_POUNDEndif] = ACTIONS(4985),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4987),
    [anon_sym_tableextension] = ACTIONS(4985),
    [anon_sym_TABLEEXTENSION] = ACTIONS(4985),
    [anon_sym_Tableextension] = ACTIONS(4985),
    [anon_sym_TableExtension] = ACTIONS(4985),
    [anon_sym_tableExtension] = ACTIONS(4985),
    [sym_page_keyword] = ACTIONS(4987),
    [anon_sym_pageextension] = ACTIONS(4985),
    [anon_sym_PAGEEXTENSION] = ACTIONS(4985),
    [anon_sym_Pageextension] = ACTIONS(4985),
    [anon_sym_PageExtension] = ACTIONS(4985),
    [anon_sym_pageExtension] = ACTIONS(4985),
    [anon_sym_codeunit] = ACTIONS(4985),
    [anon_sym_CODEUNIT] = ACTIONS(4985),
    [anon_sym_Codeunit] = ACTIONS(4985),
    [anon_sym_CodeUnit] = ACTIONS(4985),
    [anon_sym_COdeunit] = ACTIONS(4985),
    [anon_sym_codeUnit] = ACTIONS(4985),
    [sym_report_keyword] = ACTIONS(4987),
    [anon_sym_reportextension] = ACTIONS(4985),
    [anon_sym_REPORTEXTENSION] = ACTIONS(4985),
    [anon_sym_Reportextension] = ACTIONS(4985),
    [anon_sym_ReportExtension] = ACTIONS(4985),
    [anon_sym_reportExtension] = ACTIONS(4985),
    [sym_query_keyword] = ACTIONS(4985),
    [anon_sym_xmlport] = ACTIONS(4985),
    [anon_sym_XMLPORT] = ACTIONS(4985),
    [anon_sym_Xmlport] = ACTIONS(4985),
    [anon_sym_XMLport] = ACTIONS(4985),
    [anon_sym_XMLPort] = ACTIONS(4985),
    [anon_sym_XmlPort] = ACTIONS(4985),
    [anon_sym_enum] = ACTIONS(4987),
    [anon_sym_ENUM] = ACTIONS(4987),
    [anon_sym_Enum] = ACTIONS(4987),
    [anon_sym_eNUM] = ACTIONS(4985),
    [anon_sym_eNum] = ACTIONS(4985),
    [anon_sym_ENum] = ACTIONS(4985),
    [anon_sym_enumextension] = ACTIONS(4985),
    [anon_sym_ENUMEXTENSION] = ACTIONS(4985),
    [anon_sym_Enumextension] = ACTIONS(4985),
    [anon_sym_EnumExtension] = ACTIONS(4985),
    [anon_sym_enumExtension] = ACTIONS(4985),
    [sym_interface_keyword] = ACTIONS(4985),
    [anon_sym_controladdin] = ACTIONS(4985),
    [anon_sym_CONTROLADDIN] = ACTIONS(4985),
    [anon_sym_Controladdin] = ACTIONS(4985),
    [anon_sym_ControlAddIn] = ACTIONS(4985),
    [anon_sym_ControlAddin] = ACTIONS(4985),
    [anon_sym_controlAddIn] = ACTIONS(4985),
    [anon_sym_controlAddin] = ACTIONS(4985),
    [anon_sym_dotnet] = ACTIONS(4985),
    [anon_sym_DOTNET] = ACTIONS(4985),
    [anon_sym_Dotnet] = ACTIONS(4985),
    [anon_sym_DotNet] = ACTIONS(4985),
    [anon_sym_dotNet] = ACTIONS(4985),
    [sym_profile_keyword] = ACTIONS(4987),
    [anon_sym_profileextension] = ACTIONS(4985),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(4985),
    [anon_sym_Profileextension] = ACTIONS(4985),
    [anon_sym_ProfileExtension] = ACTIONS(4985),
    [anon_sym_profileExtension] = ACTIONS(4985),
    [anon_sym_permissionset] = ACTIONS(4987),
    [anon_sym_PERMISSIONSET] = ACTIONS(4987),
    [anon_sym_Permissionset] = ACTIONS(4987),
    [anon_sym_PermissionSet] = ACTIONS(4987),
    [anon_sym_permissionSet] = ACTIONS(4987),
    [anon_sym_permissionsetextension] = ACTIONS(4985),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(4985),
    [anon_sym_Permissionsetextension] = ACTIONS(4985),
    [anon_sym_PermissionSetExtension] = ACTIONS(4985),
    [anon_sym_permissionSetExtension] = ACTIONS(4985),
    [sym_entitlement_keyword] = ACTIONS(4985),
    [anon_sym_pagecustomization] = ACTIONS(4985),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(4985),
    [anon_sym_Pagecustomization] = ACTIONS(4985),
    [anon_sym_PageCustomization] = ACTIONS(4985),
    [anon_sym_pageCustomization] = ACTIONS(4985),
    [sym_using_keyword] = ACTIONS(4985),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(4985),
    [sym_preproc_close] = ACTIONS(4985),
  },
  [STATE(1951)] = {
    [anon_sym_POUNDif] = ACTIONS(4989),
    [anon_sym_POUNDIF] = ACTIONS(4989),
    [anon_sym_POUNDIf] = ACTIONS(4989),
    [anon_sym_POUNDelif] = ACTIONS(4989),
    [anon_sym_POUNDELIF] = ACTIONS(4989),
    [anon_sym_POUNDElif] = ACTIONS(4989),
    [anon_sym_POUNDelse] = ACTIONS(4989),
    [anon_sym_POUNDELSE] = ACTIONS(4989),
    [anon_sym_POUNDElse] = ACTIONS(4989),
    [anon_sym_POUNDendif] = ACTIONS(4989),
    [anon_sym_POUNDENDIF] = ACTIONS(4989),
    [anon_sym_POUNDEndif] = ACTIONS(4989),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4991),
    [anon_sym_tableextension] = ACTIONS(4989),
    [anon_sym_TABLEEXTENSION] = ACTIONS(4989),
    [anon_sym_Tableextension] = ACTIONS(4989),
    [anon_sym_TableExtension] = ACTIONS(4989),
    [anon_sym_tableExtension] = ACTIONS(4989),
    [sym_page_keyword] = ACTIONS(4991),
    [anon_sym_pageextension] = ACTIONS(4989),
    [anon_sym_PAGEEXTENSION] = ACTIONS(4989),
    [anon_sym_Pageextension] = ACTIONS(4989),
    [anon_sym_PageExtension] = ACTIONS(4989),
    [anon_sym_pageExtension] = ACTIONS(4989),
    [anon_sym_codeunit] = ACTIONS(4989),
    [anon_sym_CODEUNIT] = ACTIONS(4989),
    [anon_sym_Codeunit] = ACTIONS(4989),
    [anon_sym_CodeUnit] = ACTIONS(4989),
    [anon_sym_COdeunit] = ACTIONS(4989),
    [anon_sym_codeUnit] = ACTIONS(4989),
    [sym_report_keyword] = ACTIONS(4991),
    [anon_sym_reportextension] = ACTIONS(4989),
    [anon_sym_REPORTEXTENSION] = ACTIONS(4989),
    [anon_sym_Reportextension] = ACTIONS(4989),
    [anon_sym_ReportExtension] = ACTIONS(4989),
    [anon_sym_reportExtension] = ACTIONS(4989),
    [sym_query_keyword] = ACTIONS(4989),
    [anon_sym_xmlport] = ACTIONS(4989),
    [anon_sym_XMLPORT] = ACTIONS(4989),
    [anon_sym_Xmlport] = ACTIONS(4989),
    [anon_sym_XMLport] = ACTIONS(4989),
    [anon_sym_XMLPort] = ACTIONS(4989),
    [anon_sym_XmlPort] = ACTIONS(4989),
    [anon_sym_enum] = ACTIONS(4991),
    [anon_sym_ENUM] = ACTIONS(4991),
    [anon_sym_Enum] = ACTIONS(4991),
    [anon_sym_eNUM] = ACTIONS(4989),
    [anon_sym_eNum] = ACTIONS(4989),
    [anon_sym_ENum] = ACTIONS(4989),
    [anon_sym_enumextension] = ACTIONS(4989),
    [anon_sym_ENUMEXTENSION] = ACTIONS(4989),
    [anon_sym_Enumextension] = ACTIONS(4989),
    [anon_sym_EnumExtension] = ACTIONS(4989),
    [anon_sym_enumExtension] = ACTIONS(4989),
    [sym_interface_keyword] = ACTIONS(4989),
    [anon_sym_controladdin] = ACTIONS(4989),
    [anon_sym_CONTROLADDIN] = ACTIONS(4989),
    [anon_sym_Controladdin] = ACTIONS(4989),
    [anon_sym_ControlAddIn] = ACTIONS(4989),
    [anon_sym_ControlAddin] = ACTIONS(4989),
    [anon_sym_controlAddIn] = ACTIONS(4989),
    [anon_sym_controlAddin] = ACTIONS(4989),
    [anon_sym_dotnet] = ACTIONS(4989),
    [anon_sym_DOTNET] = ACTIONS(4989),
    [anon_sym_Dotnet] = ACTIONS(4989),
    [anon_sym_DotNet] = ACTIONS(4989),
    [anon_sym_dotNet] = ACTIONS(4989),
    [sym_profile_keyword] = ACTIONS(4991),
    [anon_sym_profileextension] = ACTIONS(4989),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(4989),
    [anon_sym_Profileextension] = ACTIONS(4989),
    [anon_sym_ProfileExtension] = ACTIONS(4989),
    [anon_sym_profileExtension] = ACTIONS(4989),
    [anon_sym_permissionset] = ACTIONS(4991),
    [anon_sym_PERMISSIONSET] = ACTIONS(4991),
    [anon_sym_Permissionset] = ACTIONS(4991),
    [anon_sym_PermissionSet] = ACTIONS(4991),
    [anon_sym_permissionSet] = ACTIONS(4991),
    [anon_sym_permissionsetextension] = ACTIONS(4989),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(4989),
    [anon_sym_Permissionsetextension] = ACTIONS(4989),
    [anon_sym_PermissionSetExtension] = ACTIONS(4989),
    [anon_sym_permissionSetExtension] = ACTIONS(4989),
    [sym_entitlement_keyword] = ACTIONS(4989),
    [anon_sym_pagecustomization] = ACTIONS(4989),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(4989),
    [anon_sym_Pagecustomization] = ACTIONS(4989),
    [anon_sym_PageCustomization] = ACTIONS(4989),
    [anon_sym_pageCustomization] = ACTIONS(4989),
    [sym_using_keyword] = ACTIONS(4989),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(4989),
    [sym_preproc_close] = ACTIONS(4989),
  },
  [STATE(1952)] = {
    [anon_sym_POUNDif] = ACTIONS(4993),
    [anon_sym_POUNDIF] = ACTIONS(4993),
    [anon_sym_POUNDIf] = ACTIONS(4993),
    [anon_sym_POUNDelif] = ACTIONS(4993),
    [anon_sym_POUNDELIF] = ACTIONS(4993),
    [anon_sym_POUNDElif] = ACTIONS(4993),
    [anon_sym_POUNDelse] = ACTIONS(4993),
    [anon_sym_POUNDELSE] = ACTIONS(4993),
    [anon_sym_POUNDElse] = ACTIONS(4993),
    [anon_sym_POUNDendif] = ACTIONS(4993),
    [anon_sym_POUNDENDIF] = ACTIONS(4993),
    [anon_sym_POUNDEndif] = ACTIONS(4993),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4995),
    [anon_sym_tableextension] = ACTIONS(4993),
    [anon_sym_TABLEEXTENSION] = ACTIONS(4993),
    [anon_sym_Tableextension] = ACTIONS(4993),
    [anon_sym_TableExtension] = ACTIONS(4993),
    [anon_sym_tableExtension] = ACTIONS(4993),
    [sym_page_keyword] = ACTIONS(4995),
    [anon_sym_pageextension] = ACTIONS(4993),
    [anon_sym_PAGEEXTENSION] = ACTIONS(4993),
    [anon_sym_Pageextension] = ACTIONS(4993),
    [anon_sym_PageExtension] = ACTIONS(4993),
    [anon_sym_pageExtension] = ACTIONS(4993),
    [anon_sym_codeunit] = ACTIONS(4993),
    [anon_sym_CODEUNIT] = ACTIONS(4993),
    [anon_sym_Codeunit] = ACTIONS(4993),
    [anon_sym_CodeUnit] = ACTIONS(4993),
    [anon_sym_COdeunit] = ACTIONS(4993),
    [anon_sym_codeUnit] = ACTIONS(4993),
    [sym_report_keyword] = ACTIONS(4995),
    [anon_sym_reportextension] = ACTIONS(4993),
    [anon_sym_REPORTEXTENSION] = ACTIONS(4993),
    [anon_sym_Reportextension] = ACTIONS(4993),
    [anon_sym_ReportExtension] = ACTIONS(4993),
    [anon_sym_reportExtension] = ACTIONS(4993),
    [sym_query_keyword] = ACTIONS(4993),
    [anon_sym_xmlport] = ACTIONS(4993),
    [anon_sym_XMLPORT] = ACTIONS(4993),
    [anon_sym_Xmlport] = ACTIONS(4993),
    [anon_sym_XMLport] = ACTIONS(4993),
    [anon_sym_XMLPort] = ACTIONS(4993),
    [anon_sym_XmlPort] = ACTIONS(4993),
    [anon_sym_enum] = ACTIONS(4995),
    [anon_sym_ENUM] = ACTIONS(4995),
    [anon_sym_Enum] = ACTIONS(4995),
    [anon_sym_eNUM] = ACTIONS(4993),
    [anon_sym_eNum] = ACTIONS(4993),
    [anon_sym_ENum] = ACTIONS(4993),
    [anon_sym_enumextension] = ACTIONS(4993),
    [anon_sym_ENUMEXTENSION] = ACTIONS(4993),
    [anon_sym_Enumextension] = ACTIONS(4993),
    [anon_sym_EnumExtension] = ACTIONS(4993),
    [anon_sym_enumExtension] = ACTIONS(4993),
    [sym_interface_keyword] = ACTIONS(4993),
    [anon_sym_controladdin] = ACTIONS(4993),
    [anon_sym_CONTROLADDIN] = ACTIONS(4993),
    [anon_sym_Controladdin] = ACTIONS(4993),
    [anon_sym_ControlAddIn] = ACTIONS(4993),
    [anon_sym_ControlAddin] = ACTIONS(4993),
    [anon_sym_controlAddIn] = ACTIONS(4993),
    [anon_sym_controlAddin] = ACTIONS(4993),
    [anon_sym_dotnet] = ACTIONS(4993),
    [anon_sym_DOTNET] = ACTIONS(4993),
    [anon_sym_Dotnet] = ACTIONS(4993),
    [anon_sym_DotNet] = ACTIONS(4993),
    [anon_sym_dotNet] = ACTIONS(4993),
    [sym_profile_keyword] = ACTIONS(4995),
    [anon_sym_profileextension] = ACTIONS(4993),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(4993),
    [anon_sym_Profileextension] = ACTIONS(4993),
    [anon_sym_ProfileExtension] = ACTIONS(4993),
    [anon_sym_profileExtension] = ACTIONS(4993),
    [anon_sym_permissionset] = ACTIONS(4995),
    [anon_sym_PERMISSIONSET] = ACTIONS(4995),
    [anon_sym_Permissionset] = ACTIONS(4995),
    [anon_sym_PermissionSet] = ACTIONS(4995),
    [anon_sym_permissionSet] = ACTIONS(4995),
    [anon_sym_permissionsetextension] = ACTIONS(4993),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(4993),
    [anon_sym_Permissionsetextension] = ACTIONS(4993),
    [anon_sym_PermissionSetExtension] = ACTIONS(4993),
    [anon_sym_permissionSetExtension] = ACTIONS(4993),
    [sym_entitlement_keyword] = ACTIONS(4993),
    [anon_sym_pagecustomization] = ACTIONS(4993),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(4993),
    [anon_sym_Pagecustomization] = ACTIONS(4993),
    [anon_sym_PageCustomization] = ACTIONS(4993),
    [anon_sym_pageCustomization] = ACTIONS(4993),
    [sym_using_keyword] = ACTIONS(4993),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(4993),
    [sym_preproc_close] = ACTIONS(4993),
  },
  [STATE(1953)] = {
    [anon_sym_POUNDif] = ACTIONS(4997),
    [anon_sym_POUNDIF] = ACTIONS(4997),
    [anon_sym_POUNDIf] = ACTIONS(4997),
    [anon_sym_POUNDelif] = ACTIONS(4997),
    [anon_sym_POUNDELIF] = ACTIONS(4997),
    [anon_sym_POUNDElif] = ACTIONS(4997),
    [anon_sym_POUNDelse] = ACTIONS(4997),
    [anon_sym_POUNDELSE] = ACTIONS(4997),
    [anon_sym_POUNDElse] = ACTIONS(4997),
    [anon_sym_POUNDendif] = ACTIONS(4997),
    [anon_sym_POUNDENDIF] = ACTIONS(4997),
    [anon_sym_POUNDEndif] = ACTIONS(4997),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4999),
    [anon_sym_tableextension] = ACTIONS(4997),
    [anon_sym_TABLEEXTENSION] = ACTIONS(4997),
    [anon_sym_Tableextension] = ACTIONS(4997),
    [anon_sym_TableExtension] = ACTIONS(4997),
    [anon_sym_tableExtension] = ACTIONS(4997),
    [sym_page_keyword] = ACTIONS(4999),
    [anon_sym_pageextension] = ACTIONS(4997),
    [anon_sym_PAGEEXTENSION] = ACTIONS(4997),
    [anon_sym_Pageextension] = ACTIONS(4997),
    [anon_sym_PageExtension] = ACTIONS(4997),
    [anon_sym_pageExtension] = ACTIONS(4997),
    [anon_sym_codeunit] = ACTIONS(4997),
    [anon_sym_CODEUNIT] = ACTIONS(4997),
    [anon_sym_Codeunit] = ACTIONS(4997),
    [anon_sym_CodeUnit] = ACTIONS(4997),
    [anon_sym_COdeunit] = ACTIONS(4997),
    [anon_sym_codeUnit] = ACTIONS(4997),
    [sym_report_keyword] = ACTIONS(4999),
    [anon_sym_reportextension] = ACTIONS(4997),
    [anon_sym_REPORTEXTENSION] = ACTIONS(4997),
    [anon_sym_Reportextension] = ACTIONS(4997),
    [anon_sym_ReportExtension] = ACTIONS(4997),
    [anon_sym_reportExtension] = ACTIONS(4997),
    [sym_query_keyword] = ACTIONS(4997),
    [anon_sym_xmlport] = ACTIONS(4997),
    [anon_sym_XMLPORT] = ACTIONS(4997),
    [anon_sym_Xmlport] = ACTIONS(4997),
    [anon_sym_XMLport] = ACTIONS(4997),
    [anon_sym_XMLPort] = ACTIONS(4997),
    [anon_sym_XmlPort] = ACTIONS(4997),
    [anon_sym_enum] = ACTIONS(4999),
    [anon_sym_ENUM] = ACTIONS(4999),
    [anon_sym_Enum] = ACTIONS(4999),
    [anon_sym_eNUM] = ACTIONS(4997),
    [anon_sym_eNum] = ACTIONS(4997),
    [anon_sym_ENum] = ACTIONS(4997),
    [anon_sym_enumextension] = ACTIONS(4997),
    [anon_sym_ENUMEXTENSION] = ACTIONS(4997),
    [anon_sym_Enumextension] = ACTIONS(4997),
    [anon_sym_EnumExtension] = ACTIONS(4997),
    [anon_sym_enumExtension] = ACTIONS(4997),
    [sym_interface_keyword] = ACTIONS(4997),
    [anon_sym_controladdin] = ACTIONS(4997),
    [anon_sym_CONTROLADDIN] = ACTIONS(4997),
    [anon_sym_Controladdin] = ACTIONS(4997),
    [anon_sym_ControlAddIn] = ACTIONS(4997),
    [anon_sym_ControlAddin] = ACTIONS(4997),
    [anon_sym_controlAddIn] = ACTIONS(4997),
    [anon_sym_controlAddin] = ACTIONS(4997),
    [anon_sym_dotnet] = ACTIONS(4997),
    [anon_sym_DOTNET] = ACTIONS(4997),
    [anon_sym_Dotnet] = ACTIONS(4997),
    [anon_sym_DotNet] = ACTIONS(4997),
    [anon_sym_dotNet] = ACTIONS(4997),
    [sym_profile_keyword] = ACTIONS(4999),
    [anon_sym_profileextension] = ACTIONS(4997),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(4997),
    [anon_sym_Profileextension] = ACTIONS(4997),
    [anon_sym_ProfileExtension] = ACTIONS(4997),
    [anon_sym_profileExtension] = ACTIONS(4997),
    [anon_sym_permissionset] = ACTIONS(4999),
    [anon_sym_PERMISSIONSET] = ACTIONS(4999),
    [anon_sym_Permissionset] = ACTIONS(4999),
    [anon_sym_PermissionSet] = ACTIONS(4999),
    [anon_sym_permissionSet] = ACTIONS(4999),
    [anon_sym_permissionsetextension] = ACTIONS(4997),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(4997),
    [anon_sym_Permissionsetextension] = ACTIONS(4997),
    [anon_sym_PermissionSetExtension] = ACTIONS(4997),
    [anon_sym_permissionSetExtension] = ACTIONS(4997),
    [sym_entitlement_keyword] = ACTIONS(4997),
    [anon_sym_pagecustomization] = ACTIONS(4997),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(4997),
    [anon_sym_Pagecustomization] = ACTIONS(4997),
    [anon_sym_PageCustomization] = ACTIONS(4997),
    [anon_sym_pageCustomization] = ACTIONS(4997),
    [sym_using_keyword] = ACTIONS(4997),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(4997),
    [sym_preproc_close] = ACTIONS(4997),
  },
  [STATE(1954)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_DASH] = ACTIONS(4951),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(4959),
    [aux_sym__expression_token2] = ACTIONS(4961),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(4963),
    [anon_sym_div] = ACTIONS(4965),
    [anon_sym_DIV] = ACTIONS(4967),
    [anon_sym_Div] = ACTIONS(4969),
    [anon_sym_mod] = ACTIONS(4971),
    [anon_sym_MOD] = ACTIONS(4973),
    [anon_sym_Mod] = ACTIONS(4975),
    [anon_sym_PLUS] = ACTIONS(4977),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(4979),
    [anon_sym_AND] = ACTIONS(4981),
    [anon_sym_And] = ACTIONS(4983),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(1955)] = {
    [anon_sym_POUNDif] = ACTIONS(5001),
    [anon_sym_POUNDIF] = ACTIONS(5001),
    [anon_sym_POUNDIf] = ACTIONS(5001),
    [anon_sym_POUNDelif] = ACTIONS(5001),
    [anon_sym_POUNDELIF] = ACTIONS(5001),
    [anon_sym_POUNDElif] = ACTIONS(5001),
    [anon_sym_POUNDelse] = ACTIONS(5001),
    [anon_sym_POUNDELSE] = ACTIONS(5001),
    [anon_sym_POUNDElse] = ACTIONS(5001),
    [anon_sym_POUNDendif] = ACTIONS(5001),
    [anon_sym_POUNDENDIF] = ACTIONS(5001),
    [anon_sym_POUNDEndif] = ACTIONS(5001),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5003),
    [anon_sym_tableextension] = ACTIONS(5001),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5001),
    [anon_sym_Tableextension] = ACTIONS(5001),
    [anon_sym_TableExtension] = ACTIONS(5001),
    [anon_sym_tableExtension] = ACTIONS(5001),
    [sym_page_keyword] = ACTIONS(5003),
    [anon_sym_pageextension] = ACTIONS(5001),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5001),
    [anon_sym_Pageextension] = ACTIONS(5001),
    [anon_sym_PageExtension] = ACTIONS(5001),
    [anon_sym_pageExtension] = ACTIONS(5001),
    [anon_sym_codeunit] = ACTIONS(5001),
    [anon_sym_CODEUNIT] = ACTIONS(5001),
    [anon_sym_Codeunit] = ACTIONS(5001),
    [anon_sym_CodeUnit] = ACTIONS(5001),
    [anon_sym_COdeunit] = ACTIONS(5001),
    [anon_sym_codeUnit] = ACTIONS(5001),
    [sym_report_keyword] = ACTIONS(5003),
    [anon_sym_reportextension] = ACTIONS(5001),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5001),
    [anon_sym_Reportextension] = ACTIONS(5001),
    [anon_sym_ReportExtension] = ACTIONS(5001),
    [anon_sym_reportExtension] = ACTIONS(5001),
    [sym_query_keyword] = ACTIONS(5001),
    [anon_sym_xmlport] = ACTIONS(5001),
    [anon_sym_XMLPORT] = ACTIONS(5001),
    [anon_sym_Xmlport] = ACTIONS(5001),
    [anon_sym_XMLport] = ACTIONS(5001),
    [anon_sym_XMLPort] = ACTIONS(5001),
    [anon_sym_XmlPort] = ACTIONS(5001),
    [anon_sym_enum] = ACTIONS(5003),
    [anon_sym_ENUM] = ACTIONS(5003),
    [anon_sym_Enum] = ACTIONS(5003),
    [anon_sym_eNUM] = ACTIONS(5001),
    [anon_sym_eNum] = ACTIONS(5001),
    [anon_sym_ENum] = ACTIONS(5001),
    [anon_sym_enumextension] = ACTIONS(5001),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5001),
    [anon_sym_Enumextension] = ACTIONS(5001),
    [anon_sym_EnumExtension] = ACTIONS(5001),
    [anon_sym_enumExtension] = ACTIONS(5001),
    [sym_interface_keyword] = ACTIONS(5001),
    [anon_sym_controladdin] = ACTIONS(5001),
    [anon_sym_CONTROLADDIN] = ACTIONS(5001),
    [anon_sym_Controladdin] = ACTIONS(5001),
    [anon_sym_ControlAddIn] = ACTIONS(5001),
    [anon_sym_ControlAddin] = ACTIONS(5001),
    [anon_sym_controlAddIn] = ACTIONS(5001),
    [anon_sym_controlAddin] = ACTIONS(5001),
    [anon_sym_dotnet] = ACTIONS(5001),
    [anon_sym_DOTNET] = ACTIONS(5001),
    [anon_sym_Dotnet] = ACTIONS(5001),
    [anon_sym_DotNet] = ACTIONS(5001),
    [anon_sym_dotNet] = ACTIONS(5001),
    [sym_profile_keyword] = ACTIONS(5003),
    [anon_sym_profileextension] = ACTIONS(5001),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5001),
    [anon_sym_Profileextension] = ACTIONS(5001),
    [anon_sym_ProfileExtension] = ACTIONS(5001),
    [anon_sym_profileExtension] = ACTIONS(5001),
    [anon_sym_permissionset] = ACTIONS(5003),
    [anon_sym_PERMISSIONSET] = ACTIONS(5003),
    [anon_sym_Permissionset] = ACTIONS(5003),
    [anon_sym_PermissionSet] = ACTIONS(5003),
    [anon_sym_permissionSet] = ACTIONS(5003),
    [anon_sym_permissionsetextension] = ACTIONS(5001),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5001),
    [anon_sym_Permissionsetextension] = ACTIONS(5001),
    [anon_sym_PermissionSetExtension] = ACTIONS(5001),
    [anon_sym_permissionSetExtension] = ACTIONS(5001),
    [sym_entitlement_keyword] = ACTIONS(5001),
    [anon_sym_pagecustomization] = ACTIONS(5001),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5001),
    [anon_sym_Pagecustomization] = ACTIONS(5001),
    [anon_sym_PageCustomization] = ACTIONS(5001),
    [anon_sym_pageCustomization] = ACTIONS(5001),
    [sym_using_keyword] = ACTIONS(5001),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5001),
    [sym_preproc_close] = ACTIONS(5001),
  },
  [STATE(1956)] = {
    [anon_sym_POUNDif] = ACTIONS(5005),
    [anon_sym_POUNDIF] = ACTIONS(5005),
    [anon_sym_POUNDIf] = ACTIONS(5005),
    [anon_sym_POUNDelif] = ACTIONS(5005),
    [anon_sym_POUNDELIF] = ACTIONS(5005),
    [anon_sym_POUNDElif] = ACTIONS(5005),
    [anon_sym_POUNDelse] = ACTIONS(5005),
    [anon_sym_POUNDELSE] = ACTIONS(5005),
    [anon_sym_POUNDElse] = ACTIONS(5005),
    [anon_sym_POUNDendif] = ACTIONS(5005),
    [anon_sym_POUNDENDIF] = ACTIONS(5005),
    [anon_sym_POUNDEndif] = ACTIONS(5005),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5007),
    [anon_sym_tableextension] = ACTIONS(5005),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5005),
    [anon_sym_Tableextension] = ACTIONS(5005),
    [anon_sym_TableExtension] = ACTIONS(5005),
    [anon_sym_tableExtension] = ACTIONS(5005),
    [sym_page_keyword] = ACTIONS(5007),
    [anon_sym_pageextension] = ACTIONS(5005),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5005),
    [anon_sym_Pageextension] = ACTIONS(5005),
    [anon_sym_PageExtension] = ACTIONS(5005),
    [anon_sym_pageExtension] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(5005),
    [anon_sym_CODEUNIT] = ACTIONS(5005),
    [anon_sym_Codeunit] = ACTIONS(5005),
    [anon_sym_CodeUnit] = ACTIONS(5005),
    [anon_sym_COdeunit] = ACTIONS(5005),
    [anon_sym_codeUnit] = ACTIONS(5005),
    [sym_report_keyword] = ACTIONS(5007),
    [anon_sym_reportextension] = ACTIONS(5005),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5005),
    [anon_sym_Reportextension] = ACTIONS(5005),
    [anon_sym_ReportExtension] = ACTIONS(5005),
    [anon_sym_reportExtension] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(5005),
    [anon_sym_XMLPORT] = ACTIONS(5005),
    [anon_sym_Xmlport] = ACTIONS(5005),
    [anon_sym_XMLport] = ACTIONS(5005),
    [anon_sym_XMLPort] = ACTIONS(5005),
    [anon_sym_XmlPort] = ACTIONS(5005),
    [anon_sym_enum] = ACTIONS(5007),
    [anon_sym_ENUM] = ACTIONS(5007),
    [anon_sym_Enum] = ACTIONS(5007),
    [anon_sym_eNUM] = ACTIONS(5005),
    [anon_sym_eNum] = ACTIONS(5005),
    [anon_sym_ENum] = ACTIONS(5005),
    [anon_sym_enumextension] = ACTIONS(5005),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5005),
    [anon_sym_Enumextension] = ACTIONS(5005),
    [anon_sym_EnumExtension] = ACTIONS(5005),
    [anon_sym_enumExtension] = ACTIONS(5005),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(5005),
    [anon_sym_CONTROLADDIN] = ACTIONS(5005),
    [anon_sym_Controladdin] = ACTIONS(5005),
    [anon_sym_ControlAddIn] = ACTIONS(5005),
    [anon_sym_ControlAddin] = ACTIONS(5005),
    [anon_sym_controlAddIn] = ACTIONS(5005),
    [anon_sym_controlAddin] = ACTIONS(5005),
    [anon_sym_dotnet] = ACTIONS(5005),
    [anon_sym_DOTNET] = ACTIONS(5005),
    [anon_sym_Dotnet] = ACTIONS(5005),
    [anon_sym_DotNet] = ACTIONS(5005),
    [anon_sym_dotNet] = ACTIONS(5005),
    [sym_profile_keyword] = ACTIONS(5007),
    [anon_sym_profileextension] = ACTIONS(5005),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5005),
    [anon_sym_Profileextension] = ACTIONS(5005),
    [anon_sym_ProfileExtension] = ACTIONS(5005),
    [anon_sym_profileExtension] = ACTIONS(5005),
    [anon_sym_permissionset] = ACTIONS(5007),
    [anon_sym_PERMISSIONSET] = ACTIONS(5007),
    [anon_sym_Permissionset] = ACTIONS(5007),
    [anon_sym_PermissionSet] = ACTIONS(5007),
    [anon_sym_permissionSet] = ACTIONS(5007),
    [anon_sym_permissionsetextension] = ACTIONS(5005),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5005),
    [anon_sym_Permissionsetextension] = ACTIONS(5005),
    [anon_sym_PermissionSetExtension] = ACTIONS(5005),
    [anon_sym_permissionSetExtension] = ACTIONS(5005),
    [sym_entitlement_keyword] = ACTIONS(5005),
    [anon_sym_pagecustomization] = ACTIONS(5005),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5005),
    [anon_sym_Pagecustomization] = ACTIONS(5005),
    [anon_sym_PageCustomization] = ACTIONS(5005),
    [anon_sym_pageCustomization] = ACTIONS(5005),
    [sym_using_keyword] = ACTIONS(5005),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5005),
    [sym_preproc_close] = ACTIONS(5005),
  },
  [STATE(1957)] = {
    [anon_sym_POUNDif] = ACTIONS(5009),
    [anon_sym_POUNDIF] = ACTIONS(5009),
    [anon_sym_POUNDIf] = ACTIONS(5009),
    [anon_sym_POUNDelif] = ACTIONS(5009),
    [anon_sym_POUNDELIF] = ACTIONS(5009),
    [anon_sym_POUNDElif] = ACTIONS(5009),
    [anon_sym_POUNDelse] = ACTIONS(5009),
    [anon_sym_POUNDELSE] = ACTIONS(5009),
    [anon_sym_POUNDElse] = ACTIONS(5009),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5011),
    [anon_sym_tableextension] = ACTIONS(5009),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5009),
    [anon_sym_Tableextension] = ACTIONS(5009),
    [anon_sym_TableExtension] = ACTIONS(5009),
    [anon_sym_tableExtension] = ACTIONS(5009),
    [sym_page_keyword] = ACTIONS(5011),
    [anon_sym_pageextension] = ACTIONS(5009),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5009),
    [anon_sym_Pageextension] = ACTIONS(5009),
    [anon_sym_PageExtension] = ACTIONS(5009),
    [anon_sym_pageExtension] = ACTIONS(5009),
    [anon_sym_codeunit] = ACTIONS(5009),
    [anon_sym_CODEUNIT] = ACTIONS(5009),
    [anon_sym_Codeunit] = ACTIONS(5009),
    [anon_sym_CodeUnit] = ACTIONS(5009),
    [anon_sym_COdeunit] = ACTIONS(5009),
    [anon_sym_codeUnit] = ACTIONS(5009),
    [sym_report_keyword] = ACTIONS(5011),
    [anon_sym_reportextension] = ACTIONS(5009),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5009),
    [anon_sym_Reportextension] = ACTIONS(5009),
    [anon_sym_ReportExtension] = ACTIONS(5009),
    [anon_sym_reportExtension] = ACTIONS(5009),
    [sym_query_keyword] = ACTIONS(5009),
    [anon_sym_xmlport] = ACTIONS(5009),
    [anon_sym_XMLPORT] = ACTIONS(5009),
    [anon_sym_Xmlport] = ACTIONS(5009),
    [anon_sym_XMLport] = ACTIONS(5009),
    [anon_sym_XMLPort] = ACTIONS(5009),
    [anon_sym_XmlPort] = ACTIONS(5009),
    [anon_sym_enum] = ACTIONS(5011),
    [anon_sym_ENUM] = ACTIONS(5011),
    [anon_sym_Enum] = ACTIONS(5011),
    [anon_sym_eNUM] = ACTIONS(5009),
    [anon_sym_eNum] = ACTIONS(5009),
    [anon_sym_ENum] = ACTIONS(5009),
    [anon_sym_enumextension] = ACTIONS(5009),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5009),
    [anon_sym_Enumextension] = ACTIONS(5009),
    [anon_sym_EnumExtension] = ACTIONS(5009),
    [anon_sym_enumExtension] = ACTIONS(5009),
    [sym_interface_keyword] = ACTIONS(5009),
    [anon_sym_controladdin] = ACTIONS(5009),
    [anon_sym_CONTROLADDIN] = ACTIONS(5009),
    [anon_sym_Controladdin] = ACTIONS(5009),
    [anon_sym_ControlAddIn] = ACTIONS(5009),
    [anon_sym_ControlAddin] = ACTIONS(5009),
    [anon_sym_controlAddIn] = ACTIONS(5009),
    [anon_sym_controlAddin] = ACTIONS(5009),
    [anon_sym_dotnet] = ACTIONS(5009),
    [anon_sym_DOTNET] = ACTIONS(5009),
    [anon_sym_Dotnet] = ACTIONS(5009),
    [anon_sym_DotNet] = ACTIONS(5009),
    [anon_sym_dotNet] = ACTIONS(5009),
    [sym_profile_keyword] = ACTIONS(5011),
    [anon_sym_profileextension] = ACTIONS(5009),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5009),
    [anon_sym_Profileextension] = ACTIONS(5009),
    [anon_sym_ProfileExtension] = ACTIONS(5009),
    [anon_sym_profileExtension] = ACTIONS(5009),
    [anon_sym_permissionset] = ACTIONS(5011),
    [anon_sym_PERMISSIONSET] = ACTIONS(5011),
    [anon_sym_Permissionset] = ACTIONS(5011),
    [anon_sym_PermissionSet] = ACTIONS(5011),
    [anon_sym_permissionSet] = ACTIONS(5011),
    [anon_sym_permissionsetextension] = ACTIONS(5009),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5009),
    [anon_sym_Permissionsetextension] = ACTIONS(5009),
    [anon_sym_PermissionSetExtension] = ACTIONS(5009),
    [anon_sym_permissionSetExtension] = ACTIONS(5009),
    [sym_entitlement_keyword] = ACTIONS(5009),
    [anon_sym_pagecustomization] = ACTIONS(5009),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5009),
    [anon_sym_Pagecustomization] = ACTIONS(5009),
    [anon_sym_PageCustomization] = ACTIONS(5009),
    [anon_sym_pageCustomization] = ACTIONS(5009),
    [sym_using_keyword] = ACTIONS(5009),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5009),
    [sym_preproc_close] = ACTIONS(5009),
  },
  [STATE(1958)] = {
    [anon_sym_POUNDif] = ACTIONS(5013),
    [anon_sym_POUNDIF] = ACTIONS(5013),
    [anon_sym_POUNDIf] = ACTIONS(5013),
    [anon_sym_POUNDelif] = ACTIONS(5013),
    [anon_sym_POUNDELIF] = ACTIONS(5013),
    [anon_sym_POUNDElif] = ACTIONS(5013),
    [anon_sym_POUNDelse] = ACTIONS(5013),
    [anon_sym_POUNDELSE] = ACTIONS(5013),
    [anon_sym_POUNDElse] = ACTIONS(5013),
    [anon_sym_POUNDendif] = ACTIONS(5013),
    [anon_sym_POUNDENDIF] = ACTIONS(5013),
    [anon_sym_POUNDEndif] = ACTIONS(5013),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5015),
    [anon_sym_tableextension] = ACTIONS(5013),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5013),
    [anon_sym_Tableextension] = ACTIONS(5013),
    [anon_sym_TableExtension] = ACTIONS(5013),
    [anon_sym_tableExtension] = ACTIONS(5013),
    [sym_page_keyword] = ACTIONS(5015),
    [anon_sym_pageextension] = ACTIONS(5013),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5013),
    [anon_sym_Pageextension] = ACTIONS(5013),
    [anon_sym_PageExtension] = ACTIONS(5013),
    [anon_sym_pageExtension] = ACTIONS(5013),
    [anon_sym_codeunit] = ACTIONS(5013),
    [anon_sym_CODEUNIT] = ACTIONS(5013),
    [anon_sym_Codeunit] = ACTIONS(5013),
    [anon_sym_CodeUnit] = ACTIONS(5013),
    [anon_sym_COdeunit] = ACTIONS(5013),
    [anon_sym_codeUnit] = ACTIONS(5013),
    [sym_report_keyword] = ACTIONS(5015),
    [anon_sym_reportextension] = ACTIONS(5013),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5013),
    [anon_sym_Reportextension] = ACTIONS(5013),
    [anon_sym_ReportExtension] = ACTIONS(5013),
    [anon_sym_reportExtension] = ACTIONS(5013),
    [sym_query_keyword] = ACTIONS(5013),
    [anon_sym_xmlport] = ACTIONS(5013),
    [anon_sym_XMLPORT] = ACTIONS(5013),
    [anon_sym_Xmlport] = ACTIONS(5013),
    [anon_sym_XMLport] = ACTIONS(5013),
    [anon_sym_XMLPort] = ACTIONS(5013),
    [anon_sym_XmlPort] = ACTIONS(5013),
    [anon_sym_enum] = ACTIONS(5015),
    [anon_sym_ENUM] = ACTIONS(5015),
    [anon_sym_Enum] = ACTIONS(5015),
    [anon_sym_eNUM] = ACTIONS(5013),
    [anon_sym_eNum] = ACTIONS(5013),
    [anon_sym_ENum] = ACTIONS(5013),
    [anon_sym_enumextension] = ACTIONS(5013),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5013),
    [anon_sym_Enumextension] = ACTIONS(5013),
    [anon_sym_EnumExtension] = ACTIONS(5013),
    [anon_sym_enumExtension] = ACTIONS(5013),
    [sym_interface_keyword] = ACTIONS(5013),
    [anon_sym_controladdin] = ACTIONS(5013),
    [anon_sym_CONTROLADDIN] = ACTIONS(5013),
    [anon_sym_Controladdin] = ACTIONS(5013),
    [anon_sym_ControlAddIn] = ACTIONS(5013),
    [anon_sym_ControlAddin] = ACTIONS(5013),
    [anon_sym_controlAddIn] = ACTIONS(5013),
    [anon_sym_controlAddin] = ACTIONS(5013),
    [anon_sym_dotnet] = ACTIONS(5013),
    [anon_sym_DOTNET] = ACTIONS(5013),
    [anon_sym_Dotnet] = ACTIONS(5013),
    [anon_sym_DotNet] = ACTIONS(5013),
    [anon_sym_dotNet] = ACTIONS(5013),
    [sym_profile_keyword] = ACTIONS(5015),
    [anon_sym_profileextension] = ACTIONS(5013),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5013),
    [anon_sym_Profileextension] = ACTIONS(5013),
    [anon_sym_ProfileExtension] = ACTIONS(5013),
    [anon_sym_profileExtension] = ACTIONS(5013),
    [anon_sym_permissionset] = ACTIONS(5015),
    [anon_sym_PERMISSIONSET] = ACTIONS(5015),
    [anon_sym_Permissionset] = ACTIONS(5015),
    [anon_sym_PermissionSet] = ACTIONS(5015),
    [anon_sym_permissionSet] = ACTIONS(5015),
    [anon_sym_permissionsetextension] = ACTIONS(5013),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5013),
    [anon_sym_Permissionsetextension] = ACTIONS(5013),
    [anon_sym_PermissionSetExtension] = ACTIONS(5013),
    [anon_sym_permissionSetExtension] = ACTIONS(5013),
    [sym_entitlement_keyword] = ACTIONS(5013),
    [anon_sym_pagecustomization] = ACTIONS(5013),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5013),
    [anon_sym_Pagecustomization] = ACTIONS(5013),
    [anon_sym_PageCustomization] = ACTIONS(5013),
    [anon_sym_pageCustomization] = ACTIONS(5013),
    [sym_using_keyword] = ACTIONS(5013),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5013),
    [sym_preproc_close] = ACTIONS(5013),
  },
  [STATE(1959)] = {
    [anon_sym_POUNDif] = ACTIONS(5017),
    [anon_sym_POUNDIF] = ACTIONS(5017),
    [anon_sym_POUNDIf] = ACTIONS(5017),
    [anon_sym_POUNDelif] = ACTIONS(5017),
    [anon_sym_POUNDELIF] = ACTIONS(5017),
    [anon_sym_POUNDElif] = ACTIONS(5017),
    [anon_sym_POUNDelse] = ACTIONS(5017),
    [anon_sym_POUNDELSE] = ACTIONS(5017),
    [anon_sym_POUNDElse] = ACTIONS(5017),
    [anon_sym_POUNDendif] = ACTIONS(5017),
    [anon_sym_POUNDENDIF] = ACTIONS(5017),
    [anon_sym_POUNDEndif] = ACTIONS(5017),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5019),
    [anon_sym_tableextension] = ACTIONS(5017),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5017),
    [anon_sym_Tableextension] = ACTIONS(5017),
    [anon_sym_TableExtension] = ACTIONS(5017),
    [anon_sym_tableExtension] = ACTIONS(5017),
    [sym_page_keyword] = ACTIONS(5019),
    [anon_sym_pageextension] = ACTIONS(5017),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5017),
    [anon_sym_Pageextension] = ACTIONS(5017),
    [anon_sym_PageExtension] = ACTIONS(5017),
    [anon_sym_pageExtension] = ACTIONS(5017),
    [anon_sym_codeunit] = ACTIONS(5017),
    [anon_sym_CODEUNIT] = ACTIONS(5017),
    [anon_sym_Codeunit] = ACTIONS(5017),
    [anon_sym_CodeUnit] = ACTIONS(5017),
    [anon_sym_COdeunit] = ACTIONS(5017),
    [anon_sym_codeUnit] = ACTIONS(5017),
    [sym_report_keyword] = ACTIONS(5019),
    [anon_sym_reportextension] = ACTIONS(5017),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5017),
    [anon_sym_Reportextension] = ACTIONS(5017),
    [anon_sym_ReportExtension] = ACTIONS(5017),
    [anon_sym_reportExtension] = ACTIONS(5017),
    [sym_query_keyword] = ACTIONS(5017),
    [anon_sym_xmlport] = ACTIONS(5017),
    [anon_sym_XMLPORT] = ACTIONS(5017),
    [anon_sym_Xmlport] = ACTIONS(5017),
    [anon_sym_XMLport] = ACTIONS(5017),
    [anon_sym_XMLPort] = ACTIONS(5017),
    [anon_sym_XmlPort] = ACTIONS(5017),
    [anon_sym_enum] = ACTIONS(5019),
    [anon_sym_ENUM] = ACTIONS(5019),
    [anon_sym_Enum] = ACTIONS(5019),
    [anon_sym_eNUM] = ACTIONS(5017),
    [anon_sym_eNum] = ACTIONS(5017),
    [anon_sym_ENum] = ACTIONS(5017),
    [anon_sym_enumextension] = ACTIONS(5017),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5017),
    [anon_sym_Enumextension] = ACTIONS(5017),
    [anon_sym_EnumExtension] = ACTIONS(5017),
    [anon_sym_enumExtension] = ACTIONS(5017),
    [sym_interface_keyword] = ACTIONS(5017),
    [anon_sym_controladdin] = ACTIONS(5017),
    [anon_sym_CONTROLADDIN] = ACTIONS(5017),
    [anon_sym_Controladdin] = ACTIONS(5017),
    [anon_sym_ControlAddIn] = ACTIONS(5017),
    [anon_sym_ControlAddin] = ACTIONS(5017),
    [anon_sym_controlAddIn] = ACTIONS(5017),
    [anon_sym_controlAddin] = ACTIONS(5017),
    [anon_sym_dotnet] = ACTIONS(5017),
    [anon_sym_DOTNET] = ACTIONS(5017),
    [anon_sym_Dotnet] = ACTIONS(5017),
    [anon_sym_DotNet] = ACTIONS(5017),
    [anon_sym_dotNet] = ACTIONS(5017),
    [sym_profile_keyword] = ACTIONS(5019),
    [anon_sym_profileextension] = ACTIONS(5017),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5017),
    [anon_sym_Profileextension] = ACTIONS(5017),
    [anon_sym_ProfileExtension] = ACTIONS(5017),
    [anon_sym_profileExtension] = ACTIONS(5017),
    [anon_sym_permissionset] = ACTIONS(5019),
    [anon_sym_PERMISSIONSET] = ACTIONS(5019),
    [anon_sym_Permissionset] = ACTIONS(5019),
    [anon_sym_PermissionSet] = ACTIONS(5019),
    [anon_sym_permissionSet] = ACTIONS(5019),
    [anon_sym_permissionsetextension] = ACTIONS(5017),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5017),
    [anon_sym_Permissionsetextension] = ACTIONS(5017),
    [anon_sym_PermissionSetExtension] = ACTIONS(5017),
    [anon_sym_permissionSetExtension] = ACTIONS(5017),
    [sym_entitlement_keyword] = ACTIONS(5017),
    [anon_sym_pagecustomization] = ACTIONS(5017),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5017),
    [anon_sym_Pagecustomization] = ACTIONS(5017),
    [anon_sym_PageCustomization] = ACTIONS(5017),
    [anon_sym_pageCustomization] = ACTIONS(5017),
    [sym_using_keyword] = ACTIONS(5017),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5017),
    [sym_preproc_close] = ACTIONS(5017),
  },
  [STATE(1960)] = {
    [anon_sym_POUNDif] = ACTIONS(5021),
    [anon_sym_POUNDIF] = ACTIONS(5021),
    [anon_sym_POUNDIf] = ACTIONS(5021),
    [anon_sym_POUNDelif] = ACTIONS(5021),
    [anon_sym_POUNDELIF] = ACTIONS(5021),
    [anon_sym_POUNDElif] = ACTIONS(5021),
    [anon_sym_POUNDelse] = ACTIONS(5021),
    [anon_sym_POUNDELSE] = ACTIONS(5021),
    [anon_sym_POUNDElse] = ACTIONS(5021),
    [anon_sym_POUNDendif] = ACTIONS(5021),
    [anon_sym_POUNDENDIF] = ACTIONS(5021),
    [anon_sym_POUNDEndif] = ACTIONS(5021),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5023),
    [anon_sym_tableextension] = ACTIONS(5021),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5021),
    [anon_sym_Tableextension] = ACTIONS(5021),
    [anon_sym_TableExtension] = ACTIONS(5021),
    [anon_sym_tableExtension] = ACTIONS(5021),
    [sym_page_keyword] = ACTIONS(5023),
    [anon_sym_pageextension] = ACTIONS(5021),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5021),
    [anon_sym_Pageextension] = ACTIONS(5021),
    [anon_sym_PageExtension] = ACTIONS(5021),
    [anon_sym_pageExtension] = ACTIONS(5021),
    [anon_sym_codeunit] = ACTIONS(5021),
    [anon_sym_CODEUNIT] = ACTIONS(5021),
    [anon_sym_Codeunit] = ACTIONS(5021),
    [anon_sym_CodeUnit] = ACTIONS(5021),
    [anon_sym_COdeunit] = ACTIONS(5021),
    [anon_sym_codeUnit] = ACTIONS(5021),
    [sym_report_keyword] = ACTIONS(5023),
    [anon_sym_reportextension] = ACTIONS(5021),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5021),
    [anon_sym_Reportextension] = ACTIONS(5021),
    [anon_sym_ReportExtension] = ACTIONS(5021),
    [anon_sym_reportExtension] = ACTIONS(5021),
    [sym_query_keyword] = ACTIONS(5021),
    [anon_sym_xmlport] = ACTIONS(5021),
    [anon_sym_XMLPORT] = ACTIONS(5021),
    [anon_sym_Xmlport] = ACTIONS(5021),
    [anon_sym_XMLport] = ACTIONS(5021),
    [anon_sym_XMLPort] = ACTIONS(5021),
    [anon_sym_XmlPort] = ACTIONS(5021),
    [anon_sym_enum] = ACTIONS(5023),
    [anon_sym_ENUM] = ACTIONS(5023),
    [anon_sym_Enum] = ACTIONS(5023),
    [anon_sym_eNUM] = ACTIONS(5021),
    [anon_sym_eNum] = ACTIONS(5021),
    [anon_sym_ENum] = ACTIONS(5021),
    [anon_sym_enumextension] = ACTIONS(5021),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5021),
    [anon_sym_Enumextension] = ACTIONS(5021),
    [anon_sym_EnumExtension] = ACTIONS(5021),
    [anon_sym_enumExtension] = ACTIONS(5021),
    [sym_interface_keyword] = ACTIONS(5021),
    [anon_sym_controladdin] = ACTIONS(5021),
    [anon_sym_CONTROLADDIN] = ACTIONS(5021),
    [anon_sym_Controladdin] = ACTIONS(5021),
    [anon_sym_ControlAddIn] = ACTIONS(5021),
    [anon_sym_ControlAddin] = ACTIONS(5021),
    [anon_sym_controlAddIn] = ACTIONS(5021),
    [anon_sym_controlAddin] = ACTIONS(5021),
    [anon_sym_dotnet] = ACTIONS(5021),
    [anon_sym_DOTNET] = ACTIONS(5021),
    [anon_sym_Dotnet] = ACTIONS(5021),
    [anon_sym_DotNet] = ACTIONS(5021),
    [anon_sym_dotNet] = ACTIONS(5021),
    [sym_profile_keyword] = ACTIONS(5023),
    [anon_sym_profileextension] = ACTIONS(5021),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5021),
    [anon_sym_Profileextension] = ACTIONS(5021),
    [anon_sym_ProfileExtension] = ACTIONS(5021),
    [anon_sym_profileExtension] = ACTIONS(5021),
    [anon_sym_permissionset] = ACTIONS(5023),
    [anon_sym_PERMISSIONSET] = ACTIONS(5023),
    [anon_sym_Permissionset] = ACTIONS(5023),
    [anon_sym_PermissionSet] = ACTIONS(5023),
    [anon_sym_permissionSet] = ACTIONS(5023),
    [anon_sym_permissionsetextension] = ACTIONS(5021),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5021),
    [anon_sym_Permissionsetextension] = ACTIONS(5021),
    [anon_sym_PermissionSetExtension] = ACTIONS(5021),
    [anon_sym_permissionSetExtension] = ACTIONS(5021),
    [sym_entitlement_keyword] = ACTIONS(5021),
    [anon_sym_pagecustomization] = ACTIONS(5021),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5021),
    [anon_sym_Pagecustomization] = ACTIONS(5021),
    [anon_sym_PageCustomization] = ACTIONS(5021),
    [anon_sym_pageCustomization] = ACTIONS(5021),
    [sym_using_keyword] = ACTIONS(5021),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5021),
    [sym_preproc_close] = ACTIONS(5021),
  },
  [STATE(1961)] = {
    [anon_sym_POUNDif] = ACTIONS(5025),
    [anon_sym_POUNDIF] = ACTIONS(5025),
    [anon_sym_POUNDIf] = ACTIONS(5025),
    [anon_sym_POUNDelif] = ACTIONS(5025),
    [anon_sym_POUNDELIF] = ACTIONS(5025),
    [anon_sym_POUNDElif] = ACTIONS(5025),
    [anon_sym_POUNDelse] = ACTIONS(5025),
    [anon_sym_POUNDELSE] = ACTIONS(5025),
    [anon_sym_POUNDElse] = ACTIONS(5025),
    [anon_sym_POUNDendif] = ACTIONS(5025),
    [anon_sym_POUNDENDIF] = ACTIONS(5025),
    [anon_sym_POUNDEndif] = ACTIONS(5025),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5027),
    [anon_sym_tableextension] = ACTIONS(5025),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5025),
    [anon_sym_Tableextension] = ACTIONS(5025),
    [anon_sym_TableExtension] = ACTIONS(5025),
    [anon_sym_tableExtension] = ACTIONS(5025),
    [sym_page_keyword] = ACTIONS(5027),
    [anon_sym_pageextension] = ACTIONS(5025),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5025),
    [anon_sym_Pageextension] = ACTIONS(5025),
    [anon_sym_PageExtension] = ACTIONS(5025),
    [anon_sym_pageExtension] = ACTIONS(5025),
    [anon_sym_codeunit] = ACTIONS(5025),
    [anon_sym_CODEUNIT] = ACTIONS(5025),
    [anon_sym_Codeunit] = ACTIONS(5025),
    [anon_sym_CodeUnit] = ACTIONS(5025),
    [anon_sym_COdeunit] = ACTIONS(5025),
    [anon_sym_codeUnit] = ACTIONS(5025),
    [sym_report_keyword] = ACTIONS(5027),
    [anon_sym_reportextension] = ACTIONS(5025),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5025),
    [anon_sym_Reportextension] = ACTIONS(5025),
    [anon_sym_ReportExtension] = ACTIONS(5025),
    [anon_sym_reportExtension] = ACTIONS(5025),
    [sym_query_keyword] = ACTIONS(5025),
    [anon_sym_xmlport] = ACTIONS(5025),
    [anon_sym_XMLPORT] = ACTIONS(5025),
    [anon_sym_Xmlport] = ACTIONS(5025),
    [anon_sym_XMLport] = ACTIONS(5025),
    [anon_sym_XMLPort] = ACTIONS(5025),
    [anon_sym_XmlPort] = ACTIONS(5025),
    [anon_sym_enum] = ACTIONS(5027),
    [anon_sym_ENUM] = ACTIONS(5027),
    [anon_sym_Enum] = ACTIONS(5027),
    [anon_sym_eNUM] = ACTIONS(5025),
    [anon_sym_eNum] = ACTIONS(5025),
    [anon_sym_ENum] = ACTIONS(5025),
    [anon_sym_enumextension] = ACTIONS(5025),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5025),
    [anon_sym_Enumextension] = ACTIONS(5025),
    [anon_sym_EnumExtension] = ACTIONS(5025),
    [anon_sym_enumExtension] = ACTIONS(5025),
    [sym_interface_keyword] = ACTIONS(5025),
    [anon_sym_controladdin] = ACTIONS(5025),
    [anon_sym_CONTROLADDIN] = ACTIONS(5025),
    [anon_sym_Controladdin] = ACTIONS(5025),
    [anon_sym_ControlAddIn] = ACTIONS(5025),
    [anon_sym_ControlAddin] = ACTIONS(5025),
    [anon_sym_controlAddIn] = ACTIONS(5025),
    [anon_sym_controlAddin] = ACTIONS(5025),
    [anon_sym_dotnet] = ACTIONS(5025),
    [anon_sym_DOTNET] = ACTIONS(5025),
    [anon_sym_Dotnet] = ACTIONS(5025),
    [anon_sym_DotNet] = ACTIONS(5025),
    [anon_sym_dotNet] = ACTIONS(5025),
    [sym_profile_keyword] = ACTIONS(5027),
    [anon_sym_profileextension] = ACTIONS(5025),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5025),
    [anon_sym_Profileextension] = ACTIONS(5025),
    [anon_sym_ProfileExtension] = ACTIONS(5025),
    [anon_sym_profileExtension] = ACTIONS(5025),
    [anon_sym_permissionset] = ACTIONS(5027),
    [anon_sym_PERMISSIONSET] = ACTIONS(5027),
    [anon_sym_Permissionset] = ACTIONS(5027),
    [anon_sym_PermissionSet] = ACTIONS(5027),
    [anon_sym_permissionSet] = ACTIONS(5027),
    [anon_sym_permissionsetextension] = ACTIONS(5025),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5025),
    [anon_sym_Permissionsetextension] = ACTIONS(5025),
    [anon_sym_PermissionSetExtension] = ACTIONS(5025),
    [anon_sym_permissionSetExtension] = ACTIONS(5025),
    [sym_entitlement_keyword] = ACTIONS(5025),
    [anon_sym_pagecustomization] = ACTIONS(5025),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5025),
    [anon_sym_Pagecustomization] = ACTIONS(5025),
    [anon_sym_PageCustomization] = ACTIONS(5025),
    [anon_sym_pageCustomization] = ACTIONS(5025),
    [sym_using_keyword] = ACTIONS(5025),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5025),
    [sym_preproc_close] = ACTIONS(5025),
  },
  [STATE(1962)] = {
    [anon_sym_POUNDif] = ACTIONS(5029),
    [anon_sym_POUNDIF] = ACTIONS(5029),
    [anon_sym_POUNDIf] = ACTIONS(5029),
    [anon_sym_POUNDelif] = ACTIONS(5029),
    [anon_sym_POUNDELIF] = ACTIONS(5029),
    [anon_sym_POUNDElif] = ACTIONS(5029),
    [anon_sym_POUNDelse] = ACTIONS(5029),
    [anon_sym_POUNDELSE] = ACTIONS(5029),
    [anon_sym_POUNDElse] = ACTIONS(5029),
    [anon_sym_POUNDendif] = ACTIONS(5029),
    [anon_sym_POUNDENDIF] = ACTIONS(5029),
    [anon_sym_POUNDEndif] = ACTIONS(5029),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5031),
    [anon_sym_tableextension] = ACTIONS(5029),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5029),
    [anon_sym_Tableextension] = ACTIONS(5029),
    [anon_sym_TableExtension] = ACTIONS(5029),
    [anon_sym_tableExtension] = ACTIONS(5029),
    [sym_page_keyword] = ACTIONS(5031),
    [anon_sym_pageextension] = ACTIONS(5029),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5029),
    [anon_sym_Pageextension] = ACTIONS(5029),
    [anon_sym_PageExtension] = ACTIONS(5029),
    [anon_sym_pageExtension] = ACTIONS(5029),
    [anon_sym_codeunit] = ACTIONS(5029),
    [anon_sym_CODEUNIT] = ACTIONS(5029),
    [anon_sym_Codeunit] = ACTIONS(5029),
    [anon_sym_CodeUnit] = ACTIONS(5029),
    [anon_sym_COdeunit] = ACTIONS(5029),
    [anon_sym_codeUnit] = ACTIONS(5029),
    [sym_report_keyword] = ACTIONS(5031),
    [anon_sym_reportextension] = ACTIONS(5029),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5029),
    [anon_sym_Reportextension] = ACTIONS(5029),
    [anon_sym_ReportExtension] = ACTIONS(5029),
    [anon_sym_reportExtension] = ACTIONS(5029),
    [sym_query_keyword] = ACTIONS(5029),
    [anon_sym_xmlport] = ACTIONS(5029),
    [anon_sym_XMLPORT] = ACTIONS(5029),
    [anon_sym_Xmlport] = ACTIONS(5029),
    [anon_sym_XMLport] = ACTIONS(5029),
    [anon_sym_XMLPort] = ACTIONS(5029),
    [anon_sym_XmlPort] = ACTIONS(5029),
    [anon_sym_enum] = ACTIONS(5031),
    [anon_sym_ENUM] = ACTIONS(5031),
    [anon_sym_Enum] = ACTIONS(5031),
    [anon_sym_eNUM] = ACTIONS(5029),
    [anon_sym_eNum] = ACTIONS(5029),
    [anon_sym_ENum] = ACTIONS(5029),
    [anon_sym_enumextension] = ACTIONS(5029),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5029),
    [anon_sym_Enumextension] = ACTIONS(5029),
    [anon_sym_EnumExtension] = ACTIONS(5029),
    [anon_sym_enumExtension] = ACTIONS(5029),
    [sym_interface_keyword] = ACTIONS(5029),
    [anon_sym_controladdin] = ACTIONS(5029),
    [anon_sym_CONTROLADDIN] = ACTIONS(5029),
    [anon_sym_Controladdin] = ACTIONS(5029),
    [anon_sym_ControlAddIn] = ACTIONS(5029),
    [anon_sym_ControlAddin] = ACTIONS(5029),
    [anon_sym_controlAddIn] = ACTIONS(5029),
    [anon_sym_controlAddin] = ACTIONS(5029),
    [anon_sym_dotnet] = ACTIONS(5029),
    [anon_sym_DOTNET] = ACTIONS(5029),
    [anon_sym_Dotnet] = ACTIONS(5029),
    [anon_sym_DotNet] = ACTIONS(5029),
    [anon_sym_dotNet] = ACTIONS(5029),
    [sym_profile_keyword] = ACTIONS(5031),
    [anon_sym_profileextension] = ACTIONS(5029),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5029),
    [anon_sym_Profileextension] = ACTIONS(5029),
    [anon_sym_ProfileExtension] = ACTIONS(5029),
    [anon_sym_profileExtension] = ACTIONS(5029),
    [anon_sym_permissionset] = ACTIONS(5031),
    [anon_sym_PERMISSIONSET] = ACTIONS(5031),
    [anon_sym_Permissionset] = ACTIONS(5031),
    [anon_sym_PermissionSet] = ACTIONS(5031),
    [anon_sym_permissionSet] = ACTIONS(5031),
    [anon_sym_permissionsetextension] = ACTIONS(5029),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5029),
    [anon_sym_Permissionsetextension] = ACTIONS(5029),
    [anon_sym_PermissionSetExtension] = ACTIONS(5029),
    [anon_sym_permissionSetExtension] = ACTIONS(5029),
    [sym_entitlement_keyword] = ACTIONS(5029),
    [anon_sym_pagecustomization] = ACTIONS(5029),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5029),
    [anon_sym_Pagecustomization] = ACTIONS(5029),
    [anon_sym_PageCustomization] = ACTIONS(5029),
    [anon_sym_pageCustomization] = ACTIONS(5029),
    [sym_using_keyword] = ACTIONS(5029),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5029),
    [sym_preproc_close] = ACTIONS(5029),
  },
  [STATE(1963)] = {
    [anon_sym_POUNDif] = ACTIONS(5033),
    [anon_sym_POUNDIF] = ACTIONS(5033),
    [anon_sym_POUNDIf] = ACTIONS(5033),
    [anon_sym_POUNDelif] = ACTIONS(5033),
    [anon_sym_POUNDELIF] = ACTIONS(5033),
    [anon_sym_POUNDElif] = ACTIONS(5033),
    [anon_sym_POUNDelse] = ACTIONS(5033),
    [anon_sym_POUNDELSE] = ACTIONS(5033),
    [anon_sym_POUNDElse] = ACTIONS(5033),
    [anon_sym_POUNDendif] = ACTIONS(5033),
    [anon_sym_POUNDENDIF] = ACTIONS(5033),
    [anon_sym_POUNDEndif] = ACTIONS(5033),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5035),
    [anon_sym_tableextension] = ACTIONS(5033),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5033),
    [anon_sym_Tableextension] = ACTIONS(5033),
    [anon_sym_TableExtension] = ACTIONS(5033),
    [anon_sym_tableExtension] = ACTIONS(5033),
    [sym_page_keyword] = ACTIONS(5035),
    [anon_sym_pageextension] = ACTIONS(5033),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5033),
    [anon_sym_Pageextension] = ACTIONS(5033),
    [anon_sym_PageExtension] = ACTIONS(5033),
    [anon_sym_pageExtension] = ACTIONS(5033),
    [anon_sym_codeunit] = ACTIONS(5033),
    [anon_sym_CODEUNIT] = ACTIONS(5033),
    [anon_sym_Codeunit] = ACTIONS(5033),
    [anon_sym_CodeUnit] = ACTIONS(5033),
    [anon_sym_COdeunit] = ACTIONS(5033),
    [anon_sym_codeUnit] = ACTIONS(5033),
    [sym_report_keyword] = ACTIONS(5035),
    [anon_sym_reportextension] = ACTIONS(5033),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5033),
    [anon_sym_Reportextension] = ACTIONS(5033),
    [anon_sym_ReportExtension] = ACTIONS(5033),
    [anon_sym_reportExtension] = ACTIONS(5033),
    [sym_query_keyword] = ACTIONS(5033),
    [anon_sym_xmlport] = ACTIONS(5033),
    [anon_sym_XMLPORT] = ACTIONS(5033),
    [anon_sym_Xmlport] = ACTIONS(5033),
    [anon_sym_XMLport] = ACTIONS(5033),
    [anon_sym_XMLPort] = ACTIONS(5033),
    [anon_sym_XmlPort] = ACTIONS(5033),
    [anon_sym_enum] = ACTIONS(5035),
    [anon_sym_ENUM] = ACTIONS(5035),
    [anon_sym_Enum] = ACTIONS(5035),
    [anon_sym_eNUM] = ACTIONS(5033),
    [anon_sym_eNum] = ACTIONS(5033),
    [anon_sym_ENum] = ACTIONS(5033),
    [anon_sym_enumextension] = ACTIONS(5033),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5033),
    [anon_sym_Enumextension] = ACTIONS(5033),
    [anon_sym_EnumExtension] = ACTIONS(5033),
    [anon_sym_enumExtension] = ACTIONS(5033),
    [sym_interface_keyword] = ACTIONS(5033),
    [anon_sym_controladdin] = ACTIONS(5033),
    [anon_sym_CONTROLADDIN] = ACTIONS(5033),
    [anon_sym_Controladdin] = ACTIONS(5033),
    [anon_sym_ControlAddIn] = ACTIONS(5033),
    [anon_sym_ControlAddin] = ACTIONS(5033),
    [anon_sym_controlAddIn] = ACTIONS(5033),
    [anon_sym_controlAddin] = ACTIONS(5033),
    [anon_sym_dotnet] = ACTIONS(5033),
    [anon_sym_DOTNET] = ACTIONS(5033),
    [anon_sym_Dotnet] = ACTIONS(5033),
    [anon_sym_DotNet] = ACTIONS(5033),
    [anon_sym_dotNet] = ACTIONS(5033),
    [sym_profile_keyword] = ACTIONS(5035),
    [anon_sym_profileextension] = ACTIONS(5033),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5033),
    [anon_sym_Profileextension] = ACTIONS(5033),
    [anon_sym_ProfileExtension] = ACTIONS(5033),
    [anon_sym_profileExtension] = ACTIONS(5033),
    [anon_sym_permissionset] = ACTIONS(5035),
    [anon_sym_PERMISSIONSET] = ACTIONS(5035),
    [anon_sym_Permissionset] = ACTIONS(5035),
    [anon_sym_PermissionSet] = ACTIONS(5035),
    [anon_sym_permissionSet] = ACTIONS(5035),
    [anon_sym_permissionsetextension] = ACTIONS(5033),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5033),
    [anon_sym_Permissionsetextension] = ACTIONS(5033),
    [anon_sym_PermissionSetExtension] = ACTIONS(5033),
    [anon_sym_permissionSetExtension] = ACTIONS(5033),
    [sym_entitlement_keyword] = ACTIONS(5033),
    [anon_sym_pagecustomization] = ACTIONS(5033),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5033),
    [anon_sym_Pagecustomization] = ACTIONS(5033),
    [anon_sym_PageCustomization] = ACTIONS(5033),
    [anon_sym_pageCustomization] = ACTIONS(5033),
    [sym_using_keyword] = ACTIONS(5033),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5033),
    [sym_preproc_close] = ACTIONS(5033),
  },
  [STATE(1964)] = {
    [anon_sym_POUNDif] = ACTIONS(5037),
    [anon_sym_POUNDIF] = ACTIONS(5037),
    [anon_sym_POUNDIf] = ACTIONS(5037),
    [anon_sym_POUNDelif] = ACTIONS(5037),
    [anon_sym_POUNDELIF] = ACTIONS(5037),
    [anon_sym_POUNDElif] = ACTIONS(5037),
    [anon_sym_POUNDelse] = ACTIONS(5037),
    [anon_sym_POUNDELSE] = ACTIONS(5037),
    [anon_sym_POUNDElse] = ACTIONS(5037),
    [anon_sym_POUNDendif] = ACTIONS(5037),
    [anon_sym_POUNDENDIF] = ACTIONS(5037),
    [anon_sym_POUNDEndif] = ACTIONS(5037),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5039),
    [anon_sym_tableextension] = ACTIONS(5037),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5037),
    [anon_sym_Tableextension] = ACTIONS(5037),
    [anon_sym_TableExtension] = ACTIONS(5037),
    [anon_sym_tableExtension] = ACTIONS(5037),
    [sym_page_keyword] = ACTIONS(5039),
    [anon_sym_pageextension] = ACTIONS(5037),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5037),
    [anon_sym_Pageextension] = ACTIONS(5037),
    [anon_sym_PageExtension] = ACTIONS(5037),
    [anon_sym_pageExtension] = ACTIONS(5037),
    [anon_sym_codeunit] = ACTIONS(5037),
    [anon_sym_CODEUNIT] = ACTIONS(5037),
    [anon_sym_Codeunit] = ACTIONS(5037),
    [anon_sym_CodeUnit] = ACTIONS(5037),
    [anon_sym_COdeunit] = ACTIONS(5037),
    [anon_sym_codeUnit] = ACTIONS(5037),
    [sym_report_keyword] = ACTIONS(5039),
    [anon_sym_reportextension] = ACTIONS(5037),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5037),
    [anon_sym_Reportextension] = ACTIONS(5037),
    [anon_sym_ReportExtension] = ACTIONS(5037),
    [anon_sym_reportExtension] = ACTIONS(5037),
    [sym_query_keyword] = ACTIONS(5037),
    [anon_sym_xmlport] = ACTIONS(5037),
    [anon_sym_XMLPORT] = ACTIONS(5037),
    [anon_sym_Xmlport] = ACTIONS(5037),
    [anon_sym_XMLport] = ACTIONS(5037),
    [anon_sym_XMLPort] = ACTIONS(5037),
    [anon_sym_XmlPort] = ACTIONS(5037),
    [anon_sym_enum] = ACTIONS(5039),
    [anon_sym_ENUM] = ACTIONS(5039),
    [anon_sym_Enum] = ACTIONS(5039),
    [anon_sym_eNUM] = ACTIONS(5037),
    [anon_sym_eNum] = ACTIONS(5037),
    [anon_sym_ENum] = ACTIONS(5037),
    [anon_sym_enumextension] = ACTIONS(5037),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5037),
    [anon_sym_Enumextension] = ACTIONS(5037),
    [anon_sym_EnumExtension] = ACTIONS(5037),
    [anon_sym_enumExtension] = ACTIONS(5037),
    [sym_interface_keyword] = ACTIONS(5037),
    [anon_sym_controladdin] = ACTIONS(5037),
    [anon_sym_CONTROLADDIN] = ACTIONS(5037),
    [anon_sym_Controladdin] = ACTIONS(5037),
    [anon_sym_ControlAddIn] = ACTIONS(5037),
    [anon_sym_ControlAddin] = ACTIONS(5037),
    [anon_sym_controlAddIn] = ACTIONS(5037),
    [anon_sym_controlAddin] = ACTIONS(5037),
    [anon_sym_dotnet] = ACTIONS(5037),
    [anon_sym_DOTNET] = ACTIONS(5037),
    [anon_sym_Dotnet] = ACTIONS(5037),
    [anon_sym_DotNet] = ACTIONS(5037),
    [anon_sym_dotNet] = ACTIONS(5037),
    [sym_profile_keyword] = ACTIONS(5039),
    [anon_sym_profileextension] = ACTIONS(5037),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5037),
    [anon_sym_Profileextension] = ACTIONS(5037),
    [anon_sym_ProfileExtension] = ACTIONS(5037),
    [anon_sym_profileExtension] = ACTIONS(5037),
    [anon_sym_permissionset] = ACTIONS(5039),
    [anon_sym_PERMISSIONSET] = ACTIONS(5039),
    [anon_sym_Permissionset] = ACTIONS(5039),
    [anon_sym_PermissionSet] = ACTIONS(5039),
    [anon_sym_permissionSet] = ACTIONS(5039),
    [anon_sym_permissionsetextension] = ACTIONS(5037),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5037),
    [anon_sym_Permissionsetextension] = ACTIONS(5037),
    [anon_sym_PermissionSetExtension] = ACTIONS(5037),
    [anon_sym_permissionSetExtension] = ACTIONS(5037),
    [sym_entitlement_keyword] = ACTIONS(5037),
    [anon_sym_pagecustomization] = ACTIONS(5037),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5037),
    [anon_sym_Pagecustomization] = ACTIONS(5037),
    [anon_sym_PageCustomization] = ACTIONS(5037),
    [anon_sym_pageCustomization] = ACTIONS(5037),
    [sym_using_keyword] = ACTIONS(5037),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5037),
    [sym_preproc_close] = ACTIONS(5037),
  },
  [STATE(1965)] = {
    [anon_sym_POUNDif] = ACTIONS(5041),
    [anon_sym_POUNDIF] = ACTIONS(5041),
    [anon_sym_POUNDIf] = ACTIONS(5041),
    [anon_sym_POUNDelif] = ACTIONS(5041),
    [anon_sym_POUNDELIF] = ACTIONS(5041),
    [anon_sym_POUNDElif] = ACTIONS(5041),
    [anon_sym_POUNDelse] = ACTIONS(5041),
    [anon_sym_POUNDELSE] = ACTIONS(5041),
    [anon_sym_POUNDElse] = ACTIONS(5041),
    [anon_sym_POUNDendif] = ACTIONS(5041),
    [anon_sym_POUNDENDIF] = ACTIONS(5041),
    [anon_sym_POUNDEndif] = ACTIONS(5041),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5043),
    [anon_sym_tableextension] = ACTIONS(5041),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5041),
    [anon_sym_Tableextension] = ACTIONS(5041),
    [anon_sym_TableExtension] = ACTIONS(5041),
    [anon_sym_tableExtension] = ACTIONS(5041),
    [sym_page_keyword] = ACTIONS(5043),
    [anon_sym_pageextension] = ACTIONS(5041),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5041),
    [anon_sym_Pageextension] = ACTIONS(5041),
    [anon_sym_PageExtension] = ACTIONS(5041),
    [anon_sym_pageExtension] = ACTIONS(5041),
    [anon_sym_codeunit] = ACTIONS(5041),
    [anon_sym_CODEUNIT] = ACTIONS(5041),
    [anon_sym_Codeunit] = ACTIONS(5041),
    [anon_sym_CodeUnit] = ACTIONS(5041),
    [anon_sym_COdeunit] = ACTIONS(5041),
    [anon_sym_codeUnit] = ACTIONS(5041),
    [sym_report_keyword] = ACTIONS(5043),
    [anon_sym_reportextension] = ACTIONS(5041),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5041),
    [anon_sym_Reportextension] = ACTIONS(5041),
    [anon_sym_ReportExtension] = ACTIONS(5041),
    [anon_sym_reportExtension] = ACTIONS(5041),
    [sym_query_keyword] = ACTIONS(5041),
    [anon_sym_xmlport] = ACTIONS(5041),
    [anon_sym_XMLPORT] = ACTIONS(5041),
    [anon_sym_Xmlport] = ACTIONS(5041),
    [anon_sym_XMLport] = ACTIONS(5041),
    [anon_sym_XMLPort] = ACTIONS(5041),
    [anon_sym_XmlPort] = ACTIONS(5041),
    [anon_sym_enum] = ACTIONS(5043),
    [anon_sym_ENUM] = ACTIONS(5043),
    [anon_sym_Enum] = ACTIONS(5043),
    [anon_sym_eNUM] = ACTIONS(5041),
    [anon_sym_eNum] = ACTIONS(5041),
    [anon_sym_ENum] = ACTIONS(5041),
    [anon_sym_enumextension] = ACTIONS(5041),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5041),
    [anon_sym_Enumextension] = ACTIONS(5041),
    [anon_sym_EnumExtension] = ACTIONS(5041),
    [anon_sym_enumExtension] = ACTIONS(5041),
    [sym_interface_keyword] = ACTIONS(5041),
    [anon_sym_controladdin] = ACTIONS(5041),
    [anon_sym_CONTROLADDIN] = ACTIONS(5041),
    [anon_sym_Controladdin] = ACTIONS(5041),
    [anon_sym_ControlAddIn] = ACTIONS(5041),
    [anon_sym_ControlAddin] = ACTIONS(5041),
    [anon_sym_controlAddIn] = ACTIONS(5041),
    [anon_sym_controlAddin] = ACTIONS(5041),
    [anon_sym_dotnet] = ACTIONS(5041),
    [anon_sym_DOTNET] = ACTIONS(5041),
    [anon_sym_Dotnet] = ACTIONS(5041),
    [anon_sym_DotNet] = ACTIONS(5041),
    [anon_sym_dotNet] = ACTIONS(5041),
    [sym_profile_keyword] = ACTIONS(5043),
    [anon_sym_profileextension] = ACTIONS(5041),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5041),
    [anon_sym_Profileextension] = ACTIONS(5041),
    [anon_sym_ProfileExtension] = ACTIONS(5041),
    [anon_sym_profileExtension] = ACTIONS(5041),
    [anon_sym_permissionset] = ACTIONS(5043),
    [anon_sym_PERMISSIONSET] = ACTIONS(5043),
    [anon_sym_Permissionset] = ACTIONS(5043),
    [anon_sym_PermissionSet] = ACTIONS(5043),
    [anon_sym_permissionSet] = ACTIONS(5043),
    [anon_sym_permissionsetextension] = ACTIONS(5041),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5041),
    [anon_sym_Permissionsetextension] = ACTIONS(5041),
    [anon_sym_PermissionSetExtension] = ACTIONS(5041),
    [anon_sym_permissionSetExtension] = ACTIONS(5041),
    [sym_entitlement_keyword] = ACTIONS(5041),
    [anon_sym_pagecustomization] = ACTIONS(5041),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5041),
    [anon_sym_Pagecustomization] = ACTIONS(5041),
    [anon_sym_PageCustomization] = ACTIONS(5041),
    [anon_sym_pageCustomization] = ACTIONS(5041),
    [sym_using_keyword] = ACTIONS(5041),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5041),
    [sym_preproc_close] = ACTIONS(5041),
  },
  [STATE(1966)] = {
    [anon_sym_POUNDif] = ACTIONS(5045),
    [anon_sym_POUNDIF] = ACTIONS(5045),
    [anon_sym_POUNDIf] = ACTIONS(5045),
    [anon_sym_POUNDelif] = ACTIONS(5045),
    [anon_sym_POUNDELIF] = ACTIONS(5045),
    [anon_sym_POUNDElif] = ACTIONS(5045),
    [anon_sym_POUNDelse] = ACTIONS(5045),
    [anon_sym_POUNDELSE] = ACTIONS(5045),
    [anon_sym_POUNDElse] = ACTIONS(5045),
    [anon_sym_POUNDendif] = ACTIONS(5045),
    [anon_sym_POUNDENDIF] = ACTIONS(5045),
    [anon_sym_POUNDEndif] = ACTIONS(5045),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5047),
    [anon_sym_tableextension] = ACTIONS(5045),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5045),
    [anon_sym_Tableextension] = ACTIONS(5045),
    [anon_sym_TableExtension] = ACTIONS(5045),
    [anon_sym_tableExtension] = ACTIONS(5045),
    [sym_page_keyword] = ACTIONS(5047),
    [anon_sym_pageextension] = ACTIONS(5045),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5045),
    [anon_sym_Pageextension] = ACTIONS(5045),
    [anon_sym_PageExtension] = ACTIONS(5045),
    [anon_sym_pageExtension] = ACTIONS(5045),
    [anon_sym_codeunit] = ACTIONS(5045),
    [anon_sym_CODEUNIT] = ACTIONS(5045),
    [anon_sym_Codeunit] = ACTIONS(5045),
    [anon_sym_CodeUnit] = ACTIONS(5045),
    [anon_sym_COdeunit] = ACTIONS(5045),
    [anon_sym_codeUnit] = ACTIONS(5045),
    [sym_report_keyword] = ACTIONS(5047),
    [anon_sym_reportextension] = ACTIONS(5045),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5045),
    [anon_sym_Reportextension] = ACTIONS(5045),
    [anon_sym_ReportExtension] = ACTIONS(5045),
    [anon_sym_reportExtension] = ACTIONS(5045),
    [sym_query_keyword] = ACTIONS(5045),
    [anon_sym_xmlport] = ACTIONS(5045),
    [anon_sym_XMLPORT] = ACTIONS(5045),
    [anon_sym_Xmlport] = ACTIONS(5045),
    [anon_sym_XMLport] = ACTIONS(5045),
    [anon_sym_XMLPort] = ACTIONS(5045),
    [anon_sym_XmlPort] = ACTIONS(5045),
    [anon_sym_enum] = ACTIONS(5047),
    [anon_sym_ENUM] = ACTIONS(5047),
    [anon_sym_Enum] = ACTIONS(5047),
    [anon_sym_eNUM] = ACTIONS(5045),
    [anon_sym_eNum] = ACTIONS(5045),
    [anon_sym_ENum] = ACTIONS(5045),
    [anon_sym_enumextension] = ACTIONS(5045),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5045),
    [anon_sym_Enumextension] = ACTIONS(5045),
    [anon_sym_EnumExtension] = ACTIONS(5045),
    [anon_sym_enumExtension] = ACTIONS(5045),
    [sym_interface_keyword] = ACTIONS(5045),
    [anon_sym_controladdin] = ACTIONS(5045),
    [anon_sym_CONTROLADDIN] = ACTIONS(5045),
    [anon_sym_Controladdin] = ACTIONS(5045),
    [anon_sym_ControlAddIn] = ACTIONS(5045),
    [anon_sym_ControlAddin] = ACTIONS(5045),
    [anon_sym_controlAddIn] = ACTIONS(5045),
    [anon_sym_controlAddin] = ACTIONS(5045),
    [anon_sym_dotnet] = ACTIONS(5045),
    [anon_sym_DOTNET] = ACTIONS(5045),
    [anon_sym_Dotnet] = ACTIONS(5045),
    [anon_sym_DotNet] = ACTIONS(5045),
    [anon_sym_dotNet] = ACTIONS(5045),
    [sym_profile_keyword] = ACTIONS(5047),
    [anon_sym_profileextension] = ACTIONS(5045),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5045),
    [anon_sym_Profileextension] = ACTIONS(5045),
    [anon_sym_ProfileExtension] = ACTIONS(5045),
    [anon_sym_profileExtension] = ACTIONS(5045),
    [anon_sym_permissionset] = ACTIONS(5047),
    [anon_sym_PERMISSIONSET] = ACTIONS(5047),
    [anon_sym_Permissionset] = ACTIONS(5047),
    [anon_sym_PermissionSet] = ACTIONS(5047),
    [anon_sym_permissionSet] = ACTIONS(5047),
    [anon_sym_permissionsetextension] = ACTIONS(5045),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5045),
    [anon_sym_Permissionsetextension] = ACTIONS(5045),
    [anon_sym_PermissionSetExtension] = ACTIONS(5045),
    [anon_sym_permissionSetExtension] = ACTIONS(5045),
    [sym_entitlement_keyword] = ACTIONS(5045),
    [anon_sym_pagecustomization] = ACTIONS(5045),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5045),
    [anon_sym_Pagecustomization] = ACTIONS(5045),
    [anon_sym_PageCustomization] = ACTIONS(5045),
    [anon_sym_pageCustomization] = ACTIONS(5045),
    [sym_using_keyword] = ACTIONS(5045),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5045),
    [sym_preproc_close] = ACTIONS(5045),
  },
  [STATE(1967)] = {
    [anon_sym_POUNDif] = ACTIONS(5049),
    [anon_sym_POUNDIF] = ACTIONS(5049),
    [anon_sym_POUNDIf] = ACTIONS(5049),
    [anon_sym_POUNDelif] = ACTIONS(5049),
    [anon_sym_POUNDELIF] = ACTIONS(5049),
    [anon_sym_POUNDElif] = ACTIONS(5049),
    [anon_sym_POUNDelse] = ACTIONS(5049),
    [anon_sym_POUNDELSE] = ACTIONS(5049),
    [anon_sym_POUNDElse] = ACTIONS(5049),
    [anon_sym_POUNDendif] = ACTIONS(5049),
    [anon_sym_POUNDENDIF] = ACTIONS(5049),
    [anon_sym_POUNDEndif] = ACTIONS(5049),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5051),
    [anon_sym_tableextension] = ACTIONS(5049),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5049),
    [anon_sym_Tableextension] = ACTIONS(5049),
    [anon_sym_TableExtension] = ACTIONS(5049),
    [anon_sym_tableExtension] = ACTIONS(5049),
    [sym_page_keyword] = ACTIONS(5051),
    [anon_sym_pageextension] = ACTIONS(5049),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5049),
    [anon_sym_Pageextension] = ACTIONS(5049),
    [anon_sym_PageExtension] = ACTIONS(5049),
    [anon_sym_pageExtension] = ACTIONS(5049),
    [anon_sym_codeunit] = ACTIONS(5049),
    [anon_sym_CODEUNIT] = ACTIONS(5049),
    [anon_sym_Codeunit] = ACTIONS(5049),
    [anon_sym_CodeUnit] = ACTIONS(5049),
    [anon_sym_COdeunit] = ACTIONS(5049),
    [anon_sym_codeUnit] = ACTIONS(5049),
    [sym_report_keyword] = ACTIONS(5051),
    [anon_sym_reportextension] = ACTIONS(5049),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5049),
    [anon_sym_Reportextension] = ACTIONS(5049),
    [anon_sym_ReportExtension] = ACTIONS(5049),
    [anon_sym_reportExtension] = ACTIONS(5049),
    [sym_query_keyword] = ACTIONS(5049),
    [anon_sym_xmlport] = ACTIONS(5049),
    [anon_sym_XMLPORT] = ACTIONS(5049),
    [anon_sym_Xmlport] = ACTIONS(5049),
    [anon_sym_XMLport] = ACTIONS(5049),
    [anon_sym_XMLPort] = ACTIONS(5049),
    [anon_sym_XmlPort] = ACTIONS(5049),
    [anon_sym_enum] = ACTIONS(5051),
    [anon_sym_ENUM] = ACTIONS(5051),
    [anon_sym_Enum] = ACTIONS(5051),
    [anon_sym_eNUM] = ACTIONS(5049),
    [anon_sym_eNum] = ACTIONS(5049),
    [anon_sym_ENum] = ACTIONS(5049),
    [anon_sym_enumextension] = ACTIONS(5049),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5049),
    [anon_sym_Enumextension] = ACTIONS(5049),
    [anon_sym_EnumExtension] = ACTIONS(5049),
    [anon_sym_enumExtension] = ACTIONS(5049),
    [sym_interface_keyword] = ACTIONS(5049),
    [anon_sym_controladdin] = ACTIONS(5049),
    [anon_sym_CONTROLADDIN] = ACTIONS(5049),
    [anon_sym_Controladdin] = ACTIONS(5049),
    [anon_sym_ControlAddIn] = ACTIONS(5049),
    [anon_sym_ControlAddin] = ACTIONS(5049),
    [anon_sym_controlAddIn] = ACTIONS(5049),
    [anon_sym_controlAddin] = ACTIONS(5049),
    [anon_sym_dotnet] = ACTIONS(5049),
    [anon_sym_DOTNET] = ACTIONS(5049),
    [anon_sym_Dotnet] = ACTIONS(5049),
    [anon_sym_DotNet] = ACTIONS(5049),
    [anon_sym_dotNet] = ACTIONS(5049),
    [sym_profile_keyword] = ACTIONS(5051),
    [anon_sym_profileextension] = ACTIONS(5049),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5049),
    [anon_sym_Profileextension] = ACTIONS(5049),
    [anon_sym_ProfileExtension] = ACTIONS(5049),
    [anon_sym_profileExtension] = ACTIONS(5049),
    [anon_sym_permissionset] = ACTIONS(5051),
    [anon_sym_PERMISSIONSET] = ACTIONS(5051),
    [anon_sym_Permissionset] = ACTIONS(5051),
    [anon_sym_PermissionSet] = ACTIONS(5051),
    [anon_sym_permissionSet] = ACTIONS(5051),
    [anon_sym_permissionsetextension] = ACTIONS(5049),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5049),
    [anon_sym_Permissionsetextension] = ACTIONS(5049),
    [anon_sym_PermissionSetExtension] = ACTIONS(5049),
    [anon_sym_permissionSetExtension] = ACTIONS(5049),
    [sym_entitlement_keyword] = ACTIONS(5049),
    [anon_sym_pagecustomization] = ACTIONS(5049),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5049),
    [anon_sym_Pagecustomization] = ACTIONS(5049),
    [anon_sym_PageCustomization] = ACTIONS(5049),
    [anon_sym_pageCustomization] = ACTIONS(5049),
    [sym_using_keyword] = ACTIONS(5049),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5049),
    [sym_preproc_close] = ACTIONS(5049),
  },
  [STATE(1968)] = {
    [anon_sym_POUNDif] = ACTIONS(5053),
    [anon_sym_POUNDIF] = ACTIONS(5053),
    [anon_sym_POUNDIf] = ACTIONS(5053),
    [anon_sym_POUNDelif] = ACTIONS(5053),
    [anon_sym_POUNDELIF] = ACTIONS(5053),
    [anon_sym_POUNDElif] = ACTIONS(5053),
    [anon_sym_POUNDelse] = ACTIONS(5053),
    [anon_sym_POUNDELSE] = ACTIONS(5053),
    [anon_sym_POUNDElse] = ACTIONS(5053),
    [anon_sym_POUNDendif] = ACTIONS(5053),
    [anon_sym_POUNDENDIF] = ACTIONS(5053),
    [anon_sym_POUNDEndif] = ACTIONS(5053),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5055),
    [anon_sym_tableextension] = ACTIONS(5053),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5053),
    [anon_sym_Tableextension] = ACTIONS(5053),
    [anon_sym_TableExtension] = ACTIONS(5053),
    [anon_sym_tableExtension] = ACTIONS(5053),
    [sym_page_keyword] = ACTIONS(5055),
    [anon_sym_pageextension] = ACTIONS(5053),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5053),
    [anon_sym_Pageextension] = ACTIONS(5053),
    [anon_sym_PageExtension] = ACTIONS(5053),
    [anon_sym_pageExtension] = ACTIONS(5053),
    [anon_sym_codeunit] = ACTIONS(5053),
    [anon_sym_CODEUNIT] = ACTIONS(5053),
    [anon_sym_Codeunit] = ACTIONS(5053),
    [anon_sym_CodeUnit] = ACTIONS(5053),
    [anon_sym_COdeunit] = ACTIONS(5053),
    [anon_sym_codeUnit] = ACTIONS(5053),
    [sym_report_keyword] = ACTIONS(5055),
    [anon_sym_reportextension] = ACTIONS(5053),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5053),
    [anon_sym_Reportextension] = ACTIONS(5053),
    [anon_sym_ReportExtension] = ACTIONS(5053),
    [anon_sym_reportExtension] = ACTIONS(5053),
    [sym_query_keyword] = ACTIONS(5053),
    [anon_sym_xmlport] = ACTIONS(5053),
    [anon_sym_XMLPORT] = ACTIONS(5053),
    [anon_sym_Xmlport] = ACTIONS(5053),
    [anon_sym_XMLport] = ACTIONS(5053),
    [anon_sym_XMLPort] = ACTIONS(5053),
    [anon_sym_XmlPort] = ACTIONS(5053),
    [anon_sym_enum] = ACTIONS(5055),
    [anon_sym_ENUM] = ACTIONS(5055),
    [anon_sym_Enum] = ACTIONS(5055),
    [anon_sym_eNUM] = ACTIONS(5053),
    [anon_sym_eNum] = ACTIONS(5053),
    [anon_sym_ENum] = ACTIONS(5053),
    [anon_sym_enumextension] = ACTIONS(5053),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5053),
    [anon_sym_Enumextension] = ACTIONS(5053),
    [anon_sym_EnumExtension] = ACTIONS(5053),
    [anon_sym_enumExtension] = ACTIONS(5053),
    [sym_interface_keyword] = ACTIONS(5053),
    [anon_sym_controladdin] = ACTIONS(5053),
    [anon_sym_CONTROLADDIN] = ACTIONS(5053),
    [anon_sym_Controladdin] = ACTIONS(5053),
    [anon_sym_ControlAddIn] = ACTIONS(5053),
    [anon_sym_ControlAddin] = ACTIONS(5053),
    [anon_sym_controlAddIn] = ACTIONS(5053),
    [anon_sym_controlAddin] = ACTIONS(5053),
    [anon_sym_dotnet] = ACTIONS(5053),
    [anon_sym_DOTNET] = ACTIONS(5053),
    [anon_sym_Dotnet] = ACTIONS(5053),
    [anon_sym_DotNet] = ACTIONS(5053),
    [anon_sym_dotNet] = ACTIONS(5053),
    [sym_profile_keyword] = ACTIONS(5055),
    [anon_sym_profileextension] = ACTIONS(5053),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5053),
    [anon_sym_Profileextension] = ACTIONS(5053),
    [anon_sym_ProfileExtension] = ACTIONS(5053),
    [anon_sym_profileExtension] = ACTIONS(5053),
    [anon_sym_permissionset] = ACTIONS(5055),
    [anon_sym_PERMISSIONSET] = ACTIONS(5055),
    [anon_sym_Permissionset] = ACTIONS(5055),
    [anon_sym_PermissionSet] = ACTIONS(5055),
    [anon_sym_permissionSet] = ACTIONS(5055),
    [anon_sym_permissionsetextension] = ACTIONS(5053),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5053),
    [anon_sym_Permissionsetextension] = ACTIONS(5053),
    [anon_sym_PermissionSetExtension] = ACTIONS(5053),
    [anon_sym_permissionSetExtension] = ACTIONS(5053),
    [sym_entitlement_keyword] = ACTIONS(5053),
    [anon_sym_pagecustomization] = ACTIONS(5053),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5053),
    [anon_sym_Pagecustomization] = ACTIONS(5053),
    [anon_sym_PageCustomization] = ACTIONS(5053),
    [anon_sym_pageCustomization] = ACTIONS(5053),
    [sym_using_keyword] = ACTIONS(5053),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5053),
    [sym_preproc_close] = ACTIONS(5053),
  },
  [STATE(1969)] = {
    [anon_sym_POUNDif] = ACTIONS(5057),
    [anon_sym_POUNDIF] = ACTIONS(5057),
    [anon_sym_POUNDIf] = ACTIONS(5057),
    [anon_sym_POUNDelif] = ACTIONS(5057),
    [anon_sym_POUNDELIF] = ACTIONS(5057),
    [anon_sym_POUNDElif] = ACTIONS(5057),
    [anon_sym_POUNDelse] = ACTIONS(5057),
    [anon_sym_POUNDELSE] = ACTIONS(5057),
    [anon_sym_POUNDElse] = ACTIONS(5057),
    [anon_sym_POUNDendif] = ACTIONS(5057),
    [anon_sym_POUNDENDIF] = ACTIONS(5057),
    [anon_sym_POUNDEndif] = ACTIONS(5057),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5059),
    [anon_sym_tableextension] = ACTIONS(5057),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5057),
    [anon_sym_Tableextension] = ACTIONS(5057),
    [anon_sym_TableExtension] = ACTIONS(5057),
    [anon_sym_tableExtension] = ACTIONS(5057),
    [sym_page_keyword] = ACTIONS(5059),
    [anon_sym_pageextension] = ACTIONS(5057),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5057),
    [anon_sym_Pageextension] = ACTIONS(5057),
    [anon_sym_PageExtension] = ACTIONS(5057),
    [anon_sym_pageExtension] = ACTIONS(5057),
    [anon_sym_codeunit] = ACTIONS(5057),
    [anon_sym_CODEUNIT] = ACTIONS(5057),
    [anon_sym_Codeunit] = ACTIONS(5057),
    [anon_sym_CodeUnit] = ACTIONS(5057),
    [anon_sym_COdeunit] = ACTIONS(5057),
    [anon_sym_codeUnit] = ACTIONS(5057),
    [sym_report_keyword] = ACTIONS(5059),
    [anon_sym_reportextension] = ACTIONS(5057),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5057),
    [anon_sym_Reportextension] = ACTIONS(5057),
    [anon_sym_ReportExtension] = ACTIONS(5057),
    [anon_sym_reportExtension] = ACTIONS(5057),
    [sym_query_keyword] = ACTIONS(5057),
    [anon_sym_xmlport] = ACTIONS(5057),
    [anon_sym_XMLPORT] = ACTIONS(5057),
    [anon_sym_Xmlport] = ACTIONS(5057),
    [anon_sym_XMLport] = ACTIONS(5057),
    [anon_sym_XMLPort] = ACTIONS(5057),
    [anon_sym_XmlPort] = ACTIONS(5057),
    [anon_sym_enum] = ACTIONS(5059),
    [anon_sym_ENUM] = ACTIONS(5059),
    [anon_sym_Enum] = ACTIONS(5059),
    [anon_sym_eNUM] = ACTIONS(5057),
    [anon_sym_eNum] = ACTIONS(5057),
    [anon_sym_ENum] = ACTIONS(5057),
    [anon_sym_enumextension] = ACTIONS(5057),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5057),
    [anon_sym_Enumextension] = ACTIONS(5057),
    [anon_sym_EnumExtension] = ACTIONS(5057),
    [anon_sym_enumExtension] = ACTIONS(5057),
    [sym_interface_keyword] = ACTIONS(5057),
    [anon_sym_controladdin] = ACTIONS(5057),
    [anon_sym_CONTROLADDIN] = ACTIONS(5057),
    [anon_sym_Controladdin] = ACTIONS(5057),
    [anon_sym_ControlAddIn] = ACTIONS(5057),
    [anon_sym_ControlAddin] = ACTIONS(5057),
    [anon_sym_controlAddIn] = ACTIONS(5057),
    [anon_sym_controlAddin] = ACTIONS(5057),
    [anon_sym_dotnet] = ACTIONS(5057),
    [anon_sym_DOTNET] = ACTIONS(5057),
    [anon_sym_Dotnet] = ACTIONS(5057),
    [anon_sym_DotNet] = ACTIONS(5057),
    [anon_sym_dotNet] = ACTIONS(5057),
    [sym_profile_keyword] = ACTIONS(5059),
    [anon_sym_profileextension] = ACTIONS(5057),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5057),
    [anon_sym_Profileextension] = ACTIONS(5057),
    [anon_sym_ProfileExtension] = ACTIONS(5057),
    [anon_sym_profileExtension] = ACTIONS(5057),
    [anon_sym_permissionset] = ACTIONS(5059),
    [anon_sym_PERMISSIONSET] = ACTIONS(5059),
    [anon_sym_Permissionset] = ACTIONS(5059),
    [anon_sym_PermissionSet] = ACTIONS(5059),
    [anon_sym_permissionSet] = ACTIONS(5059),
    [anon_sym_permissionsetextension] = ACTIONS(5057),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5057),
    [anon_sym_Permissionsetextension] = ACTIONS(5057),
    [anon_sym_PermissionSetExtension] = ACTIONS(5057),
    [anon_sym_permissionSetExtension] = ACTIONS(5057),
    [sym_entitlement_keyword] = ACTIONS(5057),
    [anon_sym_pagecustomization] = ACTIONS(5057),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5057),
    [anon_sym_Pagecustomization] = ACTIONS(5057),
    [anon_sym_PageCustomization] = ACTIONS(5057),
    [anon_sym_pageCustomization] = ACTIONS(5057),
    [sym_using_keyword] = ACTIONS(5057),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5057),
    [sym_preproc_close] = ACTIONS(5057),
  },
  [STATE(1970)] = {
    [anon_sym_POUNDif] = ACTIONS(5061),
    [anon_sym_POUNDIF] = ACTIONS(5061),
    [anon_sym_POUNDIf] = ACTIONS(5061),
    [anon_sym_POUNDelif] = ACTIONS(5061),
    [anon_sym_POUNDELIF] = ACTIONS(5061),
    [anon_sym_POUNDElif] = ACTIONS(5061),
    [anon_sym_POUNDelse] = ACTIONS(5061),
    [anon_sym_POUNDELSE] = ACTIONS(5061),
    [anon_sym_POUNDElse] = ACTIONS(5061),
    [anon_sym_POUNDendif] = ACTIONS(5061),
    [anon_sym_POUNDENDIF] = ACTIONS(5061),
    [anon_sym_POUNDEndif] = ACTIONS(5061),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5063),
    [anon_sym_tableextension] = ACTIONS(5061),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5061),
    [anon_sym_Tableextension] = ACTIONS(5061),
    [anon_sym_TableExtension] = ACTIONS(5061),
    [anon_sym_tableExtension] = ACTIONS(5061),
    [sym_page_keyword] = ACTIONS(5063),
    [anon_sym_pageextension] = ACTIONS(5061),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5061),
    [anon_sym_Pageextension] = ACTIONS(5061),
    [anon_sym_PageExtension] = ACTIONS(5061),
    [anon_sym_pageExtension] = ACTIONS(5061),
    [anon_sym_codeunit] = ACTIONS(5061),
    [anon_sym_CODEUNIT] = ACTIONS(5061),
    [anon_sym_Codeunit] = ACTIONS(5061),
    [anon_sym_CodeUnit] = ACTIONS(5061),
    [anon_sym_COdeunit] = ACTIONS(5061),
    [anon_sym_codeUnit] = ACTIONS(5061),
    [sym_report_keyword] = ACTIONS(5063),
    [anon_sym_reportextension] = ACTIONS(5061),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5061),
    [anon_sym_Reportextension] = ACTIONS(5061),
    [anon_sym_ReportExtension] = ACTIONS(5061),
    [anon_sym_reportExtension] = ACTIONS(5061),
    [sym_query_keyword] = ACTIONS(5061),
    [anon_sym_xmlport] = ACTIONS(5061),
    [anon_sym_XMLPORT] = ACTIONS(5061),
    [anon_sym_Xmlport] = ACTIONS(5061),
    [anon_sym_XMLport] = ACTIONS(5061),
    [anon_sym_XMLPort] = ACTIONS(5061),
    [anon_sym_XmlPort] = ACTIONS(5061),
    [anon_sym_enum] = ACTIONS(5063),
    [anon_sym_ENUM] = ACTIONS(5063),
    [anon_sym_Enum] = ACTIONS(5063),
    [anon_sym_eNUM] = ACTIONS(5061),
    [anon_sym_eNum] = ACTIONS(5061),
    [anon_sym_ENum] = ACTIONS(5061),
    [anon_sym_enumextension] = ACTIONS(5061),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5061),
    [anon_sym_Enumextension] = ACTIONS(5061),
    [anon_sym_EnumExtension] = ACTIONS(5061),
    [anon_sym_enumExtension] = ACTIONS(5061),
    [sym_interface_keyword] = ACTIONS(5061),
    [anon_sym_controladdin] = ACTIONS(5061),
    [anon_sym_CONTROLADDIN] = ACTIONS(5061),
    [anon_sym_Controladdin] = ACTIONS(5061),
    [anon_sym_ControlAddIn] = ACTIONS(5061),
    [anon_sym_ControlAddin] = ACTIONS(5061),
    [anon_sym_controlAddIn] = ACTIONS(5061),
    [anon_sym_controlAddin] = ACTIONS(5061),
    [anon_sym_dotnet] = ACTIONS(5061),
    [anon_sym_DOTNET] = ACTIONS(5061),
    [anon_sym_Dotnet] = ACTIONS(5061),
    [anon_sym_DotNet] = ACTIONS(5061),
    [anon_sym_dotNet] = ACTIONS(5061),
    [sym_profile_keyword] = ACTIONS(5063),
    [anon_sym_profileextension] = ACTIONS(5061),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5061),
    [anon_sym_Profileextension] = ACTIONS(5061),
    [anon_sym_ProfileExtension] = ACTIONS(5061),
    [anon_sym_profileExtension] = ACTIONS(5061),
    [anon_sym_permissionset] = ACTIONS(5063),
    [anon_sym_PERMISSIONSET] = ACTIONS(5063),
    [anon_sym_Permissionset] = ACTIONS(5063),
    [anon_sym_PermissionSet] = ACTIONS(5063),
    [anon_sym_permissionSet] = ACTIONS(5063),
    [anon_sym_permissionsetextension] = ACTIONS(5061),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5061),
    [anon_sym_Permissionsetextension] = ACTIONS(5061),
    [anon_sym_PermissionSetExtension] = ACTIONS(5061),
    [anon_sym_permissionSetExtension] = ACTIONS(5061),
    [sym_entitlement_keyword] = ACTIONS(5061),
    [anon_sym_pagecustomization] = ACTIONS(5061),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5061),
    [anon_sym_Pagecustomization] = ACTIONS(5061),
    [anon_sym_PageCustomization] = ACTIONS(5061),
    [anon_sym_pageCustomization] = ACTIONS(5061),
    [sym_using_keyword] = ACTIONS(5061),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5061),
    [sym_preproc_close] = ACTIONS(5061),
  },
  [STATE(1971)] = {
    [anon_sym_POUNDif] = ACTIONS(5065),
    [anon_sym_POUNDIF] = ACTIONS(5065),
    [anon_sym_POUNDIf] = ACTIONS(5065),
    [anon_sym_POUNDelif] = ACTIONS(5065),
    [anon_sym_POUNDELIF] = ACTIONS(5065),
    [anon_sym_POUNDElif] = ACTIONS(5065),
    [anon_sym_POUNDelse] = ACTIONS(5065),
    [anon_sym_POUNDELSE] = ACTIONS(5065),
    [anon_sym_POUNDElse] = ACTIONS(5065),
    [anon_sym_POUNDendif] = ACTIONS(5065),
    [anon_sym_POUNDENDIF] = ACTIONS(5065),
    [anon_sym_POUNDEndif] = ACTIONS(5065),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5067),
    [anon_sym_tableextension] = ACTIONS(5065),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5065),
    [anon_sym_Tableextension] = ACTIONS(5065),
    [anon_sym_TableExtension] = ACTIONS(5065),
    [anon_sym_tableExtension] = ACTIONS(5065),
    [sym_page_keyword] = ACTIONS(5067),
    [anon_sym_pageextension] = ACTIONS(5065),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5065),
    [anon_sym_Pageextension] = ACTIONS(5065),
    [anon_sym_PageExtension] = ACTIONS(5065),
    [anon_sym_pageExtension] = ACTIONS(5065),
    [anon_sym_codeunit] = ACTIONS(5065),
    [anon_sym_CODEUNIT] = ACTIONS(5065),
    [anon_sym_Codeunit] = ACTIONS(5065),
    [anon_sym_CodeUnit] = ACTIONS(5065),
    [anon_sym_COdeunit] = ACTIONS(5065),
    [anon_sym_codeUnit] = ACTIONS(5065),
    [sym_report_keyword] = ACTIONS(5067),
    [anon_sym_reportextension] = ACTIONS(5065),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5065),
    [anon_sym_Reportextension] = ACTIONS(5065),
    [anon_sym_ReportExtension] = ACTIONS(5065),
    [anon_sym_reportExtension] = ACTIONS(5065),
    [sym_query_keyword] = ACTIONS(5065),
    [anon_sym_xmlport] = ACTIONS(5065),
    [anon_sym_XMLPORT] = ACTIONS(5065),
    [anon_sym_Xmlport] = ACTIONS(5065),
    [anon_sym_XMLport] = ACTIONS(5065),
    [anon_sym_XMLPort] = ACTIONS(5065),
    [anon_sym_XmlPort] = ACTIONS(5065),
    [anon_sym_enum] = ACTIONS(5067),
    [anon_sym_ENUM] = ACTIONS(5067),
    [anon_sym_Enum] = ACTIONS(5067),
    [anon_sym_eNUM] = ACTIONS(5065),
    [anon_sym_eNum] = ACTIONS(5065),
    [anon_sym_ENum] = ACTIONS(5065),
    [anon_sym_enumextension] = ACTIONS(5065),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5065),
    [anon_sym_Enumextension] = ACTIONS(5065),
    [anon_sym_EnumExtension] = ACTIONS(5065),
    [anon_sym_enumExtension] = ACTIONS(5065),
    [sym_interface_keyword] = ACTIONS(5065),
    [anon_sym_controladdin] = ACTIONS(5065),
    [anon_sym_CONTROLADDIN] = ACTIONS(5065),
    [anon_sym_Controladdin] = ACTIONS(5065),
    [anon_sym_ControlAddIn] = ACTIONS(5065),
    [anon_sym_ControlAddin] = ACTIONS(5065),
    [anon_sym_controlAddIn] = ACTIONS(5065),
    [anon_sym_controlAddin] = ACTIONS(5065),
    [anon_sym_dotnet] = ACTIONS(5065),
    [anon_sym_DOTNET] = ACTIONS(5065),
    [anon_sym_Dotnet] = ACTIONS(5065),
    [anon_sym_DotNet] = ACTIONS(5065),
    [anon_sym_dotNet] = ACTIONS(5065),
    [sym_profile_keyword] = ACTIONS(5067),
    [anon_sym_profileextension] = ACTIONS(5065),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5065),
    [anon_sym_Profileextension] = ACTIONS(5065),
    [anon_sym_ProfileExtension] = ACTIONS(5065),
    [anon_sym_profileExtension] = ACTIONS(5065),
    [anon_sym_permissionset] = ACTIONS(5067),
    [anon_sym_PERMISSIONSET] = ACTIONS(5067),
    [anon_sym_Permissionset] = ACTIONS(5067),
    [anon_sym_PermissionSet] = ACTIONS(5067),
    [anon_sym_permissionSet] = ACTIONS(5067),
    [anon_sym_permissionsetextension] = ACTIONS(5065),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5065),
    [anon_sym_Permissionsetextension] = ACTIONS(5065),
    [anon_sym_PermissionSetExtension] = ACTIONS(5065),
    [anon_sym_permissionSetExtension] = ACTIONS(5065),
    [sym_entitlement_keyword] = ACTIONS(5065),
    [anon_sym_pagecustomization] = ACTIONS(5065),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5065),
    [anon_sym_Pagecustomization] = ACTIONS(5065),
    [anon_sym_PageCustomization] = ACTIONS(5065),
    [anon_sym_pageCustomization] = ACTIONS(5065),
    [sym_using_keyword] = ACTIONS(5065),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5065),
    [sym_preproc_close] = ACTIONS(5065),
  },
  [STATE(1972)] = {
    [anon_sym_POUNDif] = ACTIONS(5069),
    [anon_sym_POUNDIF] = ACTIONS(5069),
    [anon_sym_POUNDIf] = ACTIONS(5069),
    [anon_sym_POUNDelif] = ACTIONS(5069),
    [anon_sym_POUNDELIF] = ACTIONS(5069),
    [anon_sym_POUNDElif] = ACTIONS(5069),
    [anon_sym_POUNDelse] = ACTIONS(5069),
    [anon_sym_POUNDELSE] = ACTIONS(5069),
    [anon_sym_POUNDElse] = ACTIONS(5069),
    [anon_sym_POUNDendif] = ACTIONS(5069),
    [anon_sym_POUNDENDIF] = ACTIONS(5069),
    [anon_sym_POUNDEndif] = ACTIONS(5069),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5071),
    [anon_sym_tableextension] = ACTIONS(5069),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5069),
    [anon_sym_Tableextension] = ACTIONS(5069),
    [anon_sym_TableExtension] = ACTIONS(5069),
    [anon_sym_tableExtension] = ACTIONS(5069),
    [sym_page_keyword] = ACTIONS(5071),
    [anon_sym_pageextension] = ACTIONS(5069),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5069),
    [anon_sym_Pageextension] = ACTIONS(5069),
    [anon_sym_PageExtension] = ACTIONS(5069),
    [anon_sym_pageExtension] = ACTIONS(5069),
    [anon_sym_codeunit] = ACTIONS(5069),
    [anon_sym_CODEUNIT] = ACTIONS(5069),
    [anon_sym_Codeunit] = ACTIONS(5069),
    [anon_sym_CodeUnit] = ACTIONS(5069),
    [anon_sym_COdeunit] = ACTIONS(5069),
    [anon_sym_codeUnit] = ACTIONS(5069),
    [sym_report_keyword] = ACTIONS(5071),
    [anon_sym_reportextension] = ACTIONS(5069),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5069),
    [anon_sym_Reportextension] = ACTIONS(5069),
    [anon_sym_ReportExtension] = ACTIONS(5069),
    [anon_sym_reportExtension] = ACTIONS(5069),
    [sym_query_keyword] = ACTIONS(5069),
    [anon_sym_xmlport] = ACTIONS(5069),
    [anon_sym_XMLPORT] = ACTIONS(5069),
    [anon_sym_Xmlport] = ACTIONS(5069),
    [anon_sym_XMLport] = ACTIONS(5069),
    [anon_sym_XMLPort] = ACTIONS(5069),
    [anon_sym_XmlPort] = ACTIONS(5069),
    [anon_sym_enum] = ACTIONS(5071),
    [anon_sym_ENUM] = ACTIONS(5071),
    [anon_sym_Enum] = ACTIONS(5071),
    [anon_sym_eNUM] = ACTIONS(5069),
    [anon_sym_eNum] = ACTIONS(5069),
    [anon_sym_ENum] = ACTIONS(5069),
    [anon_sym_enumextension] = ACTIONS(5069),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5069),
    [anon_sym_Enumextension] = ACTIONS(5069),
    [anon_sym_EnumExtension] = ACTIONS(5069),
    [anon_sym_enumExtension] = ACTIONS(5069),
    [sym_interface_keyword] = ACTIONS(5069),
    [anon_sym_controladdin] = ACTIONS(5069),
    [anon_sym_CONTROLADDIN] = ACTIONS(5069),
    [anon_sym_Controladdin] = ACTIONS(5069),
    [anon_sym_ControlAddIn] = ACTIONS(5069),
    [anon_sym_ControlAddin] = ACTIONS(5069),
    [anon_sym_controlAddIn] = ACTIONS(5069),
    [anon_sym_controlAddin] = ACTIONS(5069),
    [anon_sym_dotnet] = ACTIONS(5069),
    [anon_sym_DOTNET] = ACTIONS(5069),
    [anon_sym_Dotnet] = ACTIONS(5069),
    [anon_sym_DotNet] = ACTIONS(5069),
    [anon_sym_dotNet] = ACTIONS(5069),
    [sym_profile_keyword] = ACTIONS(5071),
    [anon_sym_profileextension] = ACTIONS(5069),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5069),
    [anon_sym_Profileextension] = ACTIONS(5069),
    [anon_sym_ProfileExtension] = ACTIONS(5069),
    [anon_sym_profileExtension] = ACTIONS(5069),
    [anon_sym_permissionset] = ACTIONS(5071),
    [anon_sym_PERMISSIONSET] = ACTIONS(5071),
    [anon_sym_Permissionset] = ACTIONS(5071),
    [anon_sym_PermissionSet] = ACTIONS(5071),
    [anon_sym_permissionSet] = ACTIONS(5071),
    [anon_sym_permissionsetextension] = ACTIONS(5069),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5069),
    [anon_sym_Permissionsetextension] = ACTIONS(5069),
    [anon_sym_PermissionSetExtension] = ACTIONS(5069),
    [anon_sym_permissionSetExtension] = ACTIONS(5069),
    [sym_entitlement_keyword] = ACTIONS(5069),
    [anon_sym_pagecustomization] = ACTIONS(5069),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5069),
    [anon_sym_Pagecustomization] = ACTIONS(5069),
    [anon_sym_PageCustomization] = ACTIONS(5069),
    [anon_sym_pageCustomization] = ACTIONS(5069),
    [sym_using_keyword] = ACTIONS(5069),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5069),
    [sym_preproc_close] = ACTIONS(5069),
  },
  [STATE(1973)] = {
    [anon_sym_POUNDif] = ACTIONS(5073),
    [anon_sym_POUNDIF] = ACTIONS(5073),
    [anon_sym_POUNDIf] = ACTIONS(5073),
    [anon_sym_POUNDelif] = ACTIONS(5073),
    [anon_sym_POUNDELIF] = ACTIONS(5073),
    [anon_sym_POUNDElif] = ACTIONS(5073),
    [anon_sym_POUNDelse] = ACTIONS(5073),
    [anon_sym_POUNDELSE] = ACTIONS(5073),
    [anon_sym_POUNDElse] = ACTIONS(5073),
    [anon_sym_POUNDendif] = ACTIONS(5073),
    [anon_sym_POUNDENDIF] = ACTIONS(5073),
    [anon_sym_POUNDEndif] = ACTIONS(5073),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5075),
    [anon_sym_tableextension] = ACTIONS(5073),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5073),
    [anon_sym_Tableextension] = ACTIONS(5073),
    [anon_sym_TableExtension] = ACTIONS(5073),
    [anon_sym_tableExtension] = ACTIONS(5073),
    [sym_page_keyword] = ACTIONS(5075),
    [anon_sym_pageextension] = ACTIONS(5073),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5073),
    [anon_sym_Pageextension] = ACTIONS(5073),
    [anon_sym_PageExtension] = ACTIONS(5073),
    [anon_sym_pageExtension] = ACTIONS(5073),
    [anon_sym_codeunit] = ACTIONS(5073),
    [anon_sym_CODEUNIT] = ACTIONS(5073),
    [anon_sym_Codeunit] = ACTIONS(5073),
    [anon_sym_CodeUnit] = ACTIONS(5073),
    [anon_sym_COdeunit] = ACTIONS(5073),
    [anon_sym_codeUnit] = ACTIONS(5073),
    [sym_report_keyword] = ACTIONS(5075),
    [anon_sym_reportextension] = ACTIONS(5073),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5073),
    [anon_sym_Reportextension] = ACTIONS(5073),
    [anon_sym_ReportExtension] = ACTIONS(5073),
    [anon_sym_reportExtension] = ACTIONS(5073),
    [sym_query_keyword] = ACTIONS(5073),
    [anon_sym_xmlport] = ACTIONS(5073),
    [anon_sym_XMLPORT] = ACTIONS(5073),
    [anon_sym_Xmlport] = ACTIONS(5073),
    [anon_sym_XMLport] = ACTIONS(5073),
    [anon_sym_XMLPort] = ACTIONS(5073),
    [anon_sym_XmlPort] = ACTIONS(5073),
    [anon_sym_enum] = ACTIONS(5075),
    [anon_sym_ENUM] = ACTIONS(5075),
    [anon_sym_Enum] = ACTIONS(5075),
    [anon_sym_eNUM] = ACTIONS(5073),
    [anon_sym_eNum] = ACTIONS(5073),
    [anon_sym_ENum] = ACTIONS(5073),
    [anon_sym_enumextension] = ACTIONS(5073),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5073),
    [anon_sym_Enumextension] = ACTIONS(5073),
    [anon_sym_EnumExtension] = ACTIONS(5073),
    [anon_sym_enumExtension] = ACTIONS(5073),
    [sym_interface_keyword] = ACTIONS(5073),
    [anon_sym_controladdin] = ACTIONS(5073),
    [anon_sym_CONTROLADDIN] = ACTIONS(5073),
    [anon_sym_Controladdin] = ACTIONS(5073),
    [anon_sym_ControlAddIn] = ACTIONS(5073),
    [anon_sym_ControlAddin] = ACTIONS(5073),
    [anon_sym_controlAddIn] = ACTIONS(5073),
    [anon_sym_controlAddin] = ACTIONS(5073),
    [anon_sym_dotnet] = ACTIONS(5073),
    [anon_sym_DOTNET] = ACTIONS(5073),
    [anon_sym_Dotnet] = ACTIONS(5073),
    [anon_sym_DotNet] = ACTIONS(5073),
    [anon_sym_dotNet] = ACTIONS(5073),
    [sym_profile_keyword] = ACTIONS(5075),
    [anon_sym_profileextension] = ACTIONS(5073),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5073),
    [anon_sym_Profileextension] = ACTIONS(5073),
    [anon_sym_ProfileExtension] = ACTIONS(5073),
    [anon_sym_profileExtension] = ACTIONS(5073),
    [anon_sym_permissionset] = ACTIONS(5075),
    [anon_sym_PERMISSIONSET] = ACTIONS(5075),
    [anon_sym_Permissionset] = ACTIONS(5075),
    [anon_sym_PermissionSet] = ACTIONS(5075),
    [anon_sym_permissionSet] = ACTIONS(5075),
    [anon_sym_permissionsetextension] = ACTIONS(5073),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5073),
    [anon_sym_Permissionsetextension] = ACTIONS(5073),
    [anon_sym_PermissionSetExtension] = ACTIONS(5073),
    [anon_sym_permissionSetExtension] = ACTIONS(5073),
    [sym_entitlement_keyword] = ACTIONS(5073),
    [anon_sym_pagecustomization] = ACTIONS(5073),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5073),
    [anon_sym_Pagecustomization] = ACTIONS(5073),
    [anon_sym_PageCustomization] = ACTIONS(5073),
    [anon_sym_pageCustomization] = ACTIONS(5073),
    [sym_using_keyword] = ACTIONS(5073),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5073),
    [sym_preproc_close] = ACTIONS(5073),
  },
  [STATE(1974)] = {
    [anon_sym_POUNDif] = ACTIONS(5077),
    [anon_sym_POUNDIF] = ACTIONS(5077),
    [anon_sym_POUNDIf] = ACTIONS(5077),
    [anon_sym_POUNDelif] = ACTIONS(5077),
    [anon_sym_POUNDELIF] = ACTIONS(5077),
    [anon_sym_POUNDElif] = ACTIONS(5077),
    [anon_sym_POUNDelse] = ACTIONS(5077),
    [anon_sym_POUNDELSE] = ACTIONS(5077),
    [anon_sym_POUNDElse] = ACTIONS(5077),
    [anon_sym_POUNDendif] = ACTIONS(5077),
    [anon_sym_POUNDENDIF] = ACTIONS(5077),
    [anon_sym_POUNDEndif] = ACTIONS(5077),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5079),
    [anon_sym_tableextension] = ACTIONS(5077),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5077),
    [anon_sym_Tableextension] = ACTIONS(5077),
    [anon_sym_TableExtension] = ACTIONS(5077),
    [anon_sym_tableExtension] = ACTIONS(5077),
    [sym_page_keyword] = ACTIONS(5079),
    [anon_sym_pageextension] = ACTIONS(5077),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5077),
    [anon_sym_Pageextension] = ACTIONS(5077),
    [anon_sym_PageExtension] = ACTIONS(5077),
    [anon_sym_pageExtension] = ACTIONS(5077),
    [anon_sym_codeunit] = ACTIONS(5077),
    [anon_sym_CODEUNIT] = ACTIONS(5077),
    [anon_sym_Codeunit] = ACTIONS(5077),
    [anon_sym_CodeUnit] = ACTIONS(5077),
    [anon_sym_COdeunit] = ACTIONS(5077),
    [anon_sym_codeUnit] = ACTIONS(5077),
    [sym_report_keyword] = ACTIONS(5079),
    [anon_sym_reportextension] = ACTIONS(5077),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5077),
    [anon_sym_Reportextension] = ACTIONS(5077),
    [anon_sym_ReportExtension] = ACTIONS(5077),
    [anon_sym_reportExtension] = ACTIONS(5077),
    [sym_query_keyword] = ACTIONS(5077),
    [anon_sym_xmlport] = ACTIONS(5077),
    [anon_sym_XMLPORT] = ACTIONS(5077),
    [anon_sym_Xmlport] = ACTIONS(5077),
    [anon_sym_XMLport] = ACTIONS(5077),
    [anon_sym_XMLPort] = ACTIONS(5077),
    [anon_sym_XmlPort] = ACTIONS(5077),
    [anon_sym_enum] = ACTIONS(5079),
    [anon_sym_ENUM] = ACTIONS(5079),
    [anon_sym_Enum] = ACTIONS(5079),
    [anon_sym_eNUM] = ACTIONS(5077),
    [anon_sym_eNum] = ACTIONS(5077),
    [anon_sym_ENum] = ACTIONS(5077),
    [anon_sym_enumextension] = ACTIONS(5077),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5077),
    [anon_sym_Enumextension] = ACTIONS(5077),
    [anon_sym_EnumExtension] = ACTIONS(5077),
    [anon_sym_enumExtension] = ACTIONS(5077),
    [sym_interface_keyword] = ACTIONS(5077),
    [anon_sym_controladdin] = ACTIONS(5077),
    [anon_sym_CONTROLADDIN] = ACTIONS(5077),
    [anon_sym_Controladdin] = ACTIONS(5077),
    [anon_sym_ControlAddIn] = ACTIONS(5077),
    [anon_sym_ControlAddin] = ACTIONS(5077),
    [anon_sym_controlAddIn] = ACTIONS(5077),
    [anon_sym_controlAddin] = ACTIONS(5077),
    [anon_sym_dotnet] = ACTIONS(5077),
    [anon_sym_DOTNET] = ACTIONS(5077),
    [anon_sym_Dotnet] = ACTIONS(5077),
    [anon_sym_DotNet] = ACTIONS(5077),
    [anon_sym_dotNet] = ACTIONS(5077),
    [sym_profile_keyword] = ACTIONS(5079),
    [anon_sym_profileextension] = ACTIONS(5077),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5077),
    [anon_sym_Profileextension] = ACTIONS(5077),
    [anon_sym_ProfileExtension] = ACTIONS(5077),
    [anon_sym_profileExtension] = ACTIONS(5077),
    [anon_sym_permissionset] = ACTIONS(5079),
    [anon_sym_PERMISSIONSET] = ACTIONS(5079),
    [anon_sym_Permissionset] = ACTIONS(5079),
    [anon_sym_PermissionSet] = ACTIONS(5079),
    [anon_sym_permissionSet] = ACTIONS(5079),
    [anon_sym_permissionsetextension] = ACTIONS(5077),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5077),
    [anon_sym_Permissionsetextension] = ACTIONS(5077),
    [anon_sym_PermissionSetExtension] = ACTIONS(5077),
    [anon_sym_permissionSetExtension] = ACTIONS(5077),
    [sym_entitlement_keyword] = ACTIONS(5077),
    [anon_sym_pagecustomization] = ACTIONS(5077),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5077),
    [anon_sym_Pagecustomization] = ACTIONS(5077),
    [anon_sym_PageCustomization] = ACTIONS(5077),
    [anon_sym_pageCustomization] = ACTIONS(5077),
    [sym_using_keyword] = ACTIONS(5077),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5077),
    [sym_preproc_close] = ACTIONS(5077),
  },
  [STATE(1975)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_DASH] = ACTIONS(4951),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(4959),
    [aux_sym__expression_token2] = ACTIONS(4961),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(4963),
    [anon_sym_div] = ACTIONS(4965),
    [anon_sym_DIV] = ACTIONS(4967),
    [anon_sym_Div] = ACTIONS(4969),
    [anon_sym_mod] = ACTIONS(4971),
    [anon_sym_MOD] = ACTIONS(4973),
    [anon_sym_Mod] = ACTIONS(4975),
    [anon_sym_PLUS] = ACTIONS(4977),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(4979),
    [anon_sym_AND] = ACTIONS(4981),
    [anon_sym_And] = ACTIONS(4983),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(1976)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_DASH] = ACTIONS(4951),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(4959),
    [aux_sym__expression_token2] = ACTIONS(4961),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(4963),
    [anon_sym_div] = ACTIONS(4965),
    [anon_sym_DIV] = ACTIONS(4967),
    [anon_sym_Div] = ACTIONS(4969),
    [anon_sym_mod] = ACTIONS(4971),
    [anon_sym_MOD] = ACTIONS(4973),
    [anon_sym_Mod] = ACTIONS(4975),
    [anon_sym_PLUS] = ACTIONS(4977),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(4979),
    [anon_sym_AND] = ACTIONS(4981),
    [anon_sym_And] = ACTIONS(4983),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(1977)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_DASH] = ACTIONS(4951),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(4959),
    [aux_sym__expression_token2] = ACTIONS(4961),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(4963),
    [anon_sym_div] = ACTIONS(4965),
    [anon_sym_DIV] = ACTIONS(4967),
    [anon_sym_Div] = ACTIONS(4969),
    [anon_sym_mod] = ACTIONS(4971),
    [anon_sym_MOD] = ACTIONS(4973),
    [anon_sym_Mod] = ACTIONS(4975),
    [anon_sym_PLUS] = ACTIONS(4977),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(4979),
    [anon_sym_AND] = ACTIONS(4981),
    [anon_sym_And] = ACTIONS(4983),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(1978)] = {
    [anon_sym_POUNDif] = ACTIONS(5081),
    [anon_sym_POUNDIF] = ACTIONS(5081),
    [anon_sym_POUNDIf] = ACTIONS(5081),
    [anon_sym_POUNDelif] = ACTIONS(5081),
    [anon_sym_POUNDELIF] = ACTIONS(5081),
    [anon_sym_POUNDElif] = ACTIONS(5081),
    [anon_sym_POUNDelse] = ACTIONS(5081),
    [anon_sym_POUNDELSE] = ACTIONS(5081),
    [anon_sym_POUNDElse] = ACTIONS(5081),
    [anon_sym_POUNDendif] = ACTIONS(5081),
    [anon_sym_POUNDENDIF] = ACTIONS(5081),
    [anon_sym_POUNDEndif] = ACTIONS(5081),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5083),
    [anon_sym_tableextension] = ACTIONS(5081),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5081),
    [anon_sym_Tableextension] = ACTIONS(5081),
    [anon_sym_TableExtension] = ACTIONS(5081),
    [anon_sym_tableExtension] = ACTIONS(5081),
    [sym_page_keyword] = ACTIONS(5083),
    [anon_sym_pageextension] = ACTIONS(5081),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5081),
    [anon_sym_Pageextension] = ACTIONS(5081),
    [anon_sym_PageExtension] = ACTIONS(5081),
    [anon_sym_pageExtension] = ACTIONS(5081),
    [anon_sym_codeunit] = ACTIONS(5081),
    [anon_sym_CODEUNIT] = ACTIONS(5081),
    [anon_sym_Codeunit] = ACTIONS(5081),
    [anon_sym_CodeUnit] = ACTIONS(5081),
    [anon_sym_COdeunit] = ACTIONS(5081),
    [anon_sym_codeUnit] = ACTIONS(5081),
    [sym_report_keyword] = ACTIONS(5083),
    [anon_sym_reportextension] = ACTIONS(5081),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5081),
    [anon_sym_Reportextension] = ACTIONS(5081),
    [anon_sym_ReportExtension] = ACTIONS(5081),
    [anon_sym_reportExtension] = ACTIONS(5081),
    [sym_query_keyword] = ACTIONS(5081),
    [anon_sym_xmlport] = ACTIONS(5081),
    [anon_sym_XMLPORT] = ACTIONS(5081),
    [anon_sym_Xmlport] = ACTIONS(5081),
    [anon_sym_XMLport] = ACTIONS(5081),
    [anon_sym_XMLPort] = ACTIONS(5081),
    [anon_sym_XmlPort] = ACTIONS(5081),
    [anon_sym_enum] = ACTIONS(5083),
    [anon_sym_ENUM] = ACTIONS(5083),
    [anon_sym_Enum] = ACTIONS(5083),
    [anon_sym_eNUM] = ACTIONS(5081),
    [anon_sym_eNum] = ACTIONS(5081),
    [anon_sym_ENum] = ACTIONS(5081),
    [anon_sym_enumextension] = ACTIONS(5081),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5081),
    [anon_sym_Enumextension] = ACTIONS(5081),
    [anon_sym_EnumExtension] = ACTIONS(5081),
    [anon_sym_enumExtension] = ACTIONS(5081),
    [sym_interface_keyword] = ACTIONS(5081),
    [anon_sym_controladdin] = ACTIONS(5081),
    [anon_sym_CONTROLADDIN] = ACTIONS(5081),
    [anon_sym_Controladdin] = ACTIONS(5081),
    [anon_sym_ControlAddIn] = ACTIONS(5081),
    [anon_sym_ControlAddin] = ACTIONS(5081),
    [anon_sym_controlAddIn] = ACTIONS(5081),
    [anon_sym_controlAddin] = ACTIONS(5081),
    [anon_sym_dotnet] = ACTIONS(5081),
    [anon_sym_DOTNET] = ACTIONS(5081),
    [anon_sym_Dotnet] = ACTIONS(5081),
    [anon_sym_DotNet] = ACTIONS(5081),
    [anon_sym_dotNet] = ACTIONS(5081),
    [sym_profile_keyword] = ACTIONS(5083),
    [anon_sym_profileextension] = ACTIONS(5081),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5081),
    [anon_sym_Profileextension] = ACTIONS(5081),
    [anon_sym_ProfileExtension] = ACTIONS(5081),
    [anon_sym_profileExtension] = ACTIONS(5081),
    [anon_sym_permissionset] = ACTIONS(5083),
    [anon_sym_PERMISSIONSET] = ACTIONS(5083),
    [anon_sym_Permissionset] = ACTIONS(5083),
    [anon_sym_PermissionSet] = ACTIONS(5083),
    [anon_sym_permissionSet] = ACTIONS(5083),
    [anon_sym_permissionsetextension] = ACTIONS(5081),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5081),
    [anon_sym_Permissionsetextension] = ACTIONS(5081),
    [anon_sym_PermissionSetExtension] = ACTIONS(5081),
    [anon_sym_permissionSetExtension] = ACTIONS(5081),
    [sym_entitlement_keyword] = ACTIONS(5081),
    [anon_sym_pagecustomization] = ACTIONS(5081),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5081),
    [anon_sym_Pagecustomization] = ACTIONS(5081),
    [anon_sym_PageCustomization] = ACTIONS(5081),
    [anon_sym_pageCustomization] = ACTIONS(5081),
    [sym_using_keyword] = ACTIONS(5081),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5081),
    [sym_preproc_close] = ACTIONS(5081),
  },
  [STATE(1979)] = {
    [anon_sym_POUNDif] = ACTIONS(5085),
    [anon_sym_POUNDIF] = ACTIONS(5085),
    [anon_sym_POUNDIf] = ACTIONS(5085),
    [anon_sym_POUNDelif] = ACTIONS(5085),
    [anon_sym_POUNDELIF] = ACTIONS(5085),
    [anon_sym_POUNDElif] = ACTIONS(5085),
    [anon_sym_POUNDelse] = ACTIONS(5085),
    [anon_sym_POUNDELSE] = ACTIONS(5085),
    [anon_sym_POUNDElse] = ACTIONS(5085),
    [anon_sym_POUNDendif] = ACTIONS(5085),
    [anon_sym_POUNDENDIF] = ACTIONS(5085),
    [anon_sym_POUNDEndif] = ACTIONS(5085),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5087),
    [anon_sym_tableextension] = ACTIONS(5085),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5085),
    [anon_sym_Tableextension] = ACTIONS(5085),
    [anon_sym_TableExtension] = ACTIONS(5085),
    [anon_sym_tableExtension] = ACTIONS(5085),
    [sym_page_keyword] = ACTIONS(5087),
    [anon_sym_pageextension] = ACTIONS(5085),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5085),
    [anon_sym_Pageextension] = ACTIONS(5085),
    [anon_sym_PageExtension] = ACTIONS(5085),
    [anon_sym_pageExtension] = ACTIONS(5085),
    [anon_sym_codeunit] = ACTIONS(5085),
    [anon_sym_CODEUNIT] = ACTIONS(5085),
    [anon_sym_Codeunit] = ACTIONS(5085),
    [anon_sym_CodeUnit] = ACTIONS(5085),
    [anon_sym_COdeunit] = ACTIONS(5085),
    [anon_sym_codeUnit] = ACTIONS(5085),
    [sym_report_keyword] = ACTIONS(5087),
    [anon_sym_reportextension] = ACTIONS(5085),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5085),
    [anon_sym_Reportextension] = ACTIONS(5085),
    [anon_sym_ReportExtension] = ACTIONS(5085),
    [anon_sym_reportExtension] = ACTIONS(5085),
    [sym_query_keyword] = ACTIONS(5085),
    [anon_sym_xmlport] = ACTIONS(5085),
    [anon_sym_XMLPORT] = ACTIONS(5085),
    [anon_sym_Xmlport] = ACTIONS(5085),
    [anon_sym_XMLport] = ACTIONS(5085),
    [anon_sym_XMLPort] = ACTIONS(5085),
    [anon_sym_XmlPort] = ACTIONS(5085),
    [anon_sym_enum] = ACTIONS(5087),
    [anon_sym_ENUM] = ACTIONS(5087),
    [anon_sym_Enum] = ACTIONS(5087),
    [anon_sym_eNUM] = ACTIONS(5085),
    [anon_sym_eNum] = ACTIONS(5085),
    [anon_sym_ENum] = ACTIONS(5085),
    [anon_sym_enumextension] = ACTIONS(5085),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5085),
    [anon_sym_Enumextension] = ACTIONS(5085),
    [anon_sym_EnumExtension] = ACTIONS(5085),
    [anon_sym_enumExtension] = ACTIONS(5085),
    [sym_interface_keyword] = ACTIONS(5085),
    [anon_sym_controladdin] = ACTIONS(5085),
    [anon_sym_CONTROLADDIN] = ACTIONS(5085),
    [anon_sym_Controladdin] = ACTIONS(5085),
    [anon_sym_ControlAddIn] = ACTIONS(5085),
    [anon_sym_ControlAddin] = ACTIONS(5085),
    [anon_sym_controlAddIn] = ACTIONS(5085),
    [anon_sym_controlAddin] = ACTIONS(5085),
    [anon_sym_dotnet] = ACTIONS(5085),
    [anon_sym_DOTNET] = ACTIONS(5085),
    [anon_sym_Dotnet] = ACTIONS(5085),
    [anon_sym_DotNet] = ACTIONS(5085),
    [anon_sym_dotNet] = ACTIONS(5085),
    [sym_profile_keyword] = ACTIONS(5087),
    [anon_sym_profileextension] = ACTIONS(5085),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5085),
    [anon_sym_Profileextension] = ACTIONS(5085),
    [anon_sym_ProfileExtension] = ACTIONS(5085),
    [anon_sym_profileExtension] = ACTIONS(5085),
    [anon_sym_permissionset] = ACTIONS(5087),
    [anon_sym_PERMISSIONSET] = ACTIONS(5087),
    [anon_sym_Permissionset] = ACTIONS(5087),
    [anon_sym_PermissionSet] = ACTIONS(5087),
    [anon_sym_permissionSet] = ACTIONS(5087),
    [anon_sym_permissionsetextension] = ACTIONS(5085),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5085),
    [anon_sym_Permissionsetextension] = ACTIONS(5085),
    [anon_sym_PermissionSetExtension] = ACTIONS(5085),
    [anon_sym_permissionSetExtension] = ACTIONS(5085),
    [sym_entitlement_keyword] = ACTIONS(5085),
    [anon_sym_pagecustomization] = ACTIONS(5085),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5085),
    [anon_sym_Pagecustomization] = ACTIONS(5085),
    [anon_sym_PageCustomization] = ACTIONS(5085),
    [anon_sym_pageCustomization] = ACTIONS(5085),
    [sym_using_keyword] = ACTIONS(5085),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5085),
    [sym_preproc_close] = ACTIONS(5085),
  },
  [STATE(1980)] = {
    [anon_sym_POUNDif] = ACTIONS(5089),
    [anon_sym_POUNDIF] = ACTIONS(5089),
    [anon_sym_POUNDIf] = ACTIONS(5089),
    [anon_sym_POUNDelif] = ACTIONS(5089),
    [anon_sym_POUNDELIF] = ACTIONS(5089),
    [anon_sym_POUNDElif] = ACTIONS(5089),
    [anon_sym_POUNDelse] = ACTIONS(5089),
    [anon_sym_POUNDELSE] = ACTIONS(5089),
    [anon_sym_POUNDElse] = ACTIONS(5089),
    [anon_sym_POUNDendif] = ACTIONS(5089),
    [anon_sym_POUNDENDIF] = ACTIONS(5089),
    [anon_sym_POUNDEndif] = ACTIONS(5089),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5091),
    [anon_sym_tableextension] = ACTIONS(5089),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5089),
    [anon_sym_Tableextension] = ACTIONS(5089),
    [anon_sym_TableExtension] = ACTIONS(5089),
    [anon_sym_tableExtension] = ACTIONS(5089),
    [sym_page_keyword] = ACTIONS(5091),
    [anon_sym_pageextension] = ACTIONS(5089),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5089),
    [anon_sym_Pageextension] = ACTIONS(5089),
    [anon_sym_PageExtension] = ACTIONS(5089),
    [anon_sym_pageExtension] = ACTIONS(5089),
    [anon_sym_codeunit] = ACTIONS(5089),
    [anon_sym_CODEUNIT] = ACTIONS(5089),
    [anon_sym_Codeunit] = ACTIONS(5089),
    [anon_sym_CodeUnit] = ACTIONS(5089),
    [anon_sym_COdeunit] = ACTIONS(5089),
    [anon_sym_codeUnit] = ACTIONS(5089),
    [sym_report_keyword] = ACTIONS(5091),
    [anon_sym_reportextension] = ACTIONS(5089),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5089),
    [anon_sym_Reportextension] = ACTIONS(5089),
    [anon_sym_ReportExtension] = ACTIONS(5089),
    [anon_sym_reportExtension] = ACTIONS(5089),
    [sym_query_keyword] = ACTIONS(5089),
    [anon_sym_xmlport] = ACTIONS(5089),
    [anon_sym_XMLPORT] = ACTIONS(5089),
    [anon_sym_Xmlport] = ACTIONS(5089),
    [anon_sym_XMLport] = ACTIONS(5089),
    [anon_sym_XMLPort] = ACTIONS(5089),
    [anon_sym_XmlPort] = ACTIONS(5089),
    [anon_sym_enum] = ACTIONS(5091),
    [anon_sym_ENUM] = ACTIONS(5091),
    [anon_sym_Enum] = ACTIONS(5091),
    [anon_sym_eNUM] = ACTIONS(5089),
    [anon_sym_eNum] = ACTIONS(5089),
    [anon_sym_ENum] = ACTIONS(5089),
    [anon_sym_enumextension] = ACTIONS(5089),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5089),
    [anon_sym_Enumextension] = ACTIONS(5089),
    [anon_sym_EnumExtension] = ACTIONS(5089),
    [anon_sym_enumExtension] = ACTIONS(5089),
    [sym_interface_keyword] = ACTIONS(5089),
    [anon_sym_controladdin] = ACTIONS(5089),
    [anon_sym_CONTROLADDIN] = ACTIONS(5089),
    [anon_sym_Controladdin] = ACTIONS(5089),
    [anon_sym_ControlAddIn] = ACTIONS(5089),
    [anon_sym_ControlAddin] = ACTIONS(5089),
    [anon_sym_controlAddIn] = ACTIONS(5089),
    [anon_sym_controlAddin] = ACTIONS(5089),
    [anon_sym_dotnet] = ACTIONS(5089),
    [anon_sym_DOTNET] = ACTIONS(5089),
    [anon_sym_Dotnet] = ACTIONS(5089),
    [anon_sym_DotNet] = ACTIONS(5089),
    [anon_sym_dotNet] = ACTIONS(5089),
    [sym_profile_keyword] = ACTIONS(5091),
    [anon_sym_profileextension] = ACTIONS(5089),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5089),
    [anon_sym_Profileextension] = ACTIONS(5089),
    [anon_sym_ProfileExtension] = ACTIONS(5089),
    [anon_sym_profileExtension] = ACTIONS(5089),
    [anon_sym_permissionset] = ACTIONS(5091),
    [anon_sym_PERMISSIONSET] = ACTIONS(5091),
    [anon_sym_Permissionset] = ACTIONS(5091),
    [anon_sym_PermissionSet] = ACTIONS(5091),
    [anon_sym_permissionSet] = ACTIONS(5091),
    [anon_sym_permissionsetextension] = ACTIONS(5089),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5089),
    [anon_sym_Permissionsetextension] = ACTIONS(5089),
    [anon_sym_PermissionSetExtension] = ACTIONS(5089),
    [anon_sym_permissionSetExtension] = ACTIONS(5089),
    [sym_entitlement_keyword] = ACTIONS(5089),
    [anon_sym_pagecustomization] = ACTIONS(5089),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5089),
    [anon_sym_Pagecustomization] = ACTIONS(5089),
    [anon_sym_PageCustomization] = ACTIONS(5089),
    [anon_sym_pageCustomization] = ACTIONS(5089),
    [sym_using_keyword] = ACTIONS(5089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5089),
    [sym_preproc_close] = ACTIONS(5089),
  },
  [STATE(1981)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2364),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2366),
    [anon_sym_COMMA] = ACTIONS(2366),
    [anon_sym_DASH] = ACTIONS(4951),
    [aux_sym_boolean_token1] = ACTIONS(2364),
    [aux_sym_boolean_token2] = ACTIONS(2364),
    [sym_decimal] = ACTIONS(2364),
    [anon_sym_LPAREN] = ACTIONS(2366),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2364),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2364),
    [aux_sym_basic_type_token21] = ACTIONS(2364),
    [aux_sym_basic_type_token22] = ACTIONS(2364),
    [aux_sym_basic_type_token48] = ACTIONS(2364),
    [anon_sym_not] = ACTIONS(2364),
    [anon_sym_NOT] = ACTIONS(2364),
    [anon_sym_Not] = ACTIONS(2364),
    [anon_sym_POUNDelif] = ACTIONS(2366),
    [anon_sym_POUNDELIF] = ACTIONS(2366),
    [anon_sym_POUNDElif] = ACTIONS(2366),
    [anon_sym_POUNDelse] = ACTIONS(2366),
    [anon_sym_POUNDELSE] = ACTIONS(2366),
    [anon_sym_POUNDElse] = ACTIONS(2366),
    [anon_sym_POUNDendif] = ACTIONS(2366),
    [anon_sym_POUNDENDIF] = ACTIONS(2366),
    [anon_sym_POUNDEndif] = ACTIONS(2366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2366),
    [aux_sym__expression_token1] = ACTIONS(4959),
    [aux_sym__expression_token2] = ACTIONS(4961),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2364),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2364),
    [anon_sym_SLASH] = ACTIONS(4963),
    [anon_sym_div] = ACTIONS(4965),
    [anon_sym_DIV] = ACTIONS(4967),
    [anon_sym_Div] = ACTIONS(4969),
    [anon_sym_mod] = ACTIONS(4971),
    [anon_sym_MOD] = ACTIONS(4973),
    [anon_sym_Mod] = ACTIONS(4975),
    [anon_sym_PLUS] = ACTIONS(4977),
    [anon_sym_GT_EQ] = ACTIONS(2366),
    [anon_sym_LT_EQ] = ACTIONS(2366),
    [anon_sym_GT] = ACTIONS(2364),
    [anon_sym_LT] = ACTIONS(2364),
    [anon_sym_LT_GT] = ACTIONS(2366),
    [anon_sym_and] = ACTIONS(2364),
    [anon_sym_AND] = ACTIONS(2364),
    [anon_sym_And] = ACTIONS(2364),
    [anon_sym_or] = ACTIONS(2364),
    [anon_sym_OR] = ACTIONS(2364),
    [anon_sym_Or] = ACTIONS(2364),
    [anon_sym_xor] = ACTIONS(2364),
    [anon_sym_XOR] = ACTIONS(2364),
    [anon_sym_Xor] = ACTIONS(2364),
    [anon_sym_QMARK] = ACTIONS(2366),
    [sym_datetime_literal] = ACTIONS(2366),
    [sym_date_literal] = ACTIONS(2364),
    [sym_time_literal] = ACTIONS(2364),
    [sym_biginteger_literal] = ACTIONS(2366),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2364),
    [anon_sym_codeunit] = ACTIONS(2364),
    [anon_sym_CODEUNIT] = ACTIONS(2364),
    [anon_sym_Codeunit] = ACTIONS(2364),
    [anon_sym_CodeUnit] = ACTIONS(2364),
    [anon_sym_COdeunit] = ACTIONS(2364),
    [anon_sym_codeUnit] = ACTIONS(2364),
    [sym_report_keyword] = ACTIONS(2364),
    [sym_query_keyword] = ACTIONS(2364),
    [anon_sym_xmlport] = ACTIONS(2364),
    [anon_sym_XMLPORT] = ACTIONS(2364),
    [anon_sym_Xmlport] = ACTIONS(2364),
    [anon_sym_XMLport] = ACTIONS(2364),
    [anon_sym_XMLPort] = ACTIONS(2364),
    [anon_sym_XmlPort] = ACTIONS(2364),
    [anon_sym_enum] = ACTIONS(2364),
    [anon_sym_ENUM] = ACTIONS(2364),
    [anon_sym_Enum] = ACTIONS(2364),
    [anon_sym_eNUM] = ACTIONS(2364),
    [anon_sym_eNum] = ACTIONS(2364),
    [anon_sym_ENum] = ACTIONS(2364),
    [sym_quoted_identifier] = ACTIONS(2366),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2366),
    [sym_integer] = ACTIONS(2364),
    [sym_continue_as_identifier] = ACTIONS(2366),
    [sym_preproc_close] = ACTIONS(2366),
  },
  [STATE(1982)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1987),
    [sym_identifier] = ACTIONS(2346),
    [anon_sym_SEMI] = ACTIONS(2348),
    [anon_sym_DOT] = ACTIONS(5093),
    [anon_sym_EQ] = ACTIONS(2348),
    [anon_sym_COMMA] = ACTIONS(2348),
    [anon_sym_COLON] = ACTIONS(2346),
    [anon_sym_DASH] = ACTIONS(2346),
    [aux_sym_boolean_token1] = ACTIONS(2346),
    [aux_sym_boolean_token2] = ACTIONS(2346),
    [sym_decimal] = ACTIONS(2346),
    [anon_sym_LPAREN] = ACTIONS(2348),
    [anon_sym_DOT_DOT] = ACTIONS(2348),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2346),
    [anon_sym_STAR] = ACTIONS(2346),
    [anon_sym_LBRACK] = ACTIONS(2348),
    [aux_sym_record_type_token1] = ACTIONS(2346),
    [aux_sym_basic_type_token21] = ACTIONS(2346),
    [aux_sym_basic_type_token22] = ACTIONS(2346),
    [aux_sym_basic_type_token48] = ACTIONS(2346),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2346),
    [anon_sym_POUNDif] = ACTIONS(2348),
    [anon_sym_POUNDIF] = ACTIONS(2348),
    [anon_sym_POUNDIf] = ACTIONS(2348),
    [anon_sym_not] = ACTIONS(2346),
    [anon_sym_NOT] = ACTIONS(2346),
    [anon_sym_Not] = ACTIONS(2346),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2348),
    [aux_sym__expression_token1] = ACTIONS(2348),
    [aux_sym__expression_token2] = ACTIONS(2348),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2346),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2346),
    [anon_sym_SLASH] = ACTIONS(2346),
    [anon_sym_div] = ACTIONS(2346),
    [anon_sym_DIV] = ACTIONS(2346),
    [anon_sym_Div] = ACTIONS(2346),
    [anon_sym_mod] = ACTIONS(2346),
    [anon_sym_MOD] = ACTIONS(2346),
    [anon_sym_Mod] = ACTIONS(2346),
    [anon_sym_PLUS] = ACTIONS(2346),
    [anon_sym_GT_EQ] = ACTIONS(2348),
    [anon_sym_LT_EQ] = ACTIONS(2348),
    [anon_sym_GT] = ACTIONS(2346),
    [anon_sym_LT] = ACTIONS(2346),
    [anon_sym_LT_GT] = ACTIONS(2348),
    [anon_sym_and] = ACTIONS(2346),
    [anon_sym_AND] = ACTIONS(2346),
    [anon_sym_And] = ACTIONS(2346),
    [anon_sym_or] = ACTIONS(2346),
    [anon_sym_OR] = ACTIONS(2346),
    [anon_sym_Or] = ACTIONS(2346),
    [anon_sym_xor] = ACTIONS(2346),
    [anon_sym_XOR] = ACTIONS(2346),
    [anon_sym_Xor] = ACTIONS(2346),
    [anon_sym_QMARK] = ACTIONS(2348),
    [sym_datetime_literal] = ACTIONS(2348),
    [sym_date_literal] = ACTIONS(2346),
    [sym_time_literal] = ACTIONS(2346),
    [sym_biginteger_literal] = ACTIONS(2348),
    [anon_sym_else] = ACTIONS(2346),
    [anon_sym_ELSE] = ACTIONS(2346),
    [anon_sym_Else] = ACTIONS(2346),
    [anon_sym_in] = ACTIONS(2346),
    [anon_sym_IN] = ACTIONS(2346),
    [anon_sym_In] = ACTIONS(2346),
    [sym_page_keyword] = ACTIONS(2346),
    [anon_sym_codeunit] = ACTIONS(2346),
    [anon_sym_CODEUNIT] = ACTIONS(2346),
    [anon_sym_Codeunit] = ACTIONS(2346),
    [anon_sym_CodeUnit] = ACTIONS(2346),
    [anon_sym_COdeunit] = ACTIONS(2346),
    [anon_sym_codeUnit] = ACTIONS(2346),
    [sym_report_keyword] = ACTIONS(2346),
    [sym_query_keyword] = ACTIONS(2346),
    [anon_sym_xmlport] = ACTIONS(2346),
    [anon_sym_XMLPORT] = ACTIONS(2346),
    [anon_sym_Xmlport] = ACTIONS(2346),
    [anon_sym_XMLport] = ACTIONS(2346),
    [anon_sym_XMLPort] = ACTIONS(2346),
    [anon_sym_XmlPort] = ACTIONS(2346),
    [anon_sym_enum] = ACTIONS(2346),
    [anon_sym_ENUM] = ACTIONS(2346),
    [anon_sym_Enum] = ACTIONS(2346),
    [anon_sym_eNUM] = ACTIONS(2346),
    [anon_sym_eNum] = ACTIONS(2346),
    [anon_sym_ENum] = ACTIONS(2346),
    [sym_temporary_keyword] = ACTIONS(2346),
    [sym_quoted_identifier] = ACTIONS(2348),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2348),
    [sym_integer] = ACTIONS(2346),
    [sym_continue_as_identifier] = ACTIONS(2348),
    [sym_preproc_open] = ACTIONS(2348),
  },
  [STATE(1983)] = {
    [sym_identifier] = ACTIONS(2266),
    [anon_sym_SEMI] = ACTIONS(2268),
    [anon_sym_DOT] = ACTIONS(2266),
    [anon_sym_EQ] = ACTIONS(2268),
    [anon_sym_COMMA] = ACTIONS(2268),
    [anon_sym_COLON] = ACTIONS(2266),
    [anon_sym_DASH] = ACTIONS(2266),
    [aux_sym_boolean_token1] = ACTIONS(2266),
    [aux_sym_boolean_token2] = ACTIONS(2266),
    [sym_decimal] = ACTIONS(2266),
    [anon_sym_LPAREN] = ACTIONS(2268),
    [anon_sym_DOT_DOT] = ACTIONS(2268),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2266),
    [anon_sym_STAR] = ACTIONS(2266),
    [anon_sym_LBRACK] = ACTIONS(2268),
    [aux_sym_record_type_token1] = ACTIONS(2266),
    [aux_sym_basic_type_token21] = ACTIONS(2266),
    [aux_sym_basic_type_token22] = ACTIONS(2266),
    [aux_sym_basic_type_token48] = ACTIONS(2266),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2266),
    [anon_sym_COLON_COLON] = ACTIONS(2268),
    [anon_sym_POUNDif] = ACTIONS(2268),
    [anon_sym_POUNDIF] = ACTIONS(2268),
    [anon_sym_POUNDIf] = ACTIONS(2268),
    [anon_sym_not] = ACTIONS(2266),
    [anon_sym_NOT] = ACTIONS(2266),
    [anon_sym_Not] = ACTIONS(2266),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2268),
    [aux_sym__expression_token1] = ACTIONS(2268),
    [aux_sym__expression_token2] = ACTIONS(2268),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2266),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2266),
    [anon_sym_SLASH] = ACTIONS(2266),
    [anon_sym_div] = ACTIONS(2266),
    [anon_sym_DIV] = ACTIONS(2266),
    [anon_sym_Div] = ACTIONS(2266),
    [anon_sym_mod] = ACTIONS(2266),
    [anon_sym_MOD] = ACTIONS(2266),
    [anon_sym_Mod] = ACTIONS(2266),
    [anon_sym_PLUS] = ACTIONS(2266),
    [anon_sym_GT_EQ] = ACTIONS(2268),
    [anon_sym_LT_EQ] = ACTIONS(2268),
    [anon_sym_GT] = ACTIONS(2266),
    [anon_sym_LT] = ACTIONS(2266),
    [anon_sym_LT_GT] = ACTIONS(2268),
    [anon_sym_and] = ACTIONS(2266),
    [anon_sym_AND] = ACTIONS(2266),
    [anon_sym_And] = ACTIONS(2266),
    [anon_sym_or] = ACTIONS(2266),
    [anon_sym_OR] = ACTIONS(2266),
    [anon_sym_Or] = ACTIONS(2266),
    [anon_sym_xor] = ACTIONS(2266),
    [anon_sym_XOR] = ACTIONS(2266),
    [anon_sym_Xor] = ACTIONS(2266),
    [anon_sym_QMARK] = ACTIONS(2268),
    [sym_datetime_literal] = ACTIONS(2268),
    [sym_date_literal] = ACTIONS(2266),
    [sym_time_literal] = ACTIONS(2266),
    [sym_biginteger_literal] = ACTIONS(2268),
    [anon_sym_else] = ACTIONS(2266),
    [anon_sym_ELSE] = ACTIONS(2266),
    [anon_sym_Else] = ACTIONS(2266),
    [anon_sym_in] = ACTIONS(2266),
    [anon_sym_IN] = ACTIONS(2266),
    [anon_sym_In] = ACTIONS(2266),
    [sym_page_keyword] = ACTIONS(2266),
    [anon_sym_codeunit] = ACTIONS(2266),
    [anon_sym_CODEUNIT] = ACTIONS(2266),
    [anon_sym_Codeunit] = ACTIONS(2266),
    [anon_sym_CodeUnit] = ACTIONS(2266),
    [anon_sym_COdeunit] = ACTIONS(2266),
    [anon_sym_codeUnit] = ACTIONS(2266),
    [sym_report_keyword] = ACTIONS(2266),
    [sym_query_keyword] = ACTIONS(2266),
    [anon_sym_xmlport] = ACTIONS(2266),
    [anon_sym_XMLPORT] = ACTIONS(2266),
    [anon_sym_Xmlport] = ACTIONS(2266),
    [anon_sym_XMLport] = ACTIONS(2266),
    [anon_sym_XMLPort] = ACTIONS(2266),
    [anon_sym_XmlPort] = ACTIONS(2266),
    [anon_sym_enum] = ACTIONS(2266),
    [anon_sym_ENUM] = ACTIONS(2266),
    [anon_sym_Enum] = ACTIONS(2266),
    [anon_sym_eNUM] = ACTIONS(2266),
    [anon_sym_eNum] = ACTIONS(2266),
    [anon_sym_ENum] = ACTIONS(2266),
    [sym_temporary_keyword] = ACTIONS(2266),
    [sym_quoted_identifier] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2268),
    [sym_integer] = ACTIONS(2266),
    [sym_continue_as_identifier] = ACTIONS(2268),
    [sym_preproc_open] = ACTIONS(2268),
  },
  [STATE(1984)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(2014),
    [sym_identifier] = ACTIONS(2346),
    [anon_sym_DOT] = ACTIONS(5095),
    [anon_sym_EQ] = ACTIONS(2348),
    [anon_sym_COMMA] = ACTIONS(2348),
    [anon_sym_DASH] = ACTIONS(2346),
    [aux_sym_boolean_token1] = ACTIONS(2346),
    [aux_sym_boolean_token2] = ACTIONS(2346),
    [sym_decimal] = ACTIONS(2346),
    [anon_sym_LPAREN] = ACTIONS(2348),
    [anon_sym_DOT_DOT] = ACTIONS(2348),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2346),
    [anon_sym_STAR] = ACTIONS(2346),
    [anon_sym_LBRACK] = ACTIONS(2348),
    [aux_sym_record_type_token1] = ACTIONS(2346),
    [aux_sym_basic_type_token21] = ACTIONS(2346),
    [aux_sym_basic_type_token22] = ACTIONS(2346),
    [aux_sym_basic_type_token48] = ACTIONS(2346),
    [anon_sym_not] = ACTIONS(2346),
    [anon_sym_NOT] = ACTIONS(2346),
    [anon_sym_Not] = ACTIONS(2346),
    [anon_sym_POUNDelif] = ACTIONS(2348),
    [anon_sym_POUNDELIF] = ACTIONS(2348),
    [anon_sym_POUNDElif] = ACTIONS(2348),
    [anon_sym_POUNDelse] = ACTIONS(2348),
    [anon_sym_POUNDELSE] = ACTIONS(2348),
    [anon_sym_POUNDElse] = ACTIONS(2348),
    [anon_sym_POUNDendif] = ACTIONS(2348),
    [anon_sym_POUNDENDIF] = ACTIONS(2348),
    [anon_sym_POUNDEndif] = ACTIONS(2348),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2348),
    [aux_sym__expression_token1] = ACTIONS(2348),
    [aux_sym__expression_token2] = ACTIONS(2348),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2346),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2346),
    [anon_sym_SLASH] = ACTIONS(2346),
    [anon_sym_div] = ACTIONS(2346),
    [anon_sym_DIV] = ACTIONS(2346),
    [anon_sym_Div] = ACTIONS(2346),
    [anon_sym_mod] = ACTIONS(2346),
    [anon_sym_MOD] = ACTIONS(2346),
    [anon_sym_Mod] = ACTIONS(2346),
    [anon_sym_PLUS] = ACTIONS(2346),
    [anon_sym_GT_EQ] = ACTIONS(2348),
    [anon_sym_LT_EQ] = ACTIONS(2348),
    [anon_sym_GT] = ACTIONS(2346),
    [anon_sym_LT] = ACTIONS(2346),
    [anon_sym_LT_GT] = ACTIONS(2348),
    [anon_sym_and] = ACTIONS(2346),
    [anon_sym_AND] = ACTIONS(2346),
    [anon_sym_And] = ACTIONS(2346),
    [anon_sym_or] = ACTIONS(2346),
    [anon_sym_OR] = ACTIONS(2346),
    [anon_sym_Or] = ACTIONS(2346),
    [anon_sym_xor] = ACTIONS(2346),
    [anon_sym_XOR] = ACTIONS(2346),
    [anon_sym_Xor] = ACTIONS(2346),
    [anon_sym_QMARK] = ACTIONS(2348),
    [sym_datetime_literal] = ACTIONS(2348),
    [sym_date_literal] = ACTIONS(2346),
    [sym_time_literal] = ACTIONS(2346),
    [sym_biginteger_literal] = ACTIONS(2348),
    [anon_sym_in] = ACTIONS(2346),
    [anon_sym_IN] = ACTIONS(2346),
    [anon_sym_In] = ACTIONS(2346),
    [sym_page_keyword] = ACTIONS(2346),
    [anon_sym_codeunit] = ACTIONS(2346),
    [anon_sym_CODEUNIT] = ACTIONS(2346),
    [anon_sym_Codeunit] = ACTIONS(2346),
    [anon_sym_CodeUnit] = ACTIONS(2346),
    [anon_sym_COdeunit] = ACTIONS(2346),
    [anon_sym_codeUnit] = ACTIONS(2346),
    [sym_report_keyword] = ACTIONS(2346),
    [sym_query_keyword] = ACTIONS(2346),
    [anon_sym_xmlport] = ACTIONS(2346),
    [anon_sym_XMLPORT] = ACTIONS(2346),
    [anon_sym_Xmlport] = ACTIONS(2346),
    [anon_sym_XMLport] = ACTIONS(2346),
    [anon_sym_XMLPort] = ACTIONS(2346),
    [anon_sym_XmlPort] = ACTIONS(2346),
    [anon_sym_enum] = ACTIONS(2346),
    [anon_sym_ENUM] = ACTIONS(2346),
    [anon_sym_Enum] = ACTIONS(2346),
    [anon_sym_eNUM] = ACTIONS(2346),
    [anon_sym_eNum] = ACTIONS(2346),
    [anon_sym_ENum] = ACTIONS(2346),
    [sym_temporary_keyword] = ACTIONS(2346),
    [sym_quoted_identifier] = ACTIONS(2348),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2348),
    [sym_integer] = ACTIONS(2346),
    [sym_continue_as_identifier] = ACTIONS(2348),
    [sym_preproc_close] = ACTIONS(2348),
  },
  [STATE(1985)] = {
    [anon_sym_POUNDif] = ACTIONS(5097),
    [anon_sym_POUNDIF] = ACTIONS(5097),
    [anon_sym_POUNDIf] = ACTIONS(5097),
    [anon_sym_POUNDelif] = ACTIONS(5097),
    [anon_sym_POUNDELIF] = ACTIONS(5097),
    [anon_sym_POUNDElif] = ACTIONS(5097),
    [anon_sym_POUNDelse] = ACTIONS(5097),
    [anon_sym_POUNDELSE] = ACTIONS(5097),
    [anon_sym_POUNDElse] = ACTIONS(5097),
    [anon_sym_POUNDendif] = ACTIONS(5097),
    [anon_sym_POUNDENDIF] = ACTIONS(5097),
    [anon_sym_POUNDEndif] = ACTIONS(5097),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5099),
    [anon_sym_tableextension] = ACTIONS(5097),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5097),
    [anon_sym_Tableextension] = ACTIONS(5097),
    [anon_sym_TableExtension] = ACTIONS(5097),
    [anon_sym_tableExtension] = ACTIONS(5097),
    [sym_page_keyword] = ACTIONS(5099),
    [anon_sym_pageextension] = ACTIONS(5097),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5097),
    [anon_sym_Pageextension] = ACTIONS(5097),
    [anon_sym_PageExtension] = ACTIONS(5097),
    [anon_sym_pageExtension] = ACTIONS(5097),
    [anon_sym_codeunit] = ACTIONS(5097),
    [anon_sym_CODEUNIT] = ACTIONS(5097),
    [anon_sym_Codeunit] = ACTIONS(5097),
    [anon_sym_CodeUnit] = ACTIONS(5097),
    [anon_sym_COdeunit] = ACTIONS(5097),
    [anon_sym_codeUnit] = ACTIONS(5097),
    [sym_report_keyword] = ACTIONS(5099),
    [anon_sym_reportextension] = ACTIONS(5097),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5097),
    [anon_sym_Reportextension] = ACTIONS(5097),
    [anon_sym_ReportExtension] = ACTIONS(5097),
    [anon_sym_reportExtension] = ACTIONS(5097),
    [sym_query_keyword] = ACTIONS(5097),
    [anon_sym_xmlport] = ACTIONS(5097),
    [anon_sym_XMLPORT] = ACTIONS(5097),
    [anon_sym_Xmlport] = ACTIONS(5097),
    [anon_sym_XMLport] = ACTIONS(5097),
    [anon_sym_XMLPort] = ACTIONS(5097),
    [anon_sym_XmlPort] = ACTIONS(5097),
    [anon_sym_enum] = ACTIONS(5099),
    [anon_sym_ENUM] = ACTIONS(5099),
    [anon_sym_Enum] = ACTIONS(5099),
    [anon_sym_eNUM] = ACTIONS(5097),
    [anon_sym_eNum] = ACTIONS(5097),
    [anon_sym_ENum] = ACTIONS(5097),
    [anon_sym_enumextension] = ACTIONS(5097),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5097),
    [anon_sym_Enumextension] = ACTIONS(5097),
    [anon_sym_EnumExtension] = ACTIONS(5097),
    [anon_sym_enumExtension] = ACTIONS(5097),
    [sym_interface_keyword] = ACTIONS(5097),
    [anon_sym_controladdin] = ACTIONS(5097),
    [anon_sym_CONTROLADDIN] = ACTIONS(5097),
    [anon_sym_Controladdin] = ACTIONS(5097),
    [anon_sym_ControlAddIn] = ACTIONS(5097),
    [anon_sym_ControlAddin] = ACTIONS(5097),
    [anon_sym_controlAddIn] = ACTIONS(5097),
    [anon_sym_controlAddin] = ACTIONS(5097),
    [anon_sym_dotnet] = ACTIONS(5097),
    [anon_sym_DOTNET] = ACTIONS(5097),
    [anon_sym_Dotnet] = ACTIONS(5097),
    [anon_sym_DotNet] = ACTIONS(5097),
    [anon_sym_dotNet] = ACTIONS(5097),
    [sym_profile_keyword] = ACTIONS(5099),
    [anon_sym_profileextension] = ACTIONS(5097),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5097),
    [anon_sym_Profileextension] = ACTIONS(5097),
    [anon_sym_ProfileExtension] = ACTIONS(5097),
    [anon_sym_profileExtension] = ACTIONS(5097),
    [anon_sym_permissionset] = ACTIONS(5099),
    [anon_sym_PERMISSIONSET] = ACTIONS(5099),
    [anon_sym_Permissionset] = ACTIONS(5099),
    [anon_sym_PermissionSet] = ACTIONS(5099),
    [anon_sym_permissionSet] = ACTIONS(5099),
    [anon_sym_permissionsetextension] = ACTIONS(5097),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5097),
    [anon_sym_Permissionsetextension] = ACTIONS(5097),
    [anon_sym_PermissionSetExtension] = ACTIONS(5097),
    [anon_sym_permissionSetExtension] = ACTIONS(5097),
    [sym_entitlement_keyword] = ACTIONS(5097),
    [anon_sym_pagecustomization] = ACTIONS(5097),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5097),
    [anon_sym_Pagecustomization] = ACTIONS(5097),
    [anon_sym_PageCustomization] = ACTIONS(5097),
    [anon_sym_pageCustomization] = ACTIONS(5097),
    [sym_using_keyword] = ACTIONS(5097),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5097),
    [sym_preproc_close] = ACTIONS(5097),
  },
  [STATE(1986)] = {
    [anon_sym_POUNDif] = ACTIONS(5101),
    [anon_sym_POUNDIF] = ACTIONS(5101),
    [anon_sym_POUNDIf] = ACTIONS(5101),
    [anon_sym_POUNDelif] = ACTIONS(5101),
    [anon_sym_POUNDELIF] = ACTIONS(5101),
    [anon_sym_POUNDElif] = ACTIONS(5101),
    [anon_sym_POUNDelse] = ACTIONS(5101),
    [anon_sym_POUNDELSE] = ACTIONS(5101),
    [anon_sym_POUNDElse] = ACTIONS(5101),
    [anon_sym_POUNDendif] = ACTIONS(5101),
    [anon_sym_POUNDENDIF] = ACTIONS(5101),
    [anon_sym_POUNDEndif] = ACTIONS(5101),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5103),
    [anon_sym_tableextension] = ACTIONS(5101),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5101),
    [anon_sym_Tableextension] = ACTIONS(5101),
    [anon_sym_TableExtension] = ACTIONS(5101),
    [anon_sym_tableExtension] = ACTIONS(5101),
    [sym_page_keyword] = ACTIONS(5103),
    [anon_sym_pageextension] = ACTIONS(5101),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5101),
    [anon_sym_Pageextension] = ACTIONS(5101),
    [anon_sym_PageExtension] = ACTIONS(5101),
    [anon_sym_pageExtension] = ACTIONS(5101),
    [anon_sym_codeunit] = ACTIONS(5101),
    [anon_sym_CODEUNIT] = ACTIONS(5101),
    [anon_sym_Codeunit] = ACTIONS(5101),
    [anon_sym_CodeUnit] = ACTIONS(5101),
    [anon_sym_COdeunit] = ACTIONS(5101),
    [anon_sym_codeUnit] = ACTIONS(5101),
    [sym_report_keyword] = ACTIONS(5103),
    [anon_sym_reportextension] = ACTIONS(5101),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5101),
    [anon_sym_Reportextension] = ACTIONS(5101),
    [anon_sym_ReportExtension] = ACTIONS(5101),
    [anon_sym_reportExtension] = ACTIONS(5101),
    [sym_query_keyword] = ACTIONS(5101),
    [anon_sym_xmlport] = ACTIONS(5101),
    [anon_sym_XMLPORT] = ACTIONS(5101),
    [anon_sym_Xmlport] = ACTIONS(5101),
    [anon_sym_XMLport] = ACTIONS(5101),
    [anon_sym_XMLPort] = ACTIONS(5101),
    [anon_sym_XmlPort] = ACTIONS(5101),
    [anon_sym_enum] = ACTIONS(5103),
    [anon_sym_ENUM] = ACTIONS(5103),
    [anon_sym_Enum] = ACTIONS(5103),
    [anon_sym_eNUM] = ACTIONS(5101),
    [anon_sym_eNum] = ACTIONS(5101),
    [anon_sym_ENum] = ACTIONS(5101),
    [anon_sym_enumextension] = ACTIONS(5101),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5101),
    [anon_sym_Enumextension] = ACTIONS(5101),
    [anon_sym_EnumExtension] = ACTIONS(5101),
    [anon_sym_enumExtension] = ACTIONS(5101),
    [sym_interface_keyword] = ACTIONS(5101),
    [anon_sym_controladdin] = ACTIONS(5101),
    [anon_sym_CONTROLADDIN] = ACTIONS(5101),
    [anon_sym_Controladdin] = ACTIONS(5101),
    [anon_sym_ControlAddIn] = ACTIONS(5101),
    [anon_sym_ControlAddin] = ACTIONS(5101),
    [anon_sym_controlAddIn] = ACTIONS(5101),
    [anon_sym_controlAddin] = ACTIONS(5101),
    [anon_sym_dotnet] = ACTIONS(5101),
    [anon_sym_DOTNET] = ACTIONS(5101),
    [anon_sym_Dotnet] = ACTIONS(5101),
    [anon_sym_DotNet] = ACTIONS(5101),
    [anon_sym_dotNet] = ACTIONS(5101),
    [sym_profile_keyword] = ACTIONS(5103),
    [anon_sym_profileextension] = ACTIONS(5101),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5101),
    [anon_sym_Profileextension] = ACTIONS(5101),
    [anon_sym_ProfileExtension] = ACTIONS(5101),
    [anon_sym_profileExtension] = ACTIONS(5101),
    [anon_sym_permissionset] = ACTIONS(5103),
    [anon_sym_PERMISSIONSET] = ACTIONS(5103),
    [anon_sym_Permissionset] = ACTIONS(5103),
    [anon_sym_PermissionSet] = ACTIONS(5103),
    [anon_sym_permissionSet] = ACTIONS(5103),
    [anon_sym_permissionsetextension] = ACTIONS(5101),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5101),
    [anon_sym_Permissionsetextension] = ACTIONS(5101),
    [anon_sym_PermissionSetExtension] = ACTIONS(5101),
    [anon_sym_permissionSetExtension] = ACTIONS(5101),
    [sym_entitlement_keyword] = ACTIONS(5101),
    [anon_sym_pagecustomization] = ACTIONS(5101),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5101),
    [anon_sym_Pagecustomization] = ACTIONS(5101),
    [anon_sym_PageCustomization] = ACTIONS(5101),
    [anon_sym_pageCustomization] = ACTIONS(5101),
    [sym_using_keyword] = ACTIONS(5101),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5101),
    [sym_preproc_close] = ACTIONS(5101),
  },
  [STATE(1987)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1998),
    [sym_identifier] = ACTIONS(2442),
    [anon_sym_SEMI] = ACTIONS(2444),
    [anon_sym_DOT] = ACTIONS(5093),
    [anon_sym_EQ] = ACTIONS(2444),
    [anon_sym_COMMA] = ACTIONS(2444),
    [anon_sym_COLON] = ACTIONS(2442),
    [anon_sym_DASH] = ACTIONS(2442),
    [aux_sym_boolean_token1] = ACTIONS(2442),
    [aux_sym_boolean_token2] = ACTIONS(2442),
    [sym_decimal] = ACTIONS(2442),
    [anon_sym_LPAREN] = ACTIONS(2444),
    [anon_sym_DOT_DOT] = ACTIONS(2444),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2442),
    [anon_sym_STAR] = ACTIONS(2442),
    [anon_sym_LBRACK] = ACTIONS(2444),
    [aux_sym_record_type_token1] = ACTIONS(2442),
    [aux_sym_basic_type_token21] = ACTIONS(2442),
    [aux_sym_basic_type_token22] = ACTIONS(2442),
    [aux_sym_basic_type_token48] = ACTIONS(2442),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2442),
    [anon_sym_POUNDif] = ACTIONS(2444),
    [anon_sym_POUNDIF] = ACTIONS(2444),
    [anon_sym_POUNDIf] = ACTIONS(2444),
    [anon_sym_not] = ACTIONS(2442),
    [anon_sym_NOT] = ACTIONS(2442),
    [anon_sym_Not] = ACTIONS(2442),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2444),
    [aux_sym__expression_token1] = ACTIONS(2444),
    [aux_sym__expression_token2] = ACTIONS(2444),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2442),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2442),
    [anon_sym_SLASH] = ACTIONS(2442),
    [anon_sym_div] = ACTIONS(2442),
    [anon_sym_DIV] = ACTIONS(2442),
    [anon_sym_Div] = ACTIONS(2442),
    [anon_sym_mod] = ACTIONS(2442),
    [anon_sym_MOD] = ACTIONS(2442),
    [anon_sym_Mod] = ACTIONS(2442),
    [anon_sym_PLUS] = ACTIONS(2442),
    [anon_sym_GT_EQ] = ACTIONS(2444),
    [anon_sym_LT_EQ] = ACTIONS(2444),
    [anon_sym_GT] = ACTIONS(2442),
    [anon_sym_LT] = ACTIONS(2442),
    [anon_sym_LT_GT] = ACTIONS(2444),
    [anon_sym_and] = ACTIONS(2442),
    [anon_sym_AND] = ACTIONS(2442),
    [anon_sym_And] = ACTIONS(2442),
    [anon_sym_or] = ACTIONS(2442),
    [anon_sym_OR] = ACTIONS(2442),
    [anon_sym_Or] = ACTIONS(2442),
    [anon_sym_xor] = ACTIONS(2442),
    [anon_sym_XOR] = ACTIONS(2442),
    [anon_sym_Xor] = ACTIONS(2442),
    [anon_sym_QMARK] = ACTIONS(2444),
    [sym_datetime_literal] = ACTIONS(2444),
    [sym_date_literal] = ACTIONS(2442),
    [sym_time_literal] = ACTIONS(2442),
    [sym_biginteger_literal] = ACTIONS(2444),
    [anon_sym_else] = ACTIONS(2442),
    [anon_sym_ELSE] = ACTIONS(2442),
    [anon_sym_Else] = ACTIONS(2442),
    [anon_sym_in] = ACTIONS(2442),
    [anon_sym_IN] = ACTIONS(2442),
    [anon_sym_In] = ACTIONS(2442),
    [sym_page_keyword] = ACTIONS(2442),
    [anon_sym_codeunit] = ACTIONS(2442),
    [anon_sym_CODEUNIT] = ACTIONS(2442),
    [anon_sym_Codeunit] = ACTIONS(2442),
    [anon_sym_CodeUnit] = ACTIONS(2442),
    [anon_sym_COdeunit] = ACTIONS(2442),
    [anon_sym_codeUnit] = ACTIONS(2442),
    [sym_report_keyword] = ACTIONS(2442),
    [sym_query_keyword] = ACTIONS(2442),
    [anon_sym_xmlport] = ACTIONS(2442),
    [anon_sym_XMLPORT] = ACTIONS(2442),
    [anon_sym_Xmlport] = ACTIONS(2442),
    [anon_sym_XMLport] = ACTIONS(2442),
    [anon_sym_XMLPort] = ACTIONS(2442),
    [anon_sym_XmlPort] = ACTIONS(2442),
    [anon_sym_enum] = ACTIONS(2442),
    [anon_sym_ENUM] = ACTIONS(2442),
    [anon_sym_Enum] = ACTIONS(2442),
    [anon_sym_eNUM] = ACTIONS(2442),
    [anon_sym_eNum] = ACTIONS(2442),
    [anon_sym_ENum] = ACTIONS(2442),
    [sym_temporary_keyword] = ACTIONS(2442),
    [sym_quoted_identifier] = ACTIONS(2444),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2444),
    [sym_integer] = ACTIONS(2442),
    [sym_continue_as_identifier] = ACTIONS(2444),
    [sym_preproc_open] = ACTIONS(2444),
  },
  [STATE(1988)] = {
    [anon_sym_POUNDif] = ACTIONS(5105),
    [anon_sym_POUNDIF] = ACTIONS(5105),
    [anon_sym_POUNDIf] = ACTIONS(5105),
    [anon_sym_POUNDelif] = ACTIONS(5105),
    [anon_sym_POUNDELIF] = ACTIONS(5105),
    [anon_sym_POUNDElif] = ACTIONS(5105),
    [anon_sym_POUNDelse] = ACTIONS(5105),
    [anon_sym_POUNDELSE] = ACTIONS(5105),
    [anon_sym_POUNDElse] = ACTIONS(5105),
    [anon_sym_POUNDendif] = ACTIONS(5105),
    [anon_sym_POUNDENDIF] = ACTIONS(5105),
    [anon_sym_POUNDEndif] = ACTIONS(5105),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5107),
    [anon_sym_tableextension] = ACTIONS(5105),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5105),
    [anon_sym_Tableextension] = ACTIONS(5105),
    [anon_sym_TableExtension] = ACTIONS(5105),
    [anon_sym_tableExtension] = ACTIONS(5105),
    [sym_page_keyword] = ACTIONS(5107),
    [anon_sym_pageextension] = ACTIONS(5105),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5105),
    [anon_sym_Pageextension] = ACTIONS(5105),
    [anon_sym_PageExtension] = ACTIONS(5105),
    [anon_sym_pageExtension] = ACTIONS(5105),
    [anon_sym_codeunit] = ACTIONS(5105),
    [anon_sym_CODEUNIT] = ACTIONS(5105),
    [anon_sym_Codeunit] = ACTIONS(5105),
    [anon_sym_CodeUnit] = ACTIONS(5105),
    [anon_sym_COdeunit] = ACTIONS(5105),
    [anon_sym_codeUnit] = ACTIONS(5105),
    [sym_report_keyword] = ACTIONS(5107),
    [anon_sym_reportextension] = ACTIONS(5105),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5105),
    [anon_sym_Reportextension] = ACTIONS(5105),
    [anon_sym_ReportExtension] = ACTIONS(5105),
    [anon_sym_reportExtension] = ACTIONS(5105),
    [sym_query_keyword] = ACTIONS(5105),
    [anon_sym_xmlport] = ACTIONS(5105),
    [anon_sym_XMLPORT] = ACTIONS(5105),
    [anon_sym_Xmlport] = ACTIONS(5105),
    [anon_sym_XMLport] = ACTIONS(5105),
    [anon_sym_XMLPort] = ACTIONS(5105),
    [anon_sym_XmlPort] = ACTIONS(5105),
    [anon_sym_enum] = ACTIONS(5107),
    [anon_sym_ENUM] = ACTIONS(5107),
    [anon_sym_Enum] = ACTIONS(5107),
    [anon_sym_eNUM] = ACTIONS(5105),
    [anon_sym_eNum] = ACTIONS(5105),
    [anon_sym_ENum] = ACTIONS(5105),
    [anon_sym_enumextension] = ACTIONS(5105),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5105),
    [anon_sym_Enumextension] = ACTIONS(5105),
    [anon_sym_EnumExtension] = ACTIONS(5105),
    [anon_sym_enumExtension] = ACTIONS(5105),
    [sym_interface_keyword] = ACTIONS(5105),
    [anon_sym_controladdin] = ACTIONS(5105),
    [anon_sym_CONTROLADDIN] = ACTIONS(5105),
    [anon_sym_Controladdin] = ACTIONS(5105),
    [anon_sym_ControlAddIn] = ACTIONS(5105),
    [anon_sym_ControlAddin] = ACTIONS(5105),
    [anon_sym_controlAddIn] = ACTIONS(5105),
    [anon_sym_controlAddin] = ACTIONS(5105),
    [anon_sym_dotnet] = ACTIONS(5105),
    [anon_sym_DOTNET] = ACTIONS(5105),
    [anon_sym_Dotnet] = ACTIONS(5105),
    [anon_sym_DotNet] = ACTIONS(5105),
    [anon_sym_dotNet] = ACTIONS(5105),
    [sym_profile_keyword] = ACTIONS(5107),
    [anon_sym_profileextension] = ACTIONS(5105),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5105),
    [anon_sym_Profileextension] = ACTIONS(5105),
    [anon_sym_ProfileExtension] = ACTIONS(5105),
    [anon_sym_profileExtension] = ACTIONS(5105),
    [anon_sym_permissionset] = ACTIONS(5107),
    [anon_sym_PERMISSIONSET] = ACTIONS(5107),
    [anon_sym_Permissionset] = ACTIONS(5107),
    [anon_sym_PermissionSet] = ACTIONS(5107),
    [anon_sym_permissionSet] = ACTIONS(5107),
    [anon_sym_permissionsetextension] = ACTIONS(5105),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5105),
    [anon_sym_Permissionsetextension] = ACTIONS(5105),
    [anon_sym_PermissionSetExtension] = ACTIONS(5105),
    [anon_sym_permissionSetExtension] = ACTIONS(5105),
    [sym_entitlement_keyword] = ACTIONS(5105),
    [anon_sym_pagecustomization] = ACTIONS(5105),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5105),
    [anon_sym_Pagecustomization] = ACTIONS(5105),
    [anon_sym_PageCustomization] = ACTIONS(5105),
    [anon_sym_pageCustomization] = ACTIONS(5105),
    [sym_using_keyword] = ACTIONS(5105),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5105),
    [sym_preproc_close] = ACTIONS(5105),
  },
  [STATE(1989)] = {
    [anon_sym_POUNDif] = ACTIONS(5109),
    [anon_sym_POUNDIF] = ACTIONS(5109),
    [anon_sym_POUNDIf] = ACTIONS(5109),
    [anon_sym_POUNDelif] = ACTIONS(5109),
    [anon_sym_POUNDELIF] = ACTIONS(5109),
    [anon_sym_POUNDElif] = ACTIONS(5109),
    [anon_sym_POUNDelse] = ACTIONS(5109),
    [anon_sym_POUNDELSE] = ACTIONS(5109),
    [anon_sym_POUNDElse] = ACTIONS(5109),
    [anon_sym_POUNDendif] = ACTIONS(5109),
    [anon_sym_POUNDENDIF] = ACTIONS(5109),
    [anon_sym_POUNDEndif] = ACTIONS(5109),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5111),
    [anon_sym_tableextension] = ACTIONS(5109),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5109),
    [anon_sym_Tableextension] = ACTIONS(5109),
    [anon_sym_TableExtension] = ACTIONS(5109),
    [anon_sym_tableExtension] = ACTIONS(5109),
    [sym_page_keyword] = ACTIONS(5111),
    [anon_sym_pageextension] = ACTIONS(5109),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5109),
    [anon_sym_Pageextension] = ACTIONS(5109),
    [anon_sym_PageExtension] = ACTIONS(5109),
    [anon_sym_pageExtension] = ACTIONS(5109),
    [anon_sym_codeunit] = ACTIONS(5109),
    [anon_sym_CODEUNIT] = ACTIONS(5109),
    [anon_sym_Codeunit] = ACTIONS(5109),
    [anon_sym_CodeUnit] = ACTIONS(5109),
    [anon_sym_COdeunit] = ACTIONS(5109),
    [anon_sym_codeUnit] = ACTIONS(5109),
    [sym_report_keyword] = ACTIONS(5111),
    [anon_sym_reportextension] = ACTIONS(5109),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5109),
    [anon_sym_Reportextension] = ACTIONS(5109),
    [anon_sym_ReportExtension] = ACTIONS(5109),
    [anon_sym_reportExtension] = ACTIONS(5109),
    [sym_query_keyword] = ACTIONS(5109),
    [anon_sym_xmlport] = ACTIONS(5109),
    [anon_sym_XMLPORT] = ACTIONS(5109),
    [anon_sym_Xmlport] = ACTIONS(5109),
    [anon_sym_XMLport] = ACTIONS(5109),
    [anon_sym_XMLPort] = ACTIONS(5109),
    [anon_sym_XmlPort] = ACTIONS(5109),
    [anon_sym_enum] = ACTIONS(5111),
    [anon_sym_ENUM] = ACTIONS(5111),
    [anon_sym_Enum] = ACTIONS(5111),
    [anon_sym_eNUM] = ACTIONS(5109),
    [anon_sym_eNum] = ACTIONS(5109),
    [anon_sym_ENum] = ACTIONS(5109),
    [anon_sym_enumextension] = ACTIONS(5109),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5109),
    [anon_sym_Enumextension] = ACTIONS(5109),
    [anon_sym_EnumExtension] = ACTIONS(5109),
    [anon_sym_enumExtension] = ACTIONS(5109),
    [sym_interface_keyword] = ACTIONS(5109),
    [anon_sym_controladdin] = ACTIONS(5109),
    [anon_sym_CONTROLADDIN] = ACTIONS(5109),
    [anon_sym_Controladdin] = ACTIONS(5109),
    [anon_sym_ControlAddIn] = ACTIONS(5109),
    [anon_sym_ControlAddin] = ACTIONS(5109),
    [anon_sym_controlAddIn] = ACTIONS(5109),
    [anon_sym_controlAddin] = ACTIONS(5109),
    [anon_sym_dotnet] = ACTIONS(5109),
    [anon_sym_DOTNET] = ACTIONS(5109),
    [anon_sym_Dotnet] = ACTIONS(5109),
    [anon_sym_DotNet] = ACTIONS(5109),
    [anon_sym_dotNet] = ACTIONS(5109),
    [sym_profile_keyword] = ACTIONS(5111),
    [anon_sym_profileextension] = ACTIONS(5109),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5109),
    [anon_sym_Profileextension] = ACTIONS(5109),
    [anon_sym_ProfileExtension] = ACTIONS(5109),
    [anon_sym_profileExtension] = ACTIONS(5109),
    [anon_sym_permissionset] = ACTIONS(5111),
    [anon_sym_PERMISSIONSET] = ACTIONS(5111),
    [anon_sym_Permissionset] = ACTIONS(5111),
    [anon_sym_PermissionSet] = ACTIONS(5111),
    [anon_sym_permissionSet] = ACTIONS(5111),
    [anon_sym_permissionsetextension] = ACTIONS(5109),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5109),
    [anon_sym_Permissionsetextension] = ACTIONS(5109),
    [anon_sym_PermissionSetExtension] = ACTIONS(5109),
    [anon_sym_permissionSetExtension] = ACTIONS(5109),
    [sym_entitlement_keyword] = ACTIONS(5109),
    [anon_sym_pagecustomization] = ACTIONS(5109),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5109),
    [anon_sym_Pagecustomization] = ACTIONS(5109),
    [anon_sym_PageCustomization] = ACTIONS(5109),
    [anon_sym_pageCustomization] = ACTIONS(5109),
    [sym_using_keyword] = ACTIONS(5109),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5109),
    [sym_preproc_close] = ACTIONS(5109),
  },
  [STATE(1990)] = {
    [anon_sym_POUNDif] = ACTIONS(5113),
    [anon_sym_POUNDIF] = ACTIONS(5113),
    [anon_sym_POUNDIf] = ACTIONS(5113),
    [anon_sym_POUNDelif] = ACTIONS(5113),
    [anon_sym_POUNDELIF] = ACTIONS(5113),
    [anon_sym_POUNDElif] = ACTIONS(5113),
    [anon_sym_POUNDelse] = ACTIONS(5113),
    [anon_sym_POUNDELSE] = ACTIONS(5113),
    [anon_sym_POUNDElse] = ACTIONS(5113),
    [anon_sym_POUNDendif] = ACTIONS(5113),
    [anon_sym_POUNDENDIF] = ACTIONS(5113),
    [anon_sym_POUNDEndif] = ACTIONS(5113),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5115),
    [anon_sym_tableextension] = ACTIONS(5113),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5113),
    [anon_sym_Tableextension] = ACTIONS(5113),
    [anon_sym_TableExtension] = ACTIONS(5113),
    [anon_sym_tableExtension] = ACTIONS(5113),
    [sym_page_keyword] = ACTIONS(5115),
    [anon_sym_pageextension] = ACTIONS(5113),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5113),
    [anon_sym_Pageextension] = ACTIONS(5113),
    [anon_sym_PageExtension] = ACTIONS(5113),
    [anon_sym_pageExtension] = ACTIONS(5113),
    [anon_sym_codeunit] = ACTIONS(5113),
    [anon_sym_CODEUNIT] = ACTIONS(5113),
    [anon_sym_Codeunit] = ACTIONS(5113),
    [anon_sym_CodeUnit] = ACTIONS(5113),
    [anon_sym_COdeunit] = ACTIONS(5113),
    [anon_sym_codeUnit] = ACTIONS(5113),
    [sym_report_keyword] = ACTIONS(5115),
    [anon_sym_reportextension] = ACTIONS(5113),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5113),
    [anon_sym_Reportextension] = ACTIONS(5113),
    [anon_sym_ReportExtension] = ACTIONS(5113),
    [anon_sym_reportExtension] = ACTIONS(5113),
    [sym_query_keyword] = ACTIONS(5113),
    [anon_sym_xmlport] = ACTIONS(5113),
    [anon_sym_XMLPORT] = ACTIONS(5113),
    [anon_sym_Xmlport] = ACTIONS(5113),
    [anon_sym_XMLport] = ACTIONS(5113),
    [anon_sym_XMLPort] = ACTIONS(5113),
    [anon_sym_XmlPort] = ACTIONS(5113),
    [anon_sym_enum] = ACTIONS(5115),
    [anon_sym_ENUM] = ACTIONS(5115),
    [anon_sym_Enum] = ACTIONS(5115),
    [anon_sym_eNUM] = ACTIONS(5113),
    [anon_sym_eNum] = ACTIONS(5113),
    [anon_sym_ENum] = ACTIONS(5113),
    [anon_sym_enumextension] = ACTIONS(5113),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5113),
    [anon_sym_Enumextension] = ACTIONS(5113),
    [anon_sym_EnumExtension] = ACTIONS(5113),
    [anon_sym_enumExtension] = ACTIONS(5113),
    [sym_interface_keyword] = ACTIONS(5113),
    [anon_sym_controladdin] = ACTIONS(5113),
    [anon_sym_CONTROLADDIN] = ACTIONS(5113),
    [anon_sym_Controladdin] = ACTIONS(5113),
    [anon_sym_ControlAddIn] = ACTIONS(5113),
    [anon_sym_ControlAddin] = ACTIONS(5113),
    [anon_sym_controlAddIn] = ACTIONS(5113),
    [anon_sym_controlAddin] = ACTIONS(5113),
    [anon_sym_dotnet] = ACTIONS(5113),
    [anon_sym_DOTNET] = ACTIONS(5113),
    [anon_sym_Dotnet] = ACTIONS(5113),
    [anon_sym_DotNet] = ACTIONS(5113),
    [anon_sym_dotNet] = ACTIONS(5113),
    [sym_profile_keyword] = ACTIONS(5115),
    [anon_sym_profileextension] = ACTIONS(5113),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5113),
    [anon_sym_Profileextension] = ACTIONS(5113),
    [anon_sym_ProfileExtension] = ACTIONS(5113),
    [anon_sym_profileExtension] = ACTIONS(5113),
    [anon_sym_permissionset] = ACTIONS(5115),
    [anon_sym_PERMISSIONSET] = ACTIONS(5115),
    [anon_sym_Permissionset] = ACTIONS(5115),
    [anon_sym_PermissionSet] = ACTIONS(5115),
    [anon_sym_permissionSet] = ACTIONS(5115),
    [anon_sym_permissionsetextension] = ACTIONS(5113),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5113),
    [anon_sym_Permissionsetextension] = ACTIONS(5113),
    [anon_sym_PermissionSetExtension] = ACTIONS(5113),
    [anon_sym_permissionSetExtension] = ACTIONS(5113),
    [sym_entitlement_keyword] = ACTIONS(5113),
    [anon_sym_pagecustomization] = ACTIONS(5113),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5113),
    [anon_sym_Pagecustomization] = ACTIONS(5113),
    [anon_sym_PageCustomization] = ACTIONS(5113),
    [anon_sym_pageCustomization] = ACTIONS(5113),
    [sym_using_keyword] = ACTIONS(5113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5113),
    [sym_preproc_close] = ACTIONS(5113),
  },
  [STATE(1991)] = {
    [anon_sym_POUNDif] = ACTIONS(5117),
    [anon_sym_POUNDIF] = ACTIONS(5117),
    [anon_sym_POUNDIf] = ACTIONS(5117),
    [anon_sym_POUNDelif] = ACTIONS(5117),
    [anon_sym_POUNDELIF] = ACTIONS(5117),
    [anon_sym_POUNDElif] = ACTIONS(5117),
    [anon_sym_POUNDelse] = ACTIONS(5117),
    [anon_sym_POUNDELSE] = ACTIONS(5117),
    [anon_sym_POUNDElse] = ACTIONS(5117),
    [anon_sym_POUNDendif] = ACTIONS(5117),
    [anon_sym_POUNDENDIF] = ACTIONS(5117),
    [anon_sym_POUNDEndif] = ACTIONS(5117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5119),
    [anon_sym_tableextension] = ACTIONS(5117),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5117),
    [anon_sym_Tableextension] = ACTIONS(5117),
    [anon_sym_TableExtension] = ACTIONS(5117),
    [anon_sym_tableExtension] = ACTIONS(5117),
    [sym_page_keyword] = ACTIONS(5119),
    [anon_sym_pageextension] = ACTIONS(5117),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5117),
    [anon_sym_Pageextension] = ACTIONS(5117),
    [anon_sym_PageExtension] = ACTIONS(5117),
    [anon_sym_pageExtension] = ACTIONS(5117),
    [anon_sym_codeunit] = ACTIONS(5117),
    [anon_sym_CODEUNIT] = ACTIONS(5117),
    [anon_sym_Codeunit] = ACTIONS(5117),
    [anon_sym_CodeUnit] = ACTIONS(5117),
    [anon_sym_COdeunit] = ACTIONS(5117),
    [anon_sym_codeUnit] = ACTIONS(5117),
    [sym_report_keyword] = ACTIONS(5119),
    [anon_sym_reportextension] = ACTIONS(5117),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5117),
    [anon_sym_Reportextension] = ACTIONS(5117),
    [anon_sym_ReportExtension] = ACTIONS(5117),
    [anon_sym_reportExtension] = ACTIONS(5117),
    [sym_query_keyword] = ACTIONS(5117),
    [anon_sym_xmlport] = ACTIONS(5117),
    [anon_sym_XMLPORT] = ACTIONS(5117),
    [anon_sym_Xmlport] = ACTIONS(5117),
    [anon_sym_XMLport] = ACTIONS(5117),
    [anon_sym_XMLPort] = ACTIONS(5117),
    [anon_sym_XmlPort] = ACTIONS(5117),
    [anon_sym_enum] = ACTIONS(5119),
    [anon_sym_ENUM] = ACTIONS(5119),
    [anon_sym_Enum] = ACTIONS(5119),
    [anon_sym_eNUM] = ACTIONS(5117),
    [anon_sym_eNum] = ACTIONS(5117),
    [anon_sym_ENum] = ACTIONS(5117),
    [anon_sym_enumextension] = ACTIONS(5117),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5117),
    [anon_sym_Enumextension] = ACTIONS(5117),
    [anon_sym_EnumExtension] = ACTIONS(5117),
    [anon_sym_enumExtension] = ACTIONS(5117),
    [sym_interface_keyword] = ACTIONS(5117),
    [anon_sym_controladdin] = ACTIONS(5117),
    [anon_sym_CONTROLADDIN] = ACTIONS(5117),
    [anon_sym_Controladdin] = ACTIONS(5117),
    [anon_sym_ControlAddIn] = ACTIONS(5117),
    [anon_sym_ControlAddin] = ACTIONS(5117),
    [anon_sym_controlAddIn] = ACTIONS(5117),
    [anon_sym_controlAddin] = ACTIONS(5117),
    [anon_sym_dotnet] = ACTIONS(5117),
    [anon_sym_DOTNET] = ACTIONS(5117),
    [anon_sym_Dotnet] = ACTIONS(5117),
    [anon_sym_DotNet] = ACTIONS(5117),
    [anon_sym_dotNet] = ACTIONS(5117),
    [sym_profile_keyword] = ACTIONS(5119),
    [anon_sym_profileextension] = ACTIONS(5117),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5117),
    [anon_sym_Profileextension] = ACTIONS(5117),
    [anon_sym_ProfileExtension] = ACTIONS(5117),
    [anon_sym_profileExtension] = ACTIONS(5117),
    [anon_sym_permissionset] = ACTIONS(5119),
    [anon_sym_PERMISSIONSET] = ACTIONS(5119),
    [anon_sym_Permissionset] = ACTIONS(5119),
    [anon_sym_PermissionSet] = ACTIONS(5119),
    [anon_sym_permissionSet] = ACTIONS(5119),
    [anon_sym_permissionsetextension] = ACTIONS(5117),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5117),
    [anon_sym_Permissionsetextension] = ACTIONS(5117),
    [anon_sym_PermissionSetExtension] = ACTIONS(5117),
    [anon_sym_permissionSetExtension] = ACTIONS(5117),
    [sym_entitlement_keyword] = ACTIONS(5117),
    [anon_sym_pagecustomization] = ACTIONS(5117),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5117),
    [anon_sym_Pagecustomization] = ACTIONS(5117),
    [anon_sym_PageCustomization] = ACTIONS(5117),
    [anon_sym_pageCustomization] = ACTIONS(5117),
    [sym_using_keyword] = ACTIONS(5117),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5117),
    [sym_preproc_close] = ACTIONS(5117),
  },
  [STATE(1992)] = {
    [anon_sym_POUNDif] = ACTIONS(5121),
    [anon_sym_POUNDIF] = ACTIONS(5121),
    [anon_sym_POUNDIf] = ACTIONS(5121),
    [anon_sym_POUNDelif] = ACTIONS(5121),
    [anon_sym_POUNDELIF] = ACTIONS(5121),
    [anon_sym_POUNDElif] = ACTIONS(5121),
    [anon_sym_POUNDelse] = ACTIONS(5121),
    [anon_sym_POUNDELSE] = ACTIONS(5121),
    [anon_sym_POUNDElse] = ACTIONS(5121),
    [anon_sym_POUNDendif] = ACTIONS(5121),
    [anon_sym_POUNDENDIF] = ACTIONS(5121),
    [anon_sym_POUNDEndif] = ACTIONS(5121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5123),
    [anon_sym_tableextension] = ACTIONS(5121),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5121),
    [anon_sym_Tableextension] = ACTIONS(5121),
    [anon_sym_TableExtension] = ACTIONS(5121),
    [anon_sym_tableExtension] = ACTIONS(5121),
    [sym_page_keyword] = ACTIONS(5123),
    [anon_sym_pageextension] = ACTIONS(5121),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5121),
    [anon_sym_Pageextension] = ACTIONS(5121),
    [anon_sym_PageExtension] = ACTIONS(5121),
    [anon_sym_pageExtension] = ACTIONS(5121),
    [anon_sym_codeunit] = ACTIONS(5121),
    [anon_sym_CODEUNIT] = ACTIONS(5121),
    [anon_sym_Codeunit] = ACTIONS(5121),
    [anon_sym_CodeUnit] = ACTIONS(5121),
    [anon_sym_COdeunit] = ACTIONS(5121),
    [anon_sym_codeUnit] = ACTIONS(5121),
    [sym_report_keyword] = ACTIONS(5123),
    [anon_sym_reportextension] = ACTIONS(5121),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5121),
    [anon_sym_Reportextension] = ACTIONS(5121),
    [anon_sym_ReportExtension] = ACTIONS(5121),
    [anon_sym_reportExtension] = ACTIONS(5121),
    [sym_query_keyword] = ACTIONS(5121),
    [anon_sym_xmlport] = ACTIONS(5121),
    [anon_sym_XMLPORT] = ACTIONS(5121),
    [anon_sym_Xmlport] = ACTIONS(5121),
    [anon_sym_XMLport] = ACTIONS(5121),
    [anon_sym_XMLPort] = ACTIONS(5121),
    [anon_sym_XmlPort] = ACTIONS(5121),
    [anon_sym_enum] = ACTIONS(5123),
    [anon_sym_ENUM] = ACTIONS(5123),
    [anon_sym_Enum] = ACTIONS(5123),
    [anon_sym_eNUM] = ACTIONS(5121),
    [anon_sym_eNum] = ACTIONS(5121),
    [anon_sym_ENum] = ACTIONS(5121),
    [anon_sym_enumextension] = ACTIONS(5121),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5121),
    [anon_sym_Enumextension] = ACTIONS(5121),
    [anon_sym_EnumExtension] = ACTIONS(5121),
    [anon_sym_enumExtension] = ACTIONS(5121),
    [sym_interface_keyword] = ACTIONS(5121),
    [anon_sym_controladdin] = ACTIONS(5121),
    [anon_sym_CONTROLADDIN] = ACTIONS(5121),
    [anon_sym_Controladdin] = ACTIONS(5121),
    [anon_sym_ControlAddIn] = ACTIONS(5121),
    [anon_sym_ControlAddin] = ACTIONS(5121),
    [anon_sym_controlAddIn] = ACTIONS(5121),
    [anon_sym_controlAddin] = ACTIONS(5121),
    [anon_sym_dotnet] = ACTIONS(5121),
    [anon_sym_DOTNET] = ACTIONS(5121),
    [anon_sym_Dotnet] = ACTIONS(5121),
    [anon_sym_DotNet] = ACTIONS(5121),
    [anon_sym_dotNet] = ACTIONS(5121),
    [sym_profile_keyword] = ACTIONS(5123),
    [anon_sym_profileextension] = ACTIONS(5121),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5121),
    [anon_sym_Profileextension] = ACTIONS(5121),
    [anon_sym_ProfileExtension] = ACTIONS(5121),
    [anon_sym_profileExtension] = ACTIONS(5121),
    [anon_sym_permissionset] = ACTIONS(5123),
    [anon_sym_PERMISSIONSET] = ACTIONS(5123),
    [anon_sym_Permissionset] = ACTIONS(5123),
    [anon_sym_PermissionSet] = ACTIONS(5123),
    [anon_sym_permissionSet] = ACTIONS(5123),
    [anon_sym_permissionsetextension] = ACTIONS(5121),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5121),
    [anon_sym_Permissionsetextension] = ACTIONS(5121),
    [anon_sym_PermissionSetExtension] = ACTIONS(5121),
    [anon_sym_permissionSetExtension] = ACTIONS(5121),
    [sym_entitlement_keyword] = ACTIONS(5121),
    [anon_sym_pagecustomization] = ACTIONS(5121),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5121),
    [anon_sym_Pagecustomization] = ACTIONS(5121),
    [anon_sym_PageCustomization] = ACTIONS(5121),
    [anon_sym_pageCustomization] = ACTIONS(5121),
    [sym_using_keyword] = ACTIONS(5121),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5121),
    [sym_preproc_close] = ACTIONS(5121),
  },
  [STATE(1993)] = {
    [anon_sym_POUNDif] = ACTIONS(5125),
    [anon_sym_POUNDIF] = ACTIONS(5125),
    [anon_sym_POUNDIf] = ACTIONS(5125),
    [anon_sym_POUNDelif] = ACTIONS(5125),
    [anon_sym_POUNDELIF] = ACTIONS(5125),
    [anon_sym_POUNDElif] = ACTIONS(5125),
    [anon_sym_POUNDelse] = ACTIONS(5125),
    [anon_sym_POUNDELSE] = ACTIONS(5125),
    [anon_sym_POUNDElse] = ACTIONS(5125),
    [anon_sym_POUNDendif] = ACTIONS(5125),
    [anon_sym_POUNDENDIF] = ACTIONS(5125),
    [anon_sym_POUNDEndif] = ACTIONS(5125),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5127),
    [anon_sym_tableextension] = ACTIONS(5125),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5125),
    [anon_sym_Tableextension] = ACTIONS(5125),
    [anon_sym_TableExtension] = ACTIONS(5125),
    [anon_sym_tableExtension] = ACTIONS(5125),
    [sym_page_keyword] = ACTIONS(5127),
    [anon_sym_pageextension] = ACTIONS(5125),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5125),
    [anon_sym_Pageextension] = ACTIONS(5125),
    [anon_sym_PageExtension] = ACTIONS(5125),
    [anon_sym_pageExtension] = ACTIONS(5125),
    [anon_sym_codeunit] = ACTIONS(5125),
    [anon_sym_CODEUNIT] = ACTIONS(5125),
    [anon_sym_Codeunit] = ACTIONS(5125),
    [anon_sym_CodeUnit] = ACTIONS(5125),
    [anon_sym_COdeunit] = ACTIONS(5125),
    [anon_sym_codeUnit] = ACTIONS(5125),
    [sym_report_keyword] = ACTIONS(5127),
    [anon_sym_reportextension] = ACTIONS(5125),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5125),
    [anon_sym_Reportextension] = ACTIONS(5125),
    [anon_sym_ReportExtension] = ACTIONS(5125),
    [anon_sym_reportExtension] = ACTIONS(5125),
    [sym_query_keyword] = ACTIONS(5125),
    [anon_sym_xmlport] = ACTIONS(5125),
    [anon_sym_XMLPORT] = ACTIONS(5125),
    [anon_sym_Xmlport] = ACTIONS(5125),
    [anon_sym_XMLport] = ACTIONS(5125),
    [anon_sym_XMLPort] = ACTIONS(5125),
    [anon_sym_XmlPort] = ACTIONS(5125),
    [anon_sym_enum] = ACTIONS(5127),
    [anon_sym_ENUM] = ACTIONS(5127),
    [anon_sym_Enum] = ACTIONS(5127),
    [anon_sym_eNUM] = ACTIONS(5125),
    [anon_sym_eNum] = ACTIONS(5125),
    [anon_sym_ENum] = ACTIONS(5125),
    [anon_sym_enumextension] = ACTIONS(5125),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5125),
    [anon_sym_Enumextension] = ACTIONS(5125),
    [anon_sym_EnumExtension] = ACTIONS(5125),
    [anon_sym_enumExtension] = ACTIONS(5125),
    [sym_interface_keyword] = ACTIONS(5125),
    [anon_sym_controladdin] = ACTIONS(5125),
    [anon_sym_CONTROLADDIN] = ACTIONS(5125),
    [anon_sym_Controladdin] = ACTIONS(5125),
    [anon_sym_ControlAddIn] = ACTIONS(5125),
    [anon_sym_ControlAddin] = ACTIONS(5125),
    [anon_sym_controlAddIn] = ACTIONS(5125),
    [anon_sym_controlAddin] = ACTIONS(5125),
    [anon_sym_dotnet] = ACTIONS(5125),
    [anon_sym_DOTNET] = ACTIONS(5125),
    [anon_sym_Dotnet] = ACTIONS(5125),
    [anon_sym_DotNet] = ACTIONS(5125),
    [anon_sym_dotNet] = ACTIONS(5125),
    [sym_profile_keyword] = ACTIONS(5127),
    [anon_sym_profileextension] = ACTIONS(5125),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5125),
    [anon_sym_Profileextension] = ACTIONS(5125),
    [anon_sym_ProfileExtension] = ACTIONS(5125),
    [anon_sym_profileExtension] = ACTIONS(5125),
    [anon_sym_permissionset] = ACTIONS(5127),
    [anon_sym_PERMISSIONSET] = ACTIONS(5127),
    [anon_sym_Permissionset] = ACTIONS(5127),
    [anon_sym_PermissionSet] = ACTIONS(5127),
    [anon_sym_permissionSet] = ACTIONS(5127),
    [anon_sym_permissionsetextension] = ACTIONS(5125),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5125),
    [anon_sym_Permissionsetextension] = ACTIONS(5125),
    [anon_sym_PermissionSetExtension] = ACTIONS(5125),
    [anon_sym_permissionSetExtension] = ACTIONS(5125),
    [sym_entitlement_keyword] = ACTIONS(5125),
    [anon_sym_pagecustomization] = ACTIONS(5125),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5125),
    [anon_sym_Pagecustomization] = ACTIONS(5125),
    [anon_sym_PageCustomization] = ACTIONS(5125),
    [anon_sym_pageCustomization] = ACTIONS(5125),
    [sym_using_keyword] = ACTIONS(5125),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5125),
    [sym_preproc_close] = ACTIONS(5125),
  },
  [STATE(1994)] = {
    [anon_sym_POUNDif] = ACTIONS(5129),
    [anon_sym_POUNDIF] = ACTIONS(5129),
    [anon_sym_POUNDIf] = ACTIONS(5129),
    [anon_sym_POUNDelif] = ACTIONS(5129),
    [anon_sym_POUNDELIF] = ACTIONS(5129),
    [anon_sym_POUNDElif] = ACTIONS(5129),
    [anon_sym_POUNDelse] = ACTIONS(5129),
    [anon_sym_POUNDELSE] = ACTIONS(5129),
    [anon_sym_POUNDElse] = ACTIONS(5129),
    [anon_sym_POUNDendif] = ACTIONS(5129),
    [anon_sym_POUNDENDIF] = ACTIONS(5129),
    [anon_sym_POUNDEndif] = ACTIONS(5129),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5131),
    [anon_sym_tableextension] = ACTIONS(5129),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5129),
    [anon_sym_Tableextension] = ACTIONS(5129),
    [anon_sym_TableExtension] = ACTIONS(5129),
    [anon_sym_tableExtension] = ACTIONS(5129),
    [sym_page_keyword] = ACTIONS(5131),
    [anon_sym_pageextension] = ACTIONS(5129),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5129),
    [anon_sym_Pageextension] = ACTIONS(5129),
    [anon_sym_PageExtension] = ACTIONS(5129),
    [anon_sym_pageExtension] = ACTIONS(5129),
    [anon_sym_codeunit] = ACTIONS(5129),
    [anon_sym_CODEUNIT] = ACTIONS(5129),
    [anon_sym_Codeunit] = ACTIONS(5129),
    [anon_sym_CodeUnit] = ACTIONS(5129),
    [anon_sym_COdeunit] = ACTIONS(5129),
    [anon_sym_codeUnit] = ACTIONS(5129),
    [sym_report_keyword] = ACTIONS(5131),
    [anon_sym_reportextension] = ACTIONS(5129),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5129),
    [anon_sym_Reportextension] = ACTIONS(5129),
    [anon_sym_ReportExtension] = ACTIONS(5129),
    [anon_sym_reportExtension] = ACTIONS(5129),
    [sym_query_keyword] = ACTIONS(5129),
    [anon_sym_xmlport] = ACTIONS(5129),
    [anon_sym_XMLPORT] = ACTIONS(5129),
    [anon_sym_Xmlport] = ACTIONS(5129),
    [anon_sym_XMLport] = ACTIONS(5129),
    [anon_sym_XMLPort] = ACTIONS(5129),
    [anon_sym_XmlPort] = ACTIONS(5129),
    [anon_sym_enum] = ACTIONS(5131),
    [anon_sym_ENUM] = ACTIONS(5131),
    [anon_sym_Enum] = ACTIONS(5131),
    [anon_sym_eNUM] = ACTIONS(5129),
    [anon_sym_eNum] = ACTIONS(5129),
    [anon_sym_ENum] = ACTIONS(5129),
    [anon_sym_enumextension] = ACTIONS(5129),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5129),
    [anon_sym_Enumextension] = ACTIONS(5129),
    [anon_sym_EnumExtension] = ACTIONS(5129),
    [anon_sym_enumExtension] = ACTIONS(5129),
    [sym_interface_keyword] = ACTIONS(5129),
    [anon_sym_controladdin] = ACTIONS(5129),
    [anon_sym_CONTROLADDIN] = ACTIONS(5129),
    [anon_sym_Controladdin] = ACTIONS(5129),
    [anon_sym_ControlAddIn] = ACTIONS(5129),
    [anon_sym_ControlAddin] = ACTIONS(5129),
    [anon_sym_controlAddIn] = ACTIONS(5129),
    [anon_sym_controlAddin] = ACTIONS(5129),
    [anon_sym_dotnet] = ACTIONS(5129),
    [anon_sym_DOTNET] = ACTIONS(5129),
    [anon_sym_Dotnet] = ACTIONS(5129),
    [anon_sym_DotNet] = ACTIONS(5129),
    [anon_sym_dotNet] = ACTIONS(5129),
    [sym_profile_keyword] = ACTIONS(5131),
    [anon_sym_profileextension] = ACTIONS(5129),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5129),
    [anon_sym_Profileextension] = ACTIONS(5129),
    [anon_sym_ProfileExtension] = ACTIONS(5129),
    [anon_sym_profileExtension] = ACTIONS(5129),
    [anon_sym_permissionset] = ACTIONS(5131),
    [anon_sym_PERMISSIONSET] = ACTIONS(5131),
    [anon_sym_Permissionset] = ACTIONS(5131),
    [anon_sym_PermissionSet] = ACTIONS(5131),
    [anon_sym_permissionSet] = ACTIONS(5131),
    [anon_sym_permissionsetextension] = ACTIONS(5129),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5129),
    [anon_sym_Permissionsetextension] = ACTIONS(5129),
    [anon_sym_PermissionSetExtension] = ACTIONS(5129),
    [anon_sym_permissionSetExtension] = ACTIONS(5129),
    [sym_entitlement_keyword] = ACTIONS(5129),
    [anon_sym_pagecustomization] = ACTIONS(5129),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5129),
    [anon_sym_Pagecustomization] = ACTIONS(5129),
    [anon_sym_PageCustomization] = ACTIONS(5129),
    [anon_sym_pageCustomization] = ACTIONS(5129),
    [sym_using_keyword] = ACTIONS(5129),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5129),
    [sym_preproc_close] = ACTIONS(5129),
  },
  [STATE(1995)] = {
    [anon_sym_POUNDif] = ACTIONS(5133),
    [anon_sym_POUNDIF] = ACTIONS(5133),
    [anon_sym_POUNDIf] = ACTIONS(5133),
    [anon_sym_POUNDelif] = ACTIONS(5133),
    [anon_sym_POUNDELIF] = ACTIONS(5133),
    [anon_sym_POUNDElif] = ACTIONS(5133),
    [anon_sym_POUNDelse] = ACTIONS(5133),
    [anon_sym_POUNDELSE] = ACTIONS(5133),
    [anon_sym_POUNDElse] = ACTIONS(5133),
    [anon_sym_POUNDendif] = ACTIONS(5133),
    [anon_sym_POUNDENDIF] = ACTIONS(5133),
    [anon_sym_POUNDEndif] = ACTIONS(5133),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5135),
    [anon_sym_tableextension] = ACTIONS(5133),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5133),
    [anon_sym_Tableextension] = ACTIONS(5133),
    [anon_sym_TableExtension] = ACTIONS(5133),
    [anon_sym_tableExtension] = ACTIONS(5133),
    [sym_page_keyword] = ACTIONS(5135),
    [anon_sym_pageextension] = ACTIONS(5133),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5133),
    [anon_sym_Pageextension] = ACTIONS(5133),
    [anon_sym_PageExtension] = ACTIONS(5133),
    [anon_sym_pageExtension] = ACTIONS(5133),
    [anon_sym_codeunit] = ACTIONS(5133),
    [anon_sym_CODEUNIT] = ACTIONS(5133),
    [anon_sym_Codeunit] = ACTIONS(5133),
    [anon_sym_CodeUnit] = ACTIONS(5133),
    [anon_sym_COdeunit] = ACTIONS(5133),
    [anon_sym_codeUnit] = ACTIONS(5133),
    [sym_report_keyword] = ACTIONS(5135),
    [anon_sym_reportextension] = ACTIONS(5133),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5133),
    [anon_sym_Reportextension] = ACTIONS(5133),
    [anon_sym_ReportExtension] = ACTIONS(5133),
    [anon_sym_reportExtension] = ACTIONS(5133),
    [sym_query_keyword] = ACTIONS(5133),
    [anon_sym_xmlport] = ACTIONS(5133),
    [anon_sym_XMLPORT] = ACTIONS(5133),
    [anon_sym_Xmlport] = ACTIONS(5133),
    [anon_sym_XMLport] = ACTIONS(5133),
    [anon_sym_XMLPort] = ACTIONS(5133),
    [anon_sym_XmlPort] = ACTIONS(5133),
    [anon_sym_enum] = ACTIONS(5135),
    [anon_sym_ENUM] = ACTIONS(5135),
    [anon_sym_Enum] = ACTIONS(5135),
    [anon_sym_eNUM] = ACTIONS(5133),
    [anon_sym_eNum] = ACTIONS(5133),
    [anon_sym_ENum] = ACTIONS(5133),
    [anon_sym_enumextension] = ACTIONS(5133),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5133),
    [anon_sym_Enumextension] = ACTIONS(5133),
    [anon_sym_EnumExtension] = ACTIONS(5133),
    [anon_sym_enumExtension] = ACTIONS(5133),
    [sym_interface_keyword] = ACTIONS(5133),
    [anon_sym_controladdin] = ACTIONS(5133),
    [anon_sym_CONTROLADDIN] = ACTIONS(5133),
    [anon_sym_Controladdin] = ACTIONS(5133),
    [anon_sym_ControlAddIn] = ACTIONS(5133),
    [anon_sym_ControlAddin] = ACTIONS(5133),
    [anon_sym_controlAddIn] = ACTIONS(5133),
    [anon_sym_controlAddin] = ACTIONS(5133),
    [anon_sym_dotnet] = ACTIONS(5133),
    [anon_sym_DOTNET] = ACTIONS(5133),
    [anon_sym_Dotnet] = ACTIONS(5133),
    [anon_sym_DotNet] = ACTIONS(5133),
    [anon_sym_dotNet] = ACTIONS(5133),
    [sym_profile_keyword] = ACTIONS(5135),
    [anon_sym_profileextension] = ACTIONS(5133),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5133),
    [anon_sym_Profileextension] = ACTIONS(5133),
    [anon_sym_ProfileExtension] = ACTIONS(5133),
    [anon_sym_profileExtension] = ACTIONS(5133),
    [anon_sym_permissionset] = ACTIONS(5135),
    [anon_sym_PERMISSIONSET] = ACTIONS(5135),
    [anon_sym_Permissionset] = ACTIONS(5135),
    [anon_sym_PermissionSet] = ACTIONS(5135),
    [anon_sym_permissionSet] = ACTIONS(5135),
    [anon_sym_permissionsetextension] = ACTIONS(5133),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5133),
    [anon_sym_Permissionsetextension] = ACTIONS(5133),
    [anon_sym_PermissionSetExtension] = ACTIONS(5133),
    [anon_sym_permissionSetExtension] = ACTIONS(5133),
    [sym_entitlement_keyword] = ACTIONS(5133),
    [anon_sym_pagecustomization] = ACTIONS(5133),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5133),
    [anon_sym_Pagecustomization] = ACTIONS(5133),
    [anon_sym_PageCustomization] = ACTIONS(5133),
    [anon_sym_pageCustomization] = ACTIONS(5133),
    [sym_using_keyword] = ACTIONS(5133),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5133),
    [sym_preproc_close] = ACTIONS(5133),
  },
  [STATE(1996)] = {
    [anon_sym_POUNDif] = ACTIONS(5137),
    [anon_sym_POUNDIF] = ACTIONS(5137),
    [anon_sym_POUNDIf] = ACTIONS(5137),
    [anon_sym_POUNDelif] = ACTIONS(5137),
    [anon_sym_POUNDELIF] = ACTIONS(5137),
    [anon_sym_POUNDElif] = ACTIONS(5137),
    [anon_sym_POUNDelse] = ACTIONS(5137),
    [anon_sym_POUNDELSE] = ACTIONS(5137),
    [anon_sym_POUNDElse] = ACTIONS(5137),
    [anon_sym_POUNDendif] = ACTIONS(5137),
    [anon_sym_POUNDENDIF] = ACTIONS(5137),
    [anon_sym_POUNDEndif] = ACTIONS(5137),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5139),
    [anon_sym_tableextension] = ACTIONS(5137),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5137),
    [anon_sym_Tableextension] = ACTIONS(5137),
    [anon_sym_TableExtension] = ACTIONS(5137),
    [anon_sym_tableExtension] = ACTIONS(5137),
    [sym_page_keyword] = ACTIONS(5139),
    [anon_sym_pageextension] = ACTIONS(5137),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5137),
    [anon_sym_Pageextension] = ACTIONS(5137),
    [anon_sym_PageExtension] = ACTIONS(5137),
    [anon_sym_pageExtension] = ACTIONS(5137),
    [anon_sym_codeunit] = ACTIONS(5137),
    [anon_sym_CODEUNIT] = ACTIONS(5137),
    [anon_sym_Codeunit] = ACTIONS(5137),
    [anon_sym_CodeUnit] = ACTIONS(5137),
    [anon_sym_COdeunit] = ACTIONS(5137),
    [anon_sym_codeUnit] = ACTIONS(5137),
    [sym_report_keyword] = ACTIONS(5139),
    [anon_sym_reportextension] = ACTIONS(5137),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5137),
    [anon_sym_Reportextension] = ACTIONS(5137),
    [anon_sym_ReportExtension] = ACTIONS(5137),
    [anon_sym_reportExtension] = ACTIONS(5137),
    [sym_query_keyword] = ACTIONS(5137),
    [anon_sym_xmlport] = ACTIONS(5137),
    [anon_sym_XMLPORT] = ACTIONS(5137),
    [anon_sym_Xmlport] = ACTIONS(5137),
    [anon_sym_XMLport] = ACTIONS(5137),
    [anon_sym_XMLPort] = ACTIONS(5137),
    [anon_sym_XmlPort] = ACTIONS(5137),
    [anon_sym_enum] = ACTIONS(5139),
    [anon_sym_ENUM] = ACTIONS(5139),
    [anon_sym_Enum] = ACTIONS(5139),
    [anon_sym_eNUM] = ACTIONS(5137),
    [anon_sym_eNum] = ACTIONS(5137),
    [anon_sym_ENum] = ACTIONS(5137),
    [anon_sym_enumextension] = ACTIONS(5137),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5137),
    [anon_sym_Enumextension] = ACTIONS(5137),
    [anon_sym_EnumExtension] = ACTIONS(5137),
    [anon_sym_enumExtension] = ACTIONS(5137),
    [sym_interface_keyword] = ACTIONS(5137),
    [anon_sym_controladdin] = ACTIONS(5137),
    [anon_sym_CONTROLADDIN] = ACTIONS(5137),
    [anon_sym_Controladdin] = ACTIONS(5137),
    [anon_sym_ControlAddIn] = ACTIONS(5137),
    [anon_sym_ControlAddin] = ACTIONS(5137),
    [anon_sym_controlAddIn] = ACTIONS(5137),
    [anon_sym_controlAddin] = ACTIONS(5137),
    [anon_sym_dotnet] = ACTIONS(5137),
    [anon_sym_DOTNET] = ACTIONS(5137),
    [anon_sym_Dotnet] = ACTIONS(5137),
    [anon_sym_DotNet] = ACTIONS(5137),
    [anon_sym_dotNet] = ACTIONS(5137),
    [sym_profile_keyword] = ACTIONS(5139),
    [anon_sym_profileextension] = ACTIONS(5137),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5137),
    [anon_sym_Profileextension] = ACTIONS(5137),
    [anon_sym_ProfileExtension] = ACTIONS(5137),
    [anon_sym_profileExtension] = ACTIONS(5137),
    [anon_sym_permissionset] = ACTIONS(5139),
    [anon_sym_PERMISSIONSET] = ACTIONS(5139),
    [anon_sym_Permissionset] = ACTIONS(5139),
    [anon_sym_PermissionSet] = ACTIONS(5139),
    [anon_sym_permissionSet] = ACTIONS(5139),
    [anon_sym_permissionsetextension] = ACTIONS(5137),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5137),
    [anon_sym_Permissionsetextension] = ACTIONS(5137),
    [anon_sym_PermissionSetExtension] = ACTIONS(5137),
    [anon_sym_permissionSetExtension] = ACTIONS(5137),
    [sym_entitlement_keyword] = ACTIONS(5137),
    [anon_sym_pagecustomization] = ACTIONS(5137),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5137),
    [anon_sym_Pagecustomization] = ACTIONS(5137),
    [anon_sym_PageCustomization] = ACTIONS(5137),
    [anon_sym_pageCustomization] = ACTIONS(5137),
    [sym_using_keyword] = ACTIONS(5137),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5137),
    [sym_preproc_close] = ACTIONS(5137),
  },
  [STATE(1997)] = {
    [anon_sym_POUNDif] = ACTIONS(5141),
    [anon_sym_POUNDIF] = ACTIONS(5141),
    [anon_sym_POUNDIf] = ACTIONS(5141),
    [anon_sym_POUNDelif] = ACTIONS(5141),
    [anon_sym_POUNDELIF] = ACTIONS(5141),
    [anon_sym_POUNDElif] = ACTIONS(5141),
    [anon_sym_POUNDelse] = ACTIONS(5141),
    [anon_sym_POUNDELSE] = ACTIONS(5141),
    [anon_sym_POUNDElse] = ACTIONS(5141),
    [anon_sym_POUNDendif] = ACTIONS(5141),
    [anon_sym_POUNDENDIF] = ACTIONS(5141),
    [anon_sym_POUNDEndif] = ACTIONS(5141),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5143),
    [anon_sym_tableextension] = ACTIONS(5141),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5141),
    [anon_sym_Tableextension] = ACTIONS(5141),
    [anon_sym_TableExtension] = ACTIONS(5141),
    [anon_sym_tableExtension] = ACTIONS(5141),
    [sym_page_keyword] = ACTIONS(5143),
    [anon_sym_pageextension] = ACTIONS(5141),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5141),
    [anon_sym_Pageextension] = ACTIONS(5141),
    [anon_sym_PageExtension] = ACTIONS(5141),
    [anon_sym_pageExtension] = ACTIONS(5141),
    [anon_sym_codeunit] = ACTIONS(5141),
    [anon_sym_CODEUNIT] = ACTIONS(5141),
    [anon_sym_Codeunit] = ACTIONS(5141),
    [anon_sym_CodeUnit] = ACTIONS(5141),
    [anon_sym_COdeunit] = ACTIONS(5141),
    [anon_sym_codeUnit] = ACTIONS(5141),
    [sym_report_keyword] = ACTIONS(5143),
    [anon_sym_reportextension] = ACTIONS(5141),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5141),
    [anon_sym_Reportextension] = ACTIONS(5141),
    [anon_sym_ReportExtension] = ACTIONS(5141),
    [anon_sym_reportExtension] = ACTIONS(5141),
    [sym_query_keyword] = ACTIONS(5141),
    [anon_sym_xmlport] = ACTIONS(5141),
    [anon_sym_XMLPORT] = ACTIONS(5141),
    [anon_sym_Xmlport] = ACTIONS(5141),
    [anon_sym_XMLport] = ACTIONS(5141),
    [anon_sym_XMLPort] = ACTIONS(5141),
    [anon_sym_XmlPort] = ACTIONS(5141),
    [anon_sym_enum] = ACTIONS(5143),
    [anon_sym_ENUM] = ACTIONS(5143),
    [anon_sym_Enum] = ACTIONS(5143),
    [anon_sym_eNUM] = ACTIONS(5141),
    [anon_sym_eNum] = ACTIONS(5141),
    [anon_sym_ENum] = ACTIONS(5141),
    [anon_sym_enumextension] = ACTIONS(5141),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5141),
    [anon_sym_Enumextension] = ACTIONS(5141),
    [anon_sym_EnumExtension] = ACTIONS(5141),
    [anon_sym_enumExtension] = ACTIONS(5141),
    [sym_interface_keyword] = ACTIONS(5141),
    [anon_sym_controladdin] = ACTIONS(5141),
    [anon_sym_CONTROLADDIN] = ACTIONS(5141),
    [anon_sym_Controladdin] = ACTIONS(5141),
    [anon_sym_ControlAddIn] = ACTIONS(5141),
    [anon_sym_ControlAddin] = ACTIONS(5141),
    [anon_sym_controlAddIn] = ACTIONS(5141),
    [anon_sym_controlAddin] = ACTIONS(5141),
    [anon_sym_dotnet] = ACTIONS(5141),
    [anon_sym_DOTNET] = ACTIONS(5141),
    [anon_sym_Dotnet] = ACTIONS(5141),
    [anon_sym_DotNet] = ACTIONS(5141),
    [anon_sym_dotNet] = ACTIONS(5141),
    [sym_profile_keyword] = ACTIONS(5143),
    [anon_sym_profileextension] = ACTIONS(5141),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5141),
    [anon_sym_Profileextension] = ACTIONS(5141),
    [anon_sym_ProfileExtension] = ACTIONS(5141),
    [anon_sym_profileExtension] = ACTIONS(5141),
    [anon_sym_permissionset] = ACTIONS(5143),
    [anon_sym_PERMISSIONSET] = ACTIONS(5143),
    [anon_sym_Permissionset] = ACTIONS(5143),
    [anon_sym_PermissionSet] = ACTIONS(5143),
    [anon_sym_permissionSet] = ACTIONS(5143),
    [anon_sym_permissionsetextension] = ACTIONS(5141),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5141),
    [anon_sym_Permissionsetextension] = ACTIONS(5141),
    [anon_sym_PermissionSetExtension] = ACTIONS(5141),
    [anon_sym_permissionSetExtension] = ACTIONS(5141),
    [sym_entitlement_keyword] = ACTIONS(5141),
    [anon_sym_pagecustomization] = ACTIONS(5141),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5141),
    [anon_sym_Pagecustomization] = ACTIONS(5141),
    [anon_sym_PageCustomization] = ACTIONS(5141),
    [anon_sym_pageCustomization] = ACTIONS(5141),
    [sym_using_keyword] = ACTIONS(5141),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5141),
    [sym_preproc_close] = ACTIONS(5141),
  },
  [STATE(1998)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1998),
    [sym_identifier] = ACTIONS(2396),
    [anon_sym_SEMI] = ACTIONS(2398),
    [anon_sym_DOT] = ACTIONS(5145),
    [anon_sym_EQ] = ACTIONS(2398),
    [anon_sym_COMMA] = ACTIONS(2398),
    [anon_sym_COLON] = ACTIONS(2396),
    [anon_sym_DASH] = ACTIONS(2396),
    [aux_sym_boolean_token1] = ACTIONS(2396),
    [aux_sym_boolean_token2] = ACTIONS(2396),
    [sym_decimal] = ACTIONS(2396),
    [anon_sym_LPAREN] = ACTIONS(2398),
    [anon_sym_DOT_DOT] = ACTIONS(2398),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2396),
    [anon_sym_STAR] = ACTIONS(2396),
    [anon_sym_LBRACK] = ACTIONS(2398),
    [aux_sym_record_type_token1] = ACTIONS(2396),
    [aux_sym_basic_type_token21] = ACTIONS(2396),
    [aux_sym_basic_type_token22] = ACTIONS(2396),
    [aux_sym_basic_type_token48] = ACTIONS(2396),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2396),
    [anon_sym_POUNDif] = ACTIONS(2398),
    [anon_sym_POUNDIF] = ACTIONS(2398),
    [anon_sym_POUNDIf] = ACTIONS(2398),
    [anon_sym_not] = ACTIONS(2396),
    [anon_sym_NOT] = ACTIONS(2396),
    [anon_sym_Not] = ACTIONS(2396),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2398),
    [aux_sym__expression_token1] = ACTIONS(2398),
    [aux_sym__expression_token2] = ACTIONS(2398),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2396),
    [anon_sym_SLASH] = ACTIONS(2396),
    [anon_sym_div] = ACTIONS(2396),
    [anon_sym_DIV] = ACTIONS(2396),
    [anon_sym_Div] = ACTIONS(2396),
    [anon_sym_mod] = ACTIONS(2396),
    [anon_sym_MOD] = ACTIONS(2396),
    [anon_sym_Mod] = ACTIONS(2396),
    [anon_sym_PLUS] = ACTIONS(2396),
    [anon_sym_GT_EQ] = ACTIONS(2398),
    [anon_sym_LT_EQ] = ACTIONS(2398),
    [anon_sym_GT] = ACTIONS(2396),
    [anon_sym_LT] = ACTIONS(2396),
    [anon_sym_LT_GT] = ACTIONS(2398),
    [anon_sym_and] = ACTIONS(2396),
    [anon_sym_AND] = ACTIONS(2396),
    [anon_sym_And] = ACTIONS(2396),
    [anon_sym_or] = ACTIONS(2396),
    [anon_sym_OR] = ACTIONS(2396),
    [anon_sym_Or] = ACTIONS(2396),
    [anon_sym_xor] = ACTIONS(2396),
    [anon_sym_XOR] = ACTIONS(2396),
    [anon_sym_Xor] = ACTIONS(2396),
    [anon_sym_QMARK] = ACTIONS(2398),
    [sym_datetime_literal] = ACTIONS(2398),
    [sym_date_literal] = ACTIONS(2396),
    [sym_time_literal] = ACTIONS(2396),
    [sym_biginteger_literal] = ACTIONS(2398),
    [anon_sym_else] = ACTIONS(2396),
    [anon_sym_ELSE] = ACTIONS(2396),
    [anon_sym_Else] = ACTIONS(2396),
    [anon_sym_in] = ACTIONS(2396),
    [anon_sym_IN] = ACTIONS(2396),
    [anon_sym_In] = ACTIONS(2396),
    [sym_page_keyword] = ACTIONS(2396),
    [anon_sym_codeunit] = ACTIONS(2396),
    [anon_sym_CODEUNIT] = ACTIONS(2396),
    [anon_sym_Codeunit] = ACTIONS(2396),
    [anon_sym_CodeUnit] = ACTIONS(2396),
    [anon_sym_COdeunit] = ACTIONS(2396),
    [anon_sym_codeUnit] = ACTIONS(2396),
    [sym_report_keyword] = ACTIONS(2396),
    [sym_query_keyword] = ACTIONS(2396),
    [anon_sym_xmlport] = ACTIONS(2396),
    [anon_sym_XMLPORT] = ACTIONS(2396),
    [anon_sym_Xmlport] = ACTIONS(2396),
    [anon_sym_XMLport] = ACTIONS(2396),
    [anon_sym_XMLPort] = ACTIONS(2396),
    [anon_sym_XmlPort] = ACTIONS(2396),
    [anon_sym_enum] = ACTIONS(2396),
    [anon_sym_ENUM] = ACTIONS(2396),
    [anon_sym_Enum] = ACTIONS(2396),
    [anon_sym_eNUM] = ACTIONS(2396),
    [anon_sym_eNum] = ACTIONS(2396),
    [anon_sym_ENum] = ACTIONS(2396),
    [sym_temporary_keyword] = ACTIONS(2396),
    [sym_quoted_identifier] = ACTIONS(2398),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2398),
    [sym_integer] = ACTIONS(2396),
    [sym_continue_as_identifier] = ACTIONS(2398),
    [sym_preproc_open] = ACTIONS(2398),
  },
  [STATE(1999)] = {
    [sym_identifier] = ACTIONS(2266),
    [anon_sym_DOT] = ACTIONS(2266),
    [anon_sym_EQ] = ACTIONS(2268),
    [anon_sym_COMMA] = ACTIONS(2268),
    [anon_sym_DASH] = ACTIONS(2266),
    [aux_sym_boolean_token1] = ACTIONS(2266),
    [aux_sym_boolean_token2] = ACTIONS(2266),
    [sym_decimal] = ACTIONS(2266),
    [anon_sym_LPAREN] = ACTIONS(2268),
    [anon_sym_DOT_DOT] = ACTIONS(2268),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2266),
    [anon_sym_STAR] = ACTIONS(2266),
    [anon_sym_LBRACK] = ACTIONS(2268),
    [aux_sym_record_type_token1] = ACTIONS(2266),
    [aux_sym_basic_type_token21] = ACTIONS(2266),
    [aux_sym_basic_type_token22] = ACTIONS(2266),
    [aux_sym_basic_type_token48] = ACTIONS(2266),
    [anon_sym_COLON_COLON] = ACTIONS(2268),
    [anon_sym_not] = ACTIONS(2266),
    [anon_sym_NOT] = ACTIONS(2266),
    [anon_sym_Not] = ACTIONS(2266),
    [anon_sym_POUNDelif] = ACTIONS(2268),
    [anon_sym_POUNDELIF] = ACTIONS(2268),
    [anon_sym_POUNDElif] = ACTIONS(2268),
    [anon_sym_POUNDelse] = ACTIONS(2268),
    [anon_sym_POUNDELSE] = ACTIONS(2268),
    [anon_sym_POUNDElse] = ACTIONS(2268),
    [anon_sym_POUNDendif] = ACTIONS(2268),
    [anon_sym_POUNDENDIF] = ACTIONS(2268),
    [anon_sym_POUNDEndif] = ACTIONS(2268),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2268),
    [aux_sym__expression_token1] = ACTIONS(2268),
    [aux_sym__expression_token2] = ACTIONS(2268),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2266),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2266),
    [anon_sym_SLASH] = ACTIONS(2266),
    [anon_sym_div] = ACTIONS(2266),
    [anon_sym_DIV] = ACTIONS(2266),
    [anon_sym_Div] = ACTIONS(2266),
    [anon_sym_mod] = ACTIONS(2266),
    [anon_sym_MOD] = ACTIONS(2266),
    [anon_sym_Mod] = ACTIONS(2266),
    [anon_sym_PLUS] = ACTIONS(2266),
    [anon_sym_GT_EQ] = ACTIONS(2268),
    [anon_sym_LT_EQ] = ACTIONS(2268),
    [anon_sym_GT] = ACTIONS(2266),
    [anon_sym_LT] = ACTIONS(2266),
    [anon_sym_LT_GT] = ACTIONS(2268),
    [anon_sym_and] = ACTIONS(2266),
    [anon_sym_AND] = ACTIONS(2266),
    [anon_sym_And] = ACTIONS(2266),
    [anon_sym_or] = ACTIONS(2266),
    [anon_sym_OR] = ACTIONS(2266),
    [anon_sym_Or] = ACTIONS(2266),
    [anon_sym_xor] = ACTIONS(2266),
    [anon_sym_XOR] = ACTIONS(2266),
    [anon_sym_Xor] = ACTIONS(2266),
    [anon_sym_QMARK] = ACTIONS(2268),
    [sym_datetime_literal] = ACTIONS(2268),
    [sym_date_literal] = ACTIONS(2266),
    [sym_time_literal] = ACTIONS(2266),
    [sym_biginteger_literal] = ACTIONS(2268),
    [anon_sym_in] = ACTIONS(2266),
    [anon_sym_IN] = ACTIONS(2266),
    [anon_sym_In] = ACTIONS(2266),
    [sym_page_keyword] = ACTIONS(2266),
    [anon_sym_codeunit] = ACTIONS(2266),
    [anon_sym_CODEUNIT] = ACTIONS(2266),
    [anon_sym_Codeunit] = ACTIONS(2266),
    [anon_sym_CodeUnit] = ACTIONS(2266),
    [anon_sym_COdeunit] = ACTIONS(2266),
    [anon_sym_codeUnit] = ACTIONS(2266),
    [sym_report_keyword] = ACTIONS(2266),
    [sym_query_keyword] = ACTIONS(2266),
    [anon_sym_xmlport] = ACTIONS(2266),
    [anon_sym_XMLPORT] = ACTIONS(2266),
    [anon_sym_Xmlport] = ACTIONS(2266),
    [anon_sym_XMLport] = ACTIONS(2266),
    [anon_sym_XMLPort] = ACTIONS(2266),
    [anon_sym_XmlPort] = ACTIONS(2266),
    [anon_sym_enum] = ACTIONS(2266),
    [anon_sym_ENUM] = ACTIONS(2266),
    [anon_sym_Enum] = ACTIONS(2266),
    [anon_sym_eNUM] = ACTIONS(2266),
    [anon_sym_eNum] = ACTIONS(2266),
    [anon_sym_ENum] = ACTIONS(2266),
    [sym_temporary_keyword] = ACTIONS(2266),
    [sym_quoted_identifier] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2268),
    [sym_integer] = ACTIONS(2266),
    [sym_continue_as_identifier] = ACTIONS(2268),
    [sym_preproc_close] = ACTIONS(2268),
  },
  [STATE(2000)] = {
    [anon_sym_POUNDif] = ACTIONS(5148),
    [anon_sym_POUNDIF] = ACTIONS(5148),
    [anon_sym_POUNDIf] = ACTIONS(5148),
    [anon_sym_POUNDelif] = ACTIONS(5148),
    [anon_sym_POUNDELIF] = ACTIONS(5148),
    [anon_sym_POUNDElif] = ACTIONS(5148),
    [anon_sym_POUNDelse] = ACTIONS(5148),
    [anon_sym_POUNDELSE] = ACTIONS(5148),
    [anon_sym_POUNDElse] = ACTIONS(5148),
    [anon_sym_POUNDendif] = ACTIONS(5148),
    [anon_sym_POUNDENDIF] = ACTIONS(5148),
    [anon_sym_POUNDEndif] = ACTIONS(5148),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5150),
    [anon_sym_tableextension] = ACTIONS(5148),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5148),
    [anon_sym_Tableextension] = ACTIONS(5148),
    [anon_sym_TableExtension] = ACTIONS(5148),
    [anon_sym_tableExtension] = ACTIONS(5148),
    [sym_page_keyword] = ACTIONS(5150),
    [anon_sym_pageextension] = ACTIONS(5148),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5148),
    [anon_sym_Pageextension] = ACTIONS(5148),
    [anon_sym_PageExtension] = ACTIONS(5148),
    [anon_sym_pageExtension] = ACTIONS(5148),
    [anon_sym_codeunit] = ACTIONS(5148),
    [anon_sym_CODEUNIT] = ACTIONS(5148),
    [anon_sym_Codeunit] = ACTIONS(5148),
    [anon_sym_CodeUnit] = ACTIONS(5148),
    [anon_sym_COdeunit] = ACTIONS(5148),
    [anon_sym_codeUnit] = ACTIONS(5148),
    [sym_report_keyword] = ACTIONS(5150),
    [anon_sym_reportextension] = ACTIONS(5148),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5148),
    [anon_sym_Reportextension] = ACTIONS(5148),
    [anon_sym_ReportExtension] = ACTIONS(5148),
    [anon_sym_reportExtension] = ACTIONS(5148),
    [sym_query_keyword] = ACTIONS(5148),
    [anon_sym_xmlport] = ACTIONS(5148),
    [anon_sym_XMLPORT] = ACTIONS(5148),
    [anon_sym_Xmlport] = ACTIONS(5148),
    [anon_sym_XMLport] = ACTIONS(5148),
    [anon_sym_XMLPort] = ACTIONS(5148),
    [anon_sym_XmlPort] = ACTIONS(5148),
    [anon_sym_enum] = ACTIONS(5150),
    [anon_sym_ENUM] = ACTIONS(5150),
    [anon_sym_Enum] = ACTIONS(5150),
    [anon_sym_eNUM] = ACTIONS(5148),
    [anon_sym_eNum] = ACTIONS(5148),
    [anon_sym_ENum] = ACTIONS(5148),
    [anon_sym_enumextension] = ACTIONS(5148),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5148),
    [anon_sym_Enumextension] = ACTIONS(5148),
    [anon_sym_EnumExtension] = ACTIONS(5148),
    [anon_sym_enumExtension] = ACTIONS(5148),
    [sym_interface_keyword] = ACTIONS(5148),
    [anon_sym_controladdin] = ACTIONS(5148),
    [anon_sym_CONTROLADDIN] = ACTIONS(5148),
    [anon_sym_Controladdin] = ACTIONS(5148),
    [anon_sym_ControlAddIn] = ACTIONS(5148),
    [anon_sym_ControlAddin] = ACTIONS(5148),
    [anon_sym_controlAddIn] = ACTIONS(5148),
    [anon_sym_controlAddin] = ACTIONS(5148),
    [anon_sym_dotnet] = ACTIONS(5148),
    [anon_sym_DOTNET] = ACTIONS(5148),
    [anon_sym_Dotnet] = ACTIONS(5148),
    [anon_sym_DotNet] = ACTIONS(5148),
    [anon_sym_dotNet] = ACTIONS(5148),
    [sym_profile_keyword] = ACTIONS(5150),
    [anon_sym_profileextension] = ACTIONS(5148),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5148),
    [anon_sym_Profileextension] = ACTIONS(5148),
    [anon_sym_ProfileExtension] = ACTIONS(5148),
    [anon_sym_profileExtension] = ACTIONS(5148),
    [anon_sym_permissionset] = ACTIONS(5150),
    [anon_sym_PERMISSIONSET] = ACTIONS(5150),
    [anon_sym_Permissionset] = ACTIONS(5150),
    [anon_sym_PermissionSet] = ACTIONS(5150),
    [anon_sym_permissionSet] = ACTIONS(5150),
    [anon_sym_permissionsetextension] = ACTIONS(5148),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5148),
    [anon_sym_Permissionsetextension] = ACTIONS(5148),
    [anon_sym_PermissionSetExtension] = ACTIONS(5148),
    [anon_sym_permissionSetExtension] = ACTIONS(5148),
    [sym_entitlement_keyword] = ACTIONS(5148),
    [anon_sym_pagecustomization] = ACTIONS(5148),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5148),
    [anon_sym_Pagecustomization] = ACTIONS(5148),
    [anon_sym_PageCustomization] = ACTIONS(5148),
    [anon_sym_pageCustomization] = ACTIONS(5148),
    [sym_using_keyword] = ACTIONS(5148),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5148),
    [sym_preproc_close] = ACTIONS(5148),
  },
  [STATE(2001)] = {
    [anon_sym_POUNDif] = ACTIONS(5152),
    [anon_sym_POUNDIF] = ACTIONS(5152),
    [anon_sym_POUNDIf] = ACTIONS(5152),
    [anon_sym_POUNDelif] = ACTIONS(5152),
    [anon_sym_POUNDELIF] = ACTIONS(5152),
    [anon_sym_POUNDElif] = ACTIONS(5152),
    [anon_sym_POUNDelse] = ACTIONS(5152),
    [anon_sym_POUNDELSE] = ACTIONS(5152),
    [anon_sym_POUNDElse] = ACTIONS(5152),
    [anon_sym_POUNDendif] = ACTIONS(5152),
    [anon_sym_POUNDENDIF] = ACTIONS(5152),
    [anon_sym_POUNDEndif] = ACTIONS(5152),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5154),
    [anon_sym_tableextension] = ACTIONS(5152),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5152),
    [anon_sym_Tableextension] = ACTIONS(5152),
    [anon_sym_TableExtension] = ACTIONS(5152),
    [anon_sym_tableExtension] = ACTIONS(5152),
    [sym_page_keyword] = ACTIONS(5154),
    [anon_sym_pageextension] = ACTIONS(5152),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5152),
    [anon_sym_Pageextension] = ACTIONS(5152),
    [anon_sym_PageExtension] = ACTIONS(5152),
    [anon_sym_pageExtension] = ACTIONS(5152),
    [anon_sym_codeunit] = ACTIONS(5152),
    [anon_sym_CODEUNIT] = ACTIONS(5152),
    [anon_sym_Codeunit] = ACTIONS(5152),
    [anon_sym_CodeUnit] = ACTIONS(5152),
    [anon_sym_COdeunit] = ACTIONS(5152),
    [anon_sym_codeUnit] = ACTIONS(5152),
    [sym_report_keyword] = ACTIONS(5154),
    [anon_sym_reportextension] = ACTIONS(5152),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5152),
    [anon_sym_Reportextension] = ACTIONS(5152),
    [anon_sym_ReportExtension] = ACTIONS(5152),
    [anon_sym_reportExtension] = ACTIONS(5152),
    [sym_query_keyword] = ACTIONS(5152),
    [anon_sym_xmlport] = ACTIONS(5152),
    [anon_sym_XMLPORT] = ACTIONS(5152),
    [anon_sym_Xmlport] = ACTIONS(5152),
    [anon_sym_XMLport] = ACTIONS(5152),
    [anon_sym_XMLPort] = ACTIONS(5152),
    [anon_sym_XmlPort] = ACTIONS(5152),
    [anon_sym_enum] = ACTIONS(5154),
    [anon_sym_ENUM] = ACTIONS(5154),
    [anon_sym_Enum] = ACTIONS(5154),
    [anon_sym_eNUM] = ACTIONS(5152),
    [anon_sym_eNum] = ACTIONS(5152),
    [anon_sym_ENum] = ACTIONS(5152),
    [anon_sym_enumextension] = ACTIONS(5152),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5152),
    [anon_sym_Enumextension] = ACTIONS(5152),
    [anon_sym_EnumExtension] = ACTIONS(5152),
    [anon_sym_enumExtension] = ACTIONS(5152),
    [sym_interface_keyword] = ACTIONS(5152),
    [anon_sym_controladdin] = ACTIONS(5152),
    [anon_sym_CONTROLADDIN] = ACTIONS(5152),
    [anon_sym_Controladdin] = ACTIONS(5152),
    [anon_sym_ControlAddIn] = ACTIONS(5152),
    [anon_sym_ControlAddin] = ACTIONS(5152),
    [anon_sym_controlAddIn] = ACTIONS(5152),
    [anon_sym_controlAddin] = ACTIONS(5152),
    [anon_sym_dotnet] = ACTIONS(5152),
    [anon_sym_DOTNET] = ACTIONS(5152),
    [anon_sym_Dotnet] = ACTIONS(5152),
    [anon_sym_DotNet] = ACTIONS(5152),
    [anon_sym_dotNet] = ACTIONS(5152),
    [sym_profile_keyword] = ACTIONS(5154),
    [anon_sym_profileextension] = ACTIONS(5152),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5152),
    [anon_sym_Profileextension] = ACTIONS(5152),
    [anon_sym_ProfileExtension] = ACTIONS(5152),
    [anon_sym_profileExtension] = ACTIONS(5152),
    [anon_sym_permissionset] = ACTIONS(5154),
    [anon_sym_PERMISSIONSET] = ACTIONS(5154),
    [anon_sym_Permissionset] = ACTIONS(5154),
    [anon_sym_PermissionSet] = ACTIONS(5154),
    [anon_sym_permissionSet] = ACTIONS(5154),
    [anon_sym_permissionsetextension] = ACTIONS(5152),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5152),
    [anon_sym_Permissionsetextension] = ACTIONS(5152),
    [anon_sym_PermissionSetExtension] = ACTIONS(5152),
    [anon_sym_permissionSetExtension] = ACTIONS(5152),
    [sym_entitlement_keyword] = ACTIONS(5152),
    [anon_sym_pagecustomization] = ACTIONS(5152),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5152),
    [anon_sym_Pagecustomization] = ACTIONS(5152),
    [anon_sym_PageCustomization] = ACTIONS(5152),
    [anon_sym_pageCustomization] = ACTIONS(5152),
    [sym_using_keyword] = ACTIONS(5152),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5152),
    [sym_preproc_close] = ACTIONS(5152),
  },
  [STATE(2002)] = {
    [anon_sym_POUNDif] = ACTIONS(5156),
    [anon_sym_POUNDIF] = ACTIONS(5156),
    [anon_sym_POUNDIf] = ACTIONS(5156),
    [anon_sym_POUNDelif] = ACTIONS(5156),
    [anon_sym_POUNDELIF] = ACTIONS(5156),
    [anon_sym_POUNDElif] = ACTIONS(5156),
    [anon_sym_POUNDelse] = ACTIONS(5156),
    [anon_sym_POUNDELSE] = ACTIONS(5156),
    [anon_sym_POUNDElse] = ACTIONS(5156),
    [anon_sym_POUNDendif] = ACTIONS(5156),
    [anon_sym_POUNDENDIF] = ACTIONS(5156),
    [anon_sym_POUNDEndif] = ACTIONS(5156),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5158),
    [anon_sym_tableextension] = ACTIONS(5156),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5156),
    [anon_sym_Tableextension] = ACTIONS(5156),
    [anon_sym_TableExtension] = ACTIONS(5156),
    [anon_sym_tableExtension] = ACTIONS(5156),
    [sym_page_keyword] = ACTIONS(5158),
    [anon_sym_pageextension] = ACTIONS(5156),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5156),
    [anon_sym_Pageextension] = ACTIONS(5156),
    [anon_sym_PageExtension] = ACTIONS(5156),
    [anon_sym_pageExtension] = ACTIONS(5156),
    [anon_sym_codeunit] = ACTIONS(5156),
    [anon_sym_CODEUNIT] = ACTIONS(5156),
    [anon_sym_Codeunit] = ACTIONS(5156),
    [anon_sym_CodeUnit] = ACTIONS(5156),
    [anon_sym_COdeunit] = ACTIONS(5156),
    [anon_sym_codeUnit] = ACTIONS(5156),
    [sym_report_keyword] = ACTIONS(5158),
    [anon_sym_reportextension] = ACTIONS(5156),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5156),
    [anon_sym_Reportextension] = ACTIONS(5156),
    [anon_sym_ReportExtension] = ACTIONS(5156),
    [anon_sym_reportExtension] = ACTIONS(5156),
    [sym_query_keyword] = ACTIONS(5156),
    [anon_sym_xmlport] = ACTIONS(5156),
    [anon_sym_XMLPORT] = ACTIONS(5156),
    [anon_sym_Xmlport] = ACTIONS(5156),
    [anon_sym_XMLport] = ACTIONS(5156),
    [anon_sym_XMLPort] = ACTIONS(5156),
    [anon_sym_XmlPort] = ACTIONS(5156),
    [anon_sym_enum] = ACTIONS(5158),
    [anon_sym_ENUM] = ACTIONS(5158),
    [anon_sym_Enum] = ACTIONS(5158),
    [anon_sym_eNUM] = ACTIONS(5156),
    [anon_sym_eNum] = ACTIONS(5156),
    [anon_sym_ENum] = ACTIONS(5156),
    [anon_sym_enumextension] = ACTIONS(5156),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5156),
    [anon_sym_Enumextension] = ACTIONS(5156),
    [anon_sym_EnumExtension] = ACTIONS(5156),
    [anon_sym_enumExtension] = ACTIONS(5156),
    [sym_interface_keyword] = ACTIONS(5156),
    [anon_sym_controladdin] = ACTIONS(5156),
    [anon_sym_CONTROLADDIN] = ACTIONS(5156),
    [anon_sym_Controladdin] = ACTIONS(5156),
    [anon_sym_ControlAddIn] = ACTIONS(5156),
    [anon_sym_ControlAddin] = ACTIONS(5156),
    [anon_sym_controlAddIn] = ACTIONS(5156),
    [anon_sym_controlAddin] = ACTIONS(5156),
    [anon_sym_dotnet] = ACTIONS(5156),
    [anon_sym_DOTNET] = ACTIONS(5156),
    [anon_sym_Dotnet] = ACTIONS(5156),
    [anon_sym_DotNet] = ACTIONS(5156),
    [anon_sym_dotNet] = ACTIONS(5156),
    [sym_profile_keyword] = ACTIONS(5158),
    [anon_sym_profileextension] = ACTIONS(5156),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5156),
    [anon_sym_Profileextension] = ACTIONS(5156),
    [anon_sym_ProfileExtension] = ACTIONS(5156),
    [anon_sym_profileExtension] = ACTIONS(5156),
    [anon_sym_permissionset] = ACTIONS(5158),
    [anon_sym_PERMISSIONSET] = ACTIONS(5158),
    [anon_sym_Permissionset] = ACTIONS(5158),
    [anon_sym_PermissionSet] = ACTIONS(5158),
    [anon_sym_permissionSet] = ACTIONS(5158),
    [anon_sym_permissionsetextension] = ACTIONS(5156),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5156),
    [anon_sym_Permissionsetextension] = ACTIONS(5156),
    [anon_sym_PermissionSetExtension] = ACTIONS(5156),
    [anon_sym_permissionSetExtension] = ACTIONS(5156),
    [sym_entitlement_keyword] = ACTIONS(5156),
    [anon_sym_pagecustomization] = ACTIONS(5156),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5156),
    [anon_sym_Pagecustomization] = ACTIONS(5156),
    [anon_sym_PageCustomization] = ACTIONS(5156),
    [anon_sym_pageCustomization] = ACTIONS(5156),
    [sym_using_keyword] = ACTIONS(5156),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5156),
    [sym_preproc_close] = ACTIONS(5156),
  },
  [STATE(2003)] = {
    [anon_sym_POUNDif] = ACTIONS(5160),
    [anon_sym_POUNDIF] = ACTIONS(5160),
    [anon_sym_POUNDIf] = ACTIONS(5160),
    [anon_sym_POUNDelif] = ACTIONS(5160),
    [anon_sym_POUNDELIF] = ACTIONS(5160),
    [anon_sym_POUNDElif] = ACTIONS(5160),
    [anon_sym_POUNDelse] = ACTIONS(5160),
    [anon_sym_POUNDELSE] = ACTIONS(5160),
    [anon_sym_POUNDElse] = ACTIONS(5160),
    [anon_sym_POUNDendif] = ACTIONS(5160),
    [anon_sym_POUNDENDIF] = ACTIONS(5160),
    [anon_sym_POUNDEndif] = ACTIONS(5160),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5162),
    [anon_sym_tableextension] = ACTIONS(5160),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5160),
    [anon_sym_Tableextension] = ACTIONS(5160),
    [anon_sym_TableExtension] = ACTIONS(5160),
    [anon_sym_tableExtension] = ACTIONS(5160),
    [sym_page_keyword] = ACTIONS(5162),
    [anon_sym_pageextension] = ACTIONS(5160),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5160),
    [anon_sym_Pageextension] = ACTIONS(5160),
    [anon_sym_PageExtension] = ACTIONS(5160),
    [anon_sym_pageExtension] = ACTIONS(5160),
    [anon_sym_codeunit] = ACTIONS(5160),
    [anon_sym_CODEUNIT] = ACTIONS(5160),
    [anon_sym_Codeunit] = ACTIONS(5160),
    [anon_sym_CodeUnit] = ACTIONS(5160),
    [anon_sym_COdeunit] = ACTIONS(5160),
    [anon_sym_codeUnit] = ACTIONS(5160),
    [sym_report_keyword] = ACTIONS(5162),
    [anon_sym_reportextension] = ACTIONS(5160),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5160),
    [anon_sym_Reportextension] = ACTIONS(5160),
    [anon_sym_ReportExtension] = ACTIONS(5160),
    [anon_sym_reportExtension] = ACTIONS(5160),
    [sym_query_keyword] = ACTIONS(5160),
    [anon_sym_xmlport] = ACTIONS(5160),
    [anon_sym_XMLPORT] = ACTIONS(5160),
    [anon_sym_Xmlport] = ACTIONS(5160),
    [anon_sym_XMLport] = ACTIONS(5160),
    [anon_sym_XMLPort] = ACTIONS(5160),
    [anon_sym_XmlPort] = ACTIONS(5160),
    [anon_sym_enum] = ACTIONS(5162),
    [anon_sym_ENUM] = ACTIONS(5162),
    [anon_sym_Enum] = ACTIONS(5162),
    [anon_sym_eNUM] = ACTIONS(5160),
    [anon_sym_eNum] = ACTIONS(5160),
    [anon_sym_ENum] = ACTIONS(5160),
    [anon_sym_enumextension] = ACTIONS(5160),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5160),
    [anon_sym_Enumextension] = ACTIONS(5160),
    [anon_sym_EnumExtension] = ACTIONS(5160),
    [anon_sym_enumExtension] = ACTIONS(5160),
    [sym_interface_keyword] = ACTIONS(5160),
    [anon_sym_controladdin] = ACTIONS(5160),
    [anon_sym_CONTROLADDIN] = ACTIONS(5160),
    [anon_sym_Controladdin] = ACTIONS(5160),
    [anon_sym_ControlAddIn] = ACTIONS(5160),
    [anon_sym_ControlAddin] = ACTIONS(5160),
    [anon_sym_controlAddIn] = ACTIONS(5160),
    [anon_sym_controlAddin] = ACTIONS(5160),
    [anon_sym_dotnet] = ACTIONS(5160),
    [anon_sym_DOTNET] = ACTIONS(5160),
    [anon_sym_Dotnet] = ACTIONS(5160),
    [anon_sym_DotNet] = ACTIONS(5160),
    [anon_sym_dotNet] = ACTIONS(5160),
    [sym_profile_keyword] = ACTIONS(5162),
    [anon_sym_profileextension] = ACTIONS(5160),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5160),
    [anon_sym_Profileextension] = ACTIONS(5160),
    [anon_sym_ProfileExtension] = ACTIONS(5160),
    [anon_sym_profileExtension] = ACTIONS(5160),
    [anon_sym_permissionset] = ACTIONS(5162),
    [anon_sym_PERMISSIONSET] = ACTIONS(5162),
    [anon_sym_Permissionset] = ACTIONS(5162),
    [anon_sym_PermissionSet] = ACTIONS(5162),
    [anon_sym_permissionSet] = ACTIONS(5162),
    [anon_sym_permissionsetextension] = ACTIONS(5160),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5160),
    [anon_sym_Permissionsetextension] = ACTIONS(5160),
    [anon_sym_PermissionSetExtension] = ACTIONS(5160),
    [anon_sym_permissionSetExtension] = ACTIONS(5160),
    [sym_entitlement_keyword] = ACTIONS(5160),
    [anon_sym_pagecustomization] = ACTIONS(5160),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5160),
    [anon_sym_Pagecustomization] = ACTIONS(5160),
    [anon_sym_PageCustomization] = ACTIONS(5160),
    [anon_sym_pageCustomization] = ACTIONS(5160),
    [sym_using_keyword] = ACTIONS(5160),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5160),
    [sym_preproc_close] = ACTIONS(5160),
  },
  [STATE(2004)] = {
    [anon_sym_POUNDif] = ACTIONS(5164),
    [anon_sym_POUNDIF] = ACTIONS(5164),
    [anon_sym_POUNDIf] = ACTIONS(5164),
    [anon_sym_POUNDelif] = ACTIONS(5164),
    [anon_sym_POUNDELIF] = ACTIONS(5164),
    [anon_sym_POUNDElif] = ACTIONS(5164),
    [anon_sym_POUNDelse] = ACTIONS(5164),
    [anon_sym_POUNDELSE] = ACTIONS(5164),
    [anon_sym_POUNDElse] = ACTIONS(5164),
    [anon_sym_POUNDendif] = ACTIONS(5164),
    [anon_sym_POUNDENDIF] = ACTIONS(5164),
    [anon_sym_POUNDEndif] = ACTIONS(5164),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5166),
    [anon_sym_tableextension] = ACTIONS(5164),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5164),
    [anon_sym_Tableextension] = ACTIONS(5164),
    [anon_sym_TableExtension] = ACTIONS(5164),
    [anon_sym_tableExtension] = ACTIONS(5164),
    [sym_page_keyword] = ACTIONS(5166),
    [anon_sym_pageextension] = ACTIONS(5164),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5164),
    [anon_sym_Pageextension] = ACTIONS(5164),
    [anon_sym_PageExtension] = ACTIONS(5164),
    [anon_sym_pageExtension] = ACTIONS(5164),
    [anon_sym_codeunit] = ACTIONS(5164),
    [anon_sym_CODEUNIT] = ACTIONS(5164),
    [anon_sym_Codeunit] = ACTIONS(5164),
    [anon_sym_CodeUnit] = ACTIONS(5164),
    [anon_sym_COdeunit] = ACTIONS(5164),
    [anon_sym_codeUnit] = ACTIONS(5164),
    [sym_report_keyword] = ACTIONS(5166),
    [anon_sym_reportextension] = ACTIONS(5164),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5164),
    [anon_sym_Reportextension] = ACTIONS(5164),
    [anon_sym_ReportExtension] = ACTIONS(5164),
    [anon_sym_reportExtension] = ACTIONS(5164),
    [sym_query_keyword] = ACTIONS(5164),
    [anon_sym_xmlport] = ACTIONS(5164),
    [anon_sym_XMLPORT] = ACTIONS(5164),
    [anon_sym_Xmlport] = ACTIONS(5164),
    [anon_sym_XMLport] = ACTIONS(5164),
    [anon_sym_XMLPort] = ACTIONS(5164),
    [anon_sym_XmlPort] = ACTIONS(5164),
    [anon_sym_enum] = ACTIONS(5166),
    [anon_sym_ENUM] = ACTIONS(5166),
    [anon_sym_Enum] = ACTIONS(5166),
    [anon_sym_eNUM] = ACTIONS(5164),
    [anon_sym_eNum] = ACTIONS(5164),
    [anon_sym_ENum] = ACTIONS(5164),
    [anon_sym_enumextension] = ACTIONS(5164),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5164),
    [anon_sym_Enumextension] = ACTIONS(5164),
    [anon_sym_EnumExtension] = ACTIONS(5164),
    [anon_sym_enumExtension] = ACTIONS(5164),
    [sym_interface_keyword] = ACTIONS(5164),
    [anon_sym_controladdin] = ACTIONS(5164),
    [anon_sym_CONTROLADDIN] = ACTIONS(5164),
    [anon_sym_Controladdin] = ACTIONS(5164),
    [anon_sym_ControlAddIn] = ACTIONS(5164),
    [anon_sym_ControlAddin] = ACTIONS(5164),
    [anon_sym_controlAddIn] = ACTIONS(5164),
    [anon_sym_controlAddin] = ACTIONS(5164),
    [anon_sym_dotnet] = ACTIONS(5164),
    [anon_sym_DOTNET] = ACTIONS(5164),
    [anon_sym_Dotnet] = ACTIONS(5164),
    [anon_sym_DotNet] = ACTIONS(5164),
    [anon_sym_dotNet] = ACTIONS(5164),
    [sym_profile_keyword] = ACTIONS(5166),
    [anon_sym_profileextension] = ACTIONS(5164),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5164),
    [anon_sym_Profileextension] = ACTIONS(5164),
    [anon_sym_ProfileExtension] = ACTIONS(5164),
    [anon_sym_profileExtension] = ACTIONS(5164),
    [anon_sym_permissionset] = ACTIONS(5166),
    [anon_sym_PERMISSIONSET] = ACTIONS(5166),
    [anon_sym_Permissionset] = ACTIONS(5166),
    [anon_sym_PermissionSet] = ACTIONS(5166),
    [anon_sym_permissionSet] = ACTIONS(5166),
    [anon_sym_permissionsetextension] = ACTIONS(5164),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5164),
    [anon_sym_Permissionsetextension] = ACTIONS(5164),
    [anon_sym_PermissionSetExtension] = ACTIONS(5164),
    [anon_sym_permissionSetExtension] = ACTIONS(5164),
    [sym_entitlement_keyword] = ACTIONS(5164),
    [anon_sym_pagecustomization] = ACTIONS(5164),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5164),
    [anon_sym_Pagecustomization] = ACTIONS(5164),
    [anon_sym_PageCustomization] = ACTIONS(5164),
    [anon_sym_pageCustomization] = ACTIONS(5164),
    [sym_using_keyword] = ACTIONS(5164),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5164),
    [sym_preproc_close] = ACTIONS(5164),
  },
  [STATE(2005)] = {
    [anon_sym_POUNDif] = ACTIONS(5168),
    [anon_sym_POUNDIF] = ACTIONS(5168),
    [anon_sym_POUNDIf] = ACTIONS(5168),
    [anon_sym_POUNDelif] = ACTIONS(5168),
    [anon_sym_POUNDELIF] = ACTIONS(5168),
    [anon_sym_POUNDElif] = ACTIONS(5168),
    [anon_sym_POUNDelse] = ACTIONS(5168),
    [anon_sym_POUNDELSE] = ACTIONS(5168),
    [anon_sym_POUNDElse] = ACTIONS(5168),
    [anon_sym_POUNDendif] = ACTIONS(5168),
    [anon_sym_POUNDENDIF] = ACTIONS(5168),
    [anon_sym_POUNDEndif] = ACTIONS(5168),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5170),
    [anon_sym_tableextension] = ACTIONS(5168),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5168),
    [anon_sym_Tableextension] = ACTIONS(5168),
    [anon_sym_TableExtension] = ACTIONS(5168),
    [anon_sym_tableExtension] = ACTIONS(5168),
    [sym_page_keyword] = ACTIONS(5170),
    [anon_sym_pageextension] = ACTIONS(5168),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5168),
    [anon_sym_Pageextension] = ACTIONS(5168),
    [anon_sym_PageExtension] = ACTIONS(5168),
    [anon_sym_pageExtension] = ACTIONS(5168),
    [anon_sym_codeunit] = ACTIONS(5168),
    [anon_sym_CODEUNIT] = ACTIONS(5168),
    [anon_sym_Codeunit] = ACTIONS(5168),
    [anon_sym_CodeUnit] = ACTIONS(5168),
    [anon_sym_COdeunit] = ACTIONS(5168),
    [anon_sym_codeUnit] = ACTIONS(5168),
    [sym_report_keyword] = ACTIONS(5170),
    [anon_sym_reportextension] = ACTIONS(5168),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5168),
    [anon_sym_Reportextension] = ACTIONS(5168),
    [anon_sym_ReportExtension] = ACTIONS(5168),
    [anon_sym_reportExtension] = ACTIONS(5168),
    [sym_query_keyword] = ACTIONS(5168),
    [anon_sym_xmlport] = ACTIONS(5168),
    [anon_sym_XMLPORT] = ACTIONS(5168),
    [anon_sym_Xmlport] = ACTIONS(5168),
    [anon_sym_XMLport] = ACTIONS(5168),
    [anon_sym_XMLPort] = ACTIONS(5168),
    [anon_sym_XmlPort] = ACTIONS(5168),
    [anon_sym_enum] = ACTIONS(5170),
    [anon_sym_ENUM] = ACTIONS(5170),
    [anon_sym_Enum] = ACTIONS(5170),
    [anon_sym_eNUM] = ACTIONS(5168),
    [anon_sym_eNum] = ACTIONS(5168),
    [anon_sym_ENum] = ACTIONS(5168),
    [anon_sym_enumextension] = ACTIONS(5168),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5168),
    [anon_sym_Enumextension] = ACTIONS(5168),
    [anon_sym_EnumExtension] = ACTIONS(5168),
    [anon_sym_enumExtension] = ACTIONS(5168),
    [sym_interface_keyword] = ACTIONS(5168),
    [anon_sym_controladdin] = ACTIONS(5168),
    [anon_sym_CONTROLADDIN] = ACTIONS(5168),
    [anon_sym_Controladdin] = ACTIONS(5168),
    [anon_sym_ControlAddIn] = ACTIONS(5168),
    [anon_sym_ControlAddin] = ACTIONS(5168),
    [anon_sym_controlAddIn] = ACTIONS(5168),
    [anon_sym_controlAddin] = ACTIONS(5168),
    [anon_sym_dotnet] = ACTIONS(5168),
    [anon_sym_DOTNET] = ACTIONS(5168),
    [anon_sym_Dotnet] = ACTIONS(5168),
    [anon_sym_DotNet] = ACTIONS(5168),
    [anon_sym_dotNet] = ACTIONS(5168),
    [sym_profile_keyword] = ACTIONS(5170),
    [anon_sym_profileextension] = ACTIONS(5168),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5168),
    [anon_sym_Profileextension] = ACTIONS(5168),
    [anon_sym_ProfileExtension] = ACTIONS(5168),
    [anon_sym_profileExtension] = ACTIONS(5168),
    [anon_sym_permissionset] = ACTIONS(5170),
    [anon_sym_PERMISSIONSET] = ACTIONS(5170),
    [anon_sym_Permissionset] = ACTIONS(5170),
    [anon_sym_PermissionSet] = ACTIONS(5170),
    [anon_sym_permissionSet] = ACTIONS(5170),
    [anon_sym_permissionsetextension] = ACTIONS(5168),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5168),
    [anon_sym_Permissionsetextension] = ACTIONS(5168),
    [anon_sym_PermissionSetExtension] = ACTIONS(5168),
    [anon_sym_permissionSetExtension] = ACTIONS(5168),
    [sym_entitlement_keyword] = ACTIONS(5168),
    [anon_sym_pagecustomization] = ACTIONS(5168),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5168),
    [anon_sym_Pagecustomization] = ACTIONS(5168),
    [anon_sym_PageCustomization] = ACTIONS(5168),
    [anon_sym_pageCustomization] = ACTIONS(5168),
    [sym_using_keyword] = ACTIONS(5168),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5168),
    [sym_preproc_close] = ACTIONS(5168),
  },
  [STATE(2006)] = {
    [anon_sym_POUNDif] = ACTIONS(5172),
    [anon_sym_POUNDIF] = ACTIONS(5172),
    [anon_sym_POUNDIf] = ACTIONS(5172),
    [anon_sym_POUNDelif] = ACTIONS(5172),
    [anon_sym_POUNDELIF] = ACTIONS(5172),
    [anon_sym_POUNDElif] = ACTIONS(5172),
    [anon_sym_POUNDelse] = ACTIONS(5172),
    [anon_sym_POUNDELSE] = ACTIONS(5172),
    [anon_sym_POUNDElse] = ACTIONS(5172),
    [anon_sym_POUNDendif] = ACTIONS(5172),
    [anon_sym_POUNDENDIF] = ACTIONS(5172),
    [anon_sym_POUNDEndif] = ACTIONS(5172),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5174),
    [anon_sym_tableextension] = ACTIONS(5172),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5172),
    [anon_sym_Tableextension] = ACTIONS(5172),
    [anon_sym_TableExtension] = ACTIONS(5172),
    [anon_sym_tableExtension] = ACTIONS(5172),
    [sym_page_keyword] = ACTIONS(5174),
    [anon_sym_pageextension] = ACTIONS(5172),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5172),
    [anon_sym_Pageextension] = ACTIONS(5172),
    [anon_sym_PageExtension] = ACTIONS(5172),
    [anon_sym_pageExtension] = ACTIONS(5172),
    [anon_sym_codeunit] = ACTIONS(5172),
    [anon_sym_CODEUNIT] = ACTIONS(5172),
    [anon_sym_Codeunit] = ACTIONS(5172),
    [anon_sym_CodeUnit] = ACTIONS(5172),
    [anon_sym_COdeunit] = ACTIONS(5172),
    [anon_sym_codeUnit] = ACTIONS(5172),
    [sym_report_keyword] = ACTIONS(5174),
    [anon_sym_reportextension] = ACTIONS(5172),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5172),
    [anon_sym_Reportextension] = ACTIONS(5172),
    [anon_sym_ReportExtension] = ACTIONS(5172),
    [anon_sym_reportExtension] = ACTIONS(5172),
    [sym_query_keyword] = ACTIONS(5172),
    [anon_sym_xmlport] = ACTIONS(5172),
    [anon_sym_XMLPORT] = ACTIONS(5172),
    [anon_sym_Xmlport] = ACTIONS(5172),
    [anon_sym_XMLport] = ACTIONS(5172),
    [anon_sym_XMLPort] = ACTIONS(5172),
    [anon_sym_XmlPort] = ACTIONS(5172),
    [anon_sym_enum] = ACTIONS(5174),
    [anon_sym_ENUM] = ACTIONS(5174),
    [anon_sym_Enum] = ACTIONS(5174),
    [anon_sym_eNUM] = ACTIONS(5172),
    [anon_sym_eNum] = ACTIONS(5172),
    [anon_sym_ENum] = ACTIONS(5172),
    [anon_sym_enumextension] = ACTIONS(5172),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5172),
    [anon_sym_Enumextension] = ACTIONS(5172),
    [anon_sym_EnumExtension] = ACTIONS(5172),
    [anon_sym_enumExtension] = ACTIONS(5172),
    [sym_interface_keyword] = ACTIONS(5172),
    [anon_sym_controladdin] = ACTIONS(5172),
    [anon_sym_CONTROLADDIN] = ACTIONS(5172),
    [anon_sym_Controladdin] = ACTIONS(5172),
    [anon_sym_ControlAddIn] = ACTIONS(5172),
    [anon_sym_ControlAddin] = ACTIONS(5172),
    [anon_sym_controlAddIn] = ACTIONS(5172),
    [anon_sym_controlAddin] = ACTIONS(5172),
    [anon_sym_dotnet] = ACTIONS(5172),
    [anon_sym_DOTNET] = ACTIONS(5172),
    [anon_sym_Dotnet] = ACTIONS(5172),
    [anon_sym_DotNet] = ACTIONS(5172),
    [anon_sym_dotNet] = ACTIONS(5172),
    [sym_profile_keyword] = ACTIONS(5174),
    [anon_sym_profileextension] = ACTIONS(5172),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5172),
    [anon_sym_Profileextension] = ACTIONS(5172),
    [anon_sym_ProfileExtension] = ACTIONS(5172),
    [anon_sym_profileExtension] = ACTIONS(5172),
    [anon_sym_permissionset] = ACTIONS(5174),
    [anon_sym_PERMISSIONSET] = ACTIONS(5174),
    [anon_sym_Permissionset] = ACTIONS(5174),
    [anon_sym_PermissionSet] = ACTIONS(5174),
    [anon_sym_permissionSet] = ACTIONS(5174),
    [anon_sym_permissionsetextension] = ACTIONS(5172),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5172),
    [anon_sym_Permissionsetextension] = ACTIONS(5172),
    [anon_sym_PermissionSetExtension] = ACTIONS(5172),
    [anon_sym_permissionSetExtension] = ACTIONS(5172),
    [sym_entitlement_keyword] = ACTIONS(5172),
    [anon_sym_pagecustomization] = ACTIONS(5172),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5172),
    [anon_sym_Pagecustomization] = ACTIONS(5172),
    [anon_sym_PageCustomization] = ACTIONS(5172),
    [anon_sym_pageCustomization] = ACTIONS(5172),
    [sym_using_keyword] = ACTIONS(5172),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5172),
    [sym_preproc_close] = ACTIONS(5172),
  },
  [STATE(2007)] = {
    [anon_sym_POUNDif] = ACTIONS(5176),
    [anon_sym_POUNDIF] = ACTIONS(5176),
    [anon_sym_POUNDIf] = ACTIONS(5176),
    [anon_sym_POUNDelif] = ACTIONS(5176),
    [anon_sym_POUNDELIF] = ACTIONS(5176),
    [anon_sym_POUNDElif] = ACTIONS(5176),
    [anon_sym_POUNDelse] = ACTIONS(5176),
    [anon_sym_POUNDELSE] = ACTIONS(5176),
    [anon_sym_POUNDElse] = ACTIONS(5176),
    [anon_sym_POUNDendif] = ACTIONS(5176),
    [anon_sym_POUNDENDIF] = ACTIONS(5176),
    [anon_sym_POUNDEndif] = ACTIONS(5176),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5178),
    [anon_sym_tableextension] = ACTIONS(5176),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5176),
    [anon_sym_Tableextension] = ACTIONS(5176),
    [anon_sym_TableExtension] = ACTIONS(5176),
    [anon_sym_tableExtension] = ACTIONS(5176),
    [sym_page_keyword] = ACTIONS(5178),
    [anon_sym_pageextension] = ACTIONS(5176),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5176),
    [anon_sym_Pageextension] = ACTIONS(5176),
    [anon_sym_PageExtension] = ACTIONS(5176),
    [anon_sym_pageExtension] = ACTIONS(5176),
    [anon_sym_codeunit] = ACTIONS(5176),
    [anon_sym_CODEUNIT] = ACTIONS(5176),
    [anon_sym_Codeunit] = ACTIONS(5176),
    [anon_sym_CodeUnit] = ACTIONS(5176),
    [anon_sym_COdeunit] = ACTIONS(5176),
    [anon_sym_codeUnit] = ACTIONS(5176),
    [sym_report_keyword] = ACTIONS(5178),
    [anon_sym_reportextension] = ACTIONS(5176),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5176),
    [anon_sym_Reportextension] = ACTIONS(5176),
    [anon_sym_ReportExtension] = ACTIONS(5176),
    [anon_sym_reportExtension] = ACTIONS(5176),
    [sym_query_keyword] = ACTIONS(5176),
    [anon_sym_xmlport] = ACTIONS(5176),
    [anon_sym_XMLPORT] = ACTIONS(5176),
    [anon_sym_Xmlport] = ACTIONS(5176),
    [anon_sym_XMLport] = ACTIONS(5176),
    [anon_sym_XMLPort] = ACTIONS(5176),
    [anon_sym_XmlPort] = ACTIONS(5176),
    [anon_sym_enum] = ACTIONS(5178),
    [anon_sym_ENUM] = ACTIONS(5178),
    [anon_sym_Enum] = ACTIONS(5178),
    [anon_sym_eNUM] = ACTIONS(5176),
    [anon_sym_eNum] = ACTIONS(5176),
    [anon_sym_ENum] = ACTIONS(5176),
    [anon_sym_enumextension] = ACTIONS(5176),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5176),
    [anon_sym_Enumextension] = ACTIONS(5176),
    [anon_sym_EnumExtension] = ACTIONS(5176),
    [anon_sym_enumExtension] = ACTIONS(5176),
    [sym_interface_keyword] = ACTIONS(5176),
    [anon_sym_controladdin] = ACTIONS(5176),
    [anon_sym_CONTROLADDIN] = ACTIONS(5176),
    [anon_sym_Controladdin] = ACTIONS(5176),
    [anon_sym_ControlAddIn] = ACTIONS(5176),
    [anon_sym_ControlAddin] = ACTIONS(5176),
    [anon_sym_controlAddIn] = ACTIONS(5176),
    [anon_sym_controlAddin] = ACTIONS(5176),
    [anon_sym_dotnet] = ACTIONS(5176),
    [anon_sym_DOTNET] = ACTIONS(5176),
    [anon_sym_Dotnet] = ACTIONS(5176),
    [anon_sym_DotNet] = ACTIONS(5176),
    [anon_sym_dotNet] = ACTIONS(5176),
    [sym_profile_keyword] = ACTIONS(5178),
    [anon_sym_profileextension] = ACTIONS(5176),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5176),
    [anon_sym_Profileextension] = ACTIONS(5176),
    [anon_sym_ProfileExtension] = ACTIONS(5176),
    [anon_sym_profileExtension] = ACTIONS(5176),
    [anon_sym_permissionset] = ACTIONS(5178),
    [anon_sym_PERMISSIONSET] = ACTIONS(5178),
    [anon_sym_Permissionset] = ACTIONS(5178),
    [anon_sym_PermissionSet] = ACTIONS(5178),
    [anon_sym_permissionSet] = ACTIONS(5178),
    [anon_sym_permissionsetextension] = ACTIONS(5176),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5176),
    [anon_sym_Permissionsetextension] = ACTIONS(5176),
    [anon_sym_PermissionSetExtension] = ACTIONS(5176),
    [anon_sym_permissionSetExtension] = ACTIONS(5176),
    [sym_entitlement_keyword] = ACTIONS(5176),
    [anon_sym_pagecustomization] = ACTIONS(5176),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5176),
    [anon_sym_Pagecustomization] = ACTIONS(5176),
    [anon_sym_PageCustomization] = ACTIONS(5176),
    [anon_sym_pageCustomization] = ACTIONS(5176),
    [sym_using_keyword] = ACTIONS(5176),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5176),
    [sym_preproc_close] = ACTIONS(5176),
  },
  [STATE(2008)] = {
    [anon_sym_POUNDif] = ACTIONS(5180),
    [anon_sym_POUNDIF] = ACTIONS(5180),
    [anon_sym_POUNDIf] = ACTIONS(5180),
    [anon_sym_POUNDelif] = ACTIONS(5180),
    [anon_sym_POUNDELIF] = ACTIONS(5180),
    [anon_sym_POUNDElif] = ACTIONS(5180),
    [anon_sym_POUNDelse] = ACTIONS(5180),
    [anon_sym_POUNDELSE] = ACTIONS(5180),
    [anon_sym_POUNDElse] = ACTIONS(5180),
    [anon_sym_POUNDendif] = ACTIONS(5180),
    [anon_sym_POUNDENDIF] = ACTIONS(5180),
    [anon_sym_POUNDEndif] = ACTIONS(5180),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5182),
    [anon_sym_tableextension] = ACTIONS(5180),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5180),
    [anon_sym_Tableextension] = ACTIONS(5180),
    [anon_sym_TableExtension] = ACTIONS(5180),
    [anon_sym_tableExtension] = ACTIONS(5180),
    [sym_page_keyword] = ACTIONS(5182),
    [anon_sym_pageextension] = ACTIONS(5180),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5180),
    [anon_sym_Pageextension] = ACTIONS(5180),
    [anon_sym_PageExtension] = ACTIONS(5180),
    [anon_sym_pageExtension] = ACTIONS(5180),
    [anon_sym_codeunit] = ACTIONS(5180),
    [anon_sym_CODEUNIT] = ACTIONS(5180),
    [anon_sym_Codeunit] = ACTIONS(5180),
    [anon_sym_CodeUnit] = ACTIONS(5180),
    [anon_sym_COdeunit] = ACTIONS(5180),
    [anon_sym_codeUnit] = ACTIONS(5180),
    [sym_report_keyword] = ACTIONS(5182),
    [anon_sym_reportextension] = ACTIONS(5180),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5180),
    [anon_sym_Reportextension] = ACTIONS(5180),
    [anon_sym_ReportExtension] = ACTIONS(5180),
    [anon_sym_reportExtension] = ACTIONS(5180),
    [sym_query_keyword] = ACTIONS(5180),
    [anon_sym_xmlport] = ACTIONS(5180),
    [anon_sym_XMLPORT] = ACTIONS(5180),
    [anon_sym_Xmlport] = ACTIONS(5180),
    [anon_sym_XMLport] = ACTIONS(5180),
    [anon_sym_XMLPort] = ACTIONS(5180),
    [anon_sym_XmlPort] = ACTIONS(5180),
    [anon_sym_enum] = ACTIONS(5182),
    [anon_sym_ENUM] = ACTIONS(5182),
    [anon_sym_Enum] = ACTIONS(5182),
    [anon_sym_eNUM] = ACTIONS(5180),
    [anon_sym_eNum] = ACTIONS(5180),
    [anon_sym_ENum] = ACTIONS(5180),
    [anon_sym_enumextension] = ACTIONS(5180),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5180),
    [anon_sym_Enumextension] = ACTIONS(5180),
    [anon_sym_EnumExtension] = ACTIONS(5180),
    [anon_sym_enumExtension] = ACTIONS(5180),
    [sym_interface_keyword] = ACTIONS(5180),
    [anon_sym_controladdin] = ACTIONS(5180),
    [anon_sym_CONTROLADDIN] = ACTIONS(5180),
    [anon_sym_Controladdin] = ACTIONS(5180),
    [anon_sym_ControlAddIn] = ACTIONS(5180),
    [anon_sym_ControlAddin] = ACTIONS(5180),
    [anon_sym_controlAddIn] = ACTIONS(5180),
    [anon_sym_controlAddin] = ACTIONS(5180),
    [anon_sym_dotnet] = ACTIONS(5180),
    [anon_sym_DOTNET] = ACTIONS(5180),
    [anon_sym_Dotnet] = ACTIONS(5180),
    [anon_sym_DotNet] = ACTIONS(5180),
    [anon_sym_dotNet] = ACTIONS(5180),
    [sym_profile_keyword] = ACTIONS(5182),
    [anon_sym_profileextension] = ACTIONS(5180),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5180),
    [anon_sym_Profileextension] = ACTIONS(5180),
    [anon_sym_ProfileExtension] = ACTIONS(5180),
    [anon_sym_profileExtension] = ACTIONS(5180),
    [anon_sym_permissionset] = ACTIONS(5182),
    [anon_sym_PERMISSIONSET] = ACTIONS(5182),
    [anon_sym_Permissionset] = ACTIONS(5182),
    [anon_sym_PermissionSet] = ACTIONS(5182),
    [anon_sym_permissionSet] = ACTIONS(5182),
    [anon_sym_permissionsetextension] = ACTIONS(5180),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5180),
    [anon_sym_Permissionsetextension] = ACTIONS(5180),
    [anon_sym_PermissionSetExtension] = ACTIONS(5180),
    [anon_sym_permissionSetExtension] = ACTIONS(5180),
    [sym_entitlement_keyword] = ACTIONS(5180),
    [anon_sym_pagecustomization] = ACTIONS(5180),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5180),
    [anon_sym_Pagecustomization] = ACTIONS(5180),
    [anon_sym_PageCustomization] = ACTIONS(5180),
    [anon_sym_pageCustomization] = ACTIONS(5180),
    [sym_using_keyword] = ACTIONS(5180),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5180),
    [sym_preproc_close] = ACTIONS(5180),
  },
  [STATE(2009)] = {
    [anon_sym_POUNDif] = ACTIONS(5184),
    [anon_sym_POUNDIF] = ACTIONS(5184),
    [anon_sym_POUNDIf] = ACTIONS(5184),
    [anon_sym_POUNDelif] = ACTIONS(5184),
    [anon_sym_POUNDELIF] = ACTIONS(5184),
    [anon_sym_POUNDElif] = ACTIONS(5184),
    [anon_sym_POUNDelse] = ACTIONS(5184),
    [anon_sym_POUNDELSE] = ACTIONS(5184),
    [anon_sym_POUNDElse] = ACTIONS(5184),
    [anon_sym_POUNDendif] = ACTIONS(5184),
    [anon_sym_POUNDENDIF] = ACTIONS(5184),
    [anon_sym_POUNDEndif] = ACTIONS(5184),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5186),
    [anon_sym_tableextension] = ACTIONS(5184),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5184),
    [anon_sym_Tableextension] = ACTIONS(5184),
    [anon_sym_TableExtension] = ACTIONS(5184),
    [anon_sym_tableExtension] = ACTIONS(5184),
    [sym_page_keyword] = ACTIONS(5186),
    [anon_sym_pageextension] = ACTIONS(5184),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5184),
    [anon_sym_Pageextension] = ACTIONS(5184),
    [anon_sym_PageExtension] = ACTIONS(5184),
    [anon_sym_pageExtension] = ACTIONS(5184),
    [anon_sym_codeunit] = ACTIONS(5184),
    [anon_sym_CODEUNIT] = ACTIONS(5184),
    [anon_sym_Codeunit] = ACTIONS(5184),
    [anon_sym_CodeUnit] = ACTIONS(5184),
    [anon_sym_COdeunit] = ACTIONS(5184),
    [anon_sym_codeUnit] = ACTIONS(5184),
    [sym_report_keyword] = ACTIONS(5186),
    [anon_sym_reportextension] = ACTIONS(5184),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5184),
    [anon_sym_Reportextension] = ACTIONS(5184),
    [anon_sym_ReportExtension] = ACTIONS(5184),
    [anon_sym_reportExtension] = ACTIONS(5184),
    [sym_query_keyword] = ACTIONS(5184),
    [anon_sym_xmlport] = ACTIONS(5184),
    [anon_sym_XMLPORT] = ACTIONS(5184),
    [anon_sym_Xmlport] = ACTIONS(5184),
    [anon_sym_XMLport] = ACTIONS(5184),
    [anon_sym_XMLPort] = ACTIONS(5184),
    [anon_sym_XmlPort] = ACTIONS(5184),
    [anon_sym_enum] = ACTIONS(5186),
    [anon_sym_ENUM] = ACTIONS(5186),
    [anon_sym_Enum] = ACTIONS(5186),
    [anon_sym_eNUM] = ACTIONS(5184),
    [anon_sym_eNum] = ACTIONS(5184),
    [anon_sym_ENum] = ACTIONS(5184),
    [anon_sym_enumextension] = ACTIONS(5184),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5184),
    [anon_sym_Enumextension] = ACTIONS(5184),
    [anon_sym_EnumExtension] = ACTIONS(5184),
    [anon_sym_enumExtension] = ACTIONS(5184),
    [sym_interface_keyword] = ACTIONS(5184),
    [anon_sym_controladdin] = ACTIONS(5184),
    [anon_sym_CONTROLADDIN] = ACTIONS(5184),
    [anon_sym_Controladdin] = ACTIONS(5184),
    [anon_sym_ControlAddIn] = ACTIONS(5184),
    [anon_sym_ControlAddin] = ACTIONS(5184),
    [anon_sym_controlAddIn] = ACTIONS(5184),
    [anon_sym_controlAddin] = ACTIONS(5184),
    [anon_sym_dotnet] = ACTIONS(5184),
    [anon_sym_DOTNET] = ACTIONS(5184),
    [anon_sym_Dotnet] = ACTIONS(5184),
    [anon_sym_DotNet] = ACTIONS(5184),
    [anon_sym_dotNet] = ACTIONS(5184),
    [sym_profile_keyword] = ACTIONS(5186),
    [anon_sym_profileextension] = ACTIONS(5184),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5184),
    [anon_sym_Profileextension] = ACTIONS(5184),
    [anon_sym_ProfileExtension] = ACTIONS(5184),
    [anon_sym_profileExtension] = ACTIONS(5184),
    [anon_sym_permissionset] = ACTIONS(5186),
    [anon_sym_PERMISSIONSET] = ACTIONS(5186),
    [anon_sym_Permissionset] = ACTIONS(5186),
    [anon_sym_PermissionSet] = ACTIONS(5186),
    [anon_sym_permissionSet] = ACTIONS(5186),
    [anon_sym_permissionsetextension] = ACTIONS(5184),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5184),
    [anon_sym_Permissionsetextension] = ACTIONS(5184),
    [anon_sym_PermissionSetExtension] = ACTIONS(5184),
    [anon_sym_permissionSetExtension] = ACTIONS(5184),
    [sym_entitlement_keyword] = ACTIONS(5184),
    [anon_sym_pagecustomization] = ACTIONS(5184),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5184),
    [anon_sym_Pagecustomization] = ACTIONS(5184),
    [anon_sym_PageCustomization] = ACTIONS(5184),
    [anon_sym_pageCustomization] = ACTIONS(5184),
    [sym_using_keyword] = ACTIONS(5184),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5184),
    [sym_preproc_close] = ACTIONS(5184),
  },
  [STATE(2010)] = {
    [anon_sym_POUNDif] = ACTIONS(5188),
    [anon_sym_POUNDIF] = ACTIONS(5188),
    [anon_sym_POUNDIf] = ACTIONS(5188),
    [anon_sym_POUNDelif] = ACTIONS(5188),
    [anon_sym_POUNDELIF] = ACTIONS(5188),
    [anon_sym_POUNDElif] = ACTIONS(5188),
    [anon_sym_POUNDelse] = ACTIONS(5188),
    [anon_sym_POUNDELSE] = ACTIONS(5188),
    [anon_sym_POUNDElse] = ACTIONS(5188),
    [anon_sym_POUNDendif] = ACTIONS(5188),
    [anon_sym_POUNDENDIF] = ACTIONS(5188),
    [anon_sym_POUNDEndif] = ACTIONS(5188),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5190),
    [anon_sym_tableextension] = ACTIONS(5188),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5188),
    [anon_sym_Tableextension] = ACTIONS(5188),
    [anon_sym_TableExtension] = ACTIONS(5188),
    [anon_sym_tableExtension] = ACTIONS(5188),
    [sym_page_keyword] = ACTIONS(5190),
    [anon_sym_pageextension] = ACTIONS(5188),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5188),
    [anon_sym_Pageextension] = ACTIONS(5188),
    [anon_sym_PageExtension] = ACTIONS(5188),
    [anon_sym_pageExtension] = ACTIONS(5188),
    [anon_sym_codeunit] = ACTIONS(5188),
    [anon_sym_CODEUNIT] = ACTIONS(5188),
    [anon_sym_Codeunit] = ACTIONS(5188),
    [anon_sym_CodeUnit] = ACTIONS(5188),
    [anon_sym_COdeunit] = ACTIONS(5188),
    [anon_sym_codeUnit] = ACTIONS(5188),
    [sym_report_keyword] = ACTIONS(5190),
    [anon_sym_reportextension] = ACTIONS(5188),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5188),
    [anon_sym_Reportextension] = ACTIONS(5188),
    [anon_sym_ReportExtension] = ACTIONS(5188),
    [anon_sym_reportExtension] = ACTIONS(5188),
    [sym_query_keyword] = ACTIONS(5188),
    [anon_sym_xmlport] = ACTIONS(5188),
    [anon_sym_XMLPORT] = ACTIONS(5188),
    [anon_sym_Xmlport] = ACTIONS(5188),
    [anon_sym_XMLport] = ACTIONS(5188),
    [anon_sym_XMLPort] = ACTIONS(5188),
    [anon_sym_XmlPort] = ACTIONS(5188),
    [anon_sym_enum] = ACTIONS(5190),
    [anon_sym_ENUM] = ACTIONS(5190),
    [anon_sym_Enum] = ACTIONS(5190),
    [anon_sym_eNUM] = ACTIONS(5188),
    [anon_sym_eNum] = ACTIONS(5188),
    [anon_sym_ENum] = ACTIONS(5188),
    [anon_sym_enumextension] = ACTIONS(5188),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5188),
    [anon_sym_Enumextension] = ACTIONS(5188),
    [anon_sym_EnumExtension] = ACTIONS(5188),
    [anon_sym_enumExtension] = ACTIONS(5188),
    [sym_interface_keyword] = ACTIONS(5188),
    [anon_sym_controladdin] = ACTIONS(5188),
    [anon_sym_CONTROLADDIN] = ACTIONS(5188),
    [anon_sym_Controladdin] = ACTIONS(5188),
    [anon_sym_ControlAddIn] = ACTIONS(5188),
    [anon_sym_ControlAddin] = ACTIONS(5188),
    [anon_sym_controlAddIn] = ACTIONS(5188),
    [anon_sym_controlAddin] = ACTIONS(5188),
    [anon_sym_dotnet] = ACTIONS(5188),
    [anon_sym_DOTNET] = ACTIONS(5188),
    [anon_sym_Dotnet] = ACTIONS(5188),
    [anon_sym_DotNet] = ACTIONS(5188),
    [anon_sym_dotNet] = ACTIONS(5188),
    [sym_profile_keyword] = ACTIONS(5190),
    [anon_sym_profileextension] = ACTIONS(5188),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5188),
    [anon_sym_Profileextension] = ACTIONS(5188),
    [anon_sym_ProfileExtension] = ACTIONS(5188),
    [anon_sym_profileExtension] = ACTIONS(5188),
    [anon_sym_permissionset] = ACTIONS(5190),
    [anon_sym_PERMISSIONSET] = ACTIONS(5190),
    [anon_sym_Permissionset] = ACTIONS(5190),
    [anon_sym_PermissionSet] = ACTIONS(5190),
    [anon_sym_permissionSet] = ACTIONS(5190),
    [anon_sym_permissionsetextension] = ACTIONS(5188),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5188),
    [anon_sym_Permissionsetextension] = ACTIONS(5188),
    [anon_sym_PermissionSetExtension] = ACTIONS(5188),
    [anon_sym_permissionSetExtension] = ACTIONS(5188),
    [sym_entitlement_keyword] = ACTIONS(5188),
    [anon_sym_pagecustomization] = ACTIONS(5188),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5188),
    [anon_sym_Pagecustomization] = ACTIONS(5188),
    [anon_sym_PageCustomization] = ACTIONS(5188),
    [anon_sym_pageCustomization] = ACTIONS(5188),
    [sym_using_keyword] = ACTIONS(5188),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5188),
    [sym_preproc_close] = ACTIONS(5188),
  },
  [STATE(2011)] = {
    [anon_sym_POUNDif] = ACTIONS(5192),
    [anon_sym_POUNDIF] = ACTIONS(5192),
    [anon_sym_POUNDIf] = ACTIONS(5192),
    [anon_sym_POUNDelif] = ACTIONS(5192),
    [anon_sym_POUNDELIF] = ACTIONS(5192),
    [anon_sym_POUNDElif] = ACTIONS(5192),
    [anon_sym_POUNDelse] = ACTIONS(5192),
    [anon_sym_POUNDELSE] = ACTIONS(5192),
    [anon_sym_POUNDElse] = ACTIONS(5192),
    [anon_sym_POUNDendif] = ACTIONS(5192),
    [anon_sym_POUNDENDIF] = ACTIONS(5192),
    [anon_sym_POUNDEndif] = ACTIONS(5192),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5194),
    [anon_sym_tableextension] = ACTIONS(5192),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5192),
    [anon_sym_Tableextension] = ACTIONS(5192),
    [anon_sym_TableExtension] = ACTIONS(5192),
    [anon_sym_tableExtension] = ACTIONS(5192),
    [sym_page_keyword] = ACTIONS(5194),
    [anon_sym_pageextension] = ACTIONS(5192),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5192),
    [anon_sym_Pageextension] = ACTIONS(5192),
    [anon_sym_PageExtension] = ACTIONS(5192),
    [anon_sym_pageExtension] = ACTIONS(5192),
    [anon_sym_codeunit] = ACTIONS(5192),
    [anon_sym_CODEUNIT] = ACTIONS(5192),
    [anon_sym_Codeunit] = ACTIONS(5192),
    [anon_sym_CodeUnit] = ACTIONS(5192),
    [anon_sym_COdeunit] = ACTIONS(5192),
    [anon_sym_codeUnit] = ACTIONS(5192),
    [sym_report_keyword] = ACTIONS(5194),
    [anon_sym_reportextension] = ACTIONS(5192),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5192),
    [anon_sym_Reportextension] = ACTIONS(5192),
    [anon_sym_ReportExtension] = ACTIONS(5192),
    [anon_sym_reportExtension] = ACTIONS(5192),
    [sym_query_keyword] = ACTIONS(5192),
    [anon_sym_xmlport] = ACTIONS(5192),
    [anon_sym_XMLPORT] = ACTIONS(5192),
    [anon_sym_Xmlport] = ACTIONS(5192),
    [anon_sym_XMLport] = ACTIONS(5192),
    [anon_sym_XMLPort] = ACTIONS(5192),
    [anon_sym_XmlPort] = ACTIONS(5192),
    [anon_sym_enum] = ACTIONS(5194),
    [anon_sym_ENUM] = ACTIONS(5194),
    [anon_sym_Enum] = ACTIONS(5194),
    [anon_sym_eNUM] = ACTIONS(5192),
    [anon_sym_eNum] = ACTIONS(5192),
    [anon_sym_ENum] = ACTIONS(5192),
    [anon_sym_enumextension] = ACTIONS(5192),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5192),
    [anon_sym_Enumextension] = ACTIONS(5192),
    [anon_sym_EnumExtension] = ACTIONS(5192),
    [anon_sym_enumExtension] = ACTIONS(5192),
    [sym_interface_keyword] = ACTIONS(5192),
    [anon_sym_controladdin] = ACTIONS(5192),
    [anon_sym_CONTROLADDIN] = ACTIONS(5192),
    [anon_sym_Controladdin] = ACTIONS(5192),
    [anon_sym_ControlAddIn] = ACTIONS(5192),
    [anon_sym_ControlAddin] = ACTIONS(5192),
    [anon_sym_controlAddIn] = ACTIONS(5192),
    [anon_sym_controlAddin] = ACTIONS(5192),
    [anon_sym_dotnet] = ACTIONS(5192),
    [anon_sym_DOTNET] = ACTIONS(5192),
    [anon_sym_Dotnet] = ACTIONS(5192),
    [anon_sym_DotNet] = ACTIONS(5192),
    [anon_sym_dotNet] = ACTIONS(5192),
    [sym_profile_keyword] = ACTIONS(5194),
    [anon_sym_profileextension] = ACTIONS(5192),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5192),
    [anon_sym_Profileextension] = ACTIONS(5192),
    [anon_sym_ProfileExtension] = ACTIONS(5192),
    [anon_sym_profileExtension] = ACTIONS(5192),
    [anon_sym_permissionset] = ACTIONS(5194),
    [anon_sym_PERMISSIONSET] = ACTIONS(5194),
    [anon_sym_Permissionset] = ACTIONS(5194),
    [anon_sym_PermissionSet] = ACTIONS(5194),
    [anon_sym_permissionSet] = ACTIONS(5194),
    [anon_sym_permissionsetextension] = ACTIONS(5192),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5192),
    [anon_sym_Permissionsetextension] = ACTIONS(5192),
    [anon_sym_PermissionSetExtension] = ACTIONS(5192),
    [anon_sym_permissionSetExtension] = ACTIONS(5192),
    [sym_entitlement_keyword] = ACTIONS(5192),
    [anon_sym_pagecustomization] = ACTIONS(5192),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5192),
    [anon_sym_Pagecustomization] = ACTIONS(5192),
    [anon_sym_PageCustomization] = ACTIONS(5192),
    [anon_sym_pageCustomization] = ACTIONS(5192),
    [sym_using_keyword] = ACTIONS(5192),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5192),
    [sym_preproc_close] = ACTIONS(5192),
  },
  [STATE(2012)] = {
    [anon_sym_POUNDif] = ACTIONS(5196),
    [anon_sym_POUNDIF] = ACTIONS(5196),
    [anon_sym_POUNDIf] = ACTIONS(5196),
    [anon_sym_POUNDelif] = ACTIONS(5196),
    [anon_sym_POUNDELIF] = ACTIONS(5196),
    [anon_sym_POUNDElif] = ACTIONS(5196),
    [anon_sym_POUNDelse] = ACTIONS(5196),
    [anon_sym_POUNDELSE] = ACTIONS(5196),
    [anon_sym_POUNDElse] = ACTIONS(5196),
    [anon_sym_POUNDendif] = ACTIONS(5196),
    [anon_sym_POUNDENDIF] = ACTIONS(5196),
    [anon_sym_POUNDEndif] = ACTIONS(5196),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5198),
    [anon_sym_tableextension] = ACTIONS(5196),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5196),
    [anon_sym_Tableextension] = ACTIONS(5196),
    [anon_sym_TableExtension] = ACTIONS(5196),
    [anon_sym_tableExtension] = ACTIONS(5196),
    [sym_page_keyword] = ACTIONS(5198),
    [anon_sym_pageextension] = ACTIONS(5196),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5196),
    [anon_sym_Pageextension] = ACTIONS(5196),
    [anon_sym_PageExtension] = ACTIONS(5196),
    [anon_sym_pageExtension] = ACTIONS(5196),
    [anon_sym_codeunit] = ACTIONS(5196),
    [anon_sym_CODEUNIT] = ACTIONS(5196),
    [anon_sym_Codeunit] = ACTIONS(5196),
    [anon_sym_CodeUnit] = ACTIONS(5196),
    [anon_sym_COdeunit] = ACTIONS(5196),
    [anon_sym_codeUnit] = ACTIONS(5196),
    [sym_report_keyword] = ACTIONS(5198),
    [anon_sym_reportextension] = ACTIONS(5196),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5196),
    [anon_sym_Reportextension] = ACTIONS(5196),
    [anon_sym_ReportExtension] = ACTIONS(5196),
    [anon_sym_reportExtension] = ACTIONS(5196),
    [sym_query_keyword] = ACTIONS(5196),
    [anon_sym_xmlport] = ACTIONS(5196),
    [anon_sym_XMLPORT] = ACTIONS(5196),
    [anon_sym_Xmlport] = ACTIONS(5196),
    [anon_sym_XMLport] = ACTIONS(5196),
    [anon_sym_XMLPort] = ACTIONS(5196),
    [anon_sym_XmlPort] = ACTIONS(5196),
    [anon_sym_enum] = ACTIONS(5198),
    [anon_sym_ENUM] = ACTIONS(5198),
    [anon_sym_Enum] = ACTIONS(5198),
    [anon_sym_eNUM] = ACTIONS(5196),
    [anon_sym_eNum] = ACTIONS(5196),
    [anon_sym_ENum] = ACTIONS(5196),
    [anon_sym_enumextension] = ACTIONS(5196),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5196),
    [anon_sym_Enumextension] = ACTIONS(5196),
    [anon_sym_EnumExtension] = ACTIONS(5196),
    [anon_sym_enumExtension] = ACTIONS(5196),
    [sym_interface_keyword] = ACTIONS(5196),
    [anon_sym_controladdin] = ACTIONS(5196),
    [anon_sym_CONTROLADDIN] = ACTIONS(5196),
    [anon_sym_Controladdin] = ACTIONS(5196),
    [anon_sym_ControlAddIn] = ACTIONS(5196),
    [anon_sym_ControlAddin] = ACTIONS(5196),
    [anon_sym_controlAddIn] = ACTIONS(5196),
    [anon_sym_controlAddin] = ACTIONS(5196),
    [anon_sym_dotnet] = ACTIONS(5196),
    [anon_sym_DOTNET] = ACTIONS(5196),
    [anon_sym_Dotnet] = ACTIONS(5196),
    [anon_sym_DotNet] = ACTIONS(5196),
    [anon_sym_dotNet] = ACTIONS(5196),
    [sym_profile_keyword] = ACTIONS(5198),
    [anon_sym_profileextension] = ACTIONS(5196),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5196),
    [anon_sym_Profileextension] = ACTIONS(5196),
    [anon_sym_ProfileExtension] = ACTIONS(5196),
    [anon_sym_profileExtension] = ACTIONS(5196),
    [anon_sym_permissionset] = ACTIONS(5198),
    [anon_sym_PERMISSIONSET] = ACTIONS(5198),
    [anon_sym_Permissionset] = ACTIONS(5198),
    [anon_sym_PermissionSet] = ACTIONS(5198),
    [anon_sym_permissionSet] = ACTIONS(5198),
    [anon_sym_permissionsetextension] = ACTIONS(5196),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5196),
    [anon_sym_Permissionsetextension] = ACTIONS(5196),
    [anon_sym_PermissionSetExtension] = ACTIONS(5196),
    [anon_sym_permissionSetExtension] = ACTIONS(5196),
    [sym_entitlement_keyword] = ACTIONS(5196),
    [anon_sym_pagecustomization] = ACTIONS(5196),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5196),
    [anon_sym_Pagecustomization] = ACTIONS(5196),
    [anon_sym_PageCustomization] = ACTIONS(5196),
    [anon_sym_pageCustomization] = ACTIONS(5196),
    [sym_using_keyword] = ACTIONS(5196),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5196),
    [sym_preproc_close] = ACTIONS(5196),
  },
  [STATE(2013)] = {
    [anon_sym_POUNDif] = ACTIONS(5200),
    [anon_sym_POUNDIF] = ACTIONS(5200),
    [anon_sym_POUNDIf] = ACTIONS(5200),
    [anon_sym_POUNDelif] = ACTIONS(5200),
    [anon_sym_POUNDELIF] = ACTIONS(5200),
    [anon_sym_POUNDElif] = ACTIONS(5200),
    [anon_sym_POUNDelse] = ACTIONS(5200),
    [anon_sym_POUNDELSE] = ACTIONS(5200),
    [anon_sym_POUNDElse] = ACTIONS(5200),
    [anon_sym_POUNDendif] = ACTIONS(5200),
    [anon_sym_POUNDENDIF] = ACTIONS(5200),
    [anon_sym_POUNDEndif] = ACTIONS(5200),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5202),
    [anon_sym_tableextension] = ACTIONS(5200),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5200),
    [anon_sym_Tableextension] = ACTIONS(5200),
    [anon_sym_TableExtension] = ACTIONS(5200),
    [anon_sym_tableExtension] = ACTIONS(5200),
    [sym_page_keyword] = ACTIONS(5202),
    [anon_sym_pageextension] = ACTIONS(5200),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5200),
    [anon_sym_Pageextension] = ACTIONS(5200),
    [anon_sym_PageExtension] = ACTIONS(5200),
    [anon_sym_pageExtension] = ACTIONS(5200),
    [anon_sym_codeunit] = ACTIONS(5200),
    [anon_sym_CODEUNIT] = ACTIONS(5200),
    [anon_sym_Codeunit] = ACTIONS(5200),
    [anon_sym_CodeUnit] = ACTIONS(5200),
    [anon_sym_COdeunit] = ACTIONS(5200),
    [anon_sym_codeUnit] = ACTIONS(5200),
    [sym_report_keyword] = ACTIONS(5202),
    [anon_sym_reportextension] = ACTIONS(5200),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5200),
    [anon_sym_Reportextension] = ACTIONS(5200),
    [anon_sym_ReportExtension] = ACTIONS(5200),
    [anon_sym_reportExtension] = ACTIONS(5200),
    [sym_query_keyword] = ACTIONS(5200),
    [anon_sym_xmlport] = ACTIONS(5200),
    [anon_sym_XMLPORT] = ACTIONS(5200),
    [anon_sym_Xmlport] = ACTIONS(5200),
    [anon_sym_XMLport] = ACTIONS(5200),
    [anon_sym_XMLPort] = ACTIONS(5200),
    [anon_sym_XmlPort] = ACTIONS(5200),
    [anon_sym_enum] = ACTIONS(5202),
    [anon_sym_ENUM] = ACTIONS(5202),
    [anon_sym_Enum] = ACTIONS(5202),
    [anon_sym_eNUM] = ACTIONS(5200),
    [anon_sym_eNum] = ACTIONS(5200),
    [anon_sym_ENum] = ACTIONS(5200),
    [anon_sym_enumextension] = ACTIONS(5200),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5200),
    [anon_sym_Enumextension] = ACTIONS(5200),
    [anon_sym_EnumExtension] = ACTIONS(5200),
    [anon_sym_enumExtension] = ACTIONS(5200),
    [sym_interface_keyword] = ACTIONS(5200),
    [anon_sym_controladdin] = ACTIONS(5200),
    [anon_sym_CONTROLADDIN] = ACTIONS(5200),
    [anon_sym_Controladdin] = ACTIONS(5200),
    [anon_sym_ControlAddIn] = ACTIONS(5200),
    [anon_sym_ControlAddin] = ACTIONS(5200),
    [anon_sym_controlAddIn] = ACTIONS(5200),
    [anon_sym_controlAddin] = ACTIONS(5200),
    [anon_sym_dotnet] = ACTIONS(5200),
    [anon_sym_DOTNET] = ACTIONS(5200),
    [anon_sym_Dotnet] = ACTIONS(5200),
    [anon_sym_DotNet] = ACTIONS(5200),
    [anon_sym_dotNet] = ACTIONS(5200),
    [sym_profile_keyword] = ACTIONS(5202),
    [anon_sym_profileextension] = ACTIONS(5200),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5200),
    [anon_sym_Profileextension] = ACTIONS(5200),
    [anon_sym_ProfileExtension] = ACTIONS(5200),
    [anon_sym_profileExtension] = ACTIONS(5200),
    [anon_sym_permissionset] = ACTIONS(5202),
    [anon_sym_PERMISSIONSET] = ACTIONS(5202),
    [anon_sym_Permissionset] = ACTIONS(5202),
    [anon_sym_PermissionSet] = ACTIONS(5202),
    [anon_sym_permissionSet] = ACTIONS(5202),
    [anon_sym_permissionsetextension] = ACTIONS(5200),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5200),
    [anon_sym_Permissionsetextension] = ACTIONS(5200),
    [anon_sym_PermissionSetExtension] = ACTIONS(5200),
    [anon_sym_permissionSetExtension] = ACTIONS(5200),
    [sym_entitlement_keyword] = ACTIONS(5200),
    [anon_sym_pagecustomization] = ACTIONS(5200),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5200),
    [anon_sym_Pagecustomization] = ACTIONS(5200),
    [anon_sym_PageCustomization] = ACTIONS(5200),
    [anon_sym_pageCustomization] = ACTIONS(5200),
    [sym_using_keyword] = ACTIONS(5200),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5200),
    [sym_preproc_close] = ACTIONS(5200),
  },
  [STATE(2014)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(2015),
    [sym_identifier] = ACTIONS(2442),
    [anon_sym_DOT] = ACTIONS(5095),
    [anon_sym_EQ] = ACTIONS(2444),
    [anon_sym_COMMA] = ACTIONS(2444),
    [anon_sym_DASH] = ACTIONS(2442),
    [aux_sym_boolean_token1] = ACTIONS(2442),
    [aux_sym_boolean_token2] = ACTIONS(2442),
    [sym_decimal] = ACTIONS(2442),
    [anon_sym_LPAREN] = ACTIONS(2444),
    [anon_sym_DOT_DOT] = ACTIONS(2444),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2442),
    [anon_sym_STAR] = ACTIONS(2442),
    [anon_sym_LBRACK] = ACTIONS(2444),
    [aux_sym_record_type_token1] = ACTIONS(2442),
    [aux_sym_basic_type_token21] = ACTIONS(2442),
    [aux_sym_basic_type_token22] = ACTIONS(2442),
    [aux_sym_basic_type_token48] = ACTIONS(2442),
    [anon_sym_not] = ACTIONS(2442),
    [anon_sym_NOT] = ACTIONS(2442),
    [anon_sym_Not] = ACTIONS(2442),
    [anon_sym_POUNDelif] = ACTIONS(2444),
    [anon_sym_POUNDELIF] = ACTIONS(2444),
    [anon_sym_POUNDElif] = ACTIONS(2444),
    [anon_sym_POUNDelse] = ACTIONS(2444),
    [anon_sym_POUNDELSE] = ACTIONS(2444),
    [anon_sym_POUNDElse] = ACTIONS(2444),
    [anon_sym_POUNDendif] = ACTIONS(2444),
    [anon_sym_POUNDENDIF] = ACTIONS(2444),
    [anon_sym_POUNDEndif] = ACTIONS(2444),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2444),
    [aux_sym__expression_token1] = ACTIONS(2444),
    [aux_sym__expression_token2] = ACTIONS(2444),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2442),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2442),
    [anon_sym_SLASH] = ACTIONS(2442),
    [anon_sym_div] = ACTIONS(2442),
    [anon_sym_DIV] = ACTIONS(2442),
    [anon_sym_Div] = ACTIONS(2442),
    [anon_sym_mod] = ACTIONS(2442),
    [anon_sym_MOD] = ACTIONS(2442),
    [anon_sym_Mod] = ACTIONS(2442),
    [anon_sym_PLUS] = ACTIONS(2442),
    [anon_sym_GT_EQ] = ACTIONS(2444),
    [anon_sym_LT_EQ] = ACTIONS(2444),
    [anon_sym_GT] = ACTIONS(2442),
    [anon_sym_LT] = ACTIONS(2442),
    [anon_sym_LT_GT] = ACTIONS(2444),
    [anon_sym_and] = ACTIONS(2442),
    [anon_sym_AND] = ACTIONS(2442),
    [anon_sym_And] = ACTIONS(2442),
    [anon_sym_or] = ACTIONS(2442),
    [anon_sym_OR] = ACTIONS(2442),
    [anon_sym_Or] = ACTIONS(2442),
    [anon_sym_xor] = ACTIONS(2442),
    [anon_sym_XOR] = ACTIONS(2442),
    [anon_sym_Xor] = ACTIONS(2442),
    [anon_sym_QMARK] = ACTIONS(2444),
    [sym_datetime_literal] = ACTIONS(2444),
    [sym_date_literal] = ACTIONS(2442),
    [sym_time_literal] = ACTIONS(2442),
    [sym_biginteger_literal] = ACTIONS(2444),
    [anon_sym_in] = ACTIONS(2442),
    [anon_sym_IN] = ACTIONS(2442),
    [anon_sym_In] = ACTIONS(2442),
    [sym_page_keyword] = ACTIONS(2442),
    [anon_sym_codeunit] = ACTIONS(2442),
    [anon_sym_CODEUNIT] = ACTIONS(2442),
    [anon_sym_Codeunit] = ACTIONS(2442),
    [anon_sym_CodeUnit] = ACTIONS(2442),
    [anon_sym_COdeunit] = ACTIONS(2442),
    [anon_sym_codeUnit] = ACTIONS(2442),
    [sym_report_keyword] = ACTIONS(2442),
    [sym_query_keyword] = ACTIONS(2442),
    [anon_sym_xmlport] = ACTIONS(2442),
    [anon_sym_XMLPORT] = ACTIONS(2442),
    [anon_sym_Xmlport] = ACTIONS(2442),
    [anon_sym_XMLport] = ACTIONS(2442),
    [anon_sym_XMLPort] = ACTIONS(2442),
    [anon_sym_XmlPort] = ACTIONS(2442),
    [anon_sym_enum] = ACTIONS(2442),
    [anon_sym_ENUM] = ACTIONS(2442),
    [anon_sym_Enum] = ACTIONS(2442),
    [anon_sym_eNUM] = ACTIONS(2442),
    [anon_sym_eNum] = ACTIONS(2442),
    [anon_sym_ENum] = ACTIONS(2442),
    [sym_temporary_keyword] = ACTIONS(2442),
    [sym_quoted_identifier] = ACTIONS(2444),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2444),
    [sym_integer] = ACTIONS(2442),
    [sym_continue_as_identifier] = ACTIONS(2444),
    [sym_preproc_close] = ACTIONS(2444),
  },
  [STATE(2015)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(2015),
    [sym_identifier] = ACTIONS(2396),
    [anon_sym_DOT] = ACTIONS(5204),
    [anon_sym_EQ] = ACTIONS(2398),
    [anon_sym_COMMA] = ACTIONS(2398),
    [anon_sym_DASH] = ACTIONS(2396),
    [aux_sym_boolean_token1] = ACTIONS(2396),
    [aux_sym_boolean_token2] = ACTIONS(2396),
    [sym_decimal] = ACTIONS(2396),
    [anon_sym_LPAREN] = ACTIONS(2398),
    [anon_sym_DOT_DOT] = ACTIONS(2398),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2396),
    [anon_sym_STAR] = ACTIONS(2396),
    [anon_sym_LBRACK] = ACTIONS(2398),
    [aux_sym_record_type_token1] = ACTIONS(2396),
    [aux_sym_basic_type_token21] = ACTIONS(2396),
    [aux_sym_basic_type_token22] = ACTIONS(2396),
    [aux_sym_basic_type_token48] = ACTIONS(2396),
    [anon_sym_not] = ACTIONS(2396),
    [anon_sym_NOT] = ACTIONS(2396),
    [anon_sym_Not] = ACTIONS(2396),
    [anon_sym_POUNDelif] = ACTIONS(2398),
    [anon_sym_POUNDELIF] = ACTIONS(2398),
    [anon_sym_POUNDElif] = ACTIONS(2398),
    [anon_sym_POUNDelse] = ACTIONS(2398),
    [anon_sym_POUNDELSE] = ACTIONS(2398),
    [anon_sym_POUNDElse] = ACTIONS(2398),
    [anon_sym_POUNDendif] = ACTIONS(2398),
    [anon_sym_POUNDENDIF] = ACTIONS(2398),
    [anon_sym_POUNDEndif] = ACTIONS(2398),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2398),
    [aux_sym__expression_token1] = ACTIONS(2398),
    [aux_sym__expression_token2] = ACTIONS(2398),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2396),
    [anon_sym_SLASH] = ACTIONS(2396),
    [anon_sym_div] = ACTIONS(2396),
    [anon_sym_DIV] = ACTIONS(2396),
    [anon_sym_Div] = ACTIONS(2396),
    [anon_sym_mod] = ACTIONS(2396),
    [anon_sym_MOD] = ACTIONS(2396),
    [anon_sym_Mod] = ACTIONS(2396),
    [anon_sym_PLUS] = ACTIONS(2396),
    [anon_sym_GT_EQ] = ACTIONS(2398),
    [anon_sym_LT_EQ] = ACTIONS(2398),
    [anon_sym_GT] = ACTIONS(2396),
    [anon_sym_LT] = ACTIONS(2396),
    [anon_sym_LT_GT] = ACTIONS(2398),
    [anon_sym_and] = ACTIONS(2396),
    [anon_sym_AND] = ACTIONS(2396),
    [anon_sym_And] = ACTIONS(2396),
    [anon_sym_or] = ACTIONS(2396),
    [anon_sym_OR] = ACTIONS(2396),
    [anon_sym_Or] = ACTIONS(2396),
    [anon_sym_xor] = ACTIONS(2396),
    [anon_sym_XOR] = ACTIONS(2396),
    [anon_sym_Xor] = ACTIONS(2396),
    [anon_sym_QMARK] = ACTIONS(2398),
    [sym_datetime_literal] = ACTIONS(2398),
    [sym_date_literal] = ACTIONS(2396),
    [sym_time_literal] = ACTIONS(2396),
    [sym_biginteger_literal] = ACTIONS(2398),
    [anon_sym_in] = ACTIONS(2396),
    [anon_sym_IN] = ACTIONS(2396),
    [anon_sym_In] = ACTIONS(2396),
    [sym_page_keyword] = ACTIONS(2396),
    [anon_sym_codeunit] = ACTIONS(2396),
    [anon_sym_CODEUNIT] = ACTIONS(2396),
    [anon_sym_Codeunit] = ACTIONS(2396),
    [anon_sym_CodeUnit] = ACTIONS(2396),
    [anon_sym_COdeunit] = ACTIONS(2396),
    [anon_sym_codeUnit] = ACTIONS(2396),
    [sym_report_keyword] = ACTIONS(2396),
    [sym_query_keyword] = ACTIONS(2396),
    [anon_sym_xmlport] = ACTIONS(2396),
    [anon_sym_XMLPORT] = ACTIONS(2396),
    [anon_sym_Xmlport] = ACTIONS(2396),
    [anon_sym_XMLport] = ACTIONS(2396),
    [anon_sym_XMLPort] = ACTIONS(2396),
    [anon_sym_XmlPort] = ACTIONS(2396),
    [anon_sym_enum] = ACTIONS(2396),
    [anon_sym_ENUM] = ACTIONS(2396),
    [anon_sym_Enum] = ACTIONS(2396),
    [anon_sym_eNUM] = ACTIONS(2396),
    [anon_sym_eNum] = ACTIONS(2396),
    [anon_sym_ENum] = ACTIONS(2396),
    [sym_temporary_keyword] = ACTIONS(2396),
    [sym_quoted_identifier] = ACTIONS(2398),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2398),
    [sym_integer] = ACTIONS(2396),
    [sym_continue_as_identifier] = ACTIONS(2398),
    [sym_preproc_close] = ACTIONS(2398),
  },
  [STATE(2016)] = {
    [sym_boolean] = STATE(4795),
    [sym_option_member] = STATE(6047),
    [sym_keyword_identifier] = STATE(4795),
    [sym_codeunit_keyword] = STATE(4642),
    [sym_xmlport_keyword] = STATE(4642),
    [sym_enum_keyword] = STATE(4642),
    [sym_keyword_as_identifier] = STATE(4795),
    [aux_sym_option_member_list_repeat2] = STATE(1654),
    [sym_identifier] = ACTIONS(2239),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(3744),
    [anon_sym_DASH] = ACTIONS(3704),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [aux_sym_where_condition_token1] = ACTIONS(4844),
    [anon_sym_DOT_DOT] = ACTIONS(374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(2221),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(4844),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4844),
    [aux_sym_separator_action_token1] = ACTIONS(4844),
    [aux_sym_type_declaration_token1] = ACTIONS(4844),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(374),
    [aux_sym__expression_token1] = ACTIONS(374),
    [aux_sym__expression_token2] = ACTIONS(374),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(917),
    [anon_sym_SLASH] = ACTIONS(376),
    [anon_sym_div] = ACTIONS(376),
    [anon_sym_DIV] = ACTIONS(376),
    [anon_sym_Div] = ACTIONS(376),
    [anon_sym_mod] = ACTIONS(376),
    [anon_sym_MOD] = ACTIONS(376),
    [anon_sym_Mod] = ACTIONS(376),
    [anon_sym_PLUS] = ACTIONS(376),
    [anon_sym_GT_EQ] = ACTIONS(374),
    [anon_sym_LT_EQ] = ACTIONS(374),
    [anon_sym_GT] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(376),
    [anon_sym_LT_GT] = ACTIONS(374),
    [anon_sym_and] = ACTIONS(376),
    [anon_sym_AND] = ACTIONS(376),
    [anon_sym_And] = ACTIONS(376),
    [anon_sym_or] = ACTIONS(376),
    [anon_sym_OR] = ACTIONS(376),
    [anon_sym_Or] = ACTIONS(376),
    [anon_sym_xor] = ACTIONS(376),
    [anon_sym_XOR] = ACTIONS(376),
    [anon_sym_Xor] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(374),
    [anon_sym_else] = ACTIONS(376),
    [anon_sym_ELSE] = ACTIONS(376),
    [anon_sym_Else] = ACTIONS(376),
    [anon_sym_in] = ACTIONS(376),
    [anon_sym_IN] = ACTIONS(376),
    [anon_sym_In] = ACTIONS(376),
    [sym_page_keyword] = ACTIONS(917),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(917),
    [sym_query_keyword] = ACTIONS(917),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(2239),
    [sym_internal_keyword] = ACTIONS(2239),
    [sym_protected_keyword] = ACTIONS(2239),
    [sym_key_keyword] = ACTIONS(4844),
    [sym_dataset_keyword] = ACTIONS(4844),
    [sym_quoted_identifier] = ACTIONS(3706),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3706),
    [sym_integer] = ACTIONS(3706),
  },
  [STATE(2017)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2368),
    [anon_sym_SEMI] = ACTIONS(2370),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2370),
    [anon_sym_COLON] = ACTIONS(2368),
    [anon_sym_DASH] = ACTIONS(5209),
    [aux_sym_boolean_token1] = ACTIONS(2368),
    [aux_sym_boolean_token2] = ACTIONS(2368),
    [sym_decimal] = ACTIONS(2368),
    [anon_sym_LPAREN] = ACTIONS(2370),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2368),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2368),
    [aux_sym_basic_type_token21] = ACTIONS(2368),
    [aux_sym_basic_type_token22] = ACTIONS(2368),
    [aux_sym_basic_type_token48] = ACTIONS(2368),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2368),
    [anon_sym_POUNDif] = ACTIONS(2370),
    [anon_sym_POUNDIF] = ACTIONS(2370),
    [anon_sym_POUNDIf] = ACTIONS(2370),
    [anon_sym_not] = ACTIONS(2368),
    [anon_sym_NOT] = ACTIONS(2368),
    [anon_sym_Not] = ACTIONS(2368),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2370),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2368),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2368),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(5235),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(5237),
    [anon_sym_AND] = ACTIONS(5239),
    [anon_sym_And] = ACTIONS(5241),
    [anon_sym_or] = ACTIONS(5243),
    [anon_sym_OR] = ACTIONS(5245),
    [anon_sym_Or] = ACTIONS(5247),
    [anon_sym_xor] = ACTIONS(5249),
    [anon_sym_XOR] = ACTIONS(5251),
    [anon_sym_Xor] = ACTIONS(5253),
    [anon_sym_QMARK] = ACTIONS(5255),
    [sym_datetime_literal] = ACTIONS(2370),
    [sym_date_literal] = ACTIONS(2368),
    [sym_time_literal] = ACTIONS(2368),
    [sym_biginteger_literal] = ACTIONS(2370),
    [anon_sym_else] = ACTIONS(2368),
    [anon_sym_ELSE] = ACTIONS(2368),
    [anon_sym_Else] = ACTIONS(2368),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2368),
    [anon_sym_codeunit] = ACTIONS(2368),
    [anon_sym_CODEUNIT] = ACTIONS(2368),
    [anon_sym_Codeunit] = ACTIONS(2368),
    [anon_sym_CodeUnit] = ACTIONS(2368),
    [anon_sym_COdeunit] = ACTIONS(2368),
    [anon_sym_codeUnit] = ACTIONS(2368),
    [sym_report_keyword] = ACTIONS(2368),
    [sym_query_keyword] = ACTIONS(2368),
    [anon_sym_xmlport] = ACTIONS(2368),
    [anon_sym_XMLPORT] = ACTIONS(2368),
    [anon_sym_Xmlport] = ACTIONS(2368),
    [anon_sym_XMLport] = ACTIONS(2368),
    [anon_sym_XMLPort] = ACTIONS(2368),
    [anon_sym_XmlPort] = ACTIONS(2368),
    [anon_sym_enum] = ACTIONS(2368),
    [anon_sym_ENUM] = ACTIONS(2368),
    [anon_sym_Enum] = ACTIONS(2368),
    [anon_sym_eNUM] = ACTIONS(2368),
    [anon_sym_eNum] = ACTIONS(2368),
    [anon_sym_ENum] = ACTIONS(2368),
    [sym_quoted_identifier] = ACTIONS(2370),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2370),
    [sym_integer] = ACTIONS(2368),
    [sym_continue_as_identifier] = ACTIONS(2370),
    [sym_preproc_open] = ACTIONS(2370),
  },
  [STATE(2018)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2430),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2432),
    [anon_sym_COMMA] = ACTIONS(2432),
    [anon_sym_DASH] = ACTIONS(2430),
    [aux_sym_boolean_token1] = ACTIONS(2430),
    [aux_sym_boolean_token2] = ACTIONS(2430),
    [sym_decimal] = ACTIONS(2430),
    [anon_sym_LPAREN] = ACTIONS(2432),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2430),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2430),
    [aux_sym_basic_type_token21] = ACTIONS(2430),
    [aux_sym_basic_type_token22] = ACTIONS(2430),
    [aux_sym_basic_type_token48] = ACTIONS(2430),
    [anon_sym_not] = ACTIONS(2430),
    [anon_sym_NOT] = ACTIONS(2430),
    [anon_sym_Not] = ACTIONS(2430),
    [anon_sym_POUNDelif] = ACTIONS(2432),
    [anon_sym_POUNDELIF] = ACTIONS(2432),
    [anon_sym_POUNDElif] = ACTIONS(2432),
    [anon_sym_POUNDelse] = ACTIONS(2432),
    [anon_sym_POUNDELSE] = ACTIONS(2432),
    [anon_sym_POUNDElse] = ACTIONS(2432),
    [anon_sym_POUNDendif] = ACTIONS(2432),
    [anon_sym_POUNDENDIF] = ACTIONS(2432),
    [anon_sym_POUNDEndif] = ACTIONS(2432),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2432),
    [aux_sym__expression_token1] = ACTIONS(2432),
    [aux_sym__expression_token2] = ACTIONS(2432),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2430),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2430),
    [anon_sym_SLASH] = ACTIONS(4963),
    [anon_sym_div] = ACTIONS(4965),
    [anon_sym_DIV] = ACTIONS(4967),
    [anon_sym_Div] = ACTIONS(4969),
    [anon_sym_mod] = ACTIONS(4971),
    [anon_sym_MOD] = ACTIONS(4973),
    [anon_sym_Mod] = ACTIONS(4975),
    [anon_sym_PLUS] = ACTIONS(2430),
    [anon_sym_GT_EQ] = ACTIONS(2432),
    [anon_sym_LT_EQ] = ACTIONS(2432),
    [anon_sym_GT] = ACTIONS(2430),
    [anon_sym_LT] = ACTIONS(2430),
    [anon_sym_LT_GT] = ACTIONS(2432),
    [anon_sym_and] = ACTIONS(2430),
    [anon_sym_AND] = ACTIONS(2430),
    [anon_sym_And] = ACTIONS(2430),
    [anon_sym_or] = ACTIONS(2430),
    [anon_sym_OR] = ACTIONS(2430),
    [anon_sym_Or] = ACTIONS(2430),
    [anon_sym_xor] = ACTIONS(2430),
    [anon_sym_XOR] = ACTIONS(2430),
    [anon_sym_Xor] = ACTIONS(2430),
    [anon_sym_QMARK] = ACTIONS(2432),
    [sym_datetime_literal] = ACTIONS(2432),
    [sym_date_literal] = ACTIONS(2430),
    [sym_time_literal] = ACTIONS(2430),
    [sym_biginteger_literal] = ACTIONS(2432),
    [anon_sym_in] = ACTIONS(2430),
    [anon_sym_IN] = ACTIONS(2430),
    [anon_sym_In] = ACTIONS(2430),
    [sym_page_keyword] = ACTIONS(2430),
    [anon_sym_codeunit] = ACTIONS(2430),
    [anon_sym_CODEUNIT] = ACTIONS(2430),
    [anon_sym_Codeunit] = ACTIONS(2430),
    [anon_sym_CodeUnit] = ACTIONS(2430),
    [anon_sym_COdeunit] = ACTIONS(2430),
    [anon_sym_codeUnit] = ACTIONS(2430),
    [sym_report_keyword] = ACTIONS(2430),
    [sym_query_keyword] = ACTIONS(2430),
    [anon_sym_xmlport] = ACTIONS(2430),
    [anon_sym_XMLPORT] = ACTIONS(2430),
    [anon_sym_Xmlport] = ACTIONS(2430),
    [anon_sym_XMLport] = ACTIONS(2430),
    [anon_sym_XMLPort] = ACTIONS(2430),
    [anon_sym_XmlPort] = ACTIONS(2430),
    [anon_sym_enum] = ACTIONS(2430),
    [anon_sym_ENUM] = ACTIONS(2430),
    [anon_sym_Enum] = ACTIONS(2430),
    [anon_sym_eNUM] = ACTIONS(2430),
    [anon_sym_eNum] = ACTIONS(2430),
    [anon_sym_ENum] = ACTIONS(2430),
    [sym_quoted_identifier] = ACTIONS(2432),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2432),
    [sym_integer] = ACTIONS(2430),
    [sym_continue_as_identifier] = ACTIONS(2432),
    [sym_preproc_close] = ACTIONS(2432),
  },
  [STATE(2019)] = {
    [sym_argument_list] = STATE(2093),
    [sym_identifier] = ACTIONS(2434),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_COMMA] = ACTIONS(2436),
    [anon_sym_DASH] = ACTIONS(2434),
    [aux_sym_boolean_token1] = ACTIONS(2434),
    [aux_sym_boolean_token2] = ACTIONS(2434),
    [sym_decimal] = ACTIONS(2434),
    [anon_sym_LPAREN] = ACTIONS(5257),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2434),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [aux_sym_record_type_token1] = ACTIONS(2434),
    [aux_sym_basic_type_token21] = ACTIONS(2434),
    [aux_sym_basic_type_token22] = ACTIONS(2434),
    [aux_sym_basic_type_token48] = ACTIONS(2434),
    [anon_sym_COLON_COLON] = ACTIONS(5259),
    [anon_sym_not] = ACTIONS(2434),
    [anon_sym_NOT] = ACTIONS(2434),
    [anon_sym_Not] = ACTIONS(2434),
    [anon_sym_POUNDelif] = ACTIONS(2436),
    [anon_sym_POUNDELIF] = ACTIONS(2436),
    [anon_sym_POUNDElif] = ACTIONS(2436),
    [anon_sym_POUNDelse] = ACTIONS(2436),
    [anon_sym_POUNDELSE] = ACTIONS(2436),
    [anon_sym_POUNDElse] = ACTIONS(2436),
    [anon_sym_POUNDendif] = ACTIONS(2436),
    [anon_sym_POUNDENDIF] = ACTIONS(2436),
    [anon_sym_POUNDEndif] = ACTIONS(2436),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2434),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(2434),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(2436),
    [sym_date_literal] = ACTIONS(2434),
    [sym_time_literal] = ACTIONS(2434),
    [sym_biginteger_literal] = ACTIONS(2436),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(2434),
    [anon_sym_codeunit] = ACTIONS(2434),
    [anon_sym_CODEUNIT] = ACTIONS(2434),
    [anon_sym_Codeunit] = ACTIONS(2434),
    [anon_sym_CodeUnit] = ACTIONS(2434),
    [anon_sym_COdeunit] = ACTIONS(2434),
    [anon_sym_codeUnit] = ACTIONS(2434),
    [sym_report_keyword] = ACTIONS(2434),
    [sym_query_keyword] = ACTIONS(2434),
    [anon_sym_xmlport] = ACTIONS(2434),
    [anon_sym_XMLPORT] = ACTIONS(2434),
    [anon_sym_Xmlport] = ACTIONS(2434),
    [anon_sym_XMLport] = ACTIONS(2434),
    [anon_sym_XMLPort] = ACTIONS(2434),
    [anon_sym_XmlPort] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2434),
    [anon_sym_ENUM] = ACTIONS(2434),
    [anon_sym_Enum] = ACTIONS(2434),
    [anon_sym_eNUM] = ACTIONS(2434),
    [anon_sym_eNum] = ACTIONS(2434),
    [anon_sym_ENum] = ACTIONS(2434),
    [sym_quoted_identifier] = ACTIONS(2436),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2436),
    [sym_integer] = ACTIONS(2434),
    [sym_continue_as_identifier] = ACTIONS(2436),
    [sym_preproc_close] = ACTIONS(2436),
  },
  [STATE(2020)] = {
    [anon_sym_POUNDif] = ACTIONS(5261),
    [anon_sym_POUNDIF] = ACTIONS(5261),
    [anon_sym_POUNDIf] = ACTIONS(5261),
    [anon_sym_POUNDelif] = ACTIONS(5261),
    [anon_sym_POUNDELIF] = ACTIONS(5261),
    [anon_sym_POUNDElif] = ACTIONS(5261),
    [anon_sym_POUNDelse] = ACTIONS(5261),
    [anon_sym_POUNDELSE] = ACTIONS(5261),
    [anon_sym_POUNDElse] = ACTIONS(5261),
    [anon_sym_POUNDendif] = ACTIONS(5261),
    [anon_sym_POUNDENDIF] = ACTIONS(5261),
    [anon_sym_POUNDEndif] = ACTIONS(5261),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5263),
    [anon_sym_tableextension] = ACTIONS(5261),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5261),
    [anon_sym_Tableextension] = ACTIONS(5261),
    [anon_sym_TableExtension] = ACTIONS(5261),
    [anon_sym_tableExtension] = ACTIONS(5261),
    [sym_page_keyword] = ACTIONS(5263),
    [anon_sym_pageextension] = ACTIONS(5261),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5261),
    [anon_sym_Pageextension] = ACTIONS(5261),
    [anon_sym_PageExtension] = ACTIONS(5261),
    [anon_sym_pageExtension] = ACTIONS(5261),
    [anon_sym_codeunit] = ACTIONS(5261),
    [anon_sym_CODEUNIT] = ACTIONS(5261),
    [anon_sym_Codeunit] = ACTIONS(5261),
    [anon_sym_CodeUnit] = ACTIONS(5261),
    [anon_sym_COdeunit] = ACTIONS(5261),
    [anon_sym_codeUnit] = ACTIONS(5261),
    [sym_report_keyword] = ACTIONS(5263),
    [anon_sym_reportextension] = ACTIONS(5261),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5261),
    [anon_sym_Reportextension] = ACTIONS(5261),
    [anon_sym_ReportExtension] = ACTIONS(5261),
    [anon_sym_reportExtension] = ACTIONS(5261),
    [sym_query_keyword] = ACTIONS(5261),
    [anon_sym_xmlport] = ACTIONS(5261),
    [anon_sym_XMLPORT] = ACTIONS(5261),
    [anon_sym_Xmlport] = ACTIONS(5261),
    [anon_sym_XMLport] = ACTIONS(5261),
    [anon_sym_XMLPort] = ACTIONS(5261),
    [anon_sym_XmlPort] = ACTIONS(5261),
    [anon_sym_enum] = ACTIONS(5263),
    [anon_sym_ENUM] = ACTIONS(5263),
    [anon_sym_Enum] = ACTIONS(5263),
    [anon_sym_eNUM] = ACTIONS(5261),
    [anon_sym_eNum] = ACTIONS(5261),
    [anon_sym_ENum] = ACTIONS(5261),
    [anon_sym_enumextension] = ACTIONS(5261),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5261),
    [anon_sym_Enumextension] = ACTIONS(5261),
    [anon_sym_EnumExtension] = ACTIONS(5261),
    [anon_sym_enumExtension] = ACTIONS(5261),
    [sym_interface_keyword] = ACTIONS(5261),
    [anon_sym_controladdin] = ACTIONS(5261),
    [anon_sym_CONTROLADDIN] = ACTIONS(5261),
    [anon_sym_Controladdin] = ACTIONS(5261),
    [anon_sym_ControlAddIn] = ACTIONS(5261),
    [anon_sym_ControlAddin] = ACTIONS(5261),
    [anon_sym_controlAddIn] = ACTIONS(5261),
    [anon_sym_controlAddin] = ACTIONS(5261),
    [anon_sym_dotnet] = ACTIONS(5261),
    [anon_sym_DOTNET] = ACTIONS(5261),
    [anon_sym_Dotnet] = ACTIONS(5261),
    [anon_sym_DotNet] = ACTIONS(5261),
    [anon_sym_dotNet] = ACTIONS(5261),
    [sym_profile_keyword] = ACTIONS(5263),
    [anon_sym_profileextension] = ACTIONS(5261),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5261),
    [anon_sym_Profileextension] = ACTIONS(5261),
    [anon_sym_ProfileExtension] = ACTIONS(5261),
    [anon_sym_profileExtension] = ACTIONS(5261),
    [anon_sym_permissionset] = ACTIONS(5263),
    [anon_sym_PERMISSIONSET] = ACTIONS(5263),
    [anon_sym_Permissionset] = ACTIONS(5263),
    [anon_sym_PermissionSet] = ACTIONS(5263),
    [anon_sym_permissionSet] = ACTIONS(5263),
    [anon_sym_permissionsetextension] = ACTIONS(5261),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5261),
    [anon_sym_Permissionsetextension] = ACTIONS(5261),
    [anon_sym_PermissionSetExtension] = ACTIONS(5261),
    [anon_sym_permissionSetExtension] = ACTIONS(5261),
    [sym_entitlement_keyword] = ACTIONS(5261),
    [anon_sym_pagecustomization] = ACTIONS(5261),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5261),
    [anon_sym_Pagecustomization] = ACTIONS(5261),
    [anon_sym_PageCustomization] = ACTIONS(5261),
    [anon_sym_pageCustomization] = ACTIONS(5261),
    [sym_using_keyword] = ACTIONS(5261),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5261),
    [sym_preproc_close] = ACTIONS(5261),
  },
  [STATE(2021)] = {
    [anon_sym_POUNDif] = ACTIONS(5265),
    [anon_sym_POUNDIF] = ACTIONS(5265),
    [anon_sym_POUNDIf] = ACTIONS(5265),
    [anon_sym_POUNDelif] = ACTIONS(5265),
    [anon_sym_POUNDELIF] = ACTIONS(5265),
    [anon_sym_POUNDElif] = ACTIONS(5265),
    [anon_sym_POUNDelse] = ACTIONS(5265),
    [anon_sym_POUNDELSE] = ACTIONS(5265),
    [anon_sym_POUNDElse] = ACTIONS(5265),
    [anon_sym_POUNDendif] = ACTIONS(5265),
    [anon_sym_POUNDENDIF] = ACTIONS(5265),
    [anon_sym_POUNDEndif] = ACTIONS(5265),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5267),
    [anon_sym_tableextension] = ACTIONS(5265),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5265),
    [anon_sym_Tableextension] = ACTIONS(5265),
    [anon_sym_TableExtension] = ACTIONS(5265),
    [anon_sym_tableExtension] = ACTIONS(5265),
    [sym_page_keyword] = ACTIONS(5267),
    [anon_sym_pageextension] = ACTIONS(5265),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5265),
    [anon_sym_Pageextension] = ACTIONS(5265),
    [anon_sym_PageExtension] = ACTIONS(5265),
    [anon_sym_pageExtension] = ACTIONS(5265),
    [anon_sym_codeunit] = ACTIONS(5265),
    [anon_sym_CODEUNIT] = ACTIONS(5265),
    [anon_sym_Codeunit] = ACTIONS(5265),
    [anon_sym_CodeUnit] = ACTIONS(5265),
    [anon_sym_COdeunit] = ACTIONS(5265),
    [anon_sym_codeUnit] = ACTIONS(5265),
    [sym_report_keyword] = ACTIONS(5267),
    [anon_sym_reportextension] = ACTIONS(5265),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5265),
    [anon_sym_Reportextension] = ACTIONS(5265),
    [anon_sym_ReportExtension] = ACTIONS(5265),
    [anon_sym_reportExtension] = ACTIONS(5265),
    [sym_query_keyword] = ACTIONS(5265),
    [anon_sym_xmlport] = ACTIONS(5265),
    [anon_sym_XMLPORT] = ACTIONS(5265),
    [anon_sym_Xmlport] = ACTIONS(5265),
    [anon_sym_XMLport] = ACTIONS(5265),
    [anon_sym_XMLPort] = ACTIONS(5265),
    [anon_sym_XmlPort] = ACTIONS(5265),
    [anon_sym_enum] = ACTIONS(5267),
    [anon_sym_ENUM] = ACTIONS(5267),
    [anon_sym_Enum] = ACTIONS(5267),
    [anon_sym_eNUM] = ACTIONS(5265),
    [anon_sym_eNum] = ACTIONS(5265),
    [anon_sym_ENum] = ACTIONS(5265),
    [anon_sym_enumextension] = ACTIONS(5265),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5265),
    [anon_sym_Enumextension] = ACTIONS(5265),
    [anon_sym_EnumExtension] = ACTIONS(5265),
    [anon_sym_enumExtension] = ACTIONS(5265),
    [sym_interface_keyword] = ACTIONS(5265),
    [anon_sym_controladdin] = ACTIONS(5265),
    [anon_sym_CONTROLADDIN] = ACTIONS(5265),
    [anon_sym_Controladdin] = ACTIONS(5265),
    [anon_sym_ControlAddIn] = ACTIONS(5265),
    [anon_sym_ControlAddin] = ACTIONS(5265),
    [anon_sym_controlAddIn] = ACTIONS(5265),
    [anon_sym_controlAddin] = ACTIONS(5265),
    [anon_sym_dotnet] = ACTIONS(5265),
    [anon_sym_DOTNET] = ACTIONS(5265),
    [anon_sym_Dotnet] = ACTIONS(5265),
    [anon_sym_DotNet] = ACTIONS(5265),
    [anon_sym_dotNet] = ACTIONS(5265),
    [sym_profile_keyword] = ACTIONS(5267),
    [anon_sym_profileextension] = ACTIONS(5265),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5265),
    [anon_sym_Profileextension] = ACTIONS(5265),
    [anon_sym_ProfileExtension] = ACTIONS(5265),
    [anon_sym_profileExtension] = ACTIONS(5265),
    [anon_sym_permissionset] = ACTIONS(5267),
    [anon_sym_PERMISSIONSET] = ACTIONS(5267),
    [anon_sym_Permissionset] = ACTIONS(5267),
    [anon_sym_PermissionSet] = ACTIONS(5267),
    [anon_sym_permissionSet] = ACTIONS(5267),
    [anon_sym_permissionsetextension] = ACTIONS(5265),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5265),
    [anon_sym_Permissionsetextension] = ACTIONS(5265),
    [anon_sym_PermissionSetExtension] = ACTIONS(5265),
    [anon_sym_permissionSetExtension] = ACTIONS(5265),
    [sym_entitlement_keyword] = ACTIONS(5265),
    [anon_sym_pagecustomization] = ACTIONS(5265),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5265),
    [anon_sym_Pagecustomization] = ACTIONS(5265),
    [anon_sym_PageCustomization] = ACTIONS(5265),
    [anon_sym_pageCustomization] = ACTIONS(5265),
    [sym_using_keyword] = ACTIONS(5265),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5265),
    [sym_preproc_close] = ACTIONS(5265),
  },
  [STATE(2022)] = {
    [anon_sym_POUNDif] = ACTIONS(5269),
    [anon_sym_POUNDIF] = ACTIONS(5269),
    [anon_sym_POUNDIf] = ACTIONS(5269),
    [anon_sym_POUNDelif] = ACTIONS(5269),
    [anon_sym_POUNDELIF] = ACTIONS(5269),
    [anon_sym_POUNDElif] = ACTIONS(5269),
    [anon_sym_POUNDelse] = ACTIONS(5269),
    [anon_sym_POUNDELSE] = ACTIONS(5269),
    [anon_sym_POUNDElse] = ACTIONS(5269),
    [anon_sym_POUNDendif] = ACTIONS(5269),
    [anon_sym_POUNDENDIF] = ACTIONS(5269),
    [anon_sym_POUNDEndif] = ACTIONS(5269),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5271),
    [anon_sym_tableextension] = ACTIONS(5269),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5269),
    [anon_sym_Tableextension] = ACTIONS(5269),
    [anon_sym_TableExtension] = ACTIONS(5269),
    [anon_sym_tableExtension] = ACTIONS(5269),
    [sym_page_keyword] = ACTIONS(5271),
    [anon_sym_pageextension] = ACTIONS(5269),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5269),
    [anon_sym_Pageextension] = ACTIONS(5269),
    [anon_sym_PageExtension] = ACTIONS(5269),
    [anon_sym_pageExtension] = ACTIONS(5269),
    [anon_sym_codeunit] = ACTIONS(5269),
    [anon_sym_CODEUNIT] = ACTIONS(5269),
    [anon_sym_Codeunit] = ACTIONS(5269),
    [anon_sym_CodeUnit] = ACTIONS(5269),
    [anon_sym_COdeunit] = ACTIONS(5269),
    [anon_sym_codeUnit] = ACTIONS(5269),
    [sym_report_keyword] = ACTIONS(5271),
    [anon_sym_reportextension] = ACTIONS(5269),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5269),
    [anon_sym_Reportextension] = ACTIONS(5269),
    [anon_sym_ReportExtension] = ACTIONS(5269),
    [anon_sym_reportExtension] = ACTIONS(5269),
    [sym_query_keyword] = ACTIONS(5269),
    [anon_sym_xmlport] = ACTIONS(5269),
    [anon_sym_XMLPORT] = ACTIONS(5269),
    [anon_sym_Xmlport] = ACTIONS(5269),
    [anon_sym_XMLport] = ACTIONS(5269),
    [anon_sym_XMLPort] = ACTIONS(5269),
    [anon_sym_XmlPort] = ACTIONS(5269),
    [anon_sym_enum] = ACTIONS(5271),
    [anon_sym_ENUM] = ACTIONS(5271),
    [anon_sym_Enum] = ACTIONS(5271),
    [anon_sym_eNUM] = ACTIONS(5269),
    [anon_sym_eNum] = ACTIONS(5269),
    [anon_sym_ENum] = ACTIONS(5269),
    [anon_sym_enumextension] = ACTIONS(5269),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5269),
    [anon_sym_Enumextension] = ACTIONS(5269),
    [anon_sym_EnumExtension] = ACTIONS(5269),
    [anon_sym_enumExtension] = ACTIONS(5269),
    [sym_interface_keyword] = ACTIONS(5269),
    [anon_sym_controladdin] = ACTIONS(5269),
    [anon_sym_CONTROLADDIN] = ACTIONS(5269),
    [anon_sym_Controladdin] = ACTIONS(5269),
    [anon_sym_ControlAddIn] = ACTIONS(5269),
    [anon_sym_ControlAddin] = ACTIONS(5269),
    [anon_sym_controlAddIn] = ACTIONS(5269),
    [anon_sym_controlAddin] = ACTIONS(5269),
    [anon_sym_dotnet] = ACTIONS(5269),
    [anon_sym_DOTNET] = ACTIONS(5269),
    [anon_sym_Dotnet] = ACTIONS(5269),
    [anon_sym_DotNet] = ACTIONS(5269),
    [anon_sym_dotNet] = ACTIONS(5269),
    [sym_profile_keyword] = ACTIONS(5271),
    [anon_sym_profileextension] = ACTIONS(5269),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5269),
    [anon_sym_Profileextension] = ACTIONS(5269),
    [anon_sym_ProfileExtension] = ACTIONS(5269),
    [anon_sym_profileExtension] = ACTIONS(5269),
    [anon_sym_permissionset] = ACTIONS(5271),
    [anon_sym_PERMISSIONSET] = ACTIONS(5271),
    [anon_sym_Permissionset] = ACTIONS(5271),
    [anon_sym_PermissionSet] = ACTIONS(5271),
    [anon_sym_permissionSet] = ACTIONS(5271),
    [anon_sym_permissionsetextension] = ACTIONS(5269),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5269),
    [anon_sym_Permissionsetextension] = ACTIONS(5269),
    [anon_sym_PermissionSetExtension] = ACTIONS(5269),
    [anon_sym_permissionSetExtension] = ACTIONS(5269),
    [sym_entitlement_keyword] = ACTIONS(5269),
    [anon_sym_pagecustomization] = ACTIONS(5269),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5269),
    [anon_sym_Pagecustomization] = ACTIONS(5269),
    [anon_sym_PageCustomization] = ACTIONS(5269),
    [anon_sym_pageCustomization] = ACTIONS(5269),
    [sym_using_keyword] = ACTIONS(5269),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5269),
    [sym_preproc_close] = ACTIONS(5269),
  },
  [STATE(2023)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_DASH] = ACTIONS(4951),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(4959),
    [aux_sym__expression_token2] = ACTIONS(4961),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(4963),
    [anon_sym_div] = ACTIONS(4965),
    [anon_sym_DIV] = ACTIONS(4967),
    [anon_sym_Div] = ACTIONS(4969),
    [anon_sym_mod] = ACTIONS(4971),
    [anon_sym_MOD] = ACTIONS(4973),
    [anon_sym_Mod] = ACTIONS(4975),
    [anon_sym_PLUS] = ACTIONS(4977),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(2024)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_DASH] = ACTIONS(4951),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(4959),
    [aux_sym__expression_token2] = ACTIONS(4961),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(4963),
    [anon_sym_div] = ACTIONS(4965),
    [anon_sym_DIV] = ACTIONS(4967),
    [anon_sym_Div] = ACTIONS(4969),
    [anon_sym_mod] = ACTIONS(4971),
    [anon_sym_MOD] = ACTIONS(4973),
    [anon_sym_Mod] = ACTIONS(4975),
    [anon_sym_PLUS] = ACTIONS(4977),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(4979),
    [anon_sym_AND] = ACTIONS(4981),
    [anon_sym_And] = ACTIONS(4983),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(2025)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2326),
    [anon_sym_SEMI] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2328),
    [anon_sym_COLON] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(5209),
    [aux_sym_boolean_token1] = ACTIONS(2326),
    [aux_sym_boolean_token2] = ACTIONS(2326),
    [sym_decimal] = ACTIONS(2326),
    [anon_sym_LPAREN] = ACTIONS(2328),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2326),
    [aux_sym_basic_type_token21] = ACTIONS(2326),
    [aux_sym_basic_type_token22] = ACTIONS(2326),
    [aux_sym_basic_type_token48] = ACTIONS(2326),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2326),
    [anon_sym_POUNDif] = ACTIONS(2328),
    [anon_sym_POUNDIF] = ACTIONS(2328),
    [anon_sym_POUNDIf] = ACTIONS(2328),
    [anon_sym_not] = ACTIONS(2326),
    [anon_sym_NOT] = ACTIONS(2326),
    [anon_sym_Not] = ACTIONS(2326),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(5273),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2326),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2326),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(5235),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(5237),
    [anon_sym_AND] = ACTIONS(5239),
    [anon_sym_And] = ACTIONS(5241),
    [anon_sym_or] = ACTIONS(5243),
    [anon_sym_OR] = ACTIONS(5245),
    [anon_sym_Or] = ACTIONS(5247),
    [anon_sym_xor] = ACTIONS(5249),
    [anon_sym_XOR] = ACTIONS(5251),
    [anon_sym_Xor] = ACTIONS(5253),
    [anon_sym_QMARK] = ACTIONS(5255),
    [sym_datetime_literal] = ACTIONS(2328),
    [sym_date_literal] = ACTIONS(2326),
    [sym_time_literal] = ACTIONS(2326),
    [sym_biginteger_literal] = ACTIONS(2328),
    [anon_sym_else] = ACTIONS(2326),
    [anon_sym_ELSE] = ACTIONS(2326),
    [anon_sym_Else] = ACTIONS(2326),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2326),
    [anon_sym_codeunit] = ACTIONS(2326),
    [anon_sym_CODEUNIT] = ACTIONS(2326),
    [anon_sym_Codeunit] = ACTIONS(2326),
    [anon_sym_CodeUnit] = ACTIONS(2326),
    [anon_sym_COdeunit] = ACTIONS(2326),
    [anon_sym_codeUnit] = ACTIONS(2326),
    [sym_report_keyword] = ACTIONS(2326),
    [sym_query_keyword] = ACTIONS(2326),
    [anon_sym_xmlport] = ACTIONS(2326),
    [anon_sym_XMLPORT] = ACTIONS(2326),
    [anon_sym_Xmlport] = ACTIONS(2326),
    [anon_sym_XMLport] = ACTIONS(2326),
    [anon_sym_XMLPort] = ACTIONS(2326),
    [anon_sym_XmlPort] = ACTIONS(2326),
    [anon_sym_enum] = ACTIONS(2326),
    [anon_sym_ENUM] = ACTIONS(2326),
    [anon_sym_Enum] = ACTIONS(2326),
    [anon_sym_eNUM] = ACTIONS(2326),
    [anon_sym_eNum] = ACTIONS(2326),
    [anon_sym_ENum] = ACTIONS(2326),
    [sym_quoted_identifier] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2328),
    [sym_integer] = ACTIONS(2326),
    [sym_continue_as_identifier] = ACTIONS(2328),
    [sym_preproc_open] = ACTIONS(2328),
  },
  [STATE(2026)] = {
    [anon_sym_POUNDif] = ACTIONS(5275),
    [anon_sym_POUNDIF] = ACTIONS(5275),
    [anon_sym_POUNDIf] = ACTIONS(5275),
    [anon_sym_POUNDelif] = ACTIONS(5275),
    [anon_sym_POUNDELIF] = ACTIONS(5275),
    [anon_sym_POUNDElif] = ACTIONS(5275),
    [anon_sym_POUNDelse] = ACTIONS(5275),
    [anon_sym_POUNDELSE] = ACTIONS(5275),
    [anon_sym_POUNDElse] = ACTIONS(5275),
    [anon_sym_POUNDendif] = ACTIONS(5275),
    [anon_sym_POUNDENDIF] = ACTIONS(5275),
    [anon_sym_POUNDEndif] = ACTIONS(5275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5277),
    [anon_sym_tableextension] = ACTIONS(5275),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5275),
    [anon_sym_Tableextension] = ACTIONS(5275),
    [anon_sym_TableExtension] = ACTIONS(5275),
    [anon_sym_tableExtension] = ACTIONS(5275),
    [sym_page_keyword] = ACTIONS(5277),
    [anon_sym_pageextension] = ACTIONS(5275),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5275),
    [anon_sym_Pageextension] = ACTIONS(5275),
    [anon_sym_PageExtension] = ACTIONS(5275),
    [anon_sym_pageExtension] = ACTIONS(5275),
    [anon_sym_codeunit] = ACTIONS(5275),
    [anon_sym_CODEUNIT] = ACTIONS(5275),
    [anon_sym_Codeunit] = ACTIONS(5275),
    [anon_sym_CodeUnit] = ACTIONS(5275),
    [anon_sym_COdeunit] = ACTIONS(5275),
    [anon_sym_codeUnit] = ACTIONS(5275),
    [sym_report_keyword] = ACTIONS(5277),
    [anon_sym_reportextension] = ACTIONS(5275),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5275),
    [anon_sym_Reportextension] = ACTIONS(5275),
    [anon_sym_ReportExtension] = ACTIONS(5275),
    [anon_sym_reportExtension] = ACTIONS(5275),
    [sym_query_keyword] = ACTIONS(5275),
    [anon_sym_xmlport] = ACTIONS(5275),
    [anon_sym_XMLPORT] = ACTIONS(5275),
    [anon_sym_Xmlport] = ACTIONS(5275),
    [anon_sym_XMLport] = ACTIONS(5275),
    [anon_sym_XMLPort] = ACTIONS(5275),
    [anon_sym_XmlPort] = ACTIONS(5275),
    [anon_sym_enum] = ACTIONS(5277),
    [anon_sym_ENUM] = ACTIONS(5277),
    [anon_sym_Enum] = ACTIONS(5277),
    [anon_sym_eNUM] = ACTIONS(5275),
    [anon_sym_eNum] = ACTIONS(5275),
    [anon_sym_ENum] = ACTIONS(5275),
    [anon_sym_enumextension] = ACTIONS(5275),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5275),
    [anon_sym_Enumextension] = ACTIONS(5275),
    [anon_sym_EnumExtension] = ACTIONS(5275),
    [anon_sym_enumExtension] = ACTIONS(5275),
    [sym_interface_keyword] = ACTIONS(5275),
    [anon_sym_controladdin] = ACTIONS(5275),
    [anon_sym_CONTROLADDIN] = ACTIONS(5275),
    [anon_sym_Controladdin] = ACTIONS(5275),
    [anon_sym_ControlAddIn] = ACTIONS(5275),
    [anon_sym_ControlAddin] = ACTIONS(5275),
    [anon_sym_controlAddIn] = ACTIONS(5275),
    [anon_sym_controlAddin] = ACTIONS(5275),
    [anon_sym_dotnet] = ACTIONS(5275),
    [anon_sym_DOTNET] = ACTIONS(5275),
    [anon_sym_Dotnet] = ACTIONS(5275),
    [anon_sym_DotNet] = ACTIONS(5275),
    [anon_sym_dotNet] = ACTIONS(5275),
    [sym_profile_keyword] = ACTIONS(5277),
    [anon_sym_profileextension] = ACTIONS(5275),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5275),
    [anon_sym_Profileextension] = ACTIONS(5275),
    [anon_sym_ProfileExtension] = ACTIONS(5275),
    [anon_sym_profileExtension] = ACTIONS(5275),
    [anon_sym_permissionset] = ACTIONS(5277),
    [anon_sym_PERMISSIONSET] = ACTIONS(5277),
    [anon_sym_Permissionset] = ACTIONS(5277),
    [anon_sym_PermissionSet] = ACTIONS(5277),
    [anon_sym_permissionSet] = ACTIONS(5277),
    [anon_sym_permissionsetextension] = ACTIONS(5275),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5275),
    [anon_sym_Permissionsetextension] = ACTIONS(5275),
    [anon_sym_PermissionSetExtension] = ACTIONS(5275),
    [anon_sym_permissionSetExtension] = ACTIONS(5275),
    [sym_entitlement_keyword] = ACTIONS(5275),
    [anon_sym_pagecustomization] = ACTIONS(5275),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5275),
    [anon_sym_Pagecustomization] = ACTIONS(5275),
    [anon_sym_PageCustomization] = ACTIONS(5275),
    [anon_sym_pageCustomization] = ACTIONS(5275),
    [sym_using_keyword] = ACTIONS(5275),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5275),
    [sym_preproc_close] = ACTIONS(5275),
  },
  [STATE(2027)] = {
    [anon_sym_POUNDif] = ACTIONS(5279),
    [anon_sym_POUNDIF] = ACTIONS(5279),
    [anon_sym_POUNDIf] = ACTIONS(5279),
    [anon_sym_POUNDelif] = ACTIONS(5279),
    [anon_sym_POUNDELIF] = ACTIONS(5279),
    [anon_sym_POUNDElif] = ACTIONS(5279),
    [anon_sym_POUNDelse] = ACTIONS(5279),
    [anon_sym_POUNDELSE] = ACTIONS(5279),
    [anon_sym_POUNDElse] = ACTIONS(5279),
    [anon_sym_POUNDendif] = ACTIONS(5279),
    [anon_sym_POUNDENDIF] = ACTIONS(5279),
    [anon_sym_POUNDEndif] = ACTIONS(5279),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5281),
    [anon_sym_tableextension] = ACTIONS(5279),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5279),
    [anon_sym_Tableextension] = ACTIONS(5279),
    [anon_sym_TableExtension] = ACTIONS(5279),
    [anon_sym_tableExtension] = ACTIONS(5279),
    [sym_page_keyword] = ACTIONS(5281),
    [anon_sym_pageextension] = ACTIONS(5279),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5279),
    [anon_sym_Pageextension] = ACTIONS(5279),
    [anon_sym_PageExtension] = ACTIONS(5279),
    [anon_sym_pageExtension] = ACTIONS(5279),
    [anon_sym_codeunit] = ACTIONS(5279),
    [anon_sym_CODEUNIT] = ACTIONS(5279),
    [anon_sym_Codeunit] = ACTIONS(5279),
    [anon_sym_CodeUnit] = ACTIONS(5279),
    [anon_sym_COdeunit] = ACTIONS(5279),
    [anon_sym_codeUnit] = ACTIONS(5279),
    [sym_report_keyword] = ACTIONS(5281),
    [anon_sym_reportextension] = ACTIONS(5279),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5279),
    [anon_sym_Reportextension] = ACTIONS(5279),
    [anon_sym_ReportExtension] = ACTIONS(5279),
    [anon_sym_reportExtension] = ACTIONS(5279),
    [sym_query_keyword] = ACTIONS(5279),
    [anon_sym_xmlport] = ACTIONS(5279),
    [anon_sym_XMLPORT] = ACTIONS(5279),
    [anon_sym_Xmlport] = ACTIONS(5279),
    [anon_sym_XMLport] = ACTIONS(5279),
    [anon_sym_XMLPort] = ACTIONS(5279),
    [anon_sym_XmlPort] = ACTIONS(5279),
    [anon_sym_enum] = ACTIONS(5281),
    [anon_sym_ENUM] = ACTIONS(5281),
    [anon_sym_Enum] = ACTIONS(5281),
    [anon_sym_eNUM] = ACTIONS(5279),
    [anon_sym_eNum] = ACTIONS(5279),
    [anon_sym_ENum] = ACTIONS(5279),
    [anon_sym_enumextension] = ACTIONS(5279),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5279),
    [anon_sym_Enumextension] = ACTIONS(5279),
    [anon_sym_EnumExtension] = ACTIONS(5279),
    [anon_sym_enumExtension] = ACTIONS(5279),
    [sym_interface_keyword] = ACTIONS(5279),
    [anon_sym_controladdin] = ACTIONS(5279),
    [anon_sym_CONTROLADDIN] = ACTIONS(5279),
    [anon_sym_Controladdin] = ACTIONS(5279),
    [anon_sym_ControlAddIn] = ACTIONS(5279),
    [anon_sym_ControlAddin] = ACTIONS(5279),
    [anon_sym_controlAddIn] = ACTIONS(5279),
    [anon_sym_controlAddin] = ACTIONS(5279),
    [anon_sym_dotnet] = ACTIONS(5279),
    [anon_sym_DOTNET] = ACTIONS(5279),
    [anon_sym_Dotnet] = ACTIONS(5279),
    [anon_sym_DotNet] = ACTIONS(5279),
    [anon_sym_dotNet] = ACTIONS(5279),
    [sym_profile_keyword] = ACTIONS(5281),
    [anon_sym_profileextension] = ACTIONS(5279),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5279),
    [anon_sym_Profileextension] = ACTIONS(5279),
    [anon_sym_ProfileExtension] = ACTIONS(5279),
    [anon_sym_profileExtension] = ACTIONS(5279),
    [anon_sym_permissionset] = ACTIONS(5281),
    [anon_sym_PERMISSIONSET] = ACTIONS(5281),
    [anon_sym_Permissionset] = ACTIONS(5281),
    [anon_sym_PermissionSet] = ACTIONS(5281),
    [anon_sym_permissionSet] = ACTIONS(5281),
    [anon_sym_permissionsetextension] = ACTIONS(5279),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5279),
    [anon_sym_Permissionsetextension] = ACTIONS(5279),
    [anon_sym_PermissionSetExtension] = ACTIONS(5279),
    [anon_sym_permissionSetExtension] = ACTIONS(5279),
    [sym_entitlement_keyword] = ACTIONS(5279),
    [anon_sym_pagecustomization] = ACTIONS(5279),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5279),
    [anon_sym_Pagecustomization] = ACTIONS(5279),
    [anon_sym_PageCustomization] = ACTIONS(5279),
    [anon_sym_pageCustomization] = ACTIONS(5279),
    [sym_using_keyword] = ACTIONS(5279),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5279),
    [sym_preproc_close] = ACTIONS(5279),
  },
  [STATE(2028)] = {
    [anon_sym_POUNDif] = ACTIONS(5283),
    [anon_sym_POUNDIF] = ACTIONS(5283),
    [anon_sym_POUNDIf] = ACTIONS(5283),
    [anon_sym_POUNDelif] = ACTIONS(5283),
    [anon_sym_POUNDELIF] = ACTIONS(5283),
    [anon_sym_POUNDElif] = ACTIONS(5283),
    [anon_sym_POUNDelse] = ACTIONS(5283),
    [anon_sym_POUNDELSE] = ACTIONS(5283),
    [anon_sym_POUNDElse] = ACTIONS(5283),
    [anon_sym_POUNDendif] = ACTIONS(5283),
    [anon_sym_POUNDENDIF] = ACTIONS(5283),
    [anon_sym_POUNDEndif] = ACTIONS(5283),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5285),
    [anon_sym_tableextension] = ACTIONS(5283),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5283),
    [anon_sym_Tableextension] = ACTIONS(5283),
    [anon_sym_TableExtension] = ACTIONS(5283),
    [anon_sym_tableExtension] = ACTIONS(5283),
    [sym_page_keyword] = ACTIONS(5285),
    [anon_sym_pageextension] = ACTIONS(5283),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5283),
    [anon_sym_Pageextension] = ACTIONS(5283),
    [anon_sym_PageExtension] = ACTIONS(5283),
    [anon_sym_pageExtension] = ACTIONS(5283),
    [anon_sym_codeunit] = ACTIONS(5283),
    [anon_sym_CODEUNIT] = ACTIONS(5283),
    [anon_sym_Codeunit] = ACTIONS(5283),
    [anon_sym_CodeUnit] = ACTIONS(5283),
    [anon_sym_COdeunit] = ACTIONS(5283),
    [anon_sym_codeUnit] = ACTIONS(5283),
    [sym_report_keyword] = ACTIONS(5285),
    [anon_sym_reportextension] = ACTIONS(5283),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5283),
    [anon_sym_Reportextension] = ACTIONS(5283),
    [anon_sym_ReportExtension] = ACTIONS(5283),
    [anon_sym_reportExtension] = ACTIONS(5283),
    [sym_query_keyword] = ACTIONS(5283),
    [anon_sym_xmlport] = ACTIONS(5283),
    [anon_sym_XMLPORT] = ACTIONS(5283),
    [anon_sym_Xmlport] = ACTIONS(5283),
    [anon_sym_XMLport] = ACTIONS(5283),
    [anon_sym_XMLPort] = ACTIONS(5283),
    [anon_sym_XmlPort] = ACTIONS(5283),
    [anon_sym_enum] = ACTIONS(5285),
    [anon_sym_ENUM] = ACTIONS(5285),
    [anon_sym_Enum] = ACTIONS(5285),
    [anon_sym_eNUM] = ACTIONS(5283),
    [anon_sym_eNum] = ACTIONS(5283),
    [anon_sym_ENum] = ACTIONS(5283),
    [anon_sym_enumextension] = ACTIONS(5283),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5283),
    [anon_sym_Enumextension] = ACTIONS(5283),
    [anon_sym_EnumExtension] = ACTIONS(5283),
    [anon_sym_enumExtension] = ACTIONS(5283),
    [sym_interface_keyword] = ACTIONS(5283),
    [anon_sym_controladdin] = ACTIONS(5283),
    [anon_sym_CONTROLADDIN] = ACTIONS(5283),
    [anon_sym_Controladdin] = ACTIONS(5283),
    [anon_sym_ControlAddIn] = ACTIONS(5283),
    [anon_sym_ControlAddin] = ACTIONS(5283),
    [anon_sym_controlAddIn] = ACTIONS(5283),
    [anon_sym_controlAddin] = ACTIONS(5283),
    [anon_sym_dotnet] = ACTIONS(5283),
    [anon_sym_DOTNET] = ACTIONS(5283),
    [anon_sym_Dotnet] = ACTIONS(5283),
    [anon_sym_DotNet] = ACTIONS(5283),
    [anon_sym_dotNet] = ACTIONS(5283),
    [sym_profile_keyword] = ACTIONS(5285),
    [anon_sym_profileextension] = ACTIONS(5283),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5283),
    [anon_sym_Profileextension] = ACTIONS(5283),
    [anon_sym_ProfileExtension] = ACTIONS(5283),
    [anon_sym_profileExtension] = ACTIONS(5283),
    [anon_sym_permissionset] = ACTIONS(5285),
    [anon_sym_PERMISSIONSET] = ACTIONS(5285),
    [anon_sym_Permissionset] = ACTIONS(5285),
    [anon_sym_PermissionSet] = ACTIONS(5285),
    [anon_sym_permissionSet] = ACTIONS(5285),
    [anon_sym_permissionsetextension] = ACTIONS(5283),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5283),
    [anon_sym_Permissionsetextension] = ACTIONS(5283),
    [anon_sym_PermissionSetExtension] = ACTIONS(5283),
    [anon_sym_permissionSetExtension] = ACTIONS(5283),
    [sym_entitlement_keyword] = ACTIONS(5283),
    [anon_sym_pagecustomization] = ACTIONS(5283),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5283),
    [anon_sym_Pagecustomization] = ACTIONS(5283),
    [anon_sym_PageCustomization] = ACTIONS(5283),
    [anon_sym_pageCustomization] = ACTIONS(5283),
    [sym_using_keyword] = ACTIONS(5283),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5283),
    [sym_preproc_close] = ACTIONS(5283),
  },
  [STATE(2029)] = {
    [anon_sym_POUNDif] = ACTIONS(5287),
    [anon_sym_POUNDIF] = ACTIONS(5287),
    [anon_sym_POUNDIf] = ACTIONS(5287),
    [anon_sym_POUNDelif] = ACTIONS(5287),
    [anon_sym_POUNDELIF] = ACTIONS(5287),
    [anon_sym_POUNDElif] = ACTIONS(5287),
    [anon_sym_POUNDelse] = ACTIONS(5287),
    [anon_sym_POUNDELSE] = ACTIONS(5287),
    [anon_sym_POUNDElse] = ACTIONS(5287),
    [anon_sym_POUNDendif] = ACTIONS(5287),
    [anon_sym_POUNDENDIF] = ACTIONS(5287),
    [anon_sym_POUNDEndif] = ACTIONS(5287),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5289),
    [anon_sym_tableextension] = ACTIONS(5287),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5287),
    [anon_sym_Tableextension] = ACTIONS(5287),
    [anon_sym_TableExtension] = ACTIONS(5287),
    [anon_sym_tableExtension] = ACTIONS(5287),
    [sym_page_keyword] = ACTIONS(5289),
    [anon_sym_pageextension] = ACTIONS(5287),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5287),
    [anon_sym_Pageextension] = ACTIONS(5287),
    [anon_sym_PageExtension] = ACTIONS(5287),
    [anon_sym_pageExtension] = ACTIONS(5287),
    [anon_sym_codeunit] = ACTIONS(5287),
    [anon_sym_CODEUNIT] = ACTIONS(5287),
    [anon_sym_Codeunit] = ACTIONS(5287),
    [anon_sym_CodeUnit] = ACTIONS(5287),
    [anon_sym_COdeunit] = ACTIONS(5287),
    [anon_sym_codeUnit] = ACTIONS(5287),
    [sym_report_keyword] = ACTIONS(5289),
    [anon_sym_reportextension] = ACTIONS(5287),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5287),
    [anon_sym_Reportextension] = ACTIONS(5287),
    [anon_sym_ReportExtension] = ACTIONS(5287),
    [anon_sym_reportExtension] = ACTIONS(5287),
    [sym_query_keyword] = ACTIONS(5287),
    [anon_sym_xmlport] = ACTIONS(5287),
    [anon_sym_XMLPORT] = ACTIONS(5287),
    [anon_sym_Xmlport] = ACTIONS(5287),
    [anon_sym_XMLport] = ACTIONS(5287),
    [anon_sym_XMLPort] = ACTIONS(5287),
    [anon_sym_XmlPort] = ACTIONS(5287),
    [anon_sym_enum] = ACTIONS(5289),
    [anon_sym_ENUM] = ACTIONS(5289),
    [anon_sym_Enum] = ACTIONS(5289),
    [anon_sym_eNUM] = ACTIONS(5287),
    [anon_sym_eNum] = ACTIONS(5287),
    [anon_sym_ENum] = ACTIONS(5287),
    [anon_sym_enumextension] = ACTIONS(5287),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5287),
    [anon_sym_Enumextension] = ACTIONS(5287),
    [anon_sym_EnumExtension] = ACTIONS(5287),
    [anon_sym_enumExtension] = ACTIONS(5287),
    [sym_interface_keyword] = ACTIONS(5287),
    [anon_sym_controladdin] = ACTIONS(5287),
    [anon_sym_CONTROLADDIN] = ACTIONS(5287),
    [anon_sym_Controladdin] = ACTIONS(5287),
    [anon_sym_ControlAddIn] = ACTIONS(5287),
    [anon_sym_ControlAddin] = ACTIONS(5287),
    [anon_sym_controlAddIn] = ACTIONS(5287),
    [anon_sym_controlAddin] = ACTIONS(5287),
    [anon_sym_dotnet] = ACTIONS(5287),
    [anon_sym_DOTNET] = ACTIONS(5287),
    [anon_sym_Dotnet] = ACTIONS(5287),
    [anon_sym_DotNet] = ACTIONS(5287),
    [anon_sym_dotNet] = ACTIONS(5287),
    [sym_profile_keyword] = ACTIONS(5289),
    [anon_sym_profileextension] = ACTIONS(5287),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5287),
    [anon_sym_Profileextension] = ACTIONS(5287),
    [anon_sym_ProfileExtension] = ACTIONS(5287),
    [anon_sym_profileExtension] = ACTIONS(5287),
    [anon_sym_permissionset] = ACTIONS(5289),
    [anon_sym_PERMISSIONSET] = ACTIONS(5289),
    [anon_sym_Permissionset] = ACTIONS(5289),
    [anon_sym_PermissionSet] = ACTIONS(5289),
    [anon_sym_permissionSet] = ACTIONS(5289),
    [anon_sym_permissionsetextension] = ACTIONS(5287),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5287),
    [anon_sym_Permissionsetextension] = ACTIONS(5287),
    [anon_sym_PermissionSetExtension] = ACTIONS(5287),
    [anon_sym_permissionSetExtension] = ACTIONS(5287),
    [sym_entitlement_keyword] = ACTIONS(5287),
    [anon_sym_pagecustomization] = ACTIONS(5287),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5287),
    [anon_sym_Pagecustomization] = ACTIONS(5287),
    [anon_sym_PageCustomization] = ACTIONS(5287),
    [anon_sym_pageCustomization] = ACTIONS(5287),
    [sym_using_keyword] = ACTIONS(5287),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5287),
    [sym_preproc_close] = ACTIONS(5287),
  },
  [STATE(2030)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2360),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2362),
    [anon_sym_COMMA] = ACTIONS(2362),
    [anon_sym_DASH] = ACTIONS(2360),
    [aux_sym_boolean_token1] = ACTIONS(2360),
    [aux_sym_boolean_token2] = ACTIONS(2360),
    [sym_decimal] = ACTIONS(2360),
    [anon_sym_LPAREN] = ACTIONS(2362),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2360),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2360),
    [aux_sym_basic_type_token21] = ACTIONS(2360),
    [aux_sym_basic_type_token22] = ACTIONS(2360),
    [aux_sym_basic_type_token48] = ACTIONS(2360),
    [anon_sym_not] = ACTIONS(2360),
    [anon_sym_NOT] = ACTIONS(2360),
    [anon_sym_Not] = ACTIONS(2360),
    [anon_sym_POUNDelif] = ACTIONS(2362),
    [anon_sym_POUNDELIF] = ACTIONS(2362),
    [anon_sym_POUNDElif] = ACTIONS(2362),
    [anon_sym_POUNDelse] = ACTIONS(2362),
    [anon_sym_POUNDELSE] = ACTIONS(2362),
    [anon_sym_POUNDElse] = ACTIONS(2362),
    [anon_sym_POUNDendif] = ACTIONS(2362),
    [anon_sym_POUNDENDIF] = ACTIONS(2362),
    [anon_sym_POUNDEndif] = ACTIONS(2362),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2362),
    [aux_sym__expression_token1] = ACTIONS(2362),
    [aux_sym__expression_token2] = ACTIONS(2362),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2360),
    [anon_sym_SLASH] = ACTIONS(4963),
    [anon_sym_div] = ACTIONS(4965),
    [anon_sym_DIV] = ACTIONS(4967),
    [anon_sym_Div] = ACTIONS(4969),
    [anon_sym_mod] = ACTIONS(4971),
    [anon_sym_MOD] = ACTIONS(4973),
    [anon_sym_Mod] = ACTIONS(4975),
    [anon_sym_PLUS] = ACTIONS(2360),
    [anon_sym_GT_EQ] = ACTIONS(2362),
    [anon_sym_LT_EQ] = ACTIONS(2362),
    [anon_sym_GT] = ACTIONS(2360),
    [anon_sym_LT] = ACTIONS(2360),
    [anon_sym_LT_GT] = ACTIONS(2362),
    [anon_sym_and] = ACTIONS(2360),
    [anon_sym_AND] = ACTIONS(2360),
    [anon_sym_And] = ACTIONS(2360),
    [anon_sym_or] = ACTIONS(2360),
    [anon_sym_OR] = ACTIONS(2360),
    [anon_sym_Or] = ACTIONS(2360),
    [anon_sym_xor] = ACTIONS(2360),
    [anon_sym_XOR] = ACTIONS(2360),
    [anon_sym_Xor] = ACTIONS(2360),
    [anon_sym_QMARK] = ACTIONS(2362),
    [sym_datetime_literal] = ACTIONS(2362),
    [sym_date_literal] = ACTIONS(2360),
    [sym_time_literal] = ACTIONS(2360),
    [sym_biginteger_literal] = ACTIONS(2362),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_IN] = ACTIONS(2360),
    [anon_sym_In] = ACTIONS(2360),
    [sym_page_keyword] = ACTIONS(2360),
    [anon_sym_codeunit] = ACTIONS(2360),
    [anon_sym_CODEUNIT] = ACTIONS(2360),
    [anon_sym_Codeunit] = ACTIONS(2360),
    [anon_sym_CodeUnit] = ACTIONS(2360),
    [anon_sym_COdeunit] = ACTIONS(2360),
    [anon_sym_codeUnit] = ACTIONS(2360),
    [sym_report_keyword] = ACTIONS(2360),
    [sym_query_keyword] = ACTIONS(2360),
    [anon_sym_xmlport] = ACTIONS(2360),
    [anon_sym_XMLPORT] = ACTIONS(2360),
    [anon_sym_Xmlport] = ACTIONS(2360),
    [anon_sym_XMLport] = ACTIONS(2360),
    [anon_sym_XMLPort] = ACTIONS(2360),
    [anon_sym_XmlPort] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_ENUM] = ACTIONS(2360),
    [anon_sym_Enum] = ACTIONS(2360),
    [anon_sym_eNUM] = ACTIONS(2360),
    [anon_sym_eNum] = ACTIONS(2360),
    [anon_sym_ENum] = ACTIONS(2360),
    [sym_quoted_identifier] = ACTIONS(2362),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2362),
    [sym_integer] = ACTIONS(2360),
    [sym_continue_as_identifier] = ACTIONS(2362),
    [sym_preproc_close] = ACTIONS(2362),
  },
  [STATE(2031)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2316),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2318),
    [anon_sym_COMMA] = ACTIONS(2318),
    [anon_sym_DASH] = ACTIONS(2316),
    [aux_sym_boolean_token1] = ACTIONS(2316),
    [aux_sym_boolean_token2] = ACTIONS(2316),
    [sym_decimal] = ACTIONS(2316),
    [anon_sym_LPAREN] = ACTIONS(2318),
    [anon_sym_DOT_DOT] = ACTIONS(2318),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2316),
    [anon_sym_STAR] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2316),
    [aux_sym_basic_type_token21] = ACTIONS(2316),
    [aux_sym_basic_type_token22] = ACTIONS(2316),
    [aux_sym_basic_type_token48] = ACTIONS(2316),
    [anon_sym_not] = ACTIONS(2316),
    [anon_sym_NOT] = ACTIONS(2316),
    [anon_sym_Not] = ACTIONS(2316),
    [anon_sym_POUNDelif] = ACTIONS(2318),
    [anon_sym_POUNDELIF] = ACTIONS(2318),
    [anon_sym_POUNDElif] = ACTIONS(2318),
    [anon_sym_POUNDelse] = ACTIONS(2318),
    [anon_sym_POUNDELSE] = ACTIONS(2318),
    [anon_sym_POUNDElse] = ACTIONS(2318),
    [anon_sym_POUNDendif] = ACTIONS(2318),
    [anon_sym_POUNDENDIF] = ACTIONS(2318),
    [anon_sym_POUNDEndif] = ACTIONS(2318),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2318),
    [aux_sym__expression_token1] = ACTIONS(2318),
    [aux_sym__expression_token2] = ACTIONS(2318),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2316),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2316),
    [anon_sym_SLASH] = ACTIONS(2316),
    [anon_sym_div] = ACTIONS(2316),
    [anon_sym_DIV] = ACTIONS(2316),
    [anon_sym_Div] = ACTIONS(2316),
    [anon_sym_mod] = ACTIONS(2316),
    [anon_sym_MOD] = ACTIONS(2316),
    [anon_sym_Mod] = ACTIONS(2316),
    [anon_sym_PLUS] = ACTIONS(2316),
    [anon_sym_GT_EQ] = ACTIONS(2318),
    [anon_sym_LT_EQ] = ACTIONS(2318),
    [anon_sym_GT] = ACTIONS(2316),
    [anon_sym_LT] = ACTIONS(2316),
    [anon_sym_LT_GT] = ACTIONS(2318),
    [anon_sym_and] = ACTIONS(2316),
    [anon_sym_AND] = ACTIONS(2316),
    [anon_sym_And] = ACTIONS(2316),
    [anon_sym_or] = ACTIONS(2316),
    [anon_sym_OR] = ACTIONS(2316),
    [anon_sym_Or] = ACTIONS(2316),
    [anon_sym_xor] = ACTIONS(2316),
    [anon_sym_XOR] = ACTIONS(2316),
    [anon_sym_Xor] = ACTIONS(2316),
    [anon_sym_QMARK] = ACTIONS(2318),
    [sym_datetime_literal] = ACTIONS(2318),
    [sym_date_literal] = ACTIONS(2316),
    [sym_time_literal] = ACTIONS(2316),
    [sym_biginteger_literal] = ACTIONS(2318),
    [anon_sym_in] = ACTIONS(2316),
    [anon_sym_IN] = ACTIONS(2316),
    [anon_sym_In] = ACTIONS(2316),
    [sym_page_keyword] = ACTIONS(2316),
    [anon_sym_codeunit] = ACTIONS(2316),
    [anon_sym_CODEUNIT] = ACTIONS(2316),
    [anon_sym_Codeunit] = ACTIONS(2316),
    [anon_sym_CodeUnit] = ACTIONS(2316),
    [anon_sym_COdeunit] = ACTIONS(2316),
    [anon_sym_codeUnit] = ACTIONS(2316),
    [sym_report_keyword] = ACTIONS(2316),
    [sym_query_keyword] = ACTIONS(2316),
    [anon_sym_xmlport] = ACTIONS(2316),
    [anon_sym_XMLPORT] = ACTIONS(2316),
    [anon_sym_Xmlport] = ACTIONS(2316),
    [anon_sym_XMLport] = ACTIONS(2316),
    [anon_sym_XMLPort] = ACTIONS(2316),
    [anon_sym_XmlPort] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_ENUM] = ACTIONS(2316),
    [anon_sym_Enum] = ACTIONS(2316),
    [anon_sym_eNUM] = ACTIONS(2316),
    [anon_sym_eNum] = ACTIONS(2316),
    [anon_sym_ENum] = ACTIONS(2316),
    [sym_quoted_identifier] = ACTIONS(2318),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2318),
    [sym_integer] = ACTIONS(2316),
    [sym_continue_as_identifier] = ACTIONS(2318),
    [sym_preproc_close] = ACTIONS(2318),
  },
  [STATE(2032)] = {
    [sym_argument_list] = STATE(2093),
    [sym_identifier] = ACTIONS(4658),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_COMMA] = ACTIONS(4660),
    [anon_sym_DASH] = ACTIONS(4662),
    [aux_sym_boolean_token1] = ACTIONS(4658),
    [aux_sym_boolean_token2] = ACTIONS(4658),
    [sym_decimal] = ACTIONS(4658),
    [anon_sym_LPAREN] = ACTIONS(5257),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4658),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(4665),
    [aux_sym_record_type_token1] = ACTIONS(4658),
    [aux_sym_basic_type_token21] = ACTIONS(4658),
    [aux_sym_basic_type_token22] = ACTIONS(4658),
    [aux_sym_basic_type_token48] = ACTIONS(4658),
    [anon_sym_COLON_COLON] = ACTIONS(5259),
    [anon_sym_not] = ACTIONS(4658),
    [anon_sym_NOT] = ACTIONS(4658),
    [anon_sym_Not] = ACTIONS(4658),
    [anon_sym_POUNDelif] = ACTIONS(4660),
    [anon_sym_POUNDELIF] = ACTIONS(4660),
    [anon_sym_POUNDElif] = ACTIONS(4660),
    [anon_sym_POUNDelse] = ACTIONS(4660),
    [anon_sym_POUNDELSE] = ACTIONS(4660),
    [anon_sym_POUNDElse] = ACTIONS(4660),
    [anon_sym_POUNDendif] = ACTIONS(4660),
    [anon_sym_POUNDENDIF] = ACTIONS(4660),
    [anon_sym_POUNDEndif] = ACTIONS(4660),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4658),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4658),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(4662),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(4660),
    [sym_date_literal] = ACTIONS(4658),
    [sym_time_literal] = ACTIONS(4658),
    [sym_biginteger_literal] = ACTIONS(4660),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(4658),
    [anon_sym_codeunit] = ACTIONS(4658),
    [anon_sym_CODEUNIT] = ACTIONS(4658),
    [anon_sym_Codeunit] = ACTIONS(4658),
    [anon_sym_CodeUnit] = ACTIONS(4658),
    [anon_sym_COdeunit] = ACTIONS(4658),
    [anon_sym_codeUnit] = ACTIONS(4658),
    [sym_report_keyword] = ACTIONS(4658),
    [sym_query_keyword] = ACTIONS(4658),
    [anon_sym_xmlport] = ACTIONS(4658),
    [anon_sym_XMLPORT] = ACTIONS(4658),
    [anon_sym_Xmlport] = ACTIONS(4658),
    [anon_sym_XMLport] = ACTIONS(4658),
    [anon_sym_XMLPort] = ACTIONS(4658),
    [anon_sym_XmlPort] = ACTIONS(4658),
    [anon_sym_enum] = ACTIONS(4658),
    [anon_sym_ENUM] = ACTIONS(4658),
    [anon_sym_Enum] = ACTIONS(4658),
    [anon_sym_eNUM] = ACTIONS(4658),
    [anon_sym_eNum] = ACTIONS(4658),
    [anon_sym_ENum] = ACTIONS(4658),
    [sym_quoted_identifier] = ACTIONS(4660),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4660),
    [sym_integer] = ACTIONS(4658),
    [sym_continue_as_identifier] = ACTIONS(4660),
    [sym_preproc_close] = ACTIONS(4660),
  },
  [STATE(2033)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2368),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2370),
    [anon_sym_DASH] = ACTIONS(4951),
    [aux_sym_boolean_token1] = ACTIONS(2368),
    [aux_sym_boolean_token2] = ACTIONS(2368),
    [sym_decimal] = ACTIONS(2368),
    [anon_sym_LPAREN] = ACTIONS(2370),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2368),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2368),
    [aux_sym_basic_type_token21] = ACTIONS(2368),
    [aux_sym_basic_type_token22] = ACTIONS(2368),
    [aux_sym_basic_type_token48] = ACTIONS(2368),
    [anon_sym_not] = ACTIONS(2368),
    [anon_sym_NOT] = ACTIONS(2368),
    [anon_sym_Not] = ACTIONS(2368),
    [anon_sym_POUNDelif] = ACTIONS(2370),
    [anon_sym_POUNDELIF] = ACTIONS(2370),
    [anon_sym_POUNDElif] = ACTIONS(2370),
    [anon_sym_POUNDelse] = ACTIONS(2370),
    [anon_sym_POUNDELSE] = ACTIONS(2370),
    [anon_sym_POUNDElse] = ACTIONS(2370),
    [anon_sym_POUNDendif] = ACTIONS(2370),
    [anon_sym_POUNDENDIF] = ACTIONS(2370),
    [anon_sym_POUNDEndif] = ACTIONS(2370),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2370),
    [aux_sym__expression_token1] = ACTIONS(4959),
    [aux_sym__expression_token2] = ACTIONS(4961),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2368),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2368),
    [anon_sym_SLASH] = ACTIONS(4963),
    [anon_sym_div] = ACTIONS(4965),
    [anon_sym_DIV] = ACTIONS(4967),
    [anon_sym_Div] = ACTIONS(4969),
    [anon_sym_mod] = ACTIONS(4971),
    [anon_sym_MOD] = ACTIONS(4973),
    [anon_sym_Mod] = ACTIONS(4975),
    [anon_sym_PLUS] = ACTIONS(4977),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(4979),
    [anon_sym_AND] = ACTIONS(4981),
    [anon_sym_And] = ACTIONS(4983),
    [anon_sym_or] = ACTIONS(5291),
    [anon_sym_OR] = ACTIONS(5293),
    [anon_sym_Or] = ACTIONS(5295),
    [anon_sym_xor] = ACTIONS(5297),
    [anon_sym_XOR] = ACTIONS(5299),
    [anon_sym_Xor] = ACTIONS(5301),
    [anon_sym_QMARK] = ACTIONS(5303),
    [sym_datetime_literal] = ACTIONS(2370),
    [sym_date_literal] = ACTIONS(2368),
    [sym_time_literal] = ACTIONS(2368),
    [sym_biginteger_literal] = ACTIONS(2370),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2368),
    [anon_sym_codeunit] = ACTIONS(2368),
    [anon_sym_CODEUNIT] = ACTIONS(2368),
    [anon_sym_Codeunit] = ACTIONS(2368),
    [anon_sym_CodeUnit] = ACTIONS(2368),
    [anon_sym_COdeunit] = ACTIONS(2368),
    [anon_sym_codeUnit] = ACTIONS(2368),
    [sym_report_keyword] = ACTIONS(2368),
    [sym_query_keyword] = ACTIONS(2368),
    [anon_sym_xmlport] = ACTIONS(2368),
    [anon_sym_XMLPORT] = ACTIONS(2368),
    [anon_sym_Xmlport] = ACTIONS(2368),
    [anon_sym_XMLport] = ACTIONS(2368),
    [anon_sym_XMLPort] = ACTIONS(2368),
    [anon_sym_XmlPort] = ACTIONS(2368),
    [anon_sym_enum] = ACTIONS(2368),
    [anon_sym_ENUM] = ACTIONS(2368),
    [anon_sym_Enum] = ACTIONS(2368),
    [anon_sym_eNUM] = ACTIONS(2368),
    [anon_sym_eNum] = ACTIONS(2368),
    [anon_sym_ENum] = ACTIONS(2368),
    [sym_quoted_identifier] = ACTIONS(2370),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2370),
    [sym_integer] = ACTIONS(2368),
    [sym_continue_as_identifier] = ACTIONS(2370),
    [sym_preproc_close] = ACTIONS(2370),
  },
  [STATE(2034)] = {
    [anon_sym_POUNDif] = ACTIONS(5305),
    [anon_sym_POUNDIF] = ACTIONS(5305),
    [anon_sym_POUNDIf] = ACTIONS(5305),
    [anon_sym_POUNDelif] = ACTIONS(5305),
    [anon_sym_POUNDELIF] = ACTIONS(5305),
    [anon_sym_POUNDElif] = ACTIONS(5305),
    [anon_sym_POUNDelse] = ACTIONS(5305),
    [anon_sym_POUNDELSE] = ACTIONS(5305),
    [anon_sym_POUNDElse] = ACTIONS(5305),
    [anon_sym_POUNDendif] = ACTIONS(5305),
    [anon_sym_POUNDENDIF] = ACTIONS(5305),
    [anon_sym_POUNDEndif] = ACTIONS(5305),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5307),
    [anon_sym_tableextension] = ACTIONS(5305),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5305),
    [anon_sym_Tableextension] = ACTIONS(5305),
    [anon_sym_TableExtension] = ACTIONS(5305),
    [anon_sym_tableExtension] = ACTIONS(5305),
    [sym_page_keyword] = ACTIONS(5307),
    [anon_sym_pageextension] = ACTIONS(5305),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5305),
    [anon_sym_Pageextension] = ACTIONS(5305),
    [anon_sym_PageExtension] = ACTIONS(5305),
    [anon_sym_pageExtension] = ACTIONS(5305),
    [anon_sym_codeunit] = ACTIONS(5305),
    [anon_sym_CODEUNIT] = ACTIONS(5305),
    [anon_sym_Codeunit] = ACTIONS(5305),
    [anon_sym_CodeUnit] = ACTIONS(5305),
    [anon_sym_COdeunit] = ACTIONS(5305),
    [anon_sym_codeUnit] = ACTIONS(5305),
    [sym_report_keyword] = ACTIONS(5307),
    [anon_sym_reportextension] = ACTIONS(5305),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5305),
    [anon_sym_Reportextension] = ACTIONS(5305),
    [anon_sym_ReportExtension] = ACTIONS(5305),
    [anon_sym_reportExtension] = ACTIONS(5305),
    [sym_query_keyword] = ACTIONS(5305),
    [anon_sym_xmlport] = ACTIONS(5305),
    [anon_sym_XMLPORT] = ACTIONS(5305),
    [anon_sym_Xmlport] = ACTIONS(5305),
    [anon_sym_XMLport] = ACTIONS(5305),
    [anon_sym_XMLPort] = ACTIONS(5305),
    [anon_sym_XmlPort] = ACTIONS(5305),
    [anon_sym_enum] = ACTIONS(5307),
    [anon_sym_ENUM] = ACTIONS(5307),
    [anon_sym_Enum] = ACTIONS(5307),
    [anon_sym_eNUM] = ACTIONS(5305),
    [anon_sym_eNum] = ACTIONS(5305),
    [anon_sym_ENum] = ACTIONS(5305),
    [anon_sym_enumextension] = ACTIONS(5305),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5305),
    [anon_sym_Enumextension] = ACTIONS(5305),
    [anon_sym_EnumExtension] = ACTIONS(5305),
    [anon_sym_enumExtension] = ACTIONS(5305),
    [sym_interface_keyword] = ACTIONS(5305),
    [anon_sym_controladdin] = ACTIONS(5305),
    [anon_sym_CONTROLADDIN] = ACTIONS(5305),
    [anon_sym_Controladdin] = ACTIONS(5305),
    [anon_sym_ControlAddIn] = ACTIONS(5305),
    [anon_sym_ControlAddin] = ACTIONS(5305),
    [anon_sym_controlAddIn] = ACTIONS(5305),
    [anon_sym_controlAddin] = ACTIONS(5305),
    [anon_sym_dotnet] = ACTIONS(5305),
    [anon_sym_DOTNET] = ACTIONS(5305),
    [anon_sym_Dotnet] = ACTIONS(5305),
    [anon_sym_DotNet] = ACTIONS(5305),
    [anon_sym_dotNet] = ACTIONS(5305),
    [sym_profile_keyword] = ACTIONS(5307),
    [anon_sym_profileextension] = ACTIONS(5305),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5305),
    [anon_sym_Profileextension] = ACTIONS(5305),
    [anon_sym_ProfileExtension] = ACTIONS(5305),
    [anon_sym_profileExtension] = ACTIONS(5305),
    [anon_sym_permissionset] = ACTIONS(5307),
    [anon_sym_PERMISSIONSET] = ACTIONS(5307),
    [anon_sym_Permissionset] = ACTIONS(5307),
    [anon_sym_PermissionSet] = ACTIONS(5307),
    [anon_sym_permissionSet] = ACTIONS(5307),
    [anon_sym_permissionsetextension] = ACTIONS(5305),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5305),
    [anon_sym_Permissionsetextension] = ACTIONS(5305),
    [anon_sym_PermissionSetExtension] = ACTIONS(5305),
    [anon_sym_permissionSetExtension] = ACTIONS(5305),
    [sym_entitlement_keyword] = ACTIONS(5305),
    [anon_sym_pagecustomization] = ACTIONS(5305),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5305),
    [anon_sym_Pagecustomization] = ACTIONS(5305),
    [anon_sym_PageCustomization] = ACTIONS(5305),
    [anon_sym_pageCustomization] = ACTIONS(5305),
    [sym_using_keyword] = ACTIONS(5305),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5305),
    [sym_preproc_close] = ACTIONS(5305),
  },
  [STATE(2035)] = {
    [anon_sym_POUNDif] = ACTIONS(5309),
    [anon_sym_POUNDIF] = ACTIONS(5309),
    [anon_sym_POUNDIf] = ACTIONS(5309),
    [anon_sym_POUNDelif] = ACTIONS(5309),
    [anon_sym_POUNDELIF] = ACTIONS(5309),
    [anon_sym_POUNDElif] = ACTIONS(5309),
    [anon_sym_POUNDelse] = ACTIONS(5309),
    [anon_sym_POUNDELSE] = ACTIONS(5309),
    [anon_sym_POUNDElse] = ACTIONS(5309),
    [anon_sym_POUNDendif] = ACTIONS(5309),
    [anon_sym_POUNDENDIF] = ACTIONS(5309),
    [anon_sym_POUNDEndif] = ACTIONS(5309),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5311),
    [anon_sym_tableextension] = ACTIONS(5309),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5309),
    [anon_sym_Tableextension] = ACTIONS(5309),
    [anon_sym_TableExtension] = ACTIONS(5309),
    [anon_sym_tableExtension] = ACTIONS(5309),
    [sym_page_keyword] = ACTIONS(5311),
    [anon_sym_pageextension] = ACTIONS(5309),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5309),
    [anon_sym_Pageextension] = ACTIONS(5309),
    [anon_sym_PageExtension] = ACTIONS(5309),
    [anon_sym_pageExtension] = ACTIONS(5309),
    [anon_sym_codeunit] = ACTIONS(5309),
    [anon_sym_CODEUNIT] = ACTIONS(5309),
    [anon_sym_Codeunit] = ACTIONS(5309),
    [anon_sym_CodeUnit] = ACTIONS(5309),
    [anon_sym_COdeunit] = ACTIONS(5309),
    [anon_sym_codeUnit] = ACTIONS(5309),
    [sym_report_keyword] = ACTIONS(5311),
    [anon_sym_reportextension] = ACTIONS(5309),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5309),
    [anon_sym_Reportextension] = ACTIONS(5309),
    [anon_sym_ReportExtension] = ACTIONS(5309),
    [anon_sym_reportExtension] = ACTIONS(5309),
    [sym_query_keyword] = ACTIONS(5309),
    [anon_sym_xmlport] = ACTIONS(5309),
    [anon_sym_XMLPORT] = ACTIONS(5309),
    [anon_sym_Xmlport] = ACTIONS(5309),
    [anon_sym_XMLport] = ACTIONS(5309),
    [anon_sym_XMLPort] = ACTIONS(5309),
    [anon_sym_XmlPort] = ACTIONS(5309),
    [anon_sym_enum] = ACTIONS(5311),
    [anon_sym_ENUM] = ACTIONS(5311),
    [anon_sym_Enum] = ACTIONS(5311),
    [anon_sym_eNUM] = ACTIONS(5309),
    [anon_sym_eNum] = ACTIONS(5309),
    [anon_sym_ENum] = ACTIONS(5309),
    [anon_sym_enumextension] = ACTIONS(5309),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5309),
    [anon_sym_Enumextension] = ACTIONS(5309),
    [anon_sym_EnumExtension] = ACTIONS(5309),
    [anon_sym_enumExtension] = ACTIONS(5309),
    [sym_interface_keyword] = ACTIONS(5309),
    [anon_sym_controladdin] = ACTIONS(5309),
    [anon_sym_CONTROLADDIN] = ACTIONS(5309),
    [anon_sym_Controladdin] = ACTIONS(5309),
    [anon_sym_ControlAddIn] = ACTIONS(5309),
    [anon_sym_ControlAddin] = ACTIONS(5309),
    [anon_sym_controlAddIn] = ACTIONS(5309),
    [anon_sym_controlAddin] = ACTIONS(5309),
    [anon_sym_dotnet] = ACTIONS(5309),
    [anon_sym_DOTNET] = ACTIONS(5309),
    [anon_sym_Dotnet] = ACTIONS(5309),
    [anon_sym_DotNet] = ACTIONS(5309),
    [anon_sym_dotNet] = ACTIONS(5309),
    [sym_profile_keyword] = ACTIONS(5311),
    [anon_sym_profileextension] = ACTIONS(5309),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5309),
    [anon_sym_Profileextension] = ACTIONS(5309),
    [anon_sym_ProfileExtension] = ACTIONS(5309),
    [anon_sym_profileExtension] = ACTIONS(5309),
    [anon_sym_permissionset] = ACTIONS(5311),
    [anon_sym_PERMISSIONSET] = ACTIONS(5311),
    [anon_sym_Permissionset] = ACTIONS(5311),
    [anon_sym_PermissionSet] = ACTIONS(5311),
    [anon_sym_permissionSet] = ACTIONS(5311),
    [anon_sym_permissionsetextension] = ACTIONS(5309),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5309),
    [anon_sym_Permissionsetextension] = ACTIONS(5309),
    [anon_sym_PermissionSetExtension] = ACTIONS(5309),
    [anon_sym_permissionSetExtension] = ACTIONS(5309),
    [sym_entitlement_keyword] = ACTIONS(5309),
    [anon_sym_pagecustomization] = ACTIONS(5309),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5309),
    [anon_sym_Pagecustomization] = ACTIONS(5309),
    [anon_sym_PageCustomization] = ACTIONS(5309),
    [anon_sym_pageCustomization] = ACTIONS(5309),
    [sym_using_keyword] = ACTIONS(5309),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5309),
    [sym_preproc_close] = ACTIONS(5309),
  },
  [STATE(2036)] = {
    [anon_sym_POUNDif] = ACTIONS(5313),
    [anon_sym_POUNDIF] = ACTIONS(5313),
    [anon_sym_POUNDIf] = ACTIONS(5313),
    [anon_sym_POUNDelif] = ACTIONS(5313),
    [anon_sym_POUNDELIF] = ACTIONS(5313),
    [anon_sym_POUNDElif] = ACTIONS(5313),
    [anon_sym_POUNDelse] = ACTIONS(5313),
    [anon_sym_POUNDELSE] = ACTIONS(5313),
    [anon_sym_POUNDElse] = ACTIONS(5313),
    [anon_sym_POUNDendif] = ACTIONS(5313),
    [anon_sym_POUNDENDIF] = ACTIONS(5313),
    [anon_sym_POUNDEndif] = ACTIONS(5313),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5315),
    [anon_sym_tableextension] = ACTIONS(5313),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5313),
    [anon_sym_Tableextension] = ACTIONS(5313),
    [anon_sym_TableExtension] = ACTIONS(5313),
    [anon_sym_tableExtension] = ACTIONS(5313),
    [sym_page_keyword] = ACTIONS(5315),
    [anon_sym_pageextension] = ACTIONS(5313),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5313),
    [anon_sym_Pageextension] = ACTIONS(5313),
    [anon_sym_PageExtension] = ACTIONS(5313),
    [anon_sym_pageExtension] = ACTIONS(5313),
    [anon_sym_codeunit] = ACTIONS(5313),
    [anon_sym_CODEUNIT] = ACTIONS(5313),
    [anon_sym_Codeunit] = ACTIONS(5313),
    [anon_sym_CodeUnit] = ACTIONS(5313),
    [anon_sym_COdeunit] = ACTIONS(5313),
    [anon_sym_codeUnit] = ACTIONS(5313),
    [sym_report_keyword] = ACTIONS(5315),
    [anon_sym_reportextension] = ACTIONS(5313),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5313),
    [anon_sym_Reportextension] = ACTIONS(5313),
    [anon_sym_ReportExtension] = ACTIONS(5313),
    [anon_sym_reportExtension] = ACTIONS(5313),
    [sym_query_keyword] = ACTIONS(5313),
    [anon_sym_xmlport] = ACTIONS(5313),
    [anon_sym_XMLPORT] = ACTIONS(5313),
    [anon_sym_Xmlport] = ACTIONS(5313),
    [anon_sym_XMLport] = ACTIONS(5313),
    [anon_sym_XMLPort] = ACTIONS(5313),
    [anon_sym_XmlPort] = ACTIONS(5313),
    [anon_sym_enum] = ACTIONS(5315),
    [anon_sym_ENUM] = ACTIONS(5315),
    [anon_sym_Enum] = ACTIONS(5315),
    [anon_sym_eNUM] = ACTIONS(5313),
    [anon_sym_eNum] = ACTIONS(5313),
    [anon_sym_ENum] = ACTIONS(5313),
    [anon_sym_enumextension] = ACTIONS(5313),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5313),
    [anon_sym_Enumextension] = ACTIONS(5313),
    [anon_sym_EnumExtension] = ACTIONS(5313),
    [anon_sym_enumExtension] = ACTIONS(5313),
    [sym_interface_keyword] = ACTIONS(5313),
    [anon_sym_controladdin] = ACTIONS(5313),
    [anon_sym_CONTROLADDIN] = ACTIONS(5313),
    [anon_sym_Controladdin] = ACTIONS(5313),
    [anon_sym_ControlAddIn] = ACTIONS(5313),
    [anon_sym_ControlAddin] = ACTIONS(5313),
    [anon_sym_controlAddIn] = ACTIONS(5313),
    [anon_sym_controlAddin] = ACTIONS(5313),
    [anon_sym_dotnet] = ACTIONS(5313),
    [anon_sym_DOTNET] = ACTIONS(5313),
    [anon_sym_Dotnet] = ACTIONS(5313),
    [anon_sym_DotNet] = ACTIONS(5313),
    [anon_sym_dotNet] = ACTIONS(5313),
    [sym_profile_keyword] = ACTIONS(5315),
    [anon_sym_profileextension] = ACTIONS(5313),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5313),
    [anon_sym_Profileextension] = ACTIONS(5313),
    [anon_sym_ProfileExtension] = ACTIONS(5313),
    [anon_sym_profileExtension] = ACTIONS(5313),
    [anon_sym_permissionset] = ACTIONS(5315),
    [anon_sym_PERMISSIONSET] = ACTIONS(5315),
    [anon_sym_Permissionset] = ACTIONS(5315),
    [anon_sym_PermissionSet] = ACTIONS(5315),
    [anon_sym_permissionSet] = ACTIONS(5315),
    [anon_sym_permissionsetextension] = ACTIONS(5313),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5313),
    [anon_sym_Permissionsetextension] = ACTIONS(5313),
    [anon_sym_PermissionSetExtension] = ACTIONS(5313),
    [anon_sym_permissionSetExtension] = ACTIONS(5313),
    [sym_entitlement_keyword] = ACTIONS(5313),
    [anon_sym_pagecustomization] = ACTIONS(5313),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5313),
    [anon_sym_Pagecustomization] = ACTIONS(5313),
    [anon_sym_PageCustomization] = ACTIONS(5313),
    [anon_sym_pageCustomization] = ACTIONS(5313),
    [sym_using_keyword] = ACTIONS(5313),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5313),
    [sym_preproc_close] = ACTIONS(5313),
  },
  [STATE(2037)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(2038)] = {
    [anon_sym_POUNDif] = ACTIONS(5317),
    [anon_sym_POUNDIF] = ACTIONS(5317),
    [anon_sym_POUNDIf] = ACTIONS(5317),
    [anon_sym_POUNDelif] = ACTIONS(5317),
    [anon_sym_POUNDELIF] = ACTIONS(5317),
    [anon_sym_POUNDElif] = ACTIONS(5317),
    [anon_sym_POUNDelse] = ACTIONS(5317),
    [anon_sym_POUNDELSE] = ACTIONS(5317),
    [anon_sym_POUNDElse] = ACTIONS(5317),
    [anon_sym_POUNDendif] = ACTIONS(5317),
    [anon_sym_POUNDENDIF] = ACTIONS(5317),
    [anon_sym_POUNDEndif] = ACTIONS(5317),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5319),
    [anon_sym_tableextension] = ACTIONS(5317),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5317),
    [anon_sym_Tableextension] = ACTIONS(5317),
    [anon_sym_TableExtension] = ACTIONS(5317),
    [anon_sym_tableExtension] = ACTIONS(5317),
    [sym_page_keyword] = ACTIONS(5319),
    [anon_sym_pageextension] = ACTIONS(5317),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5317),
    [anon_sym_Pageextension] = ACTIONS(5317),
    [anon_sym_PageExtension] = ACTIONS(5317),
    [anon_sym_pageExtension] = ACTIONS(5317),
    [anon_sym_codeunit] = ACTIONS(5317),
    [anon_sym_CODEUNIT] = ACTIONS(5317),
    [anon_sym_Codeunit] = ACTIONS(5317),
    [anon_sym_CodeUnit] = ACTIONS(5317),
    [anon_sym_COdeunit] = ACTIONS(5317),
    [anon_sym_codeUnit] = ACTIONS(5317),
    [sym_report_keyword] = ACTIONS(5319),
    [anon_sym_reportextension] = ACTIONS(5317),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5317),
    [anon_sym_Reportextension] = ACTIONS(5317),
    [anon_sym_ReportExtension] = ACTIONS(5317),
    [anon_sym_reportExtension] = ACTIONS(5317),
    [sym_query_keyword] = ACTIONS(5317),
    [anon_sym_xmlport] = ACTIONS(5317),
    [anon_sym_XMLPORT] = ACTIONS(5317),
    [anon_sym_Xmlport] = ACTIONS(5317),
    [anon_sym_XMLport] = ACTIONS(5317),
    [anon_sym_XMLPort] = ACTIONS(5317),
    [anon_sym_XmlPort] = ACTIONS(5317),
    [anon_sym_enum] = ACTIONS(5319),
    [anon_sym_ENUM] = ACTIONS(5319),
    [anon_sym_Enum] = ACTIONS(5319),
    [anon_sym_eNUM] = ACTIONS(5317),
    [anon_sym_eNum] = ACTIONS(5317),
    [anon_sym_ENum] = ACTIONS(5317),
    [anon_sym_enumextension] = ACTIONS(5317),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5317),
    [anon_sym_Enumextension] = ACTIONS(5317),
    [anon_sym_EnumExtension] = ACTIONS(5317),
    [anon_sym_enumExtension] = ACTIONS(5317),
    [sym_interface_keyword] = ACTIONS(5317),
    [anon_sym_controladdin] = ACTIONS(5317),
    [anon_sym_CONTROLADDIN] = ACTIONS(5317),
    [anon_sym_Controladdin] = ACTIONS(5317),
    [anon_sym_ControlAddIn] = ACTIONS(5317),
    [anon_sym_ControlAddin] = ACTIONS(5317),
    [anon_sym_controlAddIn] = ACTIONS(5317),
    [anon_sym_controlAddin] = ACTIONS(5317),
    [anon_sym_dotnet] = ACTIONS(5317),
    [anon_sym_DOTNET] = ACTIONS(5317),
    [anon_sym_Dotnet] = ACTIONS(5317),
    [anon_sym_DotNet] = ACTIONS(5317),
    [anon_sym_dotNet] = ACTIONS(5317),
    [sym_profile_keyword] = ACTIONS(5319),
    [anon_sym_profileextension] = ACTIONS(5317),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5317),
    [anon_sym_Profileextension] = ACTIONS(5317),
    [anon_sym_ProfileExtension] = ACTIONS(5317),
    [anon_sym_profileExtension] = ACTIONS(5317),
    [anon_sym_permissionset] = ACTIONS(5319),
    [anon_sym_PERMISSIONSET] = ACTIONS(5319),
    [anon_sym_Permissionset] = ACTIONS(5319),
    [anon_sym_PermissionSet] = ACTIONS(5319),
    [anon_sym_permissionSet] = ACTIONS(5319),
    [anon_sym_permissionsetextension] = ACTIONS(5317),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5317),
    [anon_sym_Permissionsetextension] = ACTIONS(5317),
    [anon_sym_PermissionSetExtension] = ACTIONS(5317),
    [anon_sym_permissionSetExtension] = ACTIONS(5317),
    [sym_entitlement_keyword] = ACTIONS(5317),
    [anon_sym_pagecustomization] = ACTIONS(5317),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5317),
    [anon_sym_Pagecustomization] = ACTIONS(5317),
    [anon_sym_PageCustomization] = ACTIONS(5317),
    [anon_sym_pageCustomization] = ACTIONS(5317),
    [sym_using_keyword] = ACTIONS(5317),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5317),
    [sym_preproc_close] = ACTIONS(5317),
  },
  [STATE(2039)] = {
    [anon_sym_POUNDif] = ACTIONS(5321),
    [anon_sym_POUNDIF] = ACTIONS(5321),
    [anon_sym_POUNDIf] = ACTIONS(5321),
    [anon_sym_POUNDelif] = ACTIONS(5321),
    [anon_sym_POUNDELIF] = ACTIONS(5321),
    [anon_sym_POUNDElif] = ACTIONS(5321),
    [anon_sym_POUNDelse] = ACTIONS(5321),
    [anon_sym_POUNDELSE] = ACTIONS(5321),
    [anon_sym_POUNDElse] = ACTIONS(5321),
    [anon_sym_POUNDendif] = ACTIONS(5321),
    [anon_sym_POUNDENDIF] = ACTIONS(5321),
    [anon_sym_POUNDEndif] = ACTIONS(5321),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5323),
    [anon_sym_tableextension] = ACTIONS(5321),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5321),
    [anon_sym_Tableextension] = ACTIONS(5321),
    [anon_sym_TableExtension] = ACTIONS(5321),
    [anon_sym_tableExtension] = ACTIONS(5321),
    [sym_page_keyword] = ACTIONS(5323),
    [anon_sym_pageextension] = ACTIONS(5321),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5321),
    [anon_sym_Pageextension] = ACTIONS(5321),
    [anon_sym_PageExtension] = ACTIONS(5321),
    [anon_sym_pageExtension] = ACTIONS(5321),
    [anon_sym_codeunit] = ACTIONS(5321),
    [anon_sym_CODEUNIT] = ACTIONS(5321),
    [anon_sym_Codeunit] = ACTIONS(5321),
    [anon_sym_CodeUnit] = ACTIONS(5321),
    [anon_sym_COdeunit] = ACTIONS(5321),
    [anon_sym_codeUnit] = ACTIONS(5321),
    [sym_report_keyword] = ACTIONS(5323),
    [anon_sym_reportextension] = ACTIONS(5321),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5321),
    [anon_sym_Reportextension] = ACTIONS(5321),
    [anon_sym_ReportExtension] = ACTIONS(5321),
    [anon_sym_reportExtension] = ACTIONS(5321),
    [sym_query_keyword] = ACTIONS(5321),
    [anon_sym_xmlport] = ACTIONS(5321),
    [anon_sym_XMLPORT] = ACTIONS(5321),
    [anon_sym_Xmlport] = ACTIONS(5321),
    [anon_sym_XMLport] = ACTIONS(5321),
    [anon_sym_XMLPort] = ACTIONS(5321),
    [anon_sym_XmlPort] = ACTIONS(5321),
    [anon_sym_enum] = ACTIONS(5323),
    [anon_sym_ENUM] = ACTIONS(5323),
    [anon_sym_Enum] = ACTIONS(5323),
    [anon_sym_eNUM] = ACTIONS(5321),
    [anon_sym_eNum] = ACTIONS(5321),
    [anon_sym_ENum] = ACTIONS(5321),
    [anon_sym_enumextension] = ACTIONS(5321),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5321),
    [anon_sym_Enumextension] = ACTIONS(5321),
    [anon_sym_EnumExtension] = ACTIONS(5321),
    [anon_sym_enumExtension] = ACTIONS(5321),
    [sym_interface_keyword] = ACTIONS(5321),
    [anon_sym_controladdin] = ACTIONS(5321),
    [anon_sym_CONTROLADDIN] = ACTIONS(5321),
    [anon_sym_Controladdin] = ACTIONS(5321),
    [anon_sym_ControlAddIn] = ACTIONS(5321),
    [anon_sym_ControlAddin] = ACTIONS(5321),
    [anon_sym_controlAddIn] = ACTIONS(5321),
    [anon_sym_controlAddin] = ACTIONS(5321),
    [anon_sym_dotnet] = ACTIONS(5321),
    [anon_sym_DOTNET] = ACTIONS(5321),
    [anon_sym_Dotnet] = ACTIONS(5321),
    [anon_sym_DotNet] = ACTIONS(5321),
    [anon_sym_dotNet] = ACTIONS(5321),
    [sym_profile_keyword] = ACTIONS(5323),
    [anon_sym_profileextension] = ACTIONS(5321),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5321),
    [anon_sym_Profileextension] = ACTIONS(5321),
    [anon_sym_ProfileExtension] = ACTIONS(5321),
    [anon_sym_profileExtension] = ACTIONS(5321),
    [anon_sym_permissionset] = ACTIONS(5323),
    [anon_sym_PERMISSIONSET] = ACTIONS(5323),
    [anon_sym_Permissionset] = ACTIONS(5323),
    [anon_sym_PermissionSet] = ACTIONS(5323),
    [anon_sym_permissionSet] = ACTIONS(5323),
    [anon_sym_permissionsetextension] = ACTIONS(5321),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5321),
    [anon_sym_Permissionsetextension] = ACTIONS(5321),
    [anon_sym_PermissionSetExtension] = ACTIONS(5321),
    [anon_sym_permissionSetExtension] = ACTIONS(5321),
    [sym_entitlement_keyword] = ACTIONS(5321),
    [anon_sym_pagecustomization] = ACTIONS(5321),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5321),
    [anon_sym_Pagecustomization] = ACTIONS(5321),
    [anon_sym_PageCustomization] = ACTIONS(5321),
    [anon_sym_pageCustomization] = ACTIONS(5321),
    [sym_using_keyword] = ACTIONS(5321),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5321),
    [sym_preproc_close] = ACTIONS(5321),
  },
  [STATE(2040)] = {
    [anon_sym_POUNDif] = ACTIONS(5325),
    [anon_sym_POUNDIF] = ACTIONS(5325),
    [anon_sym_POUNDIf] = ACTIONS(5325),
    [anon_sym_POUNDelif] = ACTIONS(5325),
    [anon_sym_POUNDELIF] = ACTIONS(5325),
    [anon_sym_POUNDElif] = ACTIONS(5325),
    [anon_sym_POUNDelse] = ACTIONS(5325),
    [anon_sym_POUNDELSE] = ACTIONS(5325),
    [anon_sym_POUNDElse] = ACTIONS(5325),
    [anon_sym_POUNDendif] = ACTIONS(5325),
    [anon_sym_POUNDENDIF] = ACTIONS(5325),
    [anon_sym_POUNDEndif] = ACTIONS(5325),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5327),
    [anon_sym_tableextension] = ACTIONS(5325),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5325),
    [anon_sym_Tableextension] = ACTIONS(5325),
    [anon_sym_TableExtension] = ACTIONS(5325),
    [anon_sym_tableExtension] = ACTIONS(5325),
    [sym_page_keyword] = ACTIONS(5327),
    [anon_sym_pageextension] = ACTIONS(5325),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5325),
    [anon_sym_Pageextension] = ACTIONS(5325),
    [anon_sym_PageExtension] = ACTIONS(5325),
    [anon_sym_pageExtension] = ACTIONS(5325),
    [anon_sym_codeunit] = ACTIONS(5325),
    [anon_sym_CODEUNIT] = ACTIONS(5325),
    [anon_sym_Codeunit] = ACTIONS(5325),
    [anon_sym_CodeUnit] = ACTIONS(5325),
    [anon_sym_COdeunit] = ACTIONS(5325),
    [anon_sym_codeUnit] = ACTIONS(5325),
    [sym_report_keyword] = ACTIONS(5327),
    [anon_sym_reportextension] = ACTIONS(5325),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5325),
    [anon_sym_Reportextension] = ACTIONS(5325),
    [anon_sym_ReportExtension] = ACTIONS(5325),
    [anon_sym_reportExtension] = ACTIONS(5325),
    [sym_query_keyword] = ACTIONS(5325),
    [anon_sym_xmlport] = ACTIONS(5325),
    [anon_sym_XMLPORT] = ACTIONS(5325),
    [anon_sym_Xmlport] = ACTIONS(5325),
    [anon_sym_XMLport] = ACTIONS(5325),
    [anon_sym_XMLPort] = ACTIONS(5325),
    [anon_sym_XmlPort] = ACTIONS(5325),
    [anon_sym_enum] = ACTIONS(5327),
    [anon_sym_ENUM] = ACTIONS(5327),
    [anon_sym_Enum] = ACTIONS(5327),
    [anon_sym_eNUM] = ACTIONS(5325),
    [anon_sym_eNum] = ACTIONS(5325),
    [anon_sym_ENum] = ACTIONS(5325),
    [anon_sym_enumextension] = ACTIONS(5325),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5325),
    [anon_sym_Enumextension] = ACTIONS(5325),
    [anon_sym_EnumExtension] = ACTIONS(5325),
    [anon_sym_enumExtension] = ACTIONS(5325),
    [sym_interface_keyword] = ACTIONS(5325),
    [anon_sym_controladdin] = ACTIONS(5325),
    [anon_sym_CONTROLADDIN] = ACTIONS(5325),
    [anon_sym_Controladdin] = ACTIONS(5325),
    [anon_sym_ControlAddIn] = ACTIONS(5325),
    [anon_sym_ControlAddin] = ACTIONS(5325),
    [anon_sym_controlAddIn] = ACTIONS(5325),
    [anon_sym_controlAddin] = ACTIONS(5325),
    [anon_sym_dotnet] = ACTIONS(5325),
    [anon_sym_DOTNET] = ACTIONS(5325),
    [anon_sym_Dotnet] = ACTIONS(5325),
    [anon_sym_DotNet] = ACTIONS(5325),
    [anon_sym_dotNet] = ACTIONS(5325),
    [sym_profile_keyword] = ACTIONS(5327),
    [anon_sym_profileextension] = ACTIONS(5325),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5325),
    [anon_sym_Profileextension] = ACTIONS(5325),
    [anon_sym_ProfileExtension] = ACTIONS(5325),
    [anon_sym_profileExtension] = ACTIONS(5325),
    [anon_sym_permissionset] = ACTIONS(5327),
    [anon_sym_PERMISSIONSET] = ACTIONS(5327),
    [anon_sym_Permissionset] = ACTIONS(5327),
    [anon_sym_PermissionSet] = ACTIONS(5327),
    [anon_sym_permissionSet] = ACTIONS(5327),
    [anon_sym_permissionsetextension] = ACTIONS(5325),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5325),
    [anon_sym_Permissionsetextension] = ACTIONS(5325),
    [anon_sym_PermissionSetExtension] = ACTIONS(5325),
    [anon_sym_permissionSetExtension] = ACTIONS(5325),
    [sym_entitlement_keyword] = ACTIONS(5325),
    [anon_sym_pagecustomization] = ACTIONS(5325),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5325),
    [anon_sym_Pagecustomization] = ACTIONS(5325),
    [anon_sym_PageCustomization] = ACTIONS(5325),
    [anon_sym_pageCustomization] = ACTIONS(5325),
    [sym_using_keyword] = ACTIONS(5325),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5325),
    [sym_preproc_close] = ACTIONS(5325),
  },
  [STATE(2041)] = {
    [anon_sym_POUNDif] = ACTIONS(5329),
    [anon_sym_POUNDIF] = ACTIONS(5329),
    [anon_sym_POUNDIf] = ACTIONS(5329),
    [anon_sym_POUNDelif] = ACTIONS(5329),
    [anon_sym_POUNDELIF] = ACTIONS(5329),
    [anon_sym_POUNDElif] = ACTIONS(5329),
    [anon_sym_POUNDelse] = ACTIONS(5329),
    [anon_sym_POUNDELSE] = ACTIONS(5329),
    [anon_sym_POUNDElse] = ACTIONS(5329),
    [anon_sym_POUNDendif] = ACTIONS(5329),
    [anon_sym_POUNDENDIF] = ACTIONS(5329),
    [anon_sym_POUNDEndif] = ACTIONS(5329),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5331),
    [anon_sym_tableextension] = ACTIONS(5329),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5329),
    [anon_sym_Tableextension] = ACTIONS(5329),
    [anon_sym_TableExtension] = ACTIONS(5329),
    [anon_sym_tableExtension] = ACTIONS(5329),
    [sym_page_keyword] = ACTIONS(5331),
    [anon_sym_pageextension] = ACTIONS(5329),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5329),
    [anon_sym_Pageextension] = ACTIONS(5329),
    [anon_sym_PageExtension] = ACTIONS(5329),
    [anon_sym_pageExtension] = ACTIONS(5329),
    [anon_sym_codeunit] = ACTIONS(5329),
    [anon_sym_CODEUNIT] = ACTIONS(5329),
    [anon_sym_Codeunit] = ACTIONS(5329),
    [anon_sym_CodeUnit] = ACTIONS(5329),
    [anon_sym_COdeunit] = ACTIONS(5329),
    [anon_sym_codeUnit] = ACTIONS(5329),
    [sym_report_keyword] = ACTIONS(5331),
    [anon_sym_reportextension] = ACTIONS(5329),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5329),
    [anon_sym_Reportextension] = ACTIONS(5329),
    [anon_sym_ReportExtension] = ACTIONS(5329),
    [anon_sym_reportExtension] = ACTIONS(5329),
    [sym_query_keyword] = ACTIONS(5329),
    [anon_sym_xmlport] = ACTIONS(5329),
    [anon_sym_XMLPORT] = ACTIONS(5329),
    [anon_sym_Xmlport] = ACTIONS(5329),
    [anon_sym_XMLport] = ACTIONS(5329),
    [anon_sym_XMLPort] = ACTIONS(5329),
    [anon_sym_XmlPort] = ACTIONS(5329),
    [anon_sym_enum] = ACTIONS(5331),
    [anon_sym_ENUM] = ACTIONS(5331),
    [anon_sym_Enum] = ACTIONS(5331),
    [anon_sym_eNUM] = ACTIONS(5329),
    [anon_sym_eNum] = ACTIONS(5329),
    [anon_sym_ENum] = ACTIONS(5329),
    [anon_sym_enumextension] = ACTIONS(5329),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5329),
    [anon_sym_Enumextension] = ACTIONS(5329),
    [anon_sym_EnumExtension] = ACTIONS(5329),
    [anon_sym_enumExtension] = ACTIONS(5329),
    [sym_interface_keyword] = ACTIONS(5329),
    [anon_sym_controladdin] = ACTIONS(5329),
    [anon_sym_CONTROLADDIN] = ACTIONS(5329),
    [anon_sym_Controladdin] = ACTIONS(5329),
    [anon_sym_ControlAddIn] = ACTIONS(5329),
    [anon_sym_ControlAddin] = ACTIONS(5329),
    [anon_sym_controlAddIn] = ACTIONS(5329),
    [anon_sym_controlAddin] = ACTIONS(5329),
    [anon_sym_dotnet] = ACTIONS(5329),
    [anon_sym_DOTNET] = ACTIONS(5329),
    [anon_sym_Dotnet] = ACTIONS(5329),
    [anon_sym_DotNet] = ACTIONS(5329),
    [anon_sym_dotNet] = ACTIONS(5329),
    [sym_profile_keyword] = ACTIONS(5331),
    [anon_sym_profileextension] = ACTIONS(5329),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5329),
    [anon_sym_Profileextension] = ACTIONS(5329),
    [anon_sym_ProfileExtension] = ACTIONS(5329),
    [anon_sym_profileExtension] = ACTIONS(5329),
    [anon_sym_permissionset] = ACTIONS(5331),
    [anon_sym_PERMISSIONSET] = ACTIONS(5331),
    [anon_sym_Permissionset] = ACTIONS(5331),
    [anon_sym_PermissionSet] = ACTIONS(5331),
    [anon_sym_permissionSet] = ACTIONS(5331),
    [anon_sym_permissionsetextension] = ACTIONS(5329),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5329),
    [anon_sym_Permissionsetextension] = ACTIONS(5329),
    [anon_sym_PermissionSetExtension] = ACTIONS(5329),
    [anon_sym_permissionSetExtension] = ACTIONS(5329),
    [sym_entitlement_keyword] = ACTIONS(5329),
    [anon_sym_pagecustomization] = ACTIONS(5329),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5329),
    [anon_sym_Pagecustomization] = ACTIONS(5329),
    [anon_sym_PageCustomization] = ACTIONS(5329),
    [anon_sym_pageCustomization] = ACTIONS(5329),
    [sym_using_keyword] = ACTIONS(5329),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5329),
    [sym_preproc_close] = ACTIONS(5329),
  },
  [STATE(2042)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2326),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2328),
    [anon_sym_DASH] = ACTIONS(4951),
    [aux_sym_boolean_token1] = ACTIONS(2326),
    [aux_sym_boolean_token2] = ACTIONS(2326),
    [sym_decimal] = ACTIONS(2326),
    [anon_sym_LPAREN] = ACTIONS(2328),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2326),
    [aux_sym_basic_type_token21] = ACTIONS(2326),
    [aux_sym_basic_type_token22] = ACTIONS(2326),
    [aux_sym_basic_type_token48] = ACTIONS(2326),
    [anon_sym_not] = ACTIONS(2326),
    [anon_sym_NOT] = ACTIONS(2326),
    [anon_sym_Not] = ACTIONS(2326),
    [anon_sym_POUNDelif] = ACTIONS(2328),
    [anon_sym_POUNDELIF] = ACTIONS(2328),
    [anon_sym_POUNDElif] = ACTIONS(2328),
    [anon_sym_POUNDelse] = ACTIONS(2328),
    [anon_sym_POUNDELSE] = ACTIONS(2328),
    [anon_sym_POUNDElse] = ACTIONS(2328),
    [anon_sym_POUNDendif] = ACTIONS(2328),
    [anon_sym_POUNDENDIF] = ACTIONS(2328),
    [anon_sym_POUNDEndif] = ACTIONS(2328),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(5333),
    [aux_sym__expression_token1] = ACTIONS(4959),
    [aux_sym__expression_token2] = ACTIONS(4961),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2326),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2326),
    [anon_sym_SLASH] = ACTIONS(4963),
    [anon_sym_div] = ACTIONS(4965),
    [anon_sym_DIV] = ACTIONS(4967),
    [anon_sym_Div] = ACTIONS(4969),
    [anon_sym_mod] = ACTIONS(4971),
    [anon_sym_MOD] = ACTIONS(4973),
    [anon_sym_Mod] = ACTIONS(4975),
    [anon_sym_PLUS] = ACTIONS(4977),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(4979),
    [anon_sym_AND] = ACTIONS(4981),
    [anon_sym_And] = ACTIONS(4983),
    [anon_sym_or] = ACTIONS(5291),
    [anon_sym_OR] = ACTIONS(5293),
    [anon_sym_Or] = ACTIONS(5295),
    [anon_sym_xor] = ACTIONS(5297),
    [anon_sym_XOR] = ACTIONS(5299),
    [anon_sym_Xor] = ACTIONS(5301),
    [anon_sym_QMARK] = ACTIONS(5303),
    [sym_datetime_literal] = ACTIONS(2328),
    [sym_date_literal] = ACTIONS(2326),
    [sym_time_literal] = ACTIONS(2326),
    [sym_biginteger_literal] = ACTIONS(2328),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2326),
    [anon_sym_codeunit] = ACTIONS(2326),
    [anon_sym_CODEUNIT] = ACTIONS(2326),
    [anon_sym_Codeunit] = ACTIONS(2326),
    [anon_sym_CodeUnit] = ACTIONS(2326),
    [anon_sym_COdeunit] = ACTIONS(2326),
    [anon_sym_codeUnit] = ACTIONS(2326),
    [sym_report_keyword] = ACTIONS(2326),
    [sym_query_keyword] = ACTIONS(2326),
    [anon_sym_xmlport] = ACTIONS(2326),
    [anon_sym_XMLPORT] = ACTIONS(2326),
    [anon_sym_Xmlport] = ACTIONS(2326),
    [anon_sym_XMLport] = ACTIONS(2326),
    [anon_sym_XMLPort] = ACTIONS(2326),
    [anon_sym_XmlPort] = ACTIONS(2326),
    [anon_sym_enum] = ACTIONS(2326),
    [anon_sym_ENUM] = ACTIONS(2326),
    [anon_sym_Enum] = ACTIONS(2326),
    [anon_sym_eNUM] = ACTIONS(2326),
    [anon_sym_eNum] = ACTIONS(2326),
    [anon_sym_ENum] = ACTIONS(2326),
    [sym_quoted_identifier] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2328),
    [sym_integer] = ACTIONS(2326),
    [sym_continue_as_identifier] = ACTIONS(2328),
    [sym_preproc_close] = ACTIONS(2328),
  },
  [STATE(2043)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(2044)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(2045)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(2046)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2430),
    [anon_sym_SEMI] = ACTIONS(2432),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2432),
    [anon_sym_COMMA] = ACTIONS(2432),
    [anon_sym_COLON] = ACTIONS(2430),
    [anon_sym_DASH] = ACTIONS(2430),
    [aux_sym_boolean_token1] = ACTIONS(2430),
    [aux_sym_boolean_token2] = ACTIONS(2430),
    [sym_decimal] = ACTIONS(2430),
    [anon_sym_LPAREN] = ACTIONS(2432),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2430),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2430),
    [aux_sym_basic_type_token21] = ACTIONS(2430),
    [aux_sym_basic_type_token22] = ACTIONS(2430),
    [aux_sym_basic_type_token48] = ACTIONS(2430),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2430),
    [anon_sym_POUNDif] = ACTIONS(2432),
    [anon_sym_POUNDIF] = ACTIONS(2432),
    [anon_sym_POUNDIf] = ACTIONS(2432),
    [anon_sym_not] = ACTIONS(2430),
    [anon_sym_NOT] = ACTIONS(2430),
    [anon_sym_Not] = ACTIONS(2430),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2432),
    [aux_sym__expression_token1] = ACTIONS(2432),
    [aux_sym__expression_token2] = ACTIONS(2432),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2430),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2430),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(2430),
    [anon_sym_GT_EQ] = ACTIONS(2432),
    [anon_sym_LT_EQ] = ACTIONS(2432),
    [anon_sym_GT] = ACTIONS(2430),
    [anon_sym_LT] = ACTIONS(2430),
    [anon_sym_LT_GT] = ACTIONS(2432),
    [anon_sym_and] = ACTIONS(2430),
    [anon_sym_AND] = ACTIONS(2430),
    [anon_sym_And] = ACTIONS(2430),
    [anon_sym_or] = ACTIONS(2430),
    [anon_sym_OR] = ACTIONS(2430),
    [anon_sym_Or] = ACTIONS(2430),
    [anon_sym_xor] = ACTIONS(2430),
    [anon_sym_XOR] = ACTIONS(2430),
    [anon_sym_Xor] = ACTIONS(2430),
    [anon_sym_QMARK] = ACTIONS(2432),
    [sym_datetime_literal] = ACTIONS(2432),
    [sym_date_literal] = ACTIONS(2430),
    [sym_time_literal] = ACTIONS(2430),
    [sym_biginteger_literal] = ACTIONS(2432),
    [anon_sym_else] = ACTIONS(2430),
    [anon_sym_ELSE] = ACTIONS(2430),
    [anon_sym_Else] = ACTIONS(2430),
    [anon_sym_in] = ACTIONS(2430),
    [anon_sym_IN] = ACTIONS(2430),
    [anon_sym_In] = ACTIONS(2430),
    [sym_page_keyword] = ACTIONS(2430),
    [anon_sym_codeunit] = ACTIONS(2430),
    [anon_sym_CODEUNIT] = ACTIONS(2430),
    [anon_sym_Codeunit] = ACTIONS(2430),
    [anon_sym_CodeUnit] = ACTIONS(2430),
    [anon_sym_COdeunit] = ACTIONS(2430),
    [anon_sym_codeUnit] = ACTIONS(2430),
    [sym_report_keyword] = ACTIONS(2430),
    [sym_query_keyword] = ACTIONS(2430),
    [anon_sym_xmlport] = ACTIONS(2430),
    [anon_sym_XMLPORT] = ACTIONS(2430),
    [anon_sym_Xmlport] = ACTIONS(2430),
    [anon_sym_XMLport] = ACTIONS(2430),
    [anon_sym_XMLPort] = ACTIONS(2430),
    [anon_sym_XmlPort] = ACTIONS(2430),
    [anon_sym_enum] = ACTIONS(2430),
    [anon_sym_ENUM] = ACTIONS(2430),
    [anon_sym_Enum] = ACTIONS(2430),
    [anon_sym_eNUM] = ACTIONS(2430),
    [anon_sym_eNum] = ACTIONS(2430),
    [anon_sym_ENum] = ACTIONS(2430),
    [sym_quoted_identifier] = ACTIONS(2432),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2432),
    [sym_integer] = ACTIONS(2430),
    [sym_continue_as_identifier] = ACTIONS(2432),
    [sym_preproc_open] = ACTIONS(2432),
  },
  [STATE(2047)] = {
    [sym_argument_list] = STATE(2117),
    [sym_identifier] = ACTIONS(2434),
    [anon_sym_SEMI] = ACTIONS(2436),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_COMMA] = ACTIONS(2436),
    [anon_sym_COLON] = ACTIONS(2434),
    [anon_sym_DASH] = ACTIONS(2434),
    [aux_sym_boolean_token1] = ACTIONS(2434),
    [aux_sym_boolean_token2] = ACTIONS(2434),
    [sym_decimal] = ACTIONS(2434),
    [anon_sym_LPAREN] = ACTIONS(5335),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2434),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [aux_sym_record_type_token1] = ACTIONS(2434),
    [aux_sym_basic_type_token21] = ACTIONS(2434),
    [aux_sym_basic_type_token22] = ACTIONS(2434),
    [aux_sym_basic_type_token48] = ACTIONS(2434),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2434),
    [anon_sym_COLON_COLON] = ACTIONS(5337),
    [anon_sym_POUNDif] = ACTIONS(2436),
    [anon_sym_POUNDIF] = ACTIONS(2436),
    [anon_sym_POUNDIf] = ACTIONS(2436),
    [anon_sym_not] = ACTIONS(2434),
    [anon_sym_NOT] = ACTIONS(2434),
    [anon_sym_Not] = ACTIONS(2434),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2434),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(2434),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(2436),
    [sym_date_literal] = ACTIONS(2434),
    [sym_time_literal] = ACTIONS(2434),
    [sym_biginteger_literal] = ACTIONS(2436),
    [anon_sym_else] = ACTIONS(2434),
    [anon_sym_ELSE] = ACTIONS(2434),
    [anon_sym_Else] = ACTIONS(2434),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(2434),
    [anon_sym_codeunit] = ACTIONS(2434),
    [anon_sym_CODEUNIT] = ACTIONS(2434),
    [anon_sym_Codeunit] = ACTIONS(2434),
    [anon_sym_CodeUnit] = ACTIONS(2434),
    [anon_sym_COdeunit] = ACTIONS(2434),
    [anon_sym_codeUnit] = ACTIONS(2434),
    [sym_report_keyword] = ACTIONS(2434),
    [sym_query_keyword] = ACTIONS(2434),
    [anon_sym_xmlport] = ACTIONS(2434),
    [anon_sym_XMLPORT] = ACTIONS(2434),
    [anon_sym_Xmlport] = ACTIONS(2434),
    [anon_sym_XMLport] = ACTIONS(2434),
    [anon_sym_XMLPort] = ACTIONS(2434),
    [anon_sym_XmlPort] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2434),
    [anon_sym_ENUM] = ACTIONS(2434),
    [anon_sym_Enum] = ACTIONS(2434),
    [anon_sym_eNUM] = ACTIONS(2434),
    [anon_sym_eNum] = ACTIONS(2434),
    [anon_sym_ENum] = ACTIONS(2434),
    [sym_quoted_identifier] = ACTIONS(2436),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2436),
    [sym_integer] = ACTIONS(2434),
    [sym_continue_as_identifier] = ACTIONS(2436),
    [sym_preproc_open] = ACTIONS(2436),
  },
  [STATE(2048)] = {
    [anon_sym_POUNDif] = ACTIONS(5339),
    [anon_sym_POUNDIF] = ACTIONS(5339),
    [anon_sym_POUNDIf] = ACTIONS(5339),
    [anon_sym_POUNDelif] = ACTIONS(5339),
    [anon_sym_POUNDELIF] = ACTIONS(5339),
    [anon_sym_POUNDElif] = ACTIONS(5339),
    [anon_sym_POUNDelse] = ACTIONS(5339),
    [anon_sym_POUNDELSE] = ACTIONS(5339),
    [anon_sym_POUNDElse] = ACTIONS(5339),
    [anon_sym_POUNDendif] = ACTIONS(5339),
    [anon_sym_POUNDENDIF] = ACTIONS(5339),
    [anon_sym_POUNDEndif] = ACTIONS(5339),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5341),
    [anon_sym_tableextension] = ACTIONS(5339),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5339),
    [anon_sym_Tableextension] = ACTIONS(5339),
    [anon_sym_TableExtension] = ACTIONS(5339),
    [anon_sym_tableExtension] = ACTIONS(5339),
    [sym_page_keyword] = ACTIONS(5341),
    [anon_sym_pageextension] = ACTIONS(5339),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5339),
    [anon_sym_Pageextension] = ACTIONS(5339),
    [anon_sym_PageExtension] = ACTIONS(5339),
    [anon_sym_pageExtension] = ACTIONS(5339),
    [anon_sym_codeunit] = ACTIONS(5339),
    [anon_sym_CODEUNIT] = ACTIONS(5339),
    [anon_sym_Codeunit] = ACTIONS(5339),
    [anon_sym_CodeUnit] = ACTIONS(5339),
    [anon_sym_COdeunit] = ACTIONS(5339),
    [anon_sym_codeUnit] = ACTIONS(5339),
    [sym_report_keyword] = ACTIONS(5341),
    [anon_sym_reportextension] = ACTIONS(5339),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5339),
    [anon_sym_Reportextension] = ACTIONS(5339),
    [anon_sym_ReportExtension] = ACTIONS(5339),
    [anon_sym_reportExtension] = ACTIONS(5339),
    [sym_query_keyword] = ACTIONS(5339),
    [anon_sym_xmlport] = ACTIONS(5339),
    [anon_sym_XMLPORT] = ACTIONS(5339),
    [anon_sym_Xmlport] = ACTIONS(5339),
    [anon_sym_XMLport] = ACTIONS(5339),
    [anon_sym_XMLPort] = ACTIONS(5339),
    [anon_sym_XmlPort] = ACTIONS(5339),
    [anon_sym_enum] = ACTIONS(5341),
    [anon_sym_ENUM] = ACTIONS(5341),
    [anon_sym_Enum] = ACTIONS(5341),
    [anon_sym_eNUM] = ACTIONS(5339),
    [anon_sym_eNum] = ACTIONS(5339),
    [anon_sym_ENum] = ACTIONS(5339),
    [anon_sym_enumextension] = ACTIONS(5339),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5339),
    [anon_sym_Enumextension] = ACTIONS(5339),
    [anon_sym_EnumExtension] = ACTIONS(5339),
    [anon_sym_enumExtension] = ACTIONS(5339),
    [sym_interface_keyword] = ACTIONS(5339),
    [anon_sym_controladdin] = ACTIONS(5339),
    [anon_sym_CONTROLADDIN] = ACTIONS(5339),
    [anon_sym_Controladdin] = ACTIONS(5339),
    [anon_sym_ControlAddIn] = ACTIONS(5339),
    [anon_sym_ControlAddin] = ACTIONS(5339),
    [anon_sym_controlAddIn] = ACTIONS(5339),
    [anon_sym_controlAddin] = ACTIONS(5339),
    [anon_sym_dotnet] = ACTIONS(5339),
    [anon_sym_DOTNET] = ACTIONS(5339),
    [anon_sym_Dotnet] = ACTIONS(5339),
    [anon_sym_DotNet] = ACTIONS(5339),
    [anon_sym_dotNet] = ACTIONS(5339),
    [sym_profile_keyword] = ACTIONS(5341),
    [anon_sym_profileextension] = ACTIONS(5339),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5339),
    [anon_sym_Profileextension] = ACTIONS(5339),
    [anon_sym_ProfileExtension] = ACTIONS(5339),
    [anon_sym_profileExtension] = ACTIONS(5339),
    [anon_sym_permissionset] = ACTIONS(5341),
    [anon_sym_PERMISSIONSET] = ACTIONS(5341),
    [anon_sym_Permissionset] = ACTIONS(5341),
    [anon_sym_PermissionSet] = ACTIONS(5341),
    [anon_sym_permissionSet] = ACTIONS(5341),
    [anon_sym_permissionsetextension] = ACTIONS(5339),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5339),
    [anon_sym_Permissionsetextension] = ACTIONS(5339),
    [anon_sym_PermissionSetExtension] = ACTIONS(5339),
    [anon_sym_permissionSetExtension] = ACTIONS(5339),
    [sym_entitlement_keyword] = ACTIONS(5339),
    [anon_sym_pagecustomization] = ACTIONS(5339),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5339),
    [anon_sym_Pagecustomization] = ACTIONS(5339),
    [anon_sym_PageCustomization] = ACTIONS(5339),
    [anon_sym_pageCustomization] = ACTIONS(5339),
    [sym_using_keyword] = ACTIONS(5339),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5339),
    [sym_preproc_close] = ACTIONS(5339),
  },
  [STATE(2049)] = {
    [anon_sym_POUNDif] = ACTIONS(5343),
    [anon_sym_POUNDIF] = ACTIONS(5343),
    [anon_sym_POUNDIf] = ACTIONS(5343),
    [anon_sym_POUNDelif] = ACTIONS(5343),
    [anon_sym_POUNDELIF] = ACTIONS(5343),
    [anon_sym_POUNDElif] = ACTIONS(5343),
    [anon_sym_POUNDelse] = ACTIONS(5343),
    [anon_sym_POUNDELSE] = ACTIONS(5343),
    [anon_sym_POUNDElse] = ACTIONS(5343),
    [anon_sym_POUNDendif] = ACTIONS(5343),
    [anon_sym_POUNDENDIF] = ACTIONS(5343),
    [anon_sym_POUNDEndif] = ACTIONS(5343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5345),
    [anon_sym_tableextension] = ACTIONS(5343),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5343),
    [anon_sym_Tableextension] = ACTIONS(5343),
    [anon_sym_TableExtension] = ACTIONS(5343),
    [anon_sym_tableExtension] = ACTIONS(5343),
    [sym_page_keyword] = ACTIONS(5345),
    [anon_sym_pageextension] = ACTIONS(5343),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5343),
    [anon_sym_Pageextension] = ACTIONS(5343),
    [anon_sym_PageExtension] = ACTIONS(5343),
    [anon_sym_pageExtension] = ACTIONS(5343),
    [anon_sym_codeunit] = ACTIONS(5343),
    [anon_sym_CODEUNIT] = ACTIONS(5343),
    [anon_sym_Codeunit] = ACTIONS(5343),
    [anon_sym_CodeUnit] = ACTIONS(5343),
    [anon_sym_COdeunit] = ACTIONS(5343),
    [anon_sym_codeUnit] = ACTIONS(5343),
    [sym_report_keyword] = ACTIONS(5345),
    [anon_sym_reportextension] = ACTIONS(5343),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5343),
    [anon_sym_Reportextension] = ACTIONS(5343),
    [anon_sym_ReportExtension] = ACTIONS(5343),
    [anon_sym_reportExtension] = ACTIONS(5343),
    [sym_query_keyword] = ACTIONS(5343),
    [anon_sym_xmlport] = ACTIONS(5343),
    [anon_sym_XMLPORT] = ACTIONS(5343),
    [anon_sym_Xmlport] = ACTIONS(5343),
    [anon_sym_XMLport] = ACTIONS(5343),
    [anon_sym_XMLPort] = ACTIONS(5343),
    [anon_sym_XmlPort] = ACTIONS(5343),
    [anon_sym_enum] = ACTIONS(5345),
    [anon_sym_ENUM] = ACTIONS(5345),
    [anon_sym_Enum] = ACTIONS(5345),
    [anon_sym_eNUM] = ACTIONS(5343),
    [anon_sym_eNum] = ACTIONS(5343),
    [anon_sym_ENum] = ACTIONS(5343),
    [anon_sym_enumextension] = ACTIONS(5343),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5343),
    [anon_sym_Enumextension] = ACTIONS(5343),
    [anon_sym_EnumExtension] = ACTIONS(5343),
    [anon_sym_enumExtension] = ACTIONS(5343),
    [sym_interface_keyword] = ACTIONS(5343),
    [anon_sym_controladdin] = ACTIONS(5343),
    [anon_sym_CONTROLADDIN] = ACTIONS(5343),
    [anon_sym_Controladdin] = ACTIONS(5343),
    [anon_sym_ControlAddIn] = ACTIONS(5343),
    [anon_sym_ControlAddin] = ACTIONS(5343),
    [anon_sym_controlAddIn] = ACTIONS(5343),
    [anon_sym_controlAddin] = ACTIONS(5343),
    [anon_sym_dotnet] = ACTIONS(5343),
    [anon_sym_DOTNET] = ACTIONS(5343),
    [anon_sym_Dotnet] = ACTIONS(5343),
    [anon_sym_DotNet] = ACTIONS(5343),
    [anon_sym_dotNet] = ACTIONS(5343),
    [sym_profile_keyword] = ACTIONS(5345),
    [anon_sym_profileextension] = ACTIONS(5343),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5343),
    [anon_sym_Profileextension] = ACTIONS(5343),
    [anon_sym_ProfileExtension] = ACTIONS(5343),
    [anon_sym_profileExtension] = ACTIONS(5343),
    [anon_sym_permissionset] = ACTIONS(5345),
    [anon_sym_PERMISSIONSET] = ACTIONS(5345),
    [anon_sym_Permissionset] = ACTIONS(5345),
    [anon_sym_PermissionSet] = ACTIONS(5345),
    [anon_sym_permissionSet] = ACTIONS(5345),
    [anon_sym_permissionsetextension] = ACTIONS(5343),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5343),
    [anon_sym_Permissionsetextension] = ACTIONS(5343),
    [anon_sym_PermissionSetExtension] = ACTIONS(5343),
    [anon_sym_permissionSetExtension] = ACTIONS(5343),
    [sym_entitlement_keyword] = ACTIONS(5343),
    [anon_sym_pagecustomization] = ACTIONS(5343),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5343),
    [anon_sym_Pagecustomization] = ACTIONS(5343),
    [anon_sym_PageCustomization] = ACTIONS(5343),
    [anon_sym_pageCustomization] = ACTIONS(5343),
    [sym_using_keyword] = ACTIONS(5343),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5343),
    [sym_preproc_close] = ACTIONS(5343),
  },
  [STATE(2050)] = {
    [anon_sym_POUNDif] = ACTIONS(5347),
    [anon_sym_POUNDIF] = ACTIONS(5347),
    [anon_sym_POUNDIf] = ACTIONS(5347),
    [anon_sym_POUNDelif] = ACTIONS(5347),
    [anon_sym_POUNDELIF] = ACTIONS(5347),
    [anon_sym_POUNDElif] = ACTIONS(5347),
    [anon_sym_POUNDelse] = ACTIONS(5347),
    [anon_sym_POUNDELSE] = ACTIONS(5347),
    [anon_sym_POUNDElse] = ACTIONS(5347),
    [anon_sym_POUNDendif] = ACTIONS(5347),
    [anon_sym_POUNDENDIF] = ACTIONS(5347),
    [anon_sym_POUNDEndif] = ACTIONS(5347),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5349),
    [anon_sym_tableextension] = ACTIONS(5347),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5347),
    [anon_sym_Tableextension] = ACTIONS(5347),
    [anon_sym_TableExtension] = ACTIONS(5347),
    [anon_sym_tableExtension] = ACTIONS(5347),
    [sym_page_keyword] = ACTIONS(5349),
    [anon_sym_pageextension] = ACTIONS(5347),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5347),
    [anon_sym_Pageextension] = ACTIONS(5347),
    [anon_sym_PageExtension] = ACTIONS(5347),
    [anon_sym_pageExtension] = ACTIONS(5347),
    [anon_sym_codeunit] = ACTIONS(5347),
    [anon_sym_CODEUNIT] = ACTIONS(5347),
    [anon_sym_Codeunit] = ACTIONS(5347),
    [anon_sym_CodeUnit] = ACTIONS(5347),
    [anon_sym_COdeunit] = ACTIONS(5347),
    [anon_sym_codeUnit] = ACTIONS(5347),
    [sym_report_keyword] = ACTIONS(5349),
    [anon_sym_reportextension] = ACTIONS(5347),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5347),
    [anon_sym_Reportextension] = ACTIONS(5347),
    [anon_sym_ReportExtension] = ACTIONS(5347),
    [anon_sym_reportExtension] = ACTIONS(5347),
    [sym_query_keyword] = ACTIONS(5347),
    [anon_sym_xmlport] = ACTIONS(5347),
    [anon_sym_XMLPORT] = ACTIONS(5347),
    [anon_sym_Xmlport] = ACTIONS(5347),
    [anon_sym_XMLport] = ACTIONS(5347),
    [anon_sym_XMLPort] = ACTIONS(5347),
    [anon_sym_XmlPort] = ACTIONS(5347),
    [anon_sym_enum] = ACTIONS(5349),
    [anon_sym_ENUM] = ACTIONS(5349),
    [anon_sym_Enum] = ACTIONS(5349),
    [anon_sym_eNUM] = ACTIONS(5347),
    [anon_sym_eNum] = ACTIONS(5347),
    [anon_sym_ENum] = ACTIONS(5347),
    [anon_sym_enumextension] = ACTIONS(5347),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5347),
    [anon_sym_Enumextension] = ACTIONS(5347),
    [anon_sym_EnumExtension] = ACTIONS(5347),
    [anon_sym_enumExtension] = ACTIONS(5347),
    [sym_interface_keyword] = ACTIONS(5347),
    [anon_sym_controladdin] = ACTIONS(5347),
    [anon_sym_CONTROLADDIN] = ACTIONS(5347),
    [anon_sym_Controladdin] = ACTIONS(5347),
    [anon_sym_ControlAddIn] = ACTIONS(5347),
    [anon_sym_ControlAddin] = ACTIONS(5347),
    [anon_sym_controlAddIn] = ACTIONS(5347),
    [anon_sym_controlAddin] = ACTIONS(5347),
    [anon_sym_dotnet] = ACTIONS(5347),
    [anon_sym_DOTNET] = ACTIONS(5347),
    [anon_sym_Dotnet] = ACTIONS(5347),
    [anon_sym_DotNet] = ACTIONS(5347),
    [anon_sym_dotNet] = ACTIONS(5347),
    [sym_profile_keyword] = ACTIONS(5349),
    [anon_sym_profileextension] = ACTIONS(5347),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5347),
    [anon_sym_Profileextension] = ACTIONS(5347),
    [anon_sym_ProfileExtension] = ACTIONS(5347),
    [anon_sym_profileExtension] = ACTIONS(5347),
    [anon_sym_permissionset] = ACTIONS(5349),
    [anon_sym_PERMISSIONSET] = ACTIONS(5349),
    [anon_sym_Permissionset] = ACTIONS(5349),
    [anon_sym_PermissionSet] = ACTIONS(5349),
    [anon_sym_permissionSet] = ACTIONS(5349),
    [anon_sym_permissionsetextension] = ACTIONS(5347),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5347),
    [anon_sym_Permissionsetextension] = ACTIONS(5347),
    [anon_sym_PermissionSetExtension] = ACTIONS(5347),
    [anon_sym_permissionSetExtension] = ACTIONS(5347),
    [sym_entitlement_keyword] = ACTIONS(5347),
    [anon_sym_pagecustomization] = ACTIONS(5347),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5347),
    [anon_sym_Pagecustomization] = ACTIONS(5347),
    [anon_sym_PageCustomization] = ACTIONS(5347),
    [anon_sym_pageCustomization] = ACTIONS(5347),
    [sym_using_keyword] = ACTIONS(5347),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5347),
    [sym_preproc_close] = ACTIONS(5347),
  },
  [STATE(2051)] = {
    [anon_sym_POUNDif] = ACTIONS(5351),
    [anon_sym_POUNDIF] = ACTIONS(5351),
    [anon_sym_POUNDIf] = ACTIONS(5351),
    [anon_sym_POUNDelif] = ACTIONS(5351),
    [anon_sym_POUNDELIF] = ACTIONS(5351),
    [anon_sym_POUNDElif] = ACTIONS(5351),
    [anon_sym_POUNDelse] = ACTIONS(5351),
    [anon_sym_POUNDELSE] = ACTIONS(5351),
    [anon_sym_POUNDElse] = ACTIONS(5351),
    [anon_sym_POUNDendif] = ACTIONS(5351),
    [anon_sym_POUNDENDIF] = ACTIONS(5351),
    [anon_sym_POUNDEndif] = ACTIONS(5351),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5353),
    [anon_sym_tableextension] = ACTIONS(5351),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5351),
    [anon_sym_Tableextension] = ACTIONS(5351),
    [anon_sym_TableExtension] = ACTIONS(5351),
    [anon_sym_tableExtension] = ACTIONS(5351),
    [sym_page_keyword] = ACTIONS(5353),
    [anon_sym_pageextension] = ACTIONS(5351),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5351),
    [anon_sym_Pageextension] = ACTIONS(5351),
    [anon_sym_PageExtension] = ACTIONS(5351),
    [anon_sym_pageExtension] = ACTIONS(5351),
    [anon_sym_codeunit] = ACTIONS(5351),
    [anon_sym_CODEUNIT] = ACTIONS(5351),
    [anon_sym_Codeunit] = ACTIONS(5351),
    [anon_sym_CodeUnit] = ACTIONS(5351),
    [anon_sym_COdeunit] = ACTIONS(5351),
    [anon_sym_codeUnit] = ACTIONS(5351),
    [sym_report_keyword] = ACTIONS(5353),
    [anon_sym_reportextension] = ACTIONS(5351),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5351),
    [anon_sym_Reportextension] = ACTIONS(5351),
    [anon_sym_ReportExtension] = ACTIONS(5351),
    [anon_sym_reportExtension] = ACTIONS(5351),
    [sym_query_keyword] = ACTIONS(5351),
    [anon_sym_xmlport] = ACTIONS(5351),
    [anon_sym_XMLPORT] = ACTIONS(5351),
    [anon_sym_Xmlport] = ACTIONS(5351),
    [anon_sym_XMLport] = ACTIONS(5351),
    [anon_sym_XMLPort] = ACTIONS(5351),
    [anon_sym_XmlPort] = ACTIONS(5351),
    [anon_sym_enum] = ACTIONS(5353),
    [anon_sym_ENUM] = ACTIONS(5353),
    [anon_sym_Enum] = ACTIONS(5353),
    [anon_sym_eNUM] = ACTIONS(5351),
    [anon_sym_eNum] = ACTIONS(5351),
    [anon_sym_ENum] = ACTIONS(5351),
    [anon_sym_enumextension] = ACTIONS(5351),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5351),
    [anon_sym_Enumextension] = ACTIONS(5351),
    [anon_sym_EnumExtension] = ACTIONS(5351),
    [anon_sym_enumExtension] = ACTIONS(5351),
    [sym_interface_keyword] = ACTIONS(5351),
    [anon_sym_controladdin] = ACTIONS(5351),
    [anon_sym_CONTROLADDIN] = ACTIONS(5351),
    [anon_sym_Controladdin] = ACTIONS(5351),
    [anon_sym_ControlAddIn] = ACTIONS(5351),
    [anon_sym_ControlAddin] = ACTIONS(5351),
    [anon_sym_controlAddIn] = ACTIONS(5351),
    [anon_sym_controlAddin] = ACTIONS(5351),
    [anon_sym_dotnet] = ACTIONS(5351),
    [anon_sym_DOTNET] = ACTIONS(5351),
    [anon_sym_Dotnet] = ACTIONS(5351),
    [anon_sym_DotNet] = ACTIONS(5351),
    [anon_sym_dotNet] = ACTIONS(5351),
    [sym_profile_keyword] = ACTIONS(5353),
    [anon_sym_profileextension] = ACTIONS(5351),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5351),
    [anon_sym_Profileextension] = ACTIONS(5351),
    [anon_sym_ProfileExtension] = ACTIONS(5351),
    [anon_sym_profileExtension] = ACTIONS(5351),
    [anon_sym_permissionset] = ACTIONS(5353),
    [anon_sym_PERMISSIONSET] = ACTIONS(5353),
    [anon_sym_Permissionset] = ACTIONS(5353),
    [anon_sym_PermissionSet] = ACTIONS(5353),
    [anon_sym_permissionSet] = ACTIONS(5353),
    [anon_sym_permissionsetextension] = ACTIONS(5351),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5351),
    [anon_sym_Permissionsetextension] = ACTIONS(5351),
    [anon_sym_PermissionSetExtension] = ACTIONS(5351),
    [anon_sym_permissionSetExtension] = ACTIONS(5351),
    [sym_entitlement_keyword] = ACTIONS(5351),
    [anon_sym_pagecustomization] = ACTIONS(5351),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5351),
    [anon_sym_Pagecustomization] = ACTIONS(5351),
    [anon_sym_PageCustomization] = ACTIONS(5351),
    [anon_sym_pageCustomization] = ACTIONS(5351),
    [sym_using_keyword] = ACTIONS(5351),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5351),
    [sym_preproc_close] = ACTIONS(5351),
  },
  [STATE(2052)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(2053)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(2054)] = {
    [anon_sym_POUNDif] = ACTIONS(5355),
    [anon_sym_POUNDIF] = ACTIONS(5355),
    [anon_sym_POUNDIf] = ACTIONS(5355),
    [anon_sym_POUNDelif] = ACTIONS(5355),
    [anon_sym_POUNDELIF] = ACTIONS(5355),
    [anon_sym_POUNDElif] = ACTIONS(5355),
    [anon_sym_POUNDelse] = ACTIONS(5355),
    [anon_sym_POUNDELSE] = ACTIONS(5355),
    [anon_sym_POUNDElse] = ACTIONS(5355),
    [anon_sym_POUNDendif] = ACTIONS(5355),
    [anon_sym_POUNDENDIF] = ACTIONS(5355),
    [anon_sym_POUNDEndif] = ACTIONS(5355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5357),
    [anon_sym_tableextension] = ACTIONS(5355),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5355),
    [anon_sym_Tableextension] = ACTIONS(5355),
    [anon_sym_TableExtension] = ACTIONS(5355),
    [anon_sym_tableExtension] = ACTIONS(5355),
    [sym_page_keyword] = ACTIONS(5357),
    [anon_sym_pageextension] = ACTIONS(5355),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5355),
    [anon_sym_Pageextension] = ACTIONS(5355),
    [anon_sym_PageExtension] = ACTIONS(5355),
    [anon_sym_pageExtension] = ACTIONS(5355),
    [anon_sym_codeunit] = ACTIONS(5355),
    [anon_sym_CODEUNIT] = ACTIONS(5355),
    [anon_sym_Codeunit] = ACTIONS(5355),
    [anon_sym_CodeUnit] = ACTIONS(5355),
    [anon_sym_COdeunit] = ACTIONS(5355),
    [anon_sym_codeUnit] = ACTIONS(5355),
    [sym_report_keyword] = ACTIONS(5357),
    [anon_sym_reportextension] = ACTIONS(5355),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5355),
    [anon_sym_Reportextension] = ACTIONS(5355),
    [anon_sym_ReportExtension] = ACTIONS(5355),
    [anon_sym_reportExtension] = ACTIONS(5355),
    [sym_query_keyword] = ACTIONS(5355),
    [anon_sym_xmlport] = ACTIONS(5355),
    [anon_sym_XMLPORT] = ACTIONS(5355),
    [anon_sym_Xmlport] = ACTIONS(5355),
    [anon_sym_XMLport] = ACTIONS(5355),
    [anon_sym_XMLPort] = ACTIONS(5355),
    [anon_sym_XmlPort] = ACTIONS(5355),
    [anon_sym_enum] = ACTIONS(5357),
    [anon_sym_ENUM] = ACTIONS(5357),
    [anon_sym_Enum] = ACTIONS(5357),
    [anon_sym_eNUM] = ACTIONS(5355),
    [anon_sym_eNum] = ACTIONS(5355),
    [anon_sym_ENum] = ACTIONS(5355),
    [anon_sym_enumextension] = ACTIONS(5355),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5355),
    [anon_sym_Enumextension] = ACTIONS(5355),
    [anon_sym_EnumExtension] = ACTIONS(5355),
    [anon_sym_enumExtension] = ACTIONS(5355),
    [sym_interface_keyword] = ACTIONS(5355),
    [anon_sym_controladdin] = ACTIONS(5355),
    [anon_sym_CONTROLADDIN] = ACTIONS(5355),
    [anon_sym_Controladdin] = ACTIONS(5355),
    [anon_sym_ControlAddIn] = ACTIONS(5355),
    [anon_sym_ControlAddin] = ACTIONS(5355),
    [anon_sym_controlAddIn] = ACTIONS(5355),
    [anon_sym_controlAddin] = ACTIONS(5355),
    [anon_sym_dotnet] = ACTIONS(5355),
    [anon_sym_DOTNET] = ACTIONS(5355),
    [anon_sym_Dotnet] = ACTIONS(5355),
    [anon_sym_DotNet] = ACTIONS(5355),
    [anon_sym_dotNet] = ACTIONS(5355),
    [sym_profile_keyword] = ACTIONS(5357),
    [anon_sym_profileextension] = ACTIONS(5355),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5355),
    [anon_sym_Profileextension] = ACTIONS(5355),
    [anon_sym_ProfileExtension] = ACTIONS(5355),
    [anon_sym_profileExtension] = ACTIONS(5355),
    [anon_sym_permissionset] = ACTIONS(5357),
    [anon_sym_PERMISSIONSET] = ACTIONS(5357),
    [anon_sym_Permissionset] = ACTIONS(5357),
    [anon_sym_PermissionSet] = ACTIONS(5357),
    [anon_sym_permissionSet] = ACTIONS(5357),
    [anon_sym_permissionsetextension] = ACTIONS(5355),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5355),
    [anon_sym_Permissionsetextension] = ACTIONS(5355),
    [anon_sym_PermissionSetExtension] = ACTIONS(5355),
    [anon_sym_permissionSetExtension] = ACTIONS(5355),
    [sym_entitlement_keyword] = ACTIONS(5355),
    [anon_sym_pagecustomization] = ACTIONS(5355),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5355),
    [anon_sym_Pagecustomization] = ACTIONS(5355),
    [anon_sym_PageCustomization] = ACTIONS(5355),
    [anon_sym_pageCustomization] = ACTIONS(5355),
    [sym_using_keyword] = ACTIONS(5355),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5355),
    [sym_preproc_close] = ACTIONS(5355),
  },
  [STATE(2055)] = {
    [anon_sym_POUNDif] = ACTIONS(5359),
    [anon_sym_POUNDIF] = ACTIONS(5359),
    [anon_sym_POUNDIf] = ACTIONS(5359),
    [anon_sym_POUNDelif] = ACTIONS(5359),
    [anon_sym_POUNDELIF] = ACTIONS(5359),
    [anon_sym_POUNDElif] = ACTIONS(5359),
    [anon_sym_POUNDelse] = ACTIONS(5359),
    [anon_sym_POUNDELSE] = ACTIONS(5359),
    [anon_sym_POUNDElse] = ACTIONS(5359),
    [anon_sym_POUNDendif] = ACTIONS(5359),
    [anon_sym_POUNDENDIF] = ACTIONS(5359),
    [anon_sym_POUNDEndif] = ACTIONS(5359),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5361),
    [anon_sym_tableextension] = ACTIONS(5359),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5359),
    [anon_sym_Tableextension] = ACTIONS(5359),
    [anon_sym_TableExtension] = ACTIONS(5359),
    [anon_sym_tableExtension] = ACTIONS(5359),
    [sym_page_keyword] = ACTIONS(5361),
    [anon_sym_pageextension] = ACTIONS(5359),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5359),
    [anon_sym_Pageextension] = ACTIONS(5359),
    [anon_sym_PageExtension] = ACTIONS(5359),
    [anon_sym_pageExtension] = ACTIONS(5359),
    [anon_sym_codeunit] = ACTIONS(5359),
    [anon_sym_CODEUNIT] = ACTIONS(5359),
    [anon_sym_Codeunit] = ACTIONS(5359),
    [anon_sym_CodeUnit] = ACTIONS(5359),
    [anon_sym_COdeunit] = ACTIONS(5359),
    [anon_sym_codeUnit] = ACTIONS(5359),
    [sym_report_keyword] = ACTIONS(5361),
    [anon_sym_reportextension] = ACTIONS(5359),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5359),
    [anon_sym_Reportextension] = ACTIONS(5359),
    [anon_sym_ReportExtension] = ACTIONS(5359),
    [anon_sym_reportExtension] = ACTIONS(5359),
    [sym_query_keyword] = ACTIONS(5359),
    [anon_sym_xmlport] = ACTIONS(5359),
    [anon_sym_XMLPORT] = ACTIONS(5359),
    [anon_sym_Xmlport] = ACTIONS(5359),
    [anon_sym_XMLport] = ACTIONS(5359),
    [anon_sym_XMLPort] = ACTIONS(5359),
    [anon_sym_XmlPort] = ACTIONS(5359),
    [anon_sym_enum] = ACTIONS(5361),
    [anon_sym_ENUM] = ACTIONS(5361),
    [anon_sym_Enum] = ACTIONS(5361),
    [anon_sym_eNUM] = ACTIONS(5359),
    [anon_sym_eNum] = ACTIONS(5359),
    [anon_sym_ENum] = ACTIONS(5359),
    [anon_sym_enumextension] = ACTIONS(5359),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5359),
    [anon_sym_Enumextension] = ACTIONS(5359),
    [anon_sym_EnumExtension] = ACTIONS(5359),
    [anon_sym_enumExtension] = ACTIONS(5359),
    [sym_interface_keyword] = ACTIONS(5359),
    [anon_sym_controladdin] = ACTIONS(5359),
    [anon_sym_CONTROLADDIN] = ACTIONS(5359),
    [anon_sym_Controladdin] = ACTIONS(5359),
    [anon_sym_ControlAddIn] = ACTIONS(5359),
    [anon_sym_ControlAddin] = ACTIONS(5359),
    [anon_sym_controlAddIn] = ACTIONS(5359),
    [anon_sym_controlAddin] = ACTIONS(5359),
    [anon_sym_dotnet] = ACTIONS(5359),
    [anon_sym_DOTNET] = ACTIONS(5359),
    [anon_sym_Dotnet] = ACTIONS(5359),
    [anon_sym_DotNet] = ACTIONS(5359),
    [anon_sym_dotNet] = ACTIONS(5359),
    [sym_profile_keyword] = ACTIONS(5361),
    [anon_sym_profileextension] = ACTIONS(5359),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5359),
    [anon_sym_Profileextension] = ACTIONS(5359),
    [anon_sym_ProfileExtension] = ACTIONS(5359),
    [anon_sym_profileExtension] = ACTIONS(5359),
    [anon_sym_permissionset] = ACTIONS(5361),
    [anon_sym_PERMISSIONSET] = ACTIONS(5361),
    [anon_sym_Permissionset] = ACTIONS(5361),
    [anon_sym_PermissionSet] = ACTIONS(5361),
    [anon_sym_permissionSet] = ACTIONS(5361),
    [anon_sym_permissionsetextension] = ACTIONS(5359),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5359),
    [anon_sym_Permissionsetextension] = ACTIONS(5359),
    [anon_sym_PermissionSetExtension] = ACTIONS(5359),
    [anon_sym_permissionSetExtension] = ACTIONS(5359),
    [sym_entitlement_keyword] = ACTIONS(5359),
    [anon_sym_pagecustomization] = ACTIONS(5359),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5359),
    [anon_sym_Pagecustomization] = ACTIONS(5359),
    [anon_sym_PageCustomization] = ACTIONS(5359),
    [anon_sym_pageCustomization] = ACTIONS(5359),
    [sym_using_keyword] = ACTIONS(5359),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5359),
    [sym_preproc_close] = ACTIONS(5359),
  },
  [STATE(2056)] = {
    [anon_sym_POUNDif] = ACTIONS(5363),
    [anon_sym_POUNDIF] = ACTIONS(5363),
    [anon_sym_POUNDIf] = ACTIONS(5363),
    [anon_sym_POUNDelif] = ACTIONS(5363),
    [anon_sym_POUNDELIF] = ACTIONS(5363),
    [anon_sym_POUNDElif] = ACTIONS(5363),
    [anon_sym_POUNDelse] = ACTIONS(5363),
    [anon_sym_POUNDELSE] = ACTIONS(5363),
    [anon_sym_POUNDElse] = ACTIONS(5363),
    [anon_sym_POUNDendif] = ACTIONS(5363),
    [anon_sym_POUNDENDIF] = ACTIONS(5363),
    [anon_sym_POUNDEndif] = ACTIONS(5363),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5365),
    [anon_sym_tableextension] = ACTIONS(5363),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5363),
    [anon_sym_Tableextension] = ACTIONS(5363),
    [anon_sym_TableExtension] = ACTIONS(5363),
    [anon_sym_tableExtension] = ACTIONS(5363),
    [sym_page_keyword] = ACTIONS(5365),
    [anon_sym_pageextension] = ACTIONS(5363),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5363),
    [anon_sym_Pageextension] = ACTIONS(5363),
    [anon_sym_PageExtension] = ACTIONS(5363),
    [anon_sym_pageExtension] = ACTIONS(5363),
    [anon_sym_codeunit] = ACTIONS(5363),
    [anon_sym_CODEUNIT] = ACTIONS(5363),
    [anon_sym_Codeunit] = ACTIONS(5363),
    [anon_sym_CodeUnit] = ACTIONS(5363),
    [anon_sym_COdeunit] = ACTIONS(5363),
    [anon_sym_codeUnit] = ACTIONS(5363),
    [sym_report_keyword] = ACTIONS(5365),
    [anon_sym_reportextension] = ACTIONS(5363),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5363),
    [anon_sym_Reportextension] = ACTIONS(5363),
    [anon_sym_ReportExtension] = ACTIONS(5363),
    [anon_sym_reportExtension] = ACTIONS(5363),
    [sym_query_keyword] = ACTIONS(5363),
    [anon_sym_xmlport] = ACTIONS(5363),
    [anon_sym_XMLPORT] = ACTIONS(5363),
    [anon_sym_Xmlport] = ACTIONS(5363),
    [anon_sym_XMLport] = ACTIONS(5363),
    [anon_sym_XMLPort] = ACTIONS(5363),
    [anon_sym_XmlPort] = ACTIONS(5363),
    [anon_sym_enum] = ACTIONS(5365),
    [anon_sym_ENUM] = ACTIONS(5365),
    [anon_sym_Enum] = ACTIONS(5365),
    [anon_sym_eNUM] = ACTIONS(5363),
    [anon_sym_eNum] = ACTIONS(5363),
    [anon_sym_ENum] = ACTIONS(5363),
    [anon_sym_enumextension] = ACTIONS(5363),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5363),
    [anon_sym_Enumextension] = ACTIONS(5363),
    [anon_sym_EnumExtension] = ACTIONS(5363),
    [anon_sym_enumExtension] = ACTIONS(5363),
    [sym_interface_keyword] = ACTIONS(5363),
    [anon_sym_controladdin] = ACTIONS(5363),
    [anon_sym_CONTROLADDIN] = ACTIONS(5363),
    [anon_sym_Controladdin] = ACTIONS(5363),
    [anon_sym_ControlAddIn] = ACTIONS(5363),
    [anon_sym_ControlAddin] = ACTIONS(5363),
    [anon_sym_controlAddIn] = ACTIONS(5363),
    [anon_sym_controlAddin] = ACTIONS(5363),
    [anon_sym_dotnet] = ACTIONS(5363),
    [anon_sym_DOTNET] = ACTIONS(5363),
    [anon_sym_Dotnet] = ACTIONS(5363),
    [anon_sym_DotNet] = ACTIONS(5363),
    [anon_sym_dotNet] = ACTIONS(5363),
    [sym_profile_keyword] = ACTIONS(5365),
    [anon_sym_profileextension] = ACTIONS(5363),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5363),
    [anon_sym_Profileextension] = ACTIONS(5363),
    [anon_sym_ProfileExtension] = ACTIONS(5363),
    [anon_sym_profileExtension] = ACTIONS(5363),
    [anon_sym_permissionset] = ACTIONS(5365),
    [anon_sym_PERMISSIONSET] = ACTIONS(5365),
    [anon_sym_Permissionset] = ACTIONS(5365),
    [anon_sym_PermissionSet] = ACTIONS(5365),
    [anon_sym_permissionSet] = ACTIONS(5365),
    [anon_sym_permissionsetextension] = ACTIONS(5363),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5363),
    [anon_sym_Permissionsetextension] = ACTIONS(5363),
    [anon_sym_PermissionSetExtension] = ACTIONS(5363),
    [anon_sym_permissionSetExtension] = ACTIONS(5363),
    [sym_entitlement_keyword] = ACTIONS(5363),
    [anon_sym_pagecustomization] = ACTIONS(5363),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5363),
    [anon_sym_Pagecustomization] = ACTIONS(5363),
    [anon_sym_PageCustomization] = ACTIONS(5363),
    [anon_sym_pageCustomization] = ACTIONS(5363),
    [sym_using_keyword] = ACTIONS(5363),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5363),
    [sym_preproc_close] = ACTIONS(5363),
  },
  [STATE(2057)] = {
    [anon_sym_POUNDif] = ACTIONS(5367),
    [anon_sym_POUNDIF] = ACTIONS(5367),
    [anon_sym_POUNDIf] = ACTIONS(5367),
    [anon_sym_POUNDelif] = ACTIONS(5367),
    [anon_sym_POUNDELIF] = ACTIONS(5367),
    [anon_sym_POUNDElif] = ACTIONS(5367),
    [anon_sym_POUNDelse] = ACTIONS(5367),
    [anon_sym_POUNDELSE] = ACTIONS(5367),
    [anon_sym_POUNDElse] = ACTIONS(5367),
    [anon_sym_POUNDendif] = ACTIONS(5367),
    [anon_sym_POUNDENDIF] = ACTIONS(5367),
    [anon_sym_POUNDEndif] = ACTIONS(5367),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5369),
    [anon_sym_tableextension] = ACTIONS(5367),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5367),
    [anon_sym_Tableextension] = ACTIONS(5367),
    [anon_sym_TableExtension] = ACTIONS(5367),
    [anon_sym_tableExtension] = ACTIONS(5367),
    [sym_page_keyword] = ACTIONS(5369),
    [anon_sym_pageextension] = ACTIONS(5367),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5367),
    [anon_sym_Pageextension] = ACTIONS(5367),
    [anon_sym_PageExtension] = ACTIONS(5367),
    [anon_sym_pageExtension] = ACTIONS(5367),
    [anon_sym_codeunit] = ACTIONS(5367),
    [anon_sym_CODEUNIT] = ACTIONS(5367),
    [anon_sym_Codeunit] = ACTIONS(5367),
    [anon_sym_CodeUnit] = ACTIONS(5367),
    [anon_sym_COdeunit] = ACTIONS(5367),
    [anon_sym_codeUnit] = ACTIONS(5367),
    [sym_report_keyword] = ACTIONS(5369),
    [anon_sym_reportextension] = ACTIONS(5367),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5367),
    [anon_sym_Reportextension] = ACTIONS(5367),
    [anon_sym_ReportExtension] = ACTIONS(5367),
    [anon_sym_reportExtension] = ACTIONS(5367),
    [sym_query_keyword] = ACTIONS(5367),
    [anon_sym_xmlport] = ACTIONS(5367),
    [anon_sym_XMLPORT] = ACTIONS(5367),
    [anon_sym_Xmlport] = ACTIONS(5367),
    [anon_sym_XMLport] = ACTIONS(5367),
    [anon_sym_XMLPort] = ACTIONS(5367),
    [anon_sym_XmlPort] = ACTIONS(5367),
    [anon_sym_enum] = ACTIONS(5369),
    [anon_sym_ENUM] = ACTIONS(5369),
    [anon_sym_Enum] = ACTIONS(5369),
    [anon_sym_eNUM] = ACTIONS(5367),
    [anon_sym_eNum] = ACTIONS(5367),
    [anon_sym_ENum] = ACTIONS(5367),
    [anon_sym_enumextension] = ACTIONS(5367),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5367),
    [anon_sym_Enumextension] = ACTIONS(5367),
    [anon_sym_EnumExtension] = ACTIONS(5367),
    [anon_sym_enumExtension] = ACTIONS(5367),
    [sym_interface_keyword] = ACTIONS(5367),
    [anon_sym_controladdin] = ACTIONS(5367),
    [anon_sym_CONTROLADDIN] = ACTIONS(5367),
    [anon_sym_Controladdin] = ACTIONS(5367),
    [anon_sym_ControlAddIn] = ACTIONS(5367),
    [anon_sym_ControlAddin] = ACTIONS(5367),
    [anon_sym_controlAddIn] = ACTIONS(5367),
    [anon_sym_controlAddin] = ACTIONS(5367),
    [anon_sym_dotnet] = ACTIONS(5367),
    [anon_sym_DOTNET] = ACTIONS(5367),
    [anon_sym_Dotnet] = ACTIONS(5367),
    [anon_sym_DotNet] = ACTIONS(5367),
    [anon_sym_dotNet] = ACTIONS(5367),
    [sym_profile_keyword] = ACTIONS(5369),
    [anon_sym_profileextension] = ACTIONS(5367),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5367),
    [anon_sym_Profileextension] = ACTIONS(5367),
    [anon_sym_ProfileExtension] = ACTIONS(5367),
    [anon_sym_profileExtension] = ACTIONS(5367),
    [anon_sym_permissionset] = ACTIONS(5369),
    [anon_sym_PERMISSIONSET] = ACTIONS(5369),
    [anon_sym_Permissionset] = ACTIONS(5369),
    [anon_sym_PermissionSet] = ACTIONS(5369),
    [anon_sym_permissionSet] = ACTIONS(5369),
    [anon_sym_permissionsetextension] = ACTIONS(5367),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5367),
    [anon_sym_Permissionsetextension] = ACTIONS(5367),
    [anon_sym_PermissionSetExtension] = ACTIONS(5367),
    [anon_sym_permissionSetExtension] = ACTIONS(5367),
    [sym_entitlement_keyword] = ACTIONS(5367),
    [anon_sym_pagecustomization] = ACTIONS(5367),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5367),
    [anon_sym_Pagecustomization] = ACTIONS(5367),
    [anon_sym_PageCustomization] = ACTIONS(5367),
    [anon_sym_pageCustomization] = ACTIONS(5367),
    [sym_using_keyword] = ACTIONS(5367),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5367),
    [sym_preproc_close] = ACTIONS(5367),
  },
  [STATE(2058)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(2059)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [anon_sym_POUNDelif] = ACTIONS(2322),
    [anon_sym_POUNDELIF] = ACTIONS(2322),
    [anon_sym_POUNDElif] = ACTIONS(2322),
    [anon_sym_POUNDelse] = ACTIONS(2322),
    [anon_sym_POUNDELSE] = ACTIONS(2322),
    [anon_sym_POUNDElse] = ACTIONS(2322),
    [anon_sym_POUNDendif] = ACTIONS(2322),
    [anon_sym_POUNDENDIF] = ACTIONS(2322),
    [anon_sym_POUNDEndif] = ACTIONS(2322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_close] = ACTIONS(2322),
  },
  [STATE(2060)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2360),
    [anon_sym_SEMI] = ACTIONS(2362),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2362),
    [anon_sym_COMMA] = ACTIONS(2362),
    [anon_sym_COLON] = ACTIONS(2360),
    [anon_sym_DASH] = ACTIONS(2360),
    [aux_sym_boolean_token1] = ACTIONS(2360),
    [aux_sym_boolean_token2] = ACTIONS(2360),
    [sym_decimal] = ACTIONS(2360),
    [anon_sym_LPAREN] = ACTIONS(2362),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2360),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2360),
    [aux_sym_basic_type_token21] = ACTIONS(2360),
    [aux_sym_basic_type_token22] = ACTIONS(2360),
    [aux_sym_basic_type_token48] = ACTIONS(2360),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2360),
    [anon_sym_POUNDif] = ACTIONS(2362),
    [anon_sym_POUNDIF] = ACTIONS(2362),
    [anon_sym_POUNDIf] = ACTIONS(2362),
    [anon_sym_not] = ACTIONS(2360),
    [anon_sym_NOT] = ACTIONS(2360),
    [anon_sym_Not] = ACTIONS(2360),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2362),
    [aux_sym__expression_token1] = ACTIONS(2362),
    [aux_sym__expression_token2] = ACTIONS(2362),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2360),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(2360),
    [anon_sym_GT_EQ] = ACTIONS(2362),
    [anon_sym_LT_EQ] = ACTIONS(2362),
    [anon_sym_GT] = ACTIONS(2360),
    [anon_sym_LT] = ACTIONS(2360),
    [anon_sym_LT_GT] = ACTIONS(2362),
    [anon_sym_and] = ACTIONS(2360),
    [anon_sym_AND] = ACTIONS(2360),
    [anon_sym_And] = ACTIONS(2360),
    [anon_sym_or] = ACTIONS(2360),
    [anon_sym_OR] = ACTIONS(2360),
    [anon_sym_Or] = ACTIONS(2360),
    [anon_sym_xor] = ACTIONS(2360),
    [anon_sym_XOR] = ACTIONS(2360),
    [anon_sym_Xor] = ACTIONS(2360),
    [anon_sym_QMARK] = ACTIONS(2362),
    [sym_datetime_literal] = ACTIONS(2362),
    [sym_date_literal] = ACTIONS(2360),
    [sym_time_literal] = ACTIONS(2360),
    [sym_biginteger_literal] = ACTIONS(2362),
    [anon_sym_else] = ACTIONS(2360),
    [anon_sym_ELSE] = ACTIONS(2360),
    [anon_sym_Else] = ACTIONS(2360),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_IN] = ACTIONS(2360),
    [anon_sym_In] = ACTIONS(2360),
    [sym_page_keyword] = ACTIONS(2360),
    [anon_sym_codeunit] = ACTIONS(2360),
    [anon_sym_CODEUNIT] = ACTIONS(2360),
    [anon_sym_Codeunit] = ACTIONS(2360),
    [anon_sym_CodeUnit] = ACTIONS(2360),
    [anon_sym_COdeunit] = ACTIONS(2360),
    [anon_sym_codeUnit] = ACTIONS(2360),
    [sym_report_keyword] = ACTIONS(2360),
    [sym_query_keyword] = ACTIONS(2360),
    [anon_sym_xmlport] = ACTIONS(2360),
    [anon_sym_XMLPORT] = ACTIONS(2360),
    [anon_sym_Xmlport] = ACTIONS(2360),
    [anon_sym_XMLport] = ACTIONS(2360),
    [anon_sym_XMLPort] = ACTIONS(2360),
    [anon_sym_XmlPort] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_ENUM] = ACTIONS(2360),
    [anon_sym_Enum] = ACTIONS(2360),
    [anon_sym_eNUM] = ACTIONS(2360),
    [anon_sym_eNum] = ACTIONS(2360),
    [anon_sym_ENum] = ACTIONS(2360),
    [sym_quoted_identifier] = ACTIONS(2362),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2362),
    [sym_integer] = ACTIONS(2360),
    [sym_continue_as_identifier] = ACTIONS(2362),
    [sym_preproc_open] = ACTIONS(2362),
  },
  [STATE(2061)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2316),
    [anon_sym_SEMI] = ACTIONS(2318),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2318),
    [anon_sym_COMMA] = ACTIONS(2318),
    [anon_sym_COLON] = ACTIONS(2316),
    [anon_sym_DASH] = ACTIONS(2316),
    [aux_sym_boolean_token1] = ACTIONS(2316),
    [aux_sym_boolean_token2] = ACTIONS(2316),
    [sym_decimal] = ACTIONS(2316),
    [anon_sym_LPAREN] = ACTIONS(2318),
    [anon_sym_DOT_DOT] = ACTIONS(2318),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2316),
    [anon_sym_STAR] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2316),
    [aux_sym_basic_type_token21] = ACTIONS(2316),
    [aux_sym_basic_type_token22] = ACTIONS(2316),
    [aux_sym_basic_type_token48] = ACTIONS(2316),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2316),
    [anon_sym_POUNDif] = ACTIONS(2318),
    [anon_sym_POUNDIF] = ACTIONS(2318),
    [anon_sym_POUNDIf] = ACTIONS(2318),
    [anon_sym_not] = ACTIONS(2316),
    [anon_sym_NOT] = ACTIONS(2316),
    [anon_sym_Not] = ACTIONS(2316),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2318),
    [aux_sym__expression_token1] = ACTIONS(2318),
    [aux_sym__expression_token2] = ACTIONS(2318),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2316),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2316),
    [anon_sym_SLASH] = ACTIONS(2316),
    [anon_sym_div] = ACTIONS(2316),
    [anon_sym_DIV] = ACTIONS(2316),
    [anon_sym_Div] = ACTIONS(2316),
    [anon_sym_mod] = ACTIONS(2316),
    [anon_sym_MOD] = ACTIONS(2316),
    [anon_sym_Mod] = ACTIONS(2316),
    [anon_sym_PLUS] = ACTIONS(2316),
    [anon_sym_GT_EQ] = ACTIONS(2318),
    [anon_sym_LT_EQ] = ACTIONS(2318),
    [anon_sym_GT] = ACTIONS(2316),
    [anon_sym_LT] = ACTIONS(2316),
    [anon_sym_LT_GT] = ACTIONS(2318),
    [anon_sym_and] = ACTIONS(2316),
    [anon_sym_AND] = ACTIONS(2316),
    [anon_sym_And] = ACTIONS(2316),
    [anon_sym_or] = ACTIONS(2316),
    [anon_sym_OR] = ACTIONS(2316),
    [anon_sym_Or] = ACTIONS(2316),
    [anon_sym_xor] = ACTIONS(2316),
    [anon_sym_XOR] = ACTIONS(2316),
    [anon_sym_Xor] = ACTIONS(2316),
    [anon_sym_QMARK] = ACTIONS(2318),
    [sym_datetime_literal] = ACTIONS(2318),
    [sym_date_literal] = ACTIONS(2316),
    [sym_time_literal] = ACTIONS(2316),
    [sym_biginteger_literal] = ACTIONS(2318),
    [anon_sym_else] = ACTIONS(2316),
    [anon_sym_ELSE] = ACTIONS(2316),
    [anon_sym_Else] = ACTIONS(2316),
    [anon_sym_in] = ACTIONS(2316),
    [anon_sym_IN] = ACTIONS(2316),
    [anon_sym_In] = ACTIONS(2316),
    [sym_page_keyword] = ACTIONS(2316),
    [anon_sym_codeunit] = ACTIONS(2316),
    [anon_sym_CODEUNIT] = ACTIONS(2316),
    [anon_sym_Codeunit] = ACTIONS(2316),
    [anon_sym_CodeUnit] = ACTIONS(2316),
    [anon_sym_COdeunit] = ACTIONS(2316),
    [anon_sym_codeUnit] = ACTIONS(2316),
    [sym_report_keyword] = ACTIONS(2316),
    [sym_query_keyword] = ACTIONS(2316),
    [anon_sym_xmlport] = ACTIONS(2316),
    [anon_sym_XMLPORT] = ACTIONS(2316),
    [anon_sym_Xmlport] = ACTIONS(2316),
    [anon_sym_XMLport] = ACTIONS(2316),
    [anon_sym_XMLPort] = ACTIONS(2316),
    [anon_sym_XmlPort] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_ENUM] = ACTIONS(2316),
    [anon_sym_Enum] = ACTIONS(2316),
    [anon_sym_eNUM] = ACTIONS(2316),
    [anon_sym_eNum] = ACTIONS(2316),
    [anon_sym_ENum] = ACTIONS(2316),
    [sym_quoted_identifier] = ACTIONS(2318),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2318),
    [sym_integer] = ACTIONS(2316),
    [sym_continue_as_identifier] = ACTIONS(2318),
    [sym_preproc_open] = ACTIONS(2318),
  },
  [STATE(2062)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_COLON] = ACTIONS(2320),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
  },
  [STATE(2063)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_COLON] = ACTIONS(2320),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
  },
  [STATE(2064)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_COLON] = ACTIONS(2320),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
  },
  [STATE(2065)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_COLON] = ACTIONS(2320),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
  },
  [STATE(2066)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_COLON] = ACTIONS(2320),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
  },
  [STATE(2067)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_COLON] = ACTIONS(2320),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
  },
  [STATE(2068)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_COLON] = ACTIONS(2320),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
  },
  [STATE(2069)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2322),
    [anon_sym_COMMA] = ACTIONS(2322),
    [anon_sym_COLON] = ACTIONS(2320),
    [anon_sym_DASH] = ACTIONS(2320),
    [aux_sym_boolean_token1] = ACTIONS(2320),
    [aux_sym_boolean_token2] = ACTIONS(2320),
    [sym_decimal] = ACTIONS(2320),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2320),
    [aux_sym_basic_type_token21] = ACTIONS(2320),
    [aux_sym_basic_type_token22] = ACTIONS(2320),
    [aux_sym_basic_type_token48] = ACTIONS(2320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2320),
    [anon_sym_POUNDif] = ACTIONS(2322),
    [anon_sym_POUNDIF] = ACTIONS(2322),
    [anon_sym_POUNDIf] = ACTIONS(2322),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_NOT] = ACTIONS(2320),
    [anon_sym_Not] = ACTIONS(2320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2322),
    [aux_sym__expression_token1] = ACTIONS(2322),
    [aux_sym__expression_token2] = ACTIONS(2322),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2320),
    [anon_sym_SLASH] = ACTIONS(2320),
    [anon_sym_div] = ACTIONS(2320),
    [anon_sym_DIV] = ACTIONS(2320),
    [anon_sym_Div] = ACTIONS(2320),
    [anon_sym_mod] = ACTIONS(2320),
    [anon_sym_MOD] = ACTIONS(2320),
    [anon_sym_Mod] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_GT_EQ] = ACTIONS(2322),
    [anon_sym_LT_EQ] = ACTIONS(2322),
    [anon_sym_GT] = ACTIONS(2320),
    [anon_sym_LT] = ACTIONS(2320),
    [anon_sym_LT_GT] = ACTIONS(2322),
    [anon_sym_and] = ACTIONS(2320),
    [anon_sym_AND] = ACTIONS(2320),
    [anon_sym_And] = ACTIONS(2320),
    [anon_sym_or] = ACTIONS(2320),
    [anon_sym_OR] = ACTIONS(2320),
    [anon_sym_Or] = ACTIONS(2320),
    [anon_sym_xor] = ACTIONS(2320),
    [anon_sym_XOR] = ACTIONS(2320),
    [anon_sym_Xor] = ACTIONS(2320),
    [anon_sym_QMARK] = ACTIONS(2322),
    [sym_datetime_literal] = ACTIONS(2322),
    [sym_date_literal] = ACTIONS(2320),
    [sym_time_literal] = ACTIONS(2320),
    [sym_biginteger_literal] = ACTIONS(2322),
    [anon_sym_else] = ACTIONS(2320),
    [anon_sym_ELSE] = ACTIONS(2320),
    [anon_sym_Else] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_IN] = ACTIONS(2320),
    [anon_sym_In] = ACTIONS(2320),
    [sym_page_keyword] = ACTIONS(2320),
    [anon_sym_codeunit] = ACTIONS(2320),
    [anon_sym_CODEUNIT] = ACTIONS(2320),
    [anon_sym_Codeunit] = ACTIONS(2320),
    [anon_sym_CodeUnit] = ACTIONS(2320),
    [anon_sym_COdeunit] = ACTIONS(2320),
    [anon_sym_codeUnit] = ACTIONS(2320),
    [sym_report_keyword] = ACTIONS(2320),
    [sym_query_keyword] = ACTIONS(2320),
    [anon_sym_xmlport] = ACTIONS(2320),
    [anon_sym_XMLPORT] = ACTIONS(2320),
    [anon_sym_Xmlport] = ACTIONS(2320),
    [anon_sym_XMLport] = ACTIONS(2320),
    [anon_sym_XMLPort] = ACTIONS(2320),
    [anon_sym_XmlPort] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_ENUM] = ACTIONS(2320),
    [anon_sym_Enum] = ACTIONS(2320),
    [anon_sym_eNUM] = ACTIONS(2320),
    [anon_sym_eNum] = ACTIONS(2320),
    [anon_sym_ENum] = ACTIONS(2320),
    [sym_quoted_identifier] = ACTIONS(2322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2322),
    [sym_integer] = ACTIONS(2320),
    [sym_continue_as_identifier] = ACTIONS(2322),
    [sym_preproc_open] = ACTIONS(2322),
  },
  [STATE(2070)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2360),
    [anon_sym_SEMI] = ACTIONS(2362),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2362),
    [anon_sym_COMMA] = ACTIONS(2362),
    [anon_sym_COLON] = ACTIONS(2360),
    [anon_sym_DASH] = ACTIONS(2360),
    [aux_sym_boolean_token1] = ACTIONS(2360),
    [aux_sym_boolean_token2] = ACTIONS(2360),
    [sym_decimal] = ACTIONS(2360),
    [anon_sym_LPAREN] = ACTIONS(2362),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2360),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2360),
    [aux_sym_basic_type_token21] = ACTIONS(2360),
    [aux_sym_basic_type_token22] = ACTIONS(2360),
    [aux_sym_basic_type_token48] = ACTIONS(2360),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2360),
    [anon_sym_POUNDif] = ACTIONS(2362),
    [anon_sym_POUNDIF] = ACTIONS(2362),
    [anon_sym_POUNDIf] = ACTIONS(2362),
    [anon_sym_not] = ACTIONS(2360),
    [anon_sym_NOT] = ACTIONS(2360),
    [anon_sym_Not] = ACTIONS(2360),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2362),
    [aux_sym__expression_token1] = ACTIONS(2362),
    [aux_sym__expression_token2] = ACTIONS(2362),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2360),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(2360),
    [anon_sym_GT_EQ] = ACTIONS(2362),
    [anon_sym_LT_EQ] = ACTIONS(2362),
    [anon_sym_GT] = ACTIONS(2360),
    [anon_sym_LT] = ACTIONS(2360),
    [anon_sym_LT_GT] = ACTIONS(2362),
    [anon_sym_and] = ACTIONS(2360),
    [anon_sym_AND] = ACTIONS(2360),
    [anon_sym_And] = ACTIONS(2360),
    [anon_sym_or] = ACTIONS(2360),
    [anon_sym_OR] = ACTIONS(2360),
    [anon_sym_Or] = ACTIONS(2360),
    [anon_sym_xor] = ACTIONS(2360),
    [anon_sym_XOR] = ACTIONS(2360),
    [anon_sym_Xor] = ACTIONS(2360),
    [anon_sym_QMARK] = ACTIONS(2362),
    [sym_datetime_literal] = ACTIONS(2362),
    [sym_date_literal] = ACTIONS(2360),
    [sym_time_literal] = ACTIONS(2360),
    [sym_biginteger_literal] = ACTIONS(2362),
    [anon_sym_else] = ACTIONS(2360),
    [anon_sym_ELSE] = ACTIONS(2360),
    [anon_sym_Else] = ACTIONS(2360),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_IN] = ACTIONS(2360),
    [anon_sym_In] = ACTIONS(2360),
    [sym_page_keyword] = ACTIONS(2360),
    [anon_sym_codeunit] = ACTIONS(2360),
    [anon_sym_CODEUNIT] = ACTIONS(2360),
    [anon_sym_Codeunit] = ACTIONS(2360),
    [anon_sym_CodeUnit] = ACTIONS(2360),
    [anon_sym_COdeunit] = ACTIONS(2360),
    [anon_sym_codeUnit] = ACTIONS(2360),
    [sym_report_keyword] = ACTIONS(2360),
    [sym_query_keyword] = ACTIONS(2360),
    [anon_sym_xmlport] = ACTIONS(2360),
    [anon_sym_XMLPORT] = ACTIONS(2360),
    [anon_sym_Xmlport] = ACTIONS(2360),
    [anon_sym_XMLport] = ACTIONS(2360),
    [anon_sym_XMLPort] = ACTIONS(2360),
    [anon_sym_XmlPort] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_ENUM] = ACTIONS(2360),
    [anon_sym_Enum] = ACTIONS(2360),
    [anon_sym_eNUM] = ACTIONS(2360),
    [anon_sym_eNum] = ACTIONS(2360),
    [anon_sym_ENum] = ACTIONS(2360),
    [sym_quoted_identifier] = ACTIONS(2362),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2362),
    [sym_integer] = ACTIONS(2360),
    [sym_continue_as_identifier] = ACTIONS(2362),
    [sym_preproc_open] = ACTIONS(2362),
  },
  [STATE(2071)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(5209),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(5235),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(2072)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(5209),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(5235),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(2073)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(5209),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(5235),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(2074)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(5209),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(5235),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(5237),
    [anon_sym_AND] = ACTIONS(5239),
    [anon_sym_And] = ACTIONS(5241),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(2075)] = {
    [anon_sym_POUNDif] = ACTIONS(5371),
    [anon_sym_POUNDIF] = ACTIONS(5371),
    [anon_sym_POUNDIf] = ACTIONS(5371),
    [anon_sym_POUNDelif] = ACTIONS(5371),
    [anon_sym_POUNDELIF] = ACTIONS(5371),
    [anon_sym_POUNDElif] = ACTIONS(5371),
    [anon_sym_POUNDelse] = ACTIONS(5371),
    [anon_sym_POUNDELSE] = ACTIONS(5371),
    [anon_sym_POUNDElse] = ACTIONS(5371),
    [anon_sym_POUNDendif] = ACTIONS(5371),
    [anon_sym_POUNDENDIF] = ACTIONS(5371),
    [anon_sym_POUNDEndif] = ACTIONS(5371),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5373),
    [anon_sym_tableextension] = ACTIONS(5371),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5371),
    [anon_sym_Tableextension] = ACTIONS(5371),
    [anon_sym_TableExtension] = ACTIONS(5371),
    [anon_sym_tableExtension] = ACTIONS(5371),
    [sym_page_keyword] = ACTIONS(5373),
    [anon_sym_pageextension] = ACTIONS(5371),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5371),
    [anon_sym_Pageextension] = ACTIONS(5371),
    [anon_sym_PageExtension] = ACTIONS(5371),
    [anon_sym_pageExtension] = ACTIONS(5371),
    [anon_sym_codeunit] = ACTIONS(5371),
    [anon_sym_CODEUNIT] = ACTIONS(5371),
    [anon_sym_Codeunit] = ACTIONS(5371),
    [anon_sym_CodeUnit] = ACTIONS(5371),
    [anon_sym_COdeunit] = ACTIONS(5371),
    [anon_sym_codeUnit] = ACTIONS(5371),
    [sym_report_keyword] = ACTIONS(5373),
    [anon_sym_reportextension] = ACTIONS(5371),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5371),
    [anon_sym_Reportextension] = ACTIONS(5371),
    [anon_sym_ReportExtension] = ACTIONS(5371),
    [anon_sym_reportExtension] = ACTIONS(5371),
    [sym_query_keyword] = ACTIONS(5371),
    [anon_sym_xmlport] = ACTIONS(5371),
    [anon_sym_XMLPORT] = ACTIONS(5371),
    [anon_sym_Xmlport] = ACTIONS(5371),
    [anon_sym_XMLport] = ACTIONS(5371),
    [anon_sym_XMLPort] = ACTIONS(5371),
    [anon_sym_XmlPort] = ACTIONS(5371),
    [anon_sym_enum] = ACTIONS(5373),
    [anon_sym_ENUM] = ACTIONS(5373),
    [anon_sym_Enum] = ACTIONS(5373),
    [anon_sym_eNUM] = ACTIONS(5371),
    [anon_sym_eNum] = ACTIONS(5371),
    [anon_sym_ENum] = ACTIONS(5371),
    [anon_sym_enumextension] = ACTIONS(5371),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5371),
    [anon_sym_Enumextension] = ACTIONS(5371),
    [anon_sym_EnumExtension] = ACTIONS(5371),
    [anon_sym_enumExtension] = ACTIONS(5371),
    [sym_interface_keyword] = ACTIONS(5371),
    [anon_sym_controladdin] = ACTIONS(5371),
    [anon_sym_CONTROLADDIN] = ACTIONS(5371),
    [anon_sym_Controladdin] = ACTIONS(5371),
    [anon_sym_ControlAddIn] = ACTIONS(5371),
    [anon_sym_ControlAddin] = ACTIONS(5371),
    [anon_sym_controlAddIn] = ACTIONS(5371),
    [anon_sym_controlAddin] = ACTIONS(5371),
    [anon_sym_dotnet] = ACTIONS(5371),
    [anon_sym_DOTNET] = ACTIONS(5371),
    [anon_sym_Dotnet] = ACTIONS(5371),
    [anon_sym_DotNet] = ACTIONS(5371),
    [anon_sym_dotNet] = ACTIONS(5371),
    [sym_profile_keyword] = ACTIONS(5373),
    [anon_sym_profileextension] = ACTIONS(5371),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5371),
    [anon_sym_Profileextension] = ACTIONS(5371),
    [anon_sym_ProfileExtension] = ACTIONS(5371),
    [anon_sym_profileExtension] = ACTIONS(5371),
    [anon_sym_permissionset] = ACTIONS(5373),
    [anon_sym_PERMISSIONSET] = ACTIONS(5373),
    [anon_sym_Permissionset] = ACTIONS(5373),
    [anon_sym_PermissionSet] = ACTIONS(5373),
    [anon_sym_permissionSet] = ACTIONS(5373),
    [anon_sym_permissionsetextension] = ACTIONS(5371),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5371),
    [anon_sym_Permissionsetextension] = ACTIONS(5371),
    [anon_sym_PermissionSetExtension] = ACTIONS(5371),
    [anon_sym_permissionSetExtension] = ACTIONS(5371),
    [sym_entitlement_keyword] = ACTIONS(5371),
    [anon_sym_pagecustomization] = ACTIONS(5371),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5371),
    [anon_sym_Pagecustomization] = ACTIONS(5371),
    [anon_sym_PageCustomization] = ACTIONS(5371),
    [anon_sym_pageCustomization] = ACTIONS(5371),
    [sym_using_keyword] = ACTIONS(5371),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5371),
    [sym_preproc_close] = ACTIONS(5371),
  },
  [STATE(2076)] = {
    [anon_sym_POUNDif] = ACTIONS(5375),
    [anon_sym_POUNDIF] = ACTIONS(5375),
    [anon_sym_POUNDIf] = ACTIONS(5375),
    [anon_sym_POUNDelif] = ACTIONS(5375),
    [anon_sym_POUNDELIF] = ACTIONS(5375),
    [anon_sym_POUNDElif] = ACTIONS(5375),
    [anon_sym_POUNDelse] = ACTIONS(5375),
    [anon_sym_POUNDELSE] = ACTIONS(5375),
    [anon_sym_POUNDElse] = ACTIONS(5375),
    [anon_sym_POUNDendif] = ACTIONS(5375),
    [anon_sym_POUNDENDIF] = ACTIONS(5375),
    [anon_sym_POUNDEndif] = ACTIONS(5375),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5377),
    [anon_sym_tableextension] = ACTIONS(5375),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5375),
    [anon_sym_Tableextension] = ACTIONS(5375),
    [anon_sym_TableExtension] = ACTIONS(5375),
    [anon_sym_tableExtension] = ACTIONS(5375),
    [sym_page_keyword] = ACTIONS(5377),
    [anon_sym_pageextension] = ACTIONS(5375),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5375),
    [anon_sym_Pageextension] = ACTIONS(5375),
    [anon_sym_PageExtension] = ACTIONS(5375),
    [anon_sym_pageExtension] = ACTIONS(5375),
    [anon_sym_codeunit] = ACTIONS(5375),
    [anon_sym_CODEUNIT] = ACTIONS(5375),
    [anon_sym_Codeunit] = ACTIONS(5375),
    [anon_sym_CodeUnit] = ACTIONS(5375),
    [anon_sym_COdeunit] = ACTIONS(5375),
    [anon_sym_codeUnit] = ACTIONS(5375),
    [sym_report_keyword] = ACTIONS(5377),
    [anon_sym_reportextension] = ACTIONS(5375),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5375),
    [anon_sym_Reportextension] = ACTIONS(5375),
    [anon_sym_ReportExtension] = ACTIONS(5375),
    [anon_sym_reportExtension] = ACTIONS(5375),
    [sym_query_keyword] = ACTIONS(5375),
    [anon_sym_xmlport] = ACTIONS(5375),
    [anon_sym_XMLPORT] = ACTIONS(5375),
    [anon_sym_Xmlport] = ACTIONS(5375),
    [anon_sym_XMLport] = ACTIONS(5375),
    [anon_sym_XMLPort] = ACTIONS(5375),
    [anon_sym_XmlPort] = ACTIONS(5375),
    [anon_sym_enum] = ACTIONS(5377),
    [anon_sym_ENUM] = ACTIONS(5377),
    [anon_sym_Enum] = ACTIONS(5377),
    [anon_sym_eNUM] = ACTIONS(5375),
    [anon_sym_eNum] = ACTIONS(5375),
    [anon_sym_ENum] = ACTIONS(5375),
    [anon_sym_enumextension] = ACTIONS(5375),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5375),
    [anon_sym_Enumextension] = ACTIONS(5375),
    [anon_sym_EnumExtension] = ACTIONS(5375),
    [anon_sym_enumExtension] = ACTIONS(5375),
    [sym_interface_keyword] = ACTIONS(5375),
    [anon_sym_controladdin] = ACTIONS(5375),
    [anon_sym_CONTROLADDIN] = ACTIONS(5375),
    [anon_sym_Controladdin] = ACTIONS(5375),
    [anon_sym_ControlAddIn] = ACTIONS(5375),
    [anon_sym_ControlAddin] = ACTIONS(5375),
    [anon_sym_controlAddIn] = ACTIONS(5375),
    [anon_sym_controlAddin] = ACTIONS(5375),
    [anon_sym_dotnet] = ACTIONS(5375),
    [anon_sym_DOTNET] = ACTIONS(5375),
    [anon_sym_Dotnet] = ACTIONS(5375),
    [anon_sym_DotNet] = ACTIONS(5375),
    [anon_sym_dotNet] = ACTIONS(5375),
    [sym_profile_keyword] = ACTIONS(5377),
    [anon_sym_profileextension] = ACTIONS(5375),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5375),
    [anon_sym_Profileextension] = ACTIONS(5375),
    [anon_sym_ProfileExtension] = ACTIONS(5375),
    [anon_sym_profileExtension] = ACTIONS(5375),
    [anon_sym_permissionset] = ACTIONS(5377),
    [anon_sym_PERMISSIONSET] = ACTIONS(5377),
    [anon_sym_Permissionset] = ACTIONS(5377),
    [anon_sym_PermissionSet] = ACTIONS(5377),
    [anon_sym_permissionSet] = ACTIONS(5377),
    [anon_sym_permissionsetextension] = ACTIONS(5375),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5375),
    [anon_sym_Permissionsetextension] = ACTIONS(5375),
    [anon_sym_PermissionSetExtension] = ACTIONS(5375),
    [anon_sym_permissionSetExtension] = ACTIONS(5375),
    [sym_entitlement_keyword] = ACTIONS(5375),
    [anon_sym_pagecustomization] = ACTIONS(5375),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5375),
    [anon_sym_Pagecustomization] = ACTIONS(5375),
    [anon_sym_PageCustomization] = ACTIONS(5375),
    [anon_sym_pageCustomization] = ACTIONS(5375),
    [sym_using_keyword] = ACTIONS(5375),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5375),
    [sym_preproc_close] = ACTIONS(5375),
  },
  [STATE(2077)] = {
    [anon_sym_POUNDif] = ACTIONS(5379),
    [anon_sym_POUNDIF] = ACTIONS(5379),
    [anon_sym_POUNDIf] = ACTIONS(5379),
    [anon_sym_POUNDelif] = ACTIONS(5379),
    [anon_sym_POUNDELIF] = ACTIONS(5379),
    [anon_sym_POUNDElif] = ACTIONS(5379),
    [anon_sym_POUNDelse] = ACTIONS(5379),
    [anon_sym_POUNDELSE] = ACTIONS(5379),
    [anon_sym_POUNDElse] = ACTIONS(5379),
    [anon_sym_POUNDendif] = ACTIONS(5379),
    [anon_sym_POUNDENDIF] = ACTIONS(5379),
    [anon_sym_POUNDEndif] = ACTIONS(5379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5381),
    [anon_sym_tableextension] = ACTIONS(5379),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5379),
    [anon_sym_Tableextension] = ACTIONS(5379),
    [anon_sym_TableExtension] = ACTIONS(5379),
    [anon_sym_tableExtension] = ACTIONS(5379),
    [sym_page_keyword] = ACTIONS(5381),
    [anon_sym_pageextension] = ACTIONS(5379),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5379),
    [anon_sym_Pageextension] = ACTIONS(5379),
    [anon_sym_PageExtension] = ACTIONS(5379),
    [anon_sym_pageExtension] = ACTIONS(5379),
    [anon_sym_codeunit] = ACTIONS(5379),
    [anon_sym_CODEUNIT] = ACTIONS(5379),
    [anon_sym_Codeunit] = ACTIONS(5379),
    [anon_sym_CodeUnit] = ACTIONS(5379),
    [anon_sym_COdeunit] = ACTIONS(5379),
    [anon_sym_codeUnit] = ACTIONS(5379),
    [sym_report_keyword] = ACTIONS(5381),
    [anon_sym_reportextension] = ACTIONS(5379),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5379),
    [anon_sym_Reportextension] = ACTIONS(5379),
    [anon_sym_ReportExtension] = ACTIONS(5379),
    [anon_sym_reportExtension] = ACTIONS(5379),
    [sym_query_keyword] = ACTIONS(5379),
    [anon_sym_xmlport] = ACTIONS(5379),
    [anon_sym_XMLPORT] = ACTIONS(5379),
    [anon_sym_Xmlport] = ACTIONS(5379),
    [anon_sym_XMLport] = ACTIONS(5379),
    [anon_sym_XMLPort] = ACTIONS(5379),
    [anon_sym_XmlPort] = ACTIONS(5379),
    [anon_sym_enum] = ACTIONS(5381),
    [anon_sym_ENUM] = ACTIONS(5381),
    [anon_sym_Enum] = ACTIONS(5381),
    [anon_sym_eNUM] = ACTIONS(5379),
    [anon_sym_eNum] = ACTIONS(5379),
    [anon_sym_ENum] = ACTIONS(5379),
    [anon_sym_enumextension] = ACTIONS(5379),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5379),
    [anon_sym_Enumextension] = ACTIONS(5379),
    [anon_sym_EnumExtension] = ACTIONS(5379),
    [anon_sym_enumExtension] = ACTIONS(5379),
    [sym_interface_keyword] = ACTIONS(5379),
    [anon_sym_controladdin] = ACTIONS(5379),
    [anon_sym_CONTROLADDIN] = ACTIONS(5379),
    [anon_sym_Controladdin] = ACTIONS(5379),
    [anon_sym_ControlAddIn] = ACTIONS(5379),
    [anon_sym_ControlAddin] = ACTIONS(5379),
    [anon_sym_controlAddIn] = ACTIONS(5379),
    [anon_sym_controlAddin] = ACTIONS(5379),
    [anon_sym_dotnet] = ACTIONS(5379),
    [anon_sym_DOTNET] = ACTIONS(5379),
    [anon_sym_Dotnet] = ACTIONS(5379),
    [anon_sym_DotNet] = ACTIONS(5379),
    [anon_sym_dotNet] = ACTIONS(5379),
    [sym_profile_keyword] = ACTIONS(5381),
    [anon_sym_profileextension] = ACTIONS(5379),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5379),
    [anon_sym_Profileextension] = ACTIONS(5379),
    [anon_sym_ProfileExtension] = ACTIONS(5379),
    [anon_sym_profileExtension] = ACTIONS(5379),
    [anon_sym_permissionset] = ACTIONS(5381),
    [anon_sym_PERMISSIONSET] = ACTIONS(5381),
    [anon_sym_Permissionset] = ACTIONS(5381),
    [anon_sym_PermissionSet] = ACTIONS(5381),
    [anon_sym_permissionSet] = ACTIONS(5381),
    [anon_sym_permissionsetextension] = ACTIONS(5379),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5379),
    [anon_sym_Permissionsetextension] = ACTIONS(5379),
    [anon_sym_PermissionSetExtension] = ACTIONS(5379),
    [anon_sym_permissionSetExtension] = ACTIONS(5379),
    [sym_entitlement_keyword] = ACTIONS(5379),
    [anon_sym_pagecustomization] = ACTIONS(5379),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5379),
    [anon_sym_Pagecustomization] = ACTIONS(5379),
    [anon_sym_PageCustomization] = ACTIONS(5379),
    [anon_sym_pageCustomization] = ACTIONS(5379),
    [sym_using_keyword] = ACTIONS(5379),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5379),
    [sym_preproc_close] = ACTIONS(5379),
  },
  [STATE(2078)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(5209),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(5235),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(5237),
    [anon_sym_AND] = ACTIONS(5239),
    [anon_sym_And] = ACTIONS(5241),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(2079)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(5209),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(5235),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(5237),
    [anon_sym_AND] = ACTIONS(5239),
    [anon_sym_And] = ACTIONS(5241),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(2080)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(5209),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(5235),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(5237),
    [anon_sym_AND] = ACTIONS(5239),
    [anon_sym_And] = ACTIONS(5241),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(2081)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(5209),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(5235),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(5237),
    [anon_sym_AND] = ACTIONS(5239),
    [anon_sym_And] = ACTIONS(5241),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(2082)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2272),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_COLON] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(5209),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2270),
    [anon_sym_POUNDif] = ACTIONS(2272),
    [anon_sym_POUNDIF] = ACTIONS(2272),
    [anon_sym_POUNDIf] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(5235),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(5237),
    [anon_sym_AND] = ACTIONS(5239),
    [anon_sym_And] = ACTIONS(5241),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2270),
    [anon_sym_ELSE] = ACTIONS(2270),
    [anon_sym_Else] = ACTIONS(2270),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_open] = ACTIONS(2272),
  },
  [STATE(2083)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2364),
    [anon_sym_SEMI] = ACTIONS(2366),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2366),
    [anon_sym_COMMA] = ACTIONS(2366),
    [anon_sym_COLON] = ACTIONS(2364),
    [anon_sym_DASH] = ACTIONS(5209),
    [aux_sym_boolean_token1] = ACTIONS(2364),
    [aux_sym_boolean_token2] = ACTIONS(2364),
    [sym_decimal] = ACTIONS(2364),
    [anon_sym_LPAREN] = ACTIONS(2366),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2364),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2364),
    [aux_sym_basic_type_token21] = ACTIONS(2364),
    [aux_sym_basic_type_token22] = ACTIONS(2364),
    [aux_sym_basic_type_token48] = ACTIONS(2364),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2364),
    [anon_sym_POUNDif] = ACTIONS(2366),
    [anon_sym_POUNDIF] = ACTIONS(2366),
    [anon_sym_POUNDIf] = ACTIONS(2366),
    [anon_sym_not] = ACTIONS(2364),
    [anon_sym_NOT] = ACTIONS(2364),
    [anon_sym_Not] = ACTIONS(2364),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2366),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2364),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2364),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(5235),
    [anon_sym_GT_EQ] = ACTIONS(2366),
    [anon_sym_LT_EQ] = ACTIONS(2366),
    [anon_sym_GT] = ACTIONS(2364),
    [anon_sym_LT] = ACTIONS(2364),
    [anon_sym_LT_GT] = ACTIONS(2366),
    [anon_sym_and] = ACTIONS(2364),
    [anon_sym_AND] = ACTIONS(2364),
    [anon_sym_And] = ACTIONS(2364),
    [anon_sym_or] = ACTIONS(2364),
    [anon_sym_OR] = ACTIONS(2364),
    [anon_sym_Or] = ACTIONS(2364),
    [anon_sym_xor] = ACTIONS(2364),
    [anon_sym_XOR] = ACTIONS(2364),
    [anon_sym_Xor] = ACTIONS(2364),
    [anon_sym_QMARK] = ACTIONS(2366),
    [sym_datetime_literal] = ACTIONS(2366),
    [sym_date_literal] = ACTIONS(2364),
    [sym_time_literal] = ACTIONS(2364),
    [sym_biginteger_literal] = ACTIONS(2366),
    [anon_sym_else] = ACTIONS(2364),
    [anon_sym_ELSE] = ACTIONS(2364),
    [anon_sym_Else] = ACTIONS(2364),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2364),
    [anon_sym_codeunit] = ACTIONS(2364),
    [anon_sym_CODEUNIT] = ACTIONS(2364),
    [anon_sym_Codeunit] = ACTIONS(2364),
    [anon_sym_CodeUnit] = ACTIONS(2364),
    [anon_sym_COdeunit] = ACTIONS(2364),
    [anon_sym_codeUnit] = ACTIONS(2364),
    [sym_report_keyword] = ACTIONS(2364),
    [sym_query_keyword] = ACTIONS(2364),
    [anon_sym_xmlport] = ACTIONS(2364),
    [anon_sym_XMLPORT] = ACTIONS(2364),
    [anon_sym_Xmlport] = ACTIONS(2364),
    [anon_sym_XMLport] = ACTIONS(2364),
    [anon_sym_XMLPort] = ACTIONS(2364),
    [anon_sym_XmlPort] = ACTIONS(2364),
    [anon_sym_enum] = ACTIONS(2364),
    [anon_sym_ENUM] = ACTIONS(2364),
    [anon_sym_Enum] = ACTIONS(2364),
    [anon_sym_eNUM] = ACTIONS(2364),
    [anon_sym_eNum] = ACTIONS(2364),
    [anon_sym_ENum] = ACTIONS(2364),
    [sym_quoted_identifier] = ACTIONS(2366),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2366),
    [sym_integer] = ACTIONS(2364),
    [sym_continue_as_identifier] = ACTIONS(2366),
    [sym_preproc_open] = ACTIONS(2366),
  },
  [STATE(2084)] = {
    [anon_sym_POUNDif] = ACTIONS(5383),
    [anon_sym_POUNDIF] = ACTIONS(5383),
    [anon_sym_POUNDIf] = ACTIONS(5383),
    [anon_sym_POUNDelif] = ACTIONS(5383),
    [anon_sym_POUNDELIF] = ACTIONS(5383),
    [anon_sym_POUNDElif] = ACTIONS(5383),
    [anon_sym_POUNDelse] = ACTIONS(5383),
    [anon_sym_POUNDELSE] = ACTIONS(5383),
    [anon_sym_POUNDElse] = ACTIONS(5383),
    [anon_sym_POUNDendif] = ACTIONS(5383),
    [anon_sym_POUNDENDIF] = ACTIONS(5383),
    [anon_sym_POUNDEndif] = ACTIONS(5383),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5385),
    [anon_sym_tableextension] = ACTIONS(5383),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5383),
    [anon_sym_Tableextension] = ACTIONS(5383),
    [anon_sym_TableExtension] = ACTIONS(5383),
    [anon_sym_tableExtension] = ACTIONS(5383),
    [sym_page_keyword] = ACTIONS(5385),
    [anon_sym_pageextension] = ACTIONS(5383),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5383),
    [anon_sym_Pageextension] = ACTIONS(5383),
    [anon_sym_PageExtension] = ACTIONS(5383),
    [anon_sym_pageExtension] = ACTIONS(5383),
    [anon_sym_codeunit] = ACTIONS(5383),
    [anon_sym_CODEUNIT] = ACTIONS(5383),
    [anon_sym_Codeunit] = ACTIONS(5383),
    [anon_sym_CodeUnit] = ACTIONS(5383),
    [anon_sym_COdeunit] = ACTIONS(5383),
    [anon_sym_codeUnit] = ACTIONS(5383),
    [sym_report_keyword] = ACTIONS(5385),
    [anon_sym_reportextension] = ACTIONS(5383),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5383),
    [anon_sym_Reportextension] = ACTIONS(5383),
    [anon_sym_ReportExtension] = ACTIONS(5383),
    [anon_sym_reportExtension] = ACTIONS(5383),
    [sym_query_keyword] = ACTIONS(5383),
    [anon_sym_xmlport] = ACTIONS(5383),
    [anon_sym_XMLPORT] = ACTIONS(5383),
    [anon_sym_Xmlport] = ACTIONS(5383),
    [anon_sym_XMLport] = ACTIONS(5383),
    [anon_sym_XMLPort] = ACTIONS(5383),
    [anon_sym_XmlPort] = ACTIONS(5383),
    [anon_sym_enum] = ACTIONS(5385),
    [anon_sym_ENUM] = ACTIONS(5385),
    [anon_sym_Enum] = ACTIONS(5385),
    [anon_sym_eNUM] = ACTIONS(5383),
    [anon_sym_eNum] = ACTIONS(5383),
    [anon_sym_ENum] = ACTIONS(5383),
    [anon_sym_enumextension] = ACTIONS(5383),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5383),
    [anon_sym_Enumextension] = ACTIONS(5383),
    [anon_sym_EnumExtension] = ACTIONS(5383),
    [anon_sym_enumExtension] = ACTIONS(5383),
    [sym_interface_keyword] = ACTIONS(5383),
    [anon_sym_controladdin] = ACTIONS(5383),
    [anon_sym_CONTROLADDIN] = ACTIONS(5383),
    [anon_sym_Controladdin] = ACTIONS(5383),
    [anon_sym_ControlAddIn] = ACTIONS(5383),
    [anon_sym_ControlAddin] = ACTIONS(5383),
    [anon_sym_controlAddIn] = ACTIONS(5383),
    [anon_sym_controlAddin] = ACTIONS(5383),
    [anon_sym_dotnet] = ACTIONS(5383),
    [anon_sym_DOTNET] = ACTIONS(5383),
    [anon_sym_Dotnet] = ACTIONS(5383),
    [anon_sym_DotNet] = ACTIONS(5383),
    [anon_sym_dotNet] = ACTIONS(5383),
    [sym_profile_keyword] = ACTIONS(5385),
    [anon_sym_profileextension] = ACTIONS(5383),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5383),
    [anon_sym_Profileextension] = ACTIONS(5383),
    [anon_sym_ProfileExtension] = ACTIONS(5383),
    [anon_sym_profileExtension] = ACTIONS(5383),
    [anon_sym_permissionset] = ACTIONS(5385),
    [anon_sym_PERMISSIONSET] = ACTIONS(5385),
    [anon_sym_Permissionset] = ACTIONS(5385),
    [anon_sym_PermissionSet] = ACTIONS(5385),
    [anon_sym_permissionSet] = ACTIONS(5385),
    [anon_sym_permissionsetextension] = ACTIONS(5383),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5383),
    [anon_sym_Permissionsetextension] = ACTIONS(5383),
    [anon_sym_PermissionSetExtension] = ACTIONS(5383),
    [anon_sym_permissionSetExtension] = ACTIONS(5383),
    [sym_entitlement_keyword] = ACTIONS(5383),
    [anon_sym_pagecustomization] = ACTIONS(5383),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5383),
    [anon_sym_Pagecustomization] = ACTIONS(5383),
    [anon_sym_PageCustomization] = ACTIONS(5383),
    [anon_sym_pageCustomization] = ACTIONS(5383),
    [sym_using_keyword] = ACTIONS(5383),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5383),
    [sym_preproc_close] = ACTIONS(5383),
  },
  [STATE(2085)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2360),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2362),
    [anon_sym_COMMA] = ACTIONS(2362),
    [anon_sym_DASH] = ACTIONS(2360),
    [aux_sym_boolean_token1] = ACTIONS(2360),
    [aux_sym_boolean_token2] = ACTIONS(2360),
    [sym_decimal] = ACTIONS(2360),
    [anon_sym_LPAREN] = ACTIONS(2362),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2360),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2360),
    [aux_sym_basic_type_token21] = ACTIONS(2360),
    [aux_sym_basic_type_token22] = ACTIONS(2360),
    [aux_sym_basic_type_token48] = ACTIONS(2360),
    [anon_sym_not] = ACTIONS(2360),
    [anon_sym_NOT] = ACTIONS(2360),
    [anon_sym_Not] = ACTIONS(2360),
    [anon_sym_POUNDelif] = ACTIONS(2362),
    [anon_sym_POUNDELIF] = ACTIONS(2362),
    [anon_sym_POUNDElif] = ACTIONS(2362),
    [anon_sym_POUNDelse] = ACTIONS(2362),
    [anon_sym_POUNDELSE] = ACTIONS(2362),
    [anon_sym_POUNDElse] = ACTIONS(2362),
    [anon_sym_POUNDendif] = ACTIONS(2362),
    [anon_sym_POUNDENDIF] = ACTIONS(2362),
    [anon_sym_POUNDEndif] = ACTIONS(2362),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2362),
    [aux_sym__expression_token1] = ACTIONS(2362),
    [aux_sym__expression_token2] = ACTIONS(2362),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2360),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2360),
    [anon_sym_SLASH] = ACTIONS(4963),
    [anon_sym_div] = ACTIONS(4965),
    [anon_sym_DIV] = ACTIONS(4967),
    [anon_sym_Div] = ACTIONS(4969),
    [anon_sym_mod] = ACTIONS(4971),
    [anon_sym_MOD] = ACTIONS(4973),
    [anon_sym_Mod] = ACTIONS(4975),
    [anon_sym_PLUS] = ACTIONS(2360),
    [anon_sym_GT_EQ] = ACTIONS(2362),
    [anon_sym_LT_EQ] = ACTIONS(2362),
    [anon_sym_GT] = ACTIONS(2360),
    [anon_sym_LT] = ACTIONS(2360),
    [anon_sym_LT_GT] = ACTIONS(2362),
    [anon_sym_and] = ACTIONS(2360),
    [anon_sym_AND] = ACTIONS(2360),
    [anon_sym_And] = ACTIONS(2360),
    [anon_sym_or] = ACTIONS(2360),
    [anon_sym_OR] = ACTIONS(2360),
    [anon_sym_Or] = ACTIONS(2360),
    [anon_sym_xor] = ACTIONS(2360),
    [anon_sym_XOR] = ACTIONS(2360),
    [anon_sym_Xor] = ACTIONS(2360),
    [anon_sym_QMARK] = ACTIONS(2362),
    [sym_datetime_literal] = ACTIONS(2362),
    [sym_date_literal] = ACTIONS(2360),
    [sym_time_literal] = ACTIONS(2360),
    [sym_biginteger_literal] = ACTIONS(2362),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_IN] = ACTIONS(2360),
    [anon_sym_In] = ACTIONS(2360),
    [sym_page_keyword] = ACTIONS(2360),
    [anon_sym_codeunit] = ACTIONS(2360),
    [anon_sym_CODEUNIT] = ACTIONS(2360),
    [anon_sym_Codeunit] = ACTIONS(2360),
    [anon_sym_CodeUnit] = ACTIONS(2360),
    [anon_sym_COdeunit] = ACTIONS(2360),
    [anon_sym_codeUnit] = ACTIONS(2360),
    [sym_report_keyword] = ACTIONS(2360),
    [sym_query_keyword] = ACTIONS(2360),
    [anon_sym_xmlport] = ACTIONS(2360),
    [anon_sym_XMLPORT] = ACTIONS(2360),
    [anon_sym_Xmlport] = ACTIONS(2360),
    [anon_sym_XMLport] = ACTIONS(2360),
    [anon_sym_XMLPort] = ACTIONS(2360),
    [anon_sym_XmlPort] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_ENUM] = ACTIONS(2360),
    [anon_sym_Enum] = ACTIONS(2360),
    [anon_sym_eNUM] = ACTIONS(2360),
    [anon_sym_eNum] = ACTIONS(2360),
    [anon_sym_ENum] = ACTIONS(2360),
    [sym_quoted_identifier] = ACTIONS(2362),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2362),
    [sym_integer] = ACTIONS(2360),
    [sym_continue_as_identifier] = ACTIONS(2362),
    [sym_preproc_close] = ACTIONS(2362),
  },
  [STATE(2086)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_DASH] = ACTIONS(4951),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(4959),
    [aux_sym__expression_token2] = ACTIONS(4961),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(4963),
    [anon_sym_div] = ACTIONS(4965),
    [anon_sym_DIV] = ACTIONS(4967),
    [anon_sym_Div] = ACTIONS(4969),
    [anon_sym_mod] = ACTIONS(4971),
    [anon_sym_MOD] = ACTIONS(4973),
    [anon_sym_Mod] = ACTIONS(4975),
    [anon_sym_PLUS] = ACTIONS(4977),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(2087)] = {
    [sym_comparison_operator] = STATE(3200),
    [sym_in_keyword] = STATE(11188),
    [sym_identifier] = ACTIONS(2270),
    [anon_sym_DOT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_COMMA] = ACTIONS(2272),
    [anon_sym_DASH] = ACTIONS(4951),
    [aux_sym_boolean_token1] = ACTIONS(2270),
    [aux_sym_boolean_token2] = ACTIONS(2270),
    [sym_decimal] = ACTIONS(2270),
    [anon_sym_LPAREN] = ACTIONS(2272),
    [anon_sym_DOT_DOT] = ACTIONS(4953),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2270),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [aux_sym_record_type_token1] = ACTIONS(2270),
    [aux_sym_basic_type_token21] = ACTIONS(2270),
    [aux_sym_basic_type_token22] = ACTIONS(2270),
    [aux_sym_basic_type_token48] = ACTIONS(2270),
    [anon_sym_not] = ACTIONS(2270),
    [anon_sym_NOT] = ACTIONS(2270),
    [anon_sym_Not] = ACTIONS(2270),
    [anon_sym_POUNDelif] = ACTIONS(2272),
    [anon_sym_POUNDELIF] = ACTIONS(2272),
    [anon_sym_POUNDElif] = ACTIONS(2272),
    [anon_sym_POUNDelse] = ACTIONS(2272),
    [anon_sym_POUNDELSE] = ACTIONS(2272),
    [anon_sym_POUNDElse] = ACTIONS(2272),
    [anon_sym_POUNDendif] = ACTIONS(2272),
    [anon_sym_POUNDENDIF] = ACTIONS(2272),
    [anon_sym_POUNDEndif] = ACTIONS(2272),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2272),
    [aux_sym__expression_token1] = ACTIONS(4959),
    [aux_sym__expression_token2] = ACTIONS(4961),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2270),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2270),
    [anon_sym_SLASH] = ACTIONS(4963),
    [anon_sym_div] = ACTIONS(4965),
    [anon_sym_DIV] = ACTIONS(4967),
    [anon_sym_Div] = ACTIONS(4969),
    [anon_sym_mod] = ACTIONS(4971),
    [anon_sym_MOD] = ACTIONS(4973),
    [anon_sym_Mod] = ACTIONS(4975),
    [anon_sym_PLUS] = ACTIONS(4977),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(2270),
    [anon_sym_AND] = ACTIONS(2270),
    [anon_sym_And] = ACTIONS(2270),
    [anon_sym_or] = ACTIONS(2270),
    [anon_sym_OR] = ACTIONS(2270),
    [anon_sym_Or] = ACTIONS(2270),
    [anon_sym_xor] = ACTIONS(2270),
    [anon_sym_XOR] = ACTIONS(2270),
    [anon_sym_Xor] = ACTIONS(2270),
    [anon_sym_QMARK] = ACTIONS(2272),
    [sym_datetime_literal] = ACTIONS(2272),
    [sym_date_literal] = ACTIONS(2270),
    [sym_time_literal] = ACTIONS(2270),
    [sym_biginteger_literal] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2270),
    [anon_sym_codeunit] = ACTIONS(2270),
    [anon_sym_CODEUNIT] = ACTIONS(2270),
    [anon_sym_Codeunit] = ACTIONS(2270),
    [anon_sym_CodeUnit] = ACTIONS(2270),
    [anon_sym_COdeunit] = ACTIONS(2270),
    [anon_sym_codeUnit] = ACTIONS(2270),
    [sym_report_keyword] = ACTIONS(2270),
    [sym_query_keyword] = ACTIONS(2270),
    [anon_sym_xmlport] = ACTIONS(2270),
    [anon_sym_XMLPORT] = ACTIONS(2270),
    [anon_sym_Xmlport] = ACTIONS(2270),
    [anon_sym_XMLport] = ACTIONS(2270),
    [anon_sym_XMLPort] = ACTIONS(2270),
    [anon_sym_XmlPort] = ACTIONS(2270),
    [anon_sym_enum] = ACTIONS(2270),
    [anon_sym_ENUM] = ACTIONS(2270),
    [anon_sym_Enum] = ACTIONS(2270),
    [anon_sym_eNUM] = ACTIONS(2270),
    [anon_sym_eNum] = ACTIONS(2270),
    [anon_sym_ENum] = ACTIONS(2270),
    [sym_quoted_identifier] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2272),
    [sym_integer] = ACTIONS(2270),
    [sym_continue_as_identifier] = ACTIONS(2272),
    [sym_preproc_close] = ACTIONS(2272),
  },
  [STATE(2088)] = {
    [anon_sym_POUNDif] = ACTIONS(5387),
    [anon_sym_POUNDIF] = ACTIONS(5387),
    [anon_sym_POUNDIf] = ACTIONS(5387),
    [anon_sym_POUNDelif] = ACTIONS(5387),
    [anon_sym_POUNDELIF] = ACTIONS(5387),
    [anon_sym_POUNDElif] = ACTIONS(5387),
    [anon_sym_POUNDelse] = ACTIONS(5387),
    [anon_sym_POUNDELSE] = ACTIONS(5387),
    [anon_sym_POUNDElse] = ACTIONS(5387),
    [anon_sym_POUNDendif] = ACTIONS(5387),
    [anon_sym_POUNDENDIF] = ACTIONS(5387),
    [anon_sym_POUNDEndif] = ACTIONS(5387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5389),
    [anon_sym_tableextension] = ACTIONS(5387),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5387),
    [anon_sym_Tableextension] = ACTIONS(5387),
    [anon_sym_TableExtension] = ACTIONS(5387),
    [anon_sym_tableExtension] = ACTIONS(5387),
    [sym_page_keyword] = ACTIONS(5389),
    [anon_sym_pageextension] = ACTIONS(5387),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5387),
    [anon_sym_Pageextension] = ACTIONS(5387),
    [anon_sym_PageExtension] = ACTIONS(5387),
    [anon_sym_pageExtension] = ACTIONS(5387),
    [anon_sym_codeunit] = ACTIONS(5387),
    [anon_sym_CODEUNIT] = ACTIONS(5387),
    [anon_sym_Codeunit] = ACTIONS(5387),
    [anon_sym_CodeUnit] = ACTIONS(5387),
    [anon_sym_COdeunit] = ACTIONS(5387),
    [anon_sym_codeUnit] = ACTIONS(5387),
    [sym_report_keyword] = ACTIONS(5389),
    [anon_sym_reportextension] = ACTIONS(5387),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5387),
    [anon_sym_Reportextension] = ACTIONS(5387),
    [anon_sym_ReportExtension] = ACTIONS(5387),
    [anon_sym_reportExtension] = ACTIONS(5387),
    [sym_query_keyword] = ACTIONS(5387),
    [anon_sym_xmlport] = ACTIONS(5387),
    [anon_sym_XMLPORT] = ACTIONS(5387),
    [anon_sym_Xmlport] = ACTIONS(5387),
    [anon_sym_XMLport] = ACTIONS(5387),
    [anon_sym_XMLPort] = ACTIONS(5387),
    [anon_sym_XmlPort] = ACTIONS(5387),
    [anon_sym_enum] = ACTIONS(5389),
    [anon_sym_ENUM] = ACTIONS(5389),
    [anon_sym_Enum] = ACTIONS(5389),
    [anon_sym_eNUM] = ACTIONS(5387),
    [anon_sym_eNum] = ACTIONS(5387),
    [anon_sym_ENum] = ACTIONS(5387),
    [anon_sym_enumextension] = ACTIONS(5387),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5387),
    [anon_sym_Enumextension] = ACTIONS(5387),
    [anon_sym_EnumExtension] = ACTIONS(5387),
    [anon_sym_enumExtension] = ACTIONS(5387),
    [sym_interface_keyword] = ACTIONS(5387),
    [anon_sym_controladdin] = ACTIONS(5387),
    [anon_sym_CONTROLADDIN] = ACTIONS(5387),
    [anon_sym_Controladdin] = ACTIONS(5387),
    [anon_sym_ControlAddIn] = ACTIONS(5387),
    [anon_sym_ControlAddin] = ACTIONS(5387),
    [anon_sym_controlAddIn] = ACTIONS(5387),
    [anon_sym_controlAddin] = ACTIONS(5387),
    [anon_sym_dotnet] = ACTIONS(5387),
    [anon_sym_DOTNET] = ACTIONS(5387),
    [anon_sym_Dotnet] = ACTIONS(5387),
    [anon_sym_DotNet] = ACTIONS(5387),
    [anon_sym_dotNet] = ACTIONS(5387),
    [sym_profile_keyword] = ACTIONS(5389),
    [anon_sym_profileextension] = ACTIONS(5387),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5387),
    [anon_sym_Profileextension] = ACTIONS(5387),
    [anon_sym_ProfileExtension] = ACTIONS(5387),
    [anon_sym_profileExtension] = ACTIONS(5387),
    [anon_sym_permissionset] = ACTIONS(5389),
    [anon_sym_PERMISSIONSET] = ACTIONS(5389),
    [anon_sym_Permissionset] = ACTIONS(5389),
    [anon_sym_PermissionSet] = ACTIONS(5389),
    [anon_sym_permissionSet] = ACTIONS(5389),
    [anon_sym_permissionsetextension] = ACTIONS(5387),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5387),
    [anon_sym_Permissionsetextension] = ACTIONS(5387),
    [anon_sym_PermissionSetExtension] = ACTIONS(5387),
    [anon_sym_permissionSetExtension] = ACTIONS(5387),
    [sym_entitlement_keyword] = ACTIONS(5387),
    [anon_sym_pagecustomization] = ACTIONS(5387),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5387),
    [anon_sym_Pagecustomization] = ACTIONS(5387),
    [anon_sym_PageCustomization] = ACTIONS(5387),
    [anon_sym_pageCustomization] = ACTIONS(5387),
    [sym_using_keyword] = ACTIONS(5387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5387),
    [sym_preproc_close] = ACTIONS(5387),
  },
  [STATE(2089)] = {
    [sym_identifier] = ACTIONS(2547),
    [anon_sym_SEMI] = ACTIONS(2549),
    [anon_sym_DOT] = ACTIONS(2547),
    [anon_sym_EQ] = ACTIONS(2549),
    [anon_sym_COMMA] = ACTIONS(2549),
    [anon_sym_COLON] = ACTIONS(2547),
    [anon_sym_DASH] = ACTIONS(2547),
    [aux_sym_boolean_token1] = ACTIONS(2547),
    [aux_sym_boolean_token2] = ACTIONS(2547),
    [sym_decimal] = ACTIONS(2547),
    [anon_sym_LPAREN] = ACTIONS(2549),
    [anon_sym_DOT_DOT] = ACTIONS(2549),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2547),
    [anon_sym_STAR] = ACTIONS(2547),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [aux_sym_record_type_token1] = ACTIONS(2547),
    [aux_sym_basic_type_token21] = ACTIONS(2547),
    [aux_sym_basic_type_token22] = ACTIONS(2547),
    [aux_sym_basic_type_token48] = ACTIONS(2547),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2547),
    [anon_sym_COLON_COLON] = ACTIONS(2549),
    [anon_sym_POUNDif] = ACTIONS(2549),
    [anon_sym_POUNDIF] = ACTIONS(2549),
    [anon_sym_POUNDIf] = ACTIONS(2549),
    [anon_sym_not] = ACTIONS(2547),
    [anon_sym_NOT] = ACTIONS(2547),
    [anon_sym_Not] = ACTIONS(2547),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2549),
    [aux_sym__expression_token1] = ACTIONS(2549),
    [aux_sym__expression_token2] = ACTIONS(2549),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2547),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2547),
    [anon_sym_SLASH] = ACTIONS(2547),
    [anon_sym_div] = ACTIONS(2547),
    [anon_sym_DIV] = ACTIONS(2547),
    [anon_sym_Div] = ACTIONS(2547),
    [anon_sym_mod] = ACTIONS(2547),
    [anon_sym_MOD] = ACTIONS(2547),
    [anon_sym_Mod] = ACTIONS(2547),
    [anon_sym_PLUS] = ACTIONS(2547),
    [anon_sym_GT_EQ] = ACTIONS(2549),
    [anon_sym_LT_EQ] = ACTIONS(2549),
    [anon_sym_GT] = ACTIONS(2547),
    [anon_sym_LT] = ACTIONS(2547),
    [anon_sym_LT_GT] = ACTIONS(2549),
    [anon_sym_and] = ACTIONS(2547),
    [anon_sym_AND] = ACTIONS(2547),
    [anon_sym_And] = ACTIONS(2547),
    [anon_sym_or] = ACTIONS(2547),
    [anon_sym_OR] = ACTIONS(2547),
    [anon_sym_Or] = ACTIONS(2547),
    [anon_sym_xor] = ACTIONS(2547),
    [anon_sym_XOR] = ACTIONS(2547),
    [anon_sym_Xor] = ACTIONS(2547),
    [anon_sym_QMARK] = ACTIONS(2549),
    [sym_datetime_literal] = ACTIONS(2549),
    [sym_date_literal] = ACTIONS(2547),
    [sym_time_literal] = ACTIONS(2547),
    [sym_biginteger_literal] = ACTIONS(2549),
    [anon_sym_else] = ACTIONS(2547),
    [anon_sym_ELSE] = ACTIONS(2547),
    [anon_sym_Else] = ACTIONS(2547),
    [anon_sym_in] = ACTIONS(2547),
    [anon_sym_IN] = ACTIONS(2547),
    [anon_sym_In] = ACTIONS(2547),
    [sym_page_keyword] = ACTIONS(2547),
    [anon_sym_codeunit] = ACTIONS(2547),
    [anon_sym_CODEUNIT] = ACTIONS(2547),
    [anon_sym_Codeunit] = ACTIONS(2547),
    [anon_sym_CodeUnit] = ACTIONS(2547),
    [anon_sym_COdeunit] = ACTIONS(2547),
    [anon_sym_codeUnit] = ACTIONS(2547),
    [sym_report_keyword] = ACTIONS(2547),
    [sym_query_keyword] = ACTIONS(2547),
    [anon_sym_xmlport] = ACTIONS(2547),
    [anon_sym_XMLPORT] = ACTIONS(2547),
    [anon_sym_Xmlport] = ACTIONS(2547),
    [anon_sym_XMLport] = ACTIONS(2547),
    [anon_sym_XMLPort] = ACTIONS(2547),
    [anon_sym_XmlPort] = ACTIONS(2547),
    [anon_sym_enum] = ACTIONS(2547),
    [anon_sym_ENUM] = ACTIONS(2547),
    [anon_sym_Enum] = ACTIONS(2547),
    [anon_sym_eNUM] = ACTIONS(2547),
    [anon_sym_eNum] = ACTIONS(2547),
    [anon_sym_ENum] = ACTIONS(2547),
    [sym_quoted_identifier] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2549),
    [sym_integer] = ACTIONS(2547),
    [sym_continue_as_identifier] = ACTIONS(2549),
    [sym_preproc_open] = ACTIONS(2549),
  },
  [STATE(2090)] = {
    [sym_identifier] = ACTIONS(2434),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_COMMA] = ACTIONS(2436),
    [anon_sym_DASH] = ACTIONS(2434),
    [aux_sym_boolean_token1] = ACTIONS(2434),
    [aux_sym_boolean_token2] = ACTIONS(2434),
    [sym_decimal] = ACTIONS(2434),
    [anon_sym_LPAREN] = ACTIONS(2436),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2434),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [aux_sym_record_type_token1] = ACTIONS(2434),
    [aux_sym_basic_type_token21] = ACTIONS(2434),
    [aux_sym_basic_type_token22] = ACTIONS(2434),
    [aux_sym_basic_type_token48] = ACTIONS(2434),
    [anon_sym_COLON_COLON] = ACTIONS(5259),
    [anon_sym_not] = ACTIONS(2434),
    [anon_sym_NOT] = ACTIONS(2434),
    [anon_sym_Not] = ACTIONS(2434),
    [anon_sym_POUNDelif] = ACTIONS(2436),
    [anon_sym_POUNDELIF] = ACTIONS(2436),
    [anon_sym_POUNDElif] = ACTIONS(2436),
    [anon_sym_POUNDelse] = ACTIONS(2436),
    [anon_sym_POUNDELSE] = ACTIONS(2436),
    [anon_sym_POUNDElse] = ACTIONS(2436),
    [anon_sym_POUNDendif] = ACTIONS(2436),
    [anon_sym_POUNDENDIF] = ACTIONS(2436),
    [anon_sym_POUNDEndif] = ACTIONS(2436),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2434),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(2434),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(2436),
    [sym_date_literal] = ACTIONS(2434),
    [sym_time_literal] = ACTIONS(2434),
    [sym_biginteger_literal] = ACTIONS(2436),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(2434),
    [anon_sym_codeunit] = ACTIONS(2434),
    [anon_sym_CODEUNIT] = ACTIONS(2434),
    [anon_sym_Codeunit] = ACTIONS(2434),
    [anon_sym_CodeUnit] = ACTIONS(2434),
    [anon_sym_COdeunit] = ACTIONS(2434),
    [anon_sym_codeUnit] = ACTIONS(2434),
    [sym_report_keyword] = ACTIONS(2434),
    [sym_query_keyword] = ACTIONS(2434),
    [anon_sym_xmlport] = ACTIONS(2434),
    [anon_sym_XMLPORT] = ACTIONS(2434),
    [anon_sym_Xmlport] = ACTIONS(2434),
    [anon_sym_XMLport] = ACTIONS(2434),
    [anon_sym_XMLPort] = ACTIONS(2434),
    [anon_sym_XmlPort] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2434),
    [anon_sym_ENUM] = ACTIONS(2434),
    [anon_sym_Enum] = ACTIONS(2434),
    [anon_sym_eNUM] = ACTIONS(2434),
    [anon_sym_eNum] = ACTIONS(2434),
    [anon_sym_ENum] = ACTIONS(2434),
    [sym_quoted_identifier] = ACTIONS(2436),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2436),
    [sym_integer] = ACTIONS(2434),
    [sym_continue_as_identifier] = ACTIONS(2436),
    [sym_preproc_close] = ACTIONS(2436),
  },
  [STATE(2091)] = {
    [sym_identifier] = ACTIONS(2555),
    [anon_sym_DOT] = ACTIONS(2555),
    [anon_sym_EQ] = ACTIONS(2557),
    [anon_sym_COMMA] = ACTIONS(2557),
    [anon_sym_DASH] = ACTIONS(2555),
    [aux_sym_boolean_token1] = ACTIONS(2555),
    [aux_sym_boolean_token2] = ACTIONS(2555),
    [sym_decimal] = ACTIONS(2555),
    [anon_sym_LPAREN] = ACTIONS(2557),
    [anon_sym_DOT_DOT] = ACTIONS(2557),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2555),
    [anon_sym_STAR] = ACTIONS(2555),
    [anon_sym_LBRACK] = ACTIONS(2557),
    [aux_sym_record_type_token1] = ACTIONS(2555),
    [aux_sym_basic_type_token21] = ACTIONS(2555),
    [aux_sym_basic_type_token22] = ACTIONS(2555),
    [aux_sym_basic_type_token48] = ACTIONS(2555),
    [anon_sym_COLON_COLON] = ACTIONS(2557),
    [anon_sym_not] = ACTIONS(2555),
    [anon_sym_NOT] = ACTIONS(2555),
    [anon_sym_Not] = ACTIONS(2555),
    [anon_sym_POUNDelif] = ACTIONS(2557),
    [anon_sym_POUNDELIF] = ACTIONS(2557),
    [anon_sym_POUNDElif] = ACTIONS(2557),
    [anon_sym_POUNDelse] = ACTIONS(2557),
    [anon_sym_POUNDELSE] = ACTIONS(2557),
    [anon_sym_POUNDElse] = ACTIONS(2557),
    [anon_sym_POUNDendif] = ACTIONS(2557),
    [anon_sym_POUNDENDIF] = ACTIONS(2557),
    [anon_sym_POUNDEndif] = ACTIONS(2557),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2557),
    [aux_sym__expression_token1] = ACTIONS(2557),
    [aux_sym__expression_token2] = ACTIONS(2557),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2555),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2555),
    [anon_sym_SLASH] = ACTIONS(2555),
    [anon_sym_div] = ACTIONS(2555),
    [anon_sym_DIV] = ACTIONS(2555),
    [anon_sym_Div] = ACTIONS(2555),
    [anon_sym_mod] = ACTIONS(2555),
    [anon_sym_MOD] = ACTIONS(2555),
    [anon_sym_Mod] = ACTIONS(2555),
    [anon_sym_PLUS] = ACTIONS(2555),
    [anon_sym_GT_EQ] = ACTIONS(2557),
    [anon_sym_LT_EQ] = ACTIONS(2557),
    [anon_sym_GT] = ACTIONS(2555),
    [anon_sym_LT] = ACTIONS(2555),
    [anon_sym_LT_GT] = ACTIONS(2557),
    [anon_sym_and] = ACTIONS(2555),
    [anon_sym_AND] = ACTIONS(2555),
    [anon_sym_And] = ACTIONS(2555),
    [anon_sym_or] = ACTIONS(2555),
    [anon_sym_OR] = ACTIONS(2555),
    [anon_sym_Or] = ACTIONS(2555),
    [anon_sym_xor] = ACTIONS(2555),
    [anon_sym_XOR] = ACTIONS(2555),
    [anon_sym_Xor] = ACTIONS(2555),
    [anon_sym_QMARK] = ACTIONS(2557),
    [sym_datetime_literal] = ACTIONS(2557),
    [sym_date_literal] = ACTIONS(2555),
    [sym_time_literal] = ACTIONS(2555),
    [sym_biginteger_literal] = ACTIONS(2557),
    [anon_sym_in] = ACTIONS(2555),
    [anon_sym_IN] = ACTIONS(2555),
    [anon_sym_In] = ACTIONS(2555),
    [sym_page_keyword] = ACTIONS(2555),
    [anon_sym_codeunit] = ACTIONS(2555),
    [anon_sym_CODEUNIT] = ACTIONS(2555),
    [anon_sym_Codeunit] = ACTIONS(2555),
    [anon_sym_CodeUnit] = ACTIONS(2555),
    [anon_sym_COdeunit] = ACTIONS(2555),
    [anon_sym_codeUnit] = ACTIONS(2555),
    [sym_report_keyword] = ACTIONS(2555),
    [sym_query_keyword] = ACTIONS(2555),
    [anon_sym_xmlport] = ACTIONS(2555),
    [anon_sym_XMLPORT] = ACTIONS(2555),
    [anon_sym_Xmlport] = ACTIONS(2555),
    [anon_sym_XMLport] = ACTIONS(2555),
    [anon_sym_XMLPort] = ACTIONS(2555),
    [anon_sym_XmlPort] = ACTIONS(2555),
    [anon_sym_enum] = ACTIONS(2555),
    [anon_sym_ENUM] = ACTIONS(2555),
    [anon_sym_Enum] = ACTIONS(2555),
    [anon_sym_eNUM] = ACTIONS(2555),
    [anon_sym_eNum] = ACTIONS(2555),
    [anon_sym_ENum] = ACTIONS(2555),
    [sym_quoted_identifier] = ACTIONS(2557),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2557),
    [sym_integer] = ACTIONS(2555),
    [sym_continue_as_identifier] = ACTIONS(2557),
    [sym_preproc_close] = ACTIONS(2557),
  },
  [STATE(2092)] = {
    [sym_identifier] = ACTIONS(2561),
    [anon_sym_DOT] = ACTIONS(2561),
    [anon_sym_EQ] = ACTIONS(2563),
    [anon_sym_COMMA] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2561),
    [aux_sym_boolean_token1] = ACTIONS(2561),
    [aux_sym_boolean_token2] = ACTIONS(2561),
    [sym_decimal] = ACTIONS(2561),
    [anon_sym_LPAREN] = ACTIONS(2563),
    [anon_sym_DOT_DOT] = ACTIONS(2563),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2561),
    [anon_sym_STAR] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2563),
    [aux_sym_record_type_token1] = ACTIONS(2561),
    [aux_sym_basic_type_token21] = ACTIONS(2561),
    [aux_sym_basic_type_token22] = ACTIONS(2561),
    [aux_sym_basic_type_token48] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_not] = ACTIONS(2561),
    [anon_sym_NOT] = ACTIONS(2561),
    [anon_sym_Not] = ACTIONS(2561),
    [anon_sym_POUNDelif] = ACTIONS(2563),
    [anon_sym_POUNDELIF] = ACTIONS(2563),
    [anon_sym_POUNDElif] = ACTIONS(2563),
    [anon_sym_POUNDelse] = ACTIONS(2563),
    [anon_sym_POUNDELSE] = ACTIONS(2563),
    [anon_sym_POUNDElse] = ACTIONS(2563),
    [anon_sym_POUNDendif] = ACTIONS(2563),
    [anon_sym_POUNDENDIF] = ACTIONS(2563),
    [anon_sym_POUNDEndif] = ACTIONS(2563),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2563),
    [aux_sym__expression_token1] = ACTIONS(2563),
    [aux_sym__expression_token2] = ACTIONS(2563),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2561),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2561),
    [anon_sym_SLASH] = ACTIONS(2561),
    [anon_sym_div] = ACTIONS(2561),
    [anon_sym_DIV] = ACTIONS(2561),
    [anon_sym_Div] = ACTIONS(2561),
    [anon_sym_mod] = ACTIONS(2561),
    [anon_sym_MOD] = ACTIONS(2561),
    [anon_sym_Mod] = ACTIONS(2561),
    [anon_sym_PLUS] = ACTIONS(2561),
    [anon_sym_GT_EQ] = ACTIONS(2563),
    [anon_sym_LT_EQ] = ACTIONS(2563),
    [anon_sym_GT] = ACTIONS(2561),
    [anon_sym_LT] = ACTIONS(2561),
    [anon_sym_LT_GT] = ACTIONS(2563),
    [anon_sym_and] = ACTIONS(2561),
    [anon_sym_AND] = ACTIONS(2561),
    [anon_sym_And] = ACTIONS(2561),
    [anon_sym_or] = ACTIONS(2561),
    [anon_sym_OR] = ACTIONS(2561),
    [anon_sym_Or] = ACTIONS(2561),
    [anon_sym_xor] = ACTIONS(2561),
    [anon_sym_XOR] = ACTIONS(2561),
    [anon_sym_Xor] = ACTIONS(2561),
    [anon_sym_QMARK] = ACTIONS(2563),
    [sym_datetime_literal] = ACTIONS(2563),
    [sym_date_literal] = ACTIONS(2561),
    [sym_time_literal] = ACTIONS(2561),
    [sym_biginteger_literal] = ACTIONS(2563),
    [anon_sym_in] = ACTIONS(2561),
    [anon_sym_IN] = ACTIONS(2561),
    [anon_sym_In] = ACTIONS(2561),
    [sym_page_keyword] = ACTIONS(2561),
    [anon_sym_codeunit] = ACTIONS(2561),
    [anon_sym_CODEUNIT] = ACTIONS(2561),
    [anon_sym_Codeunit] = ACTIONS(2561),
    [anon_sym_CodeUnit] = ACTIONS(2561),
    [anon_sym_COdeunit] = ACTIONS(2561),
    [anon_sym_codeUnit] = ACTIONS(2561),
    [sym_report_keyword] = ACTIONS(2561),
    [sym_query_keyword] = ACTIONS(2561),
    [anon_sym_xmlport] = ACTIONS(2561),
    [anon_sym_XMLPORT] = ACTIONS(2561),
    [anon_sym_Xmlport] = ACTIONS(2561),
    [anon_sym_XMLport] = ACTIONS(2561),
    [anon_sym_XMLPort] = ACTIONS(2561),
    [anon_sym_XmlPort] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_ENUM] = ACTIONS(2561),
    [anon_sym_Enum] = ACTIONS(2561),
    [anon_sym_eNUM] = ACTIONS(2561),
    [anon_sym_eNum] = ACTIONS(2561),
    [anon_sym_ENum] = ACTIONS(2561),
    [sym_quoted_identifier] = ACTIONS(2563),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2563),
    [sym_integer] = ACTIONS(2561),
    [sym_continue_as_identifier] = ACTIONS(2563),
    [sym_preproc_close] = ACTIONS(2563),
  },
  [STATE(2093)] = {
    [sym_identifier] = ACTIONS(2565),
    [anon_sym_DOT] = ACTIONS(2565),
    [anon_sym_EQ] = ACTIONS(2567),
    [anon_sym_COMMA] = ACTIONS(2567),
    [anon_sym_DASH] = ACTIONS(2565),
    [aux_sym_boolean_token1] = ACTIONS(2565),
    [aux_sym_boolean_token2] = ACTIONS(2565),
    [sym_decimal] = ACTIONS(2565),
    [anon_sym_LPAREN] = ACTIONS(2567),
    [anon_sym_DOT_DOT] = ACTIONS(2567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2565),
    [anon_sym_STAR] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2567),
    [aux_sym_record_type_token1] = ACTIONS(2565),
    [aux_sym_basic_type_token21] = ACTIONS(2565),
    [aux_sym_basic_type_token22] = ACTIONS(2565),
    [aux_sym_basic_type_token48] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_not] = ACTIONS(2565),
    [anon_sym_NOT] = ACTIONS(2565),
    [anon_sym_Not] = ACTIONS(2565),
    [anon_sym_POUNDelif] = ACTIONS(2567),
    [anon_sym_POUNDELIF] = ACTIONS(2567),
    [anon_sym_POUNDElif] = ACTIONS(2567),
    [anon_sym_POUNDelse] = ACTIONS(2567),
    [anon_sym_POUNDELSE] = ACTIONS(2567),
    [anon_sym_POUNDElse] = ACTIONS(2567),
    [anon_sym_POUNDendif] = ACTIONS(2567),
    [anon_sym_POUNDENDIF] = ACTIONS(2567),
    [anon_sym_POUNDEndif] = ACTIONS(2567),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2567),
    [aux_sym__expression_token1] = ACTIONS(2567),
    [aux_sym__expression_token2] = ACTIONS(2567),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2565),
    [anon_sym_SLASH] = ACTIONS(2565),
    [anon_sym_div] = ACTIONS(2565),
    [anon_sym_DIV] = ACTIONS(2565),
    [anon_sym_Div] = ACTIONS(2565),
    [anon_sym_mod] = ACTIONS(2565),
    [anon_sym_MOD] = ACTIONS(2565),
    [anon_sym_Mod] = ACTIONS(2565),
    [anon_sym_PLUS] = ACTIONS(2565),
    [anon_sym_GT_EQ] = ACTIONS(2567),
    [anon_sym_LT_EQ] = ACTIONS(2567),
    [anon_sym_GT] = ACTIONS(2565),
    [anon_sym_LT] = ACTIONS(2565),
    [anon_sym_LT_GT] = ACTIONS(2567),
    [anon_sym_and] = ACTIONS(2565),
    [anon_sym_AND] = ACTIONS(2565),
    [anon_sym_And] = ACTIONS(2565),
    [anon_sym_or] = ACTIONS(2565),
    [anon_sym_OR] = ACTIONS(2565),
    [anon_sym_Or] = ACTIONS(2565),
    [anon_sym_xor] = ACTIONS(2565),
    [anon_sym_XOR] = ACTIONS(2565),
    [anon_sym_Xor] = ACTIONS(2565),
    [anon_sym_QMARK] = ACTIONS(2567),
    [sym_datetime_literal] = ACTIONS(2567),
    [sym_date_literal] = ACTIONS(2565),
    [sym_time_literal] = ACTIONS(2565),
    [sym_biginteger_literal] = ACTIONS(2567),
    [anon_sym_in] = ACTIONS(2565),
    [anon_sym_IN] = ACTIONS(2565),
    [anon_sym_In] = ACTIONS(2565),
    [sym_page_keyword] = ACTIONS(2565),
    [anon_sym_codeunit] = ACTIONS(2565),
    [anon_sym_CODEUNIT] = ACTIONS(2565),
    [anon_sym_Codeunit] = ACTIONS(2565),
    [anon_sym_CodeUnit] = ACTIONS(2565),
    [anon_sym_COdeunit] = ACTIONS(2565),
    [anon_sym_codeUnit] = ACTIONS(2565),
    [sym_report_keyword] = ACTIONS(2565),
    [sym_query_keyword] = ACTIONS(2565),
    [anon_sym_xmlport] = ACTIONS(2565),
    [anon_sym_XMLPORT] = ACTIONS(2565),
    [anon_sym_Xmlport] = ACTIONS(2565),
    [anon_sym_XMLport] = ACTIONS(2565),
    [anon_sym_XMLPort] = ACTIONS(2565),
    [anon_sym_XmlPort] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_ENUM] = ACTIONS(2565),
    [anon_sym_Enum] = ACTIONS(2565),
    [anon_sym_eNUM] = ACTIONS(2565),
    [anon_sym_eNum] = ACTIONS(2565),
    [anon_sym_ENum] = ACTIONS(2565),
    [sym_quoted_identifier] = ACTIONS(2567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2567),
    [sym_integer] = ACTIONS(2565),
    [sym_continue_as_identifier] = ACTIONS(2567),
    [sym_preproc_close] = ACTIONS(2567),
  },
  [STATE(2094)] = {
    [sym_boolean] = STATE(5930),
    [sym_option_member_list] = STATE(6079),
    [sym_option_member] = STATE(5872),
    [sym_keyword_identifier] = STATE(5930),
    [sym_codeunit_keyword] = STATE(5973),
    [sym_xmlport_keyword] = STATE(5973),
    [sym_enum_keyword] = STATE(5973),
    [sym_keyword_as_identifier] = STATE(5930),
    [aux_sym_option_member_list_repeat2] = STATE(2150),
    [sym_identifier] = ACTIONS(5391),
    [anon_sym_SEMI] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(5393),
    [anon_sym_DASH] = ACTIONS(5395),
    [aux_sym_boolean_token1] = ACTIONS(5397),
    [aux_sym_boolean_token2] = ACTIONS(5397),
    [aux_sym_where_condition_token1] = ACTIONS(5399),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5401),
    [anon_sym_LBRACK] = ACTIONS(275),
    [aux_sym_record_type_token1] = ACTIONS(5401),
    [aux_sym_basic_type_token21] = ACTIONS(5401),
    [aux_sym_basic_type_token22] = ACTIONS(5403),
    [aux_sym_basic_type_token48] = ACTIONS(5401),
    [aux_sym_basic_type_token53] = ACTIONS(5399),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5399),
    [aux_sym_modify_modification_token1] = ACTIONS(277),
    [aux_sym_separator_action_token1] = ACTIONS(5399),
    [aux_sym_assembly_declaration_token1] = ACTIONS(277),
    [aux_sym_type_declaration_token1] = ACTIONS(5399),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(277),
    [anon_sym_POUNDif] = ACTIONS(275),
    [anon_sym_POUNDIF] = ACTIONS(275),
    [anon_sym_POUNDIf] = ACTIONS(275),
    [anon_sym_POUNDelif] = ACTIONS(275),
    [anon_sym_POUNDELIF] = ACTIONS(275),
    [anon_sym_POUNDElif] = ACTIONS(275),
    [anon_sym_POUNDelse] = ACTIONS(275),
    [anon_sym_POUNDELSE] = ACTIONS(275),
    [anon_sym_POUNDElse] = ACTIONS(275),
    [anon_sym_POUNDendif] = ACTIONS(275),
    [anon_sym_POUNDENDIF] = ACTIONS(275),
    [anon_sym_POUNDEndif] = ACTIONS(275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5401),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5401),
    [sym_page_keyword] = ACTIONS(5401),
    [anon_sym_codeunit] = ACTIONS(5405),
    [anon_sym_CODEUNIT] = ACTIONS(5405),
    [anon_sym_Codeunit] = ACTIONS(5405),
    [anon_sym_CodeUnit] = ACTIONS(5405),
    [anon_sym_COdeunit] = ACTIONS(5405),
    [anon_sym_codeUnit] = ACTIONS(5405),
    [sym_report_keyword] = ACTIONS(5401),
    [sym_query_keyword] = ACTIONS(5401),
    [anon_sym_xmlport] = ACTIONS(5407),
    [anon_sym_XMLPORT] = ACTIONS(5407),
    [anon_sym_Xmlport] = ACTIONS(5407),
    [anon_sym_XMLport] = ACTIONS(5407),
    [anon_sym_XMLPort] = ACTIONS(5407),
    [anon_sym_XmlPort] = ACTIONS(5407),
    [anon_sym_enum] = ACTIONS(5409),
    [anon_sym_ENUM] = ACTIONS(5409),
    [anon_sym_Enum] = ACTIONS(5409),
    [anon_sym_eNUM] = ACTIONS(5409),
    [anon_sym_eNum] = ACTIONS(5409),
    [anon_sym_ENum] = ACTIONS(5409),
    [sym_procedure_keyword] = ACTIONS(277),
    [sym_trigger_keyword] = ACTIONS(277),
    [sym_var_keyword] = ACTIONS(277),
    [sym_local_keyword] = ACTIONS(5391),
    [sym_internal_keyword] = ACTIONS(5391),
    [sym_protected_keyword] = ACTIONS(5391),
    [sym_event_keyword] = ACTIONS(277),
    [sym_fields_keyword] = ACTIONS(277),
    [sym_keys_keyword] = ACTIONS(277),
    [sym_key_keyword] = ACTIONS(5399),
    [sym_fieldgroups_keyword] = ACTIONS(277),
    [sym_actions_keyword] = ACTIONS(277),
    [sym_layout_keyword] = ACTIONS(277),
    [sym_dataset_keyword] = ACTIONS(5399),
    [sym_elements_keyword] = ACTIONS(277),
    [sym_labels_keyword] = ACTIONS(277),
    [sym_rendering_keyword] = ACTIONS(277),
    [sym_requestpage_keyword] = ACTIONS(277),
    [sym_schema_keyword] = ACTIONS(277),
    [sym_views_keyword] = ACTIONS(277),
    [sym_quoted_identifier] = ACTIONS(5411),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5411),
    [sym_integer] = ACTIONS(5411),
    [sym_property_name] = ACTIONS(275),
    [sym_preproc_open] = ACTIONS(275),
    [sym_preproc_close] = ACTIONS(275),
    [sym_begin_keyword] = ACTIONS(275),
  },
  [STATE(2095)] = {
    [sym_identifier] = ACTIONS(2414),
    [anon_sym_SEMI] = ACTIONS(2416),
    [anon_sym_DOT] = ACTIONS(2414),
    [anon_sym_EQ] = ACTIONS(2416),
    [anon_sym_COMMA] = ACTIONS(2416),
    [anon_sym_COLON] = ACTIONS(2414),
    [anon_sym_DASH] = ACTIONS(2414),
    [aux_sym_boolean_token1] = ACTIONS(2414),
    [aux_sym_boolean_token2] = ACTIONS(2414),
    [sym_decimal] = ACTIONS(2414),
    [anon_sym_LPAREN] = ACTIONS(2416),
    [anon_sym_DOT_DOT] = ACTIONS(2416),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2414),
    [anon_sym_STAR] = ACTIONS(2414),
    [anon_sym_LBRACK] = ACTIONS(2416),
    [aux_sym_record_type_token1] = ACTIONS(2414),
    [aux_sym_basic_type_token21] = ACTIONS(2414),
    [aux_sym_basic_type_token22] = ACTIONS(2414),
    [aux_sym_basic_type_token48] = ACTIONS(2414),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2414),
    [anon_sym_COLON_COLON] = ACTIONS(2416),
    [anon_sym_POUNDif] = ACTIONS(2416),
    [anon_sym_POUNDIF] = ACTIONS(2416),
    [anon_sym_POUNDIf] = ACTIONS(2416),
    [anon_sym_not] = ACTIONS(2414),
    [anon_sym_NOT] = ACTIONS(2414),
    [anon_sym_Not] = ACTIONS(2414),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2416),
    [aux_sym__expression_token1] = ACTIONS(2416),
    [aux_sym__expression_token2] = ACTIONS(2416),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2414),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2414),
    [anon_sym_SLASH] = ACTIONS(2414),
    [anon_sym_div] = ACTIONS(2414),
    [anon_sym_DIV] = ACTIONS(2414),
    [anon_sym_Div] = ACTIONS(2414),
    [anon_sym_mod] = ACTIONS(2414),
    [anon_sym_MOD] = ACTIONS(2414),
    [anon_sym_Mod] = ACTIONS(2414),
    [anon_sym_PLUS] = ACTIONS(2414),
    [anon_sym_GT_EQ] = ACTIONS(2416),
    [anon_sym_LT_EQ] = ACTIONS(2416),
    [anon_sym_GT] = ACTIONS(2414),
    [anon_sym_LT] = ACTIONS(2414),
    [anon_sym_LT_GT] = ACTIONS(2416),
    [anon_sym_and] = ACTIONS(2414),
    [anon_sym_AND] = ACTIONS(2414),
    [anon_sym_And] = ACTIONS(2414),
    [anon_sym_or] = ACTIONS(2414),
    [anon_sym_OR] = ACTIONS(2414),
    [anon_sym_Or] = ACTIONS(2414),
    [anon_sym_xor] = ACTIONS(2414),
    [anon_sym_XOR] = ACTIONS(2414),
    [anon_sym_Xor] = ACTIONS(2414),
    [anon_sym_QMARK] = ACTIONS(2416),
    [sym_datetime_literal] = ACTIONS(2416),
    [sym_date_literal] = ACTIONS(2414),
    [sym_time_literal] = ACTIONS(2414),
    [sym_biginteger_literal] = ACTIONS(2416),
    [anon_sym_else] = ACTIONS(2414),
    [anon_sym_ELSE] = ACTIONS(2414),
    [anon_sym_Else] = ACTIONS(2414),
    [anon_sym_in] = ACTIONS(2414),
    [anon_sym_IN] = ACTIONS(2414),
    [anon_sym_In] = ACTIONS(2414),
    [sym_page_keyword] = ACTIONS(2414),
    [anon_sym_codeunit] = ACTIONS(2414),
    [anon_sym_CODEUNIT] = ACTIONS(2414),
    [anon_sym_Codeunit] = ACTIONS(2414),
    [anon_sym_CodeUnit] = ACTIONS(2414),
    [anon_sym_COdeunit] = ACTIONS(2414),
    [anon_sym_codeUnit] = ACTIONS(2414),
    [sym_report_keyword] = ACTIONS(2414),
    [sym_query_keyword] = ACTIONS(2414),
    [anon_sym_xmlport] = ACTIONS(2414),
    [anon_sym_XMLPORT] = ACTIONS(2414),
    [anon_sym_Xmlport] = ACTIONS(2414),
    [anon_sym_XMLport] = ACTIONS(2414),
    [anon_sym_XMLPort] = ACTIONS(2414),
    [anon_sym_XmlPort] = ACTIONS(2414),
    [anon_sym_enum] = ACTIONS(2414),
    [anon_sym_ENUM] = ACTIONS(2414),
    [anon_sym_Enum] = ACTIONS(2414),
    [anon_sym_eNUM] = ACTIONS(2414),
    [anon_sym_eNum] = ACTIONS(2414),
    [anon_sym_ENum] = ACTIONS(2414),
    [sym_quoted_identifier] = ACTIONS(2416),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2416),
    [sym_integer] = ACTIONS(2414),
    [sym_continue_as_identifier] = ACTIONS(2416),
    [sym_preproc_open] = ACTIONS(2416),
  },
  [STATE(2096)] = {
    [sym_identifier] = ACTIONS(2418),
    [anon_sym_SEMI] = ACTIONS(2420),
    [anon_sym_DOT] = ACTIONS(2418),
    [anon_sym_EQ] = ACTIONS(2420),
    [anon_sym_COMMA] = ACTIONS(2420),
    [anon_sym_COLON] = ACTIONS(2418),
    [anon_sym_DASH] = ACTIONS(2418),
    [aux_sym_boolean_token1] = ACTIONS(2418),
    [aux_sym_boolean_token2] = ACTIONS(2418),
    [sym_decimal] = ACTIONS(2418),
    [anon_sym_LPAREN] = ACTIONS(2420),
    [anon_sym_DOT_DOT] = ACTIONS(2420),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2418),
    [anon_sym_STAR] = ACTIONS(2418),
    [anon_sym_LBRACK] = ACTIONS(2420),
    [aux_sym_record_type_token1] = ACTIONS(2418),
    [aux_sym_basic_type_token21] = ACTIONS(2418),
    [aux_sym_basic_type_token22] = ACTIONS(2418),
    [aux_sym_basic_type_token48] = ACTIONS(2418),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2418),
    [anon_sym_COLON_COLON] = ACTIONS(2420),
    [anon_sym_POUNDif] = ACTIONS(2420),
    [anon_sym_POUNDIF] = ACTIONS(2420),
    [anon_sym_POUNDIf] = ACTIONS(2420),
    [anon_sym_not] = ACTIONS(2418),
    [anon_sym_NOT] = ACTIONS(2418),
    [anon_sym_Not] = ACTIONS(2418),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2420),
    [aux_sym__expression_token1] = ACTIONS(2420),
    [aux_sym__expression_token2] = ACTIONS(2420),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2418),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2418),
    [anon_sym_SLASH] = ACTIONS(2418),
    [anon_sym_div] = ACTIONS(2418),
    [anon_sym_DIV] = ACTIONS(2418),
    [anon_sym_Div] = ACTIONS(2418),
    [anon_sym_mod] = ACTIONS(2418),
    [anon_sym_MOD] = ACTIONS(2418),
    [anon_sym_Mod] = ACTIONS(2418),
    [anon_sym_PLUS] = ACTIONS(2418),
    [anon_sym_GT_EQ] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(2420),
    [anon_sym_GT] = ACTIONS(2418),
    [anon_sym_LT] = ACTIONS(2418),
    [anon_sym_LT_GT] = ACTIONS(2420),
    [anon_sym_and] = ACTIONS(2418),
    [anon_sym_AND] = ACTIONS(2418),
    [anon_sym_And] = ACTIONS(2418),
    [anon_sym_or] = ACTIONS(2418),
    [anon_sym_OR] = ACTIONS(2418),
    [anon_sym_Or] = ACTIONS(2418),
    [anon_sym_xor] = ACTIONS(2418),
    [anon_sym_XOR] = ACTIONS(2418),
    [anon_sym_Xor] = ACTIONS(2418),
    [anon_sym_QMARK] = ACTIONS(2420),
    [sym_datetime_literal] = ACTIONS(2420),
    [sym_date_literal] = ACTIONS(2418),
    [sym_time_literal] = ACTIONS(2418),
    [sym_biginteger_literal] = ACTIONS(2420),
    [anon_sym_else] = ACTIONS(2418),
    [anon_sym_ELSE] = ACTIONS(2418),
    [anon_sym_Else] = ACTIONS(2418),
    [anon_sym_in] = ACTIONS(2418),
    [anon_sym_IN] = ACTIONS(2418),
    [anon_sym_In] = ACTIONS(2418),
    [sym_page_keyword] = ACTIONS(2418),
    [anon_sym_codeunit] = ACTIONS(2418),
    [anon_sym_CODEUNIT] = ACTIONS(2418),
    [anon_sym_Codeunit] = ACTIONS(2418),
    [anon_sym_CodeUnit] = ACTIONS(2418),
    [anon_sym_COdeunit] = ACTIONS(2418),
    [anon_sym_codeUnit] = ACTIONS(2418),
    [sym_report_keyword] = ACTIONS(2418),
    [sym_query_keyword] = ACTIONS(2418),
    [anon_sym_xmlport] = ACTIONS(2418),
    [anon_sym_XMLPORT] = ACTIONS(2418),
    [anon_sym_Xmlport] = ACTIONS(2418),
    [anon_sym_XMLport] = ACTIONS(2418),
    [anon_sym_XMLPort] = ACTIONS(2418),
    [anon_sym_XmlPort] = ACTIONS(2418),
    [anon_sym_enum] = ACTIONS(2418),
    [anon_sym_ENUM] = ACTIONS(2418),
    [anon_sym_Enum] = ACTIONS(2418),
    [anon_sym_eNUM] = ACTIONS(2418),
    [anon_sym_eNum] = ACTIONS(2418),
    [anon_sym_ENum] = ACTIONS(2418),
    [sym_quoted_identifier] = ACTIONS(2420),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2420),
    [sym_integer] = ACTIONS(2418),
    [sym_continue_as_identifier] = ACTIONS(2420),
    [sym_preproc_open] = ACTIONS(2420),
  },
  [STATE(2097)] = {
    [sym_identifier] = ACTIONS(2422),
    [anon_sym_SEMI] = ACTIONS(2424),
    [anon_sym_DOT] = ACTIONS(2422),
    [anon_sym_EQ] = ACTIONS(2424),
    [anon_sym_COMMA] = ACTIONS(2424),
    [anon_sym_COLON] = ACTIONS(2422),
    [anon_sym_DASH] = ACTIONS(2422),
    [aux_sym_boolean_token1] = ACTIONS(2422),
    [aux_sym_boolean_token2] = ACTIONS(2422),
    [sym_decimal] = ACTIONS(2422),
    [anon_sym_LPAREN] = ACTIONS(2424),
    [anon_sym_DOT_DOT] = ACTIONS(2424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2422),
    [anon_sym_STAR] = ACTIONS(2422),
    [anon_sym_LBRACK] = ACTIONS(2424),
    [aux_sym_record_type_token1] = ACTIONS(2422),
    [aux_sym_basic_type_token21] = ACTIONS(2422),
    [aux_sym_basic_type_token22] = ACTIONS(2422),
    [aux_sym_basic_type_token48] = ACTIONS(2422),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2422),
    [anon_sym_COLON_COLON] = ACTIONS(2424),
    [anon_sym_POUNDif] = ACTIONS(2424),
    [anon_sym_POUNDIF] = ACTIONS(2424),
    [anon_sym_POUNDIf] = ACTIONS(2424),
    [anon_sym_not] = ACTIONS(2422),
    [anon_sym_NOT] = ACTIONS(2422),
    [anon_sym_Not] = ACTIONS(2422),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2424),
    [aux_sym__expression_token1] = ACTIONS(2424),
    [aux_sym__expression_token2] = ACTIONS(2424),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2422),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2422),
    [anon_sym_SLASH] = ACTIONS(2422),
    [anon_sym_div] = ACTIONS(2422),
    [anon_sym_DIV] = ACTIONS(2422),
    [anon_sym_Div] = ACTIONS(2422),
    [anon_sym_mod] = ACTIONS(2422),
    [anon_sym_MOD] = ACTIONS(2422),
    [anon_sym_Mod] = ACTIONS(2422),
    [anon_sym_PLUS] = ACTIONS(2422),
    [anon_sym_GT_EQ] = ACTIONS(2424),
    [anon_sym_LT_EQ] = ACTIONS(2424),
    [anon_sym_GT] = ACTIONS(2422),
    [anon_sym_LT] = ACTIONS(2422),
    [anon_sym_LT_GT] = ACTIONS(2424),
    [anon_sym_and] = ACTIONS(2422),
    [anon_sym_AND] = ACTIONS(2422),
    [anon_sym_And] = ACTIONS(2422),
    [anon_sym_or] = ACTIONS(2422),
    [anon_sym_OR] = ACTIONS(2422),
    [anon_sym_Or] = ACTIONS(2422),
    [anon_sym_xor] = ACTIONS(2422),
    [anon_sym_XOR] = ACTIONS(2422),
    [anon_sym_Xor] = ACTIONS(2422),
    [anon_sym_QMARK] = ACTIONS(2424),
    [sym_datetime_literal] = ACTIONS(2424),
    [sym_date_literal] = ACTIONS(2422),
    [sym_time_literal] = ACTIONS(2422),
    [sym_biginteger_literal] = ACTIONS(2424),
    [anon_sym_else] = ACTIONS(2422),
    [anon_sym_ELSE] = ACTIONS(2422),
    [anon_sym_Else] = ACTIONS(2422),
    [anon_sym_in] = ACTIONS(2422),
    [anon_sym_IN] = ACTIONS(2422),
    [anon_sym_In] = ACTIONS(2422),
    [sym_page_keyword] = ACTIONS(2422),
    [anon_sym_codeunit] = ACTIONS(2422),
    [anon_sym_CODEUNIT] = ACTIONS(2422),
    [anon_sym_Codeunit] = ACTIONS(2422),
    [anon_sym_CodeUnit] = ACTIONS(2422),
    [anon_sym_COdeunit] = ACTIONS(2422),
    [anon_sym_codeUnit] = ACTIONS(2422),
    [sym_report_keyword] = ACTIONS(2422),
    [sym_query_keyword] = ACTIONS(2422),
    [anon_sym_xmlport] = ACTIONS(2422),
    [anon_sym_XMLPORT] = ACTIONS(2422),
    [anon_sym_Xmlport] = ACTIONS(2422),
    [anon_sym_XMLport] = ACTIONS(2422),
    [anon_sym_XMLPort] = ACTIONS(2422),
    [anon_sym_XmlPort] = ACTIONS(2422),
    [anon_sym_enum] = ACTIONS(2422),
    [anon_sym_ENUM] = ACTIONS(2422),
    [anon_sym_Enum] = ACTIONS(2422),
    [anon_sym_eNUM] = ACTIONS(2422),
    [anon_sym_eNum] = ACTIONS(2422),
    [anon_sym_ENum] = ACTIONS(2422),
    [sym_quoted_identifier] = ACTIONS(2424),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2424),
    [sym_integer] = ACTIONS(2422),
    [sym_continue_as_identifier] = ACTIONS(2424),
    [sym_preproc_open] = ACTIONS(2424),
  },
  [STATE(2098)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_SEMI] = ACTIONS(2428),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_COMMA] = ACTIONS(2428),
    [anon_sym_COLON] = ACTIONS(2426),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2426),
    [anon_sym_COLON_COLON] = ACTIONS(2428),
    [anon_sym_POUNDif] = ACTIONS(2428),
    [anon_sym_POUNDIF] = ACTIONS(2428),
    [anon_sym_POUNDIf] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2428),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_else] = ACTIONS(2426),
    [anon_sym_ELSE] = ACTIONS(2426),
    [anon_sym_Else] = ACTIONS(2426),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_open] = ACTIONS(2428),
  },
  [STATE(2099)] = {
    [sym_identifier] = ACTIONS(2525),
    [anon_sym_DOT] = ACTIONS(2525),
    [anon_sym_EQ] = ACTIONS(2527),
    [anon_sym_COMMA] = ACTIONS(2527),
    [anon_sym_DASH] = ACTIONS(2525),
    [aux_sym_boolean_token1] = ACTIONS(2525),
    [aux_sym_boolean_token2] = ACTIONS(2525),
    [sym_decimal] = ACTIONS(2525),
    [anon_sym_LPAREN] = ACTIONS(2527),
    [anon_sym_DOT_DOT] = ACTIONS(2527),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2525),
    [anon_sym_STAR] = ACTIONS(2525),
    [anon_sym_LBRACK] = ACTIONS(2527),
    [aux_sym_record_type_token1] = ACTIONS(2525),
    [aux_sym_basic_type_token21] = ACTIONS(2525),
    [aux_sym_basic_type_token22] = ACTIONS(2525),
    [aux_sym_basic_type_token48] = ACTIONS(2525),
    [anon_sym_COLON_COLON] = ACTIONS(2527),
    [anon_sym_not] = ACTIONS(2525),
    [anon_sym_NOT] = ACTIONS(2525),
    [anon_sym_Not] = ACTIONS(2525),
    [anon_sym_POUNDelif] = ACTIONS(2527),
    [anon_sym_POUNDELIF] = ACTIONS(2527),
    [anon_sym_POUNDElif] = ACTIONS(2527),
    [anon_sym_POUNDelse] = ACTIONS(2527),
    [anon_sym_POUNDELSE] = ACTIONS(2527),
    [anon_sym_POUNDElse] = ACTIONS(2527),
    [anon_sym_POUNDendif] = ACTIONS(2527),
    [anon_sym_POUNDENDIF] = ACTIONS(2527),
    [anon_sym_POUNDEndif] = ACTIONS(2527),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2527),
    [aux_sym__expression_token1] = ACTIONS(2527),
    [aux_sym__expression_token2] = ACTIONS(2527),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2525),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2525),
    [anon_sym_SLASH] = ACTIONS(2525),
    [anon_sym_div] = ACTIONS(2525),
    [anon_sym_DIV] = ACTIONS(2525),
    [anon_sym_Div] = ACTIONS(2525),
    [anon_sym_mod] = ACTIONS(2525),
    [anon_sym_MOD] = ACTIONS(2525),
    [anon_sym_Mod] = ACTIONS(2525),
    [anon_sym_PLUS] = ACTIONS(2525),
    [anon_sym_GT_EQ] = ACTIONS(2527),
    [anon_sym_LT_EQ] = ACTIONS(2527),
    [anon_sym_GT] = ACTIONS(2525),
    [anon_sym_LT] = ACTIONS(2525),
    [anon_sym_LT_GT] = ACTIONS(2527),
    [anon_sym_and] = ACTIONS(2525),
    [anon_sym_AND] = ACTIONS(2525),
    [anon_sym_And] = ACTIONS(2525),
    [anon_sym_or] = ACTIONS(2525),
    [anon_sym_OR] = ACTIONS(2525),
    [anon_sym_Or] = ACTIONS(2525),
    [anon_sym_xor] = ACTIONS(2525),
    [anon_sym_XOR] = ACTIONS(2525),
    [anon_sym_Xor] = ACTIONS(2525),
    [anon_sym_QMARK] = ACTIONS(2527),
    [sym_datetime_literal] = ACTIONS(2527),
    [sym_date_literal] = ACTIONS(2525),
    [sym_time_literal] = ACTIONS(2525),
    [sym_biginteger_literal] = ACTIONS(2527),
    [anon_sym_in] = ACTIONS(2525),
    [anon_sym_IN] = ACTIONS(2525),
    [anon_sym_In] = ACTIONS(2525),
    [sym_page_keyword] = ACTIONS(2525),
    [anon_sym_codeunit] = ACTIONS(2525),
    [anon_sym_CODEUNIT] = ACTIONS(2525),
    [anon_sym_Codeunit] = ACTIONS(2525),
    [anon_sym_CodeUnit] = ACTIONS(2525),
    [anon_sym_COdeunit] = ACTIONS(2525),
    [anon_sym_codeUnit] = ACTIONS(2525),
    [sym_report_keyword] = ACTIONS(2525),
    [sym_query_keyword] = ACTIONS(2525),
    [anon_sym_xmlport] = ACTIONS(2525),
    [anon_sym_XMLPORT] = ACTIONS(2525),
    [anon_sym_Xmlport] = ACTIONS(2525),
    [anon_sym_XMLport] = ACTIONS(2525),
    [anon_sym_XMLPort] = ACTIONS(2525),
    [anon_sym_XmlPort] = ACTIONS(2525),
    [anon_sym_enum] = ACTIONS(2525),
    [anon_sym_ENUM] = ACTIONS(2525),
    [anon_sym_Enum] = ACTIONS(2525),
    [anon_sym_eNUM] = ACTIONS(2525),
    [anon_sym_eNum] = ACTIONS(2525),
    [anon_sym_ENum] = ACTIONS(2525),
    [sym_quoted_identifier] = ACTIONS(2527),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2527),
    [sym_integer] = ACTIONS(2525),
    [sym_continue_as_identifier] = ACTIONS(2527),
    [sym_preproc_close] = ACTIONS(2527),
  },
  [STATE(2100)] = {
    [sym_identifier] = ACTIONS(2517),
    [anon_sym_DOT] = ACTIONS(2517),
    [anon_sym_EQ] = ACTIONS(2519),
    [anon_sym_COMMA] = ACTIONS(2519),
    [anon_sym_DASH] = ACTIONS(2517),
    [aux_sym_boolean_token1] = ACTIONS(2517),
    [aux_sym_boolean_token2] = ACTIONS(2517),
    [sym_decimal] = ACTIONS(2517),
    [anon_sym_LPAREN] = ACTIONS(2519),
    [anon_sym_DOT_DOT] = ACTIONS(2519),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2517),
    [anon_sym_STAR] = ACTIONS(2517),
    [anon_sym_LBRACK] = ACTIONS(2519),
    [aux_sym_record_type_token1] = ACTIONS(2517),
    [aux_sym_basic_type_token21] = ACTIONS(2517),
    [aux_sym_basic_type_token22] = ACTIONS(2517),
    [aux_sym_basic_type_token48] = ACTIONS(2517),
    [anon_sym_COLON_COLON] = ACTIONS(2519),
    [anon_sym_not] = ACTIONS(2517),
    [anon_sym_NOT] = ACTIONS(2517),
    [anon_sym_Not] = ACTIONS(2517),
    [anon_sym_POUNDelif] = ACTIONS(2519),
    [anon_sym_POUNDELIF] = ACTIONS(2519),
    [anon_sym_POUNDElif] = ACTIONS(2519),
    [anon_sym_POUNDelse] = ACTIONS(2519),
    [anon_sym_POUNDELSE] = ACTIONS(2519),
    [anon_sym_POUNDElse] = ACTIONS(2519),
    [anon_sym_POUNDendif] = ACTIONS(2519),
    [anon_sym_POUNDENDIF] = ACTIONS(2519),
    [anon_sym_POUNDEndif] = ACTIONS(2519),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2519),
    [aux_sym__expression_token1] = ACTIONS(2519),
    [aux_sym__expression_token2] = ACTIONS(2519),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2517),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2517),
    [anon_sym_SLASH] = ACTIONS(2517),
    [anon_sym_div] = ACTIONS(2517),
    [anon_sym_DIV] = ACTIONS(2517),
    [anon_sym_Div] = ACTIONS(2517),
    [anon_sym_mod] = ACTIONS(2517),
    [anon_sym_MOD] = ACTIONS(2517),
    [anon_sym_Mod] = ACTIONS(2517),
    [anon_sym_PLUS] = ACTIONS(2517),
    [anon_sym_GT_EQ] = ACTIONS(2519),
    [anon_sym_LT_EQ] = ACTIONS(2519),
    [anon_sym_GT] = ACTIONS(2517),
    [anon_sym_LT] = ACTIONS(2517),
    [anon_sym_LT_GT] = ACTIONS(2519),
    [anon_sym_and] = ACTIONS(2517),
    [anon_sym_AND] = ACTIONS(2517),
    [anon_sym_And] = ACTIONS(2517),
    [anon_sym_or] = ACTIONS(2517),
    [anon_sym_OR] = ACTIONS(2517),
    [anon_sym_Or] = ACTIONS(2517),
    [anon_sym_xor] = ACTIONS(2517),
    [anon_sym_XOR] = ACTIONS(2517),
    [anon_sym_Xor] = ACTIONS(2517),
    [anon_sym_QMARK] = ACTIONS(2519),
    [sym_datetime_literal] = ACTIONS(2519),
    [sym_date_literal] = ACTIONS(2517),
    [sym_time_literal] = ACTIONS(2517),
    [sym_biginteger_literal] = ACTIONS(2519),
    [anon_sym_in] = ACTIONS(2517),
    [anon_sym_IN] = ACTIONS(2517),
    [anon_sym_In] = ACTIONS(2517),
    [sym_page_keyword] = ACTIONS(2517),
    [anon_sym_codeunit] = ACTIONS(2517),
    [anon_sym_CODEUNIT] = ACTIONS(2517),
    [anon_sym_Codeunit] = ACTIONS(2517),
    [anon_sym_CodeUnit] = ACTIONS(2517),
    [anon_sym_COdeunit] = ACTIONS(2517),
    [anon_sym_codeUnit] = ACTIONS(2517),
    [sym_report_keyword] = ACTIONS(2517),
    [sym_query_keyword] = ACTIONS(2517),
    [anon_sym_xmlport] = ACTIONS(2517),
    [anon_sym_XMLPORT] = ACTIONS(2517),
    [anon_sym_Xmlport] = ACTIONS(2517),
    [anon_sym_XMLport] = ACTIONS(2517),
    [anon_sym_XMLPort] = ACTIONS(2517),
    [anon_sym_XmlPort] = ACTIONS(2517),
    [anon_sym_enum] = ACTIONS(2517),
    [anon_sym_ENUM] = ACTIONS(2517),
    [anon_sym_Enum] = ACTIONS(2517),
    [anon_sym_eNUM] = ACTIONS(2517),
    [anon_sym_eNum] = ACTIONS(2517),
    [anon_sym_ENum] = ACTIONS(2517),
    [sym_quoted_identifier] = ACTIONS(2519),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2519),
    [sym_integer] = ACTIONS(2517),
    [sym_continue_as_identifier] = ACTIONS(2519),
    [sym_preproc_close] = ACTIONS(2519),
  },
  [STATE(2101)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2111),
    [sym_identifier] = ACTIONS(376),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(5413),
    [anon_sym_COLON] = ACTIONS(376),
    [anon_sym_DASH] = ACTIONS(376),
    [aux_sym_boolean_token1] = ACTIONS(376),
    [aux_sym_boolean_token2] = ACTIONS(376),
    [sym_decimal] = ACTIONS(376),
    [anon_sym_LPAREN] = ACTIONS(374),
    [anon_sym_DOT_DOT] = ACTIONS(374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(376),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(376),
    [aux_sym_basic_type_token21] = ACTIONS(376),
    [aux_sym_basic_type_token22] = ACTIONS(376),
    [aux_sym_basic_type_token48] = ACTIONS(376),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(376),
    [anon_sym_POUNDif] = ACTIONS(374),
    [anon_sym_POUNDIF] = ACTIONS(374),
    [anon_sym_POUNDIf] = ACTIONS(374),
    [anon_sym_not] = ACTIONS(376),
    [anon_sym_NOT] = ACTIONS(376),
    [anon_sym_Not] = ACTIONS(376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(374),
    [aux_sym__expression_token1] = ACTIONS(374),
    [aux_sym__expression_token2] = ACTIONS(374),
    [aux_sym_keyword_identifier_token1] = ACTIONS(376),
    [aux_sym_keyword_identifier_token2] = ACTIONS(376),
    [anon_sym_SLASH] = ACTIONS(376),
    [anon_sym_div] = ACTIONS(376),
    [anon_sym_DIV] = ACTIONS(376),
    [anon_sym_Div] = ACTIONS(376),
    [anon_sym_mod] = ACTIONS(376),
    [anon_sym_MOD] = ACTIONS(376),
    [anon_sym_Mod] = ACTIONS(376),
    [anon_sym_PLUS] = ACTIONS(376),
    [anon_sym_GT_EQ] = ACTIONS(374),
    [anon_sym_LT_EQ] = ACTIONS(374),
    [anon_sym_GT] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(376),
    [anon_sym_LT_GT] = ACTIONS(374),
    [anon_sym_and] = ACTIONS(376),
    [anon_sym_AND] = ACTIONS(376),
    [anon_sym_And] = ACTIONS(376),
    [anon_sym_or] = ACTIONS(376),
    [anon_sym_OR] = ACTIONS(376),
    [anon_sym_Or] = ACTIONS(376),
    [anon_sym_xor] = ACTIONS(376),
    [anon_sym_XOR] = ACTIONS(376),
    [anon_sym_Xor] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(374),
    [sym_datetime_literal] = ACTIONS(374),
    [sym_date_literal] = ACTIONS(376),
    [sym_time_literal] = ACTIONS(376),
    [sym_biginteger_literal] = ACTIONS(374),
    [anon_sym_else] = ACTIONS(376),
    [anon_sym_ELSE] = ACTIONS(376),
    [anon_sym_Else] = ACTIONS(376),
    [anon_sym_in] = ACTIONS(376),
    [anon_sym_IN] = ACTIONS(376),
    [anon_sym_In] = ACTIONS(376),
    [sym_page_keyword] = ACTIONS(376),
    [anon_sym_codeunit] = ACTIONS(376),
    [anon_sym_CODEUNIT] = ACTIONS(376),
    [anon_sym_Codeunit] = ACTIONS(376),
    [anon_sym_CodeUnit] = ACTIONS(376),
    [anon_sym_COdeunit] = ACTIONS(376),
    [anon_sym_codeUnit] = ACTIONS(376),
    [sym_report_keyword] = ACTIONS(376),
    [sym_query_keyword] = ACTIONS(376),
    [anon_sym_xmlport] = ACTIONS(376),
    [anon_sym_XMLPORT] = ACTIONS(376),
    [anon_sym_Xmlport] = ACTIONS(376),
    [anon_sym_XMLport] = ACTIONS(376),
    [anon_sym_XMLPort] = ACTIONS(376),
    [anon_sym_XmlPort] = ACTIONS(376),
    [anon_sym_enum] = ACTIONS(376),
    [anon_sym_ENUM] = ACTIONS(376),
    [anon_sym_Enum] = ACTIONS(376),
    [anon_sym_eNUM] = ACTIONS(376),
    [anon_sym_eNum] = ACTIONS(376),
    [anon_sym_ENum] = ACTIONS(376),
    [sym_quoted_identifier] = ACTIONS(374),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(374),
    [sym_integer] = ACTIONS(376),
    [sym_continue_as_identifier] = ACTIONS(374),
    [sym_preproc_open] = ACTIONS(374),
  },
  [STATE(2102)] = {
    [sym_identifier] = ACTIONS(2525),
    [anon_sym_SEMI] = ACTIONS(2527),
    [anon_sym_DOT] = ACTIONS(2525),
    [anon_sym_EQ] = ACTIONS(2527),
    [anon_sym_COMMA] = ACTIONS(2527),
    [anon_sym_COLON] = ACTIONS(2525),
    [anon_sym_DASH] = ACTIONS(2525),
    [aux_sym_boolean_token1] = ACTIONS(2525),
    [aux_sym_boolean_token2] = ACTIONS(2525),
    [sym_decimal] = ACTIONS(2525),
    [anon_sym_LPAREN] = ACTIONS(2527),
    [anon_sym_DOT_DOT] = ACTIONS(2527),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2525),
    [anon_sym_STAR] = ACTIONS(2525),
    [anon_sym_LBRACK] = ACTIONS(2527),
    [aux_sym_record_type_token1] = ACTIONS(2525),
    [aux_sym_basic_type_token21] = ACTIONS(2525),
    [aux_sym_basic_type_token22] = ACTIONS(2525),
    [aux_sym_basic_type_token48] = ACTIONS(2525),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2525),
    [anon_sym_COLON_COLON] = ACTIONS(2527),
    [anon_sym_POUNDif] = ACTIONS(2527),
    [anon_sym_POUNDIF] = ACTIONS(2527),
    [anon_sym_POUNDIf] = ACTIONS(2527),
    [anon_sym_not] = ACTIONS(2525),
    [anon_sym_NOT] = ACTIONS(2525),
    [anon_sym_Not] = ACTIONS(2525),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2527),
    [aux_sym__expression_token1] = ACTIONS(2527),
    [aux_sym__expression_token2] = ACTIONS(2527),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2525),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2525),
    [anon_sym_SLASH] = ACTIONS(2525),
    [anon_sym_div] = ACTIONS(2525),
    [anon_sym_DIV] = ACTIONS(2525),
    [anon_sym_Div] = ACTIONS(2525),
    [anon_sym_mod] = ACTIONS(2525),
    [anon_sym_MOD] = ACTIONS(2525),
    [anon_sym_Mod] = ACTIONS(2525),
    [anon_sym_PLUS] = ACTIONS(2525),
    [anon_sym_GT_EQ] = ACTIONS(2527),
    [anon_sym_LT_EQ] = ACTIONS(2527),
    [anon_sym_GT] = ACTIONS(2525),
    [anon_sym_LT] = ACTIONS(2525),
    [anon_sym_LT_GT] = ACTIONS(2527),
    [anon_sym_and] = ACTIONS(2525),
    [anon_sym_AND] = ACTIONS(2525),
    [anon_sym_And] = ACTIONS(2525),
    [anon_sym_or] = ACTIONS(2525),
    [anon_sym_OR] = ACTIONS(2525),
    [anon_sym_Or] = ACTIONS(2525),
    [anon_sym_xor] = ACTIONS(2525),
    [anon_sym_XOR] = ACTIONS(2525),
    [anon_sym_Xor] = ACTIONS(2525),
    [anon_sym_QMARK] = ACTIONS(2527),
    [sym_datetime_literal] = ACTIONS(2527),
    [sym_date_literal] = ACTIONS(2525),
    [sym_time_literal] = ACTIONS(2525),
    [sym_biginteger_literal] = ACTIONS(2527),
    [anon_sym_else] = ACTIONS(2525),
    [anon_sym_ELSE] = ACTIONS(2525),
    [anon_sym_Else] = ACTIONS(2525),
    [anon_sym_in] = ACTIONS(2525),
    [anon_sym_IN] = ACTIONS(2525),
    [anon_sym_In] = ACTIONS(2525),
    [sym_page_keyword] = ACTIONS(2525),
    [anon_sym_codeunit] = ACTIONS(2525),
    [anon_sym_CODEUNIT] = ACTIONS(2525),
    [anon_sym_Codeunit] = ACTIONS(2525),
    [anon_sym_CodeUnit] = ACTIONS(2525),
    [anon_sym_COdeunit] = ACTIONS(2525),
    [anon_sym_codeUnit] = ACTIONS(2525),
    [sym_report_keyword] = ACTIONS(2525),
    [sym_query_keyword] = ACTIONS(2525),
    [anon_sym_xmlport] = ACTIONS(2525),
    [anon_sym_XMLPORT] = ACTIONS(2525),
    [anon_sym_Xmlport] = ACTIONS(2525),
    [anon_sym_XMLport] = ACTIONS(2525),
    [anon_sym_XMLPort] = ACTIONS(2525),
    [anon_sym_XmlPort] = ACTIONS(2525),
    [anon_sym_enum] = ACTIONS(2525),
    [anon_sym_ENUM] = ACTIONS(2525),
    [anon_sym_Enum] = ACTIONS(2525),
    [anon_sym_eNUM] = ACTIONS(2525),
    [anon_sym_eNum] = ACTIONS(2525),
    [anon_sym_ENum] = ACTIONS(2525),
    [sym_quoted_identifier] = ACTIONS(2527),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2527),
    [sym_integer] = ACTIONS(2525),
    [sym_continue_as_identifier] = ACTIONS(2527),
    [sym_preproc_open] = ACTIONS(2527),
  },
  [STATE(2103)] = {
    [sym_identifier] = ACTIONS(2396),
    [anon_sym_SEMI] = ACTIONS(2398),
    [anon_sym_DOT] = ACTIONS(2396),
    [anon_sym_EQ] = ACTIONS(2398),
    [anon_sym_COMMA] = ACTIONS(2398),
    [anon_sym_COLON] = ACTIONS(2396),
    [anon_sym_DASH] = ACTIONS(2396),
    [aux_sym_boolean_token1] = ACTIONS(2396),
    [aux_sym_boolean_token2] = ACTIONS(2396),
    [sym_decimal] = ACTIONS(2396),
    [anon_sym_LPAREN] = ACTIONS(2398),
    [anon_sym_DOT_DOT] = ACTIONS(2398),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2396),
    [anon_sym_STAR] = ACTIONS(2396),
    [anon_sym_LBRACK] = ACTIONS(2398),
    [aux_sym_record_type_token1] = ACTIONS(2396),
    [aux_sym_basic_type_token21] = ACTIONS(2396),
    [aux_sym_basic_type_token22] = ACTIONS(2396),
    [aux_sym_basic_type_token48] = ACTIONS(2396),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2396),
    [anon_sym_POUNDif] = ACTIONS(2398),
    [anon_sym_POUNDIF] = ACTIONS(2398),
    [anon_sym_POUNDIf] = ACTIONS(2398),
    [anon_sym_not] = ACTIONS(2396),
    [anon_sym_NOT] = ACTIONS(2396),
    [anon_sym_Not] = ACTIONS(2396),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2398),
    [aux_sym__expression_token1] = ACTIONS(2398),
    [aux_sym__expression_token2] = ACTIONS(2398),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2396),
    [anon_sym_SLASH] = ACTIONS(2396),
    [anon_sym_div] = ACTIONS(2396),
    [anon_sym_DIV] = ACTIONS(2396),
    [anon_sym_Div] = ACTIONS(2396),
    [anon_sym_mod] = ACTIONS(2396),
    [anon_sym_MOD] = ACTIONS(2396),
    [anon_sym_Mod] = ACTIONS(2396),
    [anon_sym_PLUS] = ACTIONS(2396),
    [anon_sym_GT_EQ] = ACTIONS(2398),
    [anon_sym_LT_EQ] = ACTIONS(2398),
    [anon_sym_GT] = ACTIONS(2396),
    [anon_sym_LT] = ACTIONS(2396),
    [anon_sym_LT_GT] = ACTIONS(2398),
    [anon_sym_and] = ACTIONS(2396),
    [anon_sym_AND] = ACTIONS(2396),
    [anon_sym_And] = ACTIONS(2396),
    [anon_sym_or] = ACTIONS(2396),
    [anon_sym_OR] = ACTIONS(2396),
    [anon_sym_Or] = ACTIONS(2396),
    [anon_sym_xor] = ACTIONS(2396),
    [anon_sym_XOR] = ACTIONS(2396),
    [anon_sym_Xor] = ACTIONS(2396),
    [anon_sym_QMARK] = ACTIONS(2398),
    [sym_datetime_literal] = ACTIONS(2398),
    [sym_date_literal] = ACTIONS(2396),
    [sym_time_literal] = ACTIONS(2396),
    [sym_biginteger_literal] = ACTIONS(2398),
    [anon_sym_else] = ACTIONS(2396),
    [anon_sym_ELSE] = ACTIONS(2396),
    [anon_sym_Else] = ACTIONS(2396),
    [anon_sym_in] = ACTIONS(2396),
    [anon_sym_IN] = ACTIONS(2396),
    [anon_sym_In] = ACTIONS(2396),
    [sym_page_keyword] = ACTIONS(2396),
    [anon_sym_codeunit] = ACTIONS(2396),
    [anon_sym_CODEUNIT] = ACTIONS(2396),
    [anon_sym_Codeunit] = ACTIONS(2396),
    [anon_sym_CodeUnit] = ACTIONS(2396),
    [anon_sym_COdeunit] = ACTIONS(2396),
    [anon_sym_codeUnit] = ACTIONS(2396),
    [sym_report_keyword] = ACTIONS(2396),
    [sym_query_keyword] = ACTIONS(2396),
    [anon_sym_xmlport] = ACTIONS(2396),
    [anon_sym_XMLPORT] = ACTIONS(2396),
    [anon_sym_Xmlport] = ACTIONS(2396),
    [anon_sym_XMLport] = ACTIONS(2396),
    [anon_sym_XMLPort] = ACTIONS(2396),
    [anon_sym_XmlPort] = ACTIONS(2396),
    [anon_sym_enum] = ACTIONS(2396),
    [anon_sym_ENUM] = ACTIONS(2396),
    [anon_sym_Enum] = ACTIONS(2396),
    [anon_sym_eNUM] = ACTIONS(2396),
    [anon_sym_eNum] = ACTIONS(2396),
    [anon_sym_ENum] = ACTIONS(2396),
    [sym_temporary_keyword] = ACTIONS(2396),
    [sym_quoted_identifier] = ACTIONS(2398),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2398),
    [sym_integer] = ACTIONS(2396),
    [sym_continue_as_identifier] = ACTIONS(2398),
    [sym_preproc_open] = ACTIONS(2398),
  },
  [STATE(2104)] = {
    [sym_identifier] = ACTIONS(2533),
    [anon_sym_SEMI] = ACTIONS(2535),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym_EQ] = ACTIONS(2535),
    [anon_sym_COMMA] = ACTIONS(2535),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_DASH] = ACTIONS(2533),
    [aux_sym_boolean_token1] = ACTIONS(2533),
    [aux_sym_boolean_token2] = ACTIONS(2533),
    [sym_decimal] = ACTIONS(2533),
    [anon_sym_LPAREN] = ACTIONS(2535),
    [anon_sym_DOT_DOT] = ACTIONS(2535),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2533),
    [anon_sym_STAR] = ACTIONS(2533),
    [anon_sym_LBRACK] = ACTIONS(2535),
    [aux_sym_record_type_token1] = ACTIONS(2533),
    [aux_sym_basic_type_token21] = ACTIONS(2533),
    [aux_sym_basic_type_token22] = ACTIONS(2533),
    [aux_sym_basic_type_token48] = ACTIONS(2533),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2533),
    [anon_sym_POUNDif] = ACTIONS(2535),
    [anon_sym_POUNDIF] = ACTIONS(2535),
    [anon_sym_POUNDIf] = ACTIONS(2535),
    [anon_sym_not] = ACTIONS(2533),
    [anon_sym_NOT] = ACTIONS(2533),
    [anon_sym_Not] = ACTIONS(2533),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2535),
    [aux_sym__expression_token1] = ACTIONS(2535),
    [aux_sym__expression_token2] = ACTIONS(2535),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2533),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2533),
    [anon_sym_SLASH] = ACTIONS(2533),
    [anon_sym_div] = ACTIONS(2533),
    [anon_sym_DIV] = ACTIONS(2533),
    [anon_sym_Div] = ACTIONS(2533),
    [anon_sym_mod] = ACTIONS(2533),
    [anon_sym_MOD] = ACTIONS(2533),
    [anon_sym_Mod] = ACTIONS(2533),
    [anon_sym_PLUS] = ACTIONS(2533),
    [anon_sym_GT_EQ] = ACTIONS(2535),
    [anon_sym_LT_EQ] = ACTIONS(2535),
    [anon_sym_GT] = ACTIONS(2533),
    [anon_sym_LT] = ACTIONS(2533),
    [anon_sym_LT_GT] = ACTIONS(2535),
    [anon_sym_and] = ACTIONS(2533),
    [anon_sym_AND] = ACTIONS(2533),
    [anon_sym_And] = ACTIONS(2533),
    [anon_sym_or] = ACTIONS(2533),
    [anon_sym_OR] = ACTIONS(2533),
    [anon_sym_Or] = ACTIONS(2533),
    [anon_sym_xor] = ACTIONS(2533),
    [anon_sym_XOR] = ACTIONS(2533),
    [anon_sym_Xor] = ACTIONS(2533),
    [anon_sym_QMARK] = ACTIONS(2535),
    [sym_datetime_literal] = ACTIONS(2535),
    [sym_date_literal] = ACTIONS(2533),
    [sym_time_literal] = ACTIONS(2533),
    [sym_biginteger_literal] = ACTIONS(2535),
    [anon_sym_else] = ACTIONS(2533),
    [anon_sym_ELSE] = ACTIONS(2533),
    [anon_sym_Else] = ACTIONS(2533),
    [anon_sym_in] = ACTIONS(2533),
    [anon_sym_IN] = ACTIONS(2533),
    [anon_sym_In] = ACTIONS(2533),
    [sym_page_keyword] = ACTIONS(2533),
    [anon_sym_codeunit] = ACTIONS(2533),
    [anon_sym_CODEUNIT] = ACTIONS(2533),
    [anon_sym_Codeunit] = ACTIONS(2533),
    [anon_sym_CodeUnit] = ACTIONS(2533),
    [anon_sym_COdeunit] = ACTIONS(2533),
    [anon_sym_codeUnit] = ACTIONS(2533),
    [sym_report_keyword] = ACTIONS(2533),
    [sym_query_keyword] = ACTIONS(2533),
    [anon_sym_xmlport] = ACTIONS(2533),
    [anon_sym_XMLPORT] = ACTIONS(2533),
    [anon_sym_Xmlport] = ACTIONS(2533),
    [anon_sym_XMLport] = ACTIONS(2533),
    [anon_sym_XMLPort] = ACTIONS(2533),
    [anon_sym_XmlPort] = ACTIONS(2533),
    [anon_sym_enum] = ACTIONS(2533),
    [anon_sym_ENUM] = ACTIONS(2533),
    [anon_sym_Enum] = ACTIONS(2533),
    [anon_sym_eNUM] = ACTIONS(2533),
    [anon_sym_eNum] = ACTIONS(2533),
    [anon_sym_ENum] = ACTIONS(2533),
    [sym_temporary_keyword] = ACTIONS(5415),
    [sym_quoted_identifier] = ACTIONS(2535),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2535),
    [sym_integer] = ACTIONS(2533),
    [sym_continue_as_identifier] = ACTIONS(2535),
    [sym_preproc_open] = ACTIONS(2535),
  },
  [STATE(2105)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_COMMA] = ACTIONS(2428),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [anon_sym_COLON_COLON] = ACTIONS(5417),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [anon_sym_POUNDelif] = ACTIONS(2428),
    [anon_sym_POUNDELIF] = ACTIONS(2428),
    [anon_sym_POUNDElif] = ACTIONS(2428),
    [anon_sym_POUNDelse] = ACTIONS(2428),
    [anon_sym_POUNDELSE] = ACTIONS(2428),
    [anon_sym_POUNDElse] = ACTIONS(2428),
    [anon_sym_POUNDendif] = ACTIONS(2428),
    [anon_sym_POUNDENDIF] = ACTIONS(2428),
    [anon_sym_POUNDEndif] = ACTIONS(2428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2428),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_close] = ACTIONS(2428),
  },
  [STATE(2106)] = {
    [sym_identifier] = ACTIONS(2521),
    [anon_sym_DOT] = ACTIONS(2521),
    [anon_sym_EQ] = ACTIONS(2523),
    [anon_sym_COMMA] = ACTIONS(2523),
    [anon_sym_DASH] = ACTIONS(2521),
    [aux_sym_boolean_token1] = ACTIONS(2521),
    [aux_sym_boolean_token2] = ACTIONS(2521),
    [sym_decimal] = ACTIONS(2521),
    [anon_sym_LPAREN] = ACTIONS(2523),
    [anon_sym_DOT_DOT] = ACTIONS(2523),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2521),
    [anon_sym_STAR] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [aux_sym_record_type_token1] = ACTIONS(2521),
    [aux_sym_basic_type_token21] = ACTIONS(2521),
    [aux_sym_basic_type_token22] = ACTIONS(2521),
    [aux_sym_basic_type_token48] = ACTIONS(2521),
    [anon_sym_COLON_COLON] = ACTIONS(2523),
    [anon_sym_not] = ACTIONS(2521),
    [anon_sym_NOT] = ACTIONS(2521),
    [anon_sym_Not] = ACTIONS(2521),
    [anon_sym_POUNDelif] = ACTIONS(2523),
    [anon_sym_POUNDELIF] = ACTIONS(2523),
    [anon_sym_POUNDElif] = ACTIONS(2523),
    [anon_sym_POUNDelse] = ACTIONS(2523),
    [anon_sym_POUNDELSE] = ACTIONS(2523),
    [anon_sym_POUNDElse] = ACTIONS(2523),
    [anon_sym_POUNDendif] = ACTIONS(2523),
    [anon_sym_POUNDENDIF] = ACTIONS(2523),
    [anon_sym_POUNDEndif] = ACTIONS(2523),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2523),
    [aux_sym__expression_token1] = ACTIONS(2523),
    [aux_sym__expression_token2] = ACTIONS(2523),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2521),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2521),
    [anon_sym_SLASH] = ACTIONS(2521),
    [anon_sym_div] = ACTIONS(2521),
    [anon_sym_DIV] = ACTIONS(2521),
    [anon_sym_Div] = ACTIONS(2521),
    [anon_sym_mod] = ACTIONS(2521),
    [anon_sym_MOD] = ACTIONS(2521),
    [anon_sym_Mod] = ACTIONS(2521),
    [anon_sym_PLUS] = ACTIONS(2521),
    [anon_sym_GT_EQ] = ACTIONS(2523),
    [anon_sym_LT_EQ] = ACTIONS(2523),
    [anon_sym_GT] = ACTIONS(2521),
    [anon_sym_LT] = ACTIONS(2521),
    [anon_sym_LT_GT] = ACTIONS(2523),
    [anon_sym_and] = ACTIONS(2521),
    [anon_sym_AND] = ACTIONS(2521),
    [anon_sym_And] = ACTIONS(2521),
    [anon_sym_or] = ACTIONS(2521),
    [anon_sym_OR] = ACTIONS(2521),
    [anon_sym_Or] = ACTIONS(2521),
    [anon_sym_xor] = ACTIONS(2521),
    [anon_sym_XOR] = ACTIONS(2521),
    [anon_sym_Xor] = ACTIONS(2521),
    [anon_sym_QMARK] = ACTIONS(2523),
    [sym_datetime_literal] = ACTIONS(2523),
    [sym_date_literal] = ACTIONS(2521),
    [sym_time_literal] = ACTIONS(2521),
    [sym_biginteger_literal] = ACTIONS(2523),
    [anon_sym_in] = ACTIONS(2521),
    [anon_sym_IN] = ACTIONS(2521),
    [anon_sym_In] = ACTIONS(2521),
    [sym_page_keyword] = ACTIONS(2521),
    [anon_sym_codeunit] = ACTIONS(2521),
    [anon_sym_CODEUNIT] = ACTIONS(2521),
    [anon_sym_Codeunit] = ACTIONS(2521),
    [anon_sym_CodeUnit] = ACTIONS(2521),
    [anon_sym_COdeunit] = ACTIONS(2521),
    [anon_sym_codeUnit] = ACTIONS(2521),
    [sym_report_keyword] = ACTIONS(2521),
    [sym_query_keyword] = ACTIONS(2521),
    [anon_sym_xmlport] = ACTIONS(2521),
    [anon_sym_XMLPORT] = ACTIONS(2521),
    [anon_sym_Xmlport] = ACTIONS(2521),
    [anon_sym_XMLport] = ACTIONS(2521),
    [anon_sym_XMLPort] = ACTIONS(2521),
    [anon_sym_XmlPort] = ACTIONS(2521),
    [anon_sym_enum] = ACTIONS(2521),
    [anon_sym_ENUM] = ACTIONS(2521),
    [anon_sym_Enum] = ACTIONS(2521),
    [anon_sym_eNUM] = ACTIONS(2521),
    [anon_sym_eNum] = ACTIONS(2521),
    [anon_sym_ENum] = ACTIONS(2521),
    [sym_quoted_identifier] = ACTIONS(2523),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2523),
    [sym_integer] = ACTIONS(2521),
    [sym_continue_as_identifier] = ACTIONS(2523),
    [sym_preproc_close] = ACTIONS(2523),
  },
  [STATE(2107)] = {
    [sym_identifier] = ACTIONS(2521),
    [anon_sym_SEMI] = ACTIONS(2523),
    [anon_sym_DOT] = ACTIONS(2521),
    [anon_sym_EQ] = ACTIONS(2523),
    [anon_sym_COMMA] = ACTIONS(2523),
    [anon_sym_COLON] = ACTIONS(2521),
    [anon_sym_DASH] = ACTIONS(2521),
    [aux_sym_boolean_token1] = ACTIONS(2521),
    [aux_sym_boolean_token2] = ACTIONS(2521),
    [sym_decimal] = ACTIONS(2521),
    [anon_sym_LPAREN] = ACTIONS(2523),
    [anon_sym_DOT_DOT] = ACTIONS(2523),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2521),
    [anon_sym_STAR] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [aux_sym_record_type_token1] = ACTIONS(2521),
    [aux_sym_basic_type_token21] = ACTIONS(2521),
    [aux_sym_basic_type_token22] = ACTIONS(2521),
    [aux_sym_basic_type_token48] = ACTIONS(2521),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2521),
    [anon_sym_COLON_COLON] = ACTIONS(2523),
    [anon_sym_POUNDif] = ACTIONS(2523),
    [anon_sym_POUNDIF] = ACTIONS(2523),
    [anon_sym_POUNDIf] = ACTIONS(2523),
    [anon_sym_not] = ACTIONS(2521),
    [anon_sym_NOT] = ACTIONS(2521),
    [anon_sym_Not] = ACTIONS(2521),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2523),
    [aux_sym__expression_token1] = ACTIONS(2523),
    [aux_sym__expression_token2] = ACTIONS(2523),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2521),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2521),
    [anon_sym_SLASH] = ACTIONS(2521),
    [anon_sym_div] = ACTIONS(2521),
    [anon_sym_DIV] = ACTIONS(2521),
    [anon_sym_Div] = ACTIONS(2521),
    [anon_sym_mod] = ACTIONS(2521),
    [anon_sym_MOD] = ACTIONS(2521),
    [anon_sym_Mod] = ACTIONS(2521),
    [anon_sym_PLUS] = ACTIONS(2521),
    [anon_sym_GT_EQ] = ACTIONS(2523),
    [anon_sym_LT_EQ] = ACTIONS(2523),
    [anon_sym_GT] = ACTIONS(2521),
    [anon_sym_LT] = ACTIONS(2521),
    [anon_sym_LT_GT] = ACTIONS(2523),
    [anon_sym_and] = ACTIONS(2521),
    [anon_sym_AND] = ACTIONS(2521),
    [anon_sym_And] = ACTIONS(2521),
    [anon_sym_or] = ACTIONS(2521),
    [anon_sym_OR] = ACTIONS(2521),
    [anon_sym_Or] = ACTIONS(2521),
    [anon_sym_xor] = ACTIONS(2521),
    [anon_sym_XOR] = ACTIONS(2521),
    [anon_sym_Xor] = ACTIONS(2521),
    [anon_sym_QMARK] = ACTIONS(2523),
    [sym_datetime_literal] = ACTIONS(2523),
    [sym_date_literal] = ACTIONS(2521),
    [sym_time_literal] = ACTIONS(2521),
    [sym_biginteger_literal] = ACTIONS(2523),
    [anon_sym_else] = ACTIONS(2521),
    [anon_sym_ELSE] = ACTIONS(2521),
    [anon_sym_Else] = ACTIONS(2521),
    [anon_sym_in] = ACTIONS(2521),
    [anon_sym_IN] = ACTIONS(2521),
    [anon_sym_In] = ACTIONS(2521),
    [sym_page_keyword] = ACTIONS(2521),
    [anon_sym_codeunit] = ACTIONS(2521),
    [anon_sym_CODEUNIT] = ACTIONS(2521),
    [anon_sym_Codeunit] = ACTIONS(2521),
    [anon_sym_CodeUnit] = ACTIONS(2521),
    [anon_sym_COdeunit] = ACTIONS(2521),
    [anon_sym_codeUnit] = ACTIONS(2521),
    [sym_report_keyword] = ACTIONS(2521),
    [sym_query_keyword] = ACTIONS(2521),
    [anon_sym_xmlport] = ACTIONS(2521),
    [anon_sym_XMLPORT] = ACTIONS(2521),
    [anon_sym_Xmlport] = ACTIONS(2521),
    [anon_sym_XMLport] = ACTIONS(2521),
    [anon_sym_XMLPort] = ACTIONS(2521),
    [anon_sym_XmlPort] = ACTIONS(2521),
    [anon_sym_enum] = ACTIONS(2521),
    [anon_sym_ENUM] = ACTIONS(2521),
    [anon_sym_Enum] = ACTIONS(2521),
    [anon_sym_eNUM] = ACTIONS(2521),
    [anon_sym_eNum] = ACTIONS(2521),
    [anon_sym_ENum] = ACTIONS(2521),
    [sym_quoted_identifier] = ACTIONS(2523),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2523),
    [sym_integer] = ACTIONS(2521),
    [sym_continue_as_identifier] = ACTIONS(2523),
    [sym_preproc_open] = ACTIONS(2523),
  },
  [STATE(2108)] = {
    [sym_boolean] = STATE(1741),
    [sym_preproc_if] = STATE(2441),
    [sym_preproc_endif] = STATE(2552),
    [sym_assignment_expression] = STATE(6354),
    [sym_case_branch] = STATE(2173),
    [sym_preproc_split_case_branch] = STATE(3395),
    [aux_sym__case_pattern] = STATE(2579),
    [sym_preproc_conditional_case_patterns] = STATE(2579),
    [sym__single_pattern] = STATE(3450),
    [sym_case_else_branch] = STATE(9304),
    [sym__expression] = STATE(6354),
    [sym_keyword_identifier] = STATE(1684),
    [sym_range_expression] = STATE(1741),
    [sym_multiplicative_expression] = STATE(1741),
    [sym_additive_expression] = STATE(1741),
    [sym_comparison_expression] = STATE(1741),
    [sym_logical_expression] = STATE(1741),
    [sym_ternary_expression] = STATE(6354),
    [sym_unary_expression] = STATE(1741),
    [sym_call_expression] = STATE(1734),
    [sym_member_expression] = STATE(1684),
    [sym_subscript_expression] = STATE(1684),
    [sym_parenthesized_expression] = STATE(1741),
    [sym_list_literal] = STATE(6354),
    [sym_qualified_enum_value] = STATE(1684),
    [sym_database_reference] = STATE(1741),
    [sym__literal_value] = STATE(1741),
    [sym_else_keyword] = STATE(87),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(2173),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2651),
    [sym_identifier] = ACTIONS(3746),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(3748),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(3752),
    [sym_date_literal] = ACTIONS(3748),
    [sym_time_literal] = ACTIONS(3748),
    [sym_biginteger_literal] = ACTIONS(3752),
    [anon_sym_else] = ACTIONS(3754),
    [anon_sym_ELSE] = ACTIONS(3754),
    [anon_sym_Else] = ACTIONS(3754),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(3756),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3752),
    [sym_integer] = ACTIONS(3748),
    [sym_continue_as_identifier] = ACTIONS(3758),
    [sym_preproc_open] = ACTIONS(3750),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2109)] = {
    [sym_boolean] = STATE(4795),
    [sym_option_member] = STATE(4829),
    [sym_keyword_identifier] = STATE(4795),
    [sym_codeunit_keyword] = STATE(4642),
    [sym_xmlport_keyword] = STATE(4642),
    [sym_enum_keyword] = STATE(4642),
    [sym_keyword_as_identifier] = STATE(4795),
    [sym_identifier] = ACTIONS(2239),
    [anon_sym_SEMI] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(391),
    [anon_sym_EQ] = ACTIONS(389),
    [anon_sym_COMMA] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(4086),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [aux_sym_where_condition_token1] = ACTIONS(4844),
    [anon_sym_DOT_DOT] = ACTIONS(389),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_STAR] = ACTIONS(391),
    [anon_sym_LBRACK] = ACTIONS(389),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(2221),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(4844),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4844),
    [aux_sym_separator_action_token1] = ACTIONS(4844),
    [aux_sym_type_declaration_token1] = ACTIONS(4844),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(389),
    [aux_sym__expression_token1] = ACTIONS(389),
    [aux_sym__expression_token2] = ACTIONS(389),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(917),
    [anon_sym_SLASH] = ACTIONS(391),
    [anon_sym_div] = ACTIONS(391),
    [anon_sym_DIV] = ACTIONS(391),
    [anon_sym_Div] = ACTIONS(391),
    [anon_sym_mod] = ACTIONS(391),
    [anon_sym_MOD] = ACTIONS(391),
    [anon_sym_Mod] = ACTIONS(391),
    [anon_sym_PLUS] = ACTIONS(391),
    [anon_sym_GT_EQ] = ACTIONS(389),
    [anon_sym_LT_EQ] = ACTIONS(389),
    [anon_sym_GT] = ACTIONS(391),
    [anon_sym_LT] = ACTIONS(391),
    [anon_sym_LT_GT] = ACTIONS(389),
    [anon_sym_and] = ACTIONS(391),
    [anon_sym_AND] = ACTIONS(391),
    [anon_sym_And] = ACTIONS(391),
    [anon_sym_or] = ACTIONS(391),
    [anon_sym_OR] = ACTIONS(391),
    [anon_sym_Or] = ACTIONS(391),
    [anon_sym_xor] = ACTIONS(391),
    [anon_sym_XOR] = ACTIONS(391),
    [anon_sym_Xor] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(389),
    [anon_sym_else] = ACTIONS(391),
    [anon_sym_ELSE] = ACTIONS(391),
    [anon_sym_Else] = ACTIONS(391),
    [anon_sym_in] = ACTIONS(391),
    [anon_sym_IN] = ACTIONS(391),
    [anon_sym_In] = ACTIONS(391),
    [sym_page_keyword] = ACTIONS(917),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(917),
    [sym_query_keyword] = ACTIONS(917),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(2239),
    [sym_internal_keyword] = ACTIONS(2239),
    [sym_protected_keyword] = ACTIONS(2239),
    [sym_key_keyword] = ACTIONS(4844),
    [sym_dataset_keyword] = ACTIONS(4844),
    [sym_quoted_identifier] = ACTIONS(3706),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3706),
    [sym_integer] = ACTIONS(3706),
  },
  [STATE(2110)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2125),
    [sym_identifier] = ACTIONS(376),
    [anon_sym_DOT] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(376),
    [aux_sym_boolean_token1] = ACTIONS(376),
    [aux_sym_boolean_token2] = ACTIONS(376),
    [sym_decimal] = ACTIONS(376),
    [anon_sym_LPAREN] = ACTIONS(374),
    [anon_sym_DOT_DOT] = ACTIONS(374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(376),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(376),
    [aux_sym_basic_type_token21] = ACTIONS(376),
    [aux_sym_basic_type_token22] = ACTIONS(376),
    [aux_sym_basic_type_token48] = ACTIONS(376),
    [anon_sym_not] = ACTIONS(376),
    [anon_sym_NOT] = ACTIONS(376),
    [anon_sym_Not] = ACTIONS(376),
    [anon_sym_POUNDelif] = ACTIONS(374),
    [anon_sym_POUNDELIF] = ACTIONS(374),
    [anon_sym_POUNDElif] = ACTIONS(374),
    [anon_sym_POUNDelse] = ACTIONS(374),
    [anon_sym_POUNDELSE] = ACTIONS(374),
    [anon_sym_POUNDElse] = ACTIONS(374),
    [anon_sym_POUNDendif] = ACTIONS(374),
    [anon_sym_POUNDENDIF] = ACTIONS(374),
    [anon_sym_POUNDEndif] = ACTIONS(374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(374),
    [aux_sym__expression_token1] = ACTIONS(374),
    [aux_sym__expression_token2] = ACTIONS(374),
    [aux_sym_keyword_identifier_token1] = ACTIONS(376),
    [aux_sym_keyword_identifier_token2] = ACTIONS(376),
    [anon_sym_SLASH] = ACTIONS(376),
    [anon_sym_div] = ACTIONS(376),
    [anon_sym_DIV] = ACTIONS(376),
    [anon_sym_Div] = ACTIONS(376),
    [anon_sym_mod] = ACTIONS(376),
    [anon_sym_MOD] = ACTIONS(376),
    [anon_sym_Mod] = ACTIONS(376),
    [anon_sym_PLUS] = ACTIONS(376),
    [anon_sym_GT_EQ] = ACTIONS(374),
    [anon_sym_LT_EQ] = ACTIONS(374),
    [anon_sym_GT] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(376),
    [anon_sym_LT_GT] = ACTIONS(374),
    [anon_sym_and] = ACTIONS(376),
    [anon_sym_AND] = ACTIONS(376),
    [anon_sym_And] = ACTIONS(376),
    [anon_sym_or] = ACTIONS(376),
    [anon_sym_OR] = ACTIONS(376),
    [anon_sym_Or] = ACTIONS(376),
    [anon_sym_xor] = ACTIONS(376),
    [anon_sym_XOR] = ACTIONS(376),
    [anon_sym_Xor] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(374),
    [sym_datetime_literal] = ACTIONS(374),
    [sym_date_literal] = ACTIONS(376),
    [sym_time_literal] = ACTIONS(376),
    [sym_biginteger_literal] = ACTIONS(374),
    [anon_sym_in] = ACTIONS(376),
    [anon_sym_IN] = ACTIONS(376),
    [anon_sym_In] = ACTIONS(376),
    [sym_page_keyword] = ACTIONS(376),
    [anon_sym_codeunit] = ACTIONS(376),
    [anon_sym_CODEUNIT] = ACTIONS(376),
    [anon_sym_Codeunit] = ACTIONS(376),
    [anon_sym_CodeUnit] = ACTIONS(376),
    [anon_sym_COdeunit] = ACTIONS(376),
    [anon_sym_codeUnit] = ACTIONS(376),
    [sym_report_keyword] = ACTIONS(376),
    [sym_query_keyword] = ACTIONS(376),
    [anon_sym_xmlport] = ACTIONS(376),
    [anon_sym_XMLPORT] = ACTIONS(376),
    [anon_sym_Xmlport] = ACTIONS(376),
    [anon_sym_XMLport] = ACTIONS(376),
    [anon_sym_XMLPort] = ACTIONS(376),
    [anon_sym_XmlPort] = ACTIONS(376),
    [anon_sym_enum] = ACTIONS(376),
    [anon_sym_ENUM] = ACTIONS(376),
    [anon_sym_Enum] = ACTIONS(376),
    [anon_sym_eNUM] = ACTIONS(376),
    [anon_sym_eNum] = ACTIONS(376),
    [anon_sym_ENum] = ACTIONS(376),
    [sym_quoted_identifier] = ACTIONS(374),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(374),
    [sym_integer] = ACTIONS(376),
    [sym_continue_as_identifier] = ACTIONS(374),
    [sym_preproc_close] = ACTIONS(374),
  },
  [STATE(2111)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2114),
    [sym_identifier] = ACTIONS(2354),
    [anon_sym_SEMI] = ACTIONS(2356),
    [anon_sym_DOT] = ACTIONS(2354),
    [anon_sym_EQ] = ACTIONS(2356),
    [anon_sym_COMMA] = ACTIONS(5413),
    [anon_sym_COLON] = ACTIONS(2354),
    [anon_sym_DASH] = ACTIONS(2354),
    [aux_sym_boolean_token1] = ACTIONS(2354),
    [aux_sym_boolean_token2] = ACTIONS(2354),
    [sym_decimal] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(2356),
    [anon_sym_DOT_DOT] = ACTIONS(2356),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2354),
    [anon_sym_STAR] = ACTIONS(2354),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [aux_sym_record_type_token1] = ACTIONS(2354),
    [aux_sym_basic_type_token21] = ACTIONS(2354),
    [aux_sym_basic_type_token22] = ACTIONS(2354),
    [aux_sym_basic_type_token48] = ACTIONS(2354),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2354),
    [anon_sym_POUNDif] = ACTIONS(2356),
    [anon_sym_POUNDIF] = ACTIONS(2356),
    [anon_sym_POUNDIf] = ACTIONS(2356),
    [anon_sym_not] = ACTIONS(2354),
    [anon_sym_NOT] = ACTIONS(2354),
    [anon_sym_Not] = ACTIONS(2354),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2356),
    [aux_sym__expression_token1] = ACTIONS(2356),
    [aux_sym__expression_token2] = ACTIONS(2356),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2354),
    [anon_sym_SLASH] = ACTIONS(2354),
    [anon_sym_div] = ACTIONS(2354),
    [anon_sym_DIV] = ACTIONS(2354),
    [anon_sym_Div] = ACTIONS(2354),
    [anon_sym_mod] = ACTIONS(2354),
    [anon_sym_MOD] = ACTIONS(2354),
    [anon_sym_Mod] = ACTIONS(2354),
    [anon_sym_PLUS] = ACTIONS(2354),
    [anon_sym_GT_EQ] = ACTIONS(2356),
    [anon_sym_LT_EQ] = ACTIONS(2356),
    [anon_sym_GT] = ACTIONS(2354),
    [anon_sym_LT] = ACTIONS(2354),
    [anon_sym_LT_GT] = ACTIONS(2356),
    [anon_sym_and] = ACTIONS(2354),
    [anon_sym_AND] = ACTIONS(2354),
    [anon_sym_And] = ACTIONS(2354),
    [anon_sym_or] = ACTIONS(2354),
    [anon_sym_OR] = ACTIONS(2354),
    [anon_sym_Or] = ACTIONS(2354),
    [anon_sym_xor] = ACTIONS(2354),
    [anon_sym_XOR] = ACTIONS(2354),
    [anon_sym_Xor] = ACTIONS(2354),
    [anon_sym_QMARK] = ACTIONS(2356),
    [sym_datetime_literal] = ACTIONS(2356),
    [sym_date_literal] = ACTIONS(2354),
    [sym_time_literal] = ACTIONS(2354),
    [sym_biginteger_literal] = ACTIONS(2356),
    [anon_sym_else] = ACTIONS(2354),
    [anon_sym_ELSE] = ACTIONS(2354),
    [anon_sym_Else] = ACTIONS(2354),
    [anon_sym_in] = ACTIONS(2354),
    [anon_sym_IN] = ACTIONS(2354),
    [anon_sym_In] = ACTIONS(2354),
    [sym_page_keyword] = ACTIONS(2354),
    [anon_sym_codeunit] = ACTIONS(2354),
    [anon_sym_CODEUNIT] = ACTIONS(2354),
    [anon_sym_Codeunit] = ACTIONS(2354),
    [anon_sym_CodeUnit] = ACTIONS(2354),
    [anon_sym_COdeunit] = ACTIONS(2354),
    [anon_sym_codeUnit] = ACTIONS(2354),
    [sym_report_keyword] = ACTIONS(2354),
    [sym_query_keyword] = ACTIONS(2354),
    [anon_sym_xmlport] = ACTIONS(2354),
    [anon_sym_XMLPORT] = ACTIONS(2354),
    [anon_sym_Xmlport] = ACTIONS(2354),
    [anon_sym_XMLport] = ACTIONS(2354),
    [anon_sym_XMLPort] = ACTIONS(2354),
    [anon_sym_XmlPort] = ACTIONS(2354),
    [anon_sym_enum] = ACTIONS(2354),
    [anon_sym_ENUM] = ACTIONS(2354),
    [anon_sym_Enum] = ACTIONS(2354),
    [anon_sym_eNUM] = ACTIONS(2354),
    [anon_sym_eNum] = ACTIONS(2354),
    [anon_sym_ENum] = ACTIONS(2354),
    [sym_quoted_identifier] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2356),
    [sym_integer] = ACTIONS(2354),
    [sym_continue_as_identifier] = ACTIONS(2356),
    [sym_preproc_open] = ACTIONS(2356),
  },
  [STATE(2112)] = {
    [sym_identifier] = ACTIONS(4658),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_COMMA] = ACTIONS(4660),
    [anon_sym_DASH] = ACTIONS(4662),
    [aux_sym_boolean_token1] = ACTIONS(4658),
    [aux_sym_boolean_token2] = ACTIONS(4658),
    [sym_decimal] = ACTIONS(4658),
    [anon_sym_LPAREN] = ACTIONS(4660),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4658),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(4665),
    [aux_sym_record_type_token1] = ACTIONS(4658),
    [aux_sym_basic_type_token21] = ACTIONS(4658),
    [aux_sym_basic_type_token22] = ACTIONS(4658),
    [aux_sym_basic_type_token48] = ACTIONS(4658),
    [anon_sym_COLON_COLON] = ACTIONS(5259),
    [anon_sym_not] = ACTIONS(4658),
    [anon_sym_NOT] = ACTIONS(4658),
    [anon_sym_Not] = ACTIONS(4658),
    [anon_sym_POUNDelif] = ACTIONS(4660),
    [anon_sym_POUNDELIF] = ACTIONS(4660),
    [anon_sym_POUNDElif] = ACTIONS(4660),
    [anon_sym_POUNDelse] = ACTIONS(4660),
    [anon_sym_POUNDELSE] = ACTIONS(4660),
    [anon_sym_POUNDElse] = ACTIONS(4660),
    [anon_sym_POUNDendif] = ACTIONS(4660),
    [anon_sym_POUNDENDIF] = ACTIONS(4660),
    [anon_sym_POUNDEndif] = ACTIONS(4660),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4658),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4658),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(4662),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(4660),
    [sym_date_literal] = ACTIONS(4658),
    [sym_time_literal] = ACTIONS(4658),
    [sym_biginteger_literal] = ACTIONS(4660),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(4658),
    [anon_sym_codeunit] = ACTIONS(4658),
    [anon_sym_CODEUNIT] = ACTIONS(4658),
    [anon_sym_Codeunit] = ACTIONS(4658),
    [anon_sym_CodeUnit] = ACTIONS(4658),
    [anon_sym_COdeunit] = ACTIONS(4658),
    [anon_sym_codeUnit] = ACTIONS(4658),
    [sym_report_keyword] = ACTIONS(4658),
    [sym_query_keyword] = ACTIONS(4658),
    [anon_sym_xmlport] = ACTIONS(4658),
    [anon_sym_XMLPORT] = ACTIONS(4658),
    [anon_sym_Xmlport] = ACTIONS(4658),
    [anon_sym_XMLport] = ACTIONS(4658),
    [anon_sym_XMLPort] = ACTIONS(4658),
    [anon_sym_XmlPort] = ACTIONS(4658),
    [anon_sym_enum] = ACTIONS(4658),
    [anon_sym_ENUM] = ACTIONS(4658),
    [anon_sym_Enum] = ACTIONS(4658),
    [anon_sym_eNUM] = ACTIONS(4658),
    [anon_sym_eNum] = ACTIONS(4658),
    [anon_sym_ENum] = ACTIONS(4658),
    [sym_quoted_identifier] = ACTIONS(4660),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4660),
    [sym_integer] = ACTIONS(4658),
    [sym_continue_as_identifier] = ACTIONS(4660),
    [sym_preproc_close] = ACTIONS(4660),
  },
  [STATE(2113)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2118),
    [sym_identifier] = ACTIONS(2354),
    [anon_sym_SEMI] = ACTIONS(2356),
    [anon_sym_DOT] = ACTIONS(2354),
    [anon_sym_EQ] = ACTIONS(2356),
    [anon_sym_COMMA] = ACTIONS(5413),
    [anon_sym_COLON] = ACTIONS(2354),
    [anon_sym_DASH] = ACTIONS(2354),
    [aux_sym_boolean_token1] = ACTIONS(2354),
    [aux_sym_boolean_token2] = ACTIONS(2354),
    [sym_decimal] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(2356),
    [anon_sym_DOT_DOT] = ACTIONS(2356),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2354),
    [anon_sym_STAR] = ACTIONS(2354),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [aux_sym_record_type_token1] = ACTIONS(2354),
    [aux_sym_basic_type_token21] = ACTIONS(2354),
    [aux_sym_basic_type_token22] = ACTIONS(2354),
    [aux_sym_basic_type_token48] = ACTIONS(2354),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2354),
    [anon_sym_POUNDif] = ACTIONS(2356),
    [anon_sym_POUNDIF] = ACTIONS(2356),
    [anon_sym_POUNDIf] = ACTIONS(2356),
    [anon_sym_not] = ACTIONS(2354),
    [anon_sym_NOT] = ACTIONS(2354),
    [anon_sym_Not] = ACTIONS(2354),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2356),
    [aux_sym__expression_token1] = ACTIONS(2356),
    [aux_sym__expression_token2] = ACTIONS(2356),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2354),
    [anon_sym_SLASH] = ACTIONS(2354),
    [anon_sym_div] = ACTIONS(2354),
    [anon_sym_DIV] = ACTIONS(2354),
    [anon_sym_Div] = ACTIONS(2354),
    [anon_sym_mod] = ACTIONS(2354),
    [anon_sym_MOD] = ACTIONS(2354),
    [anon_sym_Mod] = ACTIONS(2354),
    [anon_sym_PLUS] = ACTIONS(2354),
    [anon_sym_GT_EQ] = ACTIONS(2356),
    [anon_sym_LT_EQ] = ACTIONS(2356),
    [anon_sym_GT] = ACTIONS(2354),
    [anon_sym_LT] = ACTIONS(2354),
    [anon_sym_LT_GT] = ACTIONS(2356),
    [anon_sym_and] = ACTIONS(2354),
    [anon_sym_AND] = ACTIONS(2354),
    [anon_sym_And] = ACTIONS(2354),
    [anon_sym_or] = ACTIONS(2354),
    [anon_sym_OR] = ACTIONS(2354),
    [anon_sym_Or] = ACTIONS(2354),
    [anon_sym_xor] = ACTIONS(2354),
    [anon_sym_XOR] = ACTIONS(2354),
    [anon_sym_Xor] = ACTIONS(2354),
    [anon_sym_QMARK] = ACTIONS(2356),
    [sym_datetime_literal] = ACTIONS(2356),
    [sym_date_literal] = ACTIONS(2354),
    [sym_time_literal] = ACTIONS(2354),
    [sym_biginteger_literal] = ACTIONS(2356),
    [anon_sym_else] = ACTIONS(2354),
    [anon_sym_ELSE] = ACTIONS(2354),
    [anon_sym_Else] = ACTIONS(2354),
    [anon_sym_in] = ACTIONS(2354),
    [anon_sym_IN] = ACTIONS(2354),
    [anon_sym_In] = ACTIONS(2354),
    [sym_page_keyword] = ACTIONS(2354),
    [anon_sym_codeunit] = ACTIONS(2354),
    [anon_sym_CODEUNIT] = ACTIONS(2354),
    [anon_sym_Codeunit] = ACTIONS(2354),
    [anon_sym_CodeUnit] = ACTIONS(2354),
    [anon_sym_COdeunit] = ACTIONS(2354),
    [anon_sym_codeUnit] = ACTIONS(2354),
    [sym_report_keyword] = ACTIONS(2354),
    [sym_query_keyword] = ACTIONS(2354),
    [anon_sym_xmlport] = ACTIONS(2354),
    [anon_sym_XMLPORT] = ACTIONS(2354),
    [anon_sym_Xmlport] = ACTIONS(2354),
    [anon_sym_XMLport] = ACTIONS(2354),
    [anon_sym_XMLPort] = ACTIONS(2354),
    [anon_sym_XmlPort] = ACTIONS(2354),
    [anon_sym_enum] = ACTIONS(2354),
    [anon_sym_ENUM] = ACTIONS(2354),
    [anon_sym_Enum] = ACTIONS(2354),
    [anon_sym_eNUM] = ACTIONS(2354),
    [anon_sym_eNum] = ACTIONS(2354),
    [anon_sym_ENum] = ACTIONS(2354),
    [sym_quoted_identifier] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2356),
    [sym_integer] = ACTIONS(2354),
    [sym_continue_as_identifier] = ACTIONS(2356),
    [sym_preproc_open] = ACTIONS(2356),
  },
  [STATE(2114)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2114),
    [sym_identifier] = ACTIONS(2403),
    [anon_sym_SEMI] = ACTIONS(2405),
    [anon_sym_DOT] = ACTIONS(2403),
    [anon_sym_EQ] = ACTIONS(2405),
    [anon_sym_COMMA] = ACTIONS(5421),
    [anon_sym_COLON] = ACTIONS(2403),
    [anon_sym_DASH] = ACTIONS(2403),
    [aux_sym_boolean_token1] = ACTIONS(2403),
    [aux_sym_boolean_token2] = ACTIONS(2403),
    [sym_decimal] = ACTIONS(2403),
    [anon_sym_LPAREN] = ACTIONS(2405),
    [anon_sym_DOT_DOT] = ACTIONS(2405),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2403),
    [anon_sym_STAR] = ACTIONS(2403),
    [anon_sym_LBRACK] = ACTIONS(2405),
    [aux_sym_record_type_token1] = ACTIONS(2403),
    [aux_sym_basic_type_token21] = ACTIONS(2403),
    [aux_sym_basic_type_token22] = ACTIONS(2403),
    [aux_sym_basic_type_token48] = ACTIONS(2403),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2403),
    [anon_sym_POUNDif] = ACTIONS(2405),
    [anon_sym_POUNDIF] = ACTIONS(2405),
    [anon_sym_POUNDIf] = ACTIONS(2405),
    [anon_sym_not] = ACTIONS(2403),
    [anon_sym_NOT] = ACTIONS(2403),
    [anon_sym_Not] = ACTIONS(2403),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2405),
    [aux_sym__expression_token1] = ACTIONS(2405),
    [aux_sym__expression_token2] = ACTIONS(2405),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2403),
    [anon_sym_SLASH] = ACTIONS(2403),
    [anon_sym_div] = ACTIONS(2403),
    [anon_sym_DIV] = ACTIONS(2403),
    [anon_sym_Div] = ACTIONS(2403),
    [anon_sym_mod] = ACTIONS(2403),
    [anon_sym_MOD] = ACTIONS(2403),
    [anon_sym_Mod] = ACTIONS(2403),
    [anon_sym_PLUS] = ACTIONS(2403),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_LT_GT] = ACTIONS(2405),
    [anon_sym_and] = ACTIONS(2403),
    [anon_sym_AND] = ACTIONS(2403),
    [anon_sym_And] = ACTIONS(2403),
    [anon_sym_or] = ACTIONS(2403),
    [anon_sym_OR] = ACTIONS(2403),
    [anon_sym_Or] = ACTIONS(2403),
    [anon_sym_xor] = ACTIONS(2403),
    [anon_sym_XOR] = ACTIONS(2403),
    [anon_sym_Xor] = ACTIONS(2403),
    [anon_sym_QMARK] = ACTIONS(2405),
    [sym_datetime_literal] = ACTIONS(2405),
    [sym_date_literal] = ACTIONS(2403),
    [sym_time_literal] = ACTIONS(2403),
    [sym_biginteger_literal] = ACTIONS(2405),
    [anon_sym_else] = ACTIONS(2403),
    [anon_sym_ELSE] = ACTIONS(2403),
    [anon_sym_Else] = ACTIONS(2403),
    [anon_sym_in] = ACTIONS(2403),
    [anon_sym_IN] = ACTIONS(2403),
    [anon_sym_In] = ACTIONS(2403),
    [sym_page_keyword] = ACTIONS(2403),
    [anon_sym_codeunit] = ACTIONS(2403),
    [anon_sym_CODEUNIT] = ACTIONS(2403),
    [anon_sym_Codeunit] = ACTIONS(2403),
    [anon_sym_CodeUnit] = ACTIONS(2403),
    [anon_sym_COdeunit] = ACTIONS(2403),
    [anon_sym_codeUnit] = ACTIONS(2403),
    [sym_report_keyword] = ACTIONS(2403),
    [sym_query_keyword] = ACTIONS(2403),
    [anon_sym_xmlport] = ACTIONS(2403),
    [anon_sym_XMLPORT] = ACTIONS(2403),
    [anon_sym_Xmlport] = ACTIONS(2403),
    [anon_sym_XMLport] = ACTIONS(2403),
    [anon_sym_XMLPort] = ACTIONS(2403),
    [anon_sym_XmlPort] = ACTIONS(2403),
    [anon_sym_enum] = ACTIONS(2403),
    [anon_sym_ENUM] = ACTIONS(2403),
    [anon_sym_Enum] = ACTIONS(2403),
    [anon_sym_eNUM] = ACTIONS(2403),
    [anon_sym_eNum] = ACTIONS(2403),
    [anon_sym_ENum] = ACTIONS(2403),
    [sym_quoted_identifier] = ACTIONS(2405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2405),
    [sym_integer] = ACTIONS(2403),
    [sym_continue_as_identifier] = ACTIONS(2405),
    [sym_preproc_open] = ACTIONS(2405),
  },
  [STATE(2115)] = {
    [sym_identifier] = ACTIONS(2434),
    [anon_sym_SEMI] = ACTIONS(2436),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_COMMA] = ACTIONS(2436),
    [anon_sym_COLON] = ACTIONS(2434),
    [anon_sym_DASH] = ACTIONS(2434),
    [aux_sym_boolean_token1] = ACTIONS(2434),
    [aux_sym_boolean_token2] = ACTIONS(2434),
    [sym_decimal] = ACTIONS(2434),
    [anon_sym_LPAREN] = ACTIONS(2436),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2434),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [aux_sym_record_type_token1] = ACTIONS(2434),
    [aux_sym_basic_type_token21] = ACTIONS(2434),
    [aux_sym_basic_type_token22] = ACTIONS(2434),
    [aux_sym_basic_type_token48] = ACTIONS(2434),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2434),
    [anon_sym_COLON_COLON] = ACTIONS(5337),
    [anon_sym_POUNDif] = ACTIONS(2436),
    [anon_sym_POUNDIF] = ACTIONS(2436),
    [anon_sym_POUNDIf] = ACTIONS(2436),
    [anon_sym_not] = ACTIONS(2434),
    [anon_sym_NOT] = ACTIONS(2434),
    [anon_sym_Not] = ACTIONS(2434),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2434),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2434),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(2434),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(2436),
    [sym_date_literal] = ACTIONS(2434),
    [sym_time_literal] = ACTIONS(2434),
    [sym_biginteger_literal] = ACTIONS(2436),
    [anon_sym_else] = ACTIONS(2434),
    [anon_sym_ELSE] = ACTIONS(2434),
    [anon_sym_Else] = ACTIONS(2434),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(2434),
    [anon_sym_codeunit] = ACTIONS(2434),
    [anon_sym_CODEUNIT] = ACTIONS(2434),
    [anon_sym_Codeunit] = ACTIONS(2434),
    [anon_sym_CodeUnit] = ACTIONS(2434),
    [anon_sym_COdeunit] = ACTIONS(2434),
    [anon_sym_codeUnit] = ACTIONS(2434),
    [sym_report_keyword] = ACTIONS(2434),
    [sym_query_keyword] = ACTIONS(2434),
    [anon_sym_xmlport] = ACTIONS(2434),
    [anon_sym_XMLPORT] = ACTIONS(2434),
    [anon_sym_Xmlport] = ACTIONS(2434),
    [anon_sym_XMLport] = ACTIONS(2434),
    [anon_sym_XMLPort] = ACTIONS(2434),
    [anon_sym_XmlPort] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2434),
    [anon_sym_ENUM] = ACTIONS(2434),
    [anon_sym_Enum] = ACTIONS(2434),
    [anon_sym_eNUM] = ACTIONS(2434),
    [anon_sym_eNum] = ACTIONS(2434),
    [anon_sym_ENum] = ACTIONS(2434),
    [sym_quoted_identifier] = ACTIONS(2436),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2436),
    [sym_integer] = ACTIONS(2434),
    [sym_continue_as_identifier] = ACTIONS(2436),
    [sym_preproc_open] = ACTIONS(2436),
  },
  [STATE(2116)] = {
    [sym_identifier] = ACTIONS(2396),
    [anon_sym_DOT] = ACTIONS(2396),
    [anon_sym_EQ] = ACTIONS(2398),
    [anon_sym_COMMA] = ACTIONS(2398),
    [anon_sym_DASH] = ACTIONS(2396),
    [aux_sym_boolean_token1] = ACTIONS(2396),
    [aux_sym_boolean_token2] = ACTIONS(2396),
    [sym_decimal] = ACTIONS(2396),
    [anon_sym_LPAREN] = ACTIONS(2398),
    [anon_sym_DOT_DOT] = ACTIONS(2398),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2396),
    [anon_sym_STAR] = ACTIONS(2396),
    [anon_sym_LBRACK] = ACTIONS(2398),
    [aux_sym_record_type_token1] = ACTIONS(2396),
    [aux_sym_basic_type_token21] = ACTIONS(2396),
    [aux_sym_basic_type_token22] = ACTIONS(2396),
    [aux_sym_basic_type_token48] = ACTIONS(2396),
    [anon_sym_not] = ACTIONS(2396),
    [anon_sym_NOT] = ACTIONS(2396),
    [anon_sym_Not] = ACTIONS(2396),
    [anon_sym_POUNDelif] = ACTIONS(2398),
    [anon_sym_POUNDELIF] = ACTIONS(2398),
    [anon_sym_POUNDElif] = ACTIONS(2398),
    [anon_sym_POUNDelse] = ACTIONS(2398),
    [anon_sym_POUNDELSE] = ACTIONS(2398),
    [anon_sym_POUNDElse] = ACTIONS(2398),
    [anon_sym_POUNDendif] = ACTIONS(2398),
    [anon_sym_POUNDENDIF] = ACTIONS(2398),
    [anon_sym_POUNDEndif] = ACTIONS(2398),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2398),
    [aux_sym__expression_token1] = ACTIONS(2398),
    [aux_sym__expression_token2] = ACTIONS(2398),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2396),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2396),
    [anon_sym_SLASH] = ACTIONS(2396),
    [anon_sym_div] = ACTIONS(2396),
    [anon_sym_DIV] = ACTIONS(2396),
    [anon_sym_Div] = ACTIONS(2396),
    [anon_sym_mod] = ACTIONS(2396),
    [anon_sym_MOD] = ACTIONS(2396),
    [anon_sym_Mod] = ACTIONS(2396),
    [anon_sym_PLUS] = ACTIONS(2396),
    [anon_sym_GT_EQ] = ACTIONS(2398),
    [anon_sym_LT_EQ] = ACTIONS(2398),
    [anon_sym_GT] = ACTIONS(2396),
    [anon_sym_LT] = ACTIONS(2396),
    [anon_sym_LT_GT] = ACTIONS(2398),
    [anon_sym_and] = ACTIONS(2396),
    [anon_sym_AND] = ACTIONS(2396),
    [anon_sym_And] = ACTIONS(2396),
    [anon_sym_or] = ACTIONS(2396),
    [anon_sym_OR] = ACTIONS(2396),
    [anon_sym_Or] = ACTIONS(2396),
    [anon_sym_xor] = ACTIONS(2396),
    [anon_sym_XOR] = ACTIONS(2396),
    [anon_sym_Xor] = ACTIONS(2396),
    [anon_sym_QMARK] = ACTIONS(2398),
    [sym_datetime_literal] = ACTIONS(2398),
    [sym_date_literal] = ACTIONS(2396),
    [sym_time_literal] = ACTIONS(2396),
    [sym_biginteger_literal] = ACTIONS(2398),
    [anon_sym_in] = ACTIONS(2396),
    [anon_sym_IN] = ACTIONS(2396),
    [anon_sym_In] = ACTIONS(2396),
    [sym_page_keyword] = ACTIONS(2396),
    [anon_sym_codeunit] = ACTIONS(2396),
    [anon_sym_CODEUNIT] = ACTIONS(2396),
    [anon_sym_Codeunit] = ACTIONS(2396),
    [anon_sym_CodeUnit] = ACTIONS(2396),
    [anon_sym_COdeunit] = ACTIONS(2396),
    [anon_sym_codeUnit] = ACTIONS(2396),
    [sym_report_keyword] = ACTIONS(2396),
    [sym_query_keyword] = ACTIONS(2396),
    [anon_sym_xmlport] = ACTIONS(2396),
    [anon_sym_XMLPORT] = ACTIONS(2396),
    [anon_sym_Xmlport] = ACTIONS(2396),
    [anon_sym_XMLport] = ACTIONS(2396),
    [anon_sym_XMLPort] = ACTIONS(2396),
    [anon_sym_XmlPort] = ACTIONS(2396),
    [anon_sym_enum] = ACTIONS(2396),
    [anon_sym_ENUM] = ACTIONS(2396),
    [anon_sym_Enum] = ACTIONS(2396),
    [anon_sym_eNUM] = ACTIONS(2396),
    [anon_sym_eNum] = ACTIONS(2396),
    [anon_sym_ENum] = ACTIONS(2396),
    [sym_temporary_keyword] = ACTIONS(2396),
    [sym_quoted_identifier] = ACTIONS(2398),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2398),
    [sym_integer] = ACTIONS(2396),
    [sym_continue_as_identifier] = ACTIONS(2398),
    [sym_preproc_close] = ACTIONS(2398),
  },
  [STATE(2117)] = {
    [sym_identifier] = ACTIONS(2565),
    [anon_sym_SEMI] = ACTIONS(2567),
    [anon_sym_DOT] = ACTIONS(2565),
    [anon_sym_EQ] = ACTIONS(2567),
    [anon_sym_COMMA] = ACTIONS(2567),
    [anon_sym_COLON] = ACTIONS(2565),
    [anon_sym_DASH] = ACTIONS(2565),
    [aux_sym_boolean_token1] = ACTIONS(2565),
    [aux_sym_boolean_token2] = ACTIONS(2565),
    [sym_decimal] = ACTIONS(2565),
    [anon_sym_LPAREN] = ACTIONS(2567),
    [anon_sym_DOT_DOT] = ACTIONS(2567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2565),
    [anon_sym_STAR] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2567),
    [aux_sym_record_type_token1] = ACTIONS(2565),
    [aux_sym_basic_type_token21] = ACTIONS(2565),
    [aux_sym_basic_type_token22] = ACTIONS(2565),
    [aux_sym_basic_type_token48] = ACTIONS(2565),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_POUNDif] = ACTIONS(2567),
    [anon_sym_POUNDIF] = ACTIONS(2567),
    [anon_sym_POUNDIf] = ACTIONS(2567),
    [anon_sym_not] = ACTIONS(2565),
    [anon_sym_NOT] = ACTIONS(2565),
    [anon_sym_Not] = ACTIONS(2565),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2567),
    [aux_sym__expression_token1] = ACTIONS(2567),
    [aux_sym__expression_token2] = ACTIONS(2567),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2565),
    [anon_sym_SLASH] = ACTIONS(2565),
    [anon_sym_div] = ACTIONS(2565),
    [anon_sym_DIV] = ACTIONS(2565),
    [anon_sym_Div] = ACTIONS(2565),
    [anon_sym_mod] = ACTIONS(2565),
    [anon_sym_MOD] = ACTIONS(2565),
    [anon_sym_Mod] = ACTIONS(2565),
    [anon_sym_PLUS] = ACTIONS(2565),
    [anon_sym_GT_EQ] = ACTIONS(2567),
    [anon_sym_LT_EQ] = ACTIONS(2567),
    [anon_sym_GT] = ACTIONS(2565),
    [anon_sym_LT] = ACTIONS(2565),
    [anon_sym_LT_GT] = ACTIONS(2567),
    [anon_sym_and] = ACTIONS(2565),
    [anon_sym_AND] = ACTIONS(2565),
    [anon_sym_And] = ACTIONS(2565),
    [anon_sym_or] = ACTIONS(2565),
    [anon_sym_OR] = ACTIONS(2565),
    [anon_sym_Or] = ACTIONS(2565),
    [anon_sym_xor] = ACTIONS(2565),
    [anon_sym_XOR] = ACTIONS(2565),
    [anon_sym_Xor] = ACTIONS(2565),
    [anon_sym_QMARK] = ACTIONS(2567),
    [sym_datetime_literal] = ACTIONS(2567),
    [sym_date_literal] = ACTIONS(2565),
    [sym_time_literal] = ACTIONS(2565),
    [sym_biginteger_literal] = ACTIONS(2567),
    [anon_sym_else] = ACTIONS(2565),
    [anon_sym_ELSE] = ACTIONS(2565),
    [anon_sym_Else] = ACTIONS(2565),
    [anon_sym_in] = ACTIONS(2565),
    [anon_sym_IN] = ACTIONS(2565),
    [anon_sym_In] = ACTIONS(2565),
    [sym_page_keyword] = ACTIONS(2565),
    [anon_sym_codeunit] = ACTIONS(2565),
    [anon_sym_CODEUNIT] = ACTIONS(2565),
    [anon_sym_Codeunit] = ACTIONS(2565),
    [anon_sym_CodeUnit] = ACTIONS(2565),
    [anon_sym_COdeunit] = ACTIONS(2565),
    [anon_sym_codeUnit] = ACTIONS(2565),
    [sym_report_keyword] = ACTIONS(2565),
    [sym_query_keyword] = ACTIONS(2565),
    [anon_sym_xmlport] = ACTIONS(2565),
    [anon_sym_XMLPORT] = ACTIONS(2565),
    [anon_sym_Xmlport] = ACTIONS(2565),
    [anon_sym_XMLport] = ACTIONS(2565),
    [anon_sym_XMLPort] = ACTIONS(2565),
    [anon_sym_XmlPort] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_ENUM] = ACTIONS(2565),
    [anon_sym_Enum] = ACTIONS(2565),
    [anon_sym_eNUM] = ACTIONS(2565),
    [anon_sym_eNum] = ACTIONS(2565),
    [anon_sym_ENum] = ACTIONS(2565),
    [sym_quoted_identifier] = ACTIONS(2567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2567),
    [sym_integer] = ACTIONS(2565),
    [sym_continue_as_identifier] = ACTIONS(2567),
    [sym_preproc_open] = ACTIONS(2567),
  },
  [STATE(2118)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2114),
    [sym_identifier] = ACTIONS(2410),
    [anon_sym_SEMI] = ACTIONS(2412),
    [anon_sym_DOT] = ACTIONS(2410),
    [anon_sym_EQ] = ACTIONS(2412),
    [anon_sym_COMMA] = ACTIONS(5413),
    [anon_sym_COLON] = ACTIONS(2410),
    [anon_sym_DASH] = ACTIONS(2410),
    [aux_sym_boolean_token1] = ACTIONS(2410),
    [aux_sym_boolean_token2] = ACTIONS(2410),
    [sym_decimal] = ACTIONS(2410),
    [anon_sym_LPAREN] = ACTIONS(2412),
    [anon_sym_DOT_DOT] = ACTIONS(2412),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2410),
    [anon_sym_STAR] = ACTIONS(2410),
    [anon_sym_LBRACK] = ACTIONS(2412),
    [aux_sym_record_type_token1] = ACTIONS(2410),
    [aux_sym_basic_type_token21] = ACTIONS(2410),
    [aux_sym_basic_type_token22] = ACTIONS(2410),
    [aux_sym_basic_type_token48] = ACTIONS(2410),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2410),
    [anon_sym_POUNDif] = ACTIONS(2412),
    [anon_sym_POUNDIF] = ACTIONS(2412),
    [anon_sym_POUNDIf] = ACTIONS(2412),
    [anon_sym_not] = ACTIONS(2410),
    [anon_sym_NOT] = ACTIONS(2410),
    [anon_sym_Not] = ACTIONS(2410),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2412),
    [aux_sym__expression_token1] = ACTIONS(2412),
    [aux_sym__expression_token2] = ACTIONS(2412),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2410),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2410),
    [anon_sym_SLASH] = ACTIONS(2410),
    [anon_sym_div] = ACTIONS(2410),
    [anon_sym_DIV] = ACTIONS(2410),
    [anon_sym_Div] = ACTIONS(2410),
    [anon_sym_mod] = ACTIONS(2410),
    [anon_sym_MOD] = ACTIONS(2410),
    [anon_sym_Mod] = ACTIONS(2410),
    [anon_sym_PLUS] = ACTIONS(2410),
    [anon_sym_GT_EQ] = ACTIONS(2412),
    [anon_sym_LT_EQ] = ACTIONS(2412),
    [anon_sym_GT] = ACTIONS(2410),
    [anon_sym_LT] = ACTIONS(2410),
    [anon_sym_LT_GT] = ACTIONS(2412),
    [anon_sym_and] = ACTIONS(2410),
    [anon_sym_AND] = ACTIONS(2410),
    [anon_sym_And] = ACTIONS(2410),
    [anon_sym_or] = ACTIONS(2410),
    [anon_sym_OR] = ACTIONS(2410),
    [anon_sym_Or] = ACTIONS(2410),
    [anon_sym_xor] = ACTIONS(2410),
    [anon_sym_XOR] = ACTIONS(2410),
    [anon_sym_Xor] = ACTIONS(2410),
    [anon_sym_QMARK] = ACTIONS(2412),
    [sym_datetime_literal] = ACTIONS(2412),
    [sym_date_literal] = ACTIONS(2410),
    [sym_time_literal] = ACTIONS(2410),
    [sym_biginteger_literal] = ACTIONS(2412),
    [anon_sym_else] = ACTIONS(2410),
    [anon_sym_ELSE] = ACTIONS(2410),
    [anon_sym_Else] = ACTIONS(2410),
    [anon_sym_in] = ACTIONS(2410),
    [anon_sym_IN] = ACTIONS(2410),
    [anon_sym_In] = ACTIONS(2410),
    [sym_page_keyword] = ACTIONS(2410),
    [anon_sym_codeunit] = ACTIONS(2410),
    [anon_sym_CODEUNIT] = ACTIONS(2410),
    [anon_sym_Codeunit] = ACTIONS(2410),
    [anon_sym_CodeUnit] = ACTIONS(2410),
    [anon_sym_COdeunit] = ACTIONS(2410),
    [anon_sym_codeUnit] = ACTIONS(2410),
    [sym_report_keyword] = ACTIONS(2410),
    [sym_query_keyword] = ACTIONS(2410),
    [anon_sym_xmlport] = ACTIONS(2410),
    [anon_sym_XMLPORT] = ACTIONS(2410),
    [anon_sym_Xmlport] = ACTIONS(2410),
    [anon_sym_XMLport] = ACTIONS(2410),
    [anon_sym_XMLPort] = ACTIONS(2410),
    [anon_sym_XmlPort] = ACTIONS(2410),
    [anon_sym_enum] = ACTIONS(2410),
    [anon_sym_ENUM] = ACTIONS(2410),
    [anon_sym_Enum] = ACTIONS(2410),
    [anon_sym_eNUM] = ACTIONS(2410),
    [anon_sym_eNum] = ACTIONS(2410),
    [anon_sym_ENum] = ACTIONS(2410),
    [sym_quoted_identifier] = ACTIONS(2412),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2412),
    [sym_integer] = ACTIONS(2410),
    [sym_continue_as_identifier] = ACTIONS(2412),
    [sym_preproc_open] = ACTIONS(2412),
  },
  [STATE(2119)] = {
    [sym_identifier] = ACTIONS(2533),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym_EQ] = ACTIONS(2535),
    [anon_sym_COMMA] = ACTIONS(2535),
    [anon_sym_DASH] = ACTIONS(2533),
    [aux_sym_boolean_token1] = ACTIONS(2533),
    [aux_sym_boolean_token2] = ACTIONS(2533),
    [sym_decimal] = ACTIONS(2533),
    [anon_sym_LPAREN] = ACTIONS(2535),
    [anon_sym_DOT_DOT] = ACTIONS(2535),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2533),
    [anon_sym_STAR] = ACTIONS(2533),
    [anon_sym_LBRACK] = ACTIONS(2535),
    [aux_sym_record_type_token1] = ACTIONS(2533),
    [aux_sym_basic_type_token21] = ACTIONS(2533),
    [aux_sym_basic_type_token22] = ACTIONS(2533),
    [aux_sym_basic_type_token48] = ACTIONS(2533),
    [anon_sym_not] = ACTIONS(2533),
    [anon_sym_NOT] = ACTIONS(2533),
    [anon_sym_Not] = ACTIONS(2533),
    [anon_sym_POUNDelif] = ACTIONS(2535),
    [anon_sym_POUNDELIF] = ACTIONS(2535),
    [anon_sym_POUNDElif] = ACTIONS(2535),
    [anon_sym_POUNDelse] = ACTIONS(2535),
    [anon_sym_POUNDELSE] = ACTIONS(2535),
    [anon_sym_POUNDElse] = ACTIONS(2535),
    [anon_sym_POUNDendif] = ACTIONS(2535),
    [anon_sym_POUNDENDIF] = ACTIONS(2535),
    [anon_sym_POUNDEndif] = ACTIONS(2535),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2535),
    [aux_sym__expression_token1] = ACTIONS(2535),
    [aux_sym__expression_token2] = ACTIONS(2535),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2533),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2533),
    [anon_sym_SLASH] = ACTIONS(2533),
    [anon_sym_div] = ACTIONS(2533),
    [anon_sym_DIV] = ACTIONS(2533),
    [anon_sym_Div] = ACTIONS(2533),
    [anon_sym_mod] = ACTIONS(2533),
    [anon_sym_MOD] = ACTIONS(2533),
    [anon_sym_Mod] = ACTIONS(2533),
    [anon_sym_PLUS] = ACTIONS(2533),
    [anon_sym_GT_EQ] = ACTIONS(2535),
    [anon_sym_LT_EQ] = ACTIONS(2535),
    [anon_sym_GT] = ACTIONS(2533),
    [anon_sym_LT] = ACTIONS(2533),
    [anon_sym_LT_GT] = ACTIONS(2535),
    [anon_sym_and] = ACTIONS(2533),
    [anon_sym_AND] = ACTIONS(2533),
    [anon_sym_And] = ACTIONS(2533),
    [anon_sym_or] = ACTIONS(2533),
    [anon_sym_OR] = ACTIONS(2533),
    [anon_sym_Or] = ACTIONS(2533),
    [anon_sym_xor] = ACTIONS(2533),
    [anon_sym_XOR] = ACTIONS(2533),
    [anon_sym_Xor] = ACTIONS(2533),
    [anon_sym_QMARK] = ACTIONS(2535),
    [sym_datetime_literal] = ACTIONS(2535),
    [sym_date_literal] = ACTIONS(2533),
    [sym_time_literal] = ACTIONS(2533),
    [sym_biginteger_literal] = ACTIONS(2535),
    [anon_sym_in] = ACTIONS(2533),
    [anon_sym_IN] = ACTIONS(2533),
    [anon_sym_In] = ACTIONS(2533),
    [sym_page_keyword] = ACTIONS(2533),
    [anon_sym_codeunit] = ACTIONS(2533),
    [anon_sym_CODEUNIT] = ACTIONS(2533),
    [anon_sym_Codeunit] = ACTIONS(2533),
    [anon_sym_CodeUnit] = ACTIONS(2533),
    [anon_sym_COdeunit] = ACTIONS(2533),
    [anon_sym_codeUnit] = ACTIONS(2533),
    [sym_report_keyword] = ACTIONS(2533),
    [sym_query_keyword] = ACTIONS(2533),
    [anon_sym_xmlport] = ACTIONS(2533),
    [anon_sym_XMLPORT] = ACTIONS(2533),
    [anon_sym_Xmlport] = ACTIONS(2533),
    [anon_sym_XMLport] = ACTIONS(2533),
    [anon_sym_XMLPort] = ACTIONS(2533),
    [anon_sym_XmlPort] = ACTIONS(2533),
    [anon_sym_enum] = ACTIONS(2533),
    [anon_sym_ENUM] = ACTIONS(2533),
    [anon_sym_Enum] = ACTIONS(2533),
    [anon_sym_eNUM] = ACTIONS(2533),
    [anon_sym_eNum] = ACTIONS(2533),
    [anon_sym_ENum] = ACTIONS(2533),
    [sym_temporary_keyword] = ACTIONS(5424),
    [sym_quoted_identifier] = ACTIONS(2535),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2535),
    [sym_integer] = ACTIONS(2533),
    [sym_continue_as_identifier] = ACTIONS(2535),
    [sym_preproc_close] = ACTIONS(2535),
  },
  [STATE(2120)] = {
    [sym_identifier] = ACTIONS(2517),
    [anon_sym_SEMI] = ACTIONS(2519),
    [anon_sym_DOT] = ACTIONS(2517),
    [anon_sym_EQ] = ACTIONS(2519),
    [anon_sym_COMMA] = ACTIONS(2519),
    [anon_sym_COLON] = ACTIONS(2517),
    [anon_sym_DASH] = ACTIONS(2517),
    [aux_sym_boolean_token1] = ACTIONS(2517),
    [aux_sym_boolean_token2] = ACTIONS(2517),
    [sym_decimal] = ACTIONS(2517),
    [anon_sym_LPAREN] = ACTIONS(2519),
    [anon_sym_DOT_DOT] = ACTIONS(2519),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2517),
    [anon_sym_STAR] = ACTIONS(2517),
    [anon_sym_LBRACK] = ACTIONS(2519),
    [aux_sym_record_type_token1] = ACTIONS(2517),
    [aux_sym_basic_type_token21] = ACTIONS(2517),
    [aux_sym_basic_type_token22] = ACTIONS(2517),
    [aux_sym_basic_type_token48] = ACTIONS(2517),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2517),
    [anon_sym_COLON_COLON] = ACTIONS(2519),
    [anon_sym_POUNDif] = ACTIONS(2519),
    [anon_sym_POUNDIF] = ACTIONS(2519),
    [anon_sym_POUNDIf] = ACTIONS(2519),
    [anon_sym_not] = ACTIONS(2517),
    [anon_sym_NOT] = ACTIONS(2517),
    [anon_sym_Not] = ACTIONS(2517),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2519),
    [aux_sym__expression_token1] = ACTIONS(2519),
    [aux_sym__expression_token2] = ACTIONS(2519),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2517),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2517),
    [anon_sym_SLASH] = ACTIONS(2517),
    [anon_sym_div] = ACTIONS(2517),
    [anon_sym_DIV] = ACTIONS(2517),
    [anon_sym_Div] = ACTIONS(2517),
    [anon_sym_mod] = ACTIONS(2517),
    [anon_sym_MOD] = ACTIONS(2517),
    [anon_sym_Mod] = ACTIONS(2517),
    [anon_sym_PLUS] = ACTIONS(2517),
    [anon_sym_GT_EQ] = ACTIONS(2519),
    [anon_sym_LT_EQ] = ACTIONS(2519),
    [anon_sym_GT] = ACTIONS(2517),
    [anon_sym_LT] = ACTIONS(2517),
    [anon_sym_LT_GT] = ACTIONS(2519),
    [anon_sym_and] = ACTIONS(2517),
    [anon_sym_AND] = ACTIONS(2517),
    [anon_sym_And] = ACTIONS(2517),
    [anon_sym_or] = ACTIONS(2517),
    [anon_sym_OR] = ACTIONS(2517),
    [anon_sym_Or] = ACTIONS(2517),
    [anon_sym_xor] = ACTIONS(2517),
    [anon_sym_XOR] = ACTIONS(2517),
    [anon_sym_Xor] = ACTIONS(2517),
    [anon_sym_QMARK] = ACTIONS(2519),
    [sym_datetime_literal] = ACTIONS(2519),
    [sym_date_literal] = ACTIONS(2517),
    [sym_time_literal] = ACTIONS(2517),
    [sym_biginteger_literal] = ACTIONS(2519),
    [anon_sym_else] = ACTIONS(2517),
    [anon_sym_ELSE] = ACTIONS(2517),
    [anon_sym_Else] = ACTIONS(2517),
    [anon_sym_in] = ACTIONS(2517),
    [anon_sym_IN] = ACTIONS(2517),
    [anon_sym_In] = ACTIONS(2517),
    [sym_page_keyword] = ACTIONS(2517),
    [anon_sym_codeunit] = ACTIONS(2517),
    [anon_sym_CODEUNIT] = ACTIONS(2517),
    [anon_sym_Codeunit] = ACTIONS(2517),
    [anon_sym_CodeUnit] = ACTIONS(2517),
    [anon_sym_COdeunit] = ACTIONS(2517),
    [anon_sym_codeUnit] = ACTIONS(2517),
    [sym_report_keyword] = ACTIONS(2517),
    [sym_query_keyword] = ACTIONS(2517),
    [anon_sym_xmlport] = ACTIONS(2517),
    [anon_sym_XMLPORT] = ACTIONS(2517),
    [anon_sym_Xmlport] = ACTIONS(2517),
    [anon_sym_XMLport] = ACTIONS(2517),
    [anon_sym_XMLPort] = ACTIONS(2517),
    [anon_sym_XmlPort] = ACTIONS(2517),
    [anon_sym_enum] = ACTIONS(2517),
    [anon_sym_ENUM] = ACTIONS(2517),
    [anon_sym_Enum] = ACTIONS(2517),
    [anon_sym_eNUM] = ACTIONS(2517),
    [anon_sym_eNum] = ACTIONS(2517),
    [anon_sym_ENum] = ACTIONS(2517),
    [sym_quoted_identifier] = ACTIONS(2519),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2519),
    [sym_integer] = ACTIONS(2517),
    [sym_continue_as_identifier] = ACTIONS(2519),
    [sym_preproc_open] = ACTIONS(2519),
  },
  [STATE(2121)] = {
    [sym_identifier] = ACTIONS(2414),
    [anon_sym_DOT] = ACTIONS(2414),
    [anon_sym_EQ] = ACTIONS(2416),
    [anon_sym_COMMA] = ACTIONS(2416),
    [anon_sym_DASH] = ACTIONS(2414),
    [aux_sym_boolean_token1] = ACTIONS(2414),
    [aux_sym_boolean_token2] = ACTIONS(2414),
    [sym_decimal] = ACTIONS(2414),
    [anon_sym_LPAREN] = ACTIONS(2416),
    [anon_sym_DOT_DOT] = ACTIONS(2416),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2414),
    [anon_sym_STAR] = ACTIONS(2414),
    [anon_sym_LBRACK] = ACTIONS(2416),
    [aux_sym_record_type_token1] = ACTIONS(2414),
    [aux_sym_basic_type_token21] = ACTIONS(2414),
    [aux_sym_basic_type_token22] = ACTIONS(2414),
    [aux_sym_basic_type_token48] = ACTIONS(2414),
    [anon_sym_COLON_COLON] = ACTIONS(2416),
    [anon_sym_not] = ACTIONS(2414),
    [anon_sym_NOT] = ACTIONS(2414),
    [anon_sym_Not] = ACTIONS(2414),
    [anon_sym_POUNDelif] = ACTIONS(2416),
    [anon_sym_POUNDELIF] = ACTIONS(2416),
    [anon_sym_POUNDElif] = ACTIONS(2416),
    [anon_sym_POUNDelse] = ACTIONS(2416),
    [anon_sym_POUNDELSE] = ACTIONS(2416),
    [anon_sym_POUNDElse] = ACTIONS(2416),
    [anon_sym_POUNDendif] = ACTIONS(2416),
    [anon_sym_POUNDENDIF] = ACTIONS(2416),
    [anon_sym_POUNDEndif] = ACTIONS(2416),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2416),
    [aux_sym__expression_token1] = ACTIONS(2416),
    [aux_sym__expression_token2] = ACTIONS(2416),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2414),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2414),
    [anon_sym_SLASH] = ACTIONS(2414),
    [anon_sym_div] = ACTIONS(2414),
    [anon_sym_DIV] = ACTIONS(2414),
    [anon_sym_Div] = ACTIONS(2414),
    [anon_sym_mod] = ACTIONS(2414),
    [anon_sym_MOD] = ACTIONS(2414),
    [anon_sym_Mod] = ACTIONS(2414),
    [anon_sym_PLUS] = ACTIONS(2414),
    [anon_sym_GT_EQ] = ACTIONS(2416),
    [anon_sym_LT_EQ] = ACTIONS(2416),
    [anon_sym_GT] = ACTIONS(2414),
    [anon_sym_LT] = ACTIONS(2414),
    [anon_sym_LT_GT] = ACTIONS(2416),
    [anon_sym_and] = ACTIONS(2414),
    [anon_sym_AND] = ACTIONS(2414),
    [anon_sym_And] = ACTIONS(2414),
    [anon_sym_or] = ACTIONS(2414),
    [anon_sym_OR] = ACTIONS(2414),
    [anon_sym_Or] = ACTIONS(2414),
    [anon_sym_xor] = ACTIONS(2414),
    [anon_sym_XOR] = ACTIONS(2414),
    [anon_sym_Xor] = ACTIONS(2414),
    [anon_sym_QMARK] = ACTIONS(2416),
    [sym_datetime_literal] = ACTIONS(2416),
    [sym_date_literal] = ACTIONS(2414),
    [sym_time_literal] = ACTIONS(2414),
    [sym_biginteger_literal] = ACTIONS(2416),
    [anon_sym_in] = ACTIONS(2414),
    [anon_sym_IN] = ACTIONS(2414),
    [anon_sym_In] = ACTIONS(2414),
    [sym_page_keyword] = ACTIONS(2414),
    [anon_sym_codeunit] = ACTIONS(2414),
    [anon_sym_CODEUNIT] = ACTIONS(2414),
    [anon_sym_Codeunit] = ACTIONS(2414),
    [anon_sym_CodeUnit] = ACTIONS(2414),
    [anon_sym_COdeunit] = ACTIONS(2414),
    [anon_sym_codeUnit] = ACTIONS(2414),
    [sym_report_keyword] = ACTIONS(2414),
    [sym_query_keyword] = ACTIONS(2414),
    [anon_sym_xmlport] = ACTIONS(2414),
    [anon_sym_XMLPORT] = ACTIONS(2414),
    [anon_sym_Xmlport] = ACTIONS(2414),
    [anon_sym_XMLport] = ACTIONS(2414),
    [anon_sym_XMLPort] = ACTIONS(2414),
    [anon_sym_XmlPort] = ACTIONS(2414),
    [anon_sym_enum] = ACTIONS(2414),
    [anon_sym_ENUM] = ACTIONS(2414),
    [anon_sym_Enum] = ACTIONS(2414),
    [anon_sym_eNUM] = ACTIONS(2414),
    [anon_sym_eNum] = ACTIONS(2414),
    [anon_sym_ENum] = ACTIONS(2414),
    [sym_quoted_identifier] = ACTIONS(2416),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2416),
    [sym_integer] = ACTIONS(2414),
    [sym_continue_as_identifier] = ACTIONS(2416),
    [sym_preproc_close] = ACTIONS(2416),
  },
  [STATE(2122)] = {
    [sym_identifier] = ACTIONS(2418),
    [anon_sym_DOT] = ACTIONS(2418),
    [anon_sym_EQ] = ACTIONS(2420),
    [anon_sym_COMMA] = ACTIONS(2420),
    [anon_sym_DASH] = ACTIONS(2418),
    [aux_sym_boolean_token1] = ACTIONS(2418),
    [aux_sym_boolean_token2] = ACTIONS(2418),
    [sym_decimal] = ACTIONS(2418),
    [anon_sym_LPAREN] = ACTIONS(2420),
    [anon_sym_DOT_DOT] = ACTIONS(2420),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2418),
    [anon_sym_STAR] = ACTIONS(2418),
    [anon_sym_LBRACK] = ACTIONS(2420),
    [aux_sym_record_type_token1] = ACTIONS(2418),
    [aux_sym_basic_type_token21] = ACTIONS(2418),
    [aux_sym_basic_type_token22] = ACTIONS(2418),
    [aux_sym_basic_type_token48] = ACTIONS(2418),
    [anon_sym_COLON_COLON] = ACTIONS(2420),
    [anon_sym_not] = ACTIONS(2418),
    [anon_sym_NOT] = ACTIONS(2418),
    [anon_sym_Not] = ACTIONS(2418),
    [anon_sym_POUNDelif] = ACTIONS(2420),
    [anon_sym_POUNDELIF] = ACTIONS(2420),
    [anon_sym_POUNDElif] = ACTIONS(2420),
    [anon_sym_POUNDelse] = ACTIONS(2420),
    [anon_sym_POUNDELSE] = ACTIONS(2420),
    [anon_sym_POUNDElse] = ACTIONS(2420),
    [anon_sym_POUNDendif] = ACTIONS(2420),
    [anon_sym_POUNDENDIF] = ACTIONS(2420),
    [anon_sym_POUNDEndif] = ACTIONS(2420),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2420),
    [aux_sym__expression_token1] = ACTIONS(2420),
    [aux_sym__expression_token2] = ACTIONS(2420),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2418),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2418),
    [anon_sym_SLASH] = ACTIONS(2418),
    [anon_sym_div] = ACTIONS(2418),
    [anon_sym_DIV] = ACTIONS(2418),
    [anon_sym_Div] = ACTIONS(2418),
    [anon_sym_mod] = ACTIONS(2418),
    [anon_sym_MOD] = ACTIONS(2418),
    [anon_sym_Mod] = ACTIONS(2418),
    [anon_sym_PLUS] = ACTIONS(2418),
    [anon_sym_GT_EQ] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(2420),
    [anon_sym_GT] = ACTIONS(2418),
    [anon_sym_LT] = ACTIONS(2418),
    [anon_sym_LT_GT] = ACTIONS(2420),
    [anon_sym_and] = ACTIONS(2418),
    [anon_sym_AND] = ACTIONS(2418),
    [anon_sym_And] = ACTIONS(2418),
    [anon_sym_or] = ACTIONS(2418),
    [anon_sym_OR] = ACTIONS(2418),
    [anon_sym_Or] = ACTIONS(2418),
    [anon_sym_xor] = ACTIONS(2418),
    [anon_sym_XOR] = ACTIONS(2418),
    [anon_sym_Xor] = ACTIONS(2418),
    [anon_sym_QMARK] = ACTIONS(2420),
    [sym_datetime_literal] = ACTIONS(2420),
    [sym_date_literal] = ACTIONS(2418),
    [sym_time_literal] = ACTIONS(2418),
    [sym_biginteger_literal] = ACTIONS(2420),
    [anon_sym_in] = ACTIONS(2418),
    [anon_sym_IN] = ACTIONS(2418),
    [anon_sym_In] = ACTIONS(2418),
    [sym_page_keyword] = ACTIONS(2418),
    [anon_sym_codeunit] = ACTIONS(2418),
    [anon_sym_CODEUNIT] = ACTIONS(2418),
    [anon_sym_Codeunit] = ACTIONS(2418),
    [anon_sym_CodeUnit] = ACTIONS(2418),
    [anon_sym_COdeunit] = ACTIONS(2418),
    [anon_sym_codeUnit] = ACTIONS(2418),
    [sym_report_keyword] = ACTIONS(2418),
    [sym_query_keyword] = ACTIONS(2418),
    [anon_sym_xmlport] = ACTIONS(2418),
    [anon_sym_XMLPORT] = ACTIONS(2418),
    [anon_sym_Xmlport] = ACTIONS(2418),
    [anon_sym_XMLport] = ACTIONS(2418),
    [anon_sym_XMLPort] = ACTIONS(2418),
    [anon_sym_XmlPort] = ACTIONS(2418),
    [anon_sym_enum] = ACTIONS(2418),
    [anon_sym_ENUM] = ACTIONS(2418),
    [anon_sym_Enum] = ACTIONS(2418),
    [anon_sym_eNUM] = ACTIONS(2418),
    [anon_sym_eNum] = ACTIONS(2418),
    [anon_sym_ENum] = ACTIONS(2418),
    [sym_quoted_identifier] = ACTIONS(2420),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2420),
    [sym_integer] = ACTIONS(2418),
    [sym_continue_as_identifier] = ACTIONS(2420),
    [sym_preproc_close] = ACTIONS(2420),
  },
  [STATE(2123)] = {
    [sym_identifier] = ACTIONS(2422),
    [anon_sym_DOT] = ACTIONS(2422),
    [anon_sym_EQ] = ACTIONS(2424),
    [anon_sym_COMMA] = ACTIONS(2424),
    [anon_sym_DASH] = ACTIONS(2422),
    [aux_sym_boolean_token1] = ACTIONS(2422),
    [aux_sym_boolean_token2] = ACTIONS(2422),
    [sym_decimal] = ACTIONS(2422),
    [anon_sym_LPAREN] = ACTIONS(2424),
    [anon_sym_DOT_DOT] = ACTIONS(2424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2422),
    [anon_sym_STAR] = ACTIONS(2422),
    [anon_sym_LBRACK] = ACTIONS(2424),
    [aux_sym_record_type_token1] = ACTIONS(2422),
    [aux_sym_basic_type_token21] = ACTIONS(2422),
    [aux_sym_basic_type_token22] = ACTIONS(2422),
    [aux_sym_basic_type_token48] = ACTIONS(2422),
    [anon_sym_COLON_COLON] = ACTIONS(2424),
    [anon_sym_not] = ACTIONS(2422),
    [anon_sym_NOT] = ACTIONS(2422),
    [anon_sym_Not] = ACTIONS(2422),
    [anon_sym_POUNDelif] = ACTIONS(2424),
    [anon_sym_POUNDELIF] = ACTIONS(2424),
    [anon_sym_POUNDElif] = ACTIONS(2424),
    [anon_sym_POUNDelse] = ACTIONS(2424),
    [anon_sym_POUNDELSE] = ACTIONS(2424),
    [anon_sym_POUNDElse] = ACTIONS(2424),
    [anon_sym_POUNDendif] = ACTIONS(2424),
    [anon_sym_POUNDENDIF] = ACTIONS(2424),
    [anon_sym_POUNDEndif] = ACTIONS(2424),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2424),
    [aux_sym__expression_token1] = ACTIONS(2424),
    [aux_sym__expression_token2] = ACTIONS(2424),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2422),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2422),
    [anon_sym_SLASH] = ACTIONS(2422),
    [anon_sym_div] = ACTIONS(2422),
    [anon_sym_DIV] = ACTIONS(2422),
    [anon_sym_Div] = ACTIONS(2422),
    [anon_sym_mod] = ACTIONS(2422),
    [anon_sym_MOD] = ACTIONS(2422),
    [anon_sym_Mod] = ACTIONS(2422),
    [anon_sym_PLUS] = ACTIONS(2422),
    [anon_sym_GT_EQ] = ACTIONS(2424),
    [anon_sym_LT_EQ] = ACTIONS(2424),
    [anon_sym_GT] = ACTIONS(2422),
    [anon_sym_LT] = ACTIONS(2422),
    [anon_sym_LT_GT] = ACTIONS(2424),
    [anon_sym_and] = ACTIONS(2422),
    [anon_sym_AND] = ACTIONS(2422),
    [anon_sym_And] = ACTIONS(2422),
    [anon_sym_or] = ACTIONS(2422),
    [anon_sym_OR] = ACTIONS(2422),
    [anon_sym_Or] = ACTIONS(2422),
    [anon_sym_xor] = ACTIONS(2422),
    [anon_sym_XOR] = ACTIONS(2422),
    [anon_sym_Xor] = ACTIONS(2422),
    [anon_sym_QMARK] = ACTIONS(2424),
    [sym_datetime_literal] = ACTIONS(2424),
    [sym_date_literal] = ACTIONS(2422),
    [sym_time_literal] = ACTIONS(2422),
    [sym_biginteger_literal] = ACTIONS(2424),
    [anon_sym_in] = ACTIONS(2422),
    [anon_sym_IN] = ACTIONS(2422),
    [anon_sym_In] = ACTIONS(2422),
    [sym_page_keyword] = ACTIONS(2422),
    [anon_sym_codeunit] = ACTIONS(2422),
    [anon_sym_CODEUNIT] = ACTIONS(2422),
    [anon_sym_Codeunit] = ACTIONS(2422),
    [anon_sym_CodeUnit] = ACTIONS(2422),
    [anon_sym_COdeunit] = ACTIONS(2422),
    [anon_sym_codeUnit] = ACTIONS(2422),
    [sym_report_keyword] = ACTIONS(2422),
    [sym_query_keyword] = ACTIONS(2422),
    [anon_sym_xmlport] = ACTIONS(2422),
    [anon_sym_XMLPORT] = ACTIONS(2422),
    [anon_sym_Xmlport] = ACTIONS(2422),
    [anon_sym_XMLport] = ACTIONS(2422),
    [anon_sym_XMLPort] = ACTIONS(2422),
    [anon_sym_XmlPort] = ACTIONS(2422),
    [anon_sym_enum] = ACTIONS(2422),
    [anon_sym_ENUM] = ACTIONS(2422),
    [anon_sym_Enum] = ACTIONS(2422),
    [anon_sym_eNUM] = ACTIONS(2422),
    [anon_sym_eNum] = ACTIONS(2422),
    [anon_sym_ENum] = ACTIONS(2422),
    [sym_quoted_identifier] = ACTIONS(2424),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2424),
    [sym_integer] = ACTIONS(2422),
    [sym_continue_as_identifier] = ACTIONS(2424),
    [sym_preproc_close] = ACTIONS(2424),
  },
  [STATE(2124)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_COMMA] = ACTIONS(2428),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [anon_sym_COLON_COLON] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [anon_sym_POUNDelif] = ACTIONS(2428),
    [anon_sym_POUNDELIF] = ACTIONS(2428),
    [anon_sym_POUNDElif] = ACTIONS(2428),
    [anon_sym_POUNDelse] = ACTIONS(2428),
    [anon_sym_POUNDELSE] = ACTIONS(2428),
    [anon_sym_POUNDElse] = ACTIONS(2428),
    [anon_sym_POUNDendif] = ACTIONS(2428),
    [anon_sym_POUNDENDIF] = ACTIONS(2428),
    [anon_sym_POUNDEndif] = ACTIONS(2428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2428),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_close] = ACTIONS(2428),
  },
  [STATE(2125)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2128),
    [sym_identifier] = ACTIONS(2354),
    [anon_sym_DOT] = ACTIONS(2354),
    [anon_sym_EQ] = ACTIONS(2356),
    [anon_sym_COMMA] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(2354),
    [aux_sym_boolean_token1] = ACTIONS(2354),
    [aux_sym_boolean_token2] = ACTIONS(2354),
    [sym_decimal] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(2356),
    [anon_sym_DOT_DOT] = ACTIONS(2356),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2354),
    [anon_sym_STAR] = ACTIONS(2354),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [aux_sym_record_type_token1] = ACTIONS(2354),
    [aux_sym_basic_type_token21] = ACTIONS(2354),
    [aux_sym_basic_type_token22] = ACTIONS(2354),
    [aux_sym_basic_type_token48] = ACTIONS(2354),
    [anon_sym_not] = ACTIONS(2354),
    [anon_sym_NOT] = ACTIONS(2354),
    [anon_sym_Not] = ACTIONS(2354),
    [anon_sym_POUNDelif] = ACTIONS(2356),
    [anon_sym_POUNDELIF] = ACTIONS(2356),
    [anon_sym_POUNDElif] = ACTIONS(2356),
    [anon_sym_POUNDelse] = ACTIONS(2356),
    [anon_sym_POUNDELSE] = ACTIONS(2356),
    [anon_sym_POUNDElse] = ACTIONS(2356),
    [anon_sym_POUNDendif] = ACTIONS(2356),
    [anon_sym_POUNDENDIF] = ACTIONS(2356),
    [anon_sym_POUNDEndif] = ACTIONS(2356),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2356),
    [aux_sym__expression_token1] = ACTIONS(2356),
    [aux_sym__expression_token2] = ACTIONS(2356),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2354),
    [anon_sym_SLASH] = ACTIONS(2354),
    [anon_sym_div] = ACTIONS(2354),
    [anon_sym_DIV] = ACTIONS(2354),
    [anon_sym_Div] = ACTIONS(2354),
    [anon_sym_mod] = ACTIONS(2354),
    [anon_sym_MOD] = ACTIONS(2354),
    [anon_sym_Mod] = ACTIONS(2354),
    [anon_sym_PLUS] = ACTIONS(2354),
    [anon_sym_GT_EQ] = ACTIONS(2356),
    [anon_sym_LT_EQ] = ACTIONS(2356),
    [anon_sym_GT] = ACTIONS(2354),
    [anon_sym_LT] = ACTIONS(2354),
    [anon_sym_LT_GT] = ACTIONS(2356),
    [anon_sym_and] = ACTIONS(2354),
    [anon_sym_AND] = ACTIONS(2354),
    [anon_sym_And] = ACTIONS(2354),
    [anon_sym_or] = ACTIONS(2354),
    [anon_sym_OR] = ACTIONS(2354),
    [anon_sym_Or] = ACTIONS(2354),
    [anon_sym_xor] = ACTIONS(2354),
    [anon_sym_XOR] = ACTIONS(2354),
    [anon_sym_Xor] = ACTIONS(2354),
    [anon_sym_QMARK] = ACTIONS(2356),
    [sym_datetime_literal] = ACTIONS(2356),
    [sym_date_literal] = ACTIONS(2354),
    [sym_time_literal] = ACTIONS(2354),
    [sym_biginteger_literal] = ACTIONS(2356),
    [anon_sym_in] = ACTIONS(2354),
    [anon_sym_IN] = ACTIONS(2354),
    [anon_sym_In] = ACTIONS(2354),
    [sym_page_keyword] = ACTIONS(2354),
    [anon_sym_codeunit] = ACTIONS(2354),
    [anon_sym_CODEUNIT] = ACTIONS(2354),
    [anon_sym_Codeunit] = ACTIONS(2354),
    [anon_sym_CodeUnit] = ACTIONS(2354),
    [anon_sym_COdeunit] = ACTIONS(2354),
    [anon_sym_codeUnit] = ACTIONS(2354),
    [sym_report_keyword] = ACTIONS(2354),
    [sym_query_keyword] = ACTIONS(2354),
    [anon_sym_xmlport] = ACTIONS(2354),
    [anon_sym_XMLPORT] = ACTIONS(2354),
    [anon_sym_Xmlport] = ACTIONS(2354),
    [anon_sym_XMLport] = ACTIONS(2354),
    [anon_sym_XMLPort] = ACTIONS(2354),
    [anon_sym_XmlPort] = ACTIONS(2354),
    [anon_sym_enum] = ACTIONS(2354),
    [anon_sym_ENUM] = ACTIONS(2354),
    [anon_sym_Enum] = ACTIONS(2354),
    [anon_sym_eNUM] = ACTIONS(2354),
    [anon_sym_eNum] = ACTIONS(2354),
    [anon_sym_ENum] = ACTIONS(2354),
    [sym_quoted_identifier] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2356),
    [sym_integer] = ACTIONS(2354),
    [sym_continue_as_identifier] = ACTIONS(2356),
    [sym_preproc_close] = ACTIONS(2356),
  },
  [STATE(2126)] = {
    [sym_identifier] = ACTIONS(2543),
    [anon_sym_DOT] = ACTIONS(2543),
    [anon_sym_EQ] = ACTIONS(2545),
    [anon_sym_COMMA] = ACTIONS(2545),
    [anon_sym_DASH] = ACTIONS(2543),
    [aux_sym_boolean_token1] = ACTIONS(2543),
    [aux_sym_boolean_token2] = ACTIONS(2543),
    [sym_decimal] = ACTIONS(2543),
    [anon_sym_LPAREN] = ACTIONS(2545),
    [anon_sym_DOT_DOT] = ACTIONS(2545),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2543),
    [anon_sym_STAR] = ACTIONS(2543),
    [anon_sym_LBRACK] = ACTIONS(2545),
    [aux_sym_record_type_token1] = ACTIONS(2543),
    [aux_sym_basic_type_token21] = ACTIONS(2543),
    [aux_sym_basic_type_token22] = ACTIONS(2543),
    [aux_sym_basic_type_token48] = ACTIONS(2543),
    [anon_sym_COLON_COLON] = ACTIONS(2545),
    [anon_sym_not] = ACTIONS(2543),
    [anon_sym_NOT] = ACTIONS(2543),
    [anon_sym_Not] = ACTIONS(2543),
    [anon_sym_POUNDelif] = ACTIONS(2545),
    [anon_sym_POUNDELIF] = ACTIONS(2545),
    [anon_sym_POUNDElif] = ACTIONS(2545),
    [anon_sym_POUNDelse] = ACTIONS(2545),
    [anon_sym_POUNDELSE] = ACTIONS(2545),
    [anon_sym_POUNDElse] = ACTIONS(2545),
    [anon_sym_POUNDendif] = ACTIONS(2545),
    [anon_sym_POUNDENDIF] = ACTIONS(2545),
    [anon_sym_POUNDEndif] = ACTIONS(2545),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2545),
    [aux_sym__expression_token1] = ACTIONS(2545),
    [aux_sym__expression_token2] = ACTIONS(2545),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2543),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2543),
    [anon_sym_SLASH] = ACTIONS(2543),
    [anon_sym_div] = ACTIONS(2543),
    [anon_sym_DIV] = ACTIONS(2543),
    [anon_sym_Div] = ACTIONS(2543),
    [anon_sym_mod] = ACTIONS(2543),
    [anon_sym_MOD] = ACTIONS(2543),
    [anon_sym_Mod] = ACTIONS(2543),
    [anon_sym_PLUS] = ACTIONS(2543),
    [anon_sym_GT_EQ] = ACTIONS(2545),
    [anon_sym_LT_EQ] = ACTIONS(2545),
    [anon_sym_GT] = ACTIONS(2543),
    [anon_sym_LT] = ACTIONS(2543),
    [anon_sym_LT_GT] = ACTIONS(2545),
    [anon_sym_and] = ACTIONS(2543),
    [anon_sym_AND] = ACTIONS(2543),
    [anon_sym_And] = ACTIONS(2543),
    [anon_sym_or] = ACTIONS(2543),
    [anon_sym_OR] = ACTIONS(2543),
    [anon_sym_Or] = ACTIONS(2543),
    [anon_sym_xor] = ACTIONS(2543),
    [anon_sym_XOR] = ACTIONS(2543),
    [anon_sym_Xor] = ACTIONS(2543),
    [anon_sym_QMARK] = ACTIONS(2545),
    [sym_datetime_literal] = ACTIONS(2545),
    [sym_date_literal] = ACTIONS(2543),
    [sym_time_literal] = ACTIONS(2543),
    [sym_biginteger_literal] = ACTIONS(2545),
    [anon_sym_in] = ACTIONS(2543),
    [anon_sym_IN] = ACTIONS(2543),
    [anon_sym_In] = ACTIONS(2543),
    [sym_page_keyword] = ACTIONS(2543),
    [anon_sym_codeunit] = ACTIONS(2543),
    [anon_sym_CODEUNIT] = ACTIONS(2543),
    [anon_sym_Codeunit] = ACTIONS(2543),
    [anon_sym_CodeUnit] = ACTIONS(2543),
    [anon_sym_COdeunit] = ACTIONS(2543),
    [anon_sym_codeUnit] = ACTIONS(2543),
    [sym_report_keyword] = ACTIONS(2543),
    [sym_query_keyword] = ACTIONS(2543),
    [anon_sym_xmlport] = ACTIONS(2543),
    [anon_sym_XMLPORT] = ACTIONS(2543),
    [anon_sym_Xmlport] = ACTIONS(2543),
    [anon_sym_XMLport] = ACTIONS(2543),
    [anon_sym_XMLPort] = ACTIONS(2543),
    [anon_sym_XmlPort] = ACTIONS(2543),
    [anon_sym_enum] = ACTIONS(2543),
    [anon_sym_ENUM] = ACTIONS(2543),
    [anon_sym_Enum] = ACTIONS(2543),
    [anon_sym_eNUM] = ACTIONS(2543),
    [anon_sym_eNum] = ACTIONS(2543),
    [anon_sym_ENum] = ACTIONS(2543),
    [sym_quoted_identifier] = ACTIONS(2545),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2545),
    [sym_integer] = ACTIONS(2543),
    [sym_continue_as_identifier] = ACTIONS(2545),
    [sym_preproc_close] = ACTIONS(2545),
  },
  [STATE(2127)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2131),
    [sym_identifier] = ACTIONS(2354),
    [anon_sym_DOT] = ACTIONS(2354),
    [anon_sym_EQ] = ACTIONS(2356),
    [anon_sym_COMMA] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(2354),
    [aux_sym_boolean_token1] = ACTIONS(2354),
    [aux_sym_boolean_token2] = ACTIONS(2354),
    [sym_decimal] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(2356),
    [anon_sym_DOT_DOT] = ACTIONS(2356),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2354),
    [anon_sym_STAR] = ACTIONS(2354),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [aux_sym_record_type_token1] = ACTIONS(2354),
    [aux_sym_basic_type_token21] = ACTIONS(2354),
    [aux_sym_basic_type_token22] = ACTIONS(2354),
    [aux_sym_basic_type_token48] = ACTIONS(2354),
    [anon_sym_not] = ACTIONS(2354),
    [anon_sym_NOT] = ACTIONS(2354),
    [anon_sym_Not] = ACTIONS(2354),
    [anon_sym_POUNDelif] = ACTIONS(2356),
    [anon_sym_POUNDELIF] = ACTIONS(2356),
    [anon_sym_POUNDElif] = ACTIONS(2356),
    [anon_sym_POUNDelse] = ACTIONS(2356),
    [anon_sym_POUNDELSE] = ACTIONS(2356),
    [anon_sym_POUNDElse] = ACTIONS(2356),
    [anon_sym_POUNDendif] = ACTIONS(2356),
    [anon_sym_POUNDENDIF] = ACTIONS(2356),
    [anon_sym_POUNDEndif] = ACTIONS(2356),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2356),
    [aux_sym__expression_token1] = ACTIONS(2356),
    [aux_sym__expression_token2] = ACTIONS(2356),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2354),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2354),
    [anon_sym_SLASH] = ACTIONS(2354),
    [anon_sym_div] = ACTIONS(2354),
    [anon_sym_DIV] = ACTIONS(2354),
    [anon_sym_Div] = ACTIONS(2354),
    [anon_sym_mod] = ACTIONS(2354),
    [anon_sym_MOD] = ACTIONS(2354),
    [anon_sym_Mod] = ACTIONS(2354),
    [anon_sym_PLUS] = ACTIONS(2354),
    [anon_sym_GT_EQ] = ACTIONS(2356),
    [anon_sym_LT_EQ] = ACTIONS(2356),
    [anon_sym_GT] = ACTIONS(2354),
    [anon_sym_LT] = ACTIONS(2354),
    [anon_sym_LT_GT] = ACTIONS(2356),
    [anon_sym_and] = ACTIONS(2354),
    [anon_sym_AND] = ACTIONS(2354),
    [anon_sym_And] = ACTIONS(2354),
    [anon_sym_or] = ACTIONS(2354),
    [anon_sym_OR] = ACTIONS(2354),
    [anon_sym_Or] = ACTIONS(2354),
    [anon_sym_xor] = ACTIONS(2354),
    [anon_sym_XOR] = ACTIONS(2354),
    [anon_sym_Xor] = ACTIONS(2354),
    [anon_sym_QMARK] = ACTIONS(2356),
    [sym_datetime_literal] = ACTIONS(2356),
    [sym_date_literal] = ACTIONS(2354),
    [sym_time_literal] = ACTIONS(2354),
    [sym_biginteger_literal] = ACTIONS(2356),
    [anon_sym_in] = ACTIONS(2354),
    [anon_sym_IN] = ACTIONS(2354),
    [anon_sym_In] = ACTIONS(2354),
    [sym_page_keyword] = ACTIONS(2354),
    [anon_sym_codeunit] = ACTIONS(2354),
    [anon_sym_CODEUNIT] = ACTIONS(2354),
    [anon_sym_Codeunit] = ACTIONS(2354),
    [anon_sym_CodeUnit] = ACTIONS(2354),
    [anon_sym_COdeunit] = ACTIONS(2354),
    [anon_sym_codeUnit] = ACTIONS(2354),
    [sym_report_keyword] = ACTIONS(2354),
    [sym_query_keyword] = ACTIONS(2354),
    [anon_sym_xmlport] = ACTIONS(2354),
    [anon_sym_XMLPORT] = ACTIONS(2354),
    [anon_sym_Xmlport] = ACTIONS(2354),
    [anon_sym_XMLport] = ACTIONS(2354),
    [anon_sym_XMLPort] = ACTIONS(2354),
    [anon_sym_XmlPort] = ACTIONS(2354),
    [anon_sym_enum] = ACTIONS(2354),
    [anon_sym_ENUM] = ACTIONS(2354),
    [anon_sym_Enum] = ACTIONS(2354),
    [anon_sym_eNUM] = ACTIONS(2354),
    [anon_sym_eNum] = ACTIONS(2354),
    [anon_sym_ENum] = ACTIONS(2354),
    [sym_quoted_identifier] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2356),
    [sym_integer] = ACTIONS(2354),
    [sym_continue_as_identifier] = ACTIONS(2356),
    [sym_preproc_close] = ACTIONS(2356),
  },
  [STATE(2128)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2128),
    [sym_identifier] = ACTIONS(2403),
    [anon_sym_DOT] = ACTIONS(2403),
    [anon_sym_EQ] = ACTIONS(2405),
    [anon_sym_COMMA] = ACTIONS(5426),
    [anon_sym_DASH] = ACTIONS(2403),
    [aux_sym_boolean_token1] = ACTIONS(2403),
    [aux_sym_boolean_token2] = ACTIONS(2403),
    [sym_decimal] = ACTIONS(2403),
    [anon_sym_LPAREN] = ACTIONS(2405),
    [anon_sym_DOT_DOT] = ACTIONS(2405),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2403),
    [anon_sym_STAR] = ACTIONS(2403),
    [anon_sym_LBRACK] = ACTIONS(2405),
    [aux_sym_record_type_token1] = ACTIONS(2403),
    [aux_sym_basic_type_token21] = ACTIONS(2403),
    [aux_sym_basic_type_token22] = ACTIONS(2403),
    [aux_sym_basic_type_token48] = ACTIONS(2403),
    [anon_sym_not] = ACTIONS(2403),
    [anon_sym_NOT] = ACTIONS(2403),
    [anon_sym_Not] = ACTIONS(2403),
    [anon_sym_POUNDelif] = ACTIONS(2405),
    [anon_sym_POUNDELIF] = ACTIONS(2405),
    [anon_sym_POUNDElif] = ACTIONS(2405),
    [anon_sym_POUNDelse] = ACTIONS(2405),
    [anon_sym_POUNDELSE] = ACTIONS(2405),
    [anon_sym_POUNDElse] = ACTIONS(2405),
    [anon_sym_POUNDendif] = ACTIONS(2405),
    [anon_sym_POUNDENDIF] = ACTIONS(2405),
    [anon_sym_POUNDEndif] = ACTIONS(2405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2405),
    [aux_sym__expression_token1] = ACTIONS(2405),
    [aux_sym__expression_token2] = ACTIONS(2405),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2403),
    [anon_sym_SLASH] = ACTIONS(2403),
    [anon_sym_div] = ACTIONS(2403),
    [anon_sym_DIV] = ACTIONS(2403),
    [anon_sym_Div] = ACTIONS(2403),
    [anon_sym_mod] = ACTIONS(2403),
    [anon_sym_MOD] = ACTIONS(2403),
    [anon_sym_Mod] = ACTIONS(2403),
    [anon_sym_PLUS] = ACTIONS(2403),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_LT_GT] = ACTIONS(2405),
    [anon_sym_and] = ACTIONS(2403),
    [anon_sym_AND] = ACTIONS(2403),
    [anon_sym_And] = ACTIONS(2403),
    [anon_sym_or] = ACTIONS(2403),
    [anon_sym_OR] = ACTIONS(2403),
    [anon_sym_Or] = ACTIONS(2403),
    [anon_sym_xor] = ACTIONS(2403),
    [anon_sym_XOR] = ACTIONS(2403),
    [anon_sym_Xor] = ACTIONS(2403),
    [anon_sym_QMARK] = ACTIONS(2405),
    [sym_datetime_literal] = ACTIONS(2405),
    [sym_date_literal] = ACTIONS(2403),
    [sym_time_literal] = ACTIONS(2403),
    [sym_biginteger_literal] = ACTIONS(2405),
    [anon_sym_in] = ACTIONS(2403),
    [anon_sym_IN] = ACTIONS(2403),
    [anon_sym_In] = ACTIONS(2403),
    [sym_page_keyword] = ACTIONS(2403),
    [anon_sym_codeunit] = ACTIONS(2403),
    [anon_sym_CODEUNIT] = ACTIONS(2403),
    [anon_sym_Codeunit] = ACTIONS(2403),
    [anon_sym_CodeUnit] = ACTIONS(2403),
    [anon_sym_COdeunit] = ACTIONS(2403),
    [anon_sym_codeUnit] = ACTIONS(2403),
    [sym_report_keyword] = ACTIONS(2403),
    [sym_query_keyword] = ACTIONS(2403),
    [anon_sym_xmlport] = ACTIONS(2403),
    [anon_sym_XMLPORT] = ACTIONS(2403),
    [anon_sym_Xmlport] = ACTIONS(2403),
    [anon_sym_XMLport] = ACTIONS(2403),
    [anon_sym_XMLPort] = ACTIONS(2403),
    [anon_sym_XmlPort] = ACTIONS(2403),
    [anon_sym_enum] = ACTIONS(2403),
    [anon_sym_ENUM] = ACTIONS(2403),
    [anon_sym_Enum] = ACTIONS(2403),
    [anon_sym_eNUM] = ACTIONS(2403),
    [anon_sym_eNum] = ACTIONS(2403),
    [anon_sym_ENum] = ACTIONS(2403),
    [sym_quoted_identifier] = ACTIONS(2405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2405),
    [sym_integer] = ACTIONS(2403),
    [sym_continue_as_identifier] = ACTIONS(2405),
    [sym_preproc_close] = ACTIONS(2405),
  },
  [STATE(2129)] = {
    [sym_identifier] = ACTIONS(2547),
    [anon_sym_DOT] = ACTIONS(2547),
    [anon_sym_EQ] = ACTIONS(2549),
    [anon_sym_COMMA] = ACTIONS(2549),
    [anon_sym_DASH] = ACTIONS(2547),
    [aux_sym_boolean_token1] = ACTIONS(2547),
    [aux_sym_boolean_token2] = ACTIONS(2547),
    [sym_decimal] = ACTIONS(2547),
    [anon_sym_LPAREN] = ACTIONS(2549),
    [anon_sym_DOT_DOT] = ACTIONS(2549),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2547),
    [anon_sym_STAR] = ACTIONS(2547),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [aux_sym_record_type_token1] = ACTIONS(2547),
    [aux_sym_basic_type_token21] = ACTIONS(2547),
    [aux_sym_basic_type_token22] = ACTIONS(2547),
    [aux_sym_basic_type_token48] = ACTIONS(2547),
    [anon_sym_COLON_COLON] = ACTIONS(2549),
    [anon_sym_not] = ACTIONS(2547),
    [anon_sym_NOT] = ACTIONS(2547),
    [anon_sym_Not] = ACTIONS(2547),
    [anon_sym_POUNDelif] = ACTIONS(2549),
    [anon_sym_POUNDELIF] = ACTIONS(2549),
    [anon_sym_POUNDElif] = ACTIONS(2549),
    [anon_sym_POUNDelse] = ACTIONS(2549),
    [anon_sym_POUNDELSE] = ACTIONS(2549),
    [anon_sym_POUNDElse] = ACTIONS(2549),
    [anon_sym_POUNDendif] = ACTIONS(2549),
    [anon_sym_POUNDENDIF] = ACTIONS(2549),
    [anon_sym_POUNDEndif] = ACTIONS(2549),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2549),
    [aux_sym__expression_token1] = ACTIONS(2549),
    [aux_sym__expression_token2] = ACTIONS(2549),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2547),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2547),
    [anon_sym_SLASH] = ACTIONS(2547),
    [anon_sym_div] = ACTIONS(2547),
    [anon_sym_DIV] = ACTIONS(2547),
    [anon_sym_Div] = ACTIONS(2547),
    [anon_sym_mod] = ACTIONS(2547),
    [anon_sym_MOD] = ACTIONS(2547),
    [anon_sym_Mod] = ACTIONS(2547),
    [anon_sym_PLUS] = ACTIONS(2547),
    [anon_sym_GT_EQ] = ACTIONS(2549),
    [anon_sym_LT_EQ] = ACTIONS(2549),
    [anon_sym_GT] = ACTIONS(2547),
    [anon_sym_LT] = ACTIONS(2547),
    [anon_sym_LT_GT] = ACTIONS(2549),
    [anon_sym_and] = ACTIONS(2547),
    [anon_sym_AND] = ACTIONS(2547),
    [anon_sym_And] = ACTIONS(2547),
    [anon_sym_or] = ACTIONS(2547),
    [anon_sym_OR] = ACTIONS(2547),
    [anon_sym_Or] = ACTIONS(2547),
    [anon_sym_xor] = ACTIONS(2547),
    [anon_sym_XOR] = ACTIONS(2547),
    [anon_sym_Xor] = ACTIONS(2547),
    [anon_sym_QMARK] = ACTIONS(2549),
    [sym_datetime_literal] = ACTIONS(2549),
    [sym_date_literal] = ACTIONS(2547),
    [sym_time_literal] = ACTIONS(2547),
    [sym_biginteger_literal] = ACTIONS(2549),
    [anon_sym_in] = ACTIONS(2547),
    [anon_sym_IN] = ACTIONS(2547),
    [anon_sym_In] = ACTIONS(2547),
    [sym_page_keyword] = ACTIONS(2547),
    [anon_sym_codeunit] = ACTIONS(2547),
    [anon_sym_CODEUNIT] = ACTIONS(2547),
    [anon_sym_Codeunit] = ACTIONS(2547),
    [anon_sym_CodeUnit] = ACTIONS(2547),
    [anon_sym_COdeunit] = ACTIONS(2547),
    [anon_sym_codeUnit] = ACTIONS(2547),
    [sym_report_keyword] = ACTIONS(2547),
    [sym_query_keyword] = ACTIONS(2547),
    [anon_sym_xmlport] = ACTIONS(2547),
    [anon_sym_XMLPORT] = ACTIONS(2547),
    [anon_sym_Xmlport] = ACTIONS(2547),
    [anon_sym_XMLport] = ACTIONS(2547),
    [anon_sym_XMLPort] = ACTIONS(2547),
    [anon_sym_XmlPort] = ACTIONS(2547),
    [anon_sym_enum] = ACTIONS(2547),
    [anon_sym_ENUM] = ACTIONS(2547),
    [anon_sym_Enum] = ACTIONS(2547),
    [anon_sym_eNUM] = ACTIONS(2547),
    [anon_sym_eNum] = ACTIONS(2547),
    [anon_sym_ENum] = ACTIONS(2547),
    [sym_quoted_identifier] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2549),
    [sym_integer] = ACTIONS(2547),
    [sym_continue_as_identifier] = ACTIONS(2549),
    [sym_preproc_close] = ACTIONS(2549),
  },
  [STATE(2130)] = {
    [sym_identifier] = ACTIONS(2543),
    [anon_sym_SEMI] = ACTIONS(2545),
    [anon_sym_DOT] = ACTIONS(2543),
    [anon_sym_EQ] = ACTIONS(2545),
    [anon_sym_COMMA] = ACTIONS(2545),
    [anon_sym_COLON] = ACTIONS(2543),
    [anon_sym_DASH] = ACTIONS(2543),
    [aux_sym_boolean_token1] = ACTIONS(2543),
    [aux_sym_boolean_token2] = ACTIONS(2543),
    [sym_decimal] = ACTIONS(2543),
    [anon_sym_LPAREN] = ACTIONS(2545),
    [anon_sym_DOT_DOT] = ACTIONS(2545),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2543),
    [anon_sym_STAR] = ACTIONS(2543),
    [anon_sym_LBRACK] = ACTIONS(2545),
    [aux_sym_record_type_token1] = ACTIONS(2543),
    [aux_sym_basic_type_token21] = ACTIONS(2543),
    [aux_sym_basic_type_token22] = ACTIONS(2543),
    [aux_sym_basic_type_token48] = ACTIONS(2543),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2543),
    [anon_sym_COLON_COLON] = ACTIONS(2545),
    [anon_sym_POUNDif] = ACTIONS(2545),
    [anon_sym_POUNDIF] = ACTIONS(2545),
    [anon_sym_POUNDIf] = ACTIONS(2545),
    [anon_sym_not] = ACTIONS(2543),
    [anon_sym_NOT] = ACTIONS(2543),
    [anon_sym_Not] = ACTIONS(2543),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2545),
    [aux_sym__expression_token1] = ACTIONS(2545),
    [aux_sym__expression_token2] = ACTIONS(2545),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2543),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2543),
    [anon_sym_SLASH] = ACTIONS(2543),
    [anon_sym_div] = ACTIONS(2543),
    [anon_sym_DIV] = ACTIONS(2543),
    [anon_sym_Div] = ACTIONS(2543),
    [anon_sym_mod] = ACTIONS(2543),
    [anon_sym_MOD] = ACTIONS(2543),
    [anon_sym_Mod] = ACTIONS(2543),
    [anon_sym_PLUS] = ACTIONS(2543),
    [anon_sym_GT_EQ] = ACTIONS(2545),
    [anon_sym_LT_EQ] = ACTIONS(2545),
    [anon_sym_GT] = ACTIONS(2543),
    [anon_sym_LT] = ACTIONS(2543),
    [anon_sym_LT_GT] = ACTIONS(2545),
    [anon_sym_and] = ACTIONS(2543),
    [anon_sym_AND] = ACTIONS(2543),
    [anon_sym_And] = ACTIONS(2543),
    [anon_sym_or] = ACTIONS(2543),
    [anon_sym_OR] = ACTIONS(2543),
    [anon_sym_Or] = ACTIONS(2543),
    [anon_sym_xor] = ACTIONS(2543),
    [anon_sym_XOR] = ACTIONS(2543),
    [anon_sym_Xor] = ACTIONS(2543),
    [anon_sym_QMARK] = ACTIONS(2545),
    [sym_datetime_literal] = ACTIONS(2545),
    [sym_date_literal] = ACTIONS(2543),
    [sym_time_literal] = ACTIONS(2543),
    [sym_biginteger_literal] = ACTIONS(2545),
    [anon_sym_else] = ACTIONS(2543),
    [anon_sym_ELSE] = ACTIONS(2543),
    [anon_sym_Else] = ACTIONS(2543),
    [anon_sym_in] = ACTIONS(2543),
    [anon_sym_IN] = ACTIONS(2543),
    [anon_sym_In] = ACTIONS(2543),
    [sym_page_keyword] = ACTIONS(2543),
    [anon_sym_codeunit] = ACTIONS(2543),
    [anon_sym_CODEUNIT] = ACTIONS(2543),
    [anon_sym_Codeunit] = ACTIONS(2543),
    [anon_sym_CodeUnit] = ACTIONS(2543),
    [anon_sym_COdeunit] = ACTIONS(2543),
    [anon_sym_codeUnit] = ACTIONS(2543),
    [sym_report_keyword] = ACTIONS(2543),
    [sym_query_keyword] = ACTIONS(2543),
    [anon_sym_xmlport] = ACTIONS(2543),
    [anon_sym_XMLPORT] = ACTIONS(2543),
    [anon_sym_Xmlport] = ACTIONS(2543),
    [anon_sym_XMLport] = ACTIONS(2543),
    [anon_sym_XMLPort] = ACTIONS(2543),
    [anon_sym_XmlPort] = ACTIONS(2543),
    [anon_sym_enum] = ACTIONS(2543),
    [anon_sym_ENUM] = ACTIONS(2543),
    [anon_sym_Enum] = ACTIONS(2543),
    [anon_sym_eNUM] = ACTIONS(2543),
    [anon_sym_eNum] = ACTIONS(2543),
    [anon_sym_ENum] = ACTIONS(2543),
    [sym_quoted_identifier] = ACTIONS(2545),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2545),
    [sym_integer] = ACTIONS(2543),
    [sym_continue_as_identifier] = ACTIONS(2545),
    [sym_preproc_open] = ACTIONS(2545),
  },
  [STATE(2131)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2128),
    [sym_identifier] = ACTIONS(2410),
    [anon_sym_DOT] = ACTIONS(2410),
    [anon_sym_EQ] = ACTIONS(2412),
    [anon_sym_COMMA] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(2410),
    [aux_sym_boolean_token1] = ACTIONS(2410),
    [aux_sym_boolean_token2] = ACTIONS(2410),
    [sym_decimal] = ACTIONS(2410),
    [anon_sym_LPAREN] = ACTIONS(2412),
    [anon_sym_DOT_DOT] = ACTIONS(2412),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2410),
    [anon_sym_STAR] = ACTIONS(2410),
    [anon_sym_LBRACK] = ACTIONS(2412),
    [aux_sym_record_type_token1] = ACTIONS(2410),
    [aux_sym_basic_type_token21] = ACTIONS(2410),
    [aux_sym_basic_type_token22] = ACTIONS(2410),
    [aux_sym_basic_type_token48] = ACTIONS(2410),
    [anon_sym_not] = ACTIONS(2410),
    [anon_sym_NOT] = ACTIONS(2410),
    [anon_sym_Not] = ACTIONS(2410),
    [anon_sym_POUNDelif] = ACTIONS(2412),
    [anon_sym_POUNDELIF] = ACTIONS(2412),
    [anon_sym_POUNDElif] = ACTIONS(2412),
    [anon_sym_POUNDelse] = ACTIONS(2412),
    [anon_sym_POUNDELSE] = ACTIONS(2412),
    [anon_sym_POUNDElse] = ACTIONS(2412),
    [anon_sym_POUNDendif] = ACTIONS(2412),
    [anon_sym_POUNDENDIF] = ACTIONS(2412),
    [anon_sym_POUNDEndif] = ACTIONS(2412),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2412),
    [aux_sym__expression_token1] = ACTIONS(2412),
    [aux_sym__expression_token2] = ACTIONS(2412),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2410),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2410),
    [anon_sym_SLASH] = ACTIONS(2410),
    [anon_sym_div] = ACTIONS(2410),
    [anon_sym_DIV] = ACTIONS(2410),
    [anon_sym_Div] = ACTIONS(2410),
    [anon_sym_mod] = ACTIONS(2410),
    [anon_sym_MOD] = ACTIONS(2410),
    [anon_sym_Mod] = ACTIONS(2410),
    [anon_sym_PLUS] = ACTIONS(2410),
    [anon_sym_GT_EQ] = ACTIONS(2412),
    [anon_sym_LT_EQ] = ACTIONS(2412),
    [anon_sym_GT] = ACTIONS(2410),
    [anon_sym_LT] = ACTIONS(2410),
    [anon_sym_LT_GT] = ACTIONS(2412),
    [anon_sym_and] = ACTIONS(2410),
    [anon_sym_AND] = ACTIONS(2410),
    [anon_sym_And] = ACTIONS(2410),
    [anon_sym_or] = ACTIONS(2410),
    [anon_sym_OR] = ACTIONS(2410),
    [anon_sym_Or] = ACTIONS(2410),
    [anon_sym_xor] = ACTIONS(2410),
    [anon_sym_XOR] = ACTIONS(2410),
    [anon_sym_Xor] = ACTIONS(2410),
    [anon_sym_QMARK] = ACTIONS(2412),
    [sym_datetime_literal] = ACTIONS(2412),
    [sym_date_literal] = ACTIONS(2410),
    [sym_time_literal] = ACTIONS(2410),
    [sym_biginteger_literal] = ACTIONS(2412),
    [anon_sym_in] = ACTIONS(2410),
    [anon_sym_IN] = ACTIONS(2410),
    [anon_sym_In] = ACTIONS(2410),
    [sym_page_keyword] = ACTIONS(2410),
    [anon_sym_codeunit] = ACTIONS(2410),
    [anon_sym_CODEUNIT] = ACTIONS(2410),
    [anon_sym_Codeunit] = ACTIONS(2410),
    [anon_sym_CodeUnit] = ACTIONS(2410),
    [anon_sym_COdeunit] = ACTIONS(2410),
    [anon_sym_codeUnit] = ACTIONS(2410),
    [sym_report_keyword] = ACTIONS(2410),
    [sym_query_keyword] = ACTIONS(2410),
    [anon_sym_xmlport] = ACTIONS(2410),
    [anon_sym_XMLPORT] = ACTIONS(2410),
    [anon_sym_Xmlport] = ACTIONS(2410),
    [anon_sym_XMLport] = ACTIONS(2410),
    [anon_sym_XMLPort] = ACTIONS(2410),
    [anon_sym_XmlPort] = ACTIONS(2410),
    [anon_sym_enum] = ACTIONS(2410),
    [anon_sym_ENUM] = ACTIONS(2410),
    [anon_sym_Enum] = ACTIONS(2410),
    [anon_sym_eNUM] = ACTIONS(2410),
    [anon_sym_eNum] = ACTIONS(2410),
    [anon_sym_ENum] = ACTIONS(2410),
    [sym_quoted_identifier] = ACTIONS(2412),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2412),
    [sym_integer] = ACTIONS(2410),
    [sym_continue_as_identifier] = ACTIONS(2412),
    [sym_preproc_close] = ACTIONS(2412),
  },
  [STATE(2132)] = {
    [sym_identifier] = ACTIONS(2555),
    [anon_sym_SEMI] = ACTIONS(2557),
    [anon_sym_DOT] = ACTIONS(2555),
    [anon_sym_EQ] = ACTIONS(2557),
    [anon_sym_COMMA] = ACTIONS(2557),
    [anon_sym_COLON] = ACTIONS(2555),
    [anon_sym_DASH] = ACTIONS(2555),
    [aux_sym_boolean_token1] = ACTIONS(2555),
    [aux_sym_boolean_token2] = ACTIONS(2555),
    [sym_decimal] = ACTIONS(2555),
    [anon_sym_LPAREN] = ACTIONS(2557),
    [anon_sym_DOT_DOT] = ACTIONS(2557),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2555),
    [anon_sym_STAR] = ACTIONS(2555),
    [anon_sym_LBRACK] = ACTIONS(2557),
    [aux_sym_record_type_token1] = ACTIONS(2555),
    [aux_sym_basic_type_token21] = ACTIONS(2555),
    [aux_sym_basic_type_token22] = ACTIONS(2555),
    [aux_sym_basic_type_token48] = ACTIONS(2555),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2555),
    [anon_sym_COLON_COLON] = ACTIONS(2557),
    [anon_sym_POUNDif] = ACTIONS(2557),
    [anon_sym_POUNDIF] = ACTIONS(2557),
    [anon_sym_POUNDIf] = ACTIONS(2557),
    [anon_sym_not] = ACTIONS(2555),
    [anon_sym_NOT] = ACTIONS(2555),
    [anon_sym_Not] = ACTIONS(2555),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2557),
    [aux_sym__expression_token1] = ACTIONS(2557),
    [aux_sym__expression_token2] = ACTIONS(2557),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2555),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2555),
    [anon_sym_SLASH] = ACTIONS(2555),
    [anon_sym_div] = ACTIONS(2555),
    [anon_sym_DIV] = ACTIONS(2555),
    [anon_sym_Div] = ACTIONS(2555),
    [anon_sym_mod] = ACTIONS(2555),
    [anon_sym_MOD] = ACTIONS(2555),
    [anon_sym_Mod] = ACTIONS(2555),
    [anon_sym_PLUS] = ACTIONS(2555),
    [anon_sym_GT_EQ] = ACTIONS(2557),
    [anon_sym_LT_EQ] = ACTIONS(2557),
    [anon_sym_GT] = ACTIONS(2555),
    [anon_sym_LT] = ACTIONS(2555),
    [anon_sym_LT_GT] = ACTIONS(2557),
    [anon_sym_and] = ACTIONS(2555),
    [anon_sym_AND] = ACTIONS(2555),
    [anon_sym_And] = ACTIONS(2555),
    [anon_sym_or] = ACTIONS(2555),
    [anon_sym_OR] = ACTIONS(2555),
    [anon_sym_Or] = ACTIONS(2555),
    [anon_sym_xor] = ACTIONS(2555),
    [anon_sym_XOR] = ACTIONS(2555),
    [anon_sym_Xor] = ACTIONS(2555),
    [anon_sym_QMARK] = ACTIONS(2557),
    [sym_datetime_literal] = ACTIONS(2557),
    [sym_date_literal] = ACTIONS(2555),
    [sym_time_literal] = ACTIONS(2555),
    [sym_biginteger_literal] = ACTIONS(2557),
    [anon_sym_else] = ACTIONS(2555),
    [anon_sym_ELSE] = ACTIONS(2555),
    [anon_sym_Else] = ACTIONS(2555),
    [anon_sym_in] = ACTIONS(2555),
    [anon_sym_IN] = ACTIONS(2555),
    [anon_sym_In] = ACTIONS(2555),
    [sym_page_keyword] = ACTIONS(2555),
    [anon_sym_codeunit] = ACTIONS(2555),
    [anon_sym_CODEUNIT] = ACTIONS(2555),
    [anon_sym_Codeunit] = ACTIONS(2555),
    [anon_sym_CodeUnit] = ACTIONS(2555),
    [anon_sym_COdeunit] = ACTIONS(2555),
    [anon_sym_codeUnit] = ACTIONS(2555),
    [sym_report_keyword] = ACTIONS(2555),
    [sym_query_keyword] = ACTIONS(2555),
    [anon_sym_xmlport] = ACTIONS(2555),
    [anon_sym_XMLPORT] = ACTIONS(2555),
    [anon_sym_Xmlport] = ACTIONS(2555),
    [anon_sym_XMLport] = ACTIONS(2555),
    [anon_sym_XMLPort] = ACTIONS(2555),
    [anon_sym_XmlPort] = ACTIONS(2555),
    [anon_sym_enum] = ACTIONS(2555),
    [anon_sym_ENUM] = ACTIONS(2555),
    [anon_sym_Enum] = ACTIONS(2555),
    [anon_sym_eNUM] = ACTIONS(2555),
    [anon_sym_eNum] = ACTIONS(2555),
    [anon_sym_ENum] = ACTIONS(2555),
    [sym_quoted_identifier] = ACTIONS(2557),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2557),
    [sym_integer] = ACTIONS(2555),
    [sym_continue_as_identifier] = ACTIONS(2557),
    [sym_preproc_open] = ACTIONS(2557),
  },
  [STATE(2133)] = {
    [sym_identifier] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2563),
    [anon_sym_DOT] = ACTIONS(2561),
    [anon_sym_EQ] = ACTIONS(2563),
    [anon_sym_COMMA] = ACTIONS(2563),
    [anon_sym_COLON] = ACTIONS(2561),
    [anon_sym_DASH] = ACTIONS(2561),
    [aux_sym_boolean_token1] = ACTIONS(2561),
    [aux_sym_boolean_token2] = ACTIONS(2561),
    [sym_decimal] = ACTIONS(2561),
    [anon_sym_LPAREN] = ACTIONS(2563),
    [anon_sym_DOT_DOT] = ACTIONS(2563),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2561),
    [anon_sym_STAR] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2563),
    [aux_sym_record_type_token1] = ACTIONS(2561),
    [aux_sym_basic_type_token21] = ACTIONS(2561),
    [aux_sym_basic_type_token22] = ACTIONS(2561),
    [aux_sym_basic_type_token48] = ACTIONS(2561),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_POUNDif] = ACTIONS(2563),
    [anon_sym_POUNDIF] = ACTIONS(2563),
    [anon_sym_POUNDIf] = ACTIONS(2563),
    [anon_sym_not] = ACTIONS(2561),
    [anon_sym_NOT] = ACTIONS(2561),
    [anon_sym_Not] = ACTIONS(2561),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2563),
    [aux_sym__expression_token1] = ACTIONS(2563),
    [aux_sym__expression_token2] = ACTIONS(2563),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2561),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2561),
    [anon_sym_SLASH] = ACTIONS(2561),
    [anon_sym_div] = ACTIONS(2561),
    [anon_sym_DIV] = ACTIONS(2561),
    [anon_sym_Div] = ACTIONS(2561),
    [anon_sym_mod] = ACTIONS(2561),
    [anon_sym_MOD] = ACTIONS(2561),
    [anon_sym_Mod] = ACTIONS(2561),
    [anon_sym_PLUS] = ACTIONS(2561),
    [anon_sym_GT_EQ] = ACTIONS(2563),
    [anon_sym_LT_EQ] = ACTIONS(2563),
    [anon_sym_GT] = ACTIONS(2561),
    [anon_sym_LT] = ACTIONS(2561),
    [anon_sym_LT_GT] = ACTIONS(2563),
    [anon_sym_and] = ACTIONS(2561),
    [anon_sym_AND] = ACTIONS(2561),
    [anon_sym_And] = ACTIONS(2561),
    [anon_sym_or] = ACTIONS(2561),
    [anon_sym_OR] = ACTIONS(2561),
    [anon_sym_Or] = ACTIONS(2561),
    [anon_sym_xor] = ACTIONS(2561),
    [anon_sym_XOR] = ACTIONS(2561),
    [anon_sym_Xor] = ACTIONS(2561),
    [anon_sym_QMARK] = ACTIONS(2563),
    [sym_datetime_literal] = ACTIONS(2563),
    [sym_date_literal] = ACTIONS(2561),
    [sym_time_literal] = ACTIONS(2561),
    [sym_biginteger_literal] = ACTIONS(2563),
    [anon_sym_else] = ACTIONS(2561),
    [anon_sym_ELSE] = ACTIONS(2561),
    [anon_sym_Else] = ACTIONS(2561),
    [anon_sym_in] = ACTIONS(2561),
    [anon_sym_IN] = ACTIONS(2561),
    [anon_sym_In] = ACTIONS(2561),
    [sym_page_keyword] = ACTIONS(2561),
    [anon_sym_codeunit] = ACTIONS(2561),
    [anon_sym_CODEUNIT] = ACTIONS(2561),
    [anon_sym_Codeunit] = ACTIONS(2561),
    [anon_sym_CodeUnit] = ACTIONS(2561),
    [anon_sym_COdeunit] = ACTIONS(2561),
    [anon_sym_codeUnit] = ACTIONS(2561),
    [sym_report_keyword] = ACTIONS(2561),
    [sym_query_keyword] = ACTIONS(2561),
    [anon_sym_xmlport] = ACTIONS(2561),
    [anon_sym_XMLPORT] = ACTIONS(2561),
    [anon_sym_Xmlport] = ACTIONS(2561),
    [anon_sym_XMLport] = ACTIONS(2561),
    [anon_sym_XMLPort] = ACTIONS(2561),
    [anon_sym_XmlPort] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_ENUM] = ACTIONS(2561),
    [anon_sym_Enum] = ACTIONS(2561),
    [anon_sym_eNUM] = ACTIONS(2561),
    [anon_sym_eNum] = ACTIONS(2561),
    [anon_sym_ENum] = ACTIONS(2561),
    [sym_quoted_identifier] = ACTIONS(2563),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2563),
    [sym_integer] = ACTIONS(2561),
    [sym_continue_as_identifier] = ACTIONS(2563),
    [sym_preproc_open] = ACTIONS(2563),
  },
  [STATE(2134)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_SEMI] = ACTIONS(2428),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_COMMA] = ACTIONS(2428),
    [anon_sym_COLON] = ACTIONS(2426),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2426),
    [anon_sym_COLON_COLON] = ACTIONS(5429),
    [anon_sym_POUNDif] = ACTIONS(2428),
    [anon_sym_POUNDIF] = ACTIONS(2428),
    [anon_sym_POUNDIf] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2428),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_else] = ACTIONS(2426),
    [anon_sym_ELSE] = ACTIONS(2426),
    [anon_sym_Else] = ACTIONS(2426),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_open] = ACTIONS(2428),
  },
  [STATE(2135)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2441),
    [sym_preproc_endif] = STATE(4653),
    [sym_assignment_expression] = STATE(6338),
    [sym_case_branch] = STATE(1939),
    [sym_preproc_split_case_branch] = STATE(3395),
    [aux_sym__case_pattern] = STATE(2579),
    [sym_preproc_conditional_case_patterns] = STATE(2579),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(9819),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(87),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(1939),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(3754),
    [anon_sym_ELSE] = ACTIONS(3754),
    [anon_sym_Else] = ACTIONS(3754),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2136)] = {
    [sym_identifier] = ACTIONS(2629),
    [anon_sym_SEMI] = ACTIONS(2631),
    [anon_sym_DOT] = ACTIONS(2629),
    [anon_sym_EQ] = ACTIONS(2631),
    [anon_sym_COMMA] = ACTIONS(2631),
    [anon_sym_COLON] = ACTIONS(2629),
    [anon_sym_DASH] = ACTIONS(2629),
    [aux_sym_boolean_token1] = ACTIONS(2629),
    [aux_sym_boolean_token2] = ACTIONS(2629),
    [sym_decimal] = ACTIONS(2629),
    [anon_sym_LPAREN] = ACTIONS(2631),
    [anon_sym_DOT_DOT] = ACTIONS(2631),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2629),
    [anon_sym_STAR] = ACTIONS(2629),
    [anon_sym_LBRACK] = ACTIONS(2631),
    [aux_sym_record_type_token1] = ACTIONS(2629),
    [aux_sym_basic_type_token21] = ACTIONS(2629),
    [aux_sym_basic_type_token22] = ACTIONS(2629),
    [aux_sym_basic_type_token48] = ACTIONS(2629),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2629),
    [anon_sym_POUNDif] = ACTIONS(2631),
    [anon_sym_POUNDIF] = ACTIONS(2631),
    [anon_sym_POUNDIf] = ACTIONS(2631),
    [anon_sym_not] = ACTIONS(2629),
    [anon_sym_NOT] = ACTIONS(2629),
    [anon_sym_Not] = ACTIONS(2629),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2631),
    [aux_sym__expression_token1] = ACTIONS(2631),
    [aux_sym__expression_token2] = ACTIONS(2631),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2629),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2629),
    [anon_sym_SLASH] = ACTIONS(2629),
    [anon_sym_div] = ACTIONS(2629),
    [anon_sym_DIV] = ACTIONS(2629),
    [anon_sym_Div] = ACTIONS(2629),
    [anon_sym_mod] = ACTIONS(2629),
    [anon_sym_MOD] = ACTIONS(2629),
    [anon_sym_Mod] = ACTIONS(2629),
    [anon_sym_PLUS] = ACTIONS(2629),
    [anon_sym_GT_EQ] = ACTIONS(2631),
    [anon_sym_LT_EQ] = ACTIONS(2631),
    [anon_sym_GT] = ACTIONS(2629),
    [anon_sym_LT] = ACTIONS(2629),
    [anon_sym_LT_GT] = ACTIONS(2631),
    [anon_sym_and] = ACTIONS(2629),
    [anon_sym_AND] = ACTIONS(2629),
    [anon_sym_And] = ACTIONS(2629),
    [anon_sym_or] = ACTIONS(2629),
    [anon_sym_OR] = ACTIONS(2629),
    [anon_sym_Or] = ACTIONS(2629),
    [anon_sym_xor] = ACTIONS(2629),
    [anon_sym_XOR] = ACTIONS(2629),
    [anon_sym_Xor] = ACTIONS(2629),
    [anon_sym_QMARK] = ACTIONS(2631),
    [sym_datetime_literal] = ACTIONS(2631),
    [sym_date_literal] = ACTIONS(2629),
    [sym_time_literal] = ACTIONS(2629),
    [sym_biginteger_literal] = ACTIONS(2631),
    [anon_sym_else] = ACTIONS(2629),
    [anon_sym_ELSE] = ACTIONS(2629),
    [anon_sym_Else] = ACTIONS(2629),
    [anon_sym_in] = ACTIONS(2629),
    [anon_sym_IN] = ACTIONS(2629),
    [anon_sym_In] = ACTIONS(2629),
    [sym_page_keyword] = ACTIONS(2629),
    [anon_sym_codeunit] = ACTIONS(2629),
    [anon_sym_CODEUNIT] = ACTIONS(2629),
    [anon_sym_Codeunit] = ACTIONS(2629),
    [anon_sym_CodeUnit] = ACTIONS(2629),
    [anon_sym_COdeunit] = ACTIONS(2629),
    [anon_sym_codeUnit] = ACTIONS(2629),
    [sym_report_keyword] = ACTIONS(2629),
    [sym_query_keyword] = ACTIONS(2629),
    [anon_sym_xmlport] = ACTIONS(2629),
    [anon_sym_XMLPORT] = ACTIONS(2629),
    [anon_sym_Xmlport] = ACTIONS(2629),
    [anon_sym_XMLport] = ACTIONS(2629),
    [anon_sym_XMLPort] = ACTIONS(2629),
    [anon_sym_XmlPort] = ACTIONS(2629),
    [anon_sym_enum] = ACTIONS(2629),
    [anon_sym_ENUM] = ACTIONS(2629),
    [anon_sym_Enum] = ACTIONS(2629),
    [anon_sym_eNUM] = ACTIONS(2629),
    [anon_sym_eNum] = ACTIONS(2629),
    [anon_sym_ENum] = ACTIONS(2629),
    [sym_quoted_identifier] = ACTIONS(2631),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2631),
    [sym_integer] = ACTIONS(2629),
    [sym_continue_as_identifier] = ACTIONS(2631),
    [sym_preproc_open] = ACTIONS(2631),
  },
  [STATE(2137)] = {
    [sym_identifier] = ACTIONS(2633),
    [anon_sym_SEMI] = ACTIONS(2635),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_EQ] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [anon_sym_COLON] = ACTIONS(2633),
    [anon_sym_DASH] = ACTIONS(2633),
    [aux_sym_boolean_token1] = ACTIONS(2633),
    [aux_sym_boolean_token2] = ACTIONS(2633),
    [sym_decimal] = ACTIONS(2633),
    [anon_sym_LPAREN] = ACTIONS(2635),
    [anon_sym_DOT_DOT] = ACTIONS(2635),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2633),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [aux_sym_record_type_token1] = ACTIONS(2633),
    [aux_sym_basic_type_token21] = ACTIONS(2633),
    [aux_sym_basic_type_token22] = ACTIONS(2633),
    [aux_sym_basic_type_token48] = ACTIONS(2633),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2633),
    [anon_sym_POUNDif] = ACTIONS(2635),
    [anon_sym_POUNDIF] = ACTIONS(2635),
    [anon_sym_POUNDIf] = ACTIONS(2635),
    [anon_sym_not] = ACTIONS(2633),
    [anon_sym_NOT] = ACTIONS(2633),
    [anon_sym_Not] = ACTIONS(2633),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2635),
    [aux_sym__expression_token1] = ACTIONS(2635),
    [aux_sym__expression_token2] = ACTIONS(2635),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2633),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2633),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_div] = ACTIONS(2633),
    [anon_sym_DIV] = ACTIONS(2633),
    [anon_sym_Div] = ACTIONS(2633),
    [anon_sym_mod] = ACTIONS(2633),
    [anon_sym_MOD] = ACTIONS(2633),
    [anon_sym_Mod] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_GT] = ACTIONS(2635),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_AND] = ACTIONS(2633),
    [anon_sym_And] = ACTIONS(2633),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_OR] = ACTIONS(2633),
    [anon_sym_Or] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_XOR] = ACTIONS(2633),
    [anon_sym_Xor] = ACTIONS(2633),
    [anon_sym_QMARK] = ACTIONS(2635),
    [sym_datetime_literal] = ACTIONS(2635),
    [sym_date_literal] = ACTIONS(2633),
    [sym_time_literal] = ACTIONS(2633),
    [sym_biginteger_literal] = ACTIONS(2635),
    [anon_sym_else] = ACTIONS(2633),
    [anon_sym_ELSE] = ACTIONS(2633),
    [anon_sym_Else] = ACTIONS(2633),
    [anon_sym_in] = ACTIONS(2633),
    [anon_sym_IN] = ACTIONS(2633),
    [anon_sym_In] = ACTIONS(2633),
    [sym_page_keyword] = ACTIONS(2633),
    [anon_sym_codeunit] = ACTIONS(2633),
    [anon_sym_CODEUNIT] = ACTIONS(2633),
    [anon_sym_Codeunit] = ACTIONS(2633),
    [anon_sym_CodeUnit] = ACTIONS(2633),
    [anon_sym_COdeunit] = ACTIONS(2633),
    [anon_sym_codeUnit] = ACTIONS(2633),
    [sym_report_keyword] = ACTIONS(2633),
    [sym_query_keyword] = ACTIONS(2633),
    [anon_sym_xmlport] = ACTIONS(2633),
    [anon_sym_XMLPORT] = ACTIONS(2633),
    [anon_sym_Xmlport] = ACTIONS(2633),
    [anon_sym_XMLport] = ACTIONS(2633),
    [anon_sym_XMLPort] = ACTIONS(2633),
    [anon_sym_XmlPort] = ACTIONS(2633),
    [anon_sym_enum] = ACTIONS(2633),
    [anon_sym_ENUM] = ACTIONS(2633),
    [anon_sym_Enum] = ACTIONS(2633),
    [anon_sym_eNUM] = ACTIONS(2633),
    [anon_sym_eNum] = ACTIONS(2633),
    [anon_sym_ENum] = ACTIONS(2633),
    [sym_quoted_identifier] = ACTIONS(2635),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2635),
    [sym_integer] = ACTIONS(2633),
    [sym_continue_as_identifier] = ACTIONS(2635),
    [sym_preproc_open] = ACTIONS(2635),
  },
  [STATE(2138)] = {
    [sym_identifier] = ACTIONS(2641),
    [anon_sym_SEMI] = ACTIONS(2643),
    [anon_sym_DOT] = ACTIONS(2641),
    [anon_sym_EQ] = ACTIONS(2643),
    [anon_sym_COMMA] = ACTIONS(2643),
    [anon_sym_COLON] = ACTIONS(2641),
    [anon_sym_DASH] = ACTIONS(2641),
    [aux_sym_boolean_token1] = ACTIONS(2641),
    [aux_sym_boolean_token2] = ACTIONS(2641),
    [sym_decimal] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_DOT_DOT] = ACTIONS(2643),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2641),
    [anon_sym_STAR] = ACTIONS(2641),
    [anon_sym_LBRACK] = ACTIONS(2643),
    [aux_sym_record_type_token1] = ACTIONS(2641),
    [aux_sym_basic_type_token21] = ACTIONS(2641),
    [aux_sym_basic_type_token22] = ACTIONS(2641),
    [aux_sym_basic_type_token48] = ACTIONS(2641),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2641),
    [anon_sym_POUNDif] = ACTIONS(2643),
    [anon_sym_POUNDIF] = ACTIONS(2643),
    [anon_sym_POUNDIf] = ACTIONS(2643),
    [anon_sym_not] = ACTIONS(2641),
    [anon_sym_NOT] = ACTIONS(2641),
    [anon_sym_Not] = ACTIONS(2641),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2643),
    [aux_sym__expression_token1] = ACTIONS(2643),
    [aux_sym__expression_token2] = ACTIONS(2643),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2641),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2641),
    [anon_sym_SLASH] = ACTIONS(2641),
    [anon_sym_div] = ACTIONS(2641),
    [anon_sym_DIV] = ACTIONS(2641),
    [anon_sym_Div] = ACTIONS(2641),
    [anon_sym_mod] = ACTIONS(2641),
    [anon_sym_MOD] = ACTIONS(2641),
    [anon_sym_Mod] = ACTIONS(2641),
    [anon_sym_PLUS] = ACTIONS(2641),
    [anon_sym_GT_EQ] = ACTIONS(2643),
    [anon_sym_LT_EQ] = ACTIONS(2643),
    [anon_sym_GT] = ACTIONS(2641),
    [anon_sym_LT] = ACTIONS(2641),
    [anon_sym_LT_GT] = ACTIONS(2643),
    [anon_sym_and] = ACTIONS(2641),
    [anon_sym_AND] = ACTIONS(2641),
    [anon_sym_And] = ACTIONS(2641),
    [anon_sym_or] = ACTIONS(2641),
    [anon_sym_OR] = ACTIONS(2641),
    [anon_sym_Or] = ACTIONS(2641),
    [anon_sym_xor] = ACTIONS(2641),
    [anon_sym_XOR] = ACTIONS(2641),
    [anon_sym_Xor] = ACTIONS(2641),
    [anon_sym_QMARK] = ACTIONS(2643),
    [sym_datetime_literal] = ACTIONS(2643),
    [sym_date_literal] = ACTIONS(2641),
    [sym_time_literal] = ACTIONS(2641),
    [sym_biginteger_literal] = ACTIONS(2643),
    [anon_sym_else] = ACTIONS(2641),
    [anon_sym_ELSE] = ACTIONS(2641),
    [anon_sym_Else] = ACTIONS(2641),
    [anon_sym_in] = ACTIONS(2641),
    [anon_sym_IN] = ACTIONS(2641),
    [anon_sym_In] = ACTIONS(2641),
    [sym_page_keyword] = ACTIONS(2641),
    [anon_sym_codeunit] = ACTIONS(2641),
    [anon_sym_CODEUNIT] = ACTIONS(2641),
    [anon_sym_Codeunit] = ACTIONS(2641),
    [anon_sym_CodeUnit] = ACTIONS(2641),
    [anon_sym_COdeunit] = ACTIONS(2641),
    [anon_sym_codeUnit] = ACTIONS(2641),
    [sym_report_keyword] = ACTIONS(2641),
    [sym_query_keyword] = ACTIONS(2641),
    [anon_sym_xmlport] = ACTIONS(2641),
    [anon_sym_XMLPORT] = ACTIONS(2641),
    [anon_sym_Xmlport] = ACTIONS(2641),
    [anon_sym_XMLport] = ACTIONS(2641),
    [anon_sym_XMLPort] = ACTIONS(2641),
    [anon_sym_XmlPort] = ACTIONS(2641),
    [anon_sym_enum] = ACTIONS(2641),
    [anon_sym_ENUM] = ACTIONS(2641),
    [anon_sym_Enum] = ACTIONS(2641),
    [anon_sym_eNUM] = ACTIONS(2641),
    [anon_sym_eNum] = ACTIONS(2641),
    [anon_sym_ENum] = ACTIONS(2641),
    [sym_quoted_identifier] = ACTIONS(2643),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2643),
    [sym_integer] = ACTIONS(2641),
    [sym_continue_as_identifier] = ACTIONS(2643),
    [sym_preproc_open] = ACTIONS(2643),
  },
  [STATE(2139)] = {
    [sym_identifier] = ACTIONS(2645),
    [anon_sym_SEMI] = ACTIONS(2647),
    [anon_sym_DOT] = ACTIONS(2645),
    [anon_sym_EQ] = ACTIONS(2647),
    [anon_sym_COMMA] = ACTIONS(2647),
    [anon_sym_COLON] = ACTIONS(2645),
    [anon_sym_DASH] = ACTIONS(2645),
    [aux_sym_boolean_token1] = ACTIONS(2645),
    [aux_sym_boolean_token2] = ACTIONS(2645),
    [sym_decimal] = ACTIONS(2645),
    [anon_sym_LPAREN] = ACTIONS(2647),
    [anon_sym_DOT_DOT] = ACTIONS(2647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2645),
    [anon_sym_STAR] = ACTIONS(2645),
    [anon_sym_LBRACK] = ACTIONS(2647),
    [aux_sym_record_type_token1] = ACTIONS(2645),
    [aux_sym_basic_type_token21] = ACTIONS(2645),
    [aux_sym_basic_type_token22] = ACTIONS(2645),
    [aux_sym_basic_type_token48] = ACTIONS(2645),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2645),
    [anon_sym_POUNDif] = ACTIONS(2647),
    [anon_sym_POUNDIF] = ACTIONS(2647),
    [anon_sym_POUNDIf] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2645),
    [anon_sym_NOT] = ACTIONS(2645),
    [anon_sym_Not] = ACTIONS(2645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2647),
    [aux_sym__expression_token1] = ACTIONS(2647),
    [aux_sym__expression_token2] = ACTIONS(2647),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2645),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2645),
    [anon_sym_SLASH] = ACTIONS(2645),
    [anon_sym_div] = ACTIONS(2645),
    [anon_sym_DIV] = ACTIONS(2645),
    [anon_sym_Div] = ACTIONS(2645),
    [anon_sym_mod] = ACTIONS(2645),
    [anon_sym_MOD] = ACTIONS(2645),
    [anon_sym_Mod] = ACTIONS(2645),
    [anon_sym_PLUS] = ACTIONS(2645),
    [anon_sym_GT_EQ] = ACTIONS(2647),
    [anon_sym_LT_EQ] = ACTIONS(2647),
    [anon_sym_GT] = ACTIONS(2645),
    [anon_sym_LT] = ACTIONS(2645),
    [anon_sym_LT_GT] = ACTIONS(2647),
    [anon_sym_and] = ACTIONS(2645),
    [anon_sym_AND] = ACTIONS(2645),
    [anon_sym_And] = ACTIONS(2645),
    [anon_sym_or] = ACTIONS(2645),
    [anon_sym_OR] = ACTIONS(2645),
    [anon_sym_Or] = ACTIONS(2645),
    [anon_sym_xor] = ACTIONS(2645),
    [anon_sym_XOR] = ACTIONS(2645),
    [anon_sym_Xor] = ACTIONS(2645),
    [anon_sym_QMARK] = ACTIONS(2647),
    [sym_datetime_literal] = ACTIONS(2647),
    [sym_date_literal] = ACTIONS(2645),
    [sym_time_literal] = ACTIONS(2645),
    [sym_biginteger_literal] = ACTIONS(2647),
    [anon_sym_else] = ACTIONS(2645),
    [anon_sym_ELSE] = ACTIONS(2645),
    [anon_sym_Else] = ACTIONS(2645),
    [anon_sym_in] = ACTIONS(2645),
    [anon_sym_IN] = ACTIONS(2645),
    [anon_sym_In] = ACTIONS(2645),
    [sym_page_keyword] = ACTIONS(2645),
    [anon_sym_codeunit] = ACTIONS(2645),
    [anon_sym_CODEUNIT] = ACTIONS(2645),
    [anon_sym_Codeunit] = ACTIONS(2645),
    [anon_sym_CodeUnit] = ACTIONS(2645),
    [anon_sym_COdeunit] = ACTIONS(2645),
    [anon_sym_codeUnit] = ACTIONS(2645),
    [sym_report_keyword] = ACTIONS(2645),
    [sym_query_keyword] = ACTIONS(2645),
    [anon_sym_xmlport] = ACTIONS(2645),
    [anon_sym_XMLPORT] = ACTIONS(2645),
    [anon_sym_Xmlport] = ACTIONS(2645),
    [anon_sym_XMLport] = ACTIONS(2645),
    [anon_sym_XMLPort] = ACTIONS(2645),
    [anon_sym_XmlPort] = ACTIONS(2645),
    [anon_sym_enum] = ACTIONS(2645),
    [anon_sym_ENUM] = ACTIONS(2645),
    [anon_sym_Enum] = ACTIONS(2645),
    [anon_sym_eNUM] = ACTIONS(2645),
    [anon_sym_eNum] = ACTIONS(2645),
    [anon_sym_ENum] = ACTIONS(2645),
    [sym_quoted_identifier] = ACTIONS(2647),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2647),
    [sym_integer] = ACTIONS(2645),
    [sym_continue_as_identifier] = ACTIONS(2647),
    [sym_preproc_open] = ACTIONS(2647),
  },
  [STATE(2140)] = {
    [sym_identifier] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym_DOT] = ACTIONS(2573),
    [anon_sym_EQ] = ACTIONS(2575),
    [anon_sym_COMMA] = ACTIONS(2575),
    [anon_sym_COLON] = ACTIONS(2573),
    [anon_sym_DASH] = ACTIONS(2573),
    [aux_sym_boolean_token1] = ACTIONS(2573),
    [aux_sym_boolean_token2] = ACTIONS(2573),
    [sym_decimal] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2575),
    [anon_sym_DOT_DOT] = ACTIONS(2575),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2575),
    [aux_sym_record_type_token1] = ACTIONS(2573),
    [aux_sym_basic_type_token21] = ACTIONS(2573),
    [aux_sym_basic_type_token22] = ACTIONS(2573),
    [aux_sym_basic_type_token48] = ACTIONS(2573),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2573),
    [anon_sym_POUNDif] = ACTIONS(2575),
    [anon_sym_POUNDIF] = ACTIONS(2575),
    [anon_sym_POUNDIf] = ACTIONS(2575),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_NOT] = ACTIONS(2573),
    [anon_sym_Not] = ACTIONS(2573),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2575),
    [aux_sym__expression_token1] = ACTIONS(2575),
    [aux_sym__expression_token2] = ACTIONS(2575),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2573),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2573),
    [anon_sym_SLASH] = ACTIONS(2573),
    [anon_sym_div] = ACTIONS(2573),
    [anon_sym_DIV] = ACTIONS(2573),
    [anon_sym_Div] = ACTIONS(2573),
    [anon_sym_mod] = ACTIONS(2573),
    [anon_sym_MOD] = ACTIONS(2573),
    [anon_sym_Mod] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_GT_EQ] = ACTIONS(2575),
    [anon_sym_LT_EQ] = ACTIONS(2575),
    [anon_sym_GT] = ACTIONS(2573),
    [anon_sym_LT] = ACTIONS(2573),
    [anon_sym_LT_GT] = ACTIONS(2575),
    [anon_sym_and] = ACTIONS(2573),
    [anon_sym_AND] = ACTIONS(2573),
    [anon_sym_And] = ACTIONS(2573),
    [anon_sym_or] = ACTIONS(2573),
    [anon_sym_OR] = ACTIONS(2573),
    [anon_sym_Or] = ACTIONS(2573),
    [anon_sym_xor] = ACTIONS(2573),
    [anon_sym_XOR] = ACTIONS(2573),
    [anon_sym_Xor] = ACTIONS(2573),
    [anon_sym_QMARK] = ACTIONS(2575),
    [sym_datetime_literal] = ACTIONS(2575),
    [sym_date_literal] = ACTIONS(2573),
    [sym_time_literal] = ACTIONS(2573),
    [sym_biginteger_literal] = ACTIONS(2575),
    [anon_sym_else] = ACTIONS(2573),
    [anon_sym_ELSE] = ACTIONS(2573),
    [anon_sym_Else] = ACTIONS(2573),
    [anon_sym_in] = ACTIONS(2573),
    [anon_sym_IN] = ACTIONS(2573),
    [anon_sym_In] = ACTIONS(2573),
    [sym_page_keyword] = ACTIONS(2573),
    [anon_sym_codeunit] = ACTIONS(2573),
    [anon_sym_CODEUNIT] = ACTIONS(2573),
    [anon_sym_Codeunit] = ACTIONS(2573),
    [anon_sym_CodeUnit] = ACTIONS(2573),
    [anon_sym_COdeunit] = ACTIONS(2573),
    [anon_sym_codeUnit] = ACTIONS(2573),
    [sym_report_keyword] = ACTIONS(2573),
    [sym_query_keyword] = ACTIONS(2573),
    [anon_sym_xmlport] = ACTIONS(2573),
    [anon_sym_XMLPORT] = ACTIONS(2573),
    [anon_sym_Xmlport] = ACTIONS(2573),
    [anon_sym_XMLport] = ACTIONS(2573),
    [anon_sym_XMLPort] = ACTIONS(2573),
    [anon_sym_XmlPort] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_ENUM] = ACTIONS(2573),
    [anon_sym_Enum] = ACTIONS(2573),
    [anon_sym_eNUM] = ACTIONS(2573),
    [anon_sym_eNum] = ACTIONS(2573),
    [anon_sym_ENum] = ACTIONS(2573),
    [sym_quoted_identifier] = ACTIONS(2575),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2575),
    [sym_integer] = ACTIONS(2573),
    [sym_continue_as_identifier] = ACTIONS(2575),
    [sym_preproc_open] = ACTIONS(2575),
  },
  [STATE(2141)] = {
    [sym_identifier] = ACTIONS(2577),
    [anon_sym_SEMI] = ACTIONS(2579),
    [anon_sym_DOT] = ACTIONS(2577),
    [anon_sym_EQ] = ACTIONS(2579),
    [anon_sym_COMMA] = ACTIONS(2579),
    [anon_sym_COLON] = ACTIONS(2577),
    [anon_sym_DASH] = ACTIONS(2577),
    [aux_sym_boolean_token1] = ACTIONS(2577),
    [aux_sym_boolean_token2] = ACTIONS(2577),
    [sym_decimal] = ACTIONS(2577),
    [anon_sym_LPAREN] = ACTIONS(2579),
    [anon_sym_DOT_DOT] = ACTIONS(2579),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2577),
    [anon_sym_STAR] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [aux_sym_record_type_token1] = ACTIONS(2577),
    [aux_sym_basic_type_token21] = ACTIONS(2577),
    [aux_sym_basic_type_token22] = ACTIONS(2577),
    [aux_sym_basic_type_token48] = ACTIONS(2577),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2577),
    [anon_sym_POUNDif] = ACTIONS(2579),
    [anon_sym_POUNDIF] = ACTIONS(2579),
    [anon_sym_POUNDIf] = ACTIONS(2579),
    [anon_sym_not] = ACTIONS(2577),
    [anon_sym_NOT] = ACTIONS(2577),
    [anon_sym_Not] = ACTIONS(2577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2579),
    [aux_sym__expression_token1] = ACTIONS(2579),
    [aux_sym__expression_token2] = ACTIONS(2579),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2577),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2577),
    [anon_sym_SLASH] = ACTIONS(2577),
    [anon_sym_div] = ACTIONS(2577),
    [anon_sym_DIV] = ACTIONS(2577),
    [anon_sym_Div] = ACTIONS(2577),
    [anon_sym_mod] = ACTIONS(2577),
    [anon_sym_MOD] = ACTIONS(2577),
    [anon_sym_Mod] = ACTIONS(2577),
    [anon_sym_PLUS] = ACTIONS(2577),
    [anon_sym_GT_EQ] = ACTIONS(2579),
    [anon_sym_LT_EQ] = ACTIONS(2579),
    [anon_sym_GT] = ACTIONS(2577),
    [anon_sym_LT] = ACTIONS(2577),
    [anon_sym_LT_GT] = ACTIONS(2579),
    [anon_sym_and] = ACTIONS(2577),
    [anon_sym_AND] = ACTIONS(2577),
    [anon_sym_And] = ACTIONS(2577),
    [anon_sym_or] = ACTIONS(2577),
    [anon_sym_OR] = ACTIONS(2577),
    [anon_sym_Or] = ACTIONS(2577),
    [anon_sym_xor] = ACTIONS(2577),
    [anon_sym_XOR] = ACTIONS(2577),
    [anon_sym_Xor] = ACTIONS(2577),
    [anon_sym_QMARK] = ACTIONS(2579),
    [sym_datetime_literal] = ACTIONS(2579),
    [sym_date_literal] = ACTIONS(2577),
    [sym_time_literal] = ACTIONS(2577),
    [sym_biginteger_literal] = ACTIONS(2579),
    [anon_sym_else] = ACTIONS(2577),
    [anon_sym_ELSE] = ACTIONS(2577),
    [anon_sym_Else] = ACTIONS(2577),
    [anon_sym_in] = ACTIONS(2577),
    [anon_sym_IN] = ACTIONS(2577),
    [anon_sym_In] = ACTIONS(2577),
    [sym_page_keyword] = ACTIONS(2577),
    [anon_sym_codeunit] = ACTIONS(2577),
    [anon_sym_CODEUNIT] = ACTIONS(2577),
    [anon_sym_Codeunit] = ACTIONS(2577),
    [anon_sym_CodeUnit] = ACTIONS(2577),
    [anon_sym_COdeunit] = ACTIONS(2577),
    [anon_sym_codeUnit] = ACTIONS(2577),
    [sym_report_keyword] = ACTIONS(2577),
    [sym_query_keyword] = ACTIONS(2577),
    [anon_sym_xmlport] = ACTIONS(2577),
    [anon_sym_XMLPORT] = ACTIONS(2577),
    [anon_sym_Xmlport] = ACTIONS(2577),
    [anon_sym_XMLport] = ACTIONS(2577),
    [anon_sym_XMLPort] = ACTIONS(2577),
    [anon_sym_XmlPort] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_ENUM] = ACTIONS(2577),
    [anon_sym_Enum] = ACTIONS(2577),
    [anon_sym_eNUM] = ACTIONS(2577),
    [anon_sym_eNum] = ACTIONS(2577),
    [anon_sym_ENum] = ACTIONS(2577),
    [sym_quoted_identifier] = ACTIONS(2579),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2579),
    [sym_integer] = ACTIONS(2577),
    [sym_continue_as_identifier] = ACTIONS(2579),
    [sym_preproc_open] = ACTIONS(2579),
  },
  [STATE(2142)] = {
    [sym_identifier] = ACTIONS(2581),
    [anon_sym_SEMI] = ACTIONS(2583),
    [anon_sym_DOT] = ACTIONS(2581),
    [anon_sym_EQ] = ACTIONS(2583),
    [anon_sym_COMMA] = ACTIONS(2583),
    [anon_sym_COLON] = ACTIONS(2581),
    [anon_sym_DASH] = ACTIONS(2581),
    [aux_sym_boolean_token1] = ACTIONS(2581),
    [aux_sym_boolean_token2] = ACTIONS(2581),
    [sym_decimal] = ACTIONS(2581),
    [anon_sym_LPAREN] = ACTIONS(2583),
    [anon_sym_DOT_DOT] = ACTIONS(2583),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2581),
    [anon_sym_STAR] = ACTIONS(2581),
    [anon_sym_LBRACK] = ACTIONS(2583),
    [aux_sym_record_type_token1] = ACTIONS(2581),
    [aux_sym_basic_type_token21] = ACTIONS(2581),
    [aux_sym_basic_type_token22] = ACTIONS(2581),
    [aux_sym_basic_type_token48] = ACTIONS(2581),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2581),
    [anon_sym_POUNDif] = ACTIONS(2583),
    [anon_sym_POUNDIF] = ACTIONS(2583),
    [anon_sym_POUNDIf] = ACTIONS(2583),
    [anon_sym_not] = ACTIONS(2581),
    [anon_sym_NOT] = ACTIONS(2581),
    [anon_sym_Not] = ACTIONS(2581),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2583),
    [aux_sym__expression_token1] = ACTIONS(2583),
    [aux_sym__expression_token2] = ACTIONS(2583),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2581),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2581),
    [anon_sym_SLASH] = ACTIONS(2581),
    [anon_sym_div] = ACTIONS(2581),
    [anon_sym_DIV] = ACTIONS(2581),
    [anon_sym_Div] = ACTIONS(2581),
    [anon_sym_mod] = ACTIONS(2581),
    [anon_sym_MOD] = ACTIONS(2581),
    [anon_sym_Mod] = ACTIONS(2581),
    [anon_sym_PLUS] = ACTIONS(2581),
    [anon_sym_GT_EQ] = ACTIONS(2583),
    [anon_sym_LT_EQ] = ACTIONS(2583),
    [anon_sym_GT] = ACTIONS(2581),
    [anon_sym_LT] = ACTIONS(2581),
    [anon_sym_LT_GT] = ACTIONS(2583),
    [anon_sym_and] = ACTIONS(2581),
    [anon_sym_AND] = ACTIONS(2581),
    [anon_sym_And] = ACTIONS(2581),
    [anon_sym_or] = ACTIONS(2581),
    [anon_sym_OR] = ACTIONS(2581),
    [anon_sym_Or] = ACTIONS(2581),
    [anon_sym_xor] = ACTIONS(2581),
    [anon_sym_XOR] = ACTIONS(2581),
    [anon_sym_Xor] = ACTIONS(2581),
    [anon_sym_QMARK] = ACTIONS(2583),
    [sym_datetime_literal] = ACTIONS(2583),
    [sym_date_literal] = ACTIONS(2581),
    [sym_time_literal] = ACTIONS(2581),
    [sym_biginteger_literal] = ACTIONS(2583),
    [anon_sym_else] = ACTIONS(2581),
    [anon_sym_ELSE] = ACTIONS(2581),
    [anon_sym_Else] = ACTIONS(2581),
    [anon_sym_in] = ACTIONS(2581),
    [anon_sym_IN] = ACTIONS(2581),
    [anon_sym_In] = ACTIONS(2581),
    [sym_page_keyword] = ACTIONS(2581),
    [anon_sym_codeunit] = ACTIONS(2581),
    [anon_sym_CODEUNIT] = ACTIONS(2581),
    [anon_sym_Codeunit] = ACTIONS(2581),
    [anon_sym_CodeUnit] = ACTIONS(2581),
    [anon_sym_COdeunit] = ACTIONS(2581),
    [anon_sym_codeUnit] = ACTIONS(2581),
    [sym_report_keyword] = ACTIONS(2581),
    [sym_query_keyword] = ACTIONS(2581),
    [anon_sym_xmlport] = ACTIONS(2581),
    [anon_sym_XMLPORT] = ACTIONS(2581),
    [anon_sym_Xmlport] = ACTIONS(2581),
    [anon_sym_XMLport] = ACTIONS(2581),
    [anon_sym_XMLPort] = ACTIONS(2581),
    [anon_sym_XmlPort] = ACTIONS(2581),
    [anon_sym_enum] = ACTIONS(2581),
    [anon_sym_ENUM] = ACTIONS(2581),
    [anon_sym_Enum] = ACTIONS(2581),
    [anon_sym_eNUM] = ACTIONS(2581),
    [anon_sym_eNum] = ACTIONS(2581),
    [anon_sym_ENum] = ACTIONS(2581),
    [sym_quoted_identifier] = ACTIONS(2583),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2583),
    [sym_integer] = ACTIONS(2581),
    [sym_continue_as_identifier] = ACTIONS(2583),
    [sym_preproc_open] = ACTIONS(2583),
  },
  [STATE(2143)] = {
    [sym_identifier] = ACTIONS(2569),
    [anon_sym_SEMI] = ACTIONS(2571),
    [anon_sym_DOT] = ACTIONS(2569),
    [anon_sym_EQ] = ACTIONS(2571),
    [anon_sym_COMMA] = ACTIONS(2571),
    [anon_sym_COLON] = ACTIONS(2569),
    [anon_sym_DASH] = ACTIONS(2569),
    [aux_sym_boolean_token1] = ACTIONS(2569),
    [aux_sym_boolean_token2] = ACTIONS(2569),
    [sym_decimal] = ACTIONS(2569),
    [anon_sym_LPAREN] = ACTIONS(2571),
    [anon_sym_DOT_DOT] = ACTIONS(2571),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2569),
    [anon_sym_STAR] = ACTIONS(2569),
    [anon_sym_LBRACK] = ACTIONS(2571),
    [aux_sym_record_type_token1] = ACTIONS(2569),
    [aux_sym_basic_type_token21] = ACTIONS(2569),
    [aux_sym_basic_type_token22] = ACTIONS(2569),
    [aux_sym_basic_type_token48] = ACTIONS(2569),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2569),
    [anon_sym_POUNDif] = ACTIONS(2571),
    [anon_sym_POUNDIF] = ACTIONS(2571),
    [anon_sym_POUNDIf] = ACTIONS(2571),
    [anon_sym_not] = ACTIONS(2569),
    [anon_sym_NOT] = ACTIONS(2569),
    [anon_sym_Not] = ACTIONS(2569),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2571),
    [aux_sym__expression_token1] = ACTIONS(2571),
    [aux_sym__expression_token2] = ACTIONS(2571),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2569),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2569),
    [anon_sym_SLASH] = ACTIONS(2569),
    [anon_sym_div] = ACTIONS(2569),
    [anon_sym_DIV] = ACTIONS(2569),
    [anon_sym_Div] = ACTIONS(2569),
    [anon_sym_mod] = ACTIONS(2569),
    [anon_sym_MOD] = ACTIONS(2569),
    [anon_sym_Mod] = ACTIONS(2569),
    [anon_sym_PLUS] = ACTIONS(2569),
    [anon_sym_GT_EQ] = ACTIONS(2571),
    [anon_sym_LT_EQ] = ACTIONS(2571),
    [anon_sym_GT] = ACTIONS(2569),
    [anon_sym_LT] = ACTIONS(2569),
    [anon_sym_LT_GT] = ACTIONS(2571),
    [anon_sym_and] = ACTIONS(2569),
    [anon_sym_AND] = ACTIONS(2569),
    [anon_sym_And] = ACTIONS(2569),
    [anon_sym_or] = ACTIONS(2569),
    [anon_sym_OR] = ACTIONS(2569),
    [anon_sym_Or] = ACTIONS(2569),
    [anon_sym_xor] = ACTIONS(2569),
    [anon_sym_XOR] = ACTIONS(2569),
    [anon_sym_Xor] = ACTIONS(2569),
    [anon_sym_QMARK] = ACTIONS(2571),
    [sym_datetime_literal] = ACTIONS(2571),
    [sym_date_literal] = ACTIONS(2569),
    [sym_time_literal] = ACTIONS(2569),
    [sym_biginteger_literal] = ACTIONS(2571),
    [anon_sym_else] = ACTIONS(2569),
    [anon_sym_ELSE] = ACTIONS(2569),
    [anon_sym_Else] = ACTIONS(2569),
    [anon_sym_in] = ACTIONS(2569),
    [anon_sym_IN] = ACTIONS(2569),
    [anon_sym_In] = ACTIONS(2569),
    [sym_page_keyword] = ACTIONS(2569),
    [anon_sym_codeunit] = ACTIONS(2569),
    [anon_sym_CODEUNIT] = ACTIONS(2569),
    [anon_sym_Codeunit] = ACTIONS(2569),
    [anon_sym_CodeUnit] = ACTIONS(2569),
    [anon_sym_COdeunit] = ACTIONS(2569),
    [anon_sym_codeUnit] = ACTIONS(2569),
    [sym_report_keyword] = ACTIONS(2569),
    [sym_query_keyword] = ACTIONS(2569),
    [anon_sym_xmlport] = ACTIONS(2569),
    [anon_sym_XMLPORT] = ACTIONS(2569),
    [anon_sym_Xmlport] = ACTIONS(2569),
    [anon_sym_XMLport] = ACTIONS(2569),
    [anon_sym_XMLPort] = ACTIONS(2569),
    [anon_sym_XmlPort] = ACTIONS(2569),
    [anon_sym_enum] = ACTIONS(2569),
    [anon_sym_ENUM] = ACTIONS(2569),
    [anon_sym_Enum] = ACTIONS(2569),
    [anon_sym_eNUM] = ACTIONS(2569),
    [anon_sym_eNum] = ACTIONS(2569),
    [anon_sym_ENum] = ACTIONS(2569),
    [sym_quoted_identifier] = ACTIONS(2571),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2571),
    [sym_integer] = ACTIONS(2569),
    [sym_continue_as_identifier] = ACTIONS(2571),
    [sym_preproc_open] = ACTIONS(2571),
  },
  [STATE(2144)] = {
    [sym_identifier] = ACTIONS(2609),
    [anon_sym_SEMI] = ACTIONS(2611),
    [anon_sym_DOT] = ACTIONS(2609),
    [anon_sym_EQ] = ACTIONS(2611),
    [anon_sym_COMMA] = ACTIONS(2611),
    [anon_sym_COLON] = ACTIONS(2609),
    [anon_sym_DASH] = ACTIONS(2609),
    [aux_sym_boolean_token1] = ACTIONS(2609),
    [aux_sym_boolean_token2] = ACTIONS(2609),
    [sym_decimal] = ACTIONS(2609),
    [anon_sym_LPAREN] = ACTIONS(2611),
    [anon_sym_DOT_DOT] = ACTIONS(2611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2609),
    [anon_sym_STAR] = ACTIONS(2609),
    [anon_sym_LBRACK] = ACTIONS(2611),
    [aux_sym_record_type_token1] = ACTIONS(2609),
    [aux_sym_basic_type_token21] = ACTIONS(2609),
    [aux_sym_basic_type_token22] = ACTIONS(2609),
    [aux_sym_basic_type_token48] = ACTIONS(2609),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2609),
    [anon_sym_POUNDif] = ACTIONS(2611),
    [anon_sym_POUNDIF] = ACTIONS(2611),
    [anon_sym_POUNDIf] = ACTIONS(2611),
    [anon_sym_not] = ACTIONS(2609),
    [anon_sym_NOT] = ACTIONS(2609),
    [anon_sym_Not] = ACTIONS(2609),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2611),
    [aux_sym__expression_token1] = ACTIONS(2611),
    [aux_sym__expression_token2] = ACTIONS(2611),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2609),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2609),
    [anon_sym_SLASH] = ACTIONS(2609),
    [anon_sym_div] = ACTIONS(2609),
    [anon_sym_DIV] = ACTIONS(2609),
    [anon_sym_Div] = ACTIONS(2609),
    [anon_sym_mod] = ACTIONS(2609),
    [anon_sym_MOD] = ACTIONS(2609),
    [anon_sym_Mod] = ACTIONS(2609),
    [anon_sym_PLUS] = ACTIONS(2609),
    [anon_sym_GT_EQ] = ACTIONS(2611),
    [anon_sym_LT_EQ] = ACTIONS(2611),
    [anon_sym_GT] = ACTIONS(2609),
    [anon_sym_LT] = ACTIONS(2609),
    [anon_sym_LT_GT] = ACTIONS(2611),
    [anon_sym_and] = ACTIONS(2609),
    [anon_sym_AND] = ACTIONS(2609),
    [anon_sym_And] = ACTIONS(2609),
    [anon_sym_or] = ACTIONS(2609),
    [anon_sym_OR] = ACTIONS(2609),
    [anon_sym_Or] = ACTIONS(2609),
    [anon_sym_xor] = ACTIONS(2609),
    [anon_sym_XOR] = ACTIONS(2609),
    [anon_sym_Xor] = ACTIONS(2609),
    [anon_sym_QMARK] = ACTIONS(2611),
    [sym_datetime_literal] = ACTIONS(2611),
    [sym_date_literal] = ACTIONS(2609),
    [sym_time_literal] = ACTIONS(2609),
    [sym_biginteger_literal] = ACTIONS(2611),
    [anon_sym_else] = ACTIONS(2609),
    [anon_sym_ELSE] = ACTIONS(2609),
    [anon_sym_Else] = ACTIONS(2609),
    [anon_sym_in] = ACTIONS(2609),
    [anon_sym_IN] = ACTIONS(2609),
    [anon_sym_In] = ACTIONS(2609),
    [sym_page_keyword] = ACTIONS(2609),
    [anon_sym_codeunit] = ACTIONS(2609),
    [anon_sym_CODEUNIT] = ACTIONS(2609),
    [anon_sym_Codeunit] = ACTIONS(2609),
    [anon_sym_CodeUnit] = ACTIONS(2609),
    [anon_sym_COdeunit] = ACTIONS(2609),
    [anon_sym_codeUnit] = ACTIONS(2609),
    [sym_report_keyword] = ACTIONS(2609),
    [sym_query_keyword] = ACTIONS(2609),
    [anon_sym_xmlport] = ACTIONS(2609),
    [anon_sym_XMLPORT] = ACTIONS(2609),
    [anon_sym_Xmlport] = ACTIONS(2609),
    [anon_sym_XMLport] = ACTIONS(2609),
    [anon_sym_XMLPort] = ACTIONS(2609),
    [anon_sym_XmlPort] = ACTIONS(2609),
    [anon_sym_enum] = ACTIONS(2609),
    [anon_sym_ENUM] = ACTIONS(2609),
    [anon_sym_Enum] = ACTIONS(2609),
    [anon_sym_eNUM] = ACTIONS(2609),
    [anon_sym_eNum] = ACTIONS(2609),
    [anon_sym_ENum] = ACTIONS(2609),
    [sym_quoted_identifier] = ACTIONS(2611),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2611),
    [sym_integer] = ACTIONS(2609),
    [sym_continue_as_identifier] = ACTIONS(2611),
    [sym_preproc_open] = ACTIONS(2611),
  },
  [STATE(2145)] = {
    [sym_identifier] = ACTIONS(2601),
    [anon_sym_DOT] = ACTIONS(2601),
    [anon_sym_EQ] = ACTIONS(2603),
    [anon_sym_COMMA] = ACTIONS(2603),
    [anon_sym_DASH] = ACTIONS(2601),
    [aux_sym_boolean_token1] = ACTIONS(2601),
    [aux_sym_boolean_token2] = ACTIONS(2601),
    [sym_decimal] = ACTIONS(2601),
    [anon_sym_LPAREN] = ACTIONS(2603),
    [anon_sym_DOT_DOT] = ACTIONS(2603),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2601),
    [anon_sym_STAR] = ACTIONS(2601),
    [anon_sym_LBRACK] = ACTIONS(2603),
    [aux_sym_record_type_token1] = ACTIONS(2601),
    [aux_sym_basic_type_token21] = ACTIONS(2601),
    [aux_sym_basic_type_token22] = ACTIONS(2601),
    [aux_sym_basic_type_token48] = ACTIONS(2601),
    [anon_sym_not] = ACTIONS(2601),
    [anon_sym_NOT] = ACTIONS(2601),
    [anon_sym_Not] = ACTIONS(2601),
    [anon_sym_POUNDelif] = ACTIONS(2603),
    [anon_sym_POUNDELIF] = ACTIONS(2603),
    [anon_sym_POUNDElif] = ACTIONS(2603),
    [anon_sym_POUNDelse] = ACTIONS(2603),
    [anon_sym_POUNDELSE] = ACTIONS(2603),
    [anon_sym_POUNDElse] = ACTIONS(2603),
    [anon_sym_POUNDendif] = ACTIONS(2603),
    [anon_sym_POUNDENDIF] = ACTIONS(2603),
    [anon_sym_POUNDEndif] = ACTIONS(2603),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2603),
    [aux_sym__expression_token1] = ACTIONS(2603),
    [aux_sym__expression_token2] = ACTIONS(2603),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2601),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2601),
    [anon_sym_SLASH] = ACTIONS(2601),
    [anon_sym_div] = ACTIONS(2601),
    [anon_sym_DIV] = ACTIONS(2601),
    [anon_sym_Div] = ACTIONS(2601),
    [anon_sym_mod] = ACTIONS(2601),
    [anon_sym_MOD] = ACTIONS(2601),
    [anon_sym_Mod] = ACTIONS(2601),
    [anon_sym_PLUS] = ACTIONS(2601),
    [anon_sym_GT_EQ] = ACTIONS(2603),
    [anon_sym_LT_EQ] = ACTIONS(2603),
    [anon_sym_GT] = ACTIONS(2601),
    [anon_sym_LT] = ACTIONS(2601),
    [anon_sym_LT_GT] = ACTIONS(2603),
    [anon_sym_and] = ACTIONS(2601),
    [anon_sym_AND] = ACTIONS(2601),
    [anon_sym_And] = ACTIONS(2601),
    [anon_sym_or] = ACTIONS(2601),
    [anon_sym_OR] = ACTIONS(2601),
    [anon_sym_Or] = ACTIONS(2601),
    [anon_sym_xor] = ACTIONS(2601),
    [anon_sym_XOR] = ACTIONS(2601),
    [anon_sym_Xor] = ACTIONS(2601),
    [anon_sym_QMARK] = ACTIONS(2603),
    [sym_datetime_literal] = ACTIONS(2603),
    [sym_date_literal] = ACTIONS(2601),
    [sym_time_literal] = ACTIONS(2601),
    [sym_biginteger_literal] = ACTIONS(2603),
    [anon_sym_in] = ACTIONS(2601),
    [anon_sym_IN] = ACTIONS(2601),
    [anon_sym_In] = ACTIONS(2601),
    [sym_page_keyword] = ACTIONS(2601),
    [anon_sym_codeunit] = ACTIONS(2601),
    [anon_sym_CODEUNIT] = ACTIONS(2601),
    [anon_sym_Codeunit] = ACTIONS(2601),
    [anon_sym_CodeUnit] = ACTIONS(2601),
    [anon_sym_COdeunit] = ACTIONS(2601),
    [anon_sym_codeUnit] = ACTIONS(2601),
    [sym_report_keyword] = ACTIONS(2601),
    [sym_query_keyword] = ACTIONS(2601),
    [anon_sym_xmlport] = ACTIONS(2601),
    [anon_sym_XMLPORT] = ACTIONS(2601),
    [anon_sym_Xmlport] = ACTIONS(2601),
    [anon_sym_XMLport] = ACTIONS(2601),
    [anon_sym_XMLPort] = ACTIONS(2601),
    [anon_sym_XmlPort] = ACTIONS(2601),
    [anon_sym_enum] = ACTIONS(2601),
    [anon_sym_ENUM] = ACTIONS(2601),
    [anon_sym_Enum] = ACTIONS(2601),
    [anon_sym_eNUM] = ACTIONS(2601),
    [anon_sym_eNum] = ACTIONS(2601),
    [anon_sym_ENum] = ACTIONS(2601),
    [sym_quoted_identifier] = ACTIONS(2603),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2603),
    [sym_integer] = ACTIONS(2601),
    [sym_continue_as_identifier] = ACTIONS(2603),
    [sym_preproc_close] = ACTIONS(2603),
  },
  [STATE(2146)] = {
    [sym_identifier] = ACTIONS(2609),
    [anon_sym_DOT] = ACTIONS(2609),
    [anon_sym_EQ] = ACTIONS(2611),
    [anon_sym_COMMA] = ACTIONS(2611),
    [anon_sym_DASH] = ACTIONS(2609),
    [aux_sym_boolean_token1] = ACTIONS(2609),
    [aux_sym_boolean_token2] = ACTIONS(2609),
    [sym_decimal] = ACTIONS(2609),
    [anon_sym_LPAREN] = ACTIONS(2611),
    [anon_sym_DOT_DOT] = ACTIONS(2611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2609),
    [anon_sym_STAR] = ACTIONS(2609),
    [anon_sym_LBRACK] = ACTIONS(2611),
    [aux_sym_record_type_token1] = ACTIONS(2609),
    [aux_sym_basic_type_token21] = ACTIONS(2609),
    [aux_sym_basic_type_token22] = ACTIONS(2609),
    [aux_sym_basic_type_token48] = ACTIONS(2609),
    [anon_sym_not] = ACTIONS(2609),
    [anon_sym_NOT] = ACTIONS(2609),
    [anon_sym_Not] = ACTIONS(2609),
    [anon_sym_POUNDelif] = ACTIONS(2611),
    [anon_sym_POUNDELIF] = ACTIONS(2611),
    [anon_sym_POUNDElif] = ACTIONS(2611),
    [anon_sym_POUNDelse] = ACTIONS(2611),
    [anon_sym_POUNDELSE] = ACTIONS(2611),
    [anon_sym_POUNDElse] = ACTIONS(2611),
    [anon_sym_POUNDendif] = ACTIONS(2611),
    [anon_sym_POUNDENDIF] = ACTIONS(2611),
    [anon_sym_POUNDEndif] = ACTIONS(2611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2611),
    [aux_sym__expression_token1] = ACTIONS(2611),
    [aux_sym__expression_token2] = ACTIONS(2611),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2609),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2609),
    [anon_sym_SLASH] = ACTIONS(2609),
    [anon_sym_div] = ACTIONS(2609),
    [anon_sym_DIV] = ACTIONS(2609),
    [anon_sym_Div] = ACTIONS(2609),
    [anon_sym_mod] = ACTIONS(2609),
    [anon_sym_MOD] = ACTIONS(2609),
    [anon_sym_Mod] = ACTIONS(2609),
    [anon_sym_PLUS] = ACTIONS(2609),
    [anon_sym_GT_EQ] = ACTIONS(2611),
    [anon_sym_LT_EQ] = ACTIONS(2611),
    [anon_sym_GT] = ACTIONS(2609),
    [anon_sym_LT] = ACTIONS(2609),
    [anon_sym_LT_GT] = ACTIONS(2611),
    [anon_sym_and] = ACTIONS(2609),
    [anon_sym_AND] = ACTIONS(2609),
    [anon_sym_And] = ACTIONS(2609),
    [anon_sym_or] = ACTIONS(2609),
    [anon_sym_OR] = ACTIONS(2609),
    [anon_sym_Or] = ACTIONS(2609),
    [anon_sym_xor] = ACTIONS(2609),
    [anon_sym_XOR] = ACTIONS(2609),
    [anon_sym_Xor] = ACTIONS(2609),
    [anon_sym_QMARK] = ACTIONS(2611),
    [sym_datetime_literal] = ACTIONS(2611),
    [sym_date_literal] = ACTIONS(2609),
    [sym_time_literal] = ACTIONS(2609),
    [sym_biginteger_literal] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(2609),
    [anon_sym_IN] = ACTIONS(2609),
    [anon_sym_In] = ACTIONS(2609),
    [sym_page_keyword] = ACTIONS(2609),
    [anon_sym_codeunit] = ACTIONS(2609),
    [anon_sym_CODEUNIT] = ACTIONS(2609),
    [anon_sym_Codeunit] = ACTIONS(2609),
    [anon_sym_CodeUnit] = ACTIONS(2609),
    [anon_sym_COdeunit] = ACTIONS(2609),
    [anon_sym_codeUnit] = ACTIONS(2609),
    [sym_report_keyword] = ACTIONS(2609),
    [sym_query_keyword] = ACTIONS(2609),
    [anon_sym_xmlport] = ACTIONS(2609),
    [anon_sym_XMLPORT] = ACTIONS(2609),
    [anon_sym_Xmlport] = ACTIONS(2609),
    [anon_sym_XMLport] = ACTIONS(2609),
    [anon_sym_XMLPort] = ACTIONS(2609),
    [anon_sym_XmlPort] = ACTIONS(2609),
    [anon_sym_enum] = ACTIONS(2609),
    [anon_sym_ENUM] = ACTIONS(2609),
    [anon_sym_Enum] = ACTIONS(2609),
    [anon_sym_eNUM] = ACTIONS(2609),
    [anon_sym_eNum] = ACTIONS(2609),
    [anon_sym_ENum] = ACTIONS(2609),
    [sym_quoted_identifier] = ACTIONS(2611),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2611),
    [sym_integer] = ACTIONS(2609),
    [sym_continue_as_identifier] = ACTIONS(2611),
    [sym_preproc_close] = ACTIONS(2611),
  },
  [STATE(2147)] = {
    [sym_identifier] = ACTIONS(2637),
    [anon_sym_DOT] = ACTIONS(2637),
    [anon_sym_EQ] = ACTIONS(2639),
    [anon_sym_COMMA] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [aux_sym_boolean_token1] = ACTIONS(2637),
    [aux_sym_boolean_token2] = ACTIONS(2637),
    [sym_decimal] = ACTIONS(2637),
    [anon_sym_LPAREN] = ACTIONS(2639),
    [anon_sym_DOT_DOT] = ACTIONS(2639),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(2637),
    [anon_sym_LBRACK] = ACTIONS(2639),
    [aux_sym_record_type_token1] = ACTIONS(2637),
    [aux_sym_basic_type_token21] = ACTIONS(2637),
    [aux_sym_basic_type_token22] = ACTIONS(2637),
    [aux_sym_basic_type_token48] = ACTIONS(2637),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_NOT] = ACTIONS(2637),
    [anon_sym_Not] = ACTIONS(2637),
    [anon_sym_POUNDelif] = ACTIONS(2639),
    [anon_sym_POUNDELIF] = ACTIONS(2639),
    [anon_sym_POUNDElif] = ACTIONS(2639),
    [anon_sym_POUNDelse] = ACTIONS(2639),
    [anon_sym_POUNDELSE] = ACTIONS(2639),
    [anon_sym_POUNDElse] = ACTIONS(2639),
    [anon_sym_POUNDendif] = ACTIONS(2639),
    [anon_sym_POUNDENDIF] = ACTIONS(2639),
    [anon_sym_POUNDEndif] = ACTIONS(2639),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2639),
    [aux_sym__expression_token1] = ACTIONS(2639),
    [aux_sym__expression_token2] = ACTIONS(2639),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2637),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2637),
    [anon_sym_SLASH] = ACTIONS(2637),
    [anon_sym_div] = ACTIONS(2637),
    [anon_sym_DIV] = ACTIONS(2637),
    [anon_sym_Div] = ACTIONS(2637),
    [anon_sym_mod] = ACTIONS(2637),
    [anon_sym_MOD] = ACTIONS(2637),
    [anon_sym_Mod] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_GT_EQ] = ACTIONS(2639),
    [anon_sym_LT_EQ] = ACTIONS(2639),
    [anon_sym_GT] = ACTIONS(2637),
    [anon_sym_LT] = ACTIONS(2637),
    [anon_sym_LT_GT] = ACTIONS(2639),
    [anon_sym_and] = ACTIONS(2637),
    [anon_sym_AND] = ACTIONS(2637),
    [anon_sym_And] = ACTIONS(2637),
    [anon_sym_or] = ACTIONS(2637),
    [anon_sym_OR] = ACTIONS(2637),
    [anon_sym_Or] = ACTIONS(2637),
    [anon_sym_xor] = ACTIONS(2637),
    [anon_sym_XOR] = ACTIONS(2637),
    [anon_sym_Xor] = ACTIONS(2637),
    [anon_sym_QMARK] = ACTIONS(2639),
    [sym_datetime_literal] = ACTIONS(2639),
    [sym_date_literal] = ACTIONS(2637),
    [sym_time_literal] = ACTIONS(2637),
    [sym_biginteger_literal] = ACTIONS(2639),
    [anon_sym_in] = ACTIONS(2637),
    [anon_sym_IN] = ACTIONS(2637),
    [anon_sym_In] = ACTIONS(2637),
    [sym_page_keyword] = ACTIONS(2637),
    [anon_sym_codeunit] = ACTIONS(2637),
    [anon_sym_CODEUNIT] = ACTIONS(2637),
    [anon_sym_Codeunit] = ACTIONS(2637),
    [anon_sym_CodeUnit] = ACTIONS(2637),
    [anon_sym_COdeunit] = ACTIONS(2637),
    [anon_sym_codeUnit] = ACTIONS(2637),
    [sym_report_keyword] = ACTIONS(2637),
    [sym_query_keyword] = ACTIONS(2637),
    [anon_sym_xmlport] = ACTIONS(2637),
    [anon_sym_XMLPORT] = ACTIONS(2637),
    [anon_sym_Xmlport] = ACTIONS(2637),
    [anon_sym_XMLport] = ACTIONS(2637),
    [anon_sym_XMLPort] = ACTIONS(2637),
    [anon_sym_XmlPort] = ACTIONS(2637),
    [anon_sym_enum] = ACTIONS(2637),
    [anon_sym_ENUM] = ACTIONS(2637),
    [anon_sym_Enum] = ACTIONS(2637),
    [anon_sym_eNUM] = ACTIONS(2637),
    [anon_sym_eNum] = ACTIONS(2637),
    [anon_sym_ENum] = ACTIONS(2637),
    [sym_quoted_identifier] = ACTIONS(2639),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2639),
    [sym_integer] = ACTIONS(2637),
    [sym_continue_as_identifier] = ACTIONS(2639),
    [sym_preproc_close] = ACTIONS(2639),
  },
  [STATE(2148)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_COMMA] = ACTIONS(2595),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [anon_sym_POUNDelif] = ACTIONS(2595),
    [anon_sym_POUNDELIF] = ACTIONS(2595),
    [anon_sym_POUNDElif] = ACTIONS(2595),
    [anon_sym_POUNDelse] = ACTIONS(2595),
    [anon_sym_POUNDELSE] = ACTIONS(2595),
    [anon_sym_POUNDElse] = ACTIONS(2595),
    [anon_sym_POUNDendif] = ACTIONS(2595),
    [anon_sym_POUNDENDIF] = ACTIONS(2595),
    [anon_sym_POUNDEndif] = ACTIONS(2595),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2595),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_close] = ACTIONS(2595),
  },
  [STATE(2149)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_COMMA] = ACTIONS(2595),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [anon_sym_POUNDelif] = ACTIONS(2595),
    [anon_sym_POUNDELIF] = ACTIONS(2595),
    [anon_sym_POUNDElif] = ACTIONS(2595),
    [anon_sym_POUNDelse] = ACTIONS(2595),
    [anon_sym_POUNDELSE] = ACTIONS(2595),
    [anon_sym_POUNDElse] = ACTIONS(2595),
    [anon_sym_POUNDendif] = ACTIONS(2595),
    [anon_sym_POUNDENDIF] = ACTIONS(2595),
    [anon_sym_POUNDEndif] = ACTIONS(2595),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2595),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_close] = ACTIONS(2595),
  },
  [STATE(2150)] = {
    [sym_boolean] = STATE(5930),
    [sym_option_member] = STATE(5907),
    [sym_keyword_identifier] = STATE(5930),
    [sym_codeunit_keyword] = STATE(5973),
    [sym_xmlport_keyword] = STATE(5973),
    [sym_enum_keyword] = STATE(5973),
    [sym_keyword_as_identifier] = STATE(5930),
    [aux_sym_option_member_list_repeat2] = STATE(2527),
    [sym_identifier] = ACTIONS(5391),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(5431),
    [anon_sym_DASH] = ACTIONS(5395),
    [aux_sym_boolean_token1] = ACTIONS(5397),
    [aux_sym_boolean_token2] = ACTIONS(5397),
    [aux_sym_where_condition_token1] = ACTIONS(5399),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5401),
    [anon_sym_LBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(5401),
    [aux_sym_basic_type_token21] = ACTIONS(5401),
    [aux_sym_basic_type_token22] = ACTIONS(5403),
    [aux_sym_basic_type_token48] = ACTIONS(5401),
    [aux_sym_basic_type_token53] = ACTIONS(5399),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5399),
    [aux_sym_modify_modification_token1] = ACTIONS(376),
    [aux_sym_separator_action_token1] = ACTIONS(5399),
    [aux_sym_assembly_declaration_token1] = ACTIONS(376),
    [aux_sym_type_declaration_token1] = ACTIONS(5399),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(376),
    [anon_sym_POUNDif] = ACTIONS(374),
    [anon_sym_POUNDIF] = ACTIONS(374),
    [anon_sym_POUNDIf] = ACTIONS(374),
    [anon_sym_POUNDelif] = ACTIONS(374),
    [anon_sym_POUNDELIF] = ACTIONS(374),
    [anon_sym_POUNDElif] = ACTIONS(374),
    [anon_sym_POUNDelse] = ACTIONS(374),
    [anon_sym_POUNDELSE] = ACTIONS(374),
    [anon_sym_POUNDElse] = ACTIONS(374),
    [anon_sym_POUNDendif] = ACTIONS(374),
    [anon_sym_POUNDENDIF] = ACTIONS(374),
    [anon_sym_POUNDEndif] = ACTIONS(374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5401),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5401),
    [sym_page_keyword] = ACTIONS(5401),
    [anon_sym_codeunit] = ACTIONS(5405),
    [anon_sym_CODEUNIT] = ACTIONS(5405),
    [anon_sym_Codeunit] = ACTIONS(5405),
    [anon_sym_CodeUnit] = ACTIONS(5405),
    [anon_sym_COdeunit] = ACTIONS(5405),
    [anon_sym_codeUnit] = ACTIONS(5405),
    [sym_report_keyword] = ACTIONS(5401),
    [sym_query_keyword] = ACTIONS(5401),
    [anon_sym_xmlport] = ACTIONS(5407),
    [anon_sym_XMLPORT] = ACTIONS(5407),
    [anon_sym_Xmlport] = ACTIONS(5407),
    [anon_sym_XMLport] = ACTIONS(5407),
    [anon_sym_XMLPort] = ACTIONS(5407),
    [anon_sym_XmlPort] = ACTIONS(5407),
    [anon_sym_enum] = ACTIONS(5409),
    [anon_sym_ENUM] = ACTIONS(5409),
    [anon_sym_Enum] = ACTIONS(5409),
    [anon_sym_eNUM] = ACTIONS(5409),
    [anon_sym_eNum] = ACTIONS(5409),
    [anon_sym_ENum] = ACTIONS(5409),
    [sym_procedure_keyword] = ACTIONS(376),
    [sym_trigger_keyword] = ACTIONS(376),
    [sym_var_keyword] = ACTIONS(376),
    [sym_local_keyword] = ACTIONS(5391),
    [sym_internal_keyword] = ACTIONS(5391),
    [sym_protected_keyword] = ACTIONS(5391),
    [sym_event_keyword] = ACTIONS(376),
    [sym_fields_keyword] = ACTIONS(376),
    [sym_keys_keyword] = ACTIONS(376),
    [sym_key_keyword] = ACTIONS(5399),
    [sym_fieldgroups_keyword] = ACTIONS(376),
    [sym_actions_keyword] = ACTIONS(376),
    [sym_layout_keyword] = ACTIONS(376),
    [sym_dataset_keyword] = ACTIONS(5399),
    [sym_elements_keyword] = ACTIONS(376),
    [sym_labels_keyword] = ACTIONS(376),
    [sym_rendering_keyword] = ACTIONS(376),
    [sym_requestpage_keyword] = ACTIONS(376),
    [sym_schema_keyword] = ACTIONS(376),
    [sym_views_keyword] = ACTIONS(376),
    [sym_quoted_identifier] = ACTIONS(5411),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5411),
    [sym_integer] = ACTIONS(5411),
    [sym_property_name] = ACTIONS(374),
    [sym_preproc_open] = ACTIONS(374),
    [sym_preproc_close] = ACTIONS(374),
    [sym_begin_keyword] = ACTIONS(374),
  },
  [STATE(2151)] = {
    [sym__body_element] = STATE(3482),
    [sym_empty_statement] = STATE(3482),
    [sym_property] = STATE(4854),
    [sym_fields_section] = STATE(3482),
    [sym_keys_section] = STATE(3482),
    [sym_fieldgroups_section] = STATE(3482),
    [sym_enum_value_declaration] = STATE(3482),
    [sym_labels_section] = STATE(3482),
    [sym_layout_section] = STATE(3482),
    [sym_modify_modification] = STATE(3482),
    [sym_actions_section] = STATE(3482),
    [sym__action_element] = STATE(5431),
    [sym_action_area_section] = STATE(5431),
    [sym_action_group_section] = STATE(5431),
    [sym_action_declaration] = STATE(5431),
    [sym_separator_action] = STATE(5431),
    [sym_actionref_declaration] = STATE(5431),
    [sym_systemaction_declaration] = STATE(5431),
    [sym_fileuploadaction_declaration] = STATE(5431),
    [sym_customaction_declaration] = STATE(5431),
    [sym_addfirst_action_modification] = STATE(5431),
    [sym_addlast_action_modification] = STATE(5431),
    [sym_addafter_action_modification] = STATE(5431),
    [sym_addbefore_action_modification] = STATE(5431),
    [sym_modify_action_modification] = STATE(5431),
    [sym_views_section] = STATE(3482),
    [sym_dataset_section] = STATE(3482),
    [sym_requestpage_section] = STATE(3482),
    [sym_rendering_section] = STATE(3482),
    [sym_elements_section] = STATE(3482),
    [sym_schema_section] = STATE(3482),
    [sym_assembly_declaration] = STATE(3482),
    [sym_event_declaration] = STATE(3482),
    [sym_procedure] = STATE(3482),
    [sym_preproc_split_procedure] = STATE(3482),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(4854),
    [sym_var_section] = STATE(3482),
    [sym_attribute_item] = STATE(4854),
    [sym_preproc_conditional] = STATE(3482),
    [sym_preproc_if] = STATE(1393),
    [sym_preproc_endif] = STATE(4858),
    [sym_preproc_conditional_actions] = STATE(5431),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3482),
    [aux_sym_actions_section_repeat1] = STATE(5431),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3676),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3678),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token22] = ACTIONS(3680),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(3682),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3684),
    [aux_sym_modify_modification_token1] = ACTIONS(3686),
    [aux_sym_separator_action_token1] = ACTIONS(3688),
    [aux_sym_actionref_declaration_token1] = ACTIONS(3690),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(3692),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(3694),
    [aux_sym_customaction_declaration_token1] = ACTIONS(3696),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(3698),
    [sym_group_keyword] = ACTIONS(3700),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(2152)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_COMMA] = ACTIONS(2595),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [anon_sym_POUNDelif] = ACTIONS(2595),
    [anon_sym_POUNDELIF] = ACTIONS(2595),
    [anon_sym_POUNDElif] = ACTIONS(2595),
    [anon_sym_POUNDelse] = ACTIONS(2595),
    [anon_sym_POUNDELSE] = ACTIONS(2595),
    [anon_sym_POUNDElse] = ACTIONS(2595),
    [anon_sym_POUNDendif] = ACTIONS(2595),
    [anon_sym_POUNDENDIF] = ACTIONS(2595),
    [anon_sym_POUNDEndif] = ACTIONS(2595),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2595),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_close] = ACTIONS(2595),
  },
  [STATE(2153)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_COMMA] = ACTIONS(2428),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [anon_sym_POUNDelif] = ACTIONS(2428),
    [anon_sym_POUNDELIF] = ACTIONS(2428),
    [anon_sym_POUNDElif] = ACTIONS(2428),
    [anon_sym_POUNDelse] = ACTIONS(2428),
    [anon_sym_POUNDELSE] = ACTIONS(2428),
    [anon_sym_POUNDElse] = ACTIONS(2428),
    [anon_sym_POUNDendif] = ACTIONS(2428),
    [anon_sym_POUNDENDIF] = ACTIONS(2428),
    [anon_sym_POUNDEndif] = ACTIONS(2428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2428),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_close] = ACTIONS(2428),
  },
  [STATE(2154)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2441),
    [sym_preproc_endif] = STATE(4653),
    [sym_assignment_expression] = STATE(6338),
    [sym_case_branch] = STATE(2177),
    [sym_preproc_split_case_branch] = STATE(3395),
    [aux_sym__case_pattern] = STATE(2579),
    [sym_preproc_conditional_case_patterns] = STATE(2579),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(9819),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(87),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(2177),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(3754),
    [anon_sym_ELSE] = ACTIONS(3754),
    [anon_sym_Else] = ACTIONS(3754),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2155)] = {
    [sym_identifier] = ACTIONS(2539),
    [anon_sym_DOT] = ACTIONS(2539),
    [anon_sym_EQ] = ACTIONS(2541),
    [anon_sym_COMMA] = ACTIONS(2541),
    [anon_sym_DASH] = ACTIONS(2539),
    [aux_sym_boolean_token1] = ACTIONS(2539),
    [aux_sym_boolean_token2] = ACTIONS(2539),
    [sym_decimal] = ACTIONS(2539),
    [anon_sym_LPAREN] = ACTIONS(2541),
    [anon_sym_DOT_DOT] = ACTIONS(2541),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2539),
    [anon_sym_STAR] = ACTIONS(2539),
    [anon_sym_LBRACK] = ACTIONS(2541),
    [aux_sym_record_type_token1] = ACTIONS(2539),
    [aux_sym_basic_type_token21] = ACTIONS(2539),
    [aux_sym_basic_type_token22] = ACTIONS(2539),
    [aux_sym_basic_type_token48] = ACTIONS(2539),
    [anon_sym_not] = ACTIONS(2539),
    [anon_sym_NOT] = ACTIONS(2539),
    [anon_sym_Not] = ACTIONS(2539),
    [anon_sym_POUNDelif] = ACTIONS(2541),
    [anon_sym_POUNDELIF] = ACTIONS(2541),
    [anon_sym_POUNDElif] = ACTIONS(2541),
    [anon_sym_POUNDelse] = ACTIONS(2541),
    [anon_sym_POUNDELSE] = ACTIONS(2541),
    [anon_sym_POUNDElse] = ACTIONS(2541),
    [anon_sym_POUNDendif] = ACTIONS(2541),
    [anon_sym_POUNDENDIF] = ACTIONS(2541),
    [anon_sym_POUNDEndif] = ACTIONS(2541),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2541),
    [aux_sym__expression_token1] = ACTIONS(2541),
    [aux_sym__expression_token2] = ACTIONS(2541),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2539),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2539),
    [anon_sym_SLASH] = ACTIONS(2539),
    [anon_sym_div] = ACTIONS(2539),
    [anon_sym_DIV] = ACTIONS(2539),
    [anon_sym_Div] = ACTIONS(2539),
    [anon_sym_mod] = ACTIONS(2539),
    [anon_sym_MOD] = ACTIONS(2539),
    [anon_sym_Mod] = ACTIONS(2539),
    [anon_sym_PLUS] = ACTIONS(2539),
    [anon_sym_GT_EQ] = ACTIONS(2541),
    [anon_sym_LT_EQ] = ACTIONS(2541),
    [anon_sym_GT] = ACTIONS(2539),
    [anon_sym_LT] = ACTIONS(2539),
    [anon_sym_LT_GT] = ACTIONS(2541),
    [anon_sym_and] = ACTIONS(2539),
    [anon_sym_AND] = ACTIONS(2539),
    [anon_sym_And] = ACTIONS(2539),
    [anon_sym_or] = ACTIONS(2539),
    [anon_sym_OR] = ACTIONS(2539),
    [anon_sym_Or] = ACTIONS(2539),
    [anon_sym_xor] = ACTIONS(2539),
    [anon_sym_XOR] = ACTIONS(2539),
    [anon_sym_Xor] = ACTIONS(2539),
    [anon_sym_QMARK] = ACTIONS(2541),
    [sym_datetime_literal] = ACTIONS(2541),
    [sym_date_literal] = ACTIONS(2539),
    [sym_time_literal] = ACTIONS(2539),
    [sym_biginteger_literal] = ACTIONS(2541),
    [anon_sym_in] = ACTIONS(2539),
    [anon_sym_IN] = ACTIONS(2539),
    [anon_sym_In] = ACTIONS(2539),
    [sym_page_keyword] = ACTIONS(2539),
    [anon_sym_codeunit] = ACTIONS(2539),
    [anon_sym_CODEUNIT] = ACTIONS(2539),
    [anon_sym_Codeunit] = ACTIONS(2539),
    [anon_sym_CodeUnit] = ACTIONS(2539),
    [anon_sym_COdeunit] = ACTIONS(2539),
    [anon_sym_codeUnit] = ACTIONS(2539),
    [sym_report_keyword] = ACTIONS(2539),
    [sym_query_keyword] = ACTIONS(2539),
    [anon_sym_xmlport] = ACTIONS(2539),
    [anon_sym_XMLPORT] = ACTIONS(2539),
    [anon_sym_Xmlport] = ACTIONS(2539),
    [anon_sym_XMLport] = ACTIONS(2539),
    [anon_sym_XMLPort] = ACTIONS(2539),
    [anon_sym_XmlPort] = ACTIONS(2539),
    [anon_sym_enum] = ACTIONS(2539),
    [anon_sym_ENUM] = ACTIONS(2539),
    [anon_sym_Enum] = ACTIONS(2539),
    [anon_sym_eNUM] = ACTIONS(2539),
    [anon_sym_eNum] = ACTIONS(2539),
    [anon_sym_ENum] = ACTIONS(2539),
    [sym_quoted_identifier] = ACTIONS(2541),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2541),
    [sym_integer] = ACTIONS(2539),
    [sym_continue_as_identifier] = ACTIONS(2541),
    [sym_preproc_close] = ACTIONS(2541),
  },
  [STATE(2156)] = {
    [sym_identifier] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_COMMA] = ACTIONS(4825),
    [anon_sym_DASH] = ACTIONS(4827),
    [aux_sym_boolean_token1] = ACTIONS(4823),
    [aux_sym_boolean_token2] = ACTIONS(4823),
    [sym_decimal] = ACTIONS(4823),
    [anon_sym_LPAREN] = ACTIONS(4825),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4823),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(4830),
    [aux_sym_record_type_token1] = ACTIONS(4823),
    [aux_sym_basic_type_token21] = ACTIONS(4823),
    [aux_sym_basic_type_token22] = ACTIONS(4823),
    [aux_sym_basic_type_token48] = ACTIONS(4823),
    [anon_sym_not] = ACTIONS(4823),
    [anon_sym_NOT] = ACTIONS(4823),
    [anon_sym_Not] = ACTIONS(4823),
    [anon_sym_POUNDelif] = ACTIONS(4825),
    [anon_sym_POUNDELIF] = ACTIONS(4825),
    [anon_sym_POUNDElif] = ACTIONS(4825),
    [anon_sym_POUNDelse] = ACTIONS(4825),
    [anon_sym_POUNDELSE] = ACTIONS(4825),
    [anon_sym_POUNDElse] = ACTIONS(4825),
    [anon_sym_POUNDendif] = ACTIONS(4825),
    [anon_sym_POUNDENDIF] = ACTIONS(4825),
    [anon_sym_POUNDEndif] = ACTIONS(4825),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2595),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4823),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4823),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(4827),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(4825),
    [sym_date_literal] = ACTIONS(4823),
    [sym_time_literal] = ACTIONS(4823),
    [sym_biginteger_literal] = ACTIONS(4825),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(4823),
    [anon_sym_codeunit] = ACTIONS(4823),
    [anon_sym_CODEUNIT] = ACTIONS(4823),
    [anon_sym_Codeunit] = ACTIONS(4823),
    [anon_sym_CodeUnit] = ACTIONS(4823),
    [anon_sym_COdeunit] = ACTIONS(4823),
    [anon_sym_codeUnit] = ACTIONS(4823),
    [sym_report_keyword] = ACTIONS(4823),
    [sym_query_keyword] = ACTIONS(4823),
    [anon_sym_xmlport] = ACTIONS(4823),
    [anon_sym_XMLPORT] = ACTIONS(4823),
    [anon_sym_Xmlport] = ACTIONS(4823),
    [anon_sym_XMLport] = ACTIONS(4823),
    [anon_sym_XMLPort] = ACTIONS(4823),
    [anon_sym_XmlPort] = ACTIONS(4823),
    [anon_sym_enum] = ACTIONS(4823),
    [anon_sym_ENUM] = ACTIONS(4823),
    [anon_sym_Enum] = ACTIONS(4823),
    [anon_sym_eNUM] = ACTIONS(4823),
    [anon_sym_eNum] = ACTIONS(4823),
    [anon_sym_ENum] = ACTIONS(4823),
    [sym_quoted_identifier] = ACTIONS(4825),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4825),
    [sym_integer] = ACTIONS(4823),
    [sym_continue_as_identifier] = ACTIONS(4825),
    [sym_preproc_close] = ACTIONS(4825),
  },
  [STATE(2157)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2372),
    [anon_sym_SEMI] = ACTIONS(2374),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(5209),
    [aux_sym_boolean_token1] = ACTIONS(2372),
    [aux_sym_boolean_token2] = ACTIONS(2372),
    [sym_decimal] = ACTIONS(2372),
    [anon_sym_LPAREN] = ACTIONS(2374),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2372),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2372),
    [aux_sym_basic_type_token21] = ACTIONS(2372),
    [aux_sym_basic_type_token22] = ACTIONS(2372),
    [aux_sym_basic_type_token48] = ACTIONS(2372),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2372),
    [anon_sym_POUNDif] = ACTIONS(2374),
    [anon_sym_POUNDIF] = ACTIONS(2374),
    [anon_sym_POUNDIf] = ACTIONS(2374),
    [anon_sym_not] = ACTIONS(2372),
    [anon_sym_NOT] = ACTIONS(2372),
    [anon_sym_Not] = ACTIONS(2372),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(5433),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2372),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2372),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(5235),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(5237),
    [anon_sym_AND] = ACTIONS(5239),
    [anon_sym_And] = ACTIONS(5241),
    [anon_sym_or] = ACTIONS(5243),
    [anon_sym_OR] = ACTIONS(5245),
    [anon_sym_Or] = ACTIONS(5247),
    [anon_sym_xor] = ACTIONS(5249),
    [anon_sym_XOR] = ACTIONS(5251),
    [anon_sym_Xor] = ACTIONS(5253),
    [anon_sym_QMARK] = ACTIONS(5255),
    [sym_datetime_literal] = ACTIONS(2374),
    [sym_date_literal] = ACTIONS(2372),
    [sym_time_literal] = ACTIONS(2372),
    [sym_biginteger_literal] = ACTIONS(2374),
    [anon_sym_else] = ACTIONS(2372),
    [anon_sym_ELSE] = ACTIONS(2372),
    [anon_sym_Else] = ACTIONS(2372),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2372),
    [anon_sym_codeunit] = ACTIONS(2372),
    [anon_sym_CODEUNIT] = ACTIONS(2372),
    [anon_sym_Codeunit] = ACTIONS(2372),
    [anon_sym_CodeUnit] = ACTIONS(2372),
    [anon_sym_COdeunit] = ACTIONS(2372),
    [anon_sym_codeUnit] = ACTIONS(2372),
    [sym_report_keyword] = ACTIONS(2372),
    [sym_query_keyword] = ACTIONS(2372),
    [anon_sym_xmlport] = ACTIONS(2372),
    [anon_sym_XMLPORT] = ACTIONS(2372),
    [anon_sym_Xmlport] = ACTIONS(2372),
    [anon_sym_XMLport] = ACTIONS(2372),
    [anon_sym_XMLPort] = ACTIONS(2372),
    [anon_sym_XmlPort] = ACTIONS(2372),
    [anon_sym_enum] = ACTIONS(2372),
    [anon_sym_ENUM] = ACTIONS(2372),
    [anon_sym_Enum] = ACTIONS(2372),
    [anon_sym_eNUM] = ACTIONS(2372),
    [anon_sym_eNum] = ACTIONS(2372),
    [anon_sym_ENum] = ACTIONS(2372),
    [sym_quoted_identifier] = ACTIONS(2374),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2374),
    [sym_integer] = ACTIONS(2372),
    [sym_continue_as_identifier] = ACTIONS(2374),
    [sym_preproc_open] = ACTIONS(2374),
  },
  [STATE(2158)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2378),
    [anon_sym_SEMI] = ACTIONS(2380),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(2378),
    [aux_sym_boolean_token1] = ACTIONS(2378),
    [aux_sym_boolean_token2] = ACTIONS(2378),
    [sym_decimal] = ACTIONS(2378),
    [anon_sym_LPAREN] = ACTIONS(2380),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2378),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(2380),
    [aux_sym_record_type_token1] = ACTIONS(2378),
    [aux_sym_basic_type_token21] = ACTIONS(2378),
    [aux_sym_basic_type_token22] = ACTIONS(2378),
    [aux_sym_basic_type_token48] = ACTIONS(2378),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2378),
    [anon_sym_POUNDif] = ACTIONS(2380),
    [anon_sym_POUNDIF] = ACTIONS(2380),
    [anon_sym_POUNDIf] = ACTIONS(2380),
    [anon_sym_not] = ACTIONS(2378),
    [anon_sym_NOT] = ACTIONS(2378),
    [anon_sym_Not] = ACTIONS(2378),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(5273),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2378),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2378),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(2378),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(5237),
    [anon_sym_AND] = ACTIONS(5239),
    [anon_sym_And] = ACTIONS(5241),
    [anon_sym_or] = ACTIONS(5243),
    [anon_sym_OR] = ACTIONS(5245),
    [anon_sym_Or] = ACTIONS(5247),
    [anon_sym_xor] = ACTIONS(5249),
    [anon_sym_XOR] = ACTIONS(5251),
    [anon_sym_Xor] = ACTIONS(5253),
    [anon_sym_QMARK] = ACTIONS(5255),
    [sym_datetime_literal] = ACTIONS(2380),
    [sym_date_literal] = ACTIONS(2378),
    [sym_time_literal] = ACTIONS(2378),
    [sym_biginteger_literal] = ACTIONS(2380),
    [anon_sym_else] = ACTIONS(2378),
    [anon_sym_ELSE] = ACTIONS(2378),
    [anon_sym_Else] = ACTIONS(2378),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2378),
    [anon_sym_codeunit] = ACTIONS(2378),
    [anon_sym_CODEUNIT] = ACTIONS(2378),
    [anon_sym_Codeunit] = ACTIONS(2378),
    [anon_sym_CodeUnit] = ACTIONS(2378),
    [anon_sym_COdeunit] = ACTIONS(2378),
    [anon_sym_codeUnit] = ACTIONS(2378),
    [sym_report_keyword] = ACTIONS(2378),
    [sym_query_keyword] = ACTIONS(2378),
    [anon_sym_xmlport] = ACTIONS(2378),
    [anon_sym_XMLPORT] = ACTIONS(2378),
    [anon_sym_Xmlport] = ACTIONS(2378),
    [anon_sym_XMLport] = ACTIONS(2378),
    [anon_sym_XMLPort] = ACTIONS(2378),
    [anon_sym_XmlPort] = ACTIONS(2378),
    [anon_sym_enum] = ACTIONS(2378),
    [anon_sym_ENUM] = ACTIONS(2378),
    [anon_sym_Enum] = ACTIONS(2378),
    [anon_sym_eNUM] = ACTIONS(2378),
    [anon_sym_eNum] = ACTIONS(2378),
    [anon_sym_ENum] = ACTIONS(2378),
    [sym_quoted_identifier] = ACTIONS(2380),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2380),
    [sym_integer] = ACTIONS(2378),
    [sym_continue_as_identifier] = ACTIONS(2380),
    [sym_preproc_open] = ACTIONS(2380),
  },
  [STATE(2159)] = {
    [sym_identifier] = ACTIONS(2551),
    [anon_sym_SEMI] = ACTIONS(2553),
    [anon_sym_DOT] = ACTIONS(2551),
    [anon_sym_EQ] = ACTIONS(2553),
    [anon_sym_COMMA] = ACTIONS(2553),
    [anon_sym_COLON] = ACTIONS(2551),
    [anon_sym_DASH] = ACTIONS(2551),
    [aux_sym_boolean_token1] = ACTIONS(2551),
    [aux_sym_boolean_token2] = ACTIONS(2551),
    [sym_decimal] = ACTIONS(2551),
    [anon_sym_LPAREN] = ACTIONS(2553),
    [anon_sym_DOT_DOT] = ACTIONS(2553),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2551),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_LBRACK] = ACTIONS(2553),
    [aux_sym_record_type_token1] = ACTIONS(2551),
    [aux_sym_basic_type_token21] = ACTIONS(2551),
    [aux_sym_basic_type_token22] = ACTIONS(2551),
    [aux_sym_basic_type_token48] = ACTIONS(2551),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2551),
    [anon_sym_POUNDif] = ACTIONS(2553),
    [anon_sym_POUNDIF] = ACTIONS(2553),
    [anon_sym_POUNDIf] = ACTIONS(2553),
    [anon_sym_not] = ACTIONS(2551),
    [anon_sym_NOT] = ACTIONS(2551),
    [anon_sym_Not] = ACTIONS(2551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2553),
    [aux_sym__expression_token1] = ACTIONS(2553),
    [aux_sym__expression_token2] = ACTIONS(2553),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2551),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2551),
    [anon_sym_SLASH] = ACTIONS(2551),
    [anon_sym_div] = ACTIONS(2551),
    [anon_sym_DIV] = ACTIONS(2551),
    [anon_sym_Div] = ACTIONS(2551),
    [anon_sym_mod] = ACTIONS(2551),
    [anon_sym_MOD] = ACTIONS(2551),
    [anon_sym_Mod] = ACTIONS(2551),
    [anon_sym_PLUS] = ACTIONS(2551),
    [anon_sym_GT_EQ] = ACTIONS(2553),
    [anon_sym_LT_EQ] = ACTIONS(2553),
    [anon_sym_GT] = ACTIONS(2551),
    [anon_sym_LT] = ACTIONS(2551),
    [anon_sym_LT_GT] = ACTIONS(2553),
    [anon_sym_and] = ACTIONS(2551),
    [anon_sym_AND] = ACTIONS(2551),
    [anon_sym_And] = ACTIONS(2551),
    [anon_sym_or] = ACTIONS(2551),
    [anon_sym_OR] = ACTIONS(2551),
    [anon_sym_Or] = ACTIONS(2551),
    [anon_sym_xor] = ACTIONS(2551),
    [anon_sym_XOR] = ACTIONS(2551),
    [anon_sym_Xor] = ACTIONS(2551),
    [anon_sym_QMARK] = ACTIONS(2553),
    [sym_datetime_literal] = ACTIONS(2553),
    [sym_date_literal] = ACTIONS(2551),
    [sym_time_literal] = ACTIONS(2551),
    [sym_biginteger_literal] = ACTIONS(2553),
    [anon_sym_else] = ACTIONS(2551),
    [anon_sym_ELSE] = ACTIONS(2551),
    [anon_sym_Else] = ACTIONS(2551),
    [anon_sym_in] = ACTIONS(2551),
    [anon_sym_IN] = ACTIONS(2551),
    [anon_sym_In] = ACTIONS(2551),
    [sym_page_keyword] = ACTIONS(2551),
    [anon_sym_codeunit] = ACTIONS(2551),
    [anon_sym_CODEUNIT] = ACTIONS(2551),
    [anon_sym_Codeunit] = ACTIONS(2551),
    [anon_sym_CodeUnit] = ACTIONS(2551),
    [anon_sym_COdeunit] = ACTIONS(2551),
    [anon_sym_codeUnit] = ACTIONS(2551),
    [sym_report_keyword] = ACTIONS(2551),
    [sym_query_keyword] = ACTIONS(2551),
    [anon_sym_xmlport] = ACTIONS(2551),
    [anon_sym_XMLPORT] = ACTIONS(2551),
    [anon_sym_Xmlport] = ACTIONS(2551),
    [anon_sym_XMLport] = ACTIONS(2551),
    [anon_sym_XMLPort] = ACTIONS(2551),
    [anon_sym_XmlPort] = ACTIONS(2551),
    [anon_sym_enum] = ACTIONS(2551),
    [anon_sym_ENUM] = ACTIONS(2551),
    [anon_sym_Enum] = ACTIONS(2551),
    [anon_sym_eNUM] = ACTIONS(2551),
    [anon_sym_eNum] = ACTIONS(2551),
    [anon_sym_ENum] = ACTIONS(2551),
    [sym_quoted_identifier] = ACTIONS(2553),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2553),
    [sym_integer] = ACTIONS(2551),
    [sym_continue_as_identifier] = ACTIONS(2553),
    [sym_preproc_open] = ACTIONS(2553),
  },
  [STATE(2160)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2441),
    [sym_preproc_endif] = STATE(4658),
    [sym_assignment_expression] = STATE(6338),
    [sym_case_branch] = STATE(1939),
    [sym_preproc_split_case_branch] = STATE(3395),
    [aux_sym__case_pattern] = STATE(2579),
    [sym_preproc_conditional_case_patterns] = STATE(2579),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(9533),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(87),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(1939),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(3754),
    [anon_sym_ELSE] = ACTIONS(3754),
    [anon_sym_Else] = ACTIONS(3754),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2161)] = {
    [sym_identifier] = ACTIONS(2613),
    [anon_sym_DOT] = ACTIONS(2613),
    [anon_sym_EQ] = ACTIONS(2615),
    [anon_sym_COMMA] = ACTIONS(2615),
    [anon_sym_DASH] = ACTIONS(2613),
    [aux_sym_boolean_token1] = ACTIONS(2613),
    [aux_sym_boolean_token2] = ACTIONS(2613),
    [sym_decimal] = ACTIONS(2613),
    [anon_sym_LPAREN] = ACTIONS(2615),
    [anon_sym_DOT_DOT] = ACTIONS(2615),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2613),
    [anon_sym_STAR] = ACTIONS(2613),
    [anon_sym_LBRACK] = ACTIONS(5435),
    [aux_sym_record_type_token1] = ACTIONS(2613),
    [aux_sym_basic_type_token21] = ACTIONS(2613),
    [aux_sym_basic_type_token22] = ACTIONS(2613),
    [aux_sym_basic_type_token48] = ACTIONS(2613),
    [anon_sym_not] = ACTIONS(2613),
    [anon_sym_NOT] = ACTIONS(2613),
    [anon_sym_Not] = ACTIONS(2613),
    [anon_sym_POUNDelif] = ACTIONS(2615),
    [anon_sym_POUNDELIF] = ACTIONS(2615),
    [anon_sym_POUNDElif] = ACTIONS(2615),
    [anon_sym_POUNDelse] = ACTIONS(2615),
    [anon_sym_POUNDELSE] = ACTIONS(2615),
    [anon_sym_POUNDElse] = ACTIONS(2615),
    [anon_sym_POUNDendif] = ACTIONS(2615),
    [anon_sym_POUNDENDIF] = ACTIONS(2615),
    [anon_sym_POUNDEndif] = ACTIONS(2615),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2615),
    [aux_sym__expression_token1] = ACTIONS(2615),
    [aux_sym__expression_token2] = ACTIONS(2615),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2613),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2613),
    [anon_sym_SLASH] = ACTIONS(2613),
    [anon_sym_div] = ACTIONS(2613),
    [anon_sym_DIV] = ACTIONS(2613),
    [anon_sym_Div] = ACTIONS(2613),
    [anon_sym_mod] = ACTIONS(2613),
    [anon_sym_MOD] = ACTIONS(2613),
    [anon_sym_Mod] = ACTIONS(2613),
    [anon_sym_PLUS] = ACTIONS(2613),
    [anon_sym_GT_EQ] = ACTIONS(2615),
    [anon_sym_LT_EQ] = ACTIONS(2615),
    [anon_sym_GT] = ACTIONS(2613),
    [anon_sym_LT] = ACTIONS(2613),
    [anon_sym_LT_GT] = ACTIONS(2615),
    [anon_sym_and] = ACTIONS(2613),
    [anon_sym_AND] = ACTIONS(2613),
    [anon_sym_And] = ACTIONS(2613),
    [anon_sym_or] = ACTIONS(2613),
    [anon_sym_OR] = ACTIONS(2613),
    [anon_sym_Or] = ACTIONS(2613),
    [anon_sym_xor] = ACTIONS(2613),
    [anon_sym_XOR] = ACTIONS(2613),
    [anon_sym_Xor] = ACTIONS(2613),
    [anon_sym_QMARK] = ACTIONS(2615),
    [sym_datetime_literal] = ACTIONS(2615),
    [sym_date_literal] = ACTIONS(2613),
    [sym_time_literal] = ACTIONS(2613),
    [sym_biginteger_literal] = ACTIONS(2615),
    [anon_sym_in] = ACTIONS(2613),
    [anon_sym_IN] = ACTIONS(2613),
    [anon_sym_In] = ACTIONS(2613),
    [sym_page_keyword] = ACTIONS(2613),
    [anon_sym_codeunit] = ACTIONS(2613),
    [anon_sym_CODEUNIT] = ACTIONS(2613),
    [anon_sym_Codeunit] = ACTIONS(2613),
    [anon_sym_CodeUnit] = ACTIONS(2613),
    [anon_sym_COdeunit] = ACTIONS(2613),
    [anon_sym_codeUnit] = ACTIONS(2613),
    [sym_report_keyword] = ACTIONS(2613),
    [sym_query_keyword] = ACTIONS(2613),
    [anon_sym_xmlport] = ACTIONS(2613),
    [anon_sym_XMLPORT] = ACTIONS(2613),
    [anon_sym_Xmlport] = ACTIONS(2613),
    [anon_sym_XMLport] = ACTIONS(2613),
    [anon_sym_XMLPort] = ACTIONS(2613),
    [anon_sym_XmlPort] = ACTIONS(2613),
    [anon_sym_enum] = ACTIONS(2613),
    [anon_sym_ENUM] = ACTIONS(2613),
    [anon_sym_Enum] = ACTIONS(2613),
    [anon_sym_eNUM] = ACTIONS(2613),
    [anon_sym_eNum] = ACTIONS(2613),
    [anon_sym_ENum] = ACTIONS(2613),
    [sym_quoted_identifier] = ACTIONS(2615),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2615),
    [sym_integer] = ACTIONS(2613),
    [sym_continue_as_identifier] = ACTIONS(2615),
    [sym_preproc_close] = ACTIONS(2615),
  },
  [STATE(2162)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2382),
    [anon_sym_SEMI] = ACTIONS(2385),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(5209),
    [aux_sym_boolean_token1] = ACTIONS(2382),
    [aux_sym_boolean_token2] = ACTIONS(2382),
    [sym_decimal] = ACTIONS(2382),
    [anon_sym_LPAREN] = ACTIONS(2385),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2382),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2382),
    [aux_sym_basic_type_token21] = ACTIONS(2382),
    [aux_sym_basic_type_token22] = ACTIONS(2382),
    [aux_sym_basic_type_token48] = ACTIONS(2382),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2382),
    [anon_sym_POUNDif] = ACTIONS(2385),
    [anon_sym_POUNDIF] = ACTIONS(2385),
    [anon_sym_POUNDIf] = ACTIONS(2385),
    [anon_sym_not] = ACTIONS(2382),
    [anon_sym_NOT] = ACTIONS(2382),
    [anon_sym_Not] = ACTIONS(2382),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(5273),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2382),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(5235),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(5237),
    [anon_sym_AND] = ACTIONS(5239),
    [anon_sym_And] = ACTIONS(5241),
    [anon_sym_or] = ACTIONS(5243),
    [anon_sym_OR] = ACTIONS(5245),
    [anon_sym_Or] = ACTIONS(5247),
    [anon_sym_xor] = ACTIONS(5249),
    [anon_sym_XOR] = ACTIONS(5251),
    [anon_sym_Xor] = ACTIONS(5253),
    [anon_sym_QMARK] = ACTIONS(5255),
    [sym_datetime_literal] = ACTIONS(2385),
    [sym_date_literal] = ACTIONS(2382),
    [sym_time_literal] = ACTIONS(2382),
    [sym_biginteger_literal] = ACTIONS(2385),
    [anon_sym_else] = ACTIONS(2382),
    [anon_sym_ELSE] = ACTIONS(2382),
    [anon_sym_Else] = ACTIONS(2382),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2382),
    [anon_sym_codeunit] = ACTIONS(2382),
    [anon_sym_CODEUNIT] = ACTIONS(2382),
    [anon_sym_Codeunit] = ACTIONS(2382),
    [anon_sym_CodeUnit] = ACTIONS(2382),
    [anon_sym_COdeunit] = ACTIONS(2382),
    [anon_sym_codeUnit] = ACTIONS(2382),
    [sym_report_keyword] = ACTIONS(2382),
    [sym_query_keyword] = ACTIONS(2382),
    [anon_sym_xmlport] = ACTIONS(2382),
    [anon_sym_XMLPORT] = ACTIONS(2382),
    [anon_sym_Xmlport] = ACTIONS(2382),
    [anon_sym_XMLport] = ACTIONS(2382),
    [anon_sym_XMLPort] = ACTIONS(2382),
    [anon_sym_XmlPort] = ACTIONS(2382),
    [anon_sym_enum] = ACTIONS(2382),
    [anon_sym_ENUM] = ACTIONS(2382),
    [anon_sym_Enum] = ACTIONS(2382),
    [anon_sym_eNUM] = ACTIONS(2382),
    [anon_sym_eNum] = ACTIONS(2382),
    [anon_sym_ENum] = ACTIONS(2382),
    [sym_quoted_identifier] = ACTIONS(2385),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2385),
    [sym_integer] = ACTIONS(2382),
    [sym_continue_as_identifier] = ACTIONS(2385),
    [sym_preproc_open] = ACTIONS(2385),
  },
  [STATE(2163)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2388),
    [anon_sym_SEMI] = ACTIONS(2390),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(5209),
    [aux_sym_boolean_token1] = ACTIONS(2388),
    [aux_sym_boolean_token2] = ACTIONS(2388),
    [sym_decimal] = ACTIONS(2388),
    [anon_sym_LPAREN] = ACTIONS(2390),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2388),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2388),
    [aux_sym_basic_type_token21] = ACTIONS(2388),
    [aux_sym_basic_type_token22] = ACTIONS(2388),
    [aux_sym_basic_type_token48] = ACTIONS(2388),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2388),
    [anon_sym_POUNDif] = ACTIONS(2390),
    [anon_sym_POUNDIF] = ACTIONS(2390),
    [anon_sym_POUNDIf] = ACTIONS(2390),
    [anon_sym_not] = ACTIONS(2388),
    [anon_sym_NOT] = ACTIONS(2388),
    [anon_sym_Not] = ACTIONS(2388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(5273),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2388),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2388),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(5235),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(5237),
    [anon_sym_AND] = ACTIONS(5239),
    [anon_sym_And] = ACTIONS(5241),
    [anon_sym_or] = ACTIONS(5243),
    [anon_sym_OR] = ACTIONS(5245),
    [anon_sym_Or] = ACTIONS(5247),
    [anon_sym_xor] = ACTIONS(5249),
    [anon_sym_XOR] = ACTIONS(5251),
    [anon_sym_Xor] = ACTIONS(5253),
    [anon_sym_QMARK] = ACTIONS(5255),
    [sym_datetime_literal] = ACTIONS(2390),
    [sym_date_literal] = ACTIONS(2388),
    [sym_time_literal] = ACTIONS(2388),
    [sym_biginteger_literal] = ACTIONS(2390),
    [anon_sym_else] = ACTIONS(2388),
    [anon_sym_ELSE] = ACTIONS(2388),
    [anon_sym_Else] = ACTIONS(2388),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2388),
    [anon_sym_codeunit] = ACTIONS(2388),
    [anon_sym_CODEUNIT] = ACTIONS(2388),
    [anon_sym_Codeunit] = ACTIONS(2388),
    [anon_sym_CodeUnit] = ACTIONS(2388),
    [anon_sym_COdeunit] = ACTIONS(2388),
    [anon_sym_codeUnit] = ACTIONS(2388),
    [sym_report_keyword] = ACTIONS(2388),
    [sym_query_keyword] = ACTIONS(2388),
    [anon_sym_xmlport] = ACTIONS(2388),
    [anon_sym_XMLPORT] = ACTIONS(2388),
    [anon_sym_Xmlport] = ACTIONS(2388),
    [anon_sym_XMLport] = ACTIONS(2388),
    [anon_sym_XMLPort] = ACTIONS(2388),
    [anon_sym_XmlPort] = ACTIONS(2388),
    [anon_sym_enum] = ACTIONS(2388),
    [anon_sym_ENUM] = ACTIONS(2388),
    [anon_sym_Enum] = ACTIONS(2388),
    [anon_sym_eNUM] = ACTIONS(2388),
    [anon_sym_eNum] = ACTIONS(2388),
    [anon_sym_ENum] = ACTIONS(2388),
    [sym_quoted_identifier] = ACTIONS(2390),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2390),
    [sym_integer] = ACTIONS(2388),
    [sym_continue_as_identifier] = ACTIONS(2390),
    [sym_preproc_open] = ACTIONS(2390),
  },
  [STATE(2164)] = {
    [sym_identifier] = ACTIONS(2619),
    [anon_sym_DOT] = ACTIONS(2619),
    [anon_sym_EQ] = ACTIONS(2621),
    [anon_sym_COMMA] = ACTIONS(2621),
    [anon_sym_DASH] = ACTIONS(2619),
    [aux_sym_boolean_token1] = ACTIONS(2619),
    [aux_sym_boolean_token2] = ACTIONS(2619),
    [sym_decimal] = ACTIONS(2619),
    [anon_sym_LPAREN] = ACTIONS(2621),
    [anon_sym_DOT_DOT] = ACTIONS(2621),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2619),
    [anon_sym_STAR] = ACTIONS(2619),
    [anon_sym_LBRACK] = ACTIONS(5437),
    [aux_sym_record_type_token1] = ACTIONS(2619),
    [aux_sym_basic_type_token21] = ACTIONS(2619),
    [aux_sym_basic_type_token22] = ACTIONS(2619),
    [aux_sym_basic_type_token48] = ACTIONS(2619),
    [anon_sym_not] = ACTIONS(2619),
    [anon_sym_NOT] = ACTIONS(2619),
    [anon_sym_Not] = ACTIONS(2619),
    [anon_sym_POUNDelif] = ACTIONS(2621),
    [anon_sym_POUNDELIF] = ACTIONS(2621),
    [anon_sym_POUNDElif] = ACTIONS(2621),
    [anon_sym_POUNDelse] = ACTIONS(2621),
    [anon_sym_POUNDELSE] = ACTIONS(2621),
    [anon_sym_POUNDElse] = ACTIONS(2621),
    [anon_sym_POUNDendif] = ACTIONS(2621),
    [anon_sym_POUNDENDIF] = ACTIONS(2621),
    [anon_sym_POUNDEndif] = ACTIONS(2621),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2621),
    [aux_sym__expression_token1] = ACTIONS(2621),
    [aux_sym__expression_token2] = ACTIONS(2621),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2619),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2619),
    [anon_sym_SLASH] = ACTIONS(2619),
    [anon_sym_div] = ACTIONS(2619),
    [anon_sym_DIV] = ACTIONS(2619),
    [anon_sym_Div] = ACTIONS(2619),
    [anon_sym_mod] = ACTIONS(2619),
    [anon_sym_MOD] = ACTIONS(2619),
    [anon_sym_Mod] = ACTIONS(2619),
    [anon_sym_PLUS] = ACTIONS(2619),
    [anon_sym_GT_EQ] = ACTIONS(2621),
    [anon_sym_LT_EQ] = ACTIONS(2621),
    [anon_sym_GT] = ACTIONS(2619),
    [anon_sym_LT] = ACTIONS(2619),
    [anon_sym_LT_GT] = ACTIONS(2621),
    [anon_sym_and] = ACTIONS(2619),
    [anon_sym_AND] = ACTIONS(2619),
    [anon_sym_And] = ACTIONS(2619),
    [anon_sym_or] = ACTIONS(2619),
    [anon_sym_OR] = ACTIONS(2619),
    [anon_sym_Or] = ACTIONS(2619),
    [anon_sym_xor] = ACTIONS(2619),
    [anon_sym_XOR] = ACTIONS(2619),
    [anon_sym_Xor] = ACTIONS(2619),
    [anon_sym_QMARK] = ACTIONS(2621),
    [sym_datetime_literal] = ACTIONS(2621),
    [sym_date_literal] = ACTIONS(2619),
    [sym_time_literal] = ACTIONS(2619),
    [sym_biginteger_literal] = ACTIONS(2621),
    [anon_sym_in] = ACTIONS(2619),
    [anon_sym_IN] = ACTIONS(2619),
    [anon_sym_In] = ACTIONS(2619),
    [sym_page_keyword] = ACTIONS(2619),
    [anon_sym_codeunit] = ACTIONS(2619),
    [anon_sym_CODEUNIT] = ACTIONS(2619),
    [anon_sym_Codeunit] = ACTIONS(2619),
    [anon_sym_CodeUnit] = ACTIONS(2619),
    [anon_sym_COdeunit] = ACTIONS(2619),
    [anon_sym_codeUnit] = ACTIONS(2619),
    [sym_report_keyword] = ACTIONS(2619),
    [sym_query_keyword] = ACTIONS(2619),
    [anon_sym_xmlport] = ACTIONS(2619),
    [anon_sym_XMLPORT] = ACTIONS(2619),
    [anon_sym_Xmlport] = ACTIONS(2619),
    [anon_sym_XMLport] = ACTIONS(2619),
    [anon_sym_XMLPort] = ACTIONS(2619),
    [anon_sym_XmlPort] = ACTIONS(2619),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_ENUM] = ACTIONS(2619),
    [anon_sym_Enum] = ACTIONS(2619),
    [anon_sym_eNUM] = ACTIONS(2619),
    [anon_sym_eNum] = ACTIONS(2619),
    [anon_sym_ENum] = ACTIONS(2619),
    [sym_quoted_identifier] = ACTIONS(2621),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2621),
    [sym_integer] = ACTIONS(2619),
    [sym_continue_as_identifier] = ACTIONS(2621),
    [sym_preproc_close] = ACTIONS(2621),
  },
  [STATE(2165)] = {
    [sym_comparison_operator] = STATE(3001),
    [sym_in_keyword] = STATE(11223),
    [sym_identifier] = ACTIONS(2392),
    [anon_sym_SEMI] = ACTIONS(2394),
    [anon_sym_DOT] = ACTIONS(5207),
    [anon_sym_EQ] = ACTIONS(2276),
    [anon_sym_DASH] = ACTIONS(5209),
    [aux_sym_boolean_token1] = ACTIONS(2392),
    [aux_sym_boolean_token2] = ACTIONS(2392),
    [sym_decimal] = ACTIONS(2392),
    [anon_sym_LPAREN] = ACTIONS(2394),
    [anon_sym_DOT_DOT] = ACTIONS(5211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2392),
    [anon_sym_STAR] = ACTIONS(5213),
    [anon_sym_LBRACK] = ACTIONS(5215),
    [aux_sym_record_type_token1] = ACTIONS(2392),
    [aux_sym_basic_type_token21] = ACTIONS(2392),
    [aux_sym_basic_type_token22] = ACTIONS(2392),
    [aux_sym_basic_type_token48] = ACTIONS(2392),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2392),
    [anon_sym_POUNDif] = ACTIONS(2394),
    [anon_sym_POUNDIF] = ACTIONS(2394),
    [anon_sym_POUNDIf] = ACTIONS(2394),
    [anon_sym_not] = ACTIONS(2392),
    [anon_sym_NOT] = ACTIONS(2392),
    [anon_sym_Not] = ACTIONS(2392),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(5273),
    [aux_sym__expression_token1] = ACTIONS(5217),
    [aux_sym__expression_token2] = ACTIONS(5219),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2392),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2392),
    [anon_sym_SLASH] = ACTIONS(5221),
    [anon_sym_div] = ACTIONS(5223),
    [anon_sym_DIV] = ACTIONS(5225),
    [anon_sym_Div] = ACTIONS(5227),
    [anon_sym_mod] = ACTIONS(5229),
    [anon_sym_MOD] = ACTIONS(5231),
    [anon_sym_Mod] = ACTIONS(5233),
    [anon_sym_PLUS] = ACTIONS(5235),
    [anon_sym_GT_EQ] = ACTIONS(2276),
    [anon_sym_LT_EQ] = ACTIONS(2276),
    [anon_sym_GT] = ACTIONS(2306),
    [anon_sym_LT] = ACTIONS(2306),
    [anon_sym_LT_GT] = ACTIONS(2276),
    [anon_sym_and] = ACTIONS(5237),
    [anon_sym_AND] = ACTIONS(5239),
    [anon_sym_And] = ACTIONS(5241),
    [anon_sym_or] = ACTIONS(5243),
    [anon_sym_OR] = ACTIONS(5245),
    [anon_sym_Or] = ACTIONS(5247),
    [anon_sym_xor] = ACTIONS(5249),
    [anon_sym_XOR] = ACTIONS(5251),
    [anon_sym_Xor] = ACTIONS(5253),
    [anon_sym_QMARK] = ACTIONS(5255),
    [sym_datetime_literal] = ACTIONS(2394),
    [sym_date_literal] = ACTIONS(2392),
    [sym_time_literal] = ACTIONS(2392),
    [sym_biginteger_literal] = ACTIONS(2394),
    [anon_sym_else] = ACTIONS(2392),
    [anon_sym_ELSE] = ACTIONS(2392),
    [anon_sym_Else] = ACTIONS(2392),
    [anon_sym_in] = ACTIONS(2314),
    [anon_sym_IN] = ACTIONS(2314),
    [anon_sym_In] = ACTIONS(2314),
    [sym_page_keyword] = ACTIONS(2392),
    [anon_sym_codeunit] = ACTIONS(2392),
    [anon_sym_CODEUNIT] = ACTIONS(2392),
    [anon_sym_Codeunit] = ACTIONS(2392),
    [anon_sym_CodeUnit] = ACTIONS(2392),
    [anon_sym_COdeunit] = ACTIONS(2392),
    [anon_sym_codeUnit] = ACTIONS(2392),
    [sym_report_keyword] = ACTIONS(2392),
    [sym_query_keyword] = ACTIONS(2392),
    [anon_sym_xmlport] = ACTIONS(2392),
    [anon_sym_XMLPORT] = ACTIONS(2392),
    [anon_sym_Xmlport] = ACTIONS(2392),
    [anon_sym_XMLport] = ACTIONS(2392),
    [anon_sym_XMLPort] = ACTIONS(2392),
    [anon_sym_XmlPort] = ACTIONS(2392),
    [anon_sym_enum] = ACTIONS(2392),
    [anon_sym_ENUM] = ACTIONS(2392),
    [anon_sym_Enum] = ACTIONS(2392),
    [anon_sym_eNUM] = ACTIONS(2392),
    [anon_sym_eNum] = ACTIONS(2392),
    [anon_sym_ENum] = ACTIONS(2392),
    [sym_quoted_identifier] = ACTIONS(2394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2394),
    [sym_integer] = ACTIONS(2392),
    [sym_continue_as_identifier] = ACTIONS(2394),
    [sym_preproc_open] = ACTIONS(2394),
  },
  [STATE(2166)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_COMMA] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [anon_sym_POUNDelif] = ACTIONS(2587),
    [anon_sym_POUNDELIF] = ACTIONS(2587),
    [anon_sym_POUNDElif] = ACTIONS(2587),
    [anon_sym_POUNDelse] = ACTIONS(2587),
    [anon_sym_POUNDELSE] = ACTIONS(2587),
    [anon_sym_POUNDElse] = ACTIONS(2587),
    [anon_sym_POUNDendif] = ACTIONS(2587),
    [anon_sym_POUNDENDIF] = ACTIONS(2587),
    [anon_sym_POUNDEndif] = ACTIONS(2587),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2587),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_close] = ACTIONS(2587),
  },
  [STATE(2167)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_COMMA] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [anon_sym_POUNDelif] = ACTIONS(2587),
    [anon_sym_POUNDELIF] = ACTIONS(2587),
    [anon_sym_POUNDElif] = ACTIONS(2587),
    [anon_sym_POUNDelse] = ACTIONS(2587),
    [anon_sym_POUNDELSE] = ACTIONS(2587),
    [anon_sym_POUNDElse] = ACTIONS(2587),
    [anon_sym_POUNDendif] = ACTIONS(2587),
    [anon_sym_POUNDENDIF] = ACTIONS(2587),
    [anon_sym_POUNDEndif] = ACTIONS(2587),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2587),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_close] = ACTIONS(2587),
  },
  [STATE(2168)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_COMMA] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [anon_sym_POUNDelif] = ACTIONS(2587),
    [anon_sym_POUNDELIF] = ACTIONS(2587),
    [anon_sym_POUNDElif] = ACTIONS(2587),
    [anon_sym_POUNDelse] = ACTIONS(2587),
    [anon_sym_POUNDELSE] = ACTIONS(2587),
    [anon_sym_POUNDElse] = ACTIONS(2587),
    [anon_sym_POUNDendif] = ACTIONS(2587),
    [anon_sym_POUNDENDIF] = ACTIONS(2587),
    [anon_sym_POUNDEndif] = ACTIONS(2587),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2587),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_close] = ACTIONS(2587),
  },
  [STATE(2169)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_COMMA] = ACTIONS(2591),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [anon_sym_POUNDelif] = ACTIONS(2591),
    [anon_sym_POUNDELIF] = ACTIONS(2591),
    [anon_sym_POUNDElif] = ACTIONS(2591),
    [anon_sym_POUNDelse] = ACTIONS(2591),
    [anon_sym_POUNDELSE] = ACTIONS(2591),
    [anon_sym_POUNDElse] = ACTIONS(2591),
    [anon_sym_POUNDendif] = ACTIONS(2591),
    [anon_sym_POUNDENDIF] = ACTIONS(2591),
    [anon_sym_POUNDEndif] = ACTIONS(2591),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2591),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_close] = ACTIONS(2591),
  },
  [STATE(2170)] = {
    [sym_identifier] = ACTIONS(4658),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_COMMA] = ACTIONS(4660),
    [anon_sym_DASH] = ACTIONS(4662),
    [aux_sym_boolean_token1] = ACTIONS(4658),
    [aux_sym_boolean_token2] = ACTIONS(4658),
    [sym_decimal] = ACTIONS(4658),
    [anon_sym_LPAREN] = ACTIONS(4660),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4658),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(4665),
    [aux_sym_record_type_token1] = ACTIONS(4658),
    [aux_sym_basic_type_token21] = ACTIONS(4658),
    [aux_sym_basic_type_token22] = ACTIONS(4658),
    [aux_sym_basic_type_token48] = ACTIONS(4658),
    [anon_sym_not] = ACTIONS(4658),
    [anon_sym_NOT] = ACTIONS(4658),
    [anon_sym_Not] = ACTIONS(4658),
    [anon_sym_POUNDelif] = ACTIONS(4660),
    [anon_sym_POUNDELIF] = ACTIONS(4660),
    [anon_sym_POUNDElif] = ACTIONS(4660),
    [anon_sym_POUNDelse] = ACTIONS(4660),
    [anon_sym_POUNDELSE] = ACTIONS(4660),
    [anon_sym_POUNDElse] = ACTIONS(4660),
    [anon_sym_POUNDendif] = ACTIONS(4660),
    [anon_sym_POUNDENDIF] = ACTIONS(4660),
    [anon_sym_POUNDEndif] = ACTIONS(4660),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4658),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4658),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(4662),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(4660),
    [sym_date_literal] = ACTIONS(4658),
    [sym_time_literal] = ACTIONS(4658),
    [sym_biginteger_literal] = ACTIONS(4660),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(4658),
    [anon_sym_codeunit] = ACTIONS(4658),
    [anon_sym_CODEUNIT] = ACTIONS(4658),
    [anon_sym_Codeunit] = ACTIONS(4658),
    [anon_sym_CodeUnit] = ACTIONS(4658),
    [anon_sym_COdeunit] = ACTIONS(4658),
    [anon_sym_codeUnit] = ACTIONS(4658),
    [sym_report_keyword] = ACTIONS(4658),
    [sym_query_keyword] = ACTIONS(4658),
    [anon_sym_xmlport] = ACTIONS(4658),
    [anon_sym_XMLPORT] = ACTIONS(4658),
    [anon_sym_Xmlport] = ACTIONS(4658),
    [anon_sym_XMLport] = ACTIONS(4658),
    [anon_sym_XMLPort] = ACTIONS(4658),
    [anon_sym_XmlPort] = ACTIONS(4658),
    [anon_sym_enum] = ACTIONS(4658),
    [anon_sym_ENUM] = ACTIONS(4658),
    [anon_sym_Enum] = ACTIONS(4658),
    [anon_sym_eNUM] = ACTIONS(4658),
    [anon_sym_eNum] = ACTIONS(4658),
    [anon_sym_ENum] = ACTIONS(4658),
    [sym_quoted_identifier] = ACTIONS(4660),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4660),
    [sym_integer] = ACTIONS(4658),
    [sym_continue_as_identifier] = ACTIONS(4660),
    [sym_preproc_close] = ACTIONS(4660),
  },
  [STATE(2171)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_COMMA] = ACTIONS(2591),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [anon_sym_POUNDelif] = ACTIONS(2591),
    [anon_sym_POUNDELIF] = ACTIONS(2591),
    [anon_sym_POUNDElif] = ACTIONS(2591),
    [anon_sym_POUNDelse] = ACTIONS(2591),
    [anon_sym_POUNDELSE] = ACTIONS(2591),
    [anon_sym_POUNDElse] = ACTIONS(2591),
    [anon_sym_POUNDendif] = ACTIONS(2591),
    [anon_sym_POUNDENDIF] = ACTIONS(2591),
    [anon_sym_POUNDEndif] = ACTIONS(2591),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2591),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_close] = ACTIONS(2591),
  },
  [STATE(2172)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_COMMA] = ACTIONS(2591),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [anon_sym_POUNDelif] = ACTIONS(2591),
    [anon_sym_POUNDELIF] = ACTIONS(2591),
    [anon_sym_POUNDElif] = ACTIONS(2591),
    [anon_sym_POUNDelse] = ACTIONS(2591),
    [anon_sym_POUNDELSE] = ACTIONS(2591),
    [anon_sym_POUNDElse] = ACTIONS(2591),
    [anon_sym_POUNDendif] = ACTIONS(2591),
    [anon_sym_POUNDENDIF] = ACTIONS(2591),
    [anon_sym_POUNDEndif] = ACTIONS(2591),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2591),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_close] = ACTIONS(2591),
  },
  [STATE(2173)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2441),
    [sym_preproc_endif] = STATE(4685),
    [sym_assignment_expression] = STATE(6338),
    [sym_case_branch] = STATE(1939),
    [sym_preproc_split_case_branch] = STATE(3395),
    [aux_sym__case_pattern] = STATE(2579),
    [sym_preproc_conditional_case_patterns] = STATE(2579),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(9504),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(87),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(1939),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(3754),
    [anon_sym_ELSE] = ACTIONS(3754),
    [anon_sym_Else] = ACTIONS(3754),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2174)] = {
    [sym_identifier] = ACTIONS(2403),
    [anon_sym_DOT] = ACTIONS(2403),
    [anon_sym_EQ] = ACTIONS(2405),
    [anon_sym_COMMA] = ACTIONS(2405),
    [anon_sym_DASH] = ACTIONS(2403),
    [aux_sym_boolean_token1] = ACTIONS(2403),
    [aux_sym_boolean_token2] = ACTIONS(2403),
    [sym_decimal] = ACTIONS(2403),
    [anon_sym_LPAREN] = ACTIONS(2405),
    [anon_sym_DOT_DOT] = ACTIONS(2405),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2403),
    [anon_sym_STAR] = ACTIONS(2403),
    [anon_sym_LBRACK] = ACTIONS(2405),
    [aux_sym_record_type_token1] = ACTIONS(2403),
    [aux_sym_basic_type_token21] = ACTIONS(2403),
    [aux_sym_basic_type_token22] = ACTIONS(2403),
    [aux_sym_basic_type_token48] = ACTIONS(2403),
    [anon_sym_not] = ACTIONS(2403),
    [anon_sym_NOT] = ACTIONS(2403),
    [anon_sym_Not] = ACTIONS(2403),
    [anon_sym_POUNDelif] = ACTIONS(2405),
    [anon_sym_POUNDELIF] = ACTIONS(2405),
    [anon_sym_POUNDElif] = ACTIONS(2405),
    [anon_sym_POUNDelse] = ACTIONS(2405),
    [anon_sym_POUNDELSE] = ACTIONS(2405),
    [anon_sym_POUNDElse] = ACTIONS(2405),
    [anon_sym_POUNDendif] = ACTIONS(2405),
    [anon_sym_POUNDENDIF] = ACTIONS(2405),
    [anon_sym_POUNDEndif] = ACTIONS(2405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2405),
    [aux_sym__expression_token1] = ACTIONS(2405),
    [aux_sym__expression_token2] = ACTIONS(2405),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2403),
    [anon_sym_SLASH] = ACTIONS(2403),
    [anon_sym_div] = ACTIONS(2403),
    [anon_sym_DIV] = ACTIONS(2403),
    [anon_sym_Div] = ACTIONS(2403),
    [anon_sym_mod] = ACTIONS(2403),
    [anon_sym_MOD] = ACTIONS(2403),
    [anon_sym_Mod] = ACTIONS(2403),
    [anon_sym_PLUS] = ACTIONS(2403),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_LT_GT] = ACTIONS(2405),
    [anon_sym_and] = ACTIONS(2403),
    [anon_sym_AND] = ACTIONS(2403),
    [anon_sym_And] = ACTIONS(2403),
    [anon_sym_or] = ACTIONS(2403),
    [anon_sym_OR] = ACTIONS(2403),
    [anon_sym_Or] = ACTIONS(2403),
    [anon_sym_xor] = ACTIONS(2403),
    [anon_sym_XOR] = ACTIONS(2403),
    [anon_sym_Xor] = ACTIONS(2403),
    [anon_sym_QMARK] = ACTIONS(2405),
    [sym_datetime_literal] = ACTIONS(2405),
    [sym_date_literal] = ACTIONS(2403),
    [sym_time_literal] = ACTIONS(2403),
    [sym_biginteger_literal] = ACTIONS(2405),
    [anon_sym_in] = ACTIONS(2403),
    [anon_sym_IN] = ACTIONS(2403),
    [anon_sym_In] = ACTIONS(2403),
    [sym_page_keyword] = ACTIONS(2403),
    [anon_sym_codeunit] = ACTIONS(2403),
    [anon_sym_CODEUNIT] = ACTIONS(2403),
    [anon_sym_Codeunit] = ACTIONS(2403),
    [anon_sym_CodeUnit] = ACTIONS(2403),
    [anon_sym_COdeunit] = ACTIONS(2403),
    [anon_sym_codeUnit] = ACTIONS(2403),
    [sym_report_keyword] = ACTIONS(2403),
    [sym_query_keyword] = ACTIONS(2403),
    [anon_sym_xmlport] = ACTIONS(2403),
    [anon_sym_XMLPORT] = ACTIONS(2403),
    [anon_sym_Xmlport] = ACTIONS(2403),
    [anon_sym_XMLport] = ACTIONS(2403),
    [anon_sym_XMLPort] = ACTIONS(2403),
    [anon_sym_XmlPort] = ACTIONS(2403),
    [anon_sym_enum] = ACTIONS(2403),
    [anon_sym_ENUM] = ACTIONS(2403),
    [anon_sym_Enum] = ACTIONS(2403),
    [anon_sym_eNUM] = ACTIONS(2403),
    [anon_sym_eNum] = ACTIONS(2403),
    [anon_sym_ENum] = ACTIONS(2403),
    [sym_quoted_identifier] = ACTIONS(2405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2405),
    [sym_integer] = ACTIONS(2403),
    [sym_continue_as_identifier] = ACTIONS(2405),
    [sym_preproc_close] = ACTIONS(2405),
  },
  [STATE(2175)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2441),
    [sym_preproc_endif] = STATE(4685),
    [sym_assignment_expression] = STATE(6338),
    [sym_case_branch] = STATE(2135),
    [sym_preproc_split_case_branch] = STATE(3395),
    [aux_sym__case_pattern] = STATE(2579),
    [sym_preproc_conditional_case_patterns] = STATE(2579),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(9504),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(87),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(2135),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(3754),
    [anon_sym_ELSE] = ACTIONS(3754),
    [anon_sym_Else] = ACTIONS(3754),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2176)] = {
    [sym_identifier] = ACTIONS(2625),
    [anon_sym_SEMI] = ACTIONS(2627),
    [anon_sym_DOT] = ACTIONS(2625),
    [anon_sym_EQ] = ACTIONS(2627),
    [anon_sym_COMMA] = ACTIONS(2627),
    [anon_sym_COLON] = ACTIONS(2625),
    [anon_sym_DASH] = ACTIONS(2625),
    [aux_sym_boolean_token1] = ACTIONS(2625),
    [aux_sym_boolean_token2] = ACTIONS(2625),
    [sym_decimal] = ACTIONS(2625),
    [anon_sym_LPAREN] = ACTIONS(2627),
    [anon_sym_DOT_DOT] = ACTIONS(2627),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2625),
    [anon_sym_STAR] = ACTIONS(2625),
    [anon_sym_LBRACK] = ACTIONS(2627),
    [aux_sym_record_type_token1] = ACTIONS(2625),
    [aux_sym_basic_type_token21] = ACTIONS(2625),
    [aux_sym_basic_type_token22] = ACTIONS(2625),
    [aux_sym_basic_type_token48] = ACTIONS(2625),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2625),
    [anon_sym_POUNDif] = ACTIONS(2627),
    [anon_sym_POUNDIF] = ACTIONS(2627),
    [anon_sym_POUNDIf] = ACTIONS(2627),
    [anon_sym_not] = ACTIONS(2625),
    [anon_sym_NOT] = ACTIONS(2625),
    [anon_sym_Not] = ACTIONS(2625),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2627),
    [aux_sym__expression_token1] = ACTIONS(2627),
    [aux_sym__expression_token2] = ACTIONS(2627),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2625),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2625),
    [anon_sym_SLASH] = ACTIONS(2625),
    [anon_sym_div] = ACTIONS(2625),
    [anon_sym_DIV] = ACTIONS(2625),
    [anon_sym_Div] = ACTIONS(2625),
    [anon_sym_mod] = ACTIONS(2625),
    [anon_sym_MOD] = ACTIONS(2625),
    [anon_sym_Mod] = ACTIONS(2625),
    [anon_sym_PLUS] = ACTIONS(2625),
    [anon_sym_GT_EQ] = ACTIONS(2627),
    [anon_sym_LT_EQ] = ACTIONS(2627),
    [anon_sym_GT] = ACTIONS(2625),
    [anon_sym_LT] = ACTIONS(2625),
    [anon_sym_LT_GT] = ACTIONS(2627),
    [anon_sym_and] = ACTIONS(2625),
    [anon_sym_AND] = ACTIONS(2625),
    [anon_sym_And] = ACTIONS(2625),
    [anon_sym_or] = ACTIONS(2625),
    [anon_sym_OR] = ACTIONS(2625),
    [anon_sym_Or] = ACTIONS(2625),
    [anon_sym_xor] = ACTIONS(2625),
    [anon_sym_XOR] = ACTIONS(2625),
    [anon_sym_Xor] = ACTIONS(2625),
    [anon_sym_QMARK] = ACTIONS(2627),
    [sym_datetime_literal] = ACTIONS(2627),
    [sym_date_literal] = ACTIONS(2625),
    [sym_time_literal] = ACTIONS(2625),
    [sym_biginteger_literal] = ACTIONS(2627),
    [anon_sym_else] = ACTIONS(2625),
    [anon_sym_ELSE] = ACTIONS(2625),
    [anon_sym_Else] = ACTIONS(2625),
    [anon_sym_in] = ACTIONS(2625),
    [anon_sym_IN] = ACTIONS(2625),
    [anon_sym_In] = ACTIONS(2625),
    [sym_page_keyword] = ACTIONS(2625),
    [anon_sym_codeunit] = ACTIONS(2625),
    [anon_sym_CODEUNIT] = ACTIONS(2625),
    [anon_sym_Codeunit] = ACTIONS(2625),
    [anon_sym_CodeUnit] = ACTIONS(2625),
    [anon_sym_COdeunit] = ACTIONS(2625),
    [anon_sym_codeUnit] = ACTIONS(2625),
    [sym_report_keyword] = ACTIONS(2625),
    [sym_query_keyword] = ACTIONS(2625),
    [anon_sym_xmlport] = ACTIONS(2625),
    [anon_sym_XMLPORT] = ACTIONS(2625),
    [anon_sym_Xmlport] = ACTIONS(2625),
    [anon_sym_XMLport] = ACTIONS(2625),
    [anon_sym_XMLPort] = ACTIONS(2625),
    [anon_sym_XmlPort] = ACTIONS(2625),
    [anon_sym_enum] = ACTIONS(2625),
    [anon_sym_ENUM] = ACTIONS(2625),
    [anon_sym_Enum] = ACTIONS(2625),
    [anon_sym_eNUM] = ACTIONS(2625),
    [anon_sym_eNum] = ACTIONS(2625),
    [anon_sym_ENum] = ACTIONS(2625),
    [sym_quoted_identifier] = ACTIONS(2627),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2627),
    [sym_integer] = ACTIONS(2625),
    [sym_continue_as_identifier] = ACTIONS(2627),
    [sym_preproc_open] = ACTIONS(2627),
  },
  [STATE(2177)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2441),
    [sym_preproc_endif] = STATE(4673),
    [sym_assignment_expression] = STATE(6338),
    [sym_case_branch] = STATE(1939),
    [sym_preproc_split_case_branch] = STATE(3395),
    [aux_sym__case_pattern] = STATE(2579),
    [sym_preproc_conditional_case_patterns] = STATE(2579),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(9324),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(87),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(1939),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(3754),
    [anon_sym_ELSE] = ACTIONS(3754),
    [anon_sym_Else] = ACTIONS(3754),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2178)] = {
    [sym_identifier] = ACTIONS(2637),
    [anon_sym_SEMI] = ACTIONS(2639),
    [anon_sym_DOT] = ACTIONS(2637),
    [anon_sym_EQ] = ACTIONS(2639),
    [anon_sym_COMMA] = ACTIONS(2639),
    [anon_sym_COLON] = ACTIONS(2637),
    [anon_sym_DASH] = ACTIONS(2637),
    [aux_sym_boolean_token1] = ACTIONS(2637),
    [aux_sym_boolean_token2] = ACTIONS(2637),
    [sym_decimal] = ACTIONS(2637),
    [anon_sym_LPAREN] = ACTIONS(2639),
    [anon_sym_DOT_DOT] = ACTIONS(2639),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(2637),
    [anon_sym_LBRACK] = ACTIONS(2639),
    [aux_sym_record_type_token1] = ACTIONS(2637),
    [aux_sym_basic_type_token21] = ACTIONS(2637),
    [aux_sym_basic_type_token22] = ACTIONS(2637),
    [aux_sym_basic_type_token48] = ACTIONS(2637),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2637),
    [anon_sym_POUNDif] = ACTIONS(2639),
    [anon_sym_POUNDIF] = ACTIONS(2639),
    [anon_sym_POUNDIf] = ACTIONS(2639),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_NOT] = ACTIONS(2637),
    [anon_sym_Not] = ACTIONS(2637),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2639),
    [aux_sym__expression_token1] = ACTIONS(2639),
    [aux_sym__expression_token2] = ACTIONS(2639),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2637),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2637),
    [anon_sym_SLASH] = ACTIONS(2637),
    [anon_sym_div] = ACTIONS(2637),
    [anon_sym_DIV] = ACTIONS(2637),
    [anon_sym_Div] = ACTIONS(2637),
    [anon_sym_mod] = ACTIONS(2637),
    [anon_sym_MOD] = ACTIONS(2637),
    [anon_sym_Mod] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_GT_EQ] = ACTIONS(2639),
    [anon_sym_LT_EQ] = ACTIONS(2639),
    [anon_sym_GT] = ACTIONS(2637),
    [anon_sym_LT] = ACTIONS(2637),
    [anon_sym_LT_GT] = ACTIONS(2639),
    [anon_sym_and] = ACTIONS(2637),
    [anon_sym_AND] = ACTIONS(2637),
    [anon_sym_And] = ACTIONS(2637),
    [anon_sym_or] = ACTIONS(2637),
    [anon_sym_OR] = ACTIONS(2637),
    [anon_sym_Or] = ACTIONS(2637),
    [anon_sym_xor] = ACTIONS(2637),
    [anon_sym_XOR] = ACTIONS(2637),
    [anon_sym_Xor] = ACTIONS(2637),
    [anon_sym_QMARK] = ACTIONS(2639),
    [sym_datetime_literal] = ACTIONS(2639),
    [sym_date_literal] = ACTIONS(2637),
    [sym_time_literal] = ACTIONS(2637),
    [sym_biginteger_literal] = ACTIONS(2639),
    [anon_sym_else] = ACTIONS(2637),
    [anon_sym_ELSE] = ACTIONS(2637),
    [anon_sym_Else] = ACTIONS(2637),
    [anon_sym_in] = ACTIONS(2637),
    [anon_sym_IN] = ACTIONS(2637),
    [anon_sym_In] = ACTIONS(2637),
    [sym_page_keyword] = ACTIONS(2637),
    [anon_sym_codeunit] = ACTIONS(2637),
    [anon_sym_CODEUNIT] = ACTIONS(2637),
    [anon_sym_Codeunit] = ACTIONS(2637),
    [anon_sym_CodeUnit] = ACTIONS(2637),
    [anon_sym_COdeunit] = ACTIONS(2637),
    [anon_sym_codeUnit] = ACTIONS(2637),
    [sym_report_keyword] = ACTIONS(2637),
    [sym_query_keyword] = ACTIONS(2637),
    [anon_sym_xmlport] = ACTIONS(2637),
    [anon_sym_XMLPORT] = ACTIONS(2637),
    [anon_sym_Xmlport] = ACTIONS(2637),
    [anon_sym_XMLport] = ACTIONS(2637),
    [anon_sym_XMLPort] = ACTIONS(2637),
    [anon_sym_XmlPort] = ACTIONS(2637),
    [anon_sym_enum] = ACTIONS(2637),
    [anon_sym_ENUM] = ACTIONS(2637),
    [anon_sym_Enum] = ACTIONS(2637),
    [anon_sym_eNUM] = ACTIONS(2637),
    [anon_sym_eNum] = ACTIONS(2637),
    [anon_sym_ENum] = ACTIONS(2637),
    [sym_quoted_identifier] = ACTIONS(2639),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2639),
    [sym_integer] = ACTIONS(2637),
    [sym_continue_as_identifier] = ACTIONS(2639),
    [sym_preproc_open] = ACTIONS(2639),
  },
  [STATE(2179)] = {
    [sym_identifier] = ACTIONS(2539),
    [anon_sym_SEMI] = ACTIONS(2541),
    [anon_sym_DOT] = ACTIONS(2539),
    [anon_sym_EQ] = ACTIONS(2541),
    [anon_sym_COMMA] = ACTIONS(2541),
    [anon_sym_COLON] = ACTIONS(2539),
    [anon_sym_DASH] = ACTIONS(2539),
    [aux_sym_boolean_token1] = ACTIONS(2539),
    [aux_sym_boolean_token2] = ACTIONS(2539),
    [sym_decimal] = ACTIONS(2539),
    [anon_sym_LPAREN] = ACTIONS(2541),
    [anon_sym_DOT_DOT] = ACTIONS(2541),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2539),
    [anon_sym_STAR] = ACTIONS(2539),
    [anon_sym_LBRACK] = ACTIONS(2541),
    [aux_sym_record_type_token1] = ACTIONS(2539),
    [aux_sym_basic_type_token21] = ACTIONS(2539),
    [aux_sym_basic_type_token22] = ACTIONS(2539),
    [aux_sym_basic_type_token48] = ACTIONS(2539),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2539),
    [anon_sym_POUNDif] = ACTIONS(2541),
    [anon_sym_POUNDIF] = ACTIONS(2541),
    [anon_sym_POUNDIf] = ACTIONS(2541),
    [anon_sym_not] = ACTIONS(2539),
    [anon_sym_NOT] = ACTIONS(2539),
    [anon_sym_Not] = ACTIONS(2539),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2541),
    [aux_sym__expression_token1] = ACTIONS(2541),
    [aux_sym__expression_token2] = ACTIONS(2541),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2539),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2539),
    [anon_sym_SLASH] = ACTIONS(2539),
    [anon_sym_div] = ACTIONS(2539),
    [anon_sym_DIV] = ACTIONS(2539),
    [anon_sym_Div] = ACTIONS(2539),
    [anon_sym_mod] = ACTIONS(2539),
    [anon_sym_MOD] = ACTIONS(2539),
    [anon_sym_Mod] = ACTIONS(2539),
    [anon_sym_PLUS] = ACTIONS(2539),
    [anon_sym_GT_EQ] = ACTIONS(2541),
    [anon_sym_LT_EQ] = ACTIONS(2541),
    [anon_sym_GT] = ACTIONS(2539),
    [anon_sym_LT] = ACTIONS(2539),
    [anon_sym_LT_GT] = ACTIONS(2541),
    [anon_sym_and] = ACTIONS(2539),
    [anon_sym_AND] = ACTIONS(2539),
    [anon_sym_And] = ACTIONS(2539),
    [anon_sym_or] = ACTIONS(2539),
    [anon_sym_OR] = ACTIONS(2539),
    [anon_sym_Or] = ACTIONS(2539),
    [anon_sym_xor] = ACTIONS(2539),
    [anon_sym_XOR] = ACTIONS(2539),
    [anon_sym_Xor] = ACTIONS(2539),
    [anon_sym_QMARK] = ACTIONS(2541),
    [sym_datetime_literal] = ACTIONS(2541),
    [sym_date_literal] = ACTIONS(2539),
    [sym_time_literal] = ACTIONS(2539),
    [sym_biginteger_literal] = ACTIONS(2541),
    [anon_sym_else] = ACTIONS(2539),
    [anon_sym_ELSE] = ACTIONS(2539),
    [anon_sym_Else] = ACTIONS(2539),
    [anon_sym_in] = ACTIONS(2539),
    [anon_sym_IN] = ACTIONS(2539),
    [anon_sym_In] = ACTIONS(2539),
    [sym_page_keyword] = ACTIONS(2539),
    [anon_sym_codeunit] = ACTIONS(2539),
    [anon_sym_CODEUNIT] = ACTIONS(2539),
    [anon_sym_Codeunit] = ACTIONS(2539),
    [anon_sym_CodeUnit] = ACTIONS(2539),
    [anon_sym_COdeunit] = ACTIONS(2539),
    [anon_sym_codeUnit] = ACTIONS(2539),
    [sym_report_keyword] = ACTIONS(2539),
    [sym_query_keyword] = ACTIONS(2539),
    [anon_sym_xmlport] = ACTIONS(2539),
    [anon_sym_XMLPORT] = ACTIONS(2539),
    [anon_sym_Xmlport] = ACTIONS(2539),
    [anon_sym_XMLport] = ACTIONS(2539),
    [anon_sym_XMLPort] = ACTIONS(2539),
    [anon_sym_XmlPort] = ACTIONS(2539),
    [anon_sym_enum] = ACTIONS(2539),
    [anon_sym_ENUM] = ACTIONS(2539),
    [anon_sym_Enum] = ACTIONS(2539),
    [anon_sym_eNUM] = ACTIONS(2539),
    [anon_sym_eNum] = ACTIONS(2539),
    [anon_sym_ENum] = ACTIONS(2539),
    [sym_quoted_identifier] = ACTIONS(2541),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2541),
    [sym_integer] = ACTIONS(2539),
    [sym_continue_as_identifier] = ACTIONS(2541),
    [sym_preproc_open] = ACTIONS(2541),
  },
  [STATE(2180)] = {
    [sym_identifier] = ACTIONS(2529),
    [anon_sym_DOT] = ACTIONS(2529),
    [anon_sym_EQ] = ACTIONS(2531),
    [anon_sym_COMMA] = ACTIONS(2531),
    [anon_sym_DASH] = ACTIONS(2529),
    [aux_sym_boolean_token1] = ACTIONS(2529),
    [aux_sym_boolean_token2] = ACTIONS(2529),
    [sym_decimal] = ACTIONS(2529),
    [anon_sym_LPAREN] = ACTIONS(2531),
    [anon_sym_DOT_DOT] = ACTIONS(2531),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2529),
    [anon_sym_STAR] = ACTIONS(2529),
    [anon_sym_LBRACK] = ACTIONS(2531),
    [aux_sym_record_type_token1] = ACTIONS(2529),
    [aux_sym_basic_type_token21] = ACTIONS(2529),
    [aux_sym_basic_type_token22] = ACTIONS(2529),
    [aux_sym_basic_type_token48] = ACTIONS(2529),
    [anon_sym_not] = ACTIONS(2529),
    [anon_sym_NOT] = ACTIONS(2529),
    [anon_sym_Not] = ACTIONS(2529),
    [anon_sym_POUNDelif] = ACTIONS(2531),
    [anon_sym_POUNDELIF] = ACTIONS(2531),
    [anon_sym_POUNDElif] = ACTIONS(2531),
    [anon_sym_POUNDelse] = ACTIONS(2531),
    [anon_sym_POUNDELSE] = ACTIONS(2531),
    [anon_sym_POUNDElse] = ACTIONS(2531),
    [anon_sym_POUNDendif] = ACTIONS(2531),
    [anon_sym_POUNDENDIF] = ACTIONS(2531),
    [anon_sym_POUNDEndif] = ACTIONS(2531),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2531),
    [aux_sym__expression_token1] = ACTIONS(2531),
    [aux_sym__expression_token2] = ACTIONS(2531),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2529),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2529),
    [anon_sym_SLASH] = ACTIONS(2529),
    [anon_sym_div] = ACTIONS(2529),
    [anon_sym_DIV] = ACTIONS(2529),
    [anon_sym_Div] = ACTIONS(2529),
    [anon_sym_mod] = ACTIONS(2529),
    [anon_sym_MOD] = ACTIONS(2529),
    [anon_sym_Mod] = ACTIONS(2529),
    [anon_sym_PLUS] = ACTIONS(2529),
    [anon_sym_GT_EQ] = ACTIONS(2531),
    [anon_sym_LT_EQ] = ACTIONS(2531),
    [anon_sym_GT] = ACTIONS(2529),
    [anon_sym_LT] = ACTIONS(2529),
    [anon_sym_LT_GT] = ACTIONS(2531),
    [anon_sym_and] = ACTIONS(2529),
    [anon_sym_AND] = ACTIONS(2529),
    [anon_sym_And] = ACTIONS(2529),
    [anon_sym_or] = ACTIONS(2529),
    [anon_sym_OR] = ACTIONS(2529),
    [anon_sym_Or] = ACTIONS(2529),
    [anon_sym_xor] = ACTIONS(2529),
    [anon_sym_XOR] = ACTIONS(2529),
    [anon_sym_Xor] = ACTIONS(2529),
    [anon_sym_QMARK] = ACTIONS(2531),
    [sym_datetime_literal] = ACTIONS(2531),
    [sym_date_literal] = ACTIONS(2529),
    [sym_time_literal] = ACTIONS(2529),
    [sym_biginteger_literal] = ACTIONS(2531),
    [anon_sym_in] = ACTIONS(2529),
    [anon_sym_IN] = ACTIONS(2529),
    [anon_sym_In] = ACTIONS(2529),
    [sym_page_keyword] = ACTIONS(2529),
    [anon_sym_codeunit] = ACTIONS(2529),
    [anon_sym_CODEUNIT] = ACTIONS(2529),
    [anon_sym_Codeunit] = ACTIONS(2529),
    [anon_sym_CodeUnit] = ACTIONS(2529),
    [anon_sym_COdeunit] = ACTIONS(2529),
    [anon_sym_codeUnit] = ACTIONS(2529),
    [sym_report_keyword] = ACTIONS(2529),
    [sym_query_keyword] = ACTIONS(2529),
    [anon_sym_xmlport] = ACTIONS(2529),
    [anon_sym_XMLPORT] = ACTIONS(2529),
    [anon_sym_Xmlport] = ACTIONS(2529),
    [anon_sym_XMLport] = ACTIONS(2529),
    [anon_sym_XMLPort] = ACTIONS(2529),
    [anon_sym_XmlPort] = ACTIONS(2529),
    [anon_sym_enum] = ACTIONS(2529),
    [anon_sym_ENUM] = ACTIONS(2529),
    [anon_sym_Enum] = ACTIONS(2529),
    [anon_sym_eNUM] = ACTIONS(2529),
    [anon_sym_eNum] = ACTIONS(2529),
    [anon_sym_ENum] = ACTIONS(2529),
    [sym_quoted_identifier] = ACTIONS(2531),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2531),
    [sym_integer] = ACTIONS(2529),
    [sym_continue_as_identifier] = ACTIONS(2531),
    [sym_preproc_close] = ACTIONS(2531),
  },
  [STATE(2181)] = {
    [sym_boolean] = STATE(1527),
    [sym_code_block] = STATE(1664),
    [sym_assignment_expression] = STATE(1527),
    [sym__expression] = STATE(1527),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1527),
    [sym_multiplicative_expression] = STATE(1527),
    [sym_additive_expression] = STATE(1527),
    [sym_comparison_expression] = STATE(1527),
    [sym_logical_expression] = STATE(1527),
    [sym_ternary_expression] = STATE(1527),
    [sym_unary_expression] = STATE(1527),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1527),
    [sym_list_literal] = STATE(1527),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1527),
    [sym__literal_value] = STATE(1527),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_SEMI] = ACTIONS(2735),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(5439),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(117),
    [anon_sym_POUNDif] = ACTIONS(2735),
    [anon_sym_POUNDIF] = ACTIONS(2735),
    [anon_sym_POUNDIf] = ACTIONS(2735),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [anon_sym_POUNDelif] = ACTIONS(2735),
    [anon_sym_POUNDELIF] = ACTIONS(2735),
    [anon_sym_POUNDElif] = ACTIONS(2735),
    [anon_sym_POUNDelse] = ACTIONS(2735),
    [anon_sym_POUNDELSE] = ACTIONS(2735),
    [anon_sym_POUNDElse] = ACTIONS(2735),
    [anon_sym_POUNDendif] = ACTIONS(2735),
    [anon_sym_POUNDENDIF] = ACTIONS(2735),
    [anon_sym_POUNDEndif] = ACTIONS(2735),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(5441),
    [sym_date_literal] = ACTIONS(5439),
    [sym_time_literal] = ACTIONS(5439),
    [sym_biginteger_literal] = ACTIONS(5441),
    [anon_sym_else] = ACTIONS(2739),
    [anon_sym_ELSE] = ACTIONS(2739),
    [anon_sym_Else] = ACTIONS(2739),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5441),
    [sym_integer] = ACTIONS(5439),
    [sym_continue_as_identifier] = ACTIONS(5441),
    [sym_preproc_open] = ACTIONS(2735),
    [sym_preproc_close] = ACTIONS(2735),
    [sym_begin_keyword] = ACTIONS(125),
  },
  [STATE(2182)] = {
    [sym_identifier] = ACTIONS(2649),
    [anon_sym_DOT] = ACTIONS(2649),
    [anon_sym_EQ] = ACTIONS(2651),
    [anon_sym_COMMA] = ACTIONS(2651),
    [anon_sym_DASH] = ACTIONS(2649),
    [aux_sym_boolean_token1] = ACTIONS(2649),
    [aux_sym_boolean_token2] = ACTIONS(2649),
    [sym_decimal] = ACTIONS(2649),
    [anon_sym_LPAREN] = ACTIONS(2651),
    [anon_sym_DOT_DOT] = ACTIONS(2651),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2649),
    [anon_sym_STAR] = ACTIONS(2649),
    [anon_sym_LBRACK] = ACTIONS(2651),
    [aux_sym_record_type_token1] = ACTIONS(2649),
    [aux_sym_basic_type_token21] = ACTIONS(2649),
    [aux_sym_basic_type_token22] = ACTIONS(2649),
    [aux_sym_basic_type_token48] = ACTIONS(2649),
    [anon_sym_not] = ACTIONS(2649),
    [anon_sym_NOT] = ACTIONS(2649),
    [anon_sym_Not] = ACTIONS(2649),
    [anon_sym_POUNDelif] = ACTIONS(2651),
    [anon_sym_POUNDELIF] = ACTIONS(2651),
    [anon_sym_POUNDElif] = ACTIONS(2651),
    [anon_sym_POUNDelse] = ACTIONS(2651),
    [anon_sym_POUNDELSE] = ACTIONS(2651),
    [anon_sym_POUNDElse] = ACTIONS(2651),
    [anon_sym_POUNDendif] = ACTIONS(2651),
    [anon_sym_POUNDENDIF] = ACTIONS(2651),
    [anon_sym_POUNDEndif] = ACTIONS(2651),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2651),
    [aux_sym__expression_token1] = ACTIONS(2651),
    [aux_sym__expression_token2] = ACTIONS(2651),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2649),
    [anon_sym_SLASH] = ACTIONS(2649),
    [anon_sym_div] = ACTIONS(2649),
    [anon_sym_DIV] = ACTIONS(2649),
    [anon_sym_Div] = ACTIONS(2649),
    [anon_sym_mod] = ACTIONS(2649),
    [anon_sym_MOD] = ACTIONS(2649),
    [anon_sym_Mod] = ACTIONS(2649),
    [anon_sym_PLUS] = ACTIONS(2649),
    [anon_sym_GT_EQ] = ACTIONS(2651),
    [anon_sym_LT_EQ] = ACTIONS(2651),
    [anon_sym_GT] = ACTIONS(2649),
    [anon_sym_LT] = ACTIONS(2649),
    [anon_sym_LT_GT] = ACTIONS(2651),
    [anon_sym_and] = ACTIONS(2649),
    [anon_sym_AND] = ACTIONS(2649),
    [anon_sym_And] = ACTIONS(2649),
    [anon_sym_or] = ACTIONS(2649),
    [anon_sym_OR] = ACTIONS(2649),
    [anon_sym_Or] = ACTIONS(2649),
    [anon_sym_xor] = ACTIONS(2649),
    [anon_sym_XOR] = ACTIONS(2649),
    [anon_sym_Xor] = ACTIONS(2649),
    [anon_sym_QMARK] = ACTIONS(2651),
    [sym_datetime_literal] = ACTIONS(2651),
    [sym_date_literal] = ACTIONS(2649),
    [sym_time_literal] = ACTIONS(2649),
    [sym_biginteger_literal] = ACTIONS(2651),
    [anon_sym_in] = ACTIONS(2649),
    [anon_sym_IN] = ACTIONS(2649),
    [anon_sym_In] = ACTIONS(2649),
    [sym_page_keyword] = ACTIONS(2649),
    [anon_sym_codeunit] = ACTIONS(2649),
    [anon_sym_CODEUNIT] = ACTIONS(2649),
    [anon_sym_Codeunit] = ACTIONS(2649),
    [anon_sym_CodeUnit] = ACTIONS(2649),
    [anon_sym_COdeunit] = ACTIONS(2649),
    [anon_sym_codeUnit] = ACTIONS(2649),
    [sym_report_keyword] = ACTIONS(2649),
    [sym_query_keyword] = ACTIONS(2649),
    [anon_sym_xmlport] = ACTIONS(2649),
    [anon_sym_XMLPORT] = ACTIONS(2649),
    [anon_sym_Xmlport] = ACTIONS(2649),
    [anon_sym_XMLport] = ACTIONS(2649),
    [anon_sym_XMLPort] = ACTIONS(2649),
    [anon_sym_XmlPort] = ACTIONS(2649),
    [anon_sym_enum] = ACTIONS(2649),
    [anon_sym_ENUM] = ACTIONS(2649),
    [anon_sym_Enum] = ACTIONS(2649),
    [anon_sym_eNUM] = ACTIONS(2649),
    [anon_sym_eNum] = ACTIONS(2649),
    [anon_sym_ENum] = ACTIONS(2649),
    [sym_quoted_identifier] = ACTIONS(2651),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2651),
    [sym_integer] = ACTIONS(2649),
    [sym_continue_as_identifier] = ACTIONS(2651),
    [sym_preproc_close] = ACTIONS(2651),
  },
  [STATE(2183)] = {
    [sym_identifier] = ACTIONS(2625),
    [anon_sym_DOT] = ACTIONS(2625),
    [anon_sym_EQ] = ACTIONS(2627),
    [anon_sym_COMMA] = ACTIONS(2627),
    [anon_sym_DASH] = ACTIONS(2625),
    [aux_sym_boolean_token1] = ACTIONS(2625),
    [aux_sym_boolean_token2] = ACTIONS(2625),
    [sym_decimal] = ACTIONS(2625),
    [anon_sym_LPAREN] = ACTIONS(2627),
    [anon_sym_DOT_DOT] = ACTIONS(2627),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2625),
    [anon_sym_STAR] = ACTIONS(2625),
    [anon_sym_LBRACK] = ACTIONS(2627),
    [aux_sym_record_type_token1] = ACTIONS(2625),
    [aux_sym_basic_type_token21] = ACTIONS(2625),
    [aux_sym_basic_type_token22] = ACTIONS(2625),
    [aux_sym_basic_type_token48] = ACTIONS(2625),
    [anon_sym_not] = ACTIONS(2625),
    [anon_sym_NOT] = ACTIONS(2625),
    [anon_sym_Not] = ACTIONS(2625),
    [anon_sym_POUNDelif] = ACTIONS(2627),
    [anon_sym_POUNDELIF] = ACTIONS(2627),
    [anon_sym_POUNDElif] = ACTIONS(2627),
    [anon_sym_POUNDelse] = ACTIONS(2627),
    [anon_sym_POUNDELSE] = ACTIONS(2627),
    [anon_sym_POUNDElse] = ACTIONS(2627),
    [anon_sym_POUNDendif] = ACTIONS(2627),
    [anon_sym_POUNDENDIF] = ACTIONS(2627),
    [anon_sym_POUNDEndif] = ACTIONS(2627),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2627),
    [aux_sym__expression_token1] = ACTIONS(2627),
    [aux_sym__expression_token2] = ACTIONS(2627),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2625),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2625),
    [anon_sym_SLASH] = ACTIONS(2625),
    [anon_sym_div] = ACTIONS(2625),
    [anon_sym_DIV] = ACTIONS(2625),
    [anon_sym_Div] = ACTIONS(2625),
    [anon_sym_mod] = ACTIONS(2625),
    [anon_sym_MOD] = ACTIONS(2625),
    [anon_sym_Mod] = ACTIONS(2625),
    [anon_sym_PLUS] = ACTIONS(2625),
    [anon_sym_GT_EQ] = ACTIONS(2627),
    [anon_sym_LT_EQ] = ACTIONS(2627),
    [anon_sym_GT] = ACTIONS(2625),
    [anon_sym_LT] = ACTIONS(2625),
    [anon_sym_LT_GT] = ACTIONS(2627),
    [anon_sym_and] = ACTIONS(2625),
    [anon_sym_AND] = ACTIONS(2625),
    [anon_sym_And] = ACTIONS(2625),
    [anon_sym_or] = ACTIONS(2625),
    [anon_sym_OR] = ACTIONS(2625),
    [anon_sym_Or] = ACTIONS(2625),
    [anon_sym_xor] = ACTIONS(2625),
    [anon_sym_XOR] = ACTIONS(2625),
    [anon_sym_Xor] = ACTIONS(2625),
    [anon_sym_QMARK] = ACTIONS(2627),
    [sym_datetime_literal] = ACTIONS(2627),
    [sym_date_literal] = ACTIONS(2625),
    [sym_time_literal] = ACTIONS(2625),
    [sym_biginteger_literal] = ACTIONS(2627),
    [anon_sym_in] = ACTIONS(2625),
    [anon_sym_IN] = ACTIONS(2625),
    [anon_sym_In] = ACTIONS(2625),
    [sym_page_keyword] = ACTIONS(2625),
    [anon_sym_codeunit] = ACTIONS(2625),
    [anon_sym_CODEUNIT] = ACTIONS(2625),
    [anon_sym_Codeunit] = ACTIONS(2625),
    [anon_sym_CodeUnit] = ACTIONS(2625),
    [anon_sym_COdeunit] = ACTIONS(2625),
    [anon_sym_codeUnit] = ACTIONS(2625),
    [sym_report_keyword] = ACTIONS(2625),
    [sym_query_keyword] = ACTIONS(2625),
    [anon_sym_xmlport] = ACTIONS(2625),
    [anon_sym_XMLPORT] = ACTIONS(2625),
    [anon_sym_Xmlport] = ACTIONS(2625),
    [anon_sym_XMLport] = ACTIONS(2625),
    [anon_sym_XMLPort] = ACTIONS(2625),
    [anon_sym_XmlPort] = ACTIONS(2625),
    [anon_sym_enum] = ACTIONS(2625),
    [anon_sym_ENUM] = ACTIONS(2625),
    [anon_sym_Enum] = ACTIONS(2625),
    [anon_sym_eNUM] = ACTIONS(2625),
    [anon_sym_eNum] = ACTIONS(2625),
    [anon_sym_ENum] = ACTIONS(2625),
    [sym_quoted_identifier] = ACTIONS(2627),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2627),
    [sym_integer] = ACTIONS(2625),
    [sym_continue_as_identifier] = ACTIONS(2627),
    [sym_preproc_close] = ACTIONS(2627),
  },
  [STATE(2184)] = {
    [sym_identifier] = ACTIONS(2629),
    [anon_sym_DOT] = ACTIONS(2629),
    [anon_sym_EQ] = ACTIONS(2631),
    [anon_sym_COMMA] = ACTIONS(2631),
    [anon_sym_DASH] = ACTIONS(2629),
    [aux_sym_boolean_token1] = ACTIONS(2629),
    [aux_sym_boolean_token2] = ACTIONS(2629),
    [sym_decimal] = ACTIONS(2629),
    [anon_sym_LPAREN] = ACTIONS(2631),
    [anon_sym_DOT_DOT] = ACTIONS(2631),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2629),
    [anon_sym_STAR] = ACTIONS(2629),
    [anon_sym_LBRACK] = ACTIONS(2631),
    [aux_sym_record_type_token1] = ACTIONS(2629),
    [aux_sym_basic_type_token21] = ACTIONS(2629),
    [aux_sym_basic_type_token22] = ACTIONS(2629),
    [aux_sym_basic_type_token48] = ACTIONS(2629),
    [anon_sym_not] = ACTIONS(2629),
    [anon_sym_NOT] = ACTIONS(2629),
    [anon_sym_Not] = ACTIONS(2629),
    [anon_sym_POUNDelif] = ACTIONS(2631),
    [anon_sym_POUNDELIF] = ACTIONS(2631),
    [anon_sym_POUNDElif] = ACTIONS(2631),
    [anon_sym_POUNDelse] = ACTIONS(2631),
    [anon_sym_POUNDELSE] = ACTIONS(2631),
    [anon_sym_POUNDElse] = ACTIONS(2631),
    [anon_sym_POUNDendif] = ACTIONS(2631),
    [anon_sym_POUNDENDIF] = ACTIONS(2631),
    [anon_sym_POUNDEndif] = ACTIONS(2631),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2631),
    [aux_sym__expression_token1] = ACTIONS(2631),
    [aux_sym__expression_token2] = ACTIONS(2631),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2629),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2629),
    [anon_sym_SLASH] = ACTIONS(2629),
    [anon_sym_div] = ACTIONS(2629),
    [anon_sym_DIV] = ACTIONS(2629),
    [anon_sym_Div] = ACTIONS(2629),
    [anon_sym_mod] = ACTIONS(2629),
    [anon_sym_MOD] = ACTIONS(2629),
    [anon_sym_Mod] = ACTIONS(2629),
    [anon_sym_PLUS] = ACTIONS(2629),
    [anon_sym_GT_EQ] = ACTIONS(2631),
    [anon_sym_LT_EQ] = ACTIONS(2631),
    [anon_sym_GT] = ACTIONS(2629),
    [anon_sym_LT] = ACTIONS(2629),
    [anon_sym_LT_GT] = ACTIONS(2631),
    [anon_sym_and] = ACTIONS(2629),
    [anon_sym_AND] = ACTIONS(2629),
    [anon_sym_And] = ACTIONS(2629),
    [anon_sym_or] = ACTIONS(2629),
    [anon_sym_OR] = ACTIONS(2629),
    [anon_sym_Or] = ACTIONS(2629),
    [anon_sym_xor] = ACTIONS(2629),
    [anon_sym_XOR] = ACTIONS(2629),
    [anon_sym_Xor] = ACTIONS(2629),
    [anon_sym_QMARK] = ACTIONS(2631),
    [sym_datetime_literal] = ACTIONS(2631),
    [sym_date_literal] = ACTIONS(2629),
    [sym_time_literal] = ACTIONS(2629),
    [sym_biginteger_literal] = ACTIONS(2631),
    [anon_sym_in] = ACTIONS(2629),
    [anon_sym_IN] = ACTIONS(2629),
    [anon_sym_In] = ACTIONS(2629),
    [sym_page_keyword] = ACTIONS(2629),
    [anon_sym_codeunit] = ACTIONS(2629),
    [anon_sym_CODEUNIT] = ACTIONS(2629),
    [anon_sym_Codeunit] = ACTIONS(2629),
    [anon_sym_CodeUnit] = ACTIONS(2629),
    [anon_sym_COdeunit] = ACTIONS(2629),
    [anon_sym_codeUnit] = ACTIONS(2629),
    [sym_report_keyword] = ACTIONS(2629),
    [sym_query_keyword] = ACTIONS(2629),
    [anon_sym_xmlport] = ACTIONS(2629),
    [anon_sym_XMLPORT] = ACTIONS(2629),
    [anon_sym_Xmlport] = ACTIONS(2629),
    [anon_sym_XMLport] = ACTIONS(2629),
    [anon_sym_XMLPort] = ACTIONS(2629),
    [anon_sym_XmlPort] = ACTIONS(2629),
    [anon_sym_enum] = ACTIONS(2629),
    [anon_sym_ENUM] = ACTIONS(2629),
    [anon_sym_Enum] = ACTIONS(2629),
    [anon_sym_eNUM] = ACTIONS(2629),
    [anon_sym_eNum] = ACTIONS(2629),
    [anon_sym_ENum] = ACTIONS(2629),
    [sym_quoted_identifier] = ACTIONS(2631),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2631),
    [sym_integer] = ACTIONS(2629),
    [sym_continue_as_identifier] = ACTIONS(2631),
    [sym_preproc_close] = ACTIONS(2631),
  },
  [STATE(2185)] = {
    [sym_identifier] = ACTIONS(2597),
    [anon_sym_SEMI] = ACTIONS(2599),
    [anon_sym_DOT] = ACTIONS(2597),
    [anon_sym_EQ] = ACTIONS(2599),
    [anon_sym_COMMA] = ACTIONS(2599),
    [anon_sym_COLON] = ACTIONS(2597),
    [anon_sym_DASH] = ACTIONS(2597),
    [aux_sym_boolean_token1] = ACTIONS(2597),
    [aux_sym_boolean_token2] = ACTIONS(2597),
    [sym_decimal] = ACTIONS(2597),
    [anon_sym_LPAREN] = ACTIONS(2599),
    [anon_sym_DOT_DOT] = ACTIONS(2599),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2597),
    [anon_sym_STAR] = ACTIONS(2597),
    [anon_sym_LBRACK] = ACTIONS(2599),
    [aux_sym_record_type_token1] = ACTIONS(2597),
    [aux_sym_basic_type_token21] = ACTIONS(2597),
    [aux_sym_basic_type_token22] = ACTIONS(2597),
    [aux_sym_basic_type_token48] = ACTIONS(2597),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2597),
    [anon_sym_POUNDif] = ACTIONS(2599),
    [anon_sym_POUNDIF] = ACTIONS(2599),
    [anon_sym_POUNDIf] = ACTIONS(2599),
    [anon_sym_not] = ACTIONS(2597),
    [anon_sym_NOT] = ACTIONS(2597),
    [anon_sym_Not] = ACTIONS(2597),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2599),
    [aux_sym__expression_token1] = ACTIONS(2599),
    [aux_sym__expression_token2] = ACTIONS(2599),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2597),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2597),
    [anon_sym_SLASH] = ACTIONS(2597),
    [anon_sym_div] = ACTIONS(2597),
    [anon_sym_DIV] = ACTIONS(2597),
    [anon_sym_Div] = ACTIONS(2597),
    [anon_sym_mod] = ACTIONS(2597),
    [anon_sym_MOD] = ACTIONS(2597),
    [anon_sym_Mod] = ACTIONS(2597),
    [anon_sym_PLUS] = ACTIONS(2597),
    [anon_sym_GT_EQ] = ACTIONS(2599),
    [anon_sym_LT_EQ] = ACTIONS(2599),
    [anon_sym_GT] = ACTIONS(2597),
    [anon_sym_LT] = ACTIONS(2597),
    [anon_sym_LT_GT] = ACTIONS(2599),
    [anon_sym_and] = ACTIONS(2597),
    [anon_sym_AND] = ACTIONS(2597),
    [anon_sym_And] = ACTIONS(2597),
    [anon_sym_or] = ACTIONS(2597),
    [anon_sym_OR] = ACTIONS(2597),
    [anon_sym_Or] = ACTIONS(2597),
    [anon_sym_xor] = ACTIONS(2597),
    [anon_sym_XOR] = ACTIONS(2597),
    [anon_sym_Xor] = ACTIONS(2597),
    [anon_sym_QMARK] = ACTIONS(2599),
    [sym_datetime_literal] = ACTIONS(2599),
    [sym_date_literal] = ACTIONS(2597),
    [sym_time_literal] = ACTIONS(2597),
    [sym_biginteger_literal] = ACTIONS(2599),
    [anon_sym_else] = ACTIONS(2597),
    [anon_sym_ELSE] = ACTIONS(2597),
    [anon_sym_Else] = ACTIONS(2597),
    [anon_sym_in] = ACTIONS(2597),
    [anon_sym_IN] = ACTIONS(2597),
    [anon_sym_In] = ACTIONS(2597),
    [sym_page_keyword] = ACTIONS(2597),
    [anon_sym_codeunit] = ACTIONS(2597),
    [anon_sym_CODEUNIT] = ACTIONS(2597),
    [anon_sym_Codeunit] = ACTIONS(2597),
    [anon_sym_CodeUnit] = ACTIONS(2597),
    [anon_sym_COdeunit] = ACTIONS(2597),
    [anon_sym_codeUnit] = ACTIONS(2597),
    [sym_report_keyword] = ACTIONS(2597),
    [sym_query_keyword] = ACTIONS(2597),
    [anon_sym_xmlport] = ACTIONS(2597),
    [anon_sym_XMLPORT] = ACTIONS(2597),
    [anon_sym_Xmlport] = ACTIONS(2597),
    [anon_sym_XMLport] = ACTIONS(2597),
    [anon_sym_XMLPort] = ACTIONS(2597),
    [anon_sym_XmlPort] = ACTIONS(2597),
    [anon_sym_enum] = ACTIONS(2597),
    [anon_sym_ENUM] = ACTIONS(2597),
    [anon_sym_Enum] = ACTIONS(2597),
    [anon_sym_eNUM] = ACTIONS(2597),
    [anon_sym_eNum] = ACTIONS(2597),
    [anon_sym_ENum] = ACTIONS(2597),
    [sym_quoted_identifier] = ACTIONS(2599),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2599),
    [sym_integer] = ACTIONS(2597),
    [sym_continue_as_identifier] = ACTIONS(2599),
    [sym_preproc_open] = ACTIONS(2599),
  },
  [STATE(2186)] = {
    [sym_identifier] = ACTIONS(2601),
    [anon_sym_SEMI] = ACTIONS(2603),
    [anon_sym_DOT] = ACTIONS(2601),
    [anon_sym_EQ] = ACTIONS(2603),
    [anon_sym_COMMA] = ACTIONS(2603),
    [anon_sym_COLON] = ACTIONS(2601),
    [anon_sym_DASH] = ACTIONS(2601),
    [aux_sym_boolean_token1] = ACTIONS(2601),
    [aux_sym_boolean_token2] = ACTIONS(2601),
    [sym_decimal] = ACTIONS(2601),
    [anon_sym_LPAREN] = ACTIONS(2603),
    [anon_sym_DOT_DOT] = ACTIONS(2603),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2601),
    [anon_sym_STAR] = ACTIONS(2601),
    [anon_sym_LBRACK] = ACTIONS(2603),
    [aux_sym_record_type_token1] = ACTIONS(2601),
    [aux_sym_basic_type_token21] = ACTIONS(2601),
    [aux_sym_basic_type_token22] = ACTIONS(2601),
    [aux_sym_basic_type_token48] = ACTIONS(2601),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2601),
    [anon_sym_POUNDif] = ACTIONS(2603),
    [anon_sym_POUNDIF] = ACTIONS(2603),
    [anon_sym_POUNDIf] = ACTIONS(2603),
    [anon_sym_not] = ACTIONS(2601),
    [anon_sym_NOT] = ACTIONS(2601),
    [anon_sym_Not] = ACTIONS(2601),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2603),
    [aux_sym__expression_token1] = ACTIONS(2603),
    [aux_sym__expression_token2] = ACTIONS(2603),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2601),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2601),
    [anon_sym_SLASH] = ACTIONS(2601),
    [anon_sym_div] = ACTIONS(2601),
    [anon_sym_DIV] = ACTIONS(2601),
    [anon_sym_Div] = ACTIONS(2601),
    [anon_sym_mod] = ACTIONS(2601),
    [anon_sym_MOD] = ACTIONS(2601),
    [anon_sym_Mod] = ACTIONS(2601),
    [anon_sym_PLUS] = ACTIONS(2601),
    [anon_sym_GT_EQ] = ACTIONS(2603),
    [anon_sym_LT_EQ] = ACTIONS(2603),
    [anon_sym_GT] = ACTIONS(2601),
    [anon_sym_LT] = ACTIONS(2601),
    [anon_sym_LT_GT] = ACTIONS(2603),
    [anon_sym_and] = ACTIONS(2601),
    [anon_sym_AND] = ACTIONS(2601),
    [anon_sym_And] = ACTIONS(2601),
    [anon_sym_or] = ACTIONS(2601),
    [anon_sym_OR] = ACTIONS(2601),
    [anon_sym_Or] = ACTIONS(2601),
    [anon_sym_xor] = ACTIONS(2601),
    [anon_sym_XOR] = ACTIONS(2601),
    [anon_sym_Xor] = ACTIONS(2601),
    [anon_sym_QMARK] = ACTIONS(2603),
    [sym_datetime_literal] = ACTIONS(2603),
    [sym_date_literal] = ACTIONS(2601),
    [sym_time_literal] = ACTIONS(2601),
    [sym_biginteger_literal] = ACTIONS(2603),
    [anon_sym_else] = ACTIONS(2601),
    [anon_sym_ELSE] = ACTIONS(2601),
    [anon_sym_Else] = ACTIONS(2601),
    [anon_sym_in] = ACTIONS(2601),
    [anon_sym_IN] = ACTIONS(2601),
    [anon_sym_In] = ACTIONS(2601),
    [sym_page_keyword] = ACTIONS(2601),
    [anon_sym_codeunit] = ACTIONS(2601),
    [anon_sym_CODEUNIT] = ACTIONS(2601),
    [anon_sym_Codeunit] = ACTIONS(2601),
    [anon_sym_CodeUnit] = ACTIONS(2601),
    [anon_sym_COdeunit] = ACTIONS(2601),
    [anon_sym_codeUnit] = ACTIONS(2601),
    [sym_report_keyword] = ACTIONS(2601),
    [sym_query_keyword] = ACTIONS(2601),
    [anon_sym_xmlport] = ACTIONS(2601),
    [anon_sym_XMLPORT] = ACTIONS(2601),
    [anon_sym_Xmlport] = ACTIONS(2601),
    [anon_sym_XMLport] = ACTIONS(2601),
    [anon_sym_XMLPort] = ACTIONS(2601),
    [anon_sym_XmlPort] = ACTIONS(2601),
    [anon_sym_enum] = ACTIONS(2601),
    [anon_sym_ENUM] = ACTIONS(2601),
    [anon_sym_Enum] = ACTIONS(2601),
    [anon_sym_eNUM] = ACTIONS(2601),
    [anon_sym_eNum] = ACTIONS(2601),
    [anon_sym_ENum] = ACTIONS(2601),
    [sym_quoted_identifier] = ACTIONS(2603),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2603),
    [sym_integer] = ACTIONS(2601),
    [sym_continue_as_identifier] = ACTIONS(2603),
    [sym_preproc_open] = ACTIONS(2603),
  },
  [STATE(2187)] = {
    [sym_identifier] = ACTIONS(2633),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_EQ] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [anon_sym_DASH] = ACTIONS(2633),
    [aux_sym_boolean_token1] = ACTIONS(2633),
    [aux_sym_boolean_token2] = ACTIONS(2633),
    [sym_decimal] = ACTIONS(2633),
    [anon_sym_LPAREN] = ACTIONS(2635),
    [anon_sym_DOT_DOT] = ACTIONS(2635),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2633),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [aux_sym_record_type_token1] = ACTIONS(2633),
    [aux_sym_basic_type_token21] = ACTIONS(2633),
    [aux_sym_basic_type_token22] = ACTIONS(2633),
    [aux_sym_basic_type_token48] = ACTIONS(2633),
    [anon_sym_not] = ACTIONS(2633),
    [anon_sym_NOT] = ACTIONS(2633),
    [anon_sym_Not] = ACTIONS(2633),
    [anon_sym_POUNDelif] = ACTIONS(2635),
    [anon_sym_POUNDELIF] = ACTIONS(2635),
    [anon_sym_POUNDElif] = ACTIONS(2635),
    [anon_sym_POUNDelse] = ACTIONS(2635),
    [anon_sym_POUNDELSE] = ACTIONS(2635),
    [anon_sym_POUNDElse] = ACTIONS(2635),
    [anon_sym_POUNDendif] = ACTIONS(2635),
    [anon_sym_POUNDENDIF] = ACTIONS(2635),
    [anon_sym_POUNDEndif] = ACTIONS(2635),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2635),
    [aux_sym__expression_token1] = ACTIONS(2635),
    [aux_sym__expression_token2] = ACTIONS(2635),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2633),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2633),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_div] = ACTIONS(2633),
    [anon_sym_DIV] = ACTIONS(2633),
    [anon_sym_Div] = ACTIONS(2633),
    [anon_sym_mod] = ACTIONS(2633),
    [anon_sym_MOD] = ACTIONS(2633),
    [anon_sym_Mod] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_GT] = ACTIONS(2635),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_AND] = ACTIONS(2633),
    [anon_sym_And] = ACTIONS(2633),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_OR] = ACTIONS(2633),
    [anon_sym_Or] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_XOR] = ACTIONS(2633),
    [anon_sym_Xor] = ACTIONS(2633),
    [anon_sym_QMARK] = ACTIONS(2635),
    [sym_datetime_literal] = ACTIONS(2635),
    [sym_date_literal] = ACTIONS(2633),
    [sym_time_literal] = ACTIONS(2633),
    [sym_biginteger_literal] = ACTIONS(2635),
    [anon_sym_in] = ACTIONS(2633),
    [anon_sym_IN] = ACTIONS(2633),
    [anon_sym_In] = ACTIONS(2633),
    [sym_page_keyword] = ACTIONS(2633),
    [anon_sym_codeunit] = ACTIONS(2633),
    [anon_sym_CODEUNIT] = ACTIONS(2633),
    [anon_sym_Codeunit] = ACTIONS(2633),
    [anon_sym_CodeUnit] = ACTIONS(2633),
    [anon_sym_COdeunit] = ACTIONS(2633),
    [anon_sym_codeUnit] = ACTIONS(2633),
    [sym_report_keyword] = ACTIONS(2633),
    [sym_query_keyword] = ACTIONS(2633),
    [anon_sym_xmlport] = ACTIONS(2633),
    [anon_sym_XMLPORT] = ACTIONS(2633),
    [anon_sym_Xmlport] = ACTIONS(2633),
    [anon_sym_XMLport] = ACTIONS(2633),
    [anon_sym_XMLPort] = ACTIONS(2633),
    [anon_sym_XmlPort] = ACTIONS(2633),
    [anon_sym_enum] = ACTIONS(2633),
    [anon_sym_ENUM] = ACTIONS(2633),
    [anon_sym_Enum] = ACTIONS(2633),
    [anon_sym_eNUM] = ACTIONS(2633),
    [anon_sym_eNum] = ACTIONS(2633),
    [anon_sym_ENum] = ACTIONS(2633),
    [sym_quoted_identifier] = ACTIONS(2635),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2635),
    [sym_integer] = ACTIONS(2633),
    [sym_continue_as_identifier] = ACTIONS(2635),
    [sym_preproc_close] = ACTIONS(2635),
  },
  [STATE(2188)] = {
    [sym_identifier] = ACTIONS(2641),
    [anon_sym_DOT] = ACTIONS(2641),
    [anon_sym_EQ] = ACTIONS(2643),
    [anon_sym_COMMA] = ACTIONS(2643),
    [anon_sym_DASH] = ACTIONS(2641),
    [aux_sym_boolean_token1] = ACTIONS(2641),
    [aux_sym_boolean_token2] = ACTIONS(2641),
    [sym_decimal] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(2643),
    [anon_sym_DOT_DOT] = ACTIONS(2643),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2641),
    [anon_sym_STAR] = ACTIONS(2641),
    [anon_sym_LBRACK] = ACTIONS(2643),
    [aux_sym_record_type_token1] = ACTIONS(2641),
    [aux_sym_basic_type_token21] = ACTIONS(2641),
    [aux_sym_basic_type_token22] = ACTIONS(2641),
    [aux_sym_basic_type_token48] = ACTIONS(2641),
    [anon_sym_not] = ACTIONS(2641),
    [anon_sym_NOT] = ACTIONS(2641),
    [anon_sym_Not] = ACTIONS(2641),
    [anon_sym_POUNDelif] = ACTIONS(2643),
    [anon_sym_POUNDELIF] = ACTIONS(2643),
    [anon_sym_POUNDElif] = ACTIONS(2643),
    [anon_sym_POUNDelse] = ACTIONS(2643),
    [anon_sym_POUNDELSE] = ACTIONS(2643),
    [anon_sym_POUNDElse] = ACTIONS(2643),
    [anon_sym_POUNDendif] = ACTIONS(2643),
    [anon_sym_POUNDENDIF] = ACTIONS(2643),
    [anon_sym_POUNDEndif] = ACTIONS(2643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2643),
    [aux_sym__expression_token1] = ACTIONS(2643),
    [aux_sym__expression_token2] = ACTIONS(2643),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2641),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2641),
    [anon_sym_SLASH] = ACTIONS(2641),
    [anon_sym_div] = ACTIONS(2641),
    [anon_sym_DIV] = ACTIONS(2641),
    [anon_sym_Div] = ACTIONS(2641),
    [anon_sym_mod] = ACTIONS(2641),
    [anon_sym_MOD] = ACTIONS(2641),
    [anon_sym_Mod] = ACTIONS(2641),
    [anon_sym_PLUS] = ACTIONS(2641),
    [anon_sym_GT_EQ] = ACTIONS(2643),
    [anon_sym_LT_EQ] = ACTIONS(2643),
    [anon_sym_GT] = ACTIONS(2641),
    [anon_sym_LT] = ACTIONS(2641),
    [anon_sym_LT_GT] = ACTIONS(2643),
    [anon_sym_and] = ACTIONS(2641),
    [anon_sym_AND] = ACTIONS(2641),
    [anon_sym_And] = ACTIONS(2641),
    [anon_sym_or] = ACTIONS(2641),
    [anon_sym_OR] = ACTIONS(2641),
    [anon_sym_Or] = ACTIONS(2641),
    [anon_sym_xor] = ACTIONS(2641),
    [anon_sym_XOR] = ACTIONS(2641),
    [anon_sym_Xor] = ACTIONS(2641),
    [anon_sym_QMARK] = ACTIONS(2643),
    [sym_datetime_literal] = ACTIONS(2643),
    [sym_date_literal] = ACTIONS(2641),
    [sym_time_literal] = ACTIONS(2641),
    [sym_biginteger_literal] = ACTIONS(2643),
    [anon_sym_in] = ACTIONS(2641),
    [anon_sym_IN] = ACTIONS(2641),
    [anon_sym_In] = ACTIONS(2641),
    [sym_page_keyword] = ACTIONS(2641),
    [anon_sym_codeunit] = ACTIONS(2641),
    [anon_sym_CODEUNIT] = ACTIONS(2641),
    [anon_sym_Codeunit] = ACTIONS(2641),
    [anon_sym_CodeUnit] = ACTIONS(2641),
    [anon_sym_COdeunit] = ACTIONS(2641),
    [anon_sym_codeUnit] = ACTIONS(2641),
    [sym_report_keyword] = ACTIONS(2641),
    [sym_query_keyword] = ACTIONS(2641),
    [anon_sym_xmlport] = ACTIONS(2641),
    [anon_sym_XMLPORT] = ACTIONS(2641),
    [anon_sym_Xmlport] = ACTIONS(2641),
    [anon_sym_XMLport] = ACTIONS(2641),
    [anon_sym_XMLPort] = ACTIONS(2641),
    [anon_sym_XmlPort] = ACTIONS(2641),
    [anon_sym_enum] = ACTIONS(2641),
    [anon_sym_ENUM] = ACTIONS(2641),
    [anon_sym_Enum] = ACTIONS(2641),
    [anon_sym_eNUM] = ACTIONS(2641),
    [anon_sym_eNum] = ACTIONS(2641),
    [anon_sym_ENum] = ACTIONS(2641),
    [sym_quoted_identifier] = ACTIONS(2643),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2643),
    [sym_integer] = ACTIONS(2641),
    [sym_continue_as_identifier] = ACTIONS(2643),
    [sym_preproc_close] = ACTIONS(2643),
  },
  [STATE(2189)] = {
    [sym_identifier] = ACTIONS(2645),
    [anon_sym_DOT] = ACTIONS(2645),
    [anon_sym_EQ] = ACTIONS(2647),
    [anon_sym_COMMA] = ACTIONS(2647),
    [anon_sym_DASH] = ACTIONS(2645),
    [aux_sym_boolean_token1] = ACTIONS(2645),
    [aux_sym_boolean_token2] = ACTIONS(2645),
    [sym_decimal] = ACTIONS(2645),
    [anon_sym_LPAREN] = ACTIONS(2647),
    [anon_sym_DOT_DOT] = ACTIONS(2647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2645),
    [anon_sym_STAR] = ACTIONS(2645),
    [anon_sym_LBRACK] = ACTIONS(2647),
    [aux_sym_record_type_token1] = ACTIONS(2645),
    [aux_sym_basic_type_token21] = ACTIONS(2645),
    [aux_sym_basic_type_token22] = ACTIONS(2645),
    [aux_sym_basic_type_token48] = ACTIONS(2645),
    [anon_sym_not] = ACTIONS(2645),
    [anon_sym_NOT] = ACTIONS(2645),
    [anon_sym_Not] = ACTIONS(2645),
    [anon_sym_POUNDelif] = ACTIONS(2647),
    [anon_sym_POUNDELIF] = ACTIONS(2647),
    [anon_sym_POUNDElif] = ACTIONS(2647),
    [anon_sym_POUNDelse] = ACTIONS(2647),
    [anon_sym_POUNDELSE] = ACTIONS(2647),
    [anon_sym_POUNDElse] = ACTIONS(2647),
    [anon_sym_POUNDendif] = ACTIONS(2647),
    [anon_sym_POUNDENDIF] = ACTIONS(2647),
    [anon_sym_POUNDEndif] = ACTIONS(2647),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2647),
    [aux_sym__expression_token1] = ACTIONS(2647),
    [aux_sym__expression_token2] = ACTIONS(2647),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2645),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2645),
    [anon_sym_SLASH] = ACTIONS(2645),
    [anon_sym_div] = ACTIONS(2645),
    [anon_sym_DIV] = ACTIONS(2645),
    [anon_sym_Div] = ACTIONS(2645),
    [anon_sym_mod] = ACTIONS(2645),
    [anon_sym_MOD] = ACTIONS(2645),
    [anon_sym_Mod] = ACTIONS(2645),
    [anon_sym_PLUS] = ACTIONS(2645),
    [anon_sym_GT_EQ] = ACTIONS(2647),
    [anon_sym_LT_EQ] = ACTIONS(2647),
    [anon_sym_GT] = ACTIONS(2645),
    [anon_sym_LT] = ACTIONS(2645),
    [anon_sym_LT_GT] = ACTIONS(2647),
    [anon_sym_and] = ACTIONS(2645),
    [anon_sym_AND] = ACTIONS(2645),
    [anon_sym_And] = ACTIONS(2645),
    [anon_sym_or] = ACTIONS(2645),
    [anon_sym_OR] = ACTIONS(2645),
    [anon_sym_Or] = ACTIONS(2645),
    [anon_sym_xor] = ACTIONS(2645),
    [anon_sym_XOR] = ACTIONS(2645),
    [anon_sym_Xor] = ACTIONS(2645),
    [anon_sym_QMARK] = ACTIONS(2647),
    [sym_datetime_literal] = ACTIONS(2647),
    [sym_date_literal] = ACTIONS(2645),
    [sym_time_literal] = ACTIONS(2645),
    [sym_biginteger_literal] = ACTIONS(2647),
    [anon_sym_in] = ACTIONS(2645),
    [anon_sym_IN] = ACTIONS(2645),
    [anon_sym_In] = ACTIONS(2645),
    [sym_page_keyword] = ACTIONS(2645),
    [anon_sym_codeunit] = ACTIONS(2645),
    [anon_sym_CODEUNIT] = ACTIONS(2645),
    [anon_sym_Codeunit] = ACTIONS(2645),
    [anon_sym_CodeUnit] = ACTIONS(2645),
    [anon_sym_COdeunit] = ACTIONS(2645),
    [anon_sym_codeUnit] = ACTIONS(2645),
    [sym_report_keyword] = ACTIONS(2645),
    [sym_query_keyword] = ACTIONS(2645),
    [anon_sym_xmlport] = ACTIONS(2645),
    [anon_sym_XMLPORT] = ACTIONS(2645),
    [anon_sym_Xmlport] = ACTIONS(2645),
    [anon_sym_XMLport] = ACTIONS(2645),
    [anon_sym_XMLPort] = ACTIONS(2645),
    [anon_sym_XmlPort] = ACTIONS(2645),
    [anon_sym_enum] = ACTIONS(2645),
    [anon_sym_ENUM] = ACTIONS(2645),
    [anon_sym_Enum] = ACTIONS(2645),
    [anon_sym_eNUM] = ACTIONS(2645),
    [anon_sym_eNum] = ACTIONS(2645),
    [anon_sym_ENum] = ACTIONS(2645),
    [sym_quoted_identifier] = ACTIONS(2647),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2647),
    [sym_integer] = ACTIONS(2645),
    [sym_continue_as_identifier] = ACTIONS(2647),
    [sym_preproc_close] = ACTIONS(2647),
  },
  [STATE(2190)] = {
    [sym_identifier] = ACTIONS(2573),
    [anon_sym_DOT] = ACTIONS(2573),
    [anon_sym_EQ] = ACTIONS(2575),
    [anon_sym_COMMA] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2573),
    [aux_sym_boolean_token1] = ACTIONS(2573),
    [aux_sym_boolean_token2] = ACTIONS(2573),
    [sym_decimal] = ACTIONS(2573),
    [anon_sym_LPAREN] = ACTIONS(2575),
    [anon_sym_DOT_DOT] = ACTIONS(2575),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2575),
    [aux_sym_record_type_token1] = ACTIONS(2573),
    [aux_sym_basic_type_token21] = ACTIONS(2573),
    [aux_sym_basic_type_token22] = ACTIONS(2573),
    [aux_sym_basic_type_token48] = ACTIONS(2573),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_NOT] = ACTIONS(2573),
    [anon_sym_Not] = ACTIONS(2573),
    [anon_sym_POUNDelif] = ACTIONS(2575),
    [anon_sym_POUNDELIF] = ACTIONS(2575),
    [anon_sym_POUNDElif] = ACTIONS(2575),
    [anon_sym_POUNDelse] = ACTIONS(2575),
    [anon_sym_POUNDELSE] = ACTIONS(2575),
    [anon_sym_POUNDElse] = ACTIONS(2575),
    [anon_sym_POUNDendif] = ACTIONS(2575),
    [anon_sym_POUNDENDIF] = ACTIONS(2575),
    [anon_sym_POUNDEndif] = ACTIONS(2575),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2575),
    [aux_sym__expression_token1] = ACTIONS(2575),
    [aux_sym__expression_token2] = ACTIONS(2575),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2573),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2573),
    [anon_sym_SLASH] = ACTIONS(2573),
    [anon_sym_div] = ACTIONS(2573),
    [anon_sym_DIV] = ACTIONS(2573),
    [anon_sym_Div] = ACTIONS(2573),
    [anon_sym_mod] = ACTIONS(2573),
    [anon_sym_MOD] = ACTIONS(2573),
    [anon_sym_Mod] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_GT_EQ] = ACTIONS(2575),
    [anon_sym_LT_EQ] = ACTIONS(2575),
    [anon_sym_GT] = ACTIONS(2573),
    [anon_sym_LT] = ACTIONS(2573),
    [anon_sym_LT_GT] = ACTIONS(2575),
    [anon_sym_and] = ACTIONS(2573),
    [anon_sym_AND] = ACTIONS(2573),
    [anon_sym_And] = ACTIONS(2573),
    [anon_sym_or] = ACTIONS(2573),
    [anon_sym_OR] = ACTIONS(2573),
    [anon_sym_Or] = ACTIONS(2573),
    [anon_sym_xor] = ACTIONS(2573),
    [anon_sym_XOR] = ACTIONS(2573),
    [anon_sym_Xor] = ACTIONS(2573),
    [anon_sym_QMARK] = ACTIONS(2575),
    [sym_datetime_literal] = ACTIONS(2575),
    [sym_date_literal] = ACTIONS(2573),
    [sym_time_literal] = ACTIONS(2573),
    [sym_biginteger_literal] = ACTIONS(2575),
    [anon_sym_in] = ACTIONS(2573),
    [anon_sym_IN] = ACTIONS(2573),
    [anon_sym_In] = ACTIONS(2573),
    [sym_page_keyword] = ACTIONS(2573),
    [anon_sym_codeunit] = ACTIONS(2573),
    [anon_sym_CODEUNIT] = ACTIONS(2573),
    [anon_sym_Codeunit] = ACTIONS(2573),
    [anon_sym_CodeUnit] = ACTIONS(2573),
    [anon_sym_COdeunit] = ACTIONS(2573),
    [anon_sym_codeUnit] = ACTIONS(2573),
    [sym_report_keyword] = ACTIONS(2573),
    [sym_query_keyword] = ACTIONS(2573),
    [anon_sym_xmlport] = ACTIONS(2573),
    [anon_sym_XMLPORT] = ACTIONS(2573),
    [anon_sym_Xmlport] = ACTIONS(2573),
    [anon_sym_XMLport] = ACTIONS(2573),
    [anon_sym_XMLPort] = ACTIONS(2573),
    [anon_sym_XmlPort] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_ENUM] = ACTIONS(2573),
    [anon_sym_Enum] = ACTIONS(2573),
    [anon_sym_eNUM] = ACTIONS(2573),
    [anon_sym_eNum] = ACTIONS(2573),
    [anon_sym_ENum] = ACTIONS(2573),
    [sym_quoted_identifier] = ACTIONS(2575),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2575),
    [sym_integer] = ACTIONS(2573),
    [sym_continue_as_identifier] = ACTIONS(2575),
    [sym_preproc_close] = ACTIONS(2575),
  },
  [STATE(2191)] = {
    [sym_identifier] = ACTIONS(2577),
    [anon_sym_DOT] = ACTIONS(2577),
    [anon_sym_EQ] = ACTIONS(2579),
    [anon_sym_COMMA] = ACTIONS(2579),
    [anon_sym_DASH] = ACTIONS(2577),
    [aux_sym_boolean_token1] = ACTIONS(2577),
    [aux_sym_boolean_token2] = ACTIONS(2577),
    [sym_decimal] = ACTIONS(2577),
    [anon_sym_LPAREN] = ACTIONS(2579),
    [anon_sym_DOT_DOT] = ACTIONS(2579),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2577),
    [anon_sym_STAR] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [aux_sym_record_type_token1] = ACTIONS(2577),
    [aux_sym_basic_type_token21] = ACTIONS(2577),
    [aux_sym_basic_type_token22] = ACTIONS(2577),
    [aux_sym_basic_type_token48] = ACTIONS(2577),
    [anon_sym_not] = ACTIONS(2577),
    [anon_sym_NOT] = ACTIONS(2577),
    [anon_sym_Not] = ACTIONS(2577),
    [anon_sym_POUNDelif] = ACTIONS(2579),
    [anon_sym_POUNDELIF] = ACTIONS(2579),
    [anon_sym_POUNDElif] = ACTIONS(2579),
    [anon_sym_POUNDelse] = ACTIONS(2579),
    [anon_sym_POUNDELSE] = ACTIONS(2579),
    [anon_sym_POUNDElse] = ACTIONS(2579),
    [anon_sym_POUNDendif] = ACTIONS(2579),
    [anon_sym_POUNDENDIF] = ACTIONS(2579),
    [anon_sym_POUNDEndif] = ACTIONS(2579),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2579),
    [aux_sym__expression_token1] = ACTIONS(2579),
    [aux_sym__expression_token2] = ACTIONS(2579),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2577),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2577),
    [anon_sym_SLASH] = ACTIONS(2577),
    [anon_sym_div] = ACTIONS(2577),
    [anon_sym_DIV] = ACTIONS(2577),
    [anon_sym_Div] = ACTIONS(2577),
    [anon_sym_mod] = ACTIONS(2577),
    [anon_sym_MOD] = ACTIONS(2577),
    [anon_sym_Mod] = ACTIONS(2577),
    [anon_sym_PLUS] = ACTIONS(2577),
    [anon_sym_GT_EQ] = ACTIONS(2579),
    [anon_sym_LT_EQ] = ACTIONS(2579),
    [anon_sym_GT] = ACTIONS(2577),
    [anon_sym_LT] = ACTIONS(2577),
    [anon_sym_LT_GT] = ACTIONS(2579),
    [anon_sym_and] = ACTIONS(2577),
    [anon_sym_AND] = ACTIONS(2577),
    [anon_sym_And] = ACTIONS(2577),
    [anon_sym_or] = ACTIONS(2577),
    [anon_sym_OR] = ACTIONS(2577),
    [anon_sym_Or] = ACTIONS(2577),
    [anon_sym_xor] = ACTIONS(2577),
    [anon_sym_XOR] = ACTIONS(2577),
    [anon_sym_Xor] = ACTIONS(2577),
    [anon_sym_QMARK] = ACTIONS(2579),
    [sym_datetime_literal] = ACTIONS(2579),
    [sym_date_literal] = ACTIONS(2577),
    [sym_time_literal] = ACTIONS(2577),
    [sym_biginteger_literal] = ACTIONS(2579),
    [anon_sym_in] = ACTIONS(2577),
    [anon_sym_IN] = ACTIONS(2577),
    [anon_sym_In] = ACTIONS(2577),
    [sym_page_keyword] = ACTIONS(2577),
    [anon_sym_codeunit] = ACTIONS(2577),
    [anon_sym_CODEUNIT] = ACTIONS(2577),
    [anon_sym_Codeunit] = ACTIONS(2577),
    [anon_sym_CodeUnit] = ACTIONS(2577),
    [anon_sym_COdeunit] = ACTIONS(2577),
    [anon_sym_codeUnit] = ACTIONS(2577),
    [sym_report_keyword] = ACTIONS(2577),
    [sym_query_keyword] = ACTIONS(2577),
    [anon_sym_xmlport] = ACTIONS(2577),
    [anon_sym_XMLPORT] = ACTIONS(2577),
    [anon_sym_Xmlport] = ACTIONS(2577),
    [anon_sym_XMLport] = ACTIONS(2577),
    [anon_sym_XMLPort] = ACTIONS(2577),
    [anon_sym_XmlPort] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_ENUM] = ACTIONS(2577),
    [anon_sym_Enum] = ACTIONS(2577),
    [anon_sym_eNUM] = ACTIONS(2577),
    [anon_sym_eNum] = ACTIONS(2577),
    [anon_sym_ENum] = ACTIONS(2577),
    [sym_quoted_identifier] = ACTIONS(2579),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2579),
    [sym_integer] = ACTIONS(2577),
    [sym_continue_as_identifier] = ACTIONS(2579),
    [sym_preproc_close] = ACTIONS(2579),
  },
  [STATE(2192)] = {
    [sym_identifier] = ACTIONS(2581),
    [anon_sym_DOT] = ACTIONS(2581),
    [anon_sym_EQ] = ACTIONS(2583),
    [anon_sym_COMMA] = ACTIONS(2583),
    [anon_sym_DASH] = ACTIONS(2581),
    [aux_sym_boolean_token1] = ACTIONS(2581),
    [aux_sym_boolean_token2] = ACTIONS(2581),
    [sym_decimal] = ACTIONS(2581),
    [anon_sym_LPAREN] = ACTIONS(2583),
    [anon_sym_DOT_DOT] = ACTIONS(2583),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2581),
    [anon_sym_STAR] = ACTIONS(2581),
    [anon_sym_LBRACK] = ACTIONS(2583),
    [aux_sym_record_type_token1] = ACTIONS(2581),
    [aux_sym_basic_type_token21] = ACTIONS(2581),
    [aux_sym_basic_type_token22] = ACTIONS(2581),
    [aux_sym_basic_type_token48] = ACTIONS(2581),
    [anon_sym_not] = ACTIONS(2581),
    [anon_sym_NOT] = ACTIONS(2581),
    [anon_sym_Not] = ACTIONS(2581),
    [anon_sym_POUNDelif] = ACTIONS(2583),
    [anon_sym_POUNDELIF] = ACTIONS(2583),
    [anon_sym_POUNDElif] = ACTIONS(2583),
    [anon_sym_POUNDelse] = ACTIONS(2583),
    [anon_sym_POUNDELSE] = ACTIONS(2583),
    [anon_sym_POUNDElse] = ACTIONS(2583),
    [anon_sym_POUNDendif] = ACTIONS(2583),
    [anon_sym_POUNDENDIF] = ACTIONS(2583),
    [anon_sym_POUNDEndif] = ACTIONS(2583),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2583),
    [aux_sym__expression_token1] = ACTIONS(2583),
    [aux_sym__expression_token2] = ACTIONS(2583),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2581),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2581),
    [anon_sym_SLASH] = ACTIONS(2581),
    [anon_sym_div] = ACTIONS(2581),
    [anon_sym_DIV] = ACTIONS(2581),
    [anon_sym_Div] = ACTIONS(2581),
    [anon_sym_mod] = ACTIONS(2581),
    [anon_sym_MOD] = ACTIONS(2581),
    [anon_sym_Mod] = ACTIONS(2581),
    [anon_sym_PLUS] = ACTIONS(2581),
    [anon_sym_GT_EQ] = ACTIONS(2583),
    [anon_sym_LT_EQ] = ACTIONS(2583),
    [anon_sym_GT] = ACTIONS(2581),
    [anon_sym_LT] = ACTIONS(2581),
    [anon_sym_LT_GT] = ACTIONS(2583),
    [anon_sym_and] = ACTIONS(2581),
    [anon_sym_AND] = ACTIONS(2581),
    [anon_sym_And] = ACTIONS(2581),
    [anon_sym_or] = ACTIONS(2581),
    [anon_sym_OR] = ACTIONS(2581),
    [anon_sym_Or] = ACTIONS(2581),
    [anon_sym_xor] = ACTIONS(2581),
    [anon_sym_XOR] = ACTIONS(2581),
    [anon_sym_Xor] = ACTIONS(2581),
    [anon_sym_QMARK] = ACTIONS(2583),
    [sym_datetime_literal] = ACTIONS(2583),
    [sym_date_literal] = ACTIONS(2581),
    [sym_time_literal] = ACTIONS(2581),
    [sym_biginteger_literal] = ACTIONS(2583),
    [anon_sym_in] = ACTIONS(2581),
    [anon_sym_IN] = ACTIONS(2581),
    [anon_sym_In] = ACTIONS(2581),
    [sym_page_keyword] = ACTIONS(2581),
    [anon_sym_codeunit] = ACTIONS(2581),
    [anon_sym_CODEUNIT] = ACTIONS(2581),
    [anon_sym_Codeunit] = ACTIONS(2581),
    [anon_sym_CodeUnit] = ACTIONS(2581),
    [anon_sym_COdeunit] = ACTIONS(2581),
    [anon_sym_codeUnit] = ACTIONS(2581),
    [sym_report_keyword] = ACTIONS(2581),
    [sym_query_keyword] = ACTIONS(2581),
    [anon_sym_xmlport] = ACTIONS(2581),
    [anon_sym_XMLPORT] = ACTIONS(2581),
    [anon_sym_Xmlport] = ACTIONS(2581),
    [anon_sym_XMLport] = ACTIONS(2581),
    [anon_sym_XMLPort] = ACTIONS(2581),
    [anon_sym_XmlPort] = ACTIONS(2581),
    [anon_sym_enum] = ACTIONS(2581),
    [anon_sym_ENUM] = ACTIONS(2581),
    [anon_sym_Enum] = ACTIONS(2581),
    [anon_sym_eNUM] = ACTIONS(2581),
    [anon_sym_eNum] = ACTIONS(2581),
    [anon_sym_ENum] = ACTIONS(2581),
    [sym_quoted_identifier] = ACTIONS(2583),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2583),
    [sym_integer] = ACTIONS(2581),
    [sym_continue_as_identifier] = ACTIONS(2583),
    [sym_preproc_close] = ACTIONS(2583),
  },
  [STATE(2193)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2441),
    [sym_preproc_endif] = STATE(4673),
    [sym_assignment_expression] = STATE(6338),
    [sym_case_branch] = STATE(2160),
    [sym_preproc_split_case_branch] = STATE(3395),
    [aux_sym__case_pattern] = STATE(2579),
    [sym_preproc_conditional_case_patterns] = STATE(2579),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(9324),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(87),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(2160),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(3754),
    [anon_sym_ELSE] = ACTIONS(3754),
    [anon_sym_Else] = ACTIONS(3754),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2194)] = {
    [sym_identifier] = ACTIONS(2569),
    [anon_sym_DOT] = ACTIONS(2569),
    [anon_sym_EQ] = ACTIONS(2571),
    [anon_sym_COMMA] = ACTIONS(2571),
    [anon_sym_DASH] = ACTIONS(2569),
    [aux_sym_boolean_token1] = ACTIONS(2569),
    [aux_sym_boolean_token2] = ACTIONS(2569),
    [sym_decimal] = ACTIONS(2569),
    [anon_sym_LPAREN] = ACTIONS(2571),
    [anon_sym_DOT_DOT] = ACTIONS(2571),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2569),
    [anon_sym_STAR] = ACTIONS(2569),
    [anon_sym_LBRACK] = ACTIONS(2571),
    [aux_sym_record_type_token1] = ACTIONS(2569),
    [aux_sym_basic_type_token21] = ACTIONS(2569),
    [aux_sym_basic_type_token22] = ACTIONS(2569),
    [aux_sym_basic_type_token48] = ACTIONS(2569),
    [anon_sym_not] = ACTIONS(2569),
    [anon_sym_NOT] = ACTIONS(2569),
    [anon_sym_Not] = ACTIONS(2569),
    [anon_sym_POUNDelif] = ACTIONS(2571),
    [anon_sym_POUNDELIF] = ACTIONS(2571),
    [anon_sym_POUNDElif] = ACTIONS(2571),
    [anon_sym_POUNDelse] = ACTIONS(2571),
    [anon_sym_POUNDELSE] = ACTIONS(2571),
    [anon_sym_POUNDElse] = ACTIONS(2571),
    [anon_sym_POUNDendif] = ACTIONS(2571),
    [anon_sym_POUNDENDIF] = ACTIONS(2571),
    [anon_sym_POUNDEndif] = ACTIONS(2571),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2571),
    [aux_sym__expression_token1] = ACTIONS(2571),
    [aux_sym__expression_token2] = ACTIONS(2571),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2569),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2569),
    [anon_sym_SLASH] = ACTIONS(2569),
    [anon_sym_div] = ACTIONS(2569),
    [anon_sym_DIV] = ACTIONS(2569),
    [anon_sym_Div] = ACTIONS(2569),
    [anon_sym_mod] = ACTIONS(2569),
    [anon_sym_MOD] = ACTIONS(2569),
    [anon_sym_Mod] = ACTIONS(2569),
    [anon_sym_PLUS] = ACTIONS(2569),
    [anon_sym_GT_EQ] = ACTIONS(2571),
    [anon_sym_LT_EQ] = ACTIONS(2571),
    [anon_sym_GT] = ACTIONS(2569),
    [anon_sym_LT] = ACTIONS(2569),
    [anon_sym_LT_GT] = ACTIONS(2571),
    [anon_sym_and] = ACTIONS(2569),
    [anon_sym_AND] = ACTIONS(2569),
    [anon_sym_And] = ACTIONS(2569),
    [anon_sym_or] = ACTIONS(2569),
    [anon_sym_OR] = ACTIONS(2569),
    [anon_sym_Or] = ACTIONS(2569),
    [anon_sym_xor] = ACTIONS(2569),
    [anon_sym_XOR] = ACTIONS(2569),
    [anon_sym_Xor] = ACTIONS(2569),
    [anon_sym_QMARK] = ACTIONS(2571),
    [sym_datetime_literal] = ACTIONS(2571),
    [sym_date_literal] = ACTIONS(2569),
    [sym_time_literal] = ACTIONS(2569),
    [sym_biginteger_literal] = ACTIONS(2571),
    [anon_sym_in] = ACTIONS(2569),
    [anon_sym_IN] = ACTIONS(2569),
    [anon_sym_In] = ACTIONS(2569),
    [sym_page_keyword] = ACTIONS(2569),
    [anon_sym_codeunit] = ACTIONS(2569),
    [anon_sym_CODEUNIT] = ACTIONS(2569),
    [anon_sym_Codeunit] = ACTIONS(2569),
    [anon_sym_CodeUnit] = ACTIONS(2569),
    [anon_sym_COdeunit] = ACTIONS(2569),
    [anon_sym_codeUnit] = ACTIONS(2569),
    [sym_report_keyword] = ACTIONS(2569),
    [sym_query_keyword] = ACTIONS(2569),
    [anon_sym_xmlport] = ACTIONS(2569),
    [anon_sym_XMLPORT] = ACTIONS(2569),
    [anon_sym_Xmlport] = ACTIONS(2569),
    [anon_sym_XMLport] = ACTIONS(2569),
    [anon_sym_XMLPort] = ACTIONS(2569),
    [anon_sym_XmlPort] = ACTIONS(2569),
    [anon_sym_enum] = ACTIONS(2569),
    [anon_sym_ENUM] = ACTIONS(2569),
    [anon_sym_Enum] = ACTIONS(2569),
    [anon_sym_eNUM] = ACTIONS(2569),
    [anon_sym_eNum] = ACTIONS(2569),
    [anon_sym_ENum] = ACTIONS(2569),
    [sym_quoted_identifier] = ACTIONS(2571),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2571),
    [sym_integer] = ACTIONS(2569),
    [sym_continue_as_identifier] = ACTIONS(2571),
    [sym_preproc_close] = ACTIONS(2571),
  },
  [STATE(2195)] = {
    [sym_identifier] = ACTIONS(2613),
    [anon_sym_SEMI] = ACTIONS(2615),
    [anon_sym_DOT] = ACTIONS(2613),
    [anon_sym_EQ] = ACTIONS(2615),
    [anon_sym_COMMA] = ACTIONS(2615),
    [anon_sym_COLON] = ACTIONS(2613),
    [anon_sym_DASH] = ACTIONS(2613),
    [aux_sym_boolean_token1] = ACTIONS(2613),
    [aux_sym_boolean_token2] = ACTIONS(2613),
    [sym_decimal] = ACTIONS(2613),
    [anon_sym_LPAREN] = ACTIONS(2615),
    [anon_sym_DOT_DOT] = ACTIONS(2615),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2613),
    [anon_sym_STAR] = ACTIONS(2613),
    [anon_sym_LBRACK] = ACTIONS(5443),
    [aux_sym_record_type_token1] = ACTIONS(2613),
    [aux_sym_basic_type_token21] = ACTIONS(2613),
    [aux_sym_basic_type_token22] = ACTIONS(2613),
    [aux_sym_basic_type_token48] = ACTIONS(2613),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2613),
    [anon_sym_POUNDif] = ACTIONS(2615),
    [anon_sym_POUNDIF] = ACTIONS(2615),
    [anon_sym_POUNDIf] = ACTIONS(2615),
    [anon_sym_not] = ACTIONS(2613),
    [anon_sym_NOT] = ACTIONS(2613),
    [anon_sym_Not] = ACTIONS(2613),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2615),
    [aux_sym__expression_token1] = ACTIONS(2615),
    [aux_sym__expression_token2] = ACTIONS(2615),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2613),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2613),
    [anon_sym_SLASH] = ACTIONS(2613),
    [anon_sym_div] = ACTIONS(2613),
    [anon_sym_DIV] = ACTIONS(2613),
    [anon_sym_Div] = ACTIONS(2613),
    [anon_sym_mod] = ACTIONS(2613),
    [anon_sym_MOD] = ACTIONS(2613),
    [anon_sym_Mod] = ACTIONS(2613),
    [anon_sym_PLUS] = ACTIONS(2613),
    [anon_sym_GT_EQ] = ACTIONS(2615),
    [anon_sym_LT_EQ] = ACTIONS(2615),
    [anon_sym_GT] = ACTIONS(2613),
    [anon_sym_LT] = ACTIONS(2613),
    [anon_sym_LT_GT] = ACTIONS(2615),
    [anon_sym_and] = ACTIONS(2613),
    [anon_sym_AND] = ACTIONS(2613),
    [anon_sym_And] = ACTIONS(2613),
    [anon_sym_or] = ACTIONS(2613),
    [anon_sym_OR] = ACTIONS(2613),
    [anon_sym_Or] = ACTIONS(2613),
    [anon_sym_xor] = ACTIONS(2613),
    [anon_sym_XOR] = ACTIONS(2613),
    [anon_sym_Xor] = ACTIONS(2613),
    [anon_sym_QMARK] = ACTIONS(2615),
    [sym_datetime_literal] = ACTIONS(2615),
    [sym_date_literal] = ACTIONS(2613),
    [sym_time_literal] = ACTIONS(2613),
    [sym_biginteger_literal] = ACTIONS(2615),
    [anon_sym_else] = ACTIONS(2613),
    [anon_sym_ELSE] = ACTIONS(2613),
    [anon_sym_Else] = ACTIONS(2613),
    [anon_sym_in] = ACTIONS(2613),
    [anon_sym_IN] = ACTIONS(2613),
    [anon_sym_In] = ACTIONS(2613),
    [sym_page_keyword] = ACTIONS(2613),
    [anon_sym_codeunit] = ACTIONS(2613),
    [anon_sym_CODEUNIT] = ACTIONS(2613),
    [anon_sym_Codeunit] = ACTIONS(2613),
    [anon_sym_CodeUnit] = ACTIONS(2613),
    [anon_sym_COdeunit] = ACTIONS(2613),
    [anon_sym_codeUnit] = ACTIONS(2613),
    [sym_report_keyword] = ACTIONS(2613),
    [sym_query_keyword] = ACTIONS(2613),
    [anon_sym_xmlport] = ACTIONS(2613),
    [anon_sym_XMLPORT] = ACTIONS(2613),
    [anon_sym_Xmlport] = ACTIONS(2613),
    [anon_sym_XMLport] = ACTIONS(2613),
    [anon_sym_XMLPort] = ACTIONS(2613),
    [anon_sym_XmlPort] = ACTIONS(2613),
    [anon_sym_enum] = ACTIONS(2613),
    [anon_sym_ENUM] = ACTIONS(2613),
    [anon_sym_Enum] = ACTIONS(2613),
    [anon_sym_eNUM] = ACTIONS(2613),
    [anon_sym_eNum] = ACTIONS(2613),
    [anon_sym_ENum] = ACTIONS(2613),
    [sym_quoted_identifier] = ACTIONS(2615),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2615),
    [sym_integer] = ACTIONS(2613),
    [sym_continue_as_identifier] = ACTIONS(2615),
    [sym_preproc_open] = ACTIONS(2615),
  },
  [STATE(2196)] = {
    [sym_identifier] = ACTIONS(2619),
    [anon_sym_SEMI] = ACTIONS(2621),
    [anon_sym_DOT] = ACTIONS(2619),
    [anon_sym_EQ] = ACTIONS(2621),
    [anon_sym_COMMA] = ACTIONS(2621),
    [anon_sym_COLON] = ACTIONS(2619),
    [anon_sym_DASH] = ACTIONS(2619),
    [aux_sym_boolean_token1] = ACTIONS(2619),
    [aux_sym_boolean_token2] = ACTIONS(2619),
    [sym_decimal] = ACTIONS(2619),
    [anon_sym_LPAREN] = ACTIONS(2621),
    [anon_sym_DOT_DOT] = ACTIONS(2621),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2619),
    [anon_sym_STAR] = ACTIONS(2619),
    [anon_sym_LBRACK] = ACTIONS(5445),
    [aux_sym_record_type_token1] = ACTIONS(2619),
    [aux_sym_basic_type_token21] = ACTIONS(2619),
    [aux_sym_basic_type_token22] = ACTIONS(2619),
    [aux_sym_basic_type_token48] = ACTIONS(2619),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2619),
    [anon_sym_POUNDif] = ACTIONS(2621),
    [anon_sym_POUNDIF] = ACTIONS(2621),
    [anon_sym_POUNDIf] = ACTIONS(2621),
    [anon_sym_not] = ACTIONS(2619),
    [anon_sym_NOT] = ACTIONS(2619),
    [anon_sym_Not] = ACTIONS(2619),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2621),
    [aux_sym__expression_token1] = ACTIONS(2621),
    [aux_sym__expression_token2] = ACTIONS(2621),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2619),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2619),
    [anon_sym_SLASH] = ACTIONS(2619),
    [anon_sym_div] = ACTIONS(2619),
    [anon_sym_DIV] = ACTIONS(2619),
    [anon_sym_Div] = ACTIONS(2619),
    [anon_sym_mod] = ACTIONS(2619),
    [anon_sym_MOD] = ACTIONS(2619),
    [anon_sym_Mod] = ACTIONS(2619),
    [anon_sym_PLUS] = ACTIONS(2619),
    [anon_sym_GT_EQ] = ACTIONS(2621),
    [anon_sym_LT_EQ] = ACTIONS(2621),
    [anon_sym_GT] = ACTIONS(2619),
    [anon_sym_LT] = ACTIONS(2619),
    [anon_sym_LT_GT] = ACTIONS(2621),
    [anon_sym_and] = ACTIONS(2619),
    [anon_sym_AND] = ACTIONS(2619),
    [anon_sym_And] = ACTIONS(2619),
    [anon_sym_or] = ACTIONS(2619),
    [anon_sym_OR] = ACTIONS(2619),
    [anon_sym_Or] = ACTIONS(2619),
    [anon_sym_xor] = ACTIONS(2619),
    [anon_sym_XOR] = ACTIONS(2619),
    [anon_sym_Xor] = ACTIONS(2619),
    [anon_sym_QMARK] = ACTIONS(2621),
    [sym_datetime_literal] = ACTIONS(2621),
    [sym_date_literal] = ACTIONS(2619),
    [sym_time_literal] = ACTIONS(2619),
    [sym_biginteger_literal] = ACTIONS(2621),
    [anon_sym_else] = ACTIONS(2619),
    [anon_sym_ELSE] = ACTIONS(2619),
    [anon_sym_Else] = ACTIONS(2619),
    [anon_sym_in] = ACTIONS(2619),
    [anon_sym_IN] = ACTIONS(2619),
    [anon_sym_In] = ACTIONS(2619),
    [sym_page_keyword] = ACTIONS(2619),
    [anon_sym_codeunit] = ACTIONS(2619),
    [anon_sym_CODEUNIT] = ACTIONS(2619),
    [anon_sym_Codeunit] = ACTIONS(2619),
    [anon_sym_CodeUnit] = ACTIONS(2619),
    [anon_sym_COdeunit] = ACTIONS(2619),
    [anon_sym_codeUnit] = ACTIONS(2619),
    [sym_report_keyword] = ACTIONS(2619),
    [sym_query_keyword] = ACTIONS(2619),
    [anon_sym_xmlport] = ACTIONS(2619),
    [anon_sym_XMLPORT] = ACTIONS(2619),
    [anon_sym_Xmlport] = ACTIONS(2619),
    [anon_sym_XMLport] = ACTIONS(2619),
    [anon_sym_XMLPort] = ACTIONS(2619),
    [anon_sym_XmlPort] = ACTIONS(2619),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_ENUM] = ACTIONS(2619),
    [anon_sym_Enum] = ACTIONS(2619),
    [anon_sym_eNUM] = ACTIONS(2619),
    [anon_sym_eNum] = ACTIONS(2619),
    [anon_sym_ENum] = ACTIONS(2619),
    [sym_quoted_identifier] = ACTIONS(2621),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2621),
    [sym_integer] = ACTIONS(2619),
    [sym_continue_as_identifier] = ACTIONS(2621),
    [sym_preproc_open] = ACTIONS(2621),
  },
  [STATE(2197)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_SEMI] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_COMMA] = ACTIONS(2595),
    [anon_sym_COLON] = ACTIONS(2593),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2593),
    [anon_sym_POUNDif] = ACTIONS(2595),
    [anon_sym_POUNDIF] = ACTIONS(2595),
    [anon_sym_POUNDIf] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2595),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_else] = ACTIONS(2593),
    [anon_sym_ELSE] = ACTIONS(2593),
    [anon_sym_Else] = ACTIONS(2593),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_open] = ACTIONS(2595),
  },
  [STATE(2198)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_SEMI] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_COMMA] = ACTIONS(2595),
    [anon_sym_COLON] = ACTIONS(2593),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2593),
    [anon_sym_POUNDif] = ACTIONS(2595),
    [anon_sym_POUNDIF] = ACTIONS(2595),
    [anon_sym_POUNDIf] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2595),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_else] = ACTIONS(2593),
    [anon_sym_ELSE] = ACTIONS(2593),
    [anon_sym_Else] = ACTIONS(2593),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_open] = ACTIONS(2595),
  },
  [STATE(2199)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_COMMA] = ACTIONS(2587),
    [anon_sym_COLON] = ACTIONS(2585),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2585),
    [anon_sym_POUNDif] = ACTIONS(2587),
    [anon_sym_POUNDIF] = ACTIONS(2587),
    [anon_sym_POUNDIf] = ACTIONS(2587),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2587),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_else] = ACTIONS(2585),
    [anon_sym_ELSE] = ACTIONS(2585),
    [anon_sym_Else] = ACTIONS(2585),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_open] = ACTIONS(2587),
  },
  [STATE(2200)] = {
    [sym_identifier] = ACTIONS(2551),
    [anon_sym_DOT] = ACTIONS(2551),
    [anon_sym_EQ] = ACTIONS(2553),
    [anon_sym_COMMA] = ACTIONS(2553),
    [anon_sym_DASH] = ACTIONS(2551),
    [aux_sym_boolean_token1] = ACTIONS(2551),
    [aux_sym_boolean_token2] = ACTIONS(2551),
    [sym_decimal] = ACTIONS(2551),
    [anon_sym_LPAREN] = ACTIONS(2553),
    [anon_sym_DOT_DOT] = ACTIONS(2553),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2551),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_LBRACK] = ACTIONS(2553),
    [aux_sym_record_type_token1] = ACTIONS(2551),
    [aux_sym_basic_type_token21] = ACTIONS(2551),
    [aux_sym_basic_type_token22] = ACTIONS(2551),
    [aux_sym_basic_type_token48] = ACTIONS(2551),
    [anon_sym_not] = ACTIONS(2551),
    [anon_sym_NOT] = ACTIONS(2551),
    [anon_sym_Not] = ACTIONS(2551),
    [anon_sym_POUNDelif] = ACTIONS(2553),
    [anon_sym_POUNDELIF] = ACTIONS(2553),
    [anon_sym_POUNDElif] = ACTIONS(2553),
    [anon_sym_POUNDelse] = ACTIONS(2553),
    [anon_sym_POUNDELSE] = ACTIONS(2553),
    [anon_sym_POUNDElse] = ACTIONS(2553),
    [anon_sym_POUNDendif] = ACTIONS(2553),
    [anon_sym_POUNDENDIF] = ACTIONS(2553),
    [anon_sym_POUNDEndif] = ACTIONS(2553),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2553),
    [aux_sym__expression_token1] = ACTIONS(2553),
    [aux_sym__expression_token2] = ACTIONS(2553),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2551),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2551),
    [anon_sym_SLASH] = ACTIONS(2551),
    [anon_sym_div] = ACTIONS(2551),
    [anon_sym_DIV] = ACTIONS(2551),
    [anon_sym_Div] = ACTIONS(2551),
    [anon_sym_mod] = ACTIONS(2551),
    [anon_sym_MOD] = ACTIONS(2551),
    [anon_sym_Mod] = ACTIONS(2551),
    [anon_sym_PLUS] = ACTIONS(2551),
    [anon_sym_GT_EQ] = ACTIONS(2553),
    [anon_sym_LT_EQ] = ACTIONS(2553),
    [anon_sym_GT] = ACTIONS(2551),
    [anon_sym_LT] = ACTIONS(2551),
    [anon_sym_LT_GT] = ACTIONS(2553),
    [anon_sym_and] = ACTIONS(2551),
    [anon_sym_AND] = ACTIONS(2551),
    [anon_sym_And] = ACTIONS(2551),
    [anon_sym_or] = ACTIONS(2551),
    [anon_sym_OR] = ACTIONS(2551),
    [anon_sym_Or] = ACTIONS(2551),
    [anon_sym_xor] = ACTIONS(2551),
    [anon_sym_XOR] = ACTIONS(2551),
    [anon_sym_Xor] = ACTIONS(2551),
    [anon_sym_QMARK] = ACTIONS(2553),
    [sym_datetime_literal] = ACTIONS(2553),
    [sym_date_literal] = ACTIONS(2551),
    [sym_time_literal] = ACTIONS(2551),
    [sym_biginteger_literal] = ACTIONS(2553),
    [anon_sym_in] = ACTIONS(2551),
    [anon_sym_IN] = ACTIONS(2551),
    [anon_sym_In] = ACTIONS(2551),
    [sym_page_keyword] = ACTIONS(2551),
    [anon_sym_codeunit] = ACTIONS(2551),
    [anon_sym_CODEUNIT] = ACTIONS(2551),
    [anon_sym_Codeunit] = ACTIONS(2551),
    [anon_sym_CodeUnit] = ACTIONS(2551),
    [anon_sym_COdeunit] = ACTIONS(2551),
    [anon_sym_codeUnit] = ACTIONS(2551),
    [sym_report_keyword] = ACTIONS(2551),
    [sym_query_keyword] = ACTIONS(2551),
    [anon_sym_xmlport] = ACTIONS(2551),
    [anon_sym_XMLPORT] = ACTIONS(2551),
    [anon_sym_Xmlport] = ACTIONS(2551),
    [anon_sym_XMLport] = ACTIONS(2551),
    [anon_sym_XMLPort] = ACTIONS(2551),
    [anon_sym_XmlPort] = ACTIONS(2551),
    [anon_sym_enum] = ACTIONS(2551),
    [anon_sym_ENUM] = ACTIONS(2551),
    [anon_sym_Enum] = ACTIONS(2551),
    [anon_sym_eNUM] = ACTIONS(2551),
    [anon_sym_eNum] = ACTIONS(2551),
    [anon_sym_ENum] = ACTIONS(2551),
    [sym_quoted_identifier] = ACTIONS(2553),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2553),
    [sym_integer] = ACTIONS(2551),
    [sym_continue_as_identifier] = ACTIONS(2553),
    [sym_preproc_close] = ACTIONS(2553),
  },
  [STATE(2201)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_COMMA] = ACTIONS(2587),
    [anon_sym_COLON] = ACTIONS(2585),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2585),
    [anon_sym_POUNDif] = ACTIONS(2587),
    [anon_sym_POUNDIF] = ACTIONS(2587),
    [anon_sym_POUNDIf] = ACTIONS(2587),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2587),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_else] = ACTIONS(2585),
    [anon_sym_ELSE] = ACTIONS(2585),
    [anon_sym_Else] = ACTIONS(2585),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_open] = ACTIONS(2587),
  },
  [STATE(2202)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_SEMI] = ACTIONS(2428),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_COMMA] = ACTIONS(2428),
    [anon_sym_COLON] = ACTIONS(2426),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2426),
    [anon_sym_POUNDif] = ACTIONS(2428),
    [anon_sym_POUNDIF] = ACTIONS(2428),
    [anon_sym_POUNDIf] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2428),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_else] = ACTIONS(2426),
    [anon_sym_ELSE] = ACTIONS(2426),
    [anon_sym_Else] = ACTIONS(2426),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
    [sym_preproc_open] = ACTIONS(2428),
  },
  [STATE(2203)] = {
    [sym_identifier] = ACTIONS(2605),
    [anon_sym_DOT] = ACTIONS(2605),
    [anon_sym_EQ] = ACTIONS(2607),
    [anon_sym_COMMA] = ACTIONS(2607),
    [anon_sym_DASH] = ACTIONS(2605),
    [aux_sym_boolean_token1] = ACTIONS(2605),
    [aux_sym_boolean_token2] = ACTIONS(2605),
    [sym_decimal] = ACTIONS(2605),
    [anon_sym_LPAREN] = ACTIONS(2607),
    [anon_sym_DOT_DOT] = ACTIONS(2607),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2605),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_LBRACK] = ACTIONS(2607),
    [aux_sym_record_type_token1] = ACTIONS(2605),
    [aux_sym_basic_type_token21] = ACTIONS(2605),
    [aux_sym_basic_type_token22] = ACTIONS(2605),
    [aux_sym_basic_type_token48] = ACTIONS(2605),
    [anon_sym_not] = ACTIONS(2605),
    [anon_sym_NOT] = ACTIONS(2605),
    [anon_sym_Not] = ACTIONS(2605),
    [anon_sym_POUNDelif] = ACTIONS(2607),
    [anon_sym_POUNDELIF] = ACTIONS(2607),
    [anon_sym_POUNDElif] = ACTIONS(2607),
    [anon_sym_POUNDelse] = ACTIONS(2607),
    [anon_sym_POUNDELSE] = ACTIONS(2607),
    [anon_sym_POUNDElse] = ACTIONS(2607),
    [anon_sym_POUNDendif] = ACTIONS(2607),
    [anon_sym_POUNDENDIF] = ACTIONS(2607),
    [anon_sym_POUNDEndif] = ACTIONS(2607),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2607),
    [aux_sym__expression_token1] = ACTIONS(2607),
    [aux_sym__expression_token2] = ACTIONS(2607),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2605),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2605),
    [anon_sym_SLASH] = ACTIONS(2605),
    [anon_sym_div] = ACTIONS(2605),
    [anon_sym_DIV] = ACTIONS(2605),
    [anon_sym_Div] = ACTIONS(2605),
    [anon_sym_mod] = ACTIONS(2605),
    [anon_sym_MOD] = ACTIONS(2605),
    [anon_sym_Mod] = ACTIONS(2605),
    [anon_sym_PLUS] = ACTIONS(2605),
    [anon_sym_GT_EQ] = ACTIONS(2607),
    [anon_sym_LT_EQ] = ACTIONS(2607),
    [anon_sym_GT] = ACTIONS(2605),
    [anon_sym_LT] = ACTIONS(2605),
    [anon_sym_LT_GT] = ACTIONS(2607),
    [anon_sym_and] = ACTIONS(2605),
    [anon_sym_AND] = ACTIONS(2605),
    [anon_sym_And] = ACTIONS(2605),
    [anon_sym_or] = ACTIONS(2605),
    [anon_sym_OR] = ACTIONS(2605),
    [anon_sym_Or] = ACTIONS(2605),
    [anon_sym_xor] = ACTIONS(2605),
    [anon_sym_XOR] = ACTIONS(2605),
    [anon_sym_Xor] = ACTIONS(2605),
    [anon_sym_QMARK] = ACTIONS(2607),
    [sym_datetime_literal] = ACTIONS(2607),
    [sym_date_literal] = ACTIONS(2605),
    [sym_time_literal] = ACTIONS(2605),
    [sym_biginteger_literal] = ACTIONS(2607),
    [anon_sym_in] = ACTIONS(2605),
    [anon_sym_IN] = ACTIONS(2605),
    [anon_sym_In] = ACTIONS(2605),
    [sym_page_keyword] = ACTIONS(2605),
    [anon_sym_codeunit] = ACTIONS(2605),
    [anon_sym_CODEUNIT] = ACTIONS(2605),
    [anon_sym_Codeunit] = ACTIONS(2605),
    [anon_sym_CodeUnit] = ACTIONS(2605),
    [anon_sym_COdeunit] = ACTIONS(2605),
    [anon_sym_codeUnit] = ACTIONS(2605),
    [sym_report_keyword] = ACTIONS(2605),
    [sym_query_keyword] = ACTIONS(2605),
    [anon_sym_xmlport] = ACTIONS(2605),
    [anon_sym_XMLPORT] = ACTIONS(2605),
    [anon_sym_Xmlport] = ACTIONS(2605),
    [anon_sym_XMLport] = ACTIONS(2605),
    [anon_sym_XMLPort] = ACTIONS(2605),
    [anon_sym_XmlPort] = ACTIONS(2605),
    [anon_sym_enum] = ACTIONS(2605),
    [anon_sym_ENUM] = ACTIONS(2605),
    [anon_sym_Enum] = ACTIONS(2605),
    [anon_sym_eNUM] = ACTIONS(2605),
    [anon_sym_eNum] = ACTIONS(2605),
    [anon_sym_ENum] = ACTIONS(2605),
    [sym_quoted_identifier] = ACTIONS(2607),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2607),
    [sym_integer] = ACTIONS(2605),
    [sym_continue_as_identifier] = ACTIONS(2607),
    [sym_preproc_close] = ACTIONS(2607),
  },
  [STATE(2204)] = {
    [sym__body_element] = STATE(3490),
    [sym_empty_statement] = STATE(3490),
    [sym_property] = STATE(4854),
    [sym_fields_section] = STATE(3490),
    [sym_keys_section] = STATE(3490),
    [sym_fieldgroups_section] = STATE(3490),
    [sym_enum_value_declaration] = STATE(3490),
    [sym_labels_section] = STATE(3490),
    [sym_layout_section] = STATE(3490),
    [sym_modify_modification] = STATE(3490),
    [sym_actions_section] = STATE(3490),
    [sym__action_element] = STATE(5425),
    [sym_action_area_section] = STATE(5425),
    [sym_action_group_section] = STATE(5425),
    [sym_action_declaration] = STATE(5425),
    [sym_separator_action] = STATE(5425),
    [sym_actionref_declaration] = STATE(5425),
    [sym_systemaction_declaration] = STATE(5425),
    [sym_fileuploadaction_declaration] = STATE(5425),
    [sym_customaction_declaration] = STATE(5425),
    [sym_addfirst_action_modification] = STATE(5425),
    [sym_addlast_action_modification] = STATE(5425),
    [sym_addafter_action_modification] = STATE(5425),
    [sym_addbefore_action_modification] = STATE(5425),
    [sym_modify_action_modification] = STATE(5425),
    [sym_views_section] = STATE(3490),
    [sym_dataset_section] = STATE(3490),
    [sym_requestpage_section] = STATE(3490),
    [sym_rendering_section] = STATE(3490),
    [sym_elements_section] = STATE(3490),
    [sym_schema_section] = STATE(3490),
    [sym_assembly_declaration] = STATE(3490),
    [sym_event_declaration] = STATE(3490),
    [sym_procedure] = STATE(3490),
    [sym_preproc_split_procedure] = STATE(3490),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(4854),
    [sym_var_section] = STATE(3490),
    [sym_attribute_item] = STATE(4854),
    [sym_preproc_conditional] = STATE(3490),
    [sym_preproc_if] = STATE(1393),
    [sym_preproc_endif] = STATE(5985),
    [sym_preproc_conditional_actions] = STATE(5425),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3490),
    [aux_sym_actions_section_repeat1] = STATE(5425),
    [anon_sym_SEMI] = ACTIONS(2845),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3676),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3678),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_basic_type_token22] = ACTIONS(3680),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_addafter_modification_token1] = ACTIONS(3682),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3684),
    [aux_sym_modify_modification_token1] = ACTIONS(3686),
    [aux_sym_separator_action_token1] = ACTIONS(3688),
    [aux_sym_actionref_declaration_token1] = ACTIONS(3690),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(3692),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(3694),
    [aux_sym_customaction_declaration_token1] = ACTIONS(3696),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_area_keyword] = ACTIONS(3698),
    [sym_group_keyword] = ACTIONS(3700),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(2205)] = {
    [sym_identifier] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym_DOT] = ACTIONS(2585),
    [anon_sym_EQ] = ACTIONS(2587),
    [anon_sym_COMMA] = ACTIONS(2587),
    [anon_sym_COLON] = ACTIONS(2585),
    [anon_sym_DASH] = ACTIONS(2585),
    [aux_sym_boolean_token1] = ACTIONS(2585),
    [aux_sym_boolean_token2] = ACTIONS(2585),
    [sym_decimal] = ACTIONS(2585),
    [anon_sym_LPAREN] = ACTIONS(2587),
    [anon_sym_DOT_DOT] = ACTIONS(2587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2587),
    [aux_sym_record_type_token1] = ACTIONS(2585),
    [aux_sym_basic_type_token21] = ACTIONS(2585),
    [aux_sym_basic_type_token22] = ACTIONS(2585),
    [aux_sym_basic_type_token48] = ACTIONS(2585),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2585),
    [anon_sym_POUNDif] = ACTIONS(2587),
    [anon_sym_POUNDIF] = ACTIONS(2587),
    [anon_sym_POUNDIf] = ACTIONS(2587),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_NOT] = ACTIONS(2585),
    [anon_sym_Not] = ACTIONS(2585),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2587),
    [aux_sym__expression_token1] = ACTIONS(2587),
    [aux_sym__expression_token2] = ACTIONS(2587),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2585),
    [anon_sym_SLASH] = ACTIONS(2585),
    [anon_sym_div] = ACTIONS(2585),
    [anon_sym_DIV] = ACTIONS(2585),
    [anon_sym_Div] = ACTIONS(2585),
    [anon_sym_mod] = ACTIONS(2585),
    [anon_sym_MOD] = ACTIONS(2585),
    [anon_sym_Mod] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_GT_EQ] = ACTIONS(2587),
    [anon_sym_LT_EQ] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2585),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_LT_GT] = ACTIONS(2587),
    [anon_sym_and] = ACTIONS(2585),
    [anon_sym_AND] = ACTIONS(2585),
    [anon_sym_And] = ACTIONS(2585),
    [anon_sym_or] = ACTIONS(2585),
    [anon_sym_OR] = ACTIONS(2585),
    [anon_sym_Or] = ACTIONS(2585),
    [anon_sym_xor] = ACTIONS(2585),
    [anon_sym_XOR] = ACTIONS(2585),
    [anon_sym_Xor] = ACTIONS(2585),
    [anon_sym_QMARK] = ACTIONS(2587),
    [sym_datetime_literal] = ACTIONS(2587),
    [sym_date_literal] = ACTIONS(2585),
    [sym_time_literal] = ACTIONS(2585),
    [sym_biginteger_literal] = ACTIONS(2587),
    [anon_sym_else] = ACTIONS(2585),
    [anon_sym_ELSE] = ACTIONS(2585),
    [anon_sym_Else] = ACTIONS(2585),
    [anon_sym_in] = ACTIONS(2585),
    [anon_sym_IN] = ACTIONS(2585),
    [anon_sym_In] = ACTIONS(2585),
    [sym_page_keyword] = ACTIONS(2585),
    [anon_sym_codeunit] = ACTIONS(2585),
    [anon_sym_CODEUNIT] = ACTIONS(2585),
    [anon_sym_Codeunit] = ACTIONS(2585),
    [anon_sym_CodeUnit] = ACTIONS(2585),
    [anon_sym_COdeunit] = ACTIONS(2585),
    [anon_sym_codeUnit] = ACTIONS(2585),
    [sym_report_keyword] = ACTIONS(2585),
    [sym_query_keyword] = ACTIONS(2585),
    [anon_sym_xmlport] = ACTIONS(2585),
    [anon_sym_XMLPORT] = ACTIONS(2585),
    [anon_sym_Xmlport] = ACTIONS(2585),
    [anon_sym_XMLport] = ACTIONS(2585),
    [anon_sym_XMLPort] = ACTIONS(2585),
    [anon_sym_XmlPort] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_ENUM] = ACTIONS(2585),
    [anon_sym_Enum] = ACTIONS(2585),
    [anon_sym_eNUM] = ACTIONS(2585),
    [anon_sym_eNum] = ACTIONS(2585),
    [anon_sym_ENum] = ACTIONS(2585),
    [sym_quoted_identifier] = ACTIONS(2587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2587),
    [sym_integer] = ACTIONS(2585),
    [sym_continue_as_identifier] = ACTIONS(2587),
    [sym_preproc_open] = ACTIONS(2587),
  },
  [STATE(2206)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_SEMI] = ACTIONS(2591),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_COMMA] = ACTIONS(2591),
    [anon_sym_COLON] = ACTIONS(2589),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2589),
    [anon_sym_POUNDif] = ACTIONS(2591),
    [anon_sym_POUNDIF] = ACTIONS(2591),
    [anon_sym_POUNDIf] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2591),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_else] = ACTIONS(2589),
    [anon_sym_ELSE] = ACTIONS(2589),
    [anon_sym_Else] = ACTIONS(2589),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_open] = ACTIONS(2591),
  },
  [STATE(2207)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_SEMI] = ACTIONS(2591),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_COMMA] = ACTIONS(2591),
    [anon_sym_COLON] = ACTIONS(2589),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2589),
    [anon_sym_POUNDif] = ACTIONS(2591),
    [anon_sym_POUNDIF] = ACTIONS(2591),
    [anon_sym_POUNDIf] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2591),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_else] = ACTIONS(2589),
    [anon_sym_ELSE] = ACTIONS(2589),
    [anon_sym_Else] = ACTIONS(2589),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_open] = ACTIONS(2591),
  },
  [STATE(2208)] = {
    [sym_identifier] = ACTIONS(2593),
    [anon_sym_SEMI] = ACTIONS(2595),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_COMMA] = ACTIONS(2595),
    [anon_sym_COLON] = ACTIONS(2593),
    [anon_sym_DASH] = ACTIONS(2593),
    [aux_sym_boolean_token1] = ACTIONS(2593),
    [aux_sym_boolean_token2] = ACTIONS(2593),
    [sym_decimal] = ACTIONS(2593),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2593),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [aux_sym_record_type_token1] = ACTIONS(2593),
    [aux_sym_basic_type_token21] = ACTIONS(2593),
    [aux_sym_basic_type_token22] = ACTIONS(2593),
    [aux_sym_basic_type_token48] = ACTIONS(2593),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2593),
    [anon_sym_POUNDif] = ACTIONS(2595),
    [anon_sym_POUNDIF] = ACTIONS(2595),
    [anon_sym_POUNDIf] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2593),
    [anon_sym_NOT] = ACTIONS(2593),
    [anon_sym_Not] = ACTIONS(2593),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2595),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2593),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(2593),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(2595),
    [sym_date_literal] = ACTIONS(2593),
    [sym_time_literal] = ACTIONS(2593),
    [sym_biginteger_literal] = ACTIONS(2595),
    [anon_sym_else] = ACTIONS(2593),
    [anon_sym_ELSE] = ACTIONS(2593),
    [anon_sym_Else] = ACTIONS(2593),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(2593),
    [anon_sym_codeunit] = ACTIONS(2593),
    [anon_sym_CODEUNIT] = ACTIONS(2593),
    [anon_sym_Codeunit] = ACTIONS(2593),
    [anon_sym_CodeUnit] = ACTIONS(2593),
    [anon_sym_COdeunit] = ACTIONS(2593),
    [anon_sym_codeUnit] = ACTIONS(2593),
    [sym_report_keyword] = ACTIONS(2593),
    [sym_query_keyword] = ACTIONS(2593),
    [anon_sym_xmlport] = ACTIONS(2593),
    [anon_sym_XMLPORT] = ACTIONS(2593),
    [anon_sym_Xmlport] = ACTIONS(2593),
    [anon_sym_XMLport] = ACTIONS(2593),
    [anon_sym_XMLPort] = ACTIONS(2593),
    [anon_sym_XmlPort] = ACTIONS(2593),
    [anon_sym_enum] = ACTIONS(2593),
    [anon_sym_ENUM] = ACTIONS(2593),
    [anon_sym_Enum] = ACTIONS(2593),
    [anon_sym_eNUM] = ACTIONS(2593),
    [anon_sym_eNum] = ACTIONS(2593),
    [anon_sym_ENum] = ACTIONS(2593),
    [sym_quoted_identifier] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2595),
    [sym_integer] = ACTIONS(2593),
    [sym_continue_as_identifier] = ACTIONS(2595),
    [sym_preproc_open] = ACTIONS(2595),
  },
  [STATE(2209)] = {
    [sym_identifier] = ACTIONS(2589),
    [anon_sym_SEMI] = ACTIONS(2591),
    [anon_sym_DOT] = ACTIONS(2589),
    [anon_sym_EQ] = ACTIONS(2591),
    [anon_sym_COMMA] = ACTIONS(2591),
    [anon_sym_COLON] = ACTIONS(2589),
    [anon_sym_DASH] = ACTIONS(2589),
    [aux_sym_boolean_token1] = ACTIONS(2589),
    [aux_sym_boolean_token2] = ACTIONS(2589),
    [sym_decimal] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2591),
    [anon_sym_DOT_DOT] = ACTIONS(2591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2589),
    [anon_sym_STAR] = ACTIONS(2589),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [aux_sym_record_type_token1] = ACTIONS(2589),
    [aux_sym_basic_type_token21] = ACTIONS(2589),
    [aux_sym_basic_type_token22] = ACTIONS(2589),
    [aux_sym_basic_type_token48] = ACTIONS(2589),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2589),
    [anon_sym_POUNDif] = ACTIONS(2591),
    [anon_sym_POUNDIF] = ACTIONS(2591),
    [anon_sym_POUNDIf] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2589),
    [anon_sym_NOT] = ACTIONS(2589),
    [anon_sym_Not] = ACTIONS(2589),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2591),
    [aux_sym__expression_token1] = ACTIONS(2591),
    [aux_sym__expression_token2] = ACTIONS(2591),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2589),
    [anon_sym_SLASH] = ACTIONS(2589),
    [anon_sym_div] = ACTIONS(2589),
    [anon_sym_DIV] = ACTIONS(2589),
    [anon_sym_Div] = ACTIONS(2589),
    [anon_sym_mod] = ACTIONS(2589),
    [anon_sym_MOD] = ACTIONS(2589),
    [anon_sym_Mod] = ACTIONS(2589),
    [anon_sym_PLUS] = ACTIONS(2589),
    [anon_sym_GT_EQ] = ACTIONS(2591),
    [anon_sym_LT_EQ] = ACTIONS(2591),
    [anon_sym_GT] = ACTIONS(2589),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_LT_GT] = ACTIONS(2591),
    [anon_sym_and] = ACTIONS(2589),
    [anon_sym_AND] = ACTIONS(2589),
    [anon_sym_And] = ACTIONS(2589),
    [anon_sym_or] = ACTIONS(2589),
    [anon_sym_OR] = ACTIONS(2589),
    [anon_sym_Or] = ACTIONS(2589),
    [anon_sym_xor] = ACTIONS(2589),
    [anon_sym_XOR] = ACTIONS(2589),
    [anon_sym_Xor] = ACTIONS(2589),
    [anon_sym_QMARK] = ACTIONS(2591),
    [sym_datetime_literal] = ACTIONS(2591),
    [sym_date_literal] = ACTIONS(2589),
    [sym_time_literal] = ACTIONS(2589),
    [sym_biginteger_literal] = ACTIONS(2591),
    [anon_sym_else] = ACTIONS(2589),
    [anon_sym_ELSE] = ACTIONS(2589),
    [anon_sym_Else] = ACTIONS(2589),
    [anon_sym_in] = ACTIONS(2589),
    [anon_sym_IN] = ACTIONS(2589),
    [anon_sym_In] = ACTIONS(2589),
    [sym_page_keyword] = ACTIONS(2589),
    [anon_sym_codeunit] = ACTIONS(2589),
    [anon_sym_CODEUNIT] = ACTIONS(2589),
    [anon_sym_Codeunit] = ACTIONS(2589),
    [anon_sym_CodeUnit] = ACTIONS(2589),
    [anon_sym_COdeunit] = ACTIONS(2589),
    [anon_sym_codeUnit] = ACTIONS(2589),
    [sym_report_keyword] = ACTIONS(2589),
    [sym_query_keyword] = ACTIONS(2589),
    [anon_sym_xmlport] = ACTIONS(2589),
    [anon_sym_XMLPORT] = ACTIONS(2589),
    [anon_sym_Xmlport] = ACTIONS(2589),
    [anon_sym_XMLport] = ACTIONS(2589),
    [anon_sym_XMLPort] = ACTIONS(2589),
    [anon_sym_XmlPort] = ACTIONS(2589),
    [anon_sym_enum] = ACTIONS(2589),
    [anon_sym_ENUM] = ACTIONS(2589),
    [anon_sym_Enum] = ACTIONS(2589),
    [anon_sym_eNUM] = ACTIONS(2589),
    [anon_sym_eNum] = ACTIONS(2589),
    [anon_sym_ENum] = ACTIONS(2589),
    [sym_quoted_identifier] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2591),
    [sym_integer] = ACTIONS(2589),
    [sym_continue_as_identifier] = ACTIONS(2591),
    [sym_preproc_open] = ACTIONS(2591),
  },
  [STATE(2210)] = {
    [sym_identifier] = ACTIONS(2403),
    [anon_sym_SEMI] = ACTIONS(2405),
    [anon_sym_DOT] = ACTIONS(2403),
    [anon_sym_EQ] = ACTIONS(2405),
    [anon_sym_COMMA] = ACTIONS(2405),
    [anon_sym_COLON] = ACTIONS(2403),
    [anon_sym_DASH] = ACTIONS(2403),
    [aux_sym_boolean_token1] = ACTIONS(2403),
    [aux_sym_boolean_token2] = ACTIONS(2403),
    [sym_decimal] = ACTIONS(2403),
    [anon_sym_LPAREN] = ACTIONS(2405),
    [anon_sym_DOT_DOT] = ACTIONS(2405),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2403),
    [anon_sym_STAR] = ACTIONS(2403),
    [anon_sym_LBRACK] = ACTIONS(2405),
    [aux_sym_record_type_token1] = ACTIONS(2403),
    [aux_sym_basic_type_token21] = ACTIONS(2403),
    [aux_sym_basic_type_token22] = ACTIONS(2403),
    [aux_sym_basic_type_token48] = ACTIONS(2403),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2403),
    [anon_sym_POUNDif] = ACTIONS(2405),
    [anon_sym_POUNDIF] = ACTIONS(2405),
    [anon_sym_POUNDIf] = ACTIONS(2405),
    [anon_sym_not] = ACTIONS(2403),
    [anon_sym_NOT] = ACTIONS(2403),
    [anon_sym_Not] = ACTIONS(2403),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2405),
    [aux_sym__expression_token1] = ACTIONS(2405),
    [aux_sym__expression_token2] = ACTIONS(2405),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2403),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2403),
    [anon_sym_SLASH] = ACTIONS(2403),
    [anon_sym_div] = ACTIONS(2403),
    [anon_sym_DIV] = ACTIONS(2403),
    [anon_sym_Div] = ACTIONS(2403),
    [anon_sym_mod] = ACTIONS(2403),
    [anon_sym_MOD] = ACTIONS(2403),
    [anon_sym_Mod] = ACTIONS(2403),
    [anon_sym_PLUS] = ACTIONS(2403),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_LT_GT] = ACTIONS(2405),
    [anon_sym_and] = ACTIONS(2403),
    [anon_sym_AND] = ACTIONS(2403),
    [anon_sym_And] = ACTIONS(2403),
    [anon_sym_or] = ACTIONS(2403),
    [anon_sym_OR] = ACTIONS(2403),
    [anon_sym_Or] = ACTIONS(2403),
    [anon_sym_xor] = ACTIONS(2403),
    [anon_sym_XOR] = ACTIONS(2403),
    [anon_sym_Xor] = ACTIONS(2403),
    [anon_sym_QMARK] = ACTIONS(2405),
    [sym_datetime_literal] = ACTIONS(2405),
    [sym_date_literal] = ACTIONS(2403),
    [sym_time_literal] = ACTIONS(2403),
    [sym_biginteger_literal] = ACTIONS(2405),
    [anon_sym_else] = ACTIONS(2403),
    [anon_sym_ELSE] = ACTIONS(2403),
    [anon_sym_Else] = ACTIONS(2403),
    [anon_sym_in] = ACTIONS(2403),
    [anon_sym_IN] = ACTIONS(2403),
    [anon_sym_In] = ACTIONS(2403),
    [sym_page_keyword] = ACTIONS(2403),
    [anon_sym_codeunit] = ACTIONS(2403),
    [anon_sym_CODEUNIT] = ACTIONS(2403),
    [anon_sym_Codeunit] = ACTIONS(2403),
    [anon_sym_CodeUnit] = ACTIONS(2403),
    [anon_sym_COdeunit] = ACTIONS(2403),
    [anon_sym_codeUnit] = ACTIONS(2403),
    [sym_report_keyword] = ACTIONS(2403),
    [sym_query_keyword] = ACTIONS(2403),
    [anon_sym_xmlport] = ACTIONS(2403),
    [anon_sym_XMLPORT] = ACTIONS(2403),
    [anon_sym_Xmlport] = ACTIONS(2403),
    [anon_sym_XMLport] = ACTIONS(2403),
    [anon_sym_XMLPort] = ACTIONS(2403),
    [anon_sym_XmlPort] = ACTIONS(2403),
    [anon_sym_enum] = ACTIONS(2403),
    [anon_sym_ENUM] = ACTIONS(2403),
    [anon_sym_Enum] = ACTIONS(2403),
    [anon_sym_eNUM] = ACTIONS(2403),
    [anon_sym_eNum] = ACTIONS(2403),
    [anon_sym_ENum] = ACTIONS(2403),
    [sym_quoted_identifier] = ACTIONS(2405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2405),
    [sym_integer] = ACTIONS(2403),
    [sym_continue_as_identifier] = ACTIONS(2405),
    [sym_preproc_open] = ACTIONS(2405),
  },
  [STATE(2211)] = {
    [sym_identifier] = ACTIONS(2605),
    [anon_sym_SEMI] = ACTIONS(2607),
    [anon_sym_DOT] = ACTIONS(2605),
    [anon_sym_EQ] = ACTIONS(2607),
    [anon_sym_COMMA] = ACTIONS(2607),
    [anon_sym_COLON] = ACTIONS(2605),
    [anon_sym_DASH] = ACTIONS(2605),
    [aux_sym_boolean_token1] = ACTIONS(2605),
    [aux_sym_boolean_token2] = ACTIONS(2605),
    [sym_decimal] = ACTIONS(2605),
    [anon_sym_LPAREN] = ACTIONS(2607),
    [anon_sym_DOT_DOT] = ACTIONS(2607),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2605),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_LBRACK] = ACTIONS(2607),
    [aux_sym_record_type_token1] = ACTIONS(2605),
    [aux_sym_basic_type_token21] = ACTIONS(2605),
    [aux_sym_basic_type_token22] = ACTIONS(2605),
    [aux_sym_basic_type_token48] = ACTIONS(2605),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2605),
    [anon_sym_POUNDif] = ACTIONS(2607),
    [anon_sym_POUNDIF] = ACTIONS(2607),
    [anon_sym_POUNDIf] = ACTIONS(2607),
    [anon_sym_not] = ACTIONS(2605),
    [anon_sym_NOT] = ACTIONS(2605),
    [anon_sym_Not] = ACTIONS(2605),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2607),
    [aux_sym__expression_token1] = ACTIONS(2607),
    [aux_sym__expression_token2] = ACTIONS(2607),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2605),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2605),
    [anon_sym_SLASH] = ACTIONS(2605),
    [anon_sym_div] = ACTIONS(2605),
    [anon_sym_DIV] = ACTIONS(2605),
    [anon_sym_Div] = ACTIONS(2605),
    [anon_sym_mod] = ACTIONS(2605),
    [anon_sym_MOD] = ACTIONS(2605),
    [anon_sym_Mod] = ACTIONS(2605),
    [anon_sym_PLUS] = ACTIONS(2605),
    [anon_sym_GT_EQ] = ACTIONS(2607),
    [anon_sym_LT_EQ] = ACTIONS(2607),
    [anon_sym_GT] = ACTIONS(2605),
    [anon_sym_LT] = ACTIONS(2605),
    [anon_sym_LT_GT] = ACTIONS(2607),
    [anon_sym_and] = ACTIONS(2605),
    [anon_sym_AND] = ACTIONS(2605),
    [anon_sym_And] = ACTIONS(2605),
    [anon_sym_or] = ACTIONS(2605),
    [anon_sym_OR] = ACTIONS(2605),
    [anon_sym_Or] = ACTIONS(2605),
    [anon_sym_xor] = ACTIONS(2605),
    [anon_sym_XOR] = ACTIONS(2605),
    [anon_sym_Xor] = ACTIONS(2605),
    [anon_sym_QMARK] = ACTIONS(2607),
    [sym_datetime_literal] = ACTIONS(2607),
    [sym_date_literal] = ACTIONS(2605),
    [sym_time_literal] = ACTIONS(2605),
    [sym_biginteger_literal] = ACTIONS(2607),
    [anon_sym_else] = ACTIONS(2605),
    [anon_sym_ELSE] = ACTIONS(2605),
    [anon_sym_Else] = ACTIONS(2605),
    [anon_sym_in] = ACTIONS(2605),
    [anon_sym_IN] = ACTIONS(2605),
    [anon_sym_In] = ACTIONS(2605),
    [sym_page_keyword] = ACTIONS(2605),
    [anon_sym_codeunit] = ACTIONS(2605),
    [anon_sym_CODEUNIT] = ACTIONS(2605),
    [anon_sym_Codeunit] = ACTIONS(2605),
    [anon_sym_CodeUnit] = ACTIONS(2605),
    [anon_sym_COdeunit] = ACTIONS(2605),
    [anon_sym_codeUnit] = ACTIONS(2605),
    [sym_report_keyword] = ACTIONS(2605),
    [sym_query_keyword] = ACTIONS(2605),
    [anon_sym_xmlport] = ACTIONS(2605),
    [anon_sym_XMLPORT] = ACTIONS(2605),
    [anon_sym_Xmlport] = ACTIONS(2605),
    [anon_sym_XMLport] = ACTIONS(2605),
    [anon_sym_XMLPort] = ACTIONS(2605),
    [anon_sym_XmlPort] = ACTIONS(2605),
    [anon_sym_enum] = ACTIONS(2605),
    [anon_sym_ENUM] = ACTIONS(2605),
    [anon_sym_Enum] = ACTIONS(2605),
    [anon_sym_eNUM] = ACTIONS(2605),
    [anon_sym_eNum] = ACTIONS(2605),
    [anon_sym_ENum] = ACTIONS(2605),
    [sym_quoted_identifier] = ACTIONS(2607),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2607),
    [sym_integer] = ACTIONS(2605),
    [sym_continue_as_identifier] = ACTIONS(2607),
    [sym_preproc_open] = ACTIONS(2607),
  },
  [STATE(2212)] = {
    [sym_identifier] = ACTIONS(4874),
    [anon_sym_SEMI] = ACTIONS(4876),
    [anon_sym_DASH] = ACTIONS(4876),
    [aux_sym_boolean_token1] = ACTIONS(4874),
    [aux_sym_boolean_token2] = ACTIONS(4874),
    [sym_decimal] = ACTIONS(4874),
    [anon_sym_LPAREN] = ACTIONS(4876),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4874),
    [anon_sym_LBRACK] = ACTIONS(4876),
    [aux_sym_record_type_token1] = ACTIONS(4874),
    [aux_sym_basic_type_token21] = ACTIONS(4874),
    [aux_sym_basic_type_token22] = ACTIONS(4874),
    [aux_sym_basic_type_token48] = ACTIONS(4874),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4874),
    [anon_sym_POUNDif] = ACTIONS(4876),
    [anon_sym_POUNDIF] = ACTIONS(4876),
    [anon_sym_POUNDIf] = ACTIONS(4876),
    [anon_sym_not] = ACTIONS(4874),
    [anon_sym_NOT] = ACTIONS(4874),
    [anon_sym_Not] = ACTIONS(4874),
    [anon_sym_POUNDelse] = ACTIONS(4876),
    [anon_sym_POUNDELSE] = ACTIONS(4876),
    [anon_sym_POUNDElse] = ACTIONS(4876),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4874),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4874),
    [anon_sym_PLUS] = ACTIONS(4876),
    [sym_datetime_literal] = ACTIONS(4876),
    [sym_date_literal] = ACTIONS(4874),
    [sym_time_literal] = ACTIONS(4874),
    [sym_biginteger_literal] = ACTIONS(4876),
    [anon_sym_if] = ACTIONS(4874),
    [anon_sym_IF] = ACTIONS(4874),
    [anon_sym_If] = ACTIONS(4874),
    [anon_sym_case] = ACTIONS(4874),
    [anon_sym_CASE] = ACTIONS(4874),
    [anon_sym_Case] = ACTIONS(4874),
    [anon_sym_for] = ACTIONS(4874),
    [anon_sym_FOR] = ACTIONS(4874),
    [anon_sym_For] = ACTIONS(4874),
    [anon_sym_foreach] = ACTIONS(4874),
    [anon_sym_FOREACH] = ACTIONS(4874),
    [anon_sym_Foreach] = ACTIONS(4874),
    [anon_sym_while] = ACTIONS(4874),
    [anon_sym_WHILE] = ACTIONS(4874),
    [anon_sym_While] = ACTIONS(4874),
    [anon_sym_repeat] = ACTIONS(4874),
    [anon_sym_REPEAT] = ACTIONS(4874),
    [anon_sym_Repeat] = ACTIONS(4874),
    [anon_sym_until] = ACTIONS(4874),
    [anon_sym_UNTIL] = ACTIONS(4874),
    [anon_sym_Until] = ACTIONS(4874),
    [anon_sym_exit] = ACTIONS(4874),
    [anon_sym_EXIT] = ACTIONS(4874),
    [anon_sym_Exit] = ACTIONS(4874),
    [anon_sym_continue] = ACTIONS(4874),
    [anon_sym_CONTINUE] = ACTIONS(4874),
    [anon_sym_Continue] = ACTIONS(4874),
    [anon_sym_break] = ACTIONS(4874),
    [anon_sym_BREAK] = ACTIONS(4874),
    [anon_sym_Break] = ACTIONS(4874),
    [anon_sym_with] = ACTIONS(4874),
    [anon_sym_WITH] = ACTIONS(4874),
    [anon_sym_With] = ACTIONS(4874),
    [sym_asserterror_keyword] = ACTIONS(4876),
    [sym_page_keyword] = ACTIONS(4874),
    [anon_sym_codeunit] = ACTIONS(4874),
    [anon_sym_CODEUNIT] = ACTIONS(4874),
    [anon_sym_Codeunit] = ACTIONS(4874),
    [anon_sym_CodeUnit] = ACTIONS(4874),
    [anon_sym_COdeunit] = ACTIONS(4874),
    [anon_sym_codeUnit] = ACTIONS(4874),
    [sym_report_keyword] = ACTIONS(4874),
    [sym_query_keyword] = ACTIONS(4874),
    [anon_sym_xmlport] = ACTIONS(4874),
    [anon_sym_XMLPORT] = ACTIONS(4874),
    [anon_sym_Xmlport] = ACTIONS(4874),
    [anon_sym_XMLport] = ACTIONS(4874),
    [anon_sym_XMLPort] = ACTIONS(4874),
    [anon_sym_XmlPort] = ACTIONS(4874),
    [anon_sym_enum] = ACTIONS(4874),
    [anon_sym_ENUM] = ACTIONS(4874),
    [anon_sym_Enum] = ACTIONS(4874),
    [anon_sym_eNUM] = ACTIONS(4874),
    [anon_sym_eNum] = ACTIONS(4874),
    [anon_sym_ENum] = ACTIONS(4874),
    [sym_quoted_identifier] = ACTIONS(4876),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4876),
    [sym_integer] = ACTIONS(4874),
    [sym_continue_as_identifier] = ACTIONS(4876),
    [sym_preproc_open] = ACTIONS(4876),
  },
  [STATE(2213)] = {
    [sym_identifier] = ACTIONS(2529),
    [anon_sym_SEMI] = ACTIONS(2531),
    [anon_sym_DOT] = ACTIONS(2529),
    [anon_sym_EQ] = ACTIONS(2531),
    [anon_sym_COMMA] = ACTIONS(2531),
    [anon_sym_COLON] = ACTIONS(2529),
    [anon_sym_DASH] = ACTIONS(2529),
    [aux_sym_boolean_token1] = ACTIONS(2529),
    [aux_sym_boolean_token2] = ACTIONS(2529),
    [sym_decimal] = ACTIONS(2529),
    [anon_sym_LPAREN] = ACTIONS(2531),
    [anon_sym_DOT_DOT] = ACTIONS(2531),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2529),
    [anon_sym_STAR] = ACTIONS(2529),
    [anon_sym_LBRACK] = ACTIONS(2531),
    [aux_sym_record_type_token1] = ACTIONS(2529),
    [aux_sym_basic_type_token21] = ACTIONS(2529),
    [aux_sym_basic_type_token22] = ACTIONS(2529),
    [aux_sym_basic_type_token48] = ACTIONS(2529),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2529),
    [anon_sym_POUNDif] = ACTIONS(2531),
    [anon_sym_POUNDIF] = ACTIONS(2531),
    [anon_sym_POUNDIf] = ACTIONS(2531),
    [anon_sym_not] = ACTIONS(2529),
    [anon_sym_NOT] = ACTIONS(2529),
    [anon_sym_Not] = ACTIONS(2529),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2531),
    [aux_sym__expression_token1] = ACTIONS(2531),
    [aux_sym__expression_token2] = ACTIONS(2531),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2529),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2529),
    [anon_sym_SLASH] = ACTIONS(2529),
    [anon_sym_div] = ACTIONS(2529),
    [anon_sym_DIV] = ACTIONS(2529),
    [anon_sym_Div] = ACTIONS(2529),
    [anon_sym_mod] = ACTIONS(2529),
    [anon_sym_MOD] = ACTIONS(2529),
    [anon_sym_Mod] = ACTIONS(2529),
    [anon_sym_PLUS] = ACTIONS(2529),
    [anon_sym_GT_EQ] = ACTIONS(2531),
    [anon_sym_LT_EQ] = ACTIONS(2531),
    [anon_sym_GT] = ACTIONS(2529),
    [anon_sym_LT] = ACTIONS(2529),
    [anon_sym_LT_GT] = ACTIONS(2531),
    [anon_sym_and] = ACTIONS(2529),
    [anon_sym_AND] = ACTIONS(2529),
    [anon_sym_And] = ACTIONS(2529),
    [anon_sym_or] = ACTIONS(2529),
    [anon_sym_OR] = ACTIONS(2529),
    [anon_sym_Or] = ACTIONS(2529),
    [anon_sym_xor] = ACTIONS(2529),
    [anon_sym_XOR] = ACTIONS(2529),
    [anon_sym_Xor] = ACTIONS(2529),
    [anon_sym_QMARK] = ACTIONS(2531),
    [sym_datetime_literal] = ACTIONS(2531),
    [sym_date_literal] = ACTIONS(2529),
    [sym_time_literal] = ACTIONS(2529),
    [sym_biginteger_literal] = ACTIONS(2531),
    [anon_sym_else] = ACTIONS(2529),
    [anon_sym_ELSE] = ACTIONS(2529),
    [anon_sym_Else] = ACTIONS(2529),
    [anon_sym_in] = ACTIONS(2529),
    [anon_sym_IN] = ACTIONS(2529),
    [anon_sym_In] = ACTIONS(2529),
    [sym_page_keyword] = ACTIONS(2529),
    [anon_sym_codeunit] = ACTIONS(2529),
    [anon_sym_CODEUNIT] = ACTIONS(2529),
    [anon_sym_Codeunit] = ACTIONS(2529),
    [anon_sym_CodeUnit] = ACTIONS(2529),
    [anon_sym_COdeunit] = ACTIONS(2529),
    [anon_sym_codeUnit] = ACTIONS(2529),
    [sym_report_keyword] = ACTIONS(2529),
    [sym_query_keyword] = ACTIONS(2529),
    [anon_sym_xmlport] = ACTIONS(2529),
    [anon_sym_XMLPORT] = ACTIONS(2529),
    [anon_sym_Xmlport] = ACTIONS(2529),
    [anon_sym_XMLport] = ACTIONS(2529),
    [anon_sym_XMLPort] = ACTIONS(2529),
    [anon_sym_XmlPort] = ACTIONS(2529),
    [anon_sym_enum] = ACTIONS(2529),
    [anon_sym_ENUM] = ACTIONS(2529),
    [anon_sym_Enum] = ACTIONS(2529),
    [anon_sym_eNUM] = ACTIONS(2529),
    [anon_sym_eNum] = ACTIONS(2529),
    [anon_sym_ENum] = ACTIONS(2529),
    [sym_quoted_identifier] = ACTIONS(2531),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2531),
    [sym_integer] = ACTIONS(2529),
    [sym_continue_as_identifier] = ACTIONS(2531),
    [sym_preproc_open] = ACTIONS(2531),
  },
  [STATE(2214)] = {
    [sym_identifier] = ACTIONS(2649),
    [anon_sym_SEMI] = ACTIONS(2651),
    [anon_sym_DOT] = ACTIONS(2649),
    [anon_sym_EQ] = ACTIONS(2651),
    [anon_sym_COMMA] = ACTIONS(2651),
    [anon_sym_COLON] = ACTIONS(2649),
    [anon_sym_DASH] = ACTIONS(2649),
    [aux_sym_boolean_token1] = ACTIONS(2649),
    [aux_sym_boolean_token2] = ACTIONS(2649),
    [sym_decimal] = ACTIONS(2649),
    [anon_sym_LPAREN] = ACTIONS(2651),
    [anon_sym_DOT_DOT] = ACTIONS(2651),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2649),
    [anon_sym_STAR] = ACTIONS(2649),
    [anon_sym_LBRACK] = ACTIONS(2651),
    [aux_sym_record_type_token1] = ACTIONS(2649),
    [aux_sym_basic_type_token21] = ACTIONS(2649),
    [aux_sym_basic_type_token22] = ACTIONS(2649),
    [aux_sym_basic_type_token48] = ACTIONS(2649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2649),
    [anon_sym_POUNDif] = ACTIONS(2651),
    [anon_sym_POUNDIF] = ACTIONS(2651),
    [anon_sym_POUNDIf] = ACTIONS(2651),
    [anon_sym_not] = ACTIONS(2649),
    [anon_sym_NOT] = ACTIONS(2649),
    [anon_sym_Not] = ACTIONS(2649),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2651),
    [aux_sym__expression_token1] = ACTIONS(2651),
    [aux_sym__expression_token2] = ACTIONS(2651),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2649),
    [anon_sym_SLASH] = ACTIONS(2649),
    [anon_sym_div] = ACTIONS(2649),
    [anon_sym_DIV] = ACTIONS(2649),
    [anon_sym_Div] = ACTIONS(2649),
    [anon_sym_mod] = ACTIONS(2649),
    [anon_sym_MOD] = ACTIONS(2649),
    [anon_sym_Mod] = ACTIONS(2649),
    [anon_sym_PLUS] = ACTIONS(2649),
    [anon_sym_GT_EQ] = ACTIONS(2651),
    [anon_sym_LT_EQ] = ACTIONS(2651),
    [anon_sym_GT] = ACTIONS(2649),
    [anon_sym_LT] = ACTIONS(2649),
    [anon_sym_LT_GT] = ACTIONS(2651),
    [anon_sym_and] = ACTIONS(2649),
    [anon_sym_AND] = ACTIONS(2649),
    [anon_sym_And] = ACTIONS(2649),
    [anon_sym_or] = ACTIONS(2649),
    [anon_sym_OR] = ACTIONS(2649),
    [anon_sym_Or] = ACTIONS(2649),
    [anon_sym_xor] = ACTIONS(2649),
    [anon_sym_XOR] = ACTIONS(2649),
    [anon_sym_Xor] = ACTIONS(2649),
    [anon_sym_QMARK] = ACTIONS(2651),
    [sym_datetime_literal] = ACTIONS(2651),
    [sym_date_literal] = ACTIONS(2649),
    [sym_time_literal] = ACTIONS(2649),
    [sym_biginteger_literal] = ACTIONS(2651),
    [anon_sym_else] = ACTIONS(2649),
    [anon_sym_ELSE] = ACTIONS(2649),
    [anon_sym_Else] = ACTIONS(2649),
    [anon_sym_in] = ACTIONS(2649),
    [anon_sym_IN] = ACTIONS(2649),
    [anon_sym_In] = ACTIONS(2649),
    [sym_page_keyword] = ACTIONS(2649),
    [anon_sym_codeunit] = ACTIONS(2649),
    [anon_sym_CODEUNIT] = ACTIONS(2649),
    [anon_sym_Codeunit] = ACTIONS(2649),
    [anon_sym_CodeUnit] = ACTIONS(2649),
    [anon_sym_COdeunit] = ACTIONS(2649),
    [anon_sym_codeUnit] = ACTIONS(2649),
    [sym_report_keyword] = ACTIONS(2649),
    [sym_query_keyword] = ACTIONS(2649),
    [anon_sym_xmlport] = ACTIONS(2649),
    [anon_sym_XMLPORT] = ACTIONS(2649),
    [anon_sym_Xmlport] = ACTIONS(2649),
    [anon_sym_XMLport] = ACTIONS(2649),
    [anon_sym_XMLPort] = ACTIONS(2649),
    [anon_sym_XmlPort] = ACTIONS(2649),
    [anon_sym_enum] = ACTIONS(2649),
    [anon_sym_ENUM] = ACTIONS(2649),
    [anon_sym_Enum] = ACTIONS(2649),
    [anon_sym_eNUM] = ACTIONS(2649),
    [anon_sym_eNum] = ACTIONS(2649),
    [anon_sym_ENum] = ACTIONS(2649),
    [sym_quoted_identifier] = ACTIONS(2651),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2651),
    [sym_integer] = ACTIONS(2649),
    [sym_continue_as_identifier] = ACTIONS(2651),
    [sym_preproc_open] = ACTIONS(2651),
  },
  [STATE(2215)] = {
    [sym_identifier] = ACTIONS(2597),
    [anon_sym_DOT] = ACTIONS(2597),
    [anon_sym_EQ] = ACTIONS(2599),
    [anon_sym_COMMA] = ACTIONS(2599),
    [anon_sym_DASH] = ACTIONS(2597),
    [aux_sym_boolean_token1] = ACTIONS(2597),
    [aux_sym_boolean_token2] = ACTIONS(2597),
    [sym_decimal] = ACTIONS(2597),
    [anon_sym_LPAREN] = ACTIONS(2599),
    [anon_sym_DOT_DOT] = ACTIONS(2599),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2597),
    [anon_sym_STAR] = ACTIONS(2597),
    [anon_sym_LBRACK] = ACTIONS(2599),
    [aux_sym_record_type_token1] = ACTIONS(2597),
    [aux_sym_basic_type_token21] = ACTIONS(2597),
    [aux_sym_basic_type_token22] = ACTIONS(2597),
    [aux_sym_basic_type_token48] = ACTIONS(2597),
    [anon_sym_not] = ACTIONS(2597),
    [anon_sym_NOT] = ACTIONS(2597),
    [anon_sym_Not] = ACTIONS(2597),
    [anon_sym_POUNDelif] = ACTIONS(2599),
    [anon_sym_POUNDELIF] = ACTIONS(2599),
    [anon_sym_POUNDElif] = ACTIONS(2599),
    [anon_sym_POUNDelse] = ACTIONS(2599),
    [anon_sym_POUNDELSE] = ACTIONS(2599),
    [anon_sym_POUNDElse] = ACTIONS(2599),
    [anon_sym_POUNDendif] = ACTIONS(2599),
    [anon_sym_POUNDENDIF] = ACTIONS(2599),
    [anon_sym_POUNDEndif] = ACTIONS(2599),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2599),
    [aux_sym__expression_token1] = ACTIONS(2599),
    [aux_sym__expression_token2] = ACTIONS(2599),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2597),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2597),
    [anon_sym_SLASH] = ACTIONS(2597),
    [anon_sym_div] = ACTIONS(2597),
    [anon_sym_DIV] = ACTIONS(2597),
    [anon_sym_Div] = ACTIONS(2597),
    [anon_sym_mod] = ACTIONS(2597),
    [anon_sym_MOD] = ACTIONS(2597),
    [anon_sym_Mod] = ACTIONS(2597),
    [anon_sym_PLUS] = ACTIONS(2597),
    [anon_sym_GT_EQ] = ACTIONS(2599),
    [anon_sym_LT_EQ] = ACTIONS(2599),
    [anon_sym_GT] = ACTIONS(2597),
    [anon_sym_LT] = ACTIONS(2597),
    [anon_sym_LT_GT] = ACTIONS(2599),
    [anon_sym_and] = ACTIONS(2597),
    [anon_sym_AND] = ACTIONS(2597),
    [anon_sym_And] = ACTIONS(2597),
    [anon_sym_or] = ACTIONS(2597),
    [anon_sym_OR] = ACTIONS(2597),
    [anon_sym_Or] = ACTIONS(2597),
    [anon_sym_xor] = ACTIONS(2597),
    [anon_sym_XOR] = ACTIONS(2597),
    [anon_sym_Xor] = ACTIONS(2597),
    [anon_sym_QMARK] = ACTIONS(2599),
    [sym_datetime_literal] = ACTIONS(2599),
    [sym_date_literal] = ACTIONS(2597),
    [sym_time_literal] = ACTIONS(2597),
    [sym_biginteger_literal] = ACTIONS(2599),
    [anon_sym_in] = ACTIONS(2597),
    [anon_sym_IN] = ACTIONS(2597),
    [anon_sym_In] = ACTIONS(2597),
    [sym_page_keyword] = ACTIONS(2597),
    [anon_sym_codeunit] = ACTIONS(2597),
    [anon_sym_CODEUNIT] = ACTIONS(2597),
    [anon_sym_Codeunit] = ACTIONS(2597),
    [anon_sym_CodeUnit] = ACTIONS(2597),
    [anon_sym_COdeunit] = ACTIONS(2597),
    [anon_sym_codeUnit] = ACTIONS(2597),
    [sym_report_keyword] = ACTIONS(2597),
    [sym_query_keyword] = ACTIONS(2597),
    [anon_sym_xmlport] = ACTIONS(2597),
    [anon_sym_XMLPORT] = ACTIONS(2597),
    [anon_sym_Xmlport] = ACTIONS(2597),
    [anon_sym_XMLport] = ACTIONS(2597),
    [anon_sym_XMLPort] = ACTIONS(2597),
    [anon_sym_XmlPort] = ACTIONS(2597),
    [anon_sym_enum] = ACTIONS(2597),
    [anon_sym_ENUM] = ACTIONS(2597),
    [anon_sym_Enum] = ACTIONS(2597),
    [anon_sym_eNUM] = ACTIONS(2597),
    [anon_sym_eNum] = ACTIONS(2597),
    [anon_sym_ENum] = ACTIONS(2597),
    [sym_quoted_identifier] = ACTIONS(2599),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2599),
    [sym_integer] = ACTIONS(2597),
    [sym_continue_as_identifier] = ACTIONS(2599),
    [sym_preproc_close] = ACTIONS(2599),
  },
  [STATE(2216)] = {
    [sym_identifier] = ACTIONS(5447),
    [anon_sym_SEMI] = ACTIONS(5449),
    [anon_sym_DASH] = ACTIONS(5449),
    [aux_sym_boolean_token1] = ACTIONS(5447),
    [aux_sym_boolean_token2] = ACTIONS(5447),
    [sym_decimal] = ACTIONS(5447),
    [anon_sym_LPAREN] = ACTIONS(5449),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5447),
    [anon_sym_LBRACK] = ACTIONS(5449),
    [aux_sym_record_type_token1] = ACTIONS(5447),
    [aux_sym_basic_type_token21] = ACTIONS(5447),
    [aux_sym_basic_type_token22] = ACTIONS(5447),
    [aux_sym_basic_type_token48] = ACTIONS(5447),
    [anon_sym_POUNDif] = ACTIONS(5449),
    [anon_sym_POUNDIF] = ACTIONS(5449),
    [anon_sym_POUNDIf] = ACTIONS(5449),
    [anon_sym_not] = ACTIONS(5447),
    [anon_sym_NOT] = ACTIONS(5447),
    [anon_sym_Not] = ACTIONS(5447),
    [anon_sym_POUNDendif] = ACTIONS(5449),
    [anon_sym_POUNDENDIF] = ACTIONS(5449),
    [anon_sym_POUNDEndif] = ACTIONS(5449),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5447),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5447),
    [anon_sym_PLUS] = ACTIONS(5449),
    [sym_datetime_literal] = ACTIONS(5449),
    [sym_date_literal] = ACTIONS(5447),
    [sym_time_literal] = ACTIONS(5447),
    [sym_biginteger_literal] = ACTIONS(5449),
    [anon_sym_if] = ACTIONS(5447),
    [anon_sym_IF] = ACTIONS(5447),
    [anon_sym_If] = ACTIONS(5447),
    [anon_sym_else] = ACTIONS(5447),
    [anon_sym_ELSE] = ACTIONS(5447),
    [anon_sym_Else] = ACTIONS(5447),
    [anon_sym_case] = ACTIONS(5447),
    [anon_sym_CASE] = ACTIONS(5447),
    [anon_sym_Case] = ACTIONS(5447),
    [anon_sym_for] = ACTIONS(5447),
    [anon_sym_FOR] = ACTIONS(5447),
    [anon_sym_For] = ACTIONS(5447),
    [anon_sym_foreach] = ACTIONS(5447),
    [anon_sym_FOREACH] = ACTIONS(5447),
    [anon_sym_Foreach] = ACTIONS(5447),
    [anon_sym_while] = ACTIONS(5447),
    [anon_sym_WHILE] = ACTIONS(5447),
    [anon_sym_While] = ACTIONS(5447),
    [anon_sym_repeat] = ACTIONS(5447),
    [anon_sym_REPEAT] = ACTIONS(5447),
    [anon_sym_Repeat] = ACTIONS(5447),
    [anon_sym_exit] = ACTIONS(5447),
    [anon_sym_EXIT] = ACTIONS(5447),
    [anon_sym_Exit] = ACTIONS(5447),
    [anon_sym_continue] = ACTIONS(5447),
    [anon_sym_CONTINUE] = ACTIONS(5447),
    [anon_sym_Continue] = ACTIONS(5447),
    [anon_sym_break] = ACTIONS(5447),
    [anon_sym_BREAK] = ACTIONS(5447),
    [anon_sym_Break] = ACTIONS(5447),
    [anon_sym_with] = ACTIONS(5447),
    [anon_sym_WITH] = ACTIONS(5447),
    [anon_sym_With] = ACTIONS(5447),
    [sym_asserterror_keyword] = ACTIONS(5449),
    [sym_page_keyword] = ACTIONS(5447),
    [anon_sym_codeunit] = ACTIONS(5447),
    [anon_sym_CODEUNIT] = ACTIONS(5447),
    [anon_sym_Codeunit] = ACTIONS(5447),
    [anon_sym_CodeUnit] = ACTIONS(5447),
    [anon_sym_COdeunit] = ACTIONS(5447),
    [anon_sym_codeUnit] = ACTIONS(5447),
    [sym_report_keyword] = ACTIONS(5447),
    [sym_query_keyword] = ACTIONS(5447),
    [anon_sym_xmlport] = ACTIONS(5447),
    [anon_sym_XMLPORT] = ACTIONS(5447),
    [anon_sym_Xmlport] = ACTIONS(5447),
    [anon_sym_XMLport] = ACTIONS(5447),
    [anon_sym_XMLPort] = ACTIONS(5447),
    [anon_sym_XmlPort] = ACTIONS(5447),
    [anon_sym_enum] = ACTIONS(5447),
    [anon_sym_ENUM] = ACTIONS(5447),
    [anon_sym_Enum] = ACTIONS(5447),
    [anon_sym_eNUM] = ACTIONS(5447),
    [anon_sym_eNum] = ACTIONS(5447),
    [anon_sym_ENum] = ACTIONS(5447),
    [sym_quoted_identifier] = ACTIONS(5449),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5449),
    [sym_integer] = ACTIONS(5447),
    [sym_continue_as_identifier] = ACTIONS(5449),
    [sym_preproc_open] = ACTIONS(5449),
    [sym_preproc_close] = ACTIONS(5449),
  },
  [STATE(2217)] = {
    [sym_else_keyword] = STATE(613),
    [sym_identifier] = ACTIONS(4119),
    [anon_sym_SEMI] = ACTIONS(4121),
    [anon_sym_DASH] = ACTIONS(4121),
    [aux_sym_boolean_token1] = ACTIONS(4119),
    [aux_sym_boolean_token2] = ACTIONS(4119),
    [sym_decimal] = ACTIONS(4119),
    [anon_sym_LPAREN] = ACTIONS(4121),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4119),
    [anon_sym_LBRACK] = ACTIONS(4121),
    [aux_sym_record_type_token1] = ACTIONS(4119),
    [aux_sym_basic_type_token21] = ACTIONS(4119),
    [aux_sym_basic_type_token22] = ACTIONS(4119),
    [aux_sym_basic_type_token48] = ACTIONS(4119),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4119),
    [anon_sym_POUNDif] = ACTIONS(4121),
    [anon_sym_POUNDIF] = ACTIONS(4121),
    [anon_sym_POUNDIf] = ACTIONS(4121),
    [anon_sym_not] = ACTIONS(4119),
    [anon_sym_NOT] = ACTIONS(4119),
    [anon_sym_Not] = ACTIONS(4119),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4119),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4119),
    [anon_sym_PLUS] = ACTIONS(4121),
    [sym_datetime_literal] = ACTIONS(4121),
    [sym_date_literal] = ACTIONS(4119),
    [sym_time_literal] = ACTIONS(4119),
    [sym_biginteger_literal] = ACTIONS(4121),
    [anon_sym_if] = ACTIONS(4119),
    [anon_sym_IF] = ACTIONS(4119),
    [anon_sym_If] = ACTIONS(4119),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4119),
    [anon_sym_CASE] = ACTIONS(4119),
    [anon_sym_Case] = ACTIONS(4119),
    [anon_sym_for] = ACTIONS(4119),
    [anon_sym_FOR] = ACTIONS(4119),
    [anon_sym_For] = ACTIONS(4119),
    [anon_sym_foreach] = ACTIONS(4119),
    [anon_sym_FOREACH] = ACTIONS(4119),
    [anon_sym_Foreach] = ACTIONS(4119),
    [anon_sym_while] = ACTIONS(4119),
    [anon_sym_WHILE] = ACTIONS(4119),
    [anon_sym_While] = ACTIONS(4119),
    [anon_sym_repeat] = ACTIONS(4119),
    [anon_sym_REPEAT] = ACTIONS(4119),
    [anon_sym_Repeat] = ACTIONS(4119),
    [anon_sym_exit] = ACTIONS(4119),
    [anon_sym_EXIT] = ACTIONS(4119),
    [anon_sym_Exit] = ACTIONS(4119),
    [anon_sym_continue] = ACTIONS(4119),
    [anon_sym_CONTINUE] = ACTIONS(4119),
    [anon_sym_Continue] = ACTIONS(4119),
    [anon_sym_break] = ACTIONS(4119),
    [anon_sym_BREAK] = ACTIONS(4119),
    [anon_sym_Break] = ACTIONS(4119),
    [anon_sym_with] = ACTIONS(4119),
    [anon_sym_WITH] = ACTIONS(4119),
    [anon_sym_With] = ACTIONS(4119),
    [sym_asserterror_keyword] = ACTIONS(4121),
    [sym_page_keyword] = ACTIONS(4119),
    [anon_sym_codeunit] = ACTIONS(4119),
    [anon_sym_CODEUNIT] = ACTIONS(4119),
    [anon_sym_Codeunit] = ACTIONS(4119),
    [anon_sym_CodeUnit] = ACTIONS(4119),
    [anon_sym_COdeunit] = ACTIONS(4119),
    [anon_sym_codeUnit] = ACTIONS(4119),
    [sym_report_keyword] = ACTIONS(4119),
    [sym_query_keyword] = ACTIONS(4119),
    [anon_sym_xmlport] = ACTIONS(4119),
    [anon_sym_XMLPORT] = ACTIONS(4119),
    [anon_sym_Xmlport] = ACTIONS(4119),
    [anon_sym_XMLport] = ACTIONS(4119),
    [anon_sym_XMLPort] = ACTIONS(4119),
    [anon_sym_XmlPort] = ACTIONS(4119),
    [anon_sym_enum] = ACTIONS(4119),
    [anon_sym_ENUM] = ACTIONS(4119),
    [anon_sym_Enum] = ACTIONS(4119),
    [anon_sym_eNUM] = ACTIONS(4119),
    [anon_sym_eNum] = ACTIONS(4119),
    [anon_sym_ENum] = ACTIONS(4119),
    [sym_quoted_identifier] = ACTIONS(4121),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4121),
    [sym_integer] = ACTIONS(4119),
    [sym_continue_as_identifier] = ACTIONS(4121),
    [sym_preproc_open] = ACTIONS(4121),
    [sym_end_keyword] = ACTIONS(4121),
  },
  [STATE(2218)] = {
    [sym_boolean] = STATE(6345),
    [sym_preproc_conditional_table_relation] = STATE(12091),
    [sym_table_relation_expression] = STATE(11935),
    [sym_if_table_relation] = STATE(12091),
    [sym_simple_table_relation] = STATE(12091),
    [sym__namespaced_or_simple_ref] = STATE(10231),
    [sym_preproc_if] = STATE(1385),
    [sym_assignment_expression] = STATE(6345),
    [sym__expression] = STATE(6345),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6345),
    [sym_multiplicative_expression] = STATE(6345),
    [sym_additive_expression] = STATE(6345),
    [sym_comparison_expression] = STATE(6345),
    [sym_logical_expression] = STATE(6345),
    [sym_ternary_expression] = STATE(6345),
    [sym_unary_expression] = STATE(6345),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(5952),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6345),
    [sym_list_literal] = STATE(6345),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6345),
    [sym__literal_value] = STATE(6345),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(4762),
    [sym_keyword_as_identifier] = STATE(4762),
    [sym_identifier] = ACTIONS(5451),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_if_table_relation_token1] = ACTIONS(2213),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(5455),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(5457),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5457),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_quoted_identifier] = ACTIONS(5459),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5457),
    [sym_integer] = ACTIONS(5461),
    [sym_continue_as_identifier] = ACTIONS(5457),
    [sym_preproc_open] = ACTIONS(2223),
  },
  [STATE(2219)] = {
    [sym_else_keyword] = STATE(570),
    [sym_identifier] = ACTIONS(4169),
    [anon_sym_SEMI] = ACTIONS(4171),
    [anon_sym_DASH] = ACTIONS(4171),
    [aux_sym_boolean_token1] = ACTIONS(4169),
    [aux_sym_boolean_token2] = ACTIONS(4169),
    [sym_decimal] = ACTIONS(4169),
    [anon_sym_LPAREN] = ACTIONS(4171),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4169),
    [anon_sym_LBRACK] = ACTIONS(4171),
    [aux_sym_record_type_token1] = ACTIONS(4169),
    [aux_sym_basic_type_token21] = ACTIONS(4169),
    [aux_sym_basic_type_token22] = ACTIONS(4169),
    [aux_sym_basic_type_token48] = ACTIONS(4169),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4169),
    [anon_sym_POUNDif] = ACTIONS(4171),
    [anon_sym_POUNDIF] = ACTIONS(4171),
    [anon_sym_POUNDIf] = ACTIONS(4171),
    [anon_sym_not] = ACTIONS(4169),
    [anon_sym_NOT] = ACTIONS(4169),
    [anon_sym_Not] = ACTIONS(4169),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4169),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4169),
    [anon_sym_PLUS] = ACTIONS(4171),
    [sym_datetime_literal] = ACTIONS(4171),
    [sym_date_literal] = ACTIONS(4169),
    [sym_time_literal] = ACTIONS(4169),
    [sym_biginteger_literal] = ACTIONS(4171),
    [anon_sym_if] = ACTIONS(4169),
    [anon_sym_IF] = ACTIONS(4169),
    [anon_sym_If] = ACTIONS(4169),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4169),
    [anon_sym_CASE] = ACTIONS(4169),
    [anon_sym_Case] = ACTIONS(4169),
    [anon_sym_for] = ACTIONS(4169),
    [anon_sym_FOR] = ACTIONS(4169),
    [anon_sym_For] = ACTIONS(4169),
    [anon_sym_foreach] = ACTIONS(4169),
    [anon_sym_FOREACH] = ACTIONS(4169),
    [anon_sym_Foreach] = ACTIONS(4169),
    [anon_sym_while] = ACTIONS(4169),
    [anon_sym_WHILE] = ACTIONS(4169),
    [anon_sym_While] = ACTIONS(4169),
    [anon_sym_repeat] = ACTIONS(4169),
    [anon_sym_REPEAT] = ACTIONS(4169),
    [anon_sym_Repeat] = ACTIONS(4169),
    [anon_sym_exit] = ACTIONS(4169),
    [anon_sym_EXIT] = ACTIONS(4169),
    [anon_sym_Exit] = ACTIONS(4169),
    [anon_sym_continue] = ACTIONS(4169),
    [anon_sym_CONTINUE] = ACTIONS(4169),
    [anon_sym_Continue] = ACTIONS(4169),
    [anon_sym_break] = ACTIONS(4169),
    [anon_sym_BREAK] = ACTIONS(4169),
    [anon_sym_Break] = ACTIONS(4169),
    [anon_sym_with] = ACTIONS(4169),
    [anon_sym_WITH] = ACTIONS(4169),
    [anon_sym_With] = ACTIONS(4169),
    [sym_asserterror_keyword] = ACTIONS(4171),
    [sym_page_keyword] = ACTIONS(4169),
    [anon_sym_codeunit] = ACTIONS(4169),
    [anon_sym_CODEUNIT] = ACTIONS(4169),
    [anon_sym_Codeunit] = ACTIONS(4169),
    [anon_sym_CodeUnit] = ACTIONS(4169),
    [anon_sym_COdeunit] = ACTIONS(4169),
    [anon_sym_codeUnit] = ACTIONS(4169),
    [sym_report_keyword] = ACTIONS(4169),
    [sym_query_keyword] = ACTIONS(4169),
    [anon_sym_xmlport] = ACTIONS(4169),
    [anon_sym_XMLPORT] = ACTIONS(4169),
    [anon_sym_Xmlport] = ACTIONS(4169),
    [anon_sym_XMLport] = ACTIONS(4169),
    [anon_sym_XMLPort] = ACTIONS(4169),
    [anon_sym_XmlPort] = ACTIONS(4169),
    [anon_sym_enum] = ACTIONS(4169),
    [anon_sym_ENUM] = ACTIONS(4169),
    [anon_sym_Enum] = ACTIONS(4169),
    [anon_sym_eNUM] = ACTIONS(4169),
    [anon_sym_eNum] = ACTIONS(4169),
    [anon_sym_ENum] = ACTIONS(4169),
    [sym_quoted_identifier] = ACTIONS(4171),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4171),
    [sym_integer] = ACTIONS(4169),
    [sym_continue_as_identifier] = ACTIONS(4171),
    [sym_preproc_open] = ACTIONS(4171),
    [sym_end_keyword] = ACTIONS(4171),
  },
  [STATE(2220)] = {
    [sym_else_keyword] = STATE(446),
    [sym_identifier] = ACTIONS(4125),
    [anon_sym_SEMI] = ACTIONS(4127),
    [anon_sym_DASH] = ACTIONS(4127),
    [aux_sym_boolean_token1] = ACTIONS(4125),
    [aux_sym_boolean_token2] = ACTIONS(4125),
    [sym_decimal] = ACTIONS(4125),
    [anon_sym_LPAREN] = ACTIONS(4127),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4125),
    [anon_sym_LBRACK] = ACTIONS(4127),
    [aux_sym_record_type_token1] = ACTIONS(4125),
    [aux_sym_basic_type_token21] = ACTIONS(4125),
    [aux_sym_basic_type_token22] = ACTIONS(4125),
    [aux_sym_basic_type_token48] = ACTIONS(4125),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4125),
    [anon_sym_POUNDif] = ACTIONS(4127),
    [anon_sym_POUNDIF] = ACTIONS(4127),
    [anon_sym_POUNDIf] = ACTIONS(4127),
    [anon_sym_not] = ACTIONS(4125),
    [anon_sym_NOT] = ACTIONS(4125),
    [anon_sym_Not] = ACTIONS(4125),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4125),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4125),
    [anon_sym_PLUS] = ACTIONS(4127),
    [sym_datetime_literal] = ACTIONS(4127),
    [sym_date_literal] = ACTIONS(4125),
    [sym_time_literal] = ACTIONS(4125),
    [sym_biginteger_literal] = ACTIONS(4127),
    [anon_sym_if] = ACTIONS(4125),
    [anon_sym_IF] = ACTIONS(4125),
    [anon_sym_If] = ACTIONS(4125),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4125),
    [anon_sym_CASE] = ACTIONS(4125),
    [anon_sym_Case] = ACTIONS(4125),
    [anon_sym_for] = ACTIONS(4125),
    [anon_sym_FOR] = ACTIONS(4125),
    [anon_sym_For] = ACTIONS(4125),
    [anon_sym_foreach] = ACTIONS(4125),
    [anon_sym_FOREACH] = ACTIONS(4125),
    [anon_sym_Foreach] = ACTIONS(4125),
    [anon_sym_while] = ACTIONS(4125),
    [anon_sym_WHILE] = ACTIONS(4125),
    [anon_sym_While] = ACTIONS(4125),
    [anon_sym_repeat] = ACTIONS(4125),
    [anon_sym_REPEAT] = ACTIONS(4125),
    [anon_sym_Repeat] = ACTIONS(4125),
    [anon_sym_exit] = ACTIONS(4125),
    [anon_sym_EXIT] = ACTIONS(4125),
    [anon_sym_Exit] = ACTIONS(4125),
    [anon_sym_continue] = ACTIONS(4125),
    [anon_sym_CONTINUE] = ACTIONS(4125),
    [anon_sym_Continue] = ACTIONS(4125),
    [anon_sym_break] = ACTIONS(4125),
    [anon_sym_BREAK] = ACTIONS(4125),
    [anon_sym_Break] = ACTIONS(4125),
    [anon_sym_with] = ACTIONS(4125),
    [anon_sym_WITH] = ACTIONS(4125),
    [anon_sym_With] = ACTIONS(4125),
    [sym_asserterror_keyword] = ACTIONS(4127),
    [sym_page_keyword] = ACTIONS(4125),
    [anon_sym_codeunit] = ACTIONS(4125),
    [anon_sym_CODEUNIT] = ACTIONS(4125),
    [anon_sym_Codeunit] = ACTIONS(4125),
    [anon_sym_CodeUnit] = ACTIONS(4125),
    [anon_sym_COdeunit] = ACTIONS(4125),
    [anon_sym_codeUnit] = ACTIONS(4125),
    [sym_report_keyword] = ACTIONS(4125),
    [sym_query_keyword] = ACTIONS(4125),
    [anon_sym_xmlport] = ACTIONS(4125),
    [anon_sym_XMLPORT] = ACTIONS(4125),
    [anon_sym_Xmlport] = ACTIONS(4125),
    [anon_sym_XMLport] = ACTIONS(4125),
    [anon_sym_XMLPort] = ACTIONS(4125),
    [anon_sym_XmlPort] = ACTIONS(4125),
    [anon_sym_enum] = ACTIONS(4125),
    [anon_sym_ENUM] = ACTIONS(4125),
    [anon_sym_Enum] = ACTIONS(4125),
    [anon_sym_eNUM] = ACTIONS(4125),
    [anon_sym_eNum] = ACTIONS(4125),
    [anon_sym_ENum] = ACTIONS(4125),
    [sym_quoted_identifier] = ACTIONS(4127),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4127),
    [sym_integer] = ACTIONS(4125),
    [sym_continue_as_identifier] = ACTIONS(4127),
    [sym_preproc_open] = ACTIONS(4127),
    [sym_end_keyword] = ACTIONS(4127),
  },
  [STATE(2221)] = {
    [sym_else_keyword] = STATE(483),
    [sym_identifier] = ACTIONS(4153),
    [anon_sym_SEMI] = ACTIONS(4155),
    [anon_sym_DASH] = ACTIONS(4155),
    [aux_sym_boolean_token1] = ACTIONS(4153),
    [aux_sym_boolean_token2] = ACTIONS(4153),
    [sym_decimal] = ACTIONS(4153),
    [anon_sym_LPAREN] = ACTIONS(4155),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4153),
    [anon_sym_LBRACK] = ACTIONS(4155),
    [aux_sym_record_type_token1] = ACTIONS(4153),
    [aux_sym_basic_type_token21] = ACTIONS(4153),
    [aux_sym_basic_type_token22] = ACTIONS(4153),
    [aux_sym_basic_type_token48] = ACTIONS(4153),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4153),
    [anon_sym_POUNDif] = ACTIONS(4155),
    [anon_sym_POUNDIF] = ACTIONS(4155),
    [anon_sym_POUNDIf] = ACTIONS(4155),
    [anon_sym_not] = ACTIONS(4153),
    [anon_sym_NOT] = ACTIONS(4153),
    [anon_sym_Not] = ACTIONS(4153),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4153),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4153),
    [anon_sym_PLUS] = ACTIONS(4155),
    [sym_datetime_literal] = ACTIONS(4155),
    [sym_date_literal] = ACTIONS(4153),
    [sym_time_literal] = ACTIONS(4153),
    [sym_biginteger_literal] = ACTIONS(4155),
    [anon_sym_if] = ACTIONS(4153),
    [anon_sym_IF] = ACTIONS(4153),
    [anon_sym_If] = ACTIONS(4153),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4153),
    [anon_sym_CASE] = ACTIONS(4153),
    [anon_sym_Case] = ACTIONS(4153),
    [anon_sym_for] = ACTIONS(4153),
    [anon_sym_FOR] = ACTIONS(4153),
    [anon_sym_For] = ACTIONS(4153),
    [anon_sym_foreach] = ACTIONS(4153),
    [anon_sym_FOREACH] = ACTIONS(4153),
    [anon_sym_Foreach] = ACTIONS(4153),
    [anon_sym_while] = ACTIONS(4153),
    [anon_sym_WHILE] = ACTIONS(4153),
    [anon_sym_While] = ACTIONS(4153),
    [anon_sym_repeat] = ACTIONS(4153),
    [anon_sym_REPEAT] = ACTIONS(4153),
    [anon_sym_Repeat] = ACTIONS(4153),
    [anon_sym_exit] = ACTIONS(4153),
    [anon_sym_EXIT] = ACTIONS(4153),
    [anon_sym_Exit] = ACTIONS(4153),
    [anon_sym_continue] = ACTIONS(4153),
    [anon_sym_CONTINUE] = ACTIONS(4153),
    [anon_sym_Continue] = ACTIONS(4153),
    [anon_sym_break] = ACTIONS(4153),
    [anon_sym_BREAK] = ACTIONS(4153),
    [anon_sym_Break] = ACTIONS(4153),
    [anon_sym_with] = ACTIONS(4153),
    [anon_sym_WITH] = ACTIONS(4153),
    [anon_sym_With] = ACTIONS(4153),
    [sym_asserterror_keyword] = ACTIONS(4155),
    [sym_page_keyword] = ACTIONS(4153),
    [anon_sym_codeunit] = ACTIONS(4153),
    [anon_sym_CODEUNIT] = ACTIONS(4153),
    [anon_sym_Codeunit] = ACTIONS(4153),
    [anon_sym_CodeUnit] = ACTIONS(4153),
    [anon_sym_COdeunit] = ACTIONS(4153),
    [anon_sym_codeUnit] = ACTIONS(4153),
    [sym_report_keyword] = ACTIONS(4153),
    [sym_query_keyword] = ACTIONS(4153),
    [anon_sym_xmlport] = ACTIONS(4153),
    [anon_sym_XMLPORT] = ACTIONS(4153),
    [anon_sym_Xmlport] = ACTIONS(4153),
    [anon_sym_XMLport] = ACTIONS(4153),
    [anon_sym_XMLPort] = ACTIONS(4153),
    [anon_sym_XmlPort] = ACTIONS(4153),
    [anon_sym_enum] = ACTIONS(4153),
    [anon_sym_ENUM] = ACTIONS(4153),
    [anon_sym_Enum] = ACTIONS(4153),
    [anon_sym_eNUM] = ACTIONS(4153),
    [anon_sym_eNum] = ACTIONS(4153),
    [anon_sym_ENum] = ACTIONS(4153),
    [sym_quoted_identifier] = ACTIONS(4155),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4155),
    [sym_integer] = ACTIONS(4153),
    [sym_continue_as_identifier] = ACTIONS(4155),
    [sym_preproc_open] = ACTIONS(4155),
    [sym_end_keyword] = ACTIONS(4155),
  },
  [STATE(2222)] = {
    [sym_identifier] = ACTIONS(4139),
    [anon_sym_SEMI] = ACTIONS(4141),
    [anon_sym_DASH] = ACTIONS(4141),
    [aux_sym_boolean_token1] = ACTIONS(4139),
    [aux_sym_boolean_token2] = ACTIONS(4139),
    [sym_decimal] = ACTIONS(4139),
    [anon_sym_LPAREN] = ACTIONS(4139),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4139),
    [anon_sym_LBRACK] = ACTIONS(4141),
    [aux_sym_record_type_token1] = ACTIONS(4139),
    [aux_sym_basic_type_token21] = ACTIONS(4139),
    [aux_sym_basic_type_token22] = ACTIONS(4139),
    [aux_sym_basic_type_token48] = ACTIONS(4139),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4139),
    [anon_sym_POUNDif] = ACTIONS(4141),
    [anon_sym_POUNDIF] = ACTIONS(4141),
    [anon_sym_POUNDIf] = ACTIONS(4141),
    [anon_sym_not] = ACTIONS(4139),
    [anon_sym_NOT] = ACTIONS(4139),
    [anon_sym_Not] = ACTIONS(4139),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_LPAREN2] = ACTIONS(5463),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4139),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4139),
    [anon_sym_PLUS] = ACTIONS(4141),
    [sym_datetime_literal] = ACTIONS(4141),
    [sym_date_literal] = ACTIONS(4139),
    [sym_time_literal] = ACTIONS(4139),
    [sym_biginteger_literal] = ACTIONS(4141),
    [anon_sym_if] = ACTIONS(4139),
    [anon_sym_IF] = ACTIONS(4139),
    [anon_sym_If] = ACTIONS(4139),
    [anon_sym_else] = ACTIONS(4139),
    [anon_sym_ELSE] = ACTIONS(4139),
    [anon_sym_Else] = ACTIONS(4139),
    [anon_sym_case] = ACTIONS(4139),
    [anon_sym_CASE] = ACTIONS(4139),
    [anon_sym_Case] = ACTIONS(4139),
    [anon_sym_for] = ACTIONS(4139),
    [anon_sym_FOR] = ACTIONS(4139),
    [anon_sym_For] = ACTIONS(4139),
    [anon_sym_foreach] = ACTIONS(4139),
    [anon_sym_FOREACH] = ACTIONS(4139),
    [anon_sym_Foreach] = ACTIONS(4139),
    [anon_sym_while] = ACTIONS(4139),
    [anon_sym_WHILE] = ACTIONS(4139),
    [anon_sym_While] = ACTIONS(4139),
    [anon_sym_repeat] = ACTIONS(4139),
    [anon_sym_REPEAT] = ACTIONS(4139),
    [anon_sym_Repeat] = ACTIONS(4139),
    [anon_sym_exit] = ACTIONS(4139),
    [anon_sym_EXIT] = ACTIONS(4139),
    [anon_sym_Exit] = ACTIONS(4139),
    [anon_sym_continue] = ACTIONS(4139),
    [anon_sym_CONTINUE] = ACTIONS(4139),
    [anon_sym_Continue] = ACTIONS(4139),
    [anon_sym_break] = ACTIONS(4139),
    [anon_sym_BREAK] = ACTIONS(4139),
    [anon_sym_Break] = ACTIONS(4139),
    [anon_sym_with] = ACTIONS(4139),
    [anon_sym_WITH] = ACTIONS(4139),
    [anon_sym_With] = ACTIONS(4139),
    [sym_asserterror_keyword] = ACTIONS(4141),
    [sym_page_keyword] = ACTIONS(4139),
    [anon_sym_codeunit] = ACTIONS(4139),
    [anon_sym_CODEUNIT] = ACTIONS(4139),
    [anon_sym_Codeunit] = ACTIONS(4139),
    [anon_sym_CodeUnit] = ACTIONS(4139),
    [anon_sym_COdeunit] = ACTIONS(4139),
    [anon_sym_codeUnit] = ACTIONS(4139),
    [sym_report_keyword] = ACTIONS(4139),
    [sym_query_keyword] = ACTIONS(4139),
    [anon_sym_xmlport] = ACTIONS(4139),
    [anon_sym_XMLPORT] = ACTIONS(4139),
    [anon_sym_Xmlport] = ACTIONS(4139),
    [anon_sym_XMLport] = ACTIONS(4139),
    [anon_sym_XMLPort] = ACTIONS(4139),
    [anon_sym_XmlPort] = ACTIONS(4139),
    [anon_sym_enum] = ACTIONS(4139),
    [anon_sym_ENUM] = ACTIONS(4139),
    [anon_sym_Enum] = ACTIONS(4139),
    [anon_sym_eNUM] = ACTIONS(4139),
    [anon_sym_eNum] = ACTIONS(4139),
    [anon_sym_ENum] = ACTIONS(4139),
    [sym_quoted_identifier] = ACTIONS(4141),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4141),
    [sym_integer] = ACTIONS(4139),
    [sym_continue_as_identifier] = ACTIONS(4141),
    [sym_preproc_open] = ACTIONS(4141),
    [sym_end_keyword] = ACTIONS(4141),
  },
  [STATE(2223)] = {
    [sym_else_keyword] = STATE(571),
    [sym_identifier] = ACTIONS(4131),
    [anon_sym_SEMI] = ACTIONS(4133),
    [anon_sym_DASH] = ACTIONS(4133),
    [aux_sym_boolean_token1] = ACTIONS(4131),
    [aux_sym_boolean_token2] = ACTIONS(4131),
    [sym_decimal] = ACTIONS(4131),
    [anon_sym_LPAREN] = ACTIONS(4133),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4131),
    [anon_sym_LBRACK] = ACTIONS(4133),
    [aux_sym_record_type_token1] = ACTIONS(4131),
    [aux_sym_basic_type_token21] = ACTIONS(4131),
    [aux_sym_basic_type_token22] = ACTIONS(4131),
    [aux_sym_basic_type_token48] = ACTIONS(4131),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4131),
    [anon_sym_POUNDif] = ACTIONS(4133),
    [anon_sym_POUNDIF] = ACTIONS(4133),
    [anon_sym_POUNDIf] = ACTIONS(4133),
    [anon_sym_not] = ACTIONS(4131),
    [anon_sym_NOT] = ACTIONS(4131),
    [anon_sym_Not] = ACTIONS(4131),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4131),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4131),
    [anon_sym_PLUS] = ACTIONS(4133),
    [sym_datetime_literal] = ACTIONS(4133),
    [sym_date_literal] = ACTIONS(4131),
    [sym_time_literal] = ACTIONS(4131),
    [sym_biginteger_literal] = ACTIONS(4133),
    [anon_sym_if] = ACTIONS(4131),
    [anon_sym_IF] = ACTIONS(4131),
    [anon_sym_If] = ACTIONS(4131),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4131),
    [anon_sym_CASE] = ACTIONS(4131),
    [anon_sym_Case] = ACTIONS(4131),
    [anon_sym_for] = ACTIONS(4131),
    [anon_sym_FOR] = ACTIONS(4131),
    [anon_sym_For] = ACTIONS(4131),
    [anon_sym_foreach] = ACTIONS(4131),
    [anon_sym_FOREACH] = ACTIONS(4131),
    [anon_sym_Foreach] = ACTIONS(4131),
    [anon_sym_while] = ACTIONS(4131),
    [anon_sym_WHILE] = ACTIONS(4131),
    [anon_sym_While] = ACTIONS(4131),
    [anon_sym_repeat] = ACTIONS(4131),
    [anon_sym_REPEAT] = ACTIONS(4131),
    [anon_sym_Repeat] = ACTIONS(4131),
    [anon_sym_exit] = ACTIONS(4131),
    [anon_sym_EXIT] = ACTIONS(4131),
    [anon_sym_Exit] = ACTIONS(4131),
    [anon_sym_continue] = ACTIONS(4131),
    [anon_sym_CONTINUE] = ACTIONS(4131),
    [anon_sym_Continue] = ACTIONS(4131),
    [anon_sym_break] = ACTIONS(4131),
    [anon_sym_BREAK] = ACTIONS(4131),
    [anon_sym_Break] = ACTIONS(4131),
    [anon_sym_with] = ACTIONS(4131),
    [anon_sym_WITH] = ACTIONS(4131),
    [anon_sym_With] = ACTIONS(4131),
    [sym_asserterror_keyword] = ACTIONS(4133),
    [sym_page_keyword] = ACTIONS(4131),
    [anon_sym_codeunit] = ACTIONS(4131),
    [anon_sym_CODEUNIT] = ACTIONS(4131),
    [anon_sym_Codeunit] = ACTIONS(4131),
    [anon_sym_CodeUnit] = ACTIONS(4131),
    [anon_sym_COdeunit] = ACTIONS(4131),
    [anon_sym_codeUnit] = ACTIONS(4131),
    [sym_report_keyword] = ACTIONS(4131),
    [sym_query_keyword] = ACTIONS(4131),
    [anon_sym_xmlport] = ACTIONS(4131),
    [anon_sym_XMLPORT] = ACTIONS(4131),
    [anon_sym_Xmlport] = ACTIONS(4131),
    [anon_sym_XMLport] = ACTIONS(4131),
    [anon_sym_XMLPort] = ACTIONS(4131),
    [anon_sym_XmlPort] = ACTIONS(4131),
    [anon_sym_enum] = ACTIONS(4131),
    [anon_sym_ENUM] = ACTIONS(4131),
    [anon_sym_Enum] = ACTIONS(4131),
    [anon_sym_eNUM] = ACTIONS(4131),
    [anon_sym_eNum] = ACTIONS(4131),
    [anon_sym_ENum] = ACTIONS(4131),
    [sym_quoted_identifier] = ACTIONS(4133),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4133),
    [sym_integer] = ACTIONS(4131),
    [sym_continue_as_identifier] = ACTIONS(4133),
    [sym_preproc_open] = ACTIONS(4133),
    [sym_end_keyword] = ACTIONS(4133),
  },
  [STATE(2224)] = {
    [sym_else_keyword] = STATE(554),
    [sym_identifier] = ACTIONS(4161),
    [anon_sym_SEMI] = ACTIONS(4163),
    [anon_sym_DASH] = ACTIONS(4163),
    [aux_sym_boolean_token1] = ACTIONS(4161),
    [aux_sym_boolean_token2] = ACTIONS(4161),
    [sym_decimal] = ACTIONS(4161),
    [anon_sym_LPAREN] = ACTIONS(4163),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4161),
    [anon_sym_LBRACK] = ACTIONS(4163),
    [aux_sym_record_type_token1] = ACTIONS(4161),
    [aux_sym_basic_type_token21] = ACTIONS(4161),
    [aux_sym_basic_type_token22] = ACTIONS(4161),
    [aux_sym_basic_type_token48] = ACTIONS(4161),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4161),
    [anon_sym_POUNDif] = ACTIONS(4163),
    [anon_sym_POUNDIF] = ACTIONS(4163),
    [anon_sym_POUNDIf] = ACTIONS(4163),
    [anon_sym_not] = ACTIONS(4161),
    [anon_sym_NOT] = ACTIONS(4161),
    [anon_sym_Not] = ACTIONS(4161),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4161),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4161),
    [anon_sym_PLUS] = ACTIONS(4163),
    [sym_datetime_literal] = ACTIONS(4163),
    [sym_date_literal] = ACTIONS(4161),
    [sym_time_literal] = ACTIONS(4161),
    [sym_biginteger_literal] = ACTIONS(4163),
    [anon_sym_if] = ACTIONS(4161),
    [anon_sym_IF] = ACTIONS(4161),
    [anon_sym_If] = ACTIONS(4161),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4161),
    [anon_sym_CASE] = ACTIONS(4161),
    [anon_sym_Case] = ACTIONS(4161),
    [anon_sym_for] = ACTIONS(4161),
    [anon_sym_FOR] = ACTIONS(4161),
    [anon_sym_For] = ACTIONS(4161),
    [anon_sym_foreach] = ACTIONS(4161),
    [anon_sym_FOREACH] = ACTIONS(4161),
    [anon_sym_Foreach] = ACTIONS(4161),
    [anon_sym_while] = ACTIONS(4161),
    [anon_sym_WHILE] = ACTIONS(4161),
    [anon_sym_While] = ACTIONS(4161),
    [anon_sym_repeat] = ACTIONS(4161),
    [anon_sym_REPEAT] = ACTIONS(4161),
    [anon_sym_Repeat] = ACTIONS(4161),
    [anon_sym_exit] = ACTIONS(4161),
    [anon_sym_EXIT] = ACTIONS(4161),
    [anon_sym_Exit] = ACTIONS(4161),
    [anon_sym_continue] = ACTIONS(4161),
    [anon_sym_CONTINUE] = ACTIONS(4161),
    [anon_sym_Continue] = ACTIONS(4161),
    [anon_sym_break] = ACTIONS(4161),
    [anon_sym_BREAK] = ACTIONS(4161),
    [anon_sym_Break] = ACTIONS(4161),
    [anon_sym_with] = ACTIONS(4161),
    [anon_sym_WITH] = ACTIONS(4161),
    [anon_sym_With] = ACTIONS(4161),
    [sym_asserterror_keyword] = ACTIONS(4163),
    [sym_page_keyword] = ACTIONS(4161),
    [anon_sym_codeunit] = ACTIONS(4161),
    [anon_sym_CODEUNIT] = ACTIONS(4161),
    [anon_sym_Codeunit] = ACTIONS(4161),
    [anon_sym_CodeUnit] = ACTIONS(4161),
    [anon_sym_COdeunit] = ACTIONS(4161),
    [anon_sym_codeUnit] = ACTIONS(4161),
    [sym_report_keyword] = ACTIONS(4161),
    [sym_query_keyword] = ACTIONS(4161),
    [anon_sym_xmlport] = ACTIONS(4161),
    [anon_sym_XMLPORT] = ACTIONS(4161),
    [anon_sym_Xmlport] = ACTIONS(4161),
    [anon_sym_XMLport] = ACTIONS(4161),
    [anon_sym_XMLPort] = ACTIONS(4161),
    [anon_sym_XmlPort] = ACTIONS(4161),
    [anon_sym_enum] = ACTIONS(4161),
    [anon_sym_ENUM] = ACTIONS(4161),
    [anon_sym_Enum] = ACTIONS(4161),
    [anon_sym_eNUM] = ACTIONS(4161),
    [anon_sym_eNum] = ACTIONS(4161),
    [anon_sym_ENum] = ACTIONS(4161),
    [sym_quoted_identifier] = ACTIONS(4163),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4163),
    [sym_integer] = ACTIONS(4161),
    [sym_continue_as_identifier] = ACTIONS(4163),
    [sym_preproc_open] = ACTIONS(4163),
    [sym_end_keyword] = ACTIONS(4163),
  },
  [STATE(2225)] = {
    [sym_else_keyword] = STATE(555),
    [sym_identifier] = ACTIONS(4165),
    [anon_sym_SEMI] = ACTIONS(4167),
    [anon_sym_DASH] = ACTIONS(4167),
    [aux_sym_boolean_token1] = ACTIONS(4165),
    [aux_sym_boolean_token2] = ACTIONS(4165),
    [sym_decimal] = ACTIONS(4165),
    [anon_sym_LPAREN] = ACTIONS(4167),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4165),
    [anon_sym_LBRACK] = ACTIONS(4167),
    [aux_sym_record_type_token1] = ACTIONS(4165),
    [aux_sym_basic_type_token21] = ACTIONS(4165),
    [aux_sym_basic_type_token22] = ACTIONS(4165),
    [aux_sym_basic_type_token48] = ACTIONS(4165),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4165),
    [anon_sym_POUNDif] = ACTIONS(4167),
    [anon_sym_POUNDIF] = ACTIONS(4167),
    [anon_sym_POUNDIf] = ACTIONS(4167),
    [anon_sym_not] = ACTIONS(4165),
    [anon_sym_NOT] = ACTIONS(4165),
    [anon_sym_Not] = ACTIONS(4165),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4165),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4165),
    [anon_sym_PLUS] = ACTIONS(4167),
    [sym_datetime_literal] = ACTIONS(4167),
    [sym_date_literal] = ACTIONS(4165),
    [sym_time_literal] = ACTIONS(4165),
    [sym_biginteger_literal] = ACTIONS(4167),
    [anon_sym_if] = ACTIONS(4165),
    [anon_sym_IF] = ACTIONS(4165),
    [anon_sym_If] = ACTIONS(4165),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4165),
    [anon_sym_CASE] = ACTIONS(4165),
    [anon_sym_Case] = ACTIONS(4165),
    [anon_sym_for] = ACTIONS(4165),
    [anon_sym_FOR] = ACTIONS(4165),
    [anon_sym_For] = ACTIONS(4165),
    [anon_sym_foreach] = ACTIONS(4165),
    [anon_sym_FOREACH] = ACTIONS(4165),
    [anon_sym_Foreach] = ACTIONS(4165),
    [anon_sym_while] = ACTIONS(4165),
    [anon_sym_WHILE] = ACTIONS(4165),
    [anon_sym_While] = ACTIONS(4165),
    [anon_sym_repeat] = ACTIONS(4165),
    [anon_sym_REPEAT] = ACTIONS(4165),
    [anon_sym_Repeat] = ACTIONS(4165),
    [anon_sym_exit] = ACTIONS(4165),
    [anon_sym_EXIT] = ACTIONS(4165),
    [anon_sym_Exit] = ACTIONS(4165),
    [anon_sym_continue] = ACTIONS(4165),
    [anon_sym_CONTINUE] = ACTIONS(4165),
    [anon_sym_Continue] = ACTIONS(4165),
    [anon_sym_break] = ACTIONS(4165),
    [anon_sym_BREAK] = ACTIONS(4165),
    [anon_sym_Break] = ACTIONS(4165),
    [anon_sym_with] = ACTIONS(4165),
    [anon_sym_WITH] = ACTIONS(4165),
    [anon_sym_With] = ACTIONS(4165),
    [sym_asserterror_keyword] = ACTIONS(4167),
    [sym_page_keyword] = ACTIONS(4165),
    [anon_sym_codeunit] = ACTIONS(4165),
    [anon_sym_CODEUNIT] = ACTIONS(4165),
    [anon_sym_Codeunit] = ACTIONS(4165),
    [anon_sym_CodeUnit] = ACTIONS(4165),
    [anon_sym_COdeunit] = ACTIONS(4165),
    [anon_sym_codeUnit] = ACTIONS(4165),
    [sym_report_keyword] = ACTIONS(4165),
    [sym_query_keyword] = ACTIONS(4165),
    [anon_sym_xmlport] = ACTIONS(4165),
    [anon_sym_XMLPORT] = ACTIONS(4165),
    [anon_sym_Xmlport] = ACTIONS(4165),
    [anon_sym_XMLport] = ACTIONS(4165),
    [anon_sym_XMLPort] = ACTIONS(4165),
    [anon_sym_XmlPort] = ACTIONS(4165),
    [anon_sym_enum] = ACTIONS(4165),
    [anon_sym_ENUM] = ACTIONS(4165),
    [anon_sym_Enum] = ACTIONS(4165),
    [anon_sym_eNUM] = ACTIONS(4165),
    [anon_sym_eNum] = ACTIONS(4165),
    [anon_sym_ENum] = ACTIONS(4165),
    [sym_quoted_identifier] = ACTIONS(4167),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4167),
    [sym_integer] = ACTIONS(4165),
    [sym_continue_as_identifier] = ACTIONS(4167),
    [sym_preproc_open] = ACTIONS(4167),
    [sym_end_keyword] = ACTIONS(4167),
  },
  [STATE(2226)] = {
    [sym_identifier] = ACTIONS(4135),
    [anon_sym_SEMI] = ACTIONS(4137),
    [anon_sym_DASH] = ACTIONS(4137),
    [aux_sym_boolean_token1] = ACTIONS(4135),
    [aux_sym_boolean_token2] = ACTIONS(4135),
    [sym_decimal] = ACTIONS(4135),
    [anon_sym_LPAREN] = ACTIONS(4135),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4135),
    [anon_sym_LBRACK] = ACTIONS(4137),
    [aux_sym_record_type_token1] = ACTIONS(4135),
    [aux_sym_basic_type_token21] = ACTIONS(4135),
    [aux_sym_basic_type_token22] = ACTIONS(4135),
    [aux_sym_basic_type_token48] = ACTIONS(4135),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4135),
    [anon_sym_POUNDif] = ACTIONS(4137),
    [anon_sym_POUNDIF] = ACTIONS(4137),
    [anon_sym_POUNDIf] = ACTIONS(4137),
    [anon_sym_not] = ACTIONS(4135),
    [anon_sym_NOT] = ACTIONS(4135),
    [anon_sym_Not] = ACTIONS(4135),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_LPAREN2] = ACTIONS(4137),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4135),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [sym_datetime_literal] = ACTIONS(4137),
    [sym_date_literal] = ACTIONS(4135),
    [sym_time_literal] = ACTIONS(4135),
    [sym_biginteger_literal] = ACTIONS(4137),
    [anon_sym_if] = ACTIONS(4135),
    [anon_sym_IF] = ACTIONS(4135),
    [anon_sym_If] = ACTIONS(4135),
    [anon_sym_else] = ACTIONS(4135),
    [anon_sym_ELSE] = ACTIONS(4135),
    [anon_sym_Else] = ACTIONS(4135),
    [anon_sym_case] = ACTIONS(4135),
    [anon_sym_CASE] = ACTIONS(4135),
    [anon_sym_Case] = ACTIONS(4135),
    [anon_sym_for] = ACTIONS(4135),
    [anon_sym_FOR] = ACTIONS(4135),
    [anon_sym_For] = ACTIONS(4135),
    [anon_sym_foreach] = ACTIONS(4135),
    [anon_sym_FOREACH] = ACTIONS(4135),
    [anon_sym_Foreach] = ACTIONS(4135),
    [anon_sym_while] = ACTIONS(4135),
    [anon_sym_WHILE] = ACTIONS(4135),
    [anon_sym_While] = ACTIONS(4135),
    [anon_sym_repeat] = ACTIONS(4135),
    [anon_sym_REPEAT] = ACTIONS(4135),
    [anon_sym_Repeat] = ACTIONS(4135),
    [anon_sym_exit] = ACTIONS(4135),
    [anon_sym_EXIT] = ACTIONS(4135),
    [anon_sym_Exit] = ACTIONS(4135),
    [anon_sym_continue] = ACTIONS(4135),
    [anon_sym_CONTINUE] = ACTIONS(4135),
    [anon_sym_Continue] = ACTIONS(4135),
    [anon_sym_break] = ACTIONS(4135),
    [anon_sym_BREAK] = ACTIONS(4135),
    [anon_sym_Break] = ACTIONS(4135),
    [anon_sym_with] = ACTIONS(4135),
    [anon_sym_WITH] = ACTIONS(4135),
    [anon_sym_With] = ACTIONS(4135),
    [sym_asserterror_keyword] = ACTIONS(4137),
    [sym_page_keyword] = ACTIONS(4135),
    [anon_sym_codeunit] = ACTIONS(4135),
    [anon_sym_CODEUNIT] = ACTIONS(4135),
    [anon_sym_Codeunit] = ACTIONS(4135),
    [anon_sym_CodeUnit] = ACTIONS(4135),
    [anon_sym_COdeunit] = ACTIONS(4135),
    [anon_sym_codeUnit] = ACTIONS(4135),
    [sym_report_keyword] = ACTIONS(4135),
    [sym_query_keyword] = ACTIONS(4135),
    [anon_sym_xmlport] = ACTIONS(4135),
    [anon_sym_XMLPORT] = ACTIONS(4135),
    [anon_sym_Xmlport] = ACTIONS(4135),
    [anon_sym_XMLport] = ACTIONS(4135),
    [anon_sym_XMLPort] = ACTIONS(4135),
    [anon_sym_XmlPort] = ACTIONS(4135),
    [anon_sym_enum] = ACTIONS(4135),
    [anon_sym_ENUM] = ACTIONS(4135),
    [anon_sym_Enum] = ACTIONS(4135),
    [anon_sym_eNUM] = ACTIONS(4135),
    [anon_sym_eNum] = ACTIONS(4135),
    [anon_sym_ENum] = ACTIONS(4135),
    [sym_quoted_identifier] = ACTIONS(4137),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4137),
    [sym_integer] = ACTIONS(4135),
    [sym_continue_as_identifier] = ACTIONS(4137),
    [sym_preproc_open] = ACTIONS(4137),
    [sym_end_keyword] = ACTIONS(4137),
  },
  [STATE(2227)] = {
    [sym_else_keyword] = STATE(484),
    [sym_identifier] = ACTIONS(4157),
    [anon_sym_SEMI] = ACTIONS(4159),
    [anon_sym_DASH] = ACTIONS(4159),
    [aux_sym_boolean_token1] = ACTIONS(4157),
    [aux_sym_boolean_token2] = ACTIONS(4157),
    [sym_decimal] = ACTIONS(4157),
    [anon_sym_LPAREN] = ACTIONS(4159),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4157),
    [anon_sym_LBRACK] = ACTIONS(4159),
    [aux_sym_record_type_token1] = ACTIONS(4157),
    [aux_sym_basic_type_token21] = ACTIONS(4157),
    [aux_sym_basic_type_token22] = ACTIONS(4157),
    [aux_sym_basic_type_token48] = ACTIONS(4157),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4157),
    [anon_sym_POUNDif] = ACTIONS(4159),
    [anon_sym_POUNDIF] = ACTIONS(4159),
    [anon_sym_POUNDIf] = ACTIONS(4159),
    [anon_sym_not] = ACTIONS(4157),
    [anon_sym_NOT] = ACTIONS(4157),
    [anon_sym_Not] = ACTIONS(4157),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4157),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4157),
    [anon_sym_PLUS] = ACTIONS(4159),
    [sym_datetime_literal] = ACTIONS(4159),
    [sym_date_literal] = ACTIONS(4157),
    [sym_time_literal] = ACTIONS(4157),
    [sym_biginteger_literal] = ACTIONS(4159),
    [anon_sym_if] = ACTIONS(4157),
    [anon_sym_IF] = ACTIONS(4157),
    [anon_sym_If] = ACTIONS(4157),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4157),
    [anon_sym_CASE] = ACTIONS(4157),
    [anon_sym_Case] = ACTIONS(4157),
    [anon_sym_for] = ACTIONS(4157),
    [anon_sym_FOR] = ACTIONS(4157),
    [anon_sym_For] = ACTIONS(4157),
    [anon_sym_foreach] = ACTIONS(4157),
    [anon_sym_FOREACH] = ACTIONS(4157),
    [anon_sym_Foreach] = ACTIONS(4157),
    [anon_sym_while] = ACTIONS(4157),
    [anon_sym_WHILE] = ACTIONS(4157),
    [anon_sym_While] = ACTIONS(4157),
    [anon_sym_repeat] = ACTIONS(4157),
    [anon_sym_REPEAT] = ACTIONS(4157),
    [anon_sym_Repeat] = ACTIONS(4157),
    [anon_sym_exit] = ACTIONS(4157),
    [anon_sym_EXIT] = ACTIONS(4157),
    [anon_sym_Exit] = ACTIONS(4157),
    [anon_sym_continue] = ACTIONS(4157),
    [anon_sym_CONTINUE] = ACTIONS(4157),
    [anon_sym_Continue] = ACTIONS(4157),
    [anon_sym_break] = ACTIONS(4157),
    [anon_sym_BREAK] = ACTIONS(4157),
    [anon_sym_Break] = ACTIONS(4157),
    [anon_sym_with] = ACTIONS(4157),
    [anon_sym_WITH] = ACTIONS(4157),
    [anon_sym_With] = ACTIONS(4157),
    [sym_asserterror_keyword] = ACTIONS(4159),
    [sym_page_keyword] = ACTIONS(4157),
    [anon_sym_codeunit] = ACTIONS(4157),
    [anon_sym_CODEUNIT] = ACTIONS(4157),
    [anon_sym_Codeunit] = ACTIONS(4157),
    [anon_sym_CodeUnit] = ACTIONS(4157),
    [anon_sym_COdeunit] = ACTIONS(4157),
    [anon_sym_codeUnit] = ACTIONS(4157),
    [sym_report_keyword] = ACTIONS(4157),
    [sym_query_keyword] = ACTIONS(4157),
    [anon_sym_xmlport] = ACTIONS(4157),
    [anon_sym_XMLPORT] = ACTIONS(4157),
    [anon_sym_Xmlport] = ACTIONS(4157),
    [anon_sym_XMLport] = ACTIONS(4157),
    [anon_sym_XMLPort] = ACTIONS(4157),
    [anon_sym_XmlPort] = ACTIONS(4157),
    [anon_sym_enum] = ACTIONS(4157),
    [anon_sym_ENUM] = ACTIONS(4157),
    [anon_sym_Enum] = ACTIONS(4157),
    [anon_sym_eNUM] = ACTIONS(4157),
    [anon_sym_eNum] = ACTIONS(4157),
    [anon_sym_ENum] = ACTIONS(4157),
    [sym_quoted_identifier] = ACTIONS(4159),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4159),
    [sym_integer] = ACTIONS(4157),
    [sym_continue_as_identifier] = ACTIONS(4159),
    [sym_preproc_open] = ACTIONS(4159),
    [sym_end_keyword] = ACTIONS(4159),
  },
  [STATE(2228)] = {
    [sym_else_keyword] = STATE(237),
    [sym_identifier] = ACTIONS(4149),
    [anon_sym_SEMI] = ACTIONS(4151),
    [anon_sym_DASH] = ACTIONS(4151),
    [aux_sym_boolean_token1] = ACTIONS(4149),
    [aux_sym_boolean_token2] = ACTIONS(4149),
    [sym_decimal] = ACTIONS(4149),
    [anon_sym_LPAREN] = ACTIONS(4151),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4149),
    [anon_sym_LBRACK] = ACTIONS(4151),
    [aux_sym_record_type_token1] = ACTIONS(4149),
    [aux_sym_basic_type_token21] = ACTIONS(4149),
    [aux_sym_basic_type_token22] = ACTIONS(4149),
    [aux_sym_basic_type_token48] = ACTIONS(4149),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4149),
    [anon_sym_POUNDif] = ACTIONS(4151),
    [anon_sym_POUNDIF] = ACTIONS(4151),
    [anon_sym_POUNDIf] = ACTIONS(4151),
    [anon_sym_not] = ACTIONS(4149),
    [anon_sym_NOT] = ACTIONS(4149),
    [anon_sym_Not] = ACTIONS(4149),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4149),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4149),
    [anon_sym_PLUS] = ACTIONS(4151),
    [sym_datetime_literal] = ACTIONS(4151),
    [sym_date_literal] = ACTIONS(4149),
    [sym_time_literal] = ACTIONS(4149),
    [sym_biginteger_literal] = ACTIONS(4151),
    [anon_sym_if] = ACTIONS(4149),
    [anon_sym_IF] = ACTIONS(4149),
    [anon_sym_If] = ACTIONS(4149),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4149),
    [anon_sym_CASE] = ACTIONS(4149),
    [anon_sym_Case] = ACTIONS(4149),
    [anon_sym_for] = ACTIONS(4149),
    [anon_sym_FOR] = ACTIONS(4149),
    [anon_sym_For] = ACTIONS(4149),
    [anon_sym_foreach] = ACTIONS(4149),
    [anon_sym_FOREACH] = ACTIONS(4149),
    [anon_sym_Foreach] = ACTIONS(4149),
    [anon_sym_while] = ACTIONS(4149),
    [anon_sym_WHILE] = ACTIONS(4149),
    [anon_sym_While] = ACTIONS(4149),
    [anon_sym_repeat] = ACTIONS(4149),
    [anon_sym_REPEAT] = ACTIONS(4149),
    [anon_sym_Repeat] = ACTIONS(4149),
    [anon_sym_exit] = ACTIONS(4149),
    [anon_sym_EXIT] = ACTIONS(4149),
    [anon_sym_Exit] = ACTIONS(4149),
    [anon_sym_continue] = ACTIONS(4149),
    [anon_sym_CONTINUE] = ACTIONS(4149),
    [anon_sym_Continue] = ACTIONS(4149),
    [anon_sym_break] = ACTIONS(4149),
    [anon_sym_BREAK] = ACTIONS(4149),
    [anon_sym_Break] = ACTIONS(4149),
    [anon_sym_with] = ACTIONS(4149),
    [anon_sym_WITH] = ACTIONS(4149),
    [anon_sym_With] = ACTIONS(4149),
    [sym_asserterror_keyword] = ACTIONS(4151),
    [sym_page_keyword] = ACTIONS(4149),
    [anon_sym_codeunit] = ACTIONS(4149),
    [anon_sym_CODEUNIT] = ACTIONS(4149),
    [anon_sym_Codeunit] = ACTIONS(4149),
    [anon_sym_CodeUnit] = ACTIONS(4149),
    [anon_sym_COdeunit] = ACTIONS(4149),
    [anon_sym_codeUnit] = ACTIONS(4149),
    [sym_report_keyword] = ACTIONS(4149),
    [sym_query_keyword] = ACTIONS(4149),
    [anon_sym_xmlport] = ACTIONS(4149),
    [anon_sym_XMLPORT] = ACTIONS(4149),
    [anon_sym_Xmlport] = ACTIONS(4149),
    [anon_sym_XMLport] = ACTIONS(4149),
    [anon_sym_XMLPort] = ACTIONS(4149),
    [anon_sym_XmlPort] = ACTIONS(4149),
    [anon_sym_enum] = ACTIONS(4149),
    [anon_sym_ENUM] = ACTIONS(4149),
    [anon_sym_Enum] = ACTIONS(4149),
    [anon_sym_eNUM] = ACTIONS(4149),
    [anon_sym_eNum] = ACTIONS(4149),
    [anon_sym_ENum] = ACTIONS(4149),
    [sym_quoted_identifier] = ACTIONS(4151),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4151),
    [sym_integer] = ACTIONS(4149),
    [sym_continue_as_identifier] = ACTIONS(4151),
    [sym_preproc_open] = ACTIONS(4151),
    [sym_end_keyword] = ACTIONS(4151),
  },
  [STATE(2229)] = {
    [sym_boolean] = STATE(5930),
    [sym_option_member] = STATE(5955),
    [sym_keyword_identifier] = STATE(5930),
    [sym_codeunit_keyword] = STATE(5973),
    [sym_xmlport_keyword] = STATE(5973),
    [sym_enum_keyword] = STATE(5973),
    [sym_keyword_as_identifier] = STATE(5930),
    [sym_identifier] = ACTIONS(5391),
    [anon_sym_SEMI] = ACTIONS(389),
    [anon_sym_COMMA] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(5395),
    [aux_sym_boolean_token1] = ACTIONS(5397),
    [aux_sym_boolean_token2] = ACTIONS(5397),
    [aux_sym_where_condition_token1] = ACTIONS(5399),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5401),
    [anon_sym_LBRACK] = ACTIONS(389),
    [aux_sym_record_type_token1] = ACTIONS(5401),
    [aux_sym_basic_type_token21] = ACTIONS(5401),
    [aux_sym_basic_type_token22] = ACTIONS(5403),
    [aux_sym_basic_type_token48] = ACTIONS(5401),
    [aux_sym_basic_type_token53] = ACTIONS(5399),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5465),
    [aux_sym_modify_modification_token1] = ACTIONS(391),
    [aux_sym_separator_action_token1] = ACTIONS(5399),
    [aux_sym_assembly_declaration_token1] = ACTIONS(391),
    [aux_sym_type_declaration_token1] = ACTIONS(5399),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(391),
    [anon_sym_POUNDif] = ACTIONS(389),
    [anon_sym_POUNDIF] = ACTIONS(389),
    [anon_sym_POUNDIf] = ACTIONS(389),
    [anon_sym_POUNDelif] = ACTIONS(389),
    [anon_sym_POUNDELIF] = ACTIONS(389),
    [anon_sym_POUNDElif] = ACTIONS(389),
    [anon_sym_POUNDelse] = ACTIONS(389),
    [anon_sym_POUNDELSE] = ACTIONS(389),
    [anon_sym_POUNDElse] = ACTIONS(389),
    [anon_sym_POUNDendif] = ACTIONS(389),
    [anon_sym_POUNDENDIF] = ACTIONS(389),
    [anon_sym_POUNDEndif] = ACTIONS(389),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5401),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5401),
    [sym_page_keyword] = ACTIONS(5401),
    [anon_sym_codeunit] = ACTIONS(5405),
    [anon_sym_CODEUNIT] = ACTIONS(5405),
    [anon_sym_Codeunit] = ACTIONS(5405),
    [anon_sym_CodeUnit] = ACTIONS(5405),
    [anon_sym_COdeunit] = ACTIONS(5405),
    [anon_sym_codeUnit] = ACTIONS(5405),
    [sym_report_keyword] = ACTIONS(5401),
    [sym_query_keyword] = ACTIONS(5401),
    [anon_sym_xmlport] = ACTIONS(5407),
    [anon_sym_XMLPORT] = ACTIONS(5407),
    [anon_sym_Xmlport] = ACTIONS(5407),
    [anon_sym_XMLport] = ACTIONS(5407),
    [anon_sym_XMLPort] = ACTIONS(5407),
    [anon_sym_XmlPort] = ACTIONS(5407),
    [anon_sym_enum] = ACTIONS(5409),
    [anon_sym_ENUM] = ACTIONS(5409),
    [anon_sym_Enum] = ACTIONS(5409),
    [anon_sym_eNUM] = ACTIONS(5409),
    [anon_sym_eNum] = ACTIONS(5409),
    [anon_sym_ENum] = ACTIONS(5409),
    [sym_procedure_keyword] = ACTIONS(391),
    [sym_trigger_keyword] = ACTIONS(391),
    [sym_var_keyword] = ACTIONS(391),
    [sym_local_keyword] = ACTIONS(5468),
    [sym_internal_keyword] = ACTIONS(5468),
    [sym_protected_keyword] = ACTIONS(5468),
    [sym_event_keyword] = ACTIONS(391),
    [sym_fields_keyword] = ACTIONS(391),
    [sym_keys_keyword] = ACTIONS(391),
    [sym_key_keyword] = ACTIONS(5399),
    [sym_fieldgroups_keyword] = ACTIONS(391),
    [sym_actions_keyword] = ACTIONS(391),
    [sym_layout_keyword] = ACTIONS(391),
    [sym_dataset_keyword] = ACTIONS(5465),
    [sym_elements_keyword] = ACTIONS(391),
    [sym_labels_keyword] = ACTIONS(391),
    [sym_rendering_keyword] = ACTIONS(391),
    [sym_requestpage_keyword] = ACTIONS(391),
    [sym_schema_keyword] = ACTIONS(391),
    [sym_views_keyword] = ACTIONS(391),
    [sym_quoted_identifier] = ACTIONS(5411),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5411),
    [sym_integer] = ACTIONS(5411),
    [sym_property_name] = ACTIONS(389),
    [sym_preproc_open] = ACTIONS(389),
    [sym_preproc_close] = ACTIONS(389),
    [sym_begin_keyword] = ACTIONS(389),
  },
  [STATE(2230)] = {
    [sym_else_keyword] = STATE(444),
    [sym_identifier] = ACTIONS(4145),
    [anon_sym_SEMI] = ACTIONS(4147),
    [anon_sym_DASH] = ACTIONS(4147),
    [aux_sym_boolean_token1] = ACTIONS(4145),
    [aux_sym_boolean_token2] = ACTIONS(4145),
    [sym_decimal] = ACTIONS(4145),
    [anon_sym_LPAREN] = ACTIONS(4147),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4145),
    [anon_sym_LBRACK] = ACTIONS(4147),
    [aux_sym_record_type_token1] = ACTIONS(4145),
    [aux_sym_basic_type_token21] = ACTIONS(4145),
    [aux_sym_basic_type_token22] = ACTIONS(4145),
    [aux_sym_basic_type_token48] = ACTIONS(4145),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4145),
    [anon_sym_POUNDif] = ACTIONS(4147),
    [anon_sym_POUNDIF] = ACTIONS(4147),
    [anon_sym_POUNDIf] = ACTIONS(4147),
    [anon_sym_not] = ACTIONS(4145),
    [anon_sym_NOT] = ACTIONS(4145),
    [anon_sym_Not] = ACTIONS(4145),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4145),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4145),
    [anon_sym_PLUS] = ACTIONS(4147),
    [sym_datetime_literal] = ACTIONS(4147),
    [sym_date_literal] = ACTIONS(4145),
    [sym_time_literal] = ACTIONS(4145),
    [sym_biginteger_literal] = ACTIONS(4147),
    [anon_sym_if] = ACTIONS(4145),
    [anon_sym_IF] = ACTIONS(4145),
    [anon_sym_If] = ACTIONS(4145),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [anon_sym_case] = ACTIONS(4145),
    [anon_sym_CASE] = ACTIONS(4145),
    [anon_sym_Case] = ACTIONS(4145),
    [anon_sym_for] = ACTIONS(4145),
    [anon_sym_FOR] = ACTIONS(4145),
    [anon_sym_For] = ACTIONS(4145),
    [anon_sym_foreach] = ACTIONS(4145),
    [anon_sym_FOREACH] = ACTIONS(4145),
    [anon_sym_Foreach] = ACTIONS(4145),
    [anon_sym_while] = ACTIONS(4145),
    [anon_sym_WHILE] = ACTIONS(4145),
    [anon_sym_While] = ACTIONS(4145),
    [anon_sym_repeat] = ACTIONS(4145),
    [anon_sym_REPEAT] = ACTIONS(4145),
    [anon_sym_Repeat] = ACTIONS(4145),
    [anon_sym_exit] = ACTIONS(4145),
    [anon_sym_EXIT] = ACTIONS(4145),
    [anon_sym_Exit] = ACTIONS(4145),
    [anon_sym_continue] = ACTIONS(4145),
    [anon_sym_CONTINUE] = ACTIONS(4145),
    [anon_sym_Continue] = ACTIONS(4145),
    [anon_sym_break] = ACTIONS(4145),
    [anon_sym_BREAK] = ACTIONS(4145),
    [anon_sym_Break] = ACTIONS(4145),
    [anon_sym_with] = ACTIONS(4145),
    [anon_sym_WITH] = ACTIONS(4145),
    [anon_sym_With] = ACTIONS(4145),
    [sym_asserterror_keyword] = ACTIONS(4147),
    [sym_page_keyword] = ACTIONS(4145),
    [anon_sym_codeunit] = ACTIONS(4145),
    [anon_sym_CODEUNIT] = ACTIONS(4145),
    [anon_sym_Codeunit] = ACTIONS(4145),
    [anon_sym_CodeUnit] = ACTIONS(4145),
    [anon_sym_COdeunit] = ACTIONS(4145),
    [anon_sym_codeUnit] = ACTIONS(4145),
    [sym_report_keyword] = ACTIONS(4145),
    [sym_query_keyword] = ACTIONS(4145),
    [anon_sym_xmlport] = ACTIONS(4145),
    [anon_sym_XMLPORT] = ACTIONS(4145),
    [anon_sym_Xmlport] = ACTIONS(4145),
    [anon_sym_XMLport] = ACTIONS(4145),
    [anon_sym_XMLPort] = ACTIONS(4145),
    [anon_sym_XmlPort] = ACTIONS(4145),
    [anon_sym_enum] = ACTIONS(4145),
    [anon_sym_ENUM] = ACTIONS(4145),
    [anon_sym_Enum] = ACTIONS(4145),
    [anon_sym_eNUM] = ACTIONS(4145),
    [anon_sym_eNum] = ACTIONS(4145),
    [anon_sym_ENum] = ACTIONS(4145),
    [sym_quoted_identifier] = ACTIONS(4147),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4147),
    [sym_integer] = ACTIONS(4145),
    [sym_continue_as_identifier] = ACTIONS(4147),
    [sym_preproc_open] = ACTIONS(4147),
    [sym_end_keyword] = ACTIONS(4147),
  },
  [STATE(2231)] = {
    [sym_boolean] = STATE(6346),
    [sym_preproc_conditional_table_relation] = STATE(8794),
    [sym_table_relation_expression] = STATE(8821),
    [sym_if_table_relation] = STATE(8794),
    [sym_simple_table_relation] = STATE(8794),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_preproc_if] = STATE(1387),
    [sym_assignment_expression] = STATE(6346),
    [sym__expression] = STATE(6346),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6346),
    [sym_multiplicative_expression] = STATE(6346),
    [sym_additive_expression] = STATE(6346),
    [sym_comparison_expression] = STATE(6346),
    [sym_logical_expression] = STATE(6346),
    [sym_ternary_expression] = STATE(6346),
    [sym_unary_expression] = STATE(6346),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6346),
    [sym_list_literal] = STATE(6346),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6346),
    [sym__literal_value] = STATE(6346),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7706),
    [sym_keyword_as_identifier] = STATE(7706),
    [sym_identifier] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(3058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_if_table_relation_token1] = ACTIONS(3062),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDif] = ACTIONS(2223),
    [anon_sym_POUNDIF] = ACTIONS(2223),
    [anon_sym_POUNDIf] = ACTIONS(2223),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(3078),
    [sym_date_literal] = ACTIONS(3058),
    [sym_time_literal] = ACTIONS(3058),
    [sym_biginteger_literal] = ACTIONS(3078),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(3441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3078),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(3078),
    [sym_preproc_open] = ACTIONS(2223),
  },
  [STATE(2232)] = {
    [sym_identifier] = ACTIONS(4435),
    [anon_sym_SEMI] = ACTIONS(4437),
    [anon_sym_DASH] = ACTIONS(4437),
    [aux_sym_boolean_token1] = ACTIONS(4435),
    [aux_sym_boolean_token2] = ACTIONS(4435),
    [sym_decimal] = ACTIONS(4435),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4435),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [aux_sym_record_type_token1] = ACTIONS(4435),
    [aux_sym_basic_type_token21] = ACTIONS(4435),
    [aux_sym_basic_type_token22] = ACTIONS(4435),
    [aux_sym_basic_type_token48] = ACTIONS(4435),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4435),
    [anon_sym_POUNDif] = ACTIONS(4437),
    [anon_sym_POUNDIF] = ACTIONS(4437),
    [anon_sym_POUNDIf] = ACTIONS(4437),
    [anon_sym_not] = ACTIONS(4435),
    [anon_sym_NOT] = ACTIONS(4435),
    [anon_sym_Not] = ACTIONS(4435),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4435),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4435),
    [anon_sym_PLUS] = ACTIONS(4437),
    [sym_datetime_literal] = ACTIONS(4437),
    [sym_date_literal] = ACTIONS(4435),
    [sym_time_literal] = ACTIONS(4435),
    [sym_biginteger_literal] = ACTIONS(4437),
    [anon_sym_if] = ACTIONS(4435),
    [anon_sym_IF] = ACTIONS(4435),
    [anon_sym_If] = ACTIONS(4435),
    [anon_sym_else] = ACTIONS(4435),
    [anon_sym_ELSE] = ACTIONS(4435),
    [anon_sym_Else] = ACTIONS(4435),
    [anon_sym_case] = ACTIONS(4435),
    [anon_sym_CASE] = ACTIONS(4435),
    [anon_sym_Case] = ACTIONS(4435),
    [anon_sym_for] = ACTIONS(4435),
    [anon_sym_FOR] = ACTIONS(4435),
    [anon_sym_For] = ACTIONS(4435),
    [anon_sym_foreach] = ACTIONS(4435),
    [anon_sym_FOREACH] = ACTIONS(4435),
    [anon_sym_Foreach] = ACTIONS(4435),
    [anon_sym_while] = ACTIONS(4435),
    [anon_sym_WHILE] = ACTIONS(4435),
    [anon_sym_While] = ACTIONS(4435),
    [anon_sym_repeat] = ACTIONS(4435),
    [anon_sym_REPEAT] = ACTIONS(4435),
    [anon_sym_Repeat] = ACTIONS(4435),
    [anon_sym_exit] = ACTIONS(4435),
    [anon_sym_EXIT] = ACTIONS(4435),
    [anon_sym_Exit] = ACTIONS(4435),
    [anon_sym_continue] = ACTIONS(4435),
    [anon_sym_CONTINUE] = ACTIONS(4435),
    [anon_sym_Continue] = ACTIONS(4435),
    [anon_sym_break] = ACTIONS(4435),
    [anon_sym_BREAK] = ACTIONS(4435),
    [anon_sym_Break] = ACTIONS(4435),
    [anon_sym_with] = ACTIONS(4435),
    [anon_sym_WITH] = ACTIONS(4435),
    [anon_sym_With] = ACTIONS(4435),
    [sym_asserterror_keyword] = ACTIONS(4437),
    [sym_page_keyword] = ACTIONS(4435),
    [anon_sym_codeunit] = ACTIONS(4435),
    [anon_sym_CODEUNIT] = ACTIONS(4435),
    [anon_sym_Codeunit] = ACTIONS(4435),
    [anon_sym_CodeUnit] = ACTIONS(4435),
    [anon_sym_COdeunit] = ACTIONS(4435),
    [anon_sym_codeUnit] = ACTIONS(4435),
    [sym_report_keyword] = ACTIONS(4435),
    [sym_query_keyword] = ACTIONS(4435),
    [anon_sym_xmlport] = ACTIONS(4435),
    [anon_sym_XMLPORT] = ACTIONS(4435),
    [anon_sym_Xmlport] = ACTIONS(4435),
    [anon_sym_XMLport] = ACTIONS(4435),
    [anon_sym_XMLPort] = ACTIONS(4435),
    [anon_sym_XmlPort] = ACTIONS(4435),
    [anon_sym_enum] = ACTIONS(4435),
    [anon_sym_ENUM] = ACTIONS(4435),
    [anon_sym_Enum] = ACTIONS(4435),
    [anon_sym_eNUM] = ACTIONS(4435),
    [anon_sym_eNum] = ACTIONS(4435),
    [anon_sym_ENum] = ACTIONS(4435),
    [sym_quoted_identifier] = ACTIONS(4437),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4437),
    [sym_integer] = ACTIONS(4435),
    [sym_continue_as_identifier] = ACTIONS(4437),
    [sym_preproc_open] = ACTIONS(4437),
    [sym_end_keyword] = ACTIONS(4437),
  },
  [STATE(2233)] = {
    [sym_identifier] = ACTIONS(4403),
    [anon_sym_SEMI] = ACTIONS(4405),
    [anon_sym_DASH] = ACTIONS(4405),
    [aux_sym_boolean_token1] = ACTIONS(4403),
    [aux_sym_boolean_token2] = ACTIONS(4403),
    [sym_decimal] = ACTIONS(4403),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4403),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [aux_sym_record_type_token1] = ACTIONS(4403),
    [aux_sym_basic_type_token21] = ACTIONS(4403),
    [aux_sym_basic_type_token22] = ACTIONS(4403),
    [aux_sym_basic_type_token48] = ACTIONS(4403),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4403),
    [anon_sym_POUNDif] = ACTIONS(4405),
    [anon_sym_POUNDIF] = ACTIONS(4405),
    [anon_sym_POUNDIf] = ACTIONS(4405),
    [anon_sym_not] = ACTIONS(4403),
    [anon_sym_NOT] = ACTIONS(4403),
    [anon_sym_Not] = ACTIONS(4403),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4403),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4403),
    [anon_sym_PLUS] = ACTIONS(4405),
    [sym_datetime_literal] = ACTIONS(4405),
    [sym_date_literal] = ACTIONS(4403),
    [sym_time_literal] = ACTIONS(4403),
    [sym_biginteger_literal] = ACTIONS(4405),
    [anon_sym_if] = ACTIONS(4403),
    [anon_sym_IF] = ACTIONS(4403),
    [anon_sym_If] = ACTIONS(4403),
    [anon_sym_else] = ACTIONS(4403),
    [anon_sym_ELSE] = ACTIONS(4403),
    [anon_sym_Else] = ACTIONS(4403),
    [anon_sym_case] = ACTIONS(4403),
    [anon_sym_CASE] = ACTIONS(4403),
    [anon_sym_Case] = ACTIONS(4403),
    [anon_sym_for] = ACTIONS(4403),
    [anon_sym_FOR] = ACTIONS(4403),
    [anon_sym_For] = ACTIONS(4403),
    [anon_sym_foreach] = ACTIONS(4403),
    [anon_sym_FOREACH] = ACTIONS(4403),
    [anon_sym_Foreach] = ACTIONS(4403),
    [anon_sym_while] = ACTIONS(4403),
    [anon_sym_WHILE] = ACTIONS(4403),
    [anon_sym_While] = ACTIONS(4403),
    [anon_sym_repeat] = ACTIONS(4403),
    [anon_sym_REPEAT] = ACTIONS(4403),
    [anon_sym_Repeat] = ACTIONS(4403),
    [anon_sym_exit] = ACTIONS(4403),
    [anon_sym_EXIT] = ACTIONS(4403),
    [anon_sym_Exit] = ACTIONS(4403),
    [anon_sym_continue] = ACTIONS(4403),
    [anon_sym_CONTINUE] = ACTIONS(4403),
    [anon_sym_Continue] = ACTIONS(4403),
    [anon_sym_break] = ACTIONS(4403),
    [anon_sym_BREAK] = ACTIONS(4403),
    [anon_sym_Break] = ACTIONS(4403),
    [anon_sym_with] = ACTIONS(4403),
    [anon_sym_WITH] = ACTIONS(4403),
    [anon_sym_With] = ACTIONS(4403),
    [sym_asserterror_keyword] = ACTIONS(4405),
    [sym_page_keyword] = ACTIONS(4403),
    [anon_sym_codeunit] = ACTIONS(4403),
    [anon_sym_CODEUNIT] = ACTIONS(4403),
    [anon_sym_Codeunit] = ACTIONS(4403),
    [anon_sym_CodeUnit] = ACTIONS(4403),
    [anon_sym_COdeunit] = ACTIONS(4403),
    [anon_sym_codeUnit] = ACTIONS(4403),
    [sym_report_keyword] = ACTIONS(4403),
    [sym_query_keyword] = ACTIONS(4403),
    [anon_sym_xmlport] = ACTIONS(4403),
    [anon_sym_XMLPORT] = ACTIONS(4403),
    [anon_sym_Xmlport] = ACTIONS(4403),
    [anon_sym_XMLport] = ACTIONS(4403),
    [anon_sym_XMLPort] = ACTIONS(4403),
    [anon_sym_XmlPort] = ACTIONS(4403),
    [anon_sym_enum] = ACTIONS(4403),
    [anon_sym_ENUM] = ACTIONS(4403),
    [anon_sym_Enum] = ACTIONS(4403),
    [anon_sym_eNUM] = ACTIONS(4403),
    [anon_sym_eNum] = ACTIONS(4403),
    [anon_sym_ENum] = ACTIONS(4403),
    [sym_quoted_identifier] = ACTIONS(4405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4405),
    [sym_integer] = ACTIONS(4403),
    [sym_continue_as_identifier] = ACTIONS(4405),
    [sym_preproc_open] = ACTIONS(4405),
    [sym_end_keyword] = ACTIONS(4405),
  },
  [STATE(2234)] = {
    [sym_identifier] = ACTIONS(4776),
    [anon_sym_SEMI] = ACTIONS(4778),
    [anon_sym_DASH] = ACTIONS(4778),
    [aux_sym_boolean_token1] = ACTIONS(4776),
    [aux_sym_boolean_token2] = ACTIONS(4776),
    [sym_decimal] = ACTIONS(4776),
    [anon_sym_LPAREN] = ACTIONS(4778),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4776),
    [anon_sym_LBRACK] = ACTIONS(4778),
    [aux_sym_record_type_token1] = ACTIONS(4776),
    [aux_sym_basic_type_token21] = ACTIONS(4776),
    [aux_sym_basic_type_token22] = ACTIONS(4776),
    [aux_sym_basic_type_token48] = ACTIONS(4776),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4776),
    [anon_sym_POUNDif] = ACTIONS(4778),
    [anon_sym_POUNDIF] = ACTIONS(4778),
    [anon_sym_POUNDIf] = ACTIONS(4778),
    [anon_sym_not] = ACTIONS(4776),
    [anon_sym_NOT] = ACTIONS(4776),
    [anon_sym_Not] = ACTIONS(4776),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4776),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4776),
    [anon_sym_PLUS] = ACTIONS(4778),
    [sym_datetime_literal] = ACTIONS(4778),
    [sym_date_literal] = ACTIONS(4776),
    [sym_time_literal] = ACTIONS(4776),
    [sym_biginteger_literal] = ACTIONS(4778),
    [anon_sym_if] = ACTIONS(4776),
    [anon_sym_IF] = ACTIONS(4776),
    [anon_sym_If] = ACTIONS(4776),
    [anon_sym_else] = ACTIONS(4776),
    [anon_sym_ELSE] = ACTIONS(4776),
    [anon_sym_Else] = ACTIONS(4776),
    [anon_sym_case] = ACTIONS(4776),
    [anon_sym_CASE] = ACTIONS(4776),
    [anon_sym_Case] = ACTIONS(4776),
    [anon_sym_for] = ACTIONS(4776),
    [anon_sym_FOR] = ACTIONS(4776),
    [anon_sym_For] = ACTIONS(4776),
    [anon_sym_foreach] = ACTIONS(4776),
    [anon_sym_FOREACH] = ACTIONS(4776),
    [anon_sym_Foreach] = ACTIONS(4776),
    [anon_sym_while] = ACTIONS(4776),
    [anon_sym_WHILE] = ACTIONS(4776),
    [anon_sym_While] = ACTIONS(4776),
    [anon_sym_repeat] = ACTIONS(4776),
    [anon_sym_REPEAT] = ACTIONS(4776),
    [anon_sym_Repeat] = ACTIONS(4776),
    [anon_sym_exit] = ACTIONS(4776),
    [anon_sym_EXIT] = ACTIONS(4776),
    [anon_sym_Exit] = ACTIONS(4776),
    [anon_sym_continue] = ACTIONS(4776),
    [anon_sym_CONTINUE] = ACTIONS(4776),
    [anon_sym_Continue] = ACTIONS(4776),
    [anon_sym_break] = ACTIONS(4776),
    [anon_sym_BREAK] = ACTIONS(4776),
    [anon_sym_Break] = ACTIONS(4776),
    [anon_sym_with] = ACTIONS(4776),
    [anon_sym_WITH] = ACTIONS(4776),
    [anon_sym_With] = ACTIONS(4776),
    [sym_asserterror_keyword] = ACTIONS(4778),
    [sym_page_keyword] = ACTIONS(4776),
    [anon_sym_codeunit] = ACTIONS(4776),
    [anon_sym_CODEUNIT] = ACTIONS(4776),
    [anon_sym_Codeunit] = ACTIONS(4776),
    [anon_sym_CodeUnit] = ACTIONS(4776),
    [anon_sym_COdeunit] = ACTIONS(4776),
    [anon_sym_codeUnit] = ACTIONS(4776),
    [sym_report_keyword] = ACTIONS(4776),
    [sym_query_keyword] = ACTIONS(4776),
    [anon_sym_xmlport] = ACTIONS(4776),
    [anon_sym_XMLPORT] = ACTIONS(4776),
    [anon_sym_Xmlport] = ACTIONS(4776),
    [anon_sym_XMLport] = ACTIONS(4776),
    [anon_sym_XMLPort] = ACTIONS(4776),
    [anon_sym_XmlPort] = ACTIONS(4776),
    [anon_sym_enum] = ACTIONS(4776),
    [anon_sym_ENUM] = ACTIONS(4776),
    [anon_sym_Enum] = ACTIONS(4776),
    [anon_sym_eNUM] = ACTIONS(4776),
    [anon_sym_eNum] = ACTIONS(4776),
    [anon_sym_ENum] = ACTIONS(4776),
    [sym_quoted_identifier] = ACTIONS(4778),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4778),
    [sym_integer] = ACTIONS(4776),
    [sym_continue_as_identifier] = ACTIONS(4778),
    [sym_preproc_open] = ACTIONS(4778),
    [sym_end_keyword] = ACTIONS(4778),
  },
  [STATE(2235)] = {
    [sym_identifier] = ACTIONS(4788),
    [anon_sym_SEMI] = ACTIONS(4790),
    [anon_sym_DASH] = ACTIONS(4790),
    [aux_sym_boolean_token1] = ACTIONS(4788),
    [aux_sym_boolean_token2] = ACTIONS(4788),
    [sym_decimal] = ACTIONS(4788),
    [anon_sym_LPAREN] = ACTIONS(4790),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4788),
    [anon_sym_LBRACK] = ACTIONS(4790),
    [aux_sym_record_type_token1] = ACTIONS(4788),
    [aux_sym_basic_type_token21] = ACTIONS(4788),
    [aux_sym_basic_type_token22] = ACTIONS(4788),
    [aux_sym_basic_type_token48] = ACTIONS(4788),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4788),
    [anon_sym_POUNDif] = ACTIONS(4790),
    [anon_sym_POUNDIF] = ACTIONS(4790),
    [anon_sym_POUNDIf] = ACTIONS(4790),
    [anon_sym_not] = ACTIONS(4788),
    [anon_sym_NOT] = ACTIONS(4788),
    [anon_sym_Not] = ACTIONS(4788),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4788),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4788),
    [anon_sym_PLUS] = ACTIONS(4790),
    [sym_datetime_literal] = ACTIONS(4790),
    [sym_date_literal] = ACTIONS(4788),
    [sym_time_literal] = ACTIONS(4788),
    [sym_biginteger_literal] = ACTIONS(4790),
    [anon_sym_if] = ACTIONS(4788),
    [anon_sym_IF] = ACTIONS(4788),
    [anon_sym_If] = ACTIONS(4788),
    [anon_sym_else] = ACTIONS(4788),
    [anon_sym_ELSE] = ACTIONS(4788),
    [anon_sym_Else] = ACTIONS(4788),
    [anon_sym_case] = ACTIONS(4788),
    [anon_sym_CASE] = ACTIONS(4788),
    [anon_sym_Case] = ACTIONS(4788),
    [anon_sym_for] = ACTIONS(4788),
    [anon_sym_FOR] = ACTIONS(4788),
    [anon_sym_For] = ACTIONS(4788),
    [anon_sym_foreach] = ACTIONS(4788),
    [anon_sym_FOREACH] = ACTIONS(4788),
    [anon_sym_Foreach] = ACTIONS(4788),
    [anon_sym_while] = ACTIONS(4788),
    [anon_sym_WHILE] = ACTIONS(4788),
    [anon_sym_While] = ACTIONS(4788),
    [anon_sym_repeat] = ACTIONS(4788),
    [anon_sym_REPEAT] = ACTIONS(4788),
    [anon_sym_Repeat] = ACTIONS(4788),
    [anon_sym_exit] = ACTIONS(4788),
    [anon_sym_EXIT] = ACTIONS(4788),
    [anon_sym_Exit] = ACTIONS(4788),
    [anon_sym_continue] = ACTIONS(4788),
    [anon_sym_CONTINUE] = ACTIONS(4788),
    [anon_sym_Continue] = ACTIONS(4788),
    [anon_sym_break] = ACTIONS(4788),
    [anon_sym_BREAK] = ACTIONS(4788),
    [anon_sym_Break] = ACTIONS(4788),
    [anon_sym_with] = ACTIONS(4788),
    [anon_sym_WITH] = ACTIONS(4788),
    [anon_sym_With] = ACTIONS(4788),
    [sym_asserterror_keyword] = ACTIONS(4790),
    [sym_page_keyword] = ACTIONS(4788),
    [anon_sym_codeunit] = ACTIONS(4788),
    [anon_sym_CODEUNIT] = ACTIONS(4788),
    [anon_sym_Codeunit] = ACTIONS(4788),
    [anon_sym_CodeUnit] = ACTIONS(4788),
    [anon_sym_COdeunit] = ACTIONS(4788),
    [anon_sym_codeUnit] = ACTIONS(4788),
    [sym_report_keyword] = ACTIONS(4788),
    [sym_query_keyword] = ACTIONS(4788),
    [anon_sym_xmlport] = ACTIONS(4788),
    [anon_sym_XMLPORT] = ACTIONS(4788),
    [anon_sym_Xmlport] = ACTIONS(4788),
    [anon_sym_XMLport] = ACTIONS(4788),
    [anon_sym_XMLPort] = ACTIONS(4788),
    [anon_sym_XmlPort] = ACTIONS(4788),
    [anon_sym_enum] = ACTIONS(4788),
    [anon_sym_ENUM] = ACTIONS(4788),
    [anon_sym_Enum] = ACTIONS(4788),
    [anon_sym_eNUM] = ACTIONS(4788),
    [anon_sym_eNum] = ACTIONS(4788),
    [anon_sym_ENum] = ACTIONS(4788),
    [sym_quoted_identifier] = ACTIONS(4790),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4790),
    [sym_integer] = ACTIONS(4788),
    [sym_continue_as_identifier] = ACTIONS(4790),
    [sym_preproc_open] = ACTIONS(4790),
    [sym_end_keyword] = ACTIONS(4790),
  },
  [STATE(2236)] = {
    [sym_identifier] = ACTIONS(4792),
    [anon_sym_SEMI] = ACTIONS(4794),
    [anon_sym_DASH] = ACTIONS(4794),
    [aux_sym_boolean_token1] = ACTIONS(4792),
    [aux_sym_boolean_token2] = ACTIONS(4792),
    [sym_decimal] = ACTIONS(4792),
    [anon_sym_LPAREN] = ACTIONS(4794),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4792),
    [anon_sym_LBRACK] = ACTIONS(4794),
    [aux_sym_record_type_token1] = ACTIONS(4792),
    [aux_sym_basic_type_token21] = ACTIONS(4792),
    [aux_sym_basic_type_token22] = ACTIONS(4792),
    [aux_sym_basic_type_token48] = ACTIONS(4792),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4792),
    [anon_sym_POUNDif] = ACTIONS(4794),
    [anon_sym_POUNDIF] = ACTIONS(4794),
    [anon_sym_POUNDIf] = ACTIONS(4794),
    [anon_sym_not] = ACTIONS(4792),
    [anon_sym_NOT] = ACTIONS(4792),
    [anon_sym_Not] = ACTIONS(4792),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4792),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4792),
    [anon_sym_PLUS] = ACTIONS(4794),
    [sym_datetime_literal] = ACTIONS(4794),
    [sym_date_literal] = ACTIONS(4792),
    [sym_time_literal] = ACTIONS(4792),
    [sym_biginteger_literal] = ACTIONS(4794),
    [anon_sym_if] = ACTIONS(4792),
    [anon_sym_IF] = ACTIONS(4792),
    [anon_sym_If] = ACTIONS(4792),
    [anon_sym_else] = ACTIONS(4792),
    [anon_sym_ELSE] = ACTIONS(4792),
    [anon_sym_Else] = ACTIONS(4792),
    [anon_sym_case] = ACTIONS(4792),
    [anon_sym_CASE] = ACTIONS(4792),
    [anon_sym_Case] = ACTIONS(4792),
    [anon_sym_for] = ACTIONS(4792),
    [anon_sym_FOR] = ACTIONS(4792),
    [anon_sym_For] = ACTIONS(4792),
    [anon_sym_foreach] = ACTIONS(4792),
    [anon_sym_FOREACH] = ACTIONS(4792),
    [anon_sym_Foreach] = ACTIONS(4792),
    [anon_sym_while] = ACTIONS(4792),
    [anon_sym_WHILE] = ACTIONS(4792),
    [anon_sym_While] = ACTIONS(4792),
    [anon_sym_repeat] = ACTIONS(4792),
    [anon_sym_REPEAT] = ACTIONS(4792),
    [anon_sym_Repeat] = ACTIONS(4792),
    [anon_sym_exit] = ACTIONS(4792),
    [anon_sym_EXIT] = ACTIONS(4792),
    [anon_sym_Exit] = ACTIONS(4792),
    [anon_sym_continue] = ACTIONS(4792),
    [anon_sym_CONTINUE] = ACTIONS(4792),
    [anon_sym_Continue] = ACTIONS(4792),
    [anon_sym_break] = ACTIONS(4792),
    [anon_sym_BREAK] = ACTIONS(4792),
    [anon_sym_Break] = ACTIONS(4792),
    [anon_sym_with] = ACTIONS(4792),
    [anon_sym_WITH] = ACTIONS(4792),
    [anon_sym_With] = ACTIONS(4792),
    [sym_asserterror_keyword] = ACTIONS(4794),
    [sym_page_keyword] = ACTIONS(4792),
    [anon_sym_codeunit] = ACTIONS(4792),
    [anon_sym_CODEUNIT] = ACTIONS(4792),
    [anon_sym_Codeunit] = ACTIONS(4792),
    [anon_sym_CodeUnit] = ACTIONS(4792),
    [anon_sym_COdeunit] = ACTIONS(4792),
    [anon_sym_codeUnit] = ACTIONS(4792),
    [sym_report_keyword] = ACTIONS(4792),
    [sym_query_keyword] = ACTIONS(4792),
    [anon_sym_xmlport] = ACTIONS(4792),
    [anon_sym_XMLPORT] = ACTIONS(4792),
    [anon_sym_Xmlport] = ACTIONS(4792),
    [anon_sym_XMLport] = ACTIONS(4792),
    [anon_sym_XMLPort] = ACTIONS(4792),
    [anon_sym_XmlPort] = ACTIONS(4792),
    [anon_sym_enum] = ACTIONS(4792),
    [anon_sym_ENUM] = ACTIONS(4792),
    [anon_sym_Enum] = ACTIONS(4792),
    [anon_sym_eNUM] = ACTIONS(4792),
    [anon_sym_eNum] = ACTIONS(4792),
    [anon_sym_ENum] = ACTIONS(4792),
    [sym_quoted_identifier] = ACTIONS(4794),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4794),
    [sym_integer] = ACTIONS(4792),
    [sym_continue_as_identifier] = ACTIONS(4794),
    [sym_preproc_open] = ACTIONS(4794),
    [sym_end_keyword] = ACTIONS(4794),
  },
  [STATE(2237)] = {
    [sym_identifier] = ACTIONS(4796),
    [anon_sym_SEMI] = ACTIONS(4798),
    [anon_sym_DASH] = ACTIONS(4798),
    [aux_sym_boolean_token1] = ACTIONS(4796),
    [aux_sym_boolean_token2] = ACTIONS(4796),
    [sym_decimal] = ACTIONS(4796),
    [anon_sym_LPAREN] = ACTIONS(4798),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4796),
    [anon_sym_LBRACK] = ACTIONS(4798),
    [aux_sym_record_type_token1] = ACTIONS(4796),
    [aux_sym_basic_type_token21] = ACTIONS(4796),
    [aux_sym_basic_type_token22] = ACTIONS(4796),
    [aux_sym_basic_type_token48] = ACTIONS(4796),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4796),
    [anon_sym_POUNDif] = ACTIONS(4798),
    [anon_sym_POUNDIF] = ACTIONS(4798),
    [anon_sym_POUNDIf] = ACTIONS(4798),
    [anon_sym_not] = ACTIONS(4796),
    [anon_sym_NOT] = ACTIONS(4796),
    [anon_sym_Not] = ACTIONS(4796),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4796),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4796),
    [anon_sym_PLUS] = ACTIONS(4798),
    [sym_datetime_literal] = ACTIONS(4798),
    [sym_date_literal] = ACTIONS(4796),
    [sym_time_literal] = ACTIONS(4796),
    [sym_biginteger_literal] = ACTIONS(4798),
    [anon_sym_if] = ACTIONS(4796),
    [anon_sym_IF] = ACTIONS(4796),
    [anon_sym_If] = ACTIONS(4796),
    [anon_sym_else] = ACTIONS(4796),
    [anon_sym_ELSE] = ACTIONS(4796),
    [anon_sym_Else] = ACTIONS(4796),
    [anon_sym_case] = ACTIONS(4796),
    [anon_sym_CASE] = ACTIONS(4796),
    [anon_sym_Case] = ACTIONS(4796),
    [anon_sym_for] = ACTIONS(4796),
    [anon_sym_FOR] = ACTIONS(4796),
    [anon_sym_For] = ACTIONS(4796),
    [anon_sym_foreach] = ACTIONS(4796),
    [anon_sym_FOREACH] = ACTIONS(4796),
    [anon_sym_Foreach] = ACTIONS(4796),
    [anon_sym_while] = ACTIONS(4796),
    [anon_sym_WHILE] = ACTIONS(4796),
    [anon_sym_While] = ACTIONS(4796),
    [anon_sym_repeat] = ACTIONS(4796),
    [anon_sym_REPEAT] = ACTIONS(4796),
    [anon_sym_Repeat] = ACTIONS(4796),
    [anon_sym_exit] = ACTIONS(4796),
    [anon_sym_EXIT] = ACTIONS(4796),
    [anon_sym_Exit] = ACTIONS(4796),
    [anon_sym_continue] = ACTIONS(4796),
    [anon_sym_CONTINUE] = ACTIONS(4796),
    [anon_sym_Continue] = ACTIONS(4796),
    [anon_sym_break] = ACTIONS(4796),
    [anon_sym_BREAK] = ACTIONS(4796),
    [anon_sym_Break] = ACTIONS(4796),
    [anon_sym_with] = ACTIONS(4796),
    [anon_sym_WITH] = ACTIONS(4796),
    [anon_sym_With] = ACTIONS(4796),
    [sym_asserterror_keyword] = ACTIONS(4798),
    [sym_page_keyword] = ACTIONS(4796),
    [anon_sym_codeunit] = ACTIONS(4796),
    [anon_sym_CODEUNIT] = ACTIONS(4796),
    [anon_sym_Codeunit] = ACTIONS(4796),
    [anon_sym_CodeUnit] = ACTIONS(4796),
    [anon_sym_COdeunit] = ACTIONS(4796),
    [anon_sym_codeUnit] = ACTIONS(4796),
    [sym_report_keyword] = ACTIONS(4796),
    [sym_query_keyword] = ACTIONS(4796),
    [anon_sym_xmlport] = ACTIONS(4796),
    [anon_sym_XMLPORT] = ACTIONS(4796),
    [anon_sym_Xmlport] = ACTIONS(4796),
    [anon_sym_XMLport] = ACTIONS(4796),
    [anon_sym_XMLPort] = ACTIONS(4796),
    [anon_sym_XmlPort] = ACTIONS(4796),
    [anon_sym_enum] = ACTIONS(4796),
    [anon_sym_ENUM] = ACTIONS(4796),
    [anon_sym_Enum] = ACTIONS(4796),
    [anon_sym_eNUM] = ACTIONS(4796),
    [anon_sym_eNum] = ACTIONS(4796),
    [anon_sym_ENum] = ACTIONS(4796),
    [sym_quoted_identifier] = ACTIONS(4798),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4798),
    [sym_integer] = ACTIONS(4796),
    [sym_continue_as_identifier] = ACTIONS(4798),
    [sym_preproc_open] = ACTIONS(4798),
    [sym_end_keyword] = ACTIONS(4798),
  },
  [STATE(2238)] = {
    [sym_identifier] = ACTIONS(4800),
    [anon_sym_SEMI] = ACTIONS(4802),
    [anon_sym_DASH] = ACTIONS(4802),
    [aux_sym_boolean_token1] = ACTIONS(4800),
    [aux_sym_boolean_token2] = ACTIONS(4800),
    [sym_decimal] = ACTIONS(4800),
    [anon_sym_LPAREN] = ACTIONS(4802),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4800),
    [anon_sym_LBRACK] = ACTIONS(4802),
    [aux_sym_record_type_token1] = ACTIONS(4800),
    [aux_sym_basic_type_token21] = ACTIONS(4800),
    [aux_sym_basic_type_token22] = ACTIONS(4800),
    [aux_sym_basic_type_token48] = ACTIONS(4800),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4800),
    [anon_sym_POUNDif] = ACTIONS(4802),
    [anon_sym_POUNDIF] = ACTIONS(4802),
    [anon_sym_POUNDIf] = ACTIONS(4802),
    [anon_sym_not] = ACTIONS(4800),
    [anon_sym_NOT] = ACTIONS(4800),
    [anon_sym_Not] = ACTIONS(4800),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4800),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4800),
    [anon_sym_PLUS] = ACTIONS(4802),
    [sym_datetime_literal] = ACTIONS(4802),
    [sym_date_literal] = ACTIONS(4800),
    [sym_time_literal] = ACTIONS(4800),
    [sym_biginteger_literal] = ACTIONS(4802),
    [anon_sym_if] = ACTIONS(4800),
    [anon_sym_IF] = ACTIONS(4800),
    [anon_sym_If] = ACTIONS(4800),
    [anon_sym_else] = ACTIONS(4800),
    [anon_sym_ELSE] = ACTIONS(4800),
    [anon_sym_Else] = ACTIONS(4800),
    [anon_sym_case] = ACTIONS(4800),
    [anon_sym_CASE] = ACTIONS(4800),
    [anon_sym_Case] = ACTIONS(4800),
    [anon_sym_for] = ACTIONS(4800),
    [anon_sym_FOR] = ACTIONS(4800),
    [anon_sym_For] = ACTIONS(4800),
    [anon_sym_foreach] = ACTIONS(4800),
    [anon_sym_FOREACH] = ACTIONS(4800),
    [anon_sym_Foreach] = ACTIONS(4800),
    [anon_sym_while] = ACTIONS(4800),
    [anon_sym_WHILE] = ACTIONS(4800),
    [anon_sym_While] = ACTIONS(4800),
    [anon_sym_repeat] = ACTIONS(4800),
    [anon_sym_REPEAT] = ACTIONS(4800),
    [anon_sym_Repeat] = ACTIONS(4800),
    [anon_sym_exit] = ACTIONS(4800),
    [anon_sym_EXIT] = ACTIONS(4800),
    [anon_sym_Exit] = ACTIONS(4800),
    [anon_sym_continue] = ACTIONS(4800),
    [anon_sym_CONTINUE] = ACTIONS(4800),
    [anon_sym_Continue] = ACTIONS(4800),
    [anon_sym_break] = ACTIONS(4800),
    [anon_sym_BREAK] = ACTIONS(4800),
    [anon_sym_Break] = ACTIONS(4800),
    [anon_sym_with] = ACTIONS(4800),
    [anon_sym_WITH] = ACTIONS(4800),
    [anon_sym_With] = ACTIONS(4800),
    [sym_asserterror_keyword] = ACTIONS(4802),
    [sym_page_keyword] = ACTIONS(4800),
    [anon_sym_codeunit] = ACTIONS(4800),
    [anon_sym_CODEUNIT] = ACTIONS(4800),
    [anon_sym_Codeunit] = ACTIONS(4800),
    [anon_sym_CodeUnit] = ACTIONS(4800),
    [anon_sym_COdeunit] = ACTIONS(4800),
    [anon_sym_codeUnit] = ACTIONS(4800),
    [sym_report_keyword] = ACTIONS(4800),
    [sym_query_keyword] = ACTIONS(4800),
    [anon_sym_xmlport] = ACTIONS(4800),
    [anon_sym_XMLPORT] = ACTIONS(4800),
    [anon_sym_Xmlport] = ACTIONS(4800),
    [anon_sym_XMLport] = ACTIONS(4800),
    [anon_sym_XMLPort] = ACTIONS(4800),
    [anon_sym_XmlPort] = ACTIONS(4800),
    [anon_sym_enum] = ACTIONS(4800),
    [anon_sym_ENUM] = ACTIONS(4800),
    [anon_sym_Enum] = ACTIONS(4800),
    [anon_sym_eNUM] = ACTIONS(4800),
    [anon_sym_eNum] = ACTIONS(4800),
    [anon_sym_ENum] = ACTIONS(4800),
    [sym_quoted_identifier] = ACTIONS(4802),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4802),
    [sym_integer] = ACTIONS(4800),
    [sym_continue_as_identifier] = ACTIONS(4802),
    [sym_preproc_open] = ACTIONS(4802),
    [sym_end_keyword] = ACTIONS(4802),
  },
  [STATE(2239)] = {
    [sym_identifier] = ACTIONS(4173),
    [anon_sym_SEMI] = ACTIONS(4175),
    [anon_sym_DASH] = ACTIONS(4175),
    [aux_sym_boolean_token1] = ACTIONS(4173),
    [aux_sym_boolean_token2] = ACTIONS(4173),
    [sym_decimal] = ACTIONS(4173),
    [anon_sym_LPAREN] = ACTIONS(4175),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4173),
    [anon_sym_LBRACK] = ACTIONS(4175),
    [aux_sym_record_type_token1] = ACTIONS(4173),
    [aux_sym_basic_type_token21] = ACTIONS(4173),
    [aux_sym_basic_type_token22] = ACTIONS(4173),
    [aux_sym_basic_type_token48] = ACTIONS(4173),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4173),
    [anon_sym_POUNDif] = ACTIONS(4175),
    [anon_sym_POUNDIF] = ACTIONS(4175),
    [anon_sym_POUNDIf] = ACTIONS(4175),
    [anon_sym_not] = ACTIONS(4173),
    [anon_sym_NOT] = ACTIONS(4173),
    [anon_sym_Not] = ACTIONS(4173),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4173),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4173),
    [anon_sym_PLUS] = ACTIONS(4175),
    [sym_datetime_literal] = ACTIONS(4175),
    [sym_date_literal] = ACTIONS(4173),
    [sym_time_literal] = ACTIONS(4173),
    [sym_biginteger_literal] = ACTIONS(4175),
    [anon_sym_if] = ACTIONS(4173),
    [anon_sym_IF] = ACTIONS(4173),
    [anon_sym_If] = ACTIONS(4173),
    [anon_sym_else] = ACTIONS(4173),
    [anon_sym_ELSE] = ACTIONS(4173),
    [anon_sym_Else] = ACTIONS(4173),
    [anon_sym_case] = ACTIONS(4173),
    [anon_sym_CASE] = ACTIONS(4173),
    [anon_sym_Case] = ACTIONS(4173),
    [anon_sym_for] = ACTIONS(4173),
    [anon_sym_FOR] = ACTIONS(4173),
    [anon_sym_For] = ACTIONS(4173),
    [anon_sym_foreach] = ACTIONS(4173),
    [anon_sym_FOREACH] = ACTIONS(4173),
    [anon_sym_Foreach] = ACTIONS(4173),
    [anon_sym_while] = ACTIONS(4173),
    [anon_sym_WHILE] = ACTIONS(4173),
    [anon_sym_While] = ACTIONS(4173),
    [anon_sym_repeat] = ACTIONS(4173),
    [anon_sym_REPEAT] = ACTIONS(4173),
    [anon_sym_Repeat] = ACTIONS(4173),
    [anon_sym_exit] = ACTIONS(4173),
    [anon_sym_EXIT] = ACTIONS(4173),
    [anon_sym_Exit] = ACTIONS(4173),
    [anon_sym_continue] = ACTIONS(4173),
    [anon_sym_CONTINUE] = ACTIONS(4173),
    [anon_sym_Continue] = ACTIONS(4173),
    [anon_sym_break] = ACTIONS(4173),
    [anon_sym_BREAK] = ACTIONS(4173),
    [anon_sym_Break] = ACTIONS(4173),
    [anon_sym_with] = ACTIONS(4173),
    [anon_sym_WITH] = ACTIONS(4173),
    [anon_sym_With] = ACTIONS(4173),
    [sym_asserterror_keyword] = ACTIONS(4175),
    [sym_page_keyword] = ACTIONS(4173),
    [anon_sym_codeunit] = ACTIONS(4173),
    [anon_sym_CODEUNIT] = ACTIONS(4173),
    [anon_sym_Codeunit] = ACTIONS(4173),
    [anon_sym_CodeUnit] = ACTIONS(4173),
    [anon_sym_COdeunit] = ACTIONS(4173),
    [anon_sym_codeUnit] = ACTIONS(4173),
    [sym_report_keyword] = ACTIONS(4173),
    [sym_query_keyword] = ACTIONS(4173),
    [anon_sym_xmlport] = ACTIONS(4173),
    [anon_sym_XMLPORT] = ACTIONS(4173),
    [anon_sym_Xmlport] = ACTIONS(4173),
    [anon_sym_XMLport] = ACTIONS(4173),
    [anon_sym_XMLPort] = ACTIONS(4173),
    [anon_sym_XmlPort] = ACTIONS(4173),
    [anon_sym_enum] = ACTIONS(4173),
    [anon_sym_ENUM] = ACTIONS(4173),
    [anon_sym_Enum] = ACTIONS(4173),
    [anon_sym_eNUM] = ACTIONS(4173),
    [anon_sym_eNum] = ACTIONS(4173),
    [anon_sym_ENum] = ACTIONS(4173),
    [sym_quoted_identifier] = ACTIONS(4175),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4175),
    [sym_integer] = ACTIONS(4173),
    [sym_continue_as_identifier] = ACTIONS(4175),
    [sym_preproc_open] = ACTIONS(4175),
    [sym_end_keyword] = ACTIONS(4175),
  },
  [STATE(2240)] = {
    [sym_identifier] = ACTIONS(4606),
    [anon_sym_SEMI] = ACTIONS(4608),
    [anon_sym_DASH] = ACTIONS(4608),
    [aux_sym_boolean_token1] = ACTIONS(4606),
    [aux_sym_boolean_token2] = ACTIONS(4606),
    [sym_decimal] = ACTIONS(4606),
    [anon_sym_LPAREN] = ACTIONS(4608),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4606),
    [anon_sym_LBRACK] = ACTIONS(4608),
    [aux_sym_record_type_token1] = ACTIONS(4606),
    [aux_sym_basic_type_token21] = ACTIONS(4606),
    [aux_sym_basic_type_token22] = ACTIONS(4606),
    [aux_sym_basic_type_token48] = ACTIONS(4606),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4606),
    [anon_sym_POUNDif] = ACTIONS(4608),
    [anon_sym_POUNDIF] = ACTIONS(4608),
    [anon_sym_POUNDIf] = ACTIONS(4608),
    [anon_sym_not] = ACTIONS(4606),
    [anon_sym_NOT] = ACTIONS(4606),
    [anon_sym_Not] = ACTIONS(4606),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4606),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4606),
    [anon_sym_PLUS] = ACTIONS(4608),
    [sym_datetime_literal] = ACTIONS(4608),
    [sym_date_literal] = ACTIONS(4606),
    [sym_time_literal] = ACTIONS(4606),
    [sym_biginteger_literal] = ACTIONS(4608),
    [anon_sym_if] = ACTIONS(4606),
    [anon_sym_IF] = ACTIONS(4606),
    [anon_sym_If] = ACTIONS(4606),
    [anon_sym_else] = ACTIONS(4606),
    [anon_sym_ELSE] = ACTIONS(4606),
    [anon_sym_Else] = ACTIONS(4606),
    [anon_sym_case] = ACTIONS(4606),
    [anon_sym_CASE] = ACTIONS(4606),
    [anon_sym_Case] = ACTIONS(4606),
    [anon_sym_for] = ACTIONS(4606),
    [anon_sym_FOR] = ACTIONS(4606),
    [anon_sym_For] = ACTIONS(4606),
    [anon_sym_foreach] = ACTIONS(4606),
    [anon_sym_FOREACH] = ACTIONS(4606),
    [anon_sym_Foreach] = ACTIONS(4606),
    [anon_sym_while] = ACTIONS(4606),
    [anon_sym_WHILE] = ACTIONS(4606),
    [anon_sym_While] = ACTIONS(4606),
    [anon_sym_repeat] = ACTIONS(4606),
    [anon_sym_REPEAT] = ACTIONS(4606),
    [anon_sym_Repeat] = ACTIONS(4606),
    [anon_sym_exit] = ACTIONS(4606),
    [anon_sym_EXIT] = ACTIONS(4606),
    [anon_sym_Exit] = ACTIONS(4606),
    [anon_sym_continue] = ACTIONS(4606),
    [anon_sym_CONTINUE] = ACTIONS(4606),
    [anon_sym_Continue] = ACTIONS(4606),
    [anon_sym_break] = ACTIONS(4606),
    [anon_sym_BREAK] = ACTIONS(4606),
    [anon_sym_Break] = ACTIONS(4606),
    [anon_sym_with] = ACTIONS(4606),
    [anon_sym_WITH] = ACTIONS(4606),
    [anon_sym_With] = ACTIONS(4606),
    [sym_asserterror_keyword] = ACTIONS(4608),
    [sym_page_keyword] = ACTIONS(4606),
    [anon_sym_codeunit] = ACTIONS(4606),
    [anon_sym_CODEUNIT] = ACTIONS(4606),
    [anon_sym_Codeunit] = ACTIONS(4606),
    [anon_sym_CodeUnit] = ACTIONS(4606),
    [anon_sym_COdeunit] = ACTIONS(4606),
    [anon_sym_codeUnit] = ACTIONS(4606),
    [sym_report_keyword] = ACTIONS(4606),
    [sym_query_keyword] = ACTIONS(4606),
    [anon_sym_xmlport] = ACTIONS(4606),
    [anon_sym_XMLPORT] = ACTIONS(4606),
    [anon_sym_Xmlport] = ACTIONS(4606),
    [anon_sym_XMLport] = ACTIONS(4606),
    [anon_sym_XMLPort] = ACTIONS(4606),
    [anon_sym_XmlPort] = ACTIONS(4606),
    [anon_sym_enum] = ACTIONS(4606),
    [anon_sym_ENUM] = ACTIONS(4606),
    [anon_sym_Enum] = ACTIONS(4606),
    [anon_sym_eNUM] = ACTIONS(4606),
    [anon_sym_eNum] = ACTIONS(4606),
    [anon_sym_ENum] = ACTIONS(4606),
    [sym_quoted_identifier] = ACTIONS(4608),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4608),
    [sym_integer] = ACTIONS(4606),
    [sym_continue_as_identifier] = ACTIONS(4608),
    [sym_preproc_open] = ACTIONS(4608),
    [sym_end_keyword] = ACTIONS(4608),
  },
  [STATE(2241)] = {
    [sym_identifier] = ACTIONS(4415),
    [anon_sym_SEMI] = ACTIONS(4417),
    [anon_sym_DASH] = ACTIONS(4417),
    [aux_sym_boolean_token1] = ACTIONS(4415),
    [aux_sym_boolean_token2] = ACTIONS(4415),
    [sym_decimal] = ACTIONS(4415),
    [anon_sym_LPAREN] = ACTIONS(4417),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4415),
    [anon_sym_LBRACK] = ACTIONS(4417),
    [aux_sym_record_type_token1] = ACTIONS(4415),
    [aux_sym_basic_type_token21] = ACTIONS(4415),
    [aux_sym_basic_type_token22] = ACTIONS(4415),
    [aux_sym_basic_type_token48] = ACTIONS(4415),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4415),
    [anon_sym_POUNDif] = ACTIONS(4417),
    [anon_sym_POUNDIF] = ACTIONS(4417),
    [anon_sym_POUNDIf] = ACTIONS(4417),
    [anon_sym_not] = ACTIONS(4415),
    [anon_sym_NOT] = ACTIONS(4415),
    [anon_sym_Not] = ACTIONS(4415),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4415),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4415),
    [anon_sym_PLUS] = ACTIONS(4417),
    [sym_datetime_literal] = ACTIONS(4417),
    [sym_date_literal] = ACTIONS(4415),
    [sym_time_literal] = ACTIONS(4415),
    [sym_biginteger_literal] = ACTIONS(4417),
    [anon_sym_if] = ACTIONS(4415),
    [anon_sym_IF] = ACTIONS(4415),
    [anon_sym_If] = ACTIONS(4415),
    [anon_sym_else] = ACTIONS(4415),
    [anon_sym_ELSE] = ACTIONS(4415),
    [anon_sym_Else] = ACTIONS(4415),
    [anon_sym_case] = ACTIONS(4415),
    [anon_sym_CASE] = ACTIONS(4415),
    [anon_sym_Case] = ACTIONS(4415),
    [anon_sym_for] = ACTIONS(4415),
    [anon_sym_FOR] = ACTIONS(4415),
    [anon_sym_For] = ACTIONS(4415),
    [anon_sym_foreach] = ACTIONS(4415),
    [anon_sym_FOREACH] = ACTIONS(4415),
    [anon_sym_Foreach] = ACTIONS(4415),
    [anon_sym_while] = ACTIONS(4415),
    [anon_sym_WHILE] = ACTIONS(4415),
    [anon_sym_While] = ACTIONS(4415),
    [anon_sym_repeat] = ACTIONS(4415),
    [anon_sym_REPEAT] = ACTIONS(4415),
    [anon_sym_Repeat] = ACTIONS(4415),
    [anon_sym_exit] = ACTIONS(4415),
    [anon_sym_EXIT] = ACTIONS(4415),
    [anon_sym_Exit] = ACTIONS(4415),
    [anon_sym_continue] = ACTIONS(4415),
    [anon_sym_CONTINUE] = ACTIONS(4415),
    [anon_sym_Continue] = ACTIONS(4415),
    [anon_sym_break] = ACTIONS(4415),
    [anon_sym_BREAK] = ACTIONS(4415),
    [anon_sym_Break] = ACTIONS(4415),
    [anon_sym_with] = ACTIONS(4415),
    [anon_sym_WITH] = ACTIONS(4415),
    [anon_sym_With] = ACTIONS(4415),
    [sym_asserterror_keyword] = ACTIONS(4417),
    [sym_page_keyword] = ACTIONS(4415),
    [anon_sym_codeunit] = ACTIONS(4415),
    [anon_sym_CODEUNIT] = ACTIONS(4415),
    [anon_sym_Codeunit] = ACTIONS(4415),
    [anon_sym_CodeUnit] = ACTIONS(4415),
    [anon_sym_COdeunit] = ACTIONS(4415),
    [anon_sym_codeUnit] = ACTIONS(4415),
    [sym_report_keyword] = ACTIONS(4415),
    [sym_query_keyword] = ACTIONS(4415),
    [anon_sym_xmlport] = ACTIONS(4415),
    [anon_sym_XMLPORT] = ACTIONS(4415),
    [anon_sym_Xmlport] = ACTIONS(4415),
    [anon_sym_XMLport] = ACTIONS(4415),
    [anon_sym_XMLPort] = ACTIONS(4415),
    [anon_sym_XmlPort] = ACTIONS(4415),
    [anon_sym_enum] = ACTIONS(4415),
    [anon_sym_ENUM] = ACTIONS(4415),
    [anon_sym_Enum] = ACTIONS(4415),
    [anon_sym_eNUM] = ACTIONS(4415),
    [anon_sym_eNum] = ACTIONS(4415),
    [anon_sym_ENum] = ACTIONS(4415),
    [sym_quoted_identifier] = ACTIONS(4417),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4417),
    [sym_integer] = ACTIONS(4415),
    [sym_continue_as_identifier] = ACTIONS(4417),
    [sym_preproc_open] = ACTIONS(4417),
    [sym_end_keyword] = ACTIONS(4417),
  },
  [STATE(2242)] = {
    [sym_identifier] = ACTIONS(4407),
    [anon_sym_SEMI] = ACTIONS(4409),
    [anon_sym_DASH] = ACTIONS(4409),
    [aux_sym_boolean_token1] = ACTIONS(4407),
    [aux_sym_boolean_token2] = ACTIONS(4407),
    [sym_decimal] = ACTIONS(4407),
    [anon_sym_LPAREN] = ACTIONS(4409),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4407),
    [anon_sym_LBRACK] = ACTIONS(4409),
    [aux_sym_record_type_token1] = ACTIONS(4407),
    [aux_sym_basic_type_token21] = ACTIONS(4407),
    [aux_sym_basic_type_token22] = ACTIONS(4407),
    [aux_sym_basic_type_token48] = ACTIONS(4407),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4407),
    [anon_sym_POUNDif] = ACTIONS(4409),
    [anon_sym_POUNDIF] = ACTIONS(4409),
    [anon_sym_POUNDIf] = ACTIONS(4409),
    [anon_sym_not] = ACTIONS(4407),
    [anon_sym_NOT] = ACTIONS(4407),
    [anon_sym_Not] = ACTIONS(4407),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4407),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4407),
    [anon_sym_PLUS] = ACTIONS(4409),
    [sym_datetime_literal] = ACTIONS(4409),
    [sym_date_literal] = ACTIONS(4407),
    [sym_time_literal] = ACTIONS(4407),
    [sym_biginteger_literal] = ACTIONS(4409),
    [anon_sym_if] = ACTIONS(4407),
    [anon_sym_IF] = ACTIONS(4407),
    [anon_sym_If] = ACTIONS(4407),
    [anon_sym_else] = ACTIONS(4407),
    [anon_sym_ELSE] = ACTIONS(4407),
    [anon_sym_Else] = ACTIONS(4407),
    [anon_sym_case] = ACTIONS(4407),
    [anon_sym_CASE] = ACTIONS(4407),
    [anon_sym_Case] = ACTIONS(4407),
    [anon_sym_for] = ACTIONS(4407),
    [anon_sym_FOR] = ACTIONS(4407),
    [anon_sym_For] = ACTIONS(4407),
    [anon_sym_foreach] = ACTIONS(4407),
    [anon_sym_FOREACH] = ACTIONS(4407),
    [anon_sym_Foreach] = ACTIONS(4407),
    [anon_sym_while] = ACTIONS(4407),
    [anon_sym_WHILE] = ACTIONS(4407),
    [anon_sym_While] = ACTIONS(4407),
    [anon_sym_repeat] = ACTIONS(4407),
    [anon_sym_REPEAT] = ACTIONS(4407),
    [anon_sym_Repeat] = ACTIONS(4407),
    [anon_sym_exit] = ACTIONS(4407),
    [anon_sym_EXIT] = ACTIONS(4407),
    [anon_sym_Exit] = ACTIONS(4407),
    [anon_sym_continue] = ACTIONS(4407),
    [anon_sym_CONTINUE] = ACTIONS(4407),
    [anon_sym_Continue] = ACTIONS(4407),
    [anon_sym_break] = ACTIONS(4407),
    [anon_sym_BREAK] = ACTIONS(4407),
    [anon_sym_Break] = ACTIONS(4407),
    [anon_sym_with] = ACTIONS(4407),
    [anon_sym_WITH] = ACTIONS(4407),
    [anon_sym_With] = ACTIONS(4407),
    [sym_asserterror_keyword] = ACTIONS(4409),
    [sym_page_keyword] = ACTIONS(4407),
    [anon_sym_codeunit] = ACTIONS(4407),
    [anon_sym_CODEUNIT] = ACTIONS(4407),
    [anon_sym_Codeunit] = ACTIONS(4407),
    [anon_sym_CodeUnit] = ACTIONS(4407),
    [anon_sym_COdeunit] = ACTIONS(4407),
    [anon_sym_codeUnit] = ACTIONS(4407),
    [sym_report_keyword] = ACTIONS(4407),
    [sym_query_keyword] = ACTIONS(4407),
    [anon_sym_xmlport] = ACTIONS(4407),
    [anon_sym_XMLPORT] = ACTIONS(4407),
    [anon_sym_Xmlport] = ACTIONS(4407),
    [anon_sym_XMLport] = ACTIONS(4407),
    [anon_sym_XMLPort] = ACTIONS(4407),
    [anon_sym_XmlPort] = ACTIONS(4407),
    [anon_sym_enum] = ACTIONS(4407),
    [anon_sym_ENUM] = ACTIONS(4407),
    [anon_sym_Enum] = ACTIONS(4407),
    [anon_sym_eNUM] = ACTIONS(4407),
    [anon_sym_eNum] = ACTIONS(4407),
    [anon_sym_ENum] = ACTIONS(4407),
    [sym_quoted_identifier] = ACTIONS(4409),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4409),
    [sym_integer] = ACTIONS(4407),
    [sym_continue_as_identifier] = ACTIONS(4409),
    [sym_preproc_open] = ACTIONS(4409),
    [sym_end_keyword] = ACTIONS(4409),
  },
  [STATE(2243)] = {
    [sym_identifier] = ACTIONS(4185),
    [anon_sym_SEMI] = ACTIONS(4187),
    [anon_sym_DASH] = ACTIONS(4187),
    [aux_sym_boolean_token1] = ACTIONS(4185),
    [aux_sym_boolean_token2] = ACTIONS(4185),
    [sym_decimal] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4187),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4185),
    [anon_sym_LBRACK] = ACTIONS(4187),
    [aux_sym_record_type_token1] = ACTIONS(4185),
    [aux_sym_basic_type_token21] = ACTIONS(4185),
    [aux_sym_basic_type_token22] = ACTIONS(4185),
    [aux_sym_basic_type_token48] = ACTIONS(4185),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4185),
    [anon_sym_POUNDif] = ACTIONS(4187),
    [anon_sym_POUNDIF] = ACTIONS(4187),
    [anon_sym_POUNDIf] = ACTIONS(4187),
    [anon_sym_not] = ACTIONS(4185),
    [anon_sym_NOT] = ACTIONS(4185),
    [anon_sym_Not] = ACTIONS(4185),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4185),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4187),
    [sym_datetime_literal] = ACTIONS(4187),
    [sym_date_literal] = ACTIONS(4185),
    [sym_time_literal] = ACTIONS(4185),
    [sym_biginteger_literal] = ACTIONS(4187),
    [anon_sym_if] = ACTIONS(4185),
    [anon_sym_IF] = ACTIONS(4185),
    [anon_sym_If] = ACTIONS(4185),
    [anon_sym_else] = ACTIONS(4185),
    [anon_sym_ELSE] = ACTIONS(4185),
    [anon_sym_Else] = ACTIONS(4185),
    [anon_sym_case] = ACTIONS(4185),
    [anon_sym_CASE] = ACTIONS(4185),
    [anon_sym_Case] = ACTIONS(4185),
    [anon_sym_for] = ACTIONS(4185),
    [anon_sym_FOR] = ACTIONS(4185),
    [anon_sym_For] = ACTIONS(4185),
    [anon_sym_foreach] = ACTIONS(4185),
    [anon_sym_FOREACH] = ACTIONS(4185),
    [anon_sym_Foreach] = ACTIONS(4185),
    [anon_sym_while] = ACTIONS(4185),
    [anon_sym_WHILE] = ACTIONS(4185),
    [anon_sym_While] = ACTIONS(4185),
    [anon_sym_repeat] = ACTIONS(4185),
    [anon_sym_REPEAT] = ACTIONS(4185),
    [anon_sym_Repeat] = ACTIONS(4185),
    [anon_sym_exit] = ACTIONS(4185),
    [anon_sym_EXIT] = ACTIONS(4185),
    [anon_sym_Exit] = ACTIONS(4185),
    [anon_sym_continue] = ACTIONS(4185),
    [anon_sym_CONTINUE] = ACTIONS(4185),
    [anon_sym_Continue] = ACTIONS(4185),
    [anon_sym_break] = ACTIONS(4185),
    [anon_sym_BREAK] = ACTIONS(4185),
    [anon_sym_Break] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4185),
    [anon_sym_WITH] = ACTIONS(4185),
    [anon_sym_With] = ACTIONS(4185),
    [sym_asserterror_keyword] = ACTIONS(4187),
    [sym_page_keyword] = ACTIONS(4185),
    [anon_sym_codeunit] = ACTIONS(4185),
    [anon_sym_CODEUNIT] = ACTIONS(4185),
    [anon_sym_Codeunit] = ACTIONS(4185),
    [anon_sym_CodeUnit] = ACTIONS(4185),
    [anon_sym_COdeunit] = ACTIONS(4185),
    [anon_sym_codeUnit] = ACTIONS(4185),
    [sym_report_keyword] = ACTIONS(4185),
    [sym_query_keyword] = ACTIONS(4185),
    [anon_sym_xmlport] = ACTIONS(4185),
    [anon_sym_XMLPORT] = ACTIONS(4185),
    [anon_sym_Xmlport] = ACTIONS(4185),
    [anon_sym_XMLport] = ACTIONS(4185),
    [anon_sym_XMLPort] = ACTIONS(4185),
    [anon_sym_XmlPort] = ACTIONS(4185),
    [anon_sym_enum] = ACTIONS(4185),
    [anon_sym_ENUM] = ACTIONS(4185),
    [anon_sym_Enum] = ACTIONS(4185),
    [anon_sym_eNUM] = ACTIONS(4185),
    [anon_sym_eNum] = ACTIONS(4185),
    [anon_sym_ENum] = ACTIONS(4185),
    [sym_quoted_identifier] = ACTIONS(4187),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4187),
    [sym_integer] = ACTIONS(4185),
    [sym_continue_as_identifier] = ACTIONS(4187),
    [sym_preproc_open] = ACTIONS(4187),
    [sym_end_keyword] = ACTIONS(4187),
  },
  [STATE(2244)] = {
    [sym_identifier] = ACTIONS(4181),
    [anon_sym_SEMI] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [aux_sym_boolean_token1] = ACTIONS(4181),
    [aux_sym_boolean_token2] = ACTIONS(4181),
    [sym_decimal] = ACTIONS(4181),
    [anon_sym_LPAREN] = ACTIONS(4183),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4181),
    [anon_sym_LBRACK] = ACTIONS(4183),
    [aux_sym_record_type_token1] = ACTIONS(4181),
    [aux_sym_basic_type_token21] = ACTIONS(4181),
    [aux_sym_basic_type_token22] = ACTIONS(4181),
    [aux_sym_basic_type_token48] = ACTIONS(4181),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4181),
    [anon_sym_POUNDif] = ACTIONS(4183),
    [anon_sym_POUNDIF] = ACTIONS(4183),
    [anon_sym_POUNDIf] = ACTIONS(4183),
    [anon_sym_not] = ACTIONS(4181),
    [anon_sym_NOT] = ACTIONS(4181),
    [anon_sym_Not] = ACTIONS(4181),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4181),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4181),
    [anon_sym_PLUS] = ACTIONS(4183),
    [sym_datetime_literal] = ACTIONS(4183),
    [sym_date_literal] = ACTIONS(4181),
    [sym_time_literal] = ACTIONS(4181),
    [sym_biginteger_literal] = ACTIONS(4183),
    [anon_sym_if] = ACTIONS(4181),
    [anon_sym_IF] = ACTIONS(4181),
    [anon_sym_If] = ACTIONS(4181),
    [anon_sym_else] = ACTIONS(4181),
    [anon_sym_ELSE] = ACTIONS(4181),
    [anon_sym_Else] = ACTIONS(4181),
    [anon_sym_case] = ACTIONS(4181),
    [anon_sym_CASE] = ACTIONS(4181),
    [anon_sym_Case] = ACTIONS(4181),
    [anon_sym_for] = ACTIONS(4181),
    [anon_sym_FOR] = ACTIONS(4181),
    [anon_sym_For] = ACTIONS(4181),
    [anon_sym_foreach] = ACTIONS(4181),
    [anon_sym_FOREACH] = ACTIONS(4181),
    [anon_sym_Foreach] = ACTIONS(4181),
    [anon_sym_while] = ACTIONS(4181),
    [anon_sym_WHILE] = ACTIONS(4181),
    [anon_sym_While] = ACTIONS(4181),
    [anon_sym_repeat] = ACTIONS(4181),
    [anon_sym_REPEAT] = ACTIONS(4181),
    [anon_sym_Repeat] = ACTIONS(4181),
    [anon_sym_exit] = ACTIONS(4181),
    [anon_sym_EXIT] = ACTIONS(4181),
    [anon_sym_Exit] = ACTIONS(4181),
    [anon_sym_continue] = ACTIONS(4181),
    [anon_sym_CONTINUE] = ACTIONS(4181),
    [anon_sym_Continue] = ACTIONS(4181),
    [anon_sym_break] = ACTIONS(4181),
    [anon_sym_BREAK] = ACTIONS(4181),
    [anon_sym_Break] = ACTIONS(4181),
    [anon_sym_with] = ACTIONS(4181),
    [anon_sym_WITH] = ACTIONS(4181),
    [anon_sym_With] = ACTIONS(4181),
    [sym_asserterror_keyword] = ACTIONS(4183),
    [sym_page_keyword] = ACTIONS(4181),
    [anon_sym_codeunit] = ACTIONS(4181),
    [anon_sym_CODEUNIT] = ACTIONS(4181),
    [anon_sym_Codeunit] = ACTIONS(4181),
    [anon_sym_CodeUnit] = ACTIONS(4181),
    [anon_sym_COdeunit] = ACTIONS(4181),
    [anon_sym_codeUnit] = ACTIONS(4181),
    [sym_report_keyword] = ACTIONS(4181),
    [sym_query_keyword] = ACTIONS(4181),
    [anon_sym_xmlport] = ACTIONS(4181),
    [anon_sym_XMLPORT] = ACTIONS(4181),
    [anon_sym_Xmlport] = ACTIONS(4181),
    [anon_sym_XMLport] = ACTIONS(4181),
    [anon_sym_XMLPort] = ACTIONS(4181),
    [anon_sym_XmlPort] = ACTIONS(4181),
    [anon_sym_enum] = ACTIONS(4181),
    [anon_sym_ENUM] = ACTIONS(4181),
    [anon_sym_Enum] = ACTIONS(4181),
    [anon_sym_eNUM] = ACTIONS(4181),
    [anon_sym_eNum] = ACTIONS(4181),
    [anon_sym_ENum] = ACTIONS(4181),
    [sym_quoted_identifier] = ACTIONS(4183),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4183),
    [sym_integer] = ACTIONS(4181),
    [sym_continue_as_identifier] = ACTIONS(4183),
    [sym_preproc_open] = ACTIONS(4183),
    [sym_end_keyword] = ACTIONS(4183),
  },
  [STATE(2245)] = {
    [sym_identifier] = ACTIONS(4804),
    [anon_sym_SEMI] = ACTIONS(4806),
    [anon_sym_DASH] = ACTIONS(4806),
    [aux_sym_boolean_token1] = ACTIONS(4804),
    [aux_sym_boolean_token2] = ACTIONS(4804),
    [sym_decimal] = ACTIONS(4804),
    [anon_sym_LPAREN] = ACTIONS(4806),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4804),
    [anon_sym_LBRACK] = ACTIONS(4806),
    [aux_sym_record_type_token1] = ACTIONS(4804),
    [aux_sym_basic_type_token21] = ACTIONS(4804),
    [aux_sym_basic_type_token22] = ACTIONS(4804),
    [aux_sym_basic_type_token48] = ACTIONS(4804),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4804),
    [anon_sym_POUNDif] = ACTIONS(4806),
    [anon_sym_POUNDIF] = ACTIONS(4806),
    [anon_sym_POUNDIf] = ACTIONS(4806),
    [anon_sym_not] = ACTIONS(4804),
    [anon_sym_NOT] = ACTIONS(4804),
    [anon_sym_Not] = ACTIONS(4804),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4804),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4804),
    [anon_sym_PLUS] = ACTIONS(4806),
    [sym_datetime_literal] = ACTIONS(4806),
    [sym_date_literal] = ACTIONS(4804),
    [sym_time_literal] = ACTIONS(4804),
    [sym_biginteger_literal] = ACTIONS(4806),
    [anon_sym_if] = ACTIONS(4804),
    [anon_sym_IF] = ACTIONS(4804),
    [anon_sym_If] = ACTIONS(4804),
    [anon_sym_else] = ACTIONS(4804),
    [anon_sym_ELSE] = ACTIONS(4804),
    [anon_sym_Else] = ACTIONS(4804),
    [anon_sym_case] = ACTIONS(4804),
    [anon_sym_CASE] = ACTIONS(4804),
    [anon_sym_Case] = ACTIONS(4804),
    [anon_sym_for] = ACTIONS(4804),
    [anon_sym_FOR] = ACTIONS(4804),
    [anon_sym_For] = ACTIONS(4804),
    [anon_sym_foreach] = ACTIONS(4804),
    [anon_sym_FOREACH] = ACTIONS(4804),
    [anon_sym_Foreach] = ACTIONS(4804),
    [anon_sym_while] = ACTIONS(4804),
    [anon_sym_WHILE] = ACTIONS(4804),
    [anon_sym_While] = ACTIONS(4804),
    [anon_sym_repeat] = ACTIONS(4804),
    [anon_sym_REPEAT] = ACTIONS(4804),
    [anon_sym_Repeat] = ACTIONS(4804),
    [anon_sym_exit] = ACTIONS(4804),
    [anon_sym_EXIT] = ACTIONS(4804),
    [anon_sym_Exit] = ACTIONS(4804),
    [anon_sym_continue] = ACTIONS(4804),
    [anon_sym_CONTINUE] = ACTIONS(4804),
    [anon_sym_Continue] = ACTIONS(4804),
    [anon_sym_break] = ACTIONS(4804),
    [anon_sym_BREAK] = ACTIONS(4804),
    [anon_sym_Break] = ACTIONS(4804),
    [anon_sym_with] = ACTIONS(4804),
    [anon_sym_WITH] = ACTIONS(4804),
    [anon_sym_With] = ACTIONS(4804),
    [sym_asserterror_keyword] = ACTIONS(4806),
    [sym_page_keyword] = ACTIONS(4804),
    [anon_sym_codeunit] = ACTIONS(4804),
    [anon_sym_CODEUNIT] = ACTIONS(4804),
    [anon_sym_Codeunit] = ACTIONS(4804),
    [anon_sym_CodeUnit] = ACTIONS(4804),
    [anon_sym_COdeunit] = ACTIONS(4804),
    [anon_sym_codeUnit] = ACTIONS(4804),
    [sym_report_keyword] = ACTIONS(4804),
    [sym_query_keyword] = ACTIONS(4804),
    [anon_sym_xmlport] = ACTIONS(4804),
    [anon_sym_XMLPORT] = ACTIONS(4804),
    [anon_sym_Xmlport] = ACTIONS(4804),
    [anon_sym_XMLport] = ACTIONS(4804),
    [anon_sym_XMLPort] = ACTIONS(4804),
    [anon_sym_XmlPort] = ACTIONS(4804),
    [anon_sym_enum] = ACTIONS(4804),
    [anon_sym_ENUM] = ACTIONS(4804),
    [anon_sym_Enum] = ACTIONS(4804),
    [anon_sym_eNUM] = ACTIONS(4804),
    [anon_sym_eNum] = ACTIONS(4804),
    [anon_sym_ENum] = ACTIONS(4804),
    [sym_quoted_identifier] = ACTIONS(4806),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4806),
    [sym_integer] = ACTIONS(4804),
    [sym_continue_as_identifier] = ACTIONS(4806),
    [sym_preproc_open] = ACTIONS(4806),
    [sym_end_keyword] = ACTIONS(4806),
  },
  [STATE(2246)] = {
    [sym_identifier] = ACTIONS(4680),
    [anon_sym_SEMI] = ACTIONS(4682),
    [anon_sym_DASH] = ACTIONS(4682),
    [aux_sym_boolean_token1] = ACTIONS(4680),
    [aux_sym_boolean_token2] = ACTIONS(4680),
    [sym_decimal] = ACTIONS(4680),
    [anon_sym_LPAREN] = ACTIONS(4682),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4680),
    [anon_sym_LBRACK] = ACTIONS(4682),
    [aux_sym_record_type_token1] = ACTIONS(4680),
    [aux_sym_basic_type_token21] = ACTIONS(4680),
    [aux_sym_basic_type_token22] = ACTIONS(4680),
    [aux_sym_basic_type_token48] = ACTIONS(4680),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4680),
    [anon_sym_POUNDif] = ACTIONS(4682),
    [anon_sym_POUNDIF] = ACTIONS(4682),
    [anon_sym_POUNDIf] = ACTIONS(4682),
    [anon_sym_not] = ACTIONS(4680),
    [anon_sym_NOT] = ACTIONS(4680),
    [anon_sym_Not] = ACTIONS(4680),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4680),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4680),
    [anon_sym_PLUS] = ACTIONS(4682),
    [sym_datetime_literal] = ACTIONS(4682),
    [sym_date_literal] = ACTIONS(4680),
    [sym_time_literal] = ACTIONS(4680),
    [sym_biginteger_literal] = ACTIONS(4682),
    [anon_sym_if] = ACTIONS(4680),
    [anon_sym_IF] = ACTIONS(4680),
    [anon_sym_If] = ACTIONS(4680),
    [anon_sym_else] = ACTIONS(4680),
    [anon_sym_ELSE] = ACTIONS(4680),
    [anon_sym_Else] = ACTIONS(4680),
    [anon_sym_case] = ACTIONS(4680),
    [anon_sym_CASE] = ACTIONS(4680),
    [anon_sym_Case] = ACTIONS(4680),
    [anon_sym_for] = ACTIONS(4680),
    [anon_sym_FOR] = ACTIONS(4680),
    [anon_sym_For] = ACTIONS(4680),
    [anon_sym_foreach] = ACTIONS(4680),
    [anon_sym_FOREACH] = ACTIONS(4680),
    [anon_sym_Foreach] = ACTIONS(4680),
    [anon_sym_while] = ACTIONS(4680),
    [anon_sym_WHILE] = ACTIONS(4680),
    [anon_sym_While] = ACTIONS(4680),
    [anon_sym_repeat] = ACTIONS(4680),
    [anon_sym_REPEAT] = ACTIONS(4680),
    [anon_sym_Repeat] = ACTIONS(4680),
    [anon_sym_exit] = ACTIONS(4680),
    [anon_sym_EXIT] = ACTIONS(4680),
    [anon_sym_Exit] = ACTIONS(4680),
    [anon_sym_continue] = ACTIONS(4680),
    [anon_sym_CONTINUE] = ACTIONS(4680),
    [anon_sym_Continue] = ACTIONS(4680),
    [anon_sym_break] = ACTIONS(4680),
    [anon_sym_BREAK] = ACTIONS(4680),
    [anon_sym_Break] = ACTIONS(4680),
    [anon_sym_with] = ACTIONS(4680),
    [anon_sym_WITH] = ACTIONS(4680),
    [anon_sym_With] = ACTIONS(4680),
    [sym_asserterror_keyword] = ACTIONS(4682),
    [sym_page_keyword] = ACTIONS(4680),
    [anon_sym_codeunit] = ACTIONS(4680),
    [anon_sym_CODEUNIT] = ACTIONS(4680),
    [anon_sym_Codeunit] = ACTIONS(4680),
    [anon_sym_CodeUnit] = ACTIONS(4680),
    [anon_sym_COdeunit] = ACTIONS(4680),
    [anon_sym_codeUnit] = ACTIONS(4680),
    [sym_report_keyword] = ACTIONS(4680),
    [sym_query_keyword] = ACTIONS(4680),
    [anon_sym_xmlport] = ACTIONS(4680),
    [anon_sym_XMLPORT] = ACTIONS(4680),
    [anon_sym_Xmlport] = ACTIONS(4680),
    [anon_sym_XMLport] = ACTIONS(4680),
    [anon_sym_XMLPort] = ACTIONS(4680),
    [anon_sym_XmlPort] = ACTIONS(4680),
    [anon_sym_enum] = ACTIONS(4680),
    [anon_sym_ENUM] = ACTIONS(4680),
    [anon_sym_Enum] = ACTIONS(4680),
    [anon_sym_eNUM] = ACTIONS(4680),
    [anon_sym_eNum] = ACTIONS(4680),
    [anon_sym_ENum] = ACTIONS(4680),
    [sym_quoted_identifier] = ACTIONS(4682),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4682),
    [sym_integer] = ACTIONS(4680),
    [sym_continue_as_identifier] = ACTIONS(4682),
    [sym_preproc_open] = ACTIONS(4682),
    [sym_end_keyword] = ACTIONS(4682),
  },
  [STATE(2247)] = {
    [sym_identifier] = ACTIONS(4684),
    [anon_sym_SEMI] = ACTIONS(4686),
    [anon_sym_DASH] = ACTIONS(4686),
    [aux_sym_boolean_token1] = ACTIONS(4684),
    [aux_sym_boolean_token2] = ACTIONS(4684),
    [sym_decimal] = ACTIONS(4684),
    [anon_sym_LPAREN] = ACTIONS(4686),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4686),
    [aux_sym_record_type_token1] = ACTIONS(4684),
    [aux_sym_basic_type_token21] = ACTIONS(4684),
    [aux_sym_basic_type_token22] = ACTIONS(4684),
    [aux_sym_basic_type_token48] = ACTIONS(4684),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4684),
    [anon_sym_POUNDif] = ACTIONS(4686),
    [anon_sym_POUNDIF] = ACTIONS(4686),
    [anon_sym_POUNDIf] = ACTIONS(4686),
    [anon_sym_not] = ACTIONS(4684),
    [anon_sym_NOT] = ACTIONS(4684),
    [anon_sym_Not] = ACTIONS(4684),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4684),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4684),
    [anon_sym_PLUS] = ACTIONS(4686),
    [sym_datetime_literal] = ACTIONS(4686),
    [sym_date_literal] = ACTIONS(4684),
    [sym_time_literal] = ACTIONS(4684),
    [sym_biginteger_literal] = ACTIONS(4686),
    [anon_sym_if] = ACTIONS(4684),
    [anon_sym_IF] = ACTIONS(4684),
    [anon_sym_If] = ACTIONS(4684),
    [anon_sym_else] = ACTIONS(4684),
    [anon_sym_ELSE] = ACTIONS(4684),
    [anon_sym_Else] = ACTIONS(4684),
    [anon_sym_case] = ACTIONS(4684),
    [anon_sym_CASE] = ACTIONS(4684),
    [anon_sym_Case] = ACTIONS(4684),
    [anon_sym_for] = ACTIONS(4684),
    [anon_sym_FOR] = ACTIONS(4684),
    [anon_sym_For] = ACTIONS(4684),
    [anon_sym_foreach] = ACTIONS(4684),
    [anon_sym_FOREACH] = ACTIONS(4684),
    [anon_sym_Foreach] = ACTIONS(4684),
    [anon_sym_while] = ACTIONS(4684),
    [anon_sym_WHILE] = ACTIONS(4684),
    [anon_sym_While] = ACTIONS(4684),
    [anon_sym_repeat] = ACTIONS(4684),
    [anon_sym_REPEAT] = ACTIONS(4684),
    [anon_sym_Repeat] = ACTIONS(4684),
    [anon_sym_exit] = ACTIONS(4684),
    [anon_sym_EXIT] = ACTIONS(4684),
    [anon_sym_Exit] = ACTIONS(4684),
    [anon_sym_continue] = ACTIONS(4684),
    [anon_sym_CONTINUE] = ACTIONS(4684),
    [anon_sym_Continue] = ACTIONS(4684),
    [anon_sym_break] = ACTIONS(4684),
    [anon_sym_BREAK] = ACTIONS(4684),
    [anon_sym_Break] = ACTIONS(4684),
    [anon_sym_with] = ACTIONS(4684),
    [anon_sym_WITH] = ACTIONS(4684),
    [anon_sym_With] = ACTIONS(4684),
    [sym_asserterror_keyword] = ACTIONS(4686),
    [sym_page_keyword] = ACTIONS(4684),
    [anon_sym_codeunit] = ACTIONS(4684),
    [anon_sym_CODEUNIT] = ACTIONS(4684),
    [anon_sym_Codeunit] = ACTIONS(4684),
    [anon_sym_CodeUnit] = ACTIONS(4684),
    [anon_sym_COdeunit] = ACTIONS(4684),
    [anon_sym_codeUnit] = ACTIONS(4684),
    [sym_report_keyword] = ACTIONS(4684),
    [sym_query_keyword] = ACTIONS(4684),
    [anon_sym_xmlport] = ACTIONS(4684),
    [anon_sym_XMLPORT] = ACTIONS(4684),
    [anon_sym_Xmlport] = ACTIONS(4684),
    [anon_sym_XMLport] = ACTIONS(4684),
    [anon_sym_XMLPort] = ACTIONS(4684),
    [anon_sym_XmlPort] = ACTIONS(4684),
    [anon_sym_enum] = ACTIONS(4684),
    [anon_sym_ENUM] = ACTIONS(4684),
    [anon_sym_Enum] = ACTIONS(4684),
    [anon_sym_eNUM] = ACTIONS(4684),
    [anon_sym_eNum] = ACTIONS(4684),
    [anon_sym_ENum] = ACTIONS(4684),
    [sym_quoted_identifier] = ACTIONS(4686),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4686),
    [sym_integer] = ACTIONS(4684),
    [sym_continue_as_identifier] = ACTIONS(4686),
    [sym_preproc_open] = ACTIONS(4686),
    [sym_end_keyword] = ACTIONS(4686),
  },
  [STATE(2248)] = {
    [sym_identifier] = ACTIONS(4555),
    [anon_sym_SEMI] = ACTIONS(4557),
    [anon_sym_DASH] = ACTIONS(4557),
    [aux_sym_boolean_token1] = ACTIONS(4555),
    [aux_sym_boolean_token2] = ACTIONS(4555),
    [sym_decimal] = ACTIONS(4555),
    [anon_sym_LPAREN] = ACTIONS(4557),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4555),
    [anon_sym_LBRACK] = ACTIONS(4557),
    [aux_sym_record_type_token1] = ACTIONS(4555),
    [aux_sym_basic_type_token21] = ACTIONS(4555),
    [aux_sym_basic_type_token22] = ACTIONS(4555),
    [aux_sym_basic_type_token48] = ACTIONS(4555),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4555),
    [anon_sym_POUNDif] = ACTIONS(4557),
    [anon_sym_POUNDIF] = ACTIONS(4557),
    [anon_sym_POUNDIf] = ACTIONS(4557),
    [anon_sym_not] = ACTIONS(4555),
    [anon_sym_NOT] = ACTIONS(4555),
    [anon_sym_Not] = ACTIONS(4555),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4555),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4555),
    [anon_sym_PLUS] = ACTIONS(4557),
    [sym_datetime_literal] = ACTIONS(4557),
    [sym_date_literal] = ACTIONS(4555),
    [sym_time_literal] = ACTIONS(4555),
    [sym_biginteger_literal] = ACTIONS(4557),
    [anon_sym_if] = ACTIONS(4555),
    [anon_sym_IF] = ACTIONS(4555),
    [anon_sym_If] = ACTIONS(4555),
    [anon_sym_else] = ACTIONS(4555),
    [anon_sym_ELSE] = ACTIONS(4555),
    [anon_sym_Else] = ACTIONS(4555),
    [anon_sym_case] = ACTIONS(4555),
    [anon_sym_CASE] = ACTIONS(4555),
    [anon_sym_Case] = ACTIONS(4555),
    [anon_sym_for] = ACTIONS(4555),
    [anon_sym_FOR] = ACTIONS(4555),
    [anon_sym_For] = ACTIONS(4555),
    [anon_sym_foreach] = ACTIONS(4555),
    [anon_sym_FOREACH] = ACTIONS(4555),
    [anon_sym_Foreach] = ACTIONS(4555),
    [anon_sym_while] = ACTIONS(4555),
    [anon_sym_WHILE] = ACTIONS(4555),
    [anon_sym_While] = ACTIONS(4555),
    [anon_sym_repeat] = ACTIONS(4555),
    [anon_sym_REPEAT] = ACTIONS(4555),
    [anon_sym_Repeat] = ACTIONS(4555),
    [anon_sym_exit] = ACTIONS(4555),
    [anon_sym_EXIT] = ACTIONS(4555),
    [anon_sym_Exit] = ACTIONS(4555),
    [anon_sym_continue] = ACTIONS(4555),
    [anon_sym_CONTINUE] = ACTIONS(4555),
    [anon_sym_Continue] = ACTIONS(4555),
    [anon_sym_break] = ACTIONS(4555),
    [anon_sym_BREAK] = ACTIONS(4555),
    [anon_sym_Break] = ACTIONS(4555),
    [anon_sym_with] = ACTIONS(4555),
    [anon_sym_WITH] = ACTIONS(4555),
    [anon_sym_With] = ACTIONS(4555),
    [sym_asserterror_keyword] = ACTIONS(4557),
    [sym_page_keyword] = ACTIONS(4555),
    [anon_sym_codeunit] = ACTIONS(4555),
    [anon_sym_CODEUNIT] = ACTIONS(4555),
    [anon_sym_Codeunit] = ACTIONS(4555),
    [anon_sym_CodeUnit] = ACTIONS(4555),
    [anon_sym_COdeunit] = ACTIONS(4555),
    [anon_sym_codeUnit] = ACTIONS(4555),
    [sym_report_keyword] = ACTIONS(4555),
    [sym_query_keyword] = ACTIONS(4555),
    [anon_sym_xmlport] = ACTIONS(4555),
    [anon_sym_XMLPORT] = ACTIONS(4555),
    [anon_sym_Xmlport] = ACTIONS(4555),
    [anon_sym_XMLport] = ACTIONS(4555),
    [anon_sym_XMLPort] = ACTIONS(4555),
    [anon_sym_XmlPort] = ACTIONS(4555),
    [anon_sym_enum] = ACTIONS(4555),
    [anon_sym_ENUM] = ACTIONS(4555),
    [anon_sym_Enum] = ACTIONS(4555),
    [anon_sym_eNUM] = ACTIONS(4555),
    [anon_sym_eNum] = ACTIONS(4555),
    [anon_sym_ENum] = ACTIONS(4555),
    [sym_quoted_identifier] = ACTIONS(4557),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4557),
    [sym_integer] = ACTIONS(4555),
    [sym_continue_as_identifier] = ACTIONS(4557),
    [sym_preproc_open] = ACTIONS(4557),
    [sym_end_keyword] = ACTIONS(4557),
  },
  [STATE(2249)] = {
    [sym_identifier] = ACTIONS(4772),
    [anon_sym_SEMI] = ACTIONS(4774),
    [anon_sym_DASH] = ACTIONS(4774),
    [aux_sym_boolean_token1] = ACTIONS(4772),
    [aux_sym_boolean_token2] = ACTIONS(4772),
    [sym_decimal] = ACTIONS(4772),
    [anon_sym_LPAREN] = ACTIONS(4774),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4772),
    [anon_sym_LBRACK] = ACTIONS(4774),
    [aux_sym_record_type_token1] = ACTIONS(4772),
    [aux_sym_basic_type_token21] = ACTIONS(4772),
    [aux_sym_basic_type_token22] = ACTIONS(4772),
    [aux_sym_basic_type_token48] = ACTIONS(4772),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4772),
    [anon_sym_POUNDif] = ACTIONS(4774),
    [anon_sym_POUNDIF] = ACTIONS(4774),
    [anon_sym_POUNDIf] = ACTIONS(4774),
    [anon_sym_not] = ACTIONS(4772),
    [anon_sym_NOT] = ACTIONS(4772),
    [anon_sym_Not] = ACTIONS(4772),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4772),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4772),
    [anon_sym_PLUS] = ACTIONS(4774),
    [sym_datetime_literal] = ACTIONS(4774),
    [sym_date_literal] = ACTIONS(4772),
    [sym_time_literal] = ACTIONS(4772),
    [sym_biginteger_literal] = ACTIONS(4774),
    [anon_sym_if] = ACTIONS(4772),
    [anon_sym_IF] = ACTIONS(4772),
    [anon_sym_If] = ACTIONS(4772),
    [anon_sym_else] = ACTIONS(4772),
    [anon_sym_ELSE] = ACTIONS(4772),
    [anon_sym_Else] = ACTIONS(4772),
    [anon_sym_case] = ACTIONS(4772),
    [anon_sym_CASE] = ACTIONS(4772),
    [anon_sym_Case] = ACTIONS(4772),
    [anon_sym_for] = ACTIONS(4772),
    [anon_sym_FOR] = ACTIONS(4772),
    [anon_sym_For] = ACTIONS(4772),
    [anon_sym_foreach] = ACTIONS(4772),
    [anon_sym_FOREACH] = ACTIONS(4772),
    [anon_sym_Foreach] = ACTIONS(4772),
    [anon_sym_while] = ACTIONS(4772),
    [anon_sym_WHILE] = ACTIONS(4772),
    [anon_sym_While] = ACTIONS(4772),
    [anon_sym_repeat] = ACTIONS(4772),
    [anon_sym_REPEAT] = ACTIONS(4772),
    [anon_sym_Repeat] = ACTIONS(4772),
    [anon_sym_exit] = ACTIONS(4772),
    [anon_sym_EXIT] = ACTIONS(4772),
    [anon_sym_Exit] = ACTIONS(4772),
    [anon_sym_continue] = ACTIONS(4772),
    [anon_sym_CONTINUE] = ACTIONS(4772),
    [anon_sym_Continue] = ACTIONS(4772),
    [anon_sym_break] = ACTIONS(4772),
    [anon_sym_BREAK] = ACTIONS(4772),
    [anon_sym_Break] = ACTIONS(4772),
    [anon_sym_with] = ACTIONS(4772),
    [anon_sym_WITH] = ACTIONS(4772),
    [anon_sym_With] = ACTIONS(4772),
    [sym_asserterror_keyword] = ACTIONS(4774),
    [sym_page_keyword] = ACTIONS(4772),
    [anon_sym_codeunit] = ACTIONS(4772),
    [anon_sym_CODEUNIT] = ACTIONS(4772),
    [anon_sym_Codeunit] = ACTIONS(4772),
    [anon_sym_CodeUnit] = ACTIONS(4772),
    [anon_sym_COdeunit] = ACTIONS(4772),
    [anon_sym_codeUnit] = ACTIONS(4772),
    [sym_report_keyword] = ACTIONS(4772),
    [sym_query_keyword] = ACTIONS(4772),
    [anon_sym_xmlport] = ACTIONS(4772),
    [anon_sym_XMLPORT] = ACTIONS(4772),
    [anon_sym_Xmlport] = ACTIONS(4772),
    [anon_sym_XMLport] = ACTIONS(4772),
    [anon_sym_XMLPort] = ACTIONS(4772),
    [anon_sym_XmlPort] = ACTIONS(4772),
    [anon_sym_enum] = ACTIONS(4772),
    [anon_sym_ENUM] = ACTIONS(4772),
    [anon_sym_Enum] = ACTIONS(4772),
    [anon_sym_eNUM] = ACTIONS(4772),
    [anon_sym_eNum] = ACTIONS(4772),
    [anon_sym_ENum] = ACTIONS(4772),
    [sym_quoted_identifier] = ACTIONS(4774),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4774),
    [sym_integer] = ACTIONS(4772),
    [sym_continue_as_identifier] = ACTIONS(4774),
    [sym_preproc_open] = ACTIONS(4774),
    [sym_end_keyword] = ACTIONS(4774),
  },
  [STATE(2250)] = {
    [sym_identifier] = ACTIONS(4185),
    [anon_sym_SEMI] = ACTIONS(4187),
    [anon_sym_DASH] = ACTIONS(4187),
    [aux_sym_boolean_token1] = ACTIONS(4185),
    [aux_sym_boolean_token2] = ACTIONS(4185),
    [sym_decimal] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4187),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4185),
    [anon_sym_LBRACK] = ACTIONS(4187),
    [aux_sym_record_type_token1] = ACTIONS(4185),
    [aux_sym_basic_type_token21] = ACTIONS(4185),
    [aux_sym_basic_type_token22] = ACTIONS(4185),
    [aux_sym_basic_type_token48] = ACTIONS(4185),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4185),
    [anon_sym_POUNDif] = ACTIONS(4187),
    [anon_sym_POUNDIF] = ACTIONS(4187),
    [anon_sym_POUNDIf] = ACTIONS(4187),
    [anon_sym_not] = ACTIONS(4185),
    [anon_sym_NOT] = ACTIONS(4185),
    [anon_sym_Not] = ACTIONS(4185),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4185),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4187),
    [sym_datetime_literal] = ACTIONS(4187),
    [sym_date_literal] = ACTIONS(4185),
    [sym_time_literal] = ACTIONS(4185),
    [sym_biginteger_literal] = ACTIONS(4187),
    [anon_sym_if] = ACTIONS(4185),
    [anon_sym_IF] = ACTIONS(4185),
    [anon_sym_If] = ACTIONS(4185),
    [anon_sym_else] = ACTIONS(4185),
    [anon_sym_ELSE] = ACTIONS(4185),
    [anon_sym_Else] = ACTIONS(4185),
    [anon_sym_case] = ACTIONS(4185),
    [anon_sym_CASE] = ACTIONS(4185),
    [anon_sym_Case] = ACTIONS(4185),
    [anon_sym_for] = ACTIONS(4185),
    [anon_sym_FOR] = ACTIONS(4185),
    [anon_sym_For] = ACTIONS(4185),
    [anon_sym_foreach] = ACTIONS(4185),
    [anon_sym_FOREACH] = ACTIONS(4185),
    [anon_sym_Foreach] = ACTIONS(4185),
    [anon_sym_while] = ACTIONS(4185),
    [anon_sym_WHILE] = ACTIONS(4185),
    [anon_sym_While] = ACTIONS(4185),
    [anon_sym_repeat] = ACTIONS(4185),
    [anon_sym_REPEAT] = ACTIONS(4185),
    [anon_sym_Repeat] = ACTIONS(4185),
    [anon_sym_exit] = ACTIONS(4185),
    [anon_sym_EXIT] = ACTIONS(4185),
    [anon_sym_Exit] = ACTIONS(4185),
    [anon_sym_continue] = ACTIONS(4185),
    [anon_sym_CONTINUE] = ACTIONS(4185),
    [anon_sym_Continue] = ACTIONS(4185),
    [anon_sym_break] = ACTIONS(4185),
    [anon_sym_BREAK] = ACTIONS(4185),
    [anon_sym_Break] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4185),
    [anon_sym_WITH] = ACTIONS(4185),
    [anon_sym_With] = ACTIONS(4185),
    [sym_asserterror_keyword] = ACTIONS(4187),
    [sym_page_keyword] = ACTIONS(4185),
    [anon_sym_codeunit] = ACTIONS(4185),
    [anon_sym_CODEUNIT] = ACTIONS(4185),
    [anon_sym_Codeunit] = ACTIONS(4185),
    [anon_sym_CodeUnit] = ACTIONS(4185),
    [anon_sym_COdeunit] = ACTIONS(4185),
    [anon_sym_codeUnit] = ACTIONS(4185),
    [sym_report_keyword] = ACTIONS(4185),
    [sym_query_keyword] = ACTIONS(4185),
    [anon_sym_xmlport] = ACTIONS(4185),
    [anon_sym_XMLPORT] = ACTIONS(4185),
    [anon_sym_Xmlport] = ACTIONS(4185),
    [anon_sym_XMLport] = ACTIONS(4185),
    [anon_sym_XMLPort] = ACTIONS(4185),
    [anon_sym_XmlPort] = ACTIONS(4185),
    [anon_sym_enum] = ACTIONS(4185),
    [anon_sym_ENUM] = ACTIONS(4185),
    [anon_sym_Enum] = ACTIONS(4185),
    [anon_sym_eNUM] = ACTIONS(4185),
    [anon_sym_eNum] = ACTIONS(4185),
    [anon_sym_ENum] = ACTIONS(4185),
    [sym_quoted_identifier] = ACTIONS(4187),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4187),
    [sym_integer] = ACTIONS(4185),
    [sym_continue_as_identifier] = ACTIONS(4187),
    [sym_preproc_open] = ACTIONS(4187),
    [sym_end_keyword] = ACTIONS(4187),
  },
  [STATE(2251)] = {
    [sym_identifier] = ACTIONS(4756),
    [anon_sym_SEMI] = ACTIONS(4758),
    [anon_sym_DASH] = ACTIONS(4758),
    [aux_sym_boolean_token1] = ACTIONS(4756),
    [aux_sym_boolean_token2] = ACTIONS(4756),
    [sym_decimal] = ACTIONS(4756),
    [anon_sym_LPAREN] = ACTIONS(4758),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4756),
    [anon_sym_LBRACK] = ACTIONS(4758),
    [aux_sym_record_type_token1] = ACTIONS(4756),
    [aux_sym_basic_type_token21] = ACTIONS(4756),
    [aux_sym_basic_type_token22] = ACTIONS(4756),
    [aux_sym_basic_type_token48] = ACTIONS(4756),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4756),
    [anon_sym_POUNDif] = ACTIONS(4758),
    [anon_sym_POUNDIF] = ACTIONS(4758),
    [anon_sym_POUNDIf] = ACTIONS(4758),
    [anon_sym_not] = ACTIONS(4756),
    [anon_sym_NOT] = ACTIONS(4756),
    [anon_sym_Not] = ACTIONS(4756),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4756),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4756),
    [anon_sym_PLUS] = ACTIONS(4758),
    [sym_datetime_literal] = ACTIONS(4758),
    [sym_date_literal] = ACTIONS(4756),
    [sym_time_literal] = ACTIONS(4756),
    [sym_biginteger_literal] = ACTIONS(4758),
    [anon_sym_if] = ACTIONS(4756),
    [anon_sym_IF] = ACTIONS(4756),
    [anon_sym_If] = ACTIONS(4756),
    [anon_sym_else] = ACTIONS(4756),
    [anon_sym_ELSE] = ACTIONS(4756),
    [anon_sym_Else] = ACTIONS(4756),
    [anon_sym_case] = ACTIONS(4756),
    [anon_sym_CASE] = ACTIONS(4756),
    [anon_sym_Case] = ACTIONS(4756),
    [anon_sym_for] = ACTIONS(4756),
    [anon_sym_FOR] = ACTIONS(4756),
    [anon_sym_For] = ACTIONS(4756),
    [anon_sym_foreach] = ACTIONS(4756),
    [anon_sym_FOREACH] = ACTIONS(4756),
    [anon_sym_Foreach] = ACTIONS(4756),
    [anon_sym_while] = ACTIONS(4756),
    [anon_sym_WHILE] = ACTIONS(4756),
    [anon_sym_While] = ACTIONS(4756),
    [anon_sym_repeat] = ACTIONS(4756),
    [anon_sym_REPEAT] = ACTIONS(4756),
    [anon_sym_Repeat] = ACTIONS(4756),
    [anon_sym_exit] = ACTIONS(4756),
    [anon_sym_EXIT] = ACTIONS(4756),
    [anon_sym_Exit] = ACTIONS(4756),
    [anon_sym_continue] = ACTIONS(4756),
    [anon_sym_CONTINUE] = ACTIONS(4756),
    [anon_sym_Continue] = ACTIONS(4756),
    [anon_sym_break] = ACTIONS(4756),
    [anon_sym_BREAK] = ACTIONS(4756),
    [anon_sym_Break] = ACTIONS(4756),
    [anon_sym_with] = ACTIONS(4756),
    [anon_sym_WITH] = ACTIONS(4756),
    [anon_sym_With] = ACTIONS(4756),
    [sym_asserterror_keyword] = ACTIONS(4758),
    [sym_page_keyword] = ACTIONS(4756),
    [anon_sym_codeunit] = ACTIONS(4756),
    [anon_sym_CODEUNIT] = ACTIONS(4756),
    [anon_sym_Codeunit] = ACTIONS(4756),
    [anon_sym_CodeUnit] = ACTIONS(4756),
    [anon_sym_COdeunit] = ACTIONS(4756),
    [anon_sym_codeUnit] = ACTIONS(4756),
    [sym_report_keyword] = ACTIONS(4756),
    [sym_query_keyword] = ACTIONS(4756),
    [anon_sym_xmlport] = ACTIONS(4756),
    [anon_sym_XMLPORT] = ACTIONS(4756),
    [anon_sym_Xmlport] = ACTIONS(4756),
    [anon_sym_XMLport] = ACTIONS(4756),
    [anon_sym_XMLPort] = ACTIONS(4756),
    [anon_sym_XmlPort] = ACTIONS(4756),
    [anon_sym_enum] = ACTIONS(4756),
    [anon_sym_ENUM] = ACTIONS(4756),
    [anon_sym_Enum] = ACTIONS(4756),
    [anon_sym_eNUM] = ACTIONS(4756),
    [anon_sym_eNum] = ACTIONS(4756),
    [anon_sym_ENum] = ACTIONS(4756),
    [sym_quoted_identifier] = ACTIONS(4758),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4758),
    [sym_integer] = ACTIONS(4756),
    [sym_continue_as_identifier] = ACTIONS(4758),
    [sym_preproc_open] = ACTIONS(4758),
    [sym_end_keyword] = ACTIONS(4758),
  },
  [STATE(2252)] = {
    [sym_identifier] = ACTIONS(4760),
    [anon_sym_SEMI] = ACTIONS(4762),
    [anon_sym_DASH] = ACTIONS(4762),
    [aux_sym_boolean_token1] = ACTIONS(4760),
    [aux_sym_boolean_token2] = ACTIONS(4760),
    [sym_decimal] = ACTIONS(4760),
    [anon_sym_LPAREN] = ACTIONS(4762),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4760),
    [anon_sym_LBRACK] = ACTIONS(4762),
    [aux_sym_record_type_token1] = ACTIONS(4760),
    [aux_sym_basic_type_token21] = ACTIONS(4760),
    [aux_sym_basic_type_token22] = ACTIONS(4760),
    [aux_sym_basic_type_token48] = ACTIONS(4760),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4760),
    [anon_sym_POUNDif] = ACTIONS(4762),
    [anon_sym_POUNDIF] = ACTIONS(4762),
    [anon_sym_POUNDIf] = ACTIONS(4762),
    [anon_sym_not] = ACTIONS(4760),
    [anon_sym_NOT] = ACTIONS(4760),
    [anon_sym_Not] = ACTIONS(4760),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4760),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4760),
    [anon_sym_PLUS] = ACTIONS(4762),
    [sym_datetime_literal] = ACTIONS(4762),
    [sym_date_literal] = ACTIONS(4760),
    [sym_time_literal] = ACTIONS(4760),
    [sym_biginteger_literal] = ACTIONS(4762),
    [anon_sym_if] = ACTIONS(4760),
    [anon_sym_IF] = ACTIONS(4760),
    [anon_sym_If] = ACTIONS(4760),
    [anon_sym_else] = ACTIONS(4760),
    [anon_sym_ELSE] = ACTIONS(4760),
    [anon_sym_Else] = ACTIONS(4760),
    [anon_sym_case] = ACTIONS(4760),
    [anon_sym_CASE] = ACTIONS(4760),
    [anon_sym_Case] = ACTIONS(4760),
    [anon_sym_for] = ACTIONS(4760),
    [anon_sym_FOR] = ACTIONS(4760),
    [anon_sym_For] = ACTIONS(4760),
    [anon_sym_foreach] = ACTIONS(4760),
    [anon_sym_FOREACH] = ACTIONS(4760),
    [anon_sym_Foreach] = ACTIONS(4760),
    [anon_sym_while] = ACTIONS(4760),
    [anon_sym_WHILE] = ACTIONS(4760),
    [anon_sym_While] = ACTIONS(4760),
    [anon_sym_repeat] = ACTIONS(4760),
    [anon_sym_REPEAT] = ACTIONS(4760),
    [anon_sym_Repeat] = ACTIONS(4760),
    [anon_sym_exit] = ACTIONS(4760),
    [anon_sym_EXIT] = ACTIONS(4760),
    [anon_sym_Exit] = ACTIONS(4760),
    [anon_sym_continue] = ACTIONS(4760),
    [anon_sym_CONTINUE] = ACTIONS(4760),
    [anon_sym_Continue] = ACTIONS(4760),
    [anon_sym_break] = ACTIONS(4760),
    [anon_sym_BREAK] = ACTIONS(4760),
    [anon_sym_Break] = ACTIONS(4760),
    [anon_sym_with] = ACTIONS(4760),
    [anon_sym_WITH] = ACTIONS(4760),
    [anon_sym_With] = ACTIONS(4760),
    [sym_asserterror_keyword] = ACTIONS(4762),
    [sym_page_keyword] = ACTIONS(4760),
    [anon_sym_codeunit] = ACTIONS(4760),
    [anon_sym_CODEUNIT] = ACTIONS(4760),
    [anon_sym_Codeunit] = ACTIONS(4760),
    [anon_sym_CodeUnit] = ACTIONS(4760),
    [anon_sym_COdeunit] = ACTIONS(4760),
    [anon_sym_codeUnit] = ACTIONS(4760),
    [sym_report_keyword] = ACTIONS(4760),
    [sym_query_keyword] = ACTIONS(4760),
    [anon_sym_xmlport] = ACTIONS(4760),
    [anon_sym_XMLPORT] = ACTIONS(4760),
    [anon_sym_Xmlport] = ACTIONS(4760),
    [anon_sym_XMLport] = ACTIONS(4760),
    [anon_sym_XMLPort] = ACTIONS(4760),
    [anon_sym_XmlPort] = ACTIONS(4760),
    [anon_sym_enum] = ACTIONS(4760),
    [anon_sym_ENUM] = ACTIONS(4760),
    [anon_sym_Enum] = ACTIONS(4760),
    [anon_sym_eNUM] = ACTIONS(4760),
    [anon_sym_eNum] = ACTIONS(4760),
    [anon_sym_ENum] = ACTIONS(4760),
    [sym_quoted_identifier] = ACTIONS(4762),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4762),
    [sym_integer] = ACTIONS(4760),
    [sym_continue_as_identifier] = ACTIONS(4762),
    [sym_preproc_open] = ACTIONS(4762),
    [sym_end_keyword] = ACTIONS(4762),
  },
  [STATE(2253)] = {
    [sym_identifier] = ACTIONS(4193),
    [anon_sym_SEMI] = ACTIONS(4195),
    [anon_sym_DASH] = ACTIONS(4195),
    [aux_sym_boolean_token1] = ACTIONS(4193),
    [aux_sym_boolean_token2] = ACTIONS(4193),
    [sym_decimal] = ACTIONS(4193),
    [anon_sym_LPAREN] = ACTIONS(4195),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4193),
    [anon_sym_LBRACK] = ACTIONS(4195),
    [aux_sym_record_type_token1] = ACTIONS(4193),
    [aux_sym_basic_type_token21] = ACTIONS(4193),
    [aux_sym_basic_type_token22] = ACTIONS(4193),
    [aux_sym_basic_type_token48] = ACTIONS(4193),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4193),
    [anon_sym_POUNDif] = ACTIONS(4195),
    [anon_sym_POUNDIF] = ACTIONS(4195),
    [anon_sym_POUNDIf] = ACTIONS(4195),
    [anon_sym_not] = ACTIONS(4193),
    [anon_sym_NOT] = ACTIONS(4193),
    [anon_sym_Not] = ACTIONS(4193),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4193),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4193),
    [anon_sym_PLUS] = ACTIONS(4195),
    [sym_datetime_literal] = ACTIONS(4195),
    [sym_date_literal] = ACTIONS(4193),
    [sym_time_literal] = ACTIONS(4193),
    [sym_biginteger_literal] = ACTIONS(4195),
    [anon_sym_if] = ACTIONS(4193),
    [anon_sym_IF] = ACTIONS(4193),
    [anon_sym_If] = ACTIONS(4193),
    [anon_sym_else] = ACTIONS(4193),
    [anon_sym_ELSE] = ACTIONS(4193),
    [anon_sym_Else] = ACTIONS(4193),
    [anon_sym_case] = ACTIONS(4193),
    [anon_sym_CASE] = ACTIONS(4193),
    [anon_sym_Case] = ACTIONS(4193),
    [anon_sym_for] = ACTIONS(4193),
    [anon_sym_FOR] = ACTIONS(4193),
    [anon_sym_For] = ACTIONS(4193),
    [anon_sym_foreach] = ACTIONS(4193),
    [anon_sym_FOREACH] = ACTIONS(4193),
    [anon_sym_Foreach] = ACTIONS(4193),
    [anon_sym_while] = ACTIONS(4193),
    [anon_sym_WHILE] = ACTIONS(4193),
    [anon_sym_While] = ACTIONS(4193),
    [anon_sym_repeat] = ACTIONS(4193),
    [anon_sym_REPEAT] = ACTIONS(4193),
    [anon_sym_Repeat] = ACTIONS(4193),
    [anon_sym_exit] = ACTIONS(4193),
    [anon_sym_EXIT] = ACTIONS(4193),
    [anon_sym_Exit] = ACTIONS(4193),
    [anon_sym_continue] = ACTIONS(4193),
    [anon_sym_CONTINUE] = ACTIONS(4193),
    [anon_sym_Continue] = ACTIONS(4193),
    [anon_sym_break] = ACTIONS(4193),
    [anon_sym_BREAK] = ACTIONS(4193),
    [anon_sym_Break] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4193),
    [anon_sym_WITH] = ACTIONS(4193),
    [anon_sym_With] = ACTIONS(4193),
    [sym_asserterror_keyword] = ACTIONS(4195),
    [sym_page_keyword] = ACTIONS(4193),
    [anon_sym_codeunit] = ACTIONS(4193),
    [anon_sym_CODEUNIT] = ACTIONS(4193),
    [anon_sym_Codeunit] = ACTIONS(4193),
    [anon_sym_CodeUnit] = ACTIONS(4193),
    [anon_sym_COdeunit] = ACTIONS(4193),
    [anon_sym_codeUnit] = ACTIONS(4193),
    [sym_report_keyword] = ACTIONS(4193),
    [sym_query_keyword] = ACTIONS(4193),
    [anon_sym_xmlport] = ACTIONS(4193),
    [anon_sym_XMLPORT] = ACTIONS(4193),
    [anon_sym_Xmlport] = ACTIONS(4193),
    [anon_sym_XMLport] = ACTIONS(4193),
    [anon_sym_XMLPort] = ACTIONS(4193),
    [anon_sym_XmlPort] = ACTIONS(4193),
    [anon_sym_enum] = ACTIONS(4193),
    [anon_sym_ENUM] = ACTIONS(4193),
    [anon_sym_Enum] = ACTIONS(4193),
    [anon_sym_eNUM] = ACTIONS(4193),
    [anon_sym_eNum] = ACTIONS(4193),
    [anon_sym_ENum] = ACTIONS(4193),
    [sym_quoted_identifier] = ACTIONS(4195),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4195),
    [sym_integer] = ACTIONS(4193),
    [sym_continue_as_identifier] = ACTIONS(4195),
    [sym_preproc_open] = ACTIONS(4195),
    [sym_end_keyword] = ACTIONS(4195),
  },
  [STATE(2254)] = {
    [sym_identifier] = ACTIONS(4197),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_DASH] = ACTIONS(4199),
    [aux_sym_boolean_token1] = ACTIONS(4197),
    [aux_sym_boolean_token2] = ACTIONS(4197),
    [sym_decimal] = ACTIONS(4197),
    [anon_sym_LPAREN] = ACTIONS(4199),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4197),
    [anon_sym_LBRACK] = ACTIONS(4199),
    [aux_sym_record_type_token1] = ACTIONS(4197),
    [aux_sym_basic_type_token21] = ACTIONS(4197),
    [aux_sym_basic_type_token22] = ACTIONS(4197),
    [aux_sym_basic_type_token48] = ACTIONS(4197),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4197),
    [anon_sym_POUNDif] = ACTIONS(4199),
    [anon_sym_POUNDIF] = ACTIONS(4199),
    [anon_sym_POUNDIf] = ACTIONS(4199),
    [anon_sym_not] = ACTIONS(4197),
    [anon_sym_NOT] = ACTIONS(4197),
    [anon_sym_Not] = ACTIONS(4197),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4197),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4197),
    [anon_sym_PLUS] = ACTIONS(4199),
    [sym_datetime_literal] = ACTIONS(4199),
    [sym_date_literal] = ACTIONS(4197),
    [sym_time_literal] = ACTIONS(4197),
    [sym_biginteger_literal] = ACTIONS(4199),
    [anon_sym_if] = ACTIONS(4197),
    [anon_sym_IF] = ACTIONS(4197),
    [anon_sym_If] = ACTIONS(4197),
    [anon_sym_else] = ACTIONS(4197),
    [anon_sym_ELSE] = ACTIONS(4197),
    [anon_sym_Else] = ACTIONS(4197),
    [anon_sym_case] = ACTIONS(4197),
    [anon_sym_CASE] = ACTIONS(4197),
    [anon_sym_Case] = ACTIONS(4197),
    [anon_sym_for] = ACTIONS(4197),
    [anon_sym_FOR] = ACTIONS(4197),
    [anon_sym_For] = ACTIONS(4197),
    [anon_sym_foreach] = ACTIONS(4197),
    [anon_sym_FOREACH] = ACTIONS(4197),
    [anon_sym_Foreach] = ACTIONS(4197),
    [anon_sym_while] = ACTIONS(4197),
    [anon_sym_WHILE] = ACTIONS(4197),
    [anon_sym_While] = ACTIONS(4197),
    [anon_sym_repeat] = ACTIONS(4197),
    [anon_sym_REPEAT] = ACTIONS(4197),
    [anon_sym_Repeat] = ACTIONS(4197),
    [anon_sym_exit] = ACTIONS(4197),
    [anon_sym_EXIT] = ACTIONS(4197),
    [anon_sym_Exit] = ACTIONS(4197),
    [anon_sym_continue] = ACTIONS(4197),
    [anon_sym_CONTINUE] = ACTIONS(4197),
    [anon_sym_Continue] = ACTIONS(4197),
    [anon_sym_break] = ACTIONS(4197),
    [anon_sym_BREAK] = ACTIONS(4197),
    [anon_sym_Break] = ACTIONS(4197),
    [anon_sym_with] = ACTIONS(4197),
    [anon_sym_WITH] = ACTIONS(4197),
    [anon_sym_With] = ACTIONS(4197),
    [sym_asserterror_keyword] = ACTIONS(4199),
    [sym_page_keyword] = ACTIONS(4197),
    [anon_sym_codeunit] = ACTIONS(4197),
    [anon_sym_CODEUNIT] = ACTIONS(4197),
    [anon_sym_Codeunit] = ACTIONS(4197),
    [anon_sym_CodeUnit] = ACTIONS(4197),
    [anon_sym_COdeunit] = ACTIONS(4197),
    [anon_sym_codeUnit] = ACTIONS(4197),
    [sym_report_keyword] = ACTIONS(4197),
    [sym_query_keyword] = ACTIONS(4197),
    [anon_sym_xmlport] = ACTIONS(4197),
    [anon_sym_XMLPORT] = ACTIONS(4197),
    [anon_sym_Xmlport] = ACTIONS(4197),
    [anon_sym_XMLport] = ACTIONS(4197),
    [anon_sym_XMLPort] = ACTIONS(4197),
    [anon_sym_XmlPort] = ACTIONS(4197),
    [anon_sym_enum] = ACTIONS(4197),
    [anon_sym_ENUM] = ACTIONS(4197),
    [anon_sym_Enum] = ACTIONS(4197),
    [anon_sym_eNUM] = ACTIONS(4197),
    [anon_sym_eNum] = ACTIONS(4197),
    [anon_sym_ENum] = ACTIONS(4197),
    [sym_quoted_identifier] = ACTIONS(4199),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4199),
    [sym_integer] = ACTIONS(4197),
    [sym_continue_as_identifier] = ACTIONS(4199),
    [sym_preproc_open] = ACTIONS(4199),
    [sym_end_keyword] = ACTIONS(4199),
  },
  [STATE(2255)] = {
    [sym_identifier] = ACTIONS(4201),
    [anon_sym_SEMI] = ACTIONS(4203),
    [anon_sym_DASH] = ACTIONS(4203),
    [aux_sym_boolean_token1] = ACTIONS(4201),
    [aux_sym_boolean_token2] = ACTIONS(4201),
    [sym_decimal] = ACTIONS(4201),
    [anon_sym_LPAREN] = ACTIONS(4203),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4201),
    [anon_sym_LBRACK] = ACTIONS(4203),
    [aux_sym_record_type_token1] = ACTIONS(4201),
    [aux_sym_basic_type_token21] = ACTIONS(4201),
    [aux_sym_basic_type_token22] = ACTIONS(4201),
    [aux_sym_basic_type_token48] = ACTIONS(4201),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4201),
    [anon_sym_POUNDif] = ACTIONS(4203),
    [anon_sym_POUNDIF] = ACTIONS(4203),
    [anon_sym_POUNDIf] = ACTIONS(4203),
    [anon_sym_not] = ACTIONS(4201),
    [anon_sym_NOT] = ACTIONS(4201),
    [anon_sym_Not] = ACTIONS(4201),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4201),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4201),
    [anon_sym_PLUS] = ACTIONS(4203),
    [sym_datetime_literal] = ACTIONS(4203),
    [sym_date_literal] = ACTIONS(4201),
    [sym_time_literal] = ACTIONS(4201),
    [sym_biginteger_literal] = ACTIONS(4203),
    [anon_sym_if] = ACTIONS(4201),
    [anon_sym_IF] = ACTIONS(4201),
    [anon_sym_If] = ACTIONS(4201),
    [anon_sym_else] = ACTIONS(4201),
    [anon_sym_ELSE] = ACTIONS(4201),
    [anon_sym_Else] = ACTIONS(4201),
    [anon_sym_case] = ACTIONS(4201),
    [anon_sym_CASE] = ACTIONS(4201),
    [anon_sym_Case] = ACTIONS(4201),
    [anon_sym_for] = ACTIONS(4201),
    [anon_sym_FOR] = ACTIONS(4201),
    [anon_sym_For] = ACTIONS(4201),
    [anon_sym_foreach] = ACTIONS(4201),
    [anon_sym_FOREACH] = ACTIONS(4201),
    [anon_sym_Foreach] = ACTIONS(4201),
    [anon_sym_while] = ACTIONS(4201),
    [anon_sym_WHILE] = ACTIONS(4201),
    [anon_sym_While] = ACTIONS(4201),
    [anon_sym_repeat] = ACTIONS(4201),
    [anon_sym_REPEAT] = ACTIONS(4201),
    [anon_sym_Repeat] = ACTIONS(4201),
    [anon_sym_exit] = ACTIONS(4201),
    [anon_sym_EXIT] = ACTIONS(4201),
    [anon_sym_Exit] = ACTIONS(4201),
    [anon_sym_continue] = ACTIONS(4201),
    [anon_sym_CONTINUE] = ACTIONS(4201),
    [anon_sym_Continue] = ACTIONS(4201),
    [anon_sym_break] = ACTIONS(4201),
    [anon_sym_BREAK] = ACTIONS(4201),
    [anon_sym_Break] = ACTIONS(4201),
    [anon_sym_with] = ACTIONS(4201),
    [anon_sym_WITH] = ACTIONS(4201),
    [anon_sym_With] = ACTIONS(4201),
    [sym_asserterror_keyword] = ACTIONS(4203),
    [sym_page_keyword] = ACTIONS(4201),
    [anon_sym_codeunit] = ACTIONS(4201),
    [anon_sym_CODEUNIT] = ACTIONS(4201),
    [anon_sym_Codeunit] = ACTIONS(4201),
    [anon_sym_CodeUnit] = ACTIONS(4201),
    [anon_sym_COdeunit] = ACTIONS(4201),
    [anon_sym_codeUnit] = ACTIONS(4201),
    [sym_report_keyword] = ACTIONS(4201),
    [sym_query_keyword] = ACTIONS(4201),
    [anon_sym_xmlport] = ACTIONS(4201),
    [anon_sym_XMLPORT] = ACTIONS(4201),
    [anon_sym_Xmlport] = ACTIONS(4201),
    [anon_sym_XMLport] = ACTIONS(4201),
    [anon_sym_XMLPort] = ACTIONS(4201),
    [anon_sym_XmlPort] = ACTIONS(4201),
    [anon_sym_enum] = ACTIONS(4201),
    [anon_sym_ENUM] = ACTIONS(4201),
    [anon_sym_Enum] = ACTIONS(4201),
    [anon_sym_eNUM] = ACTIONS(4201),
    [anon_sym_eNum] = ACTIONS(4201),
    [anon_sym_ENum] = ACTIONS(4201),
    [sym_quoted_identifier] = ACTIONS(4203),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4203),
    [sym_integer] = ACTIONS(4201),
    [sym_continue_as_identifier] = ACTIONS(4203),
    [sym_preproc_open] = ACTIONS(4203),
    [sym_end_keyword] = ACTIONS(4203),
  },
  [STATE(2256)] = {
    [sym_identifier] = ACTIONS(4205),
    [anon_sym_SEMI] = ACTIONS(4207),
    [anon_sym_DASH] = ACTIONS(4207),
    [aux_sym_boolean_token1] = ACTIONS(4205),
    [aux_sym_boolean_token2] = ACTIONS(4205),
    [sym_decimal] = ACTIONS(4205),
    [anon_sym_LPAREN] = ACTIONS(4207),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4205),
    [anon_sym_LBRACK] = ACTIONS(4207),
    [aux_sym_record_type_token1] = ACTIONS(4205),
    [aux_sym_basic_type_token21] = ACTIONS(4205),
    [aux_sym_basic_type_token22] = ACTIONS(4205),
    [aux_sym_basic_type_token48] = ACTIONS(4205),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4205),
    [anon_sym_POUNDif] = ACTIONS(4207),
    [anon_sym_POUNDIF] = ACTIONS(4207),
    [anon_sym_POUNDIf] = ACTIONS(4207),
    [anon_sym_not] = ACTIONS(4205),
    [anon_sym_NOT] = ACTIONS(4205),
    [anon_sym_Not] = ACTIONS(4205),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4205),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4205),
    [anon_sym_PLUS] = ACTIONS(4207),
    [sym_datetime_literal] = ACTIONS(4207),
    [sym_date_literal] = ACTIONS(4205),
    [sym_time_literal] = ACTIONS(4205),
    [sym_biginteger_literal] = ACTIONS(4207),
    [anon_sym_if] = ACTIONS(4205),
    [anon_sym_IF] = ACTIONS(4205),
    [anon_sym_If] = ACTIONS(4205),
    [anon_sym_else] = ACTIONS(4205),
    [anon_sym_ELSE] = ACTIONS(4205),
    [anon_sym_Else] = ACTIONS(4205),
    [anon_sym_case] = ACTIONS(4205),
    [anon_sym_CASE] = ACTIONS(4205),
    [anon_sym_Case] = ACTIONS(4205),
    [anon_sym_for] = ACTIONS(4205),
    [anon_sym_FOR] = ACTIONS(4205),
    [anon_sym_For] = ACTIONS(4205),
    [anon_sym_foreach] = ACTIONS(4205),
    [anon_sym_FOREACH] = ACTIONS(4205),
    [anon_sym_Foreach] = ACTIONS(4205),
    [anon_sym_while] = ACTIONS(4205),
    [anon_sym_WHILE] = ACTIONS(4205),
    [anon_sym_While] = ACTIONS(4205),
    [anon_sym_repeat] = ACTIONS(4205),
    [anon_sym_REPEAT] = ACTIONS(4205),
    [anon_sym_Repeat] = ACTIONS(4205),
    [anon_sym_exit] = ACTIONS(4205),
    [anon_sym_EXIT] = ACTIONS(4205),
    [anon_sym_Exit] = ACTIONS(4205),
    [anon_sym_continue] = ACTIONS(4205),
    [anon_sym_CONTINUE] = ACTIONS(4205),
    [anon_sym_Continue] = ACTIONS(4205),
    [anon_sym_break] = ACTIONS(4205),
    [anon_sym_BREAK] = ACTIONS(4205),
    [anon_sym_Break] = ACTIONS(4205),
    [anon_sym_with] = ACTIONS(4205),
    [anon_sym_WITH] = ACTIONS(4205),
    [anon_sym_With] = ACTIONS(4205),
    [sym_asserterror_keyword] = ACTIONS(4207),
    [sym_page_keyword] = ACTIONS(4205),
    [anon_sym_codeunit] = ACTIONS(4205),
    [anon_sym_CODEUNIT] = ACTIONS(4205),
    [anon_sym_Codeunit] = ACTIONS(4205),
    [anon_sym_CodeUnit] = ACTIONS(4205),
    [anon_sym_COdeunit] = ACTIONS(4205),
    [anon_sym_codeUnit] = ACTIONS(4205),
    [sym_report_keyword] = ACTIONS(4205),
    [sym_query_keyword] = ACTIONS(4205),
    [anon_sym_xmlport] = ACTIONS(4205),
    [anon_sym_XMLPORT] = ACTIONS(4205),
    [anon_sym_Xmlport] = ACTIONS(4205),
    [anon_sym_XMLport] = ACTIONS(4205),
    [anon_sym_XMLPort] = ACTIONS(4205),
    [anon_sym_XmlPort] = ACTIONS(4205),
    [anon_sym_enum] = ACTIONS(4205),
    [anon_sym_ENUM] = ACTIONS(4205),
    [anon_sym_Enum] = ACTIONS(4205),
    [anon_sym_eNUM] = ACTIONS(4205),
    [anon_sym_eNum] = ACTIONS(4205),
    [anon_sym_ENum] = ACTIONS(4205),
    [sym_quoted_identifier] = ACTIONS(4207),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4207),
    [sym_integer] = ACTIONS(4205),
    [sym_continue_as_identifier] = ACTIONS(4207),
    [sym_preproc_open] = ACTIONS(4207),
    [sym_end_keyword] = ACTIONS(4207),
  },
  [STATE(2257)] = {
    [sym_identifier] = ACTIONS(4209),
    [anon_sym_SEMI] = ACTIONS(4211),
    [anon_sym_DASH] = ACTIONS(4211),
    [aux_sym_boolean_token1] = ACTIONS(4209),
    [aux_sym_boolean_token2] = ACTIONS(4209),
    [sym_decimal] = ACTIONS(4209),
    [anon_sym_LPAREN] = ACTIONS(4211),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4209),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [aux_sym_record_type_token1] = ACTIONS(4209),
    [aux_sym_basic_type_token21] = ACTIONS(4209),
    [aux_sym_basic_type_token22] = ACTIONS(4209),
    [aux_sym_basic_type_token48] = ACTIONS(4209),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4209),
    [anon_sym_POUNDif] = ACTIONS(4211),
    [anon_sym_POUNDIF] = ACTIONS(4211),
    [anon_sym_POUNDIf] = ACTIONS(4211),
    [anon_sym_not] = ACTIONS(4209),
    [anon_sym_NOT] = ACTIONS(4209),
    [anon_sym_Not] = ACTIONS(4209),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4209),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4209),
    [anon_sym_PLUS] = ACTIONS(4211),
    [sym_datetime_literal] = ACTIONS(4211),
    [sym_date_literal] = ACTIONS(4209),
    [sym_time_literal] = ACTIONS(4209),
    [sym_biginteger_literal] = ACTIONS(4211),
    [anon_sym_if] = ACTIONS(4209),
    [anon_sym_IF] = ACTIONS(4209),
    [anon_sym_If] = ACTIONS(4209),
    [anon_sym_else] = ACTIONS(4209),
    [anon_sym_ELSE] = ACTIONS(4209),
    [anon_sym_Else] = ACTIONS(4209),
    [anon_sym_case] = ACTIONS(4209),
    [anon_sym_CASE] = ACTIONS(4209),
    [anon_sym_Case] = ACTIONS(4209),
    [anon_sym_for] = ACTIONS(4209),
    [anon_sym_FOR] = ACTIONS(4209),
    [anon_sym_For] = ACTIONS(4209),
    [anon_sym_foreach] = ACTIONS(4209),
    [anon_sym_FOREACH] = ACTIONS(4209),
    [anon_sym_Foreach] = ACTIONS(4209),
    [anon_sym_while] = ACTIONS(4209),
    [anon_sym_WHILE] = ACTIONS(4209),
    [anon_sym_While] = ACTIONS(4209),
    [anon_sym_repeat] = ACTIONS(4209),
    [anon_sym_REPEAT] = ACTIONS(4209),
    [anon_sym_Repeat] = ACTIONS(4209),
    [anon_sym_exit] = ACTIONS(4209),
    [anon_sym_EXIT] = ACTIONS(4209),
    [anon_sym_Exit] = ACTIONS(4209),
    [anon_sym_continue] = ACTIONS(4209),
    [anon_sym_CONTINUE] = ACTIONS(4209),
    [anon_sym_Continue] = ACTIONS(4209),
    [anon_sym_break] = ACTIONS(4209),
    [anon_sym_BREAK] = ACTIONS(4209),
    [anon_sym_Break] = ACTIONS(4209),
    [anon_sym_with] = ACTIONS(4209),
    [anon_sym_WITH] = ACTIONS(4209),
    [anon_sym_With] = ACTIONS(4209),
    [sym_asserterror_keyword] = ACTIONS(4211),
    [sym_page_keyword] = ACTIONS(4209),
    [anon_sym_codeunit] = ACTIONS(4209),
    [anon_sym_CODEUNIT] = ACTIONS(4209),
    [anon_sym_Codeunit] = ACTIONS(4209),
    [anon_sym_CodeUnit] = ACTIONS(4209),
    [anon_sym_COdeunit] = ACTIONS(4209),
    [anon_sym_codeUnit] = ACTIONS(4209),
    [sym_report_keyword] = ACTIONS(4209),
    [sym_query_keyword] = ACTIONS(4209),
    [anon_sym_xmlport] = ACTIONS(4209),
    [anon_sym_XMLPORT] = ACTIONS(4209),
    [anon_sym_Xmlport] = ACTIONS(4209),
    [anon_sym_XMLport] = ACTIONS(4209),
    [anon_sym_XMLPort] = ACTIONS(4209),
    [anon_sym_XmlPort] = ACTIONS(4209),
    [anon_sym_enum] = ACTIONS(4209),
    [anon_sym_ENUM] = ACTIONS(4209),
    [anon_sym_Enum] = ACTIONS(4209),
    [anon_sym_eNUM] = ACTIONS(4209),
    [anon_sym_eNum] = ACTIONS(4209),
    [anon_sym_ENum] = ACTIONS(4209),
    [sym_quoted_identifier] = ACTIONS(4211),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4211),
    [sym_integer] = ACTIONS(4209),
    [sym_continue_as_identifier] = ACTIONS(4211),
    [sym_preproc_open] = ACTIONS(4211),
    [sym_end_keyword] = ACTIONS(4211),
  },
  [STATE(2258)] = {
    [sym_identifier] = ACTIONS(4559),
    [anon_sym_SEMI] = ACTIONS(4561),
    [anon_sym_DASH] = ACTIONS(4561),
    [aux_sym_boolean_token1] = ACTIONS(4559),
    [aux_sym_boolean_token2] = ACTIONS(4559),
    [sym_decimal] = ACTIONS(4559),
    [anon_sym_LPAREN] = ACTIONS(4561),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4559),
    [anon_sym_LBRACK] = ACTIONS(4561),
    [aux_sym_record_type_token1] = ACTIONS(4559),
    [aux_sym_basic_type_token21] = ACTIONS(4559),
    [aux_sym_basic_type_token22] = ACTIONS(4559),
    [aux_sym_basic_type_token48] = ACTIONS(4559),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4559),
    [anon_sym_POUNDif] = ACTIONS(4561),
    [anon_sym_POUNDIF] = ACTIONS(4561),
    [anon_sym_POUNDIf] = ACTIONS(4561),
    [anon_sym_not] = ACTIONS(4559),
    [anon_sym_NOT] = ACTIONS(4559),
    [anon_sym_Not] = ACTIONS(4559),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4559),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4559),
    [anon_sym_PLUS] = ACTIONS(4561),
    [sym_datetime_literal] = ACTIONS(4561),
    [sym_date_literal] = ACTIONS(4559),
    [sym_time_literal] = ACTIONS(4559),
    [sym_biginteger_literal] = ACTIONS(4561),
    [anon_sym_if] = ACTIONS(4559),
    [anon_sym_IF] = ACTIONS(4559),
    [anon_sym_If] = ACTIONS(4559),
    [anon_sym_else] = ACTIONS(4559),
    [anon_sym_ELSE] = ACTIONS(4559),
    [anon_sym_Else] = ACTIONS(4559),
    [anon_sym_case] = ACTIONS(4559),
    [anon_sym_CASE] = ACTIONS(4559),
    [anon_sym_Case] = ACTIONS(4559),
    [anon_sym_for] = ACTIONS(4559),
    [anon_sym_FOR] = ACTIONS(4559),
    [anon_sym_For] = ACTIONS(4559),
    [anon_sym_foreach] = ACTIONS(4559),
    [anon_sym_FOREACH] = ACTIONS(4559),
    [anon_sym_Foreach] = ACTIONS(4559),
    [anon_sym_while] = ACTIONS(4559),
    [anon_sym_WHILE] = ACTIONS(4559),
    [anon_sym_While] = ACTIONS(4559),
    [anon_sym_repeat] = ACTIONS(4559),
    [anon_sym_REPEAT] = ACTIONS(4559),
    [anon_sym_Repeat] = ACTIONS(4559),
    [anon_sym_exit] = ACTIONS(4559),
    [anon_sym_EXIT] = ACTIONS(4559),
    [anon_sym_Exit] = ACTIONS(4559),
    [anon_sym_continue] = ACTIONS(4559),
    [anon_sym_CONTINUE] = ACTIONS(4559),
    [anon_sym_Continue] = ACTIONS(4559),
    [anon_sym_break] = ACTIONS(4559),
    [anon_sym_BREAK] = ACTIONS(4559),
    [anon_sym_Break] = ACTIONS(4559),
    [anon_sym_with] = ACTIONS(4559),
    [anon_sym_WITH] = ACTIONS(4559),
    [anon_sym_With] = ACTIONS(4559),
    [sym_asserterror_keyword] = ACTIONS(4561),
    [sym_page_keyword] = ACTIONS(4559),
    [anon_sym_codeunit] = ACTIONS(4559),
    [anon_sym_CODEUNIT] = ACTIONS(4559),
    [anon_sym_Codeunit] = ACTIONS(4559),
    [anon_sym_CodeUnit] = ACTIONS(4559),
    [anon_sym_COdeunit] = ACTIONS(4559),
    [anon_sym_codeUnit] = ACTIONS(4559),
    [sym_report_keyword] = ACTIONS(4559),
    [sym_query_keyword] = ACTIONS(4559),
    [anon_sym_xmlport] = ACTIONS(4559),
    [anon_sym_XMLPORT] = ACTIONS(4559),
    [anon_sym_Xmlport] = ACTIONS(4559),
    [anon_sym_XMLport] = ACTIONS(4559),
    [anon_sym_XMLPort] = ACTIONS(4559),
    [anon_sym_XmlPort] = ACTIONS(4559),
    [anon_sym_enum] = ACTIONS(4559),
    [anon_sym_ENUM] = ACTIONS(4559),
    [anon_sym_Enum] = ACTIONS(4559),
    [anon_sym_eNUM] = ACTIONS(4559),
    [anon_sym_eNum] = ACTIONS(4559),
    [anon_sym_ENum] = ACTIONS(4559),
    [sym_quoted_identifier] = ACTIONS(4561),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4561),
    [sym_integer] = ACTIONS(4559),
    [sym_continue_as_identifier] = ACTIONS(4561),
    [sym_preproc_open] = ACTIONS(4561),
    [sym_end_keyword] = ACTIONS(4561),
  },
  [STATE(2259)] = {
    [sym_identifier] = ACTIONS(4217),
    [anon_sym_SEMI] = ACTIONS(4219),
    [anon_sym_DASH] = ACTIONS(4219),
    [aux_sym_boolean_token1] = ACTIONS(4217),
    [aux_sym_boolean_token2] = ACTIONS(4217),
    [sym_decimal] = ACTIONS(4217),
    [anon_sym_LPAREN] = ACTIONS(4219),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4217),
    [anon_sym_LBRACK] = ACTIONS(4219),
    [aux_sym_record_type_token1] = ACTIONS(4217),
    [aux_sym_basic_type_token21] = ACTIONS(4217),
    [aux_sym_basic_type_token22] = ACTIONS(4217),
    [aux_sym_basic_type_token48] = ACTIONS(4217),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4217),
    [anon_sym_POUNDif] = ACTIONS(4219),
    [anon_sym_POUNDIF] = ACTIONS(4219),
    [anon_sym_POUNDIf] = ACTIONS(4219),
    [anon_sym_not] = ACTIONS(4217),
    [anon_sym_NOT] = ACTIONS(4217),
    [anon_sym_Not] = ACTIONS(4217),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4217),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4217),
    [anon_sym_PLUS] = ACTIONS(4219),
    [sym_datetime_literal] = ACTIONS(4219),
    [sym_date_literal] = ACTIONS(4217),
    [sym_time_literal] = ACTIONS(4217),
    [sym_biginteger_literal] = ACTIONS(4219),
    [anon_sym_if] = ACTIONS(4217),
    [anon_sym_IF] = ACTIONS(4217),
    [anon_sym_If] = ACTIONS(4217),
    [anon_sym_else] = ACTIONS(4217),
    [anon_sym_ELSE] = ACTIONS(4217),
    [anon_sym_Else] = ACTIONS(4217),
    [anon_sym_case] = ACTIONS(4217),
    [anon_sym_CASE] = ACTIONS(4217),
    [anon_sym_Case] = ACTIONS(4217),
    [anon_sym_for] = ACTIONS(4217),
    [anon_sym_FOR] = ACTIONS(4217),
    [anon_sym_For] = ACTIONS(4217),
    [anon_sym_foreach] = ACTIONS(4217),
    [anon_sym_FOREACH] = ACTIONS(4217),
    [anon_sym_Foreach] = ACTIONS(4217),
    [anon_sym_while] = ACTIONS(4217),
    [anon_sym_WHILE] = ACTIONS(4217),
    [anon_sym_While] = ACTIONS(4217),
    [anon_sym_repeat] = ACTIONS(4217),
    [anon_sym_REPEAT] = ACTIONS(4217),
    [anon_sym_Repeat] = ACTIONS(4217),
    [anon_sym_exit] = ACTIONS(4217),
    [anon_sym_EXIT] = ACTIONS(4217),
    [anon_sym_Exit] = ACTIONS(4217),
    [anon_sym_continue] = ACTIONS(4217),
    [anon_sym_CONTINUE] = ACTIONS(4217),
    [anon_sym_Continue] = ACTIONS(4217),
    [anon_sym_break] = ACTIONS(4217),
    [anon_sym_BREAK] = ACTIONS(4217),
    [anon_sym_Break] = ACTIONS(4217),
    [anon_sym_with] = ACTIONS(4217),
    [anon_sym_WITH] = ACTIONS(4217),
    [anon_sym_With] = ACTIONS(4217),
    [sym_asserterror_keyword] = ACTIONS(4219),
    [sym_page_keyword] = ACTIONS(4217),
    [anon_sym_codeunit] = ACTIONS(4217),
    [anon_sym_CODEUNIT] = ACTIONS(4217),
    [anon_sym_Codeunit] = ACTIONS(4217),
    [anon_sym_CodeUnit] = ACTIONS(4217),
    [anon_sym_COdeunit] = ACTIONS(4217),
    [anon_sym_codeUnit] = ACTIONS(4217),
    [sym_report_keyword] = ACTIONS(4217),
    [sym_query_keyword] = ACTIONS(4217),
    [anon_sym_xmlport] = ACTIONS(4217),
    [anon_sym_XMLPORT] = ACTIONS(4217),
    [anon_sym_Xmlport] = ACTIONS(4217),
    [anon_sym_XMLport] = ACTIONS(4217),
    [anon_sym_XMLPort] = ACTIONS(4217),
    [anon_sym_XmlPort] = ACTIONS(4217),
    [anon_sym_enum] = ACTIONS(4217),
    [anon_sym_ENUM] = ACTIONS(4217),
    [anon_sym_Enum] = ACTIONS(4217),
    [anon_sym_eNUM] = ACTIONS(4217),
    [anon_sym_eNum] = ACTIONS(4217),
    [anon_sym_ENum] = ACTIONS(4217),
    [sym_quoted_identifier] = ACTIONS(4219),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4219),
    [sym_integer] = ACTIONS(4217),
    [sym_continue_as_identifier] = ACTIONS(4219),
    [sym_preproc_open] = ACTIONS(4219),
    [sym_end_keyword] = ACTIONS(4219),
  },
  [STATE(2260)] = {
    [sym_identifier] = ACTIONS(4584),
    [anon_sym_SEMI] = ACTIONS(4586),
    [anon_sym_DASH] = ACTIONS(4586),
    [aux_sym_boolean_token1] = ACTIONS(4584),
    [aux_sym_boolean_token2] = ACTIONS(4584),
    [sym_decimal] = ACTIONS(4584),
    [anon_sym_LPAREN] = ACTIONS(4586),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4584),
    [anon_sym_LBRACK] = ACTIONS(4586),
    [aux_sym_record_type_token1] = ACTIONS(4584),
    [aux_sym_basic_type_token21] = ACTIONS(4584),
    [aux_sym_basic_type_token22] = ACTIONS(4584),
    [aux_sym_basic_type_token48] = ACTIONS(4584),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4584),
    [anon_sym_POUNDif] = ACTIONS(4586),
    [anon_sym_POUNDIF] = ACTIONS(4586),
    [anon_sym_POUNDIf] = ACTIONS(4586),
    [anon_sym_not] = ACTIONS(4584),
    [anon_sym_NOT] = ACTIONS(4584),
    [anon_sym_Not] = ACTIONS(4584),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4584),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4584),
    [anon_sym_PLUS] = ACTIONS(4586),
    [sym_datetime_literal] = ACTIONS(4586),
    [sym_date_literal] = ACTIONS(4584),
    [sym_time_literal] = ACTIONS(4584),
    [sym_biginteger_literal] = ACTIONS(4586),
    [anon_sym_if] = ACTIONS(4584),
    [anon_sym_IF] = ACTIONS(4584),
    [anon_sym_If] = ACTIONS(4584),
    [anon_sym_else] = ACTIONS(4584),
    [anon_sym_ELSE] = ACTIONS(4584),
    [anon_sym_Else] = ACTIONS(4584),
    [anon_sym_case] = ACTIONS(4584),
    [anon_sym_CASE] = ACTIONS(4584),
    [anon_sym_Case] = ACTIONS(4584),
    [anon_sym_for] = ACTIONS(4584),
    [anon_sym_FOR] = ACTIONS(4584),
    [anon_sym_For] = ACTIONS(4584),
    [anon_sym_foreach] = ACTIONS(4584),
    [anon_sym_FOREACH] = ACTIONS(4584),
    [anon_sym_Foreach] = ACTIONS(4584),
    [anon_sym_while] = ACTIONS(4584),
    [anon_sym_WHILE] = ACTIONS(4584),
    [anon_sym_While] = ACTIONS(4584),
    [anon_sym_repeat] = ACTIONS(4584),
    [anon_sym_REPEAT] = ACTIONS(4584),
    [anon_sym_Repeat] = ACTIONS(4584),
    [anon_sym_exit] = ACTIONS(4584),
    [anon_sym_EXIT] = ACTIONS(4584),
    [anon_sym_Exit] = ACTIONS(4584),
    [anon_sym_continue] = ACTIONS(4584),
    [anon_sym_CONTINUE] = ACTIONS(4584),
    [anon_sym_Continue] = ACTIONS(4584),
    [anon_sym_break] = ACTIONS(4584),
    [anon_sym_BREAK] = ACTIONS(4584),
    [anon_sym_Break] = ACTIONS(4584),
    [anon_sym_with] = ACTIONS(4584),
    [anon_sym_WITH] = ACTIONS(4584),
    [anon_sym_With] = ACTIONS(4584),
    [sym_asserterror_keyword] = ACTIONS(4586),
    [sym_page_keyword] = ACTIONS(4584),
    [anon_sym_codeunit] = ACTIONS(4584),
    [anon_sym_CODEUNIT] = ACTIONS(4584),
    [anon_sym_Codeunit] = ACTIONS(4584),
    [anon_sym_CodeUnit] = ACTIONS(4584),
    [anon_sym_COdeunit] = ACTIONS(4584),
    [anon_sym_codeUnit] = ACTIONS(4584),
    [sym_report_keyword] = ACTIONS(4584),
    [sym_query_keyword] = ACTIONS(4584),
    [anon_sym_xmlport] = ACTIONS(4584),
    [anon_sym_XMLPORT] = ACTIONS(4584),
    [anon_sym_Xmlport] = ACTIONS(4584),
    [anon_sym_XMLport] = ACTIONS(4584),
    [anon_sym_XMLPort] = ACTIONS(4584),
    [anon_sym_XmlPort] = ACTIONS(4584),
    [anon_sym_enum] = ACTIONS(4584),
    [anon_sym_ENUM] = ACTIONS(4584),
    [anon_sym_Enum] = ACTIONS(4584),
    [anon_sym_eNUM] = ACTIONS(4584),
    [anon_sym_eNum] = ACTIONS(4584),
    [anon_sym_ENum] = ACTIONS(4584),
    [sym_quoted_identifier] = ACTIONS(4586),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4586),
    [sym_integer] = ACTIONS(4584),
    [sym_continue_as_identifier] = ACTIONS(4586),
    [sym_preproc_open] = ACTIONS(4586),
    [sym_end_keyword] = ACTIONS(4586),
  },
  [STATE(2261)] = {
    [sym_identifier] = ACTIONS(4221),
    [anon_sym_SEMI] = ACTIONS(4223),
    [anon_sym_DASH] = ACTIONS(4223),
    [aux_sym_boolean_token1] = ACTIONS(4221),
    [aux_sym_boolean_token2] = ACTIONS(4221),
    [sym_decimal] = ACTIONS(4221),
    [anon_sym_LPAREN] = ACTIONS(4223),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4221),
    [anon_sym_LBRACK] = ACTIONS(4223),
    [aux_sym_record_type_token1] = ACTIONS(4221),
    [aux_sym_basic_type_token21] = ACTIONS(4221),
    [aux_sym_basic_type_token22] = ACTIONS(4221),
    [aux_sym_basic_type_token48] = ACTIONS(4221),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4221),
    [anon_sym_POUNDif] = ACTIONS(4223),
    [anon_sym_POUNDIF] = ACTIONS(4223),
    [anon_sym_POUNDIf] = ACTIONS(4223),
    [anon_sym_not] = ACTIONS(4221),
    [anon_sym_NOT] = ACTIONS(4221),
    [anon_sym_Not] = ACTIONS(4221),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4221),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4221),
    [anon_sym_PLUS] = ACTIONS(4223),
    [sym_datetime_literal] = ACTIONS(4223),
    [sym_date_literal] = ACTIONS(4221),
    [sym_time_literal] = ACTIONS(4221),
    [sym_biginteger_literal] = ACTIONS(4223),
    [anon_sym_if] = ACTIONS(4221),
    [anon_sym_IF] = ACTIONS(4221),
    [anon_sym_If] = ACTIONS(4221),
    [anon_sym_else] = ACTIONS(4221),
    [anon_sym_ELSE] = ACTIONS(4221),
    [anon_sym_Else] = ACTIONS(4221),
    [anon_sym_case] = ACTIONS(4221),
    [anon_sym_CASE] = ACTIONS(4221),
    [anon_sym_Case] = ACTIONS(4221),
    [anon_sym_for] = ACTIONS(4221),
    [anon_sym_FOR] = ACTIONS(4221),
    [anon_sym_For] = ACTIONS(4221),
    [anon_sym_foreach] = ACTIONS(4221),
    [anon_sym_FOREACH] = ACTIONS(4221),
    [anon_sym_Foreach] = ACTIONS(4221),
    [anon_sym_while] = ACTIONS(4221),
    [anon_sym_WHILE] = ACTIONS(4221),
    [anon_sym_While] = ACTIONS(4221),
    [anon_sym_repeat] = ACTIONS(4221),
    [anon_sym_REPEAT] = ACTIONS(4221),
    [anon_sym_Repeat] = ACTIONS(4221),
    [anon_sym_exit] = ACTIONS(4221),
    [anon_sym_EXIT] = ACTIONS(4221),
    [anon_sym_Exit] = ACTIONS(4221),
    [anon_sym_continue] = ACTIONS(4221),
    [anon_sym_CONTINUE] = ACTIONS(4221),
    [anon_sym_Continue] = ACTIONS(4221),
    [anon_sym_break] = ACTIONS(4221),
    [anon_sym_BREAK] = ACTIONS(4221),
    [anon_sym_Break] = ACTIONS(4221),
    [anon_sym_with] = ACTIONS(4221),
    [anon_sym_WITH] = ACTIONS(4221),
    [anon_sym_With] = ACTIONS(4221),
    [sym_asserterror_keyword] = ACTIONS(4223),
    [sym_page_keyword] = ACTIONS(4221),
    [anon_sym_codeunit] = ACTIONS(4221),
    [anon_sym_CODEUNIT] = ACTIONS(4221),
    [anon_sym_Codeunit] = ACTIONS(4221),
    [anon_sym_CodeUnit] = ACTIONS(4221),
    [anon_sym_COdeunit] = ACTIONS(4221),
    [anon_sym_codeUnit] = ACTIONS(4221),
    [sym_report_keyword] = ACTIONS(4221),
    [sym_query_keyword] = ACTIONS(4221),
    [anon_sym_xmlport] = ACTIONS(4221),
    [anon_sym_XMLPORT] = ACTIONS(4221),
    [anon_sym_Xmlport] = ACTIONS(4221),
    [anon_sym_XMLport] = ACTIONS(4221),
    [anon_sym_XMLPort] = ACTIONS(4221),
    [anon_sym_XmlPort] = ACTIONS(4221),
    [anon_sym_enum] = ACTIONS(4221),
    [anon_sym_ENUM] = ACTIONS(4221),
    [anon_sym_Enum] = ACTIONS(4221),
    [anon_sym_eNUM] = ACTIONS(4221),
    [anon_sym_eNum] = ACTIONS(4221),
    [anon_sym_ENum] = ACTIONS(4221),
    [sym_quoted_identifier] = ACTIONS(4223),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4223),
    [sym_integer] = ACTIONS(4221),
    [sym_continue_as_identifier] = ACTIONS(4223),
    [sym_preproc_open] = ACTIONS(4223),
    [sym_end_keyword] = ACTIONS(4223),
  },
  [STATE(2262)] = {
    [sym_identifier] = ACTIONS(4225),
    [anon_sym_SEMI] = ACTIONS(4227),
    [anon_sym_DASH] = ACTIONS(4227),
    [aux_sym_boolean_token1] = ACTIONS(4225),
    [aux_sym_boolean_token2] = ACTIONS(4225),
    [sym_decimal] = ACTIONS(4225),
    [anon_sym_LPAREN] = ACTIONS(4227),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4225),
    [anon_sym_LBRACK] = ACTIONS(4227),
    [aux_sym_record_type_token1] = ACTIONS(4225),
    [aux_sym_basic_type_token21] = ACTIONS(4225),
    [aux_sym_basic_type_token22] = ACTIONS(4225),
    [aux_sym_basic_type_token48] = ACTIONS(4225),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4225),
    [anon_sym_POUNDif] = ACTIONS(4227),
    [anon_sym_POUNDIF] = ACTIONS(4227),
    [anon_sym_POUNDIf] = ACTIONS(4227),
    [anon_sym_not] = ACTIONS(4225),
    [anon_sym_NOT] = ACTIONS(4225),
    [anon_sym_Not] = ACTIONS(4225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4225),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4225),
    [anon_sym_PLUS] = ACTIONS(4227),
    [sym_datetime_literal] = ACTIONS(4227),
    [sym_date_literal] = ACTIONS(4225),
    [sym_time_literal] = ACTIONS(4225),
    [sym_biginteger_literal] = ACTIONS(4227),
    [anon_sym_if] = ACTIONS(4225),
    [anon_sym_IF] = ACTIONS(4225),
    [anon_sym_If] = ACTIONS(4225),
    [anon_sym_else] = ACTIONS(4225),
    [anon_sym_ELSE] = ACTIONS(4225),
    [anon_sym_Else] = ACTIONS(4225),
    [anon_sym_case] = ACTIONS(4225),
    [anon_sym_CASE] = ACTIONS(4225),
    [anon_sym_Case] = ACTIONS(4225),
    [anon_sym_for] = ACTIONS(4225),
    [anon_sym_FOR] = ACTIONS(4225),
    [anon_sym_For] = ACTIONS(4225),
    [anon_sym_foreach] = ACTIONS(4225),
    [anon_sym_FOREACH] = ACTIONS(4225),
    [anon_sym_Foreach] = ACTIONS(4225),
    [anon_sym_while] = ACTIONS(4225),
    [anon_sym_WHILE] = ACTIONS(4225),
    [anon_sym_While] = ACTIONS(4225),
    [anon_sym_repeat] = ACTIONS(4225),
    [anon_sym_REPEAT] = ACTIONS(4225),
    [anon_sym_Repeat] = ACTIONS(4225),
    [anon_sym_exit] = ACTIONS(4225),
    [anon_sym_EXIT] = ACTIONS(4225),
    [anon_sym_Exit] = ACTIONS(4225),
    [anon_sym_continue] = ACTIONS(4225),
    [anon_sym_CONTINUE] = ACTIONS(4225),
    [anon_sym_Continue] = ACTIONS(4225),
    [anon_sym_break] = ACTIONS(4225),
    [anon_sym_BREAK] = ACTIONS(4225),
    [anon_sym_Break] = ACTIONS(4225),
    [anon_sym_with] = ACTIONS(4225),
    [anon_sym_WITH] = ACTIONS(4225),
    [anon_sym_With] = ACTIONS(4225),
    [sym_asserterror_keyword] = ACTIONS(4227),
    [sym_page_keyword] = ACTIONS(4225),
    [anon_sym_codeunit] = ACTIONS(4225),
    [anon_sym_CODEUNIT] = ACTIONS(4225),
    [anon_sym_Codeunit] = ACTIONS(4225),
    [anon_sym_CodeUnit] = ACTIONS(4225),
    [anon_sym_COdeunit] = ACTIONS(4225),
    [anon_sym_codeUnit] = ACTIONS(4225),
    [sym_report_keyword] = ACTIONS(4225),
    [sym_query_keyword] = ACTIONS(4225),
    [anon_sym_xmlport] = ACTIONS(4225),
    [anon_sym_XMLPORT] = ACTIONS(4225),
    [anon_sym_Xmlport] = ACTIONS(4225),
    [anon_sym_XMLport] = ACTIONS(4225),
    [anon_sym_XMLPort] = ACTIONS(4225),
    [anon_sym_XmlPort] = ACTIONS(4225),
    [anon_sym_enum] = ACTIONS(4225),
    [anon_sym_ENUM] = ACTIONS(4225),
    [anon_sym_Enum] = ACTIONS(4225),
    [anon_sym_eNUM] = ACTIONS(4225),
    [anon_sym_eNum] = ACTIONS(4225),
    [anon_sym_ENum] = ACTIONS(4225),
    [sym_quoted_identifier] = ACTIONS(4227),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4227),
    [sym_integer] = ACTIONS(4225),
    [sym_continue_as_identifier] = ACTIONS(4227),
    [sym_preproc_open] = ACTIONS(4227),
    [sym_end_keyword] = ACTIONS(4227),
  },
  [STATE(2263)] = {
    [sym_identifier] = ACTIONS(4588),
    [anon_sym_SEMI] = ACTIONS(4590),
    [anon_sym_DASH] = ACTIONS(4590),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(4588),
    [anon_sym_LPAREN] = ACTIONS(4590),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4588),
    [anon_sym_LBRACK] = ACTIONS(4590),
    [aux_sym_record_type_token1] = ACTIONS(4588),
    [aux_sym_basic_type_token21] = ACTIONS(4588),
    [aux_sym_basic_type_token22] = ACTIONS(4588),
    [aux_sym_basic_type_token48] = ACTIONS(4588),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4588),
    [anon_sym_POUNDif] = ACTIONS(4590),
    [anon_sym_POUNDIF] = ACTIONS(4590),
    [anon_sym_POUNDIf] = ACTIONS(4590),
    [anon_sym_not] = ACTIONS(4588),
    [anon_sym_NOT] = ACTIONS(4588),
    [anon_sym_Not] = ACTIONS(4588),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4588),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4588),
    [anon_sym_PLUS] = ACTIONS(4590),
    [sym_datetime_literal] = ACTIONS(4590),
    [sym_date_literal] = ACTIONS(4588),
    [sym_time_literal] = ACTIONS(4588),
    [sym_biginteger_literal] = ACTIONS(4590),
    [anon_sym_if] = ACTIONS(4588),
    [anon_sym_IF] = ACTIONS(4588),
    [anon_sym_If] = ACTIONS(4588),
    [anon_sym_else] = ACTIONS(4588),
    [anon_sym_ELSE] = ACTIONS(4588),
    [anon_sym_Else] = ACTIONS(4588),
    [anon_sym_case] = ACTIONS(4588),
    [anon_sym_CASE] = ACTIONS(4588),
    [anon_sym_Case] = ACTIONS(4588),
    [anon_sym_for] = ACTIONS(4588),
    [anon_sym_FOR] = ACTIONS(4588),
    [anon_sym_For] = ACTIONS(4588),
    [anon_sym_foreach] = ACTIONS(4588),
    [anon_sym_FOREACH] = ACTIONS(4588),
    [anon_sym_Foreach] = ACTIONS(4588),
    [anon_sym_while] = ACTIONS(4588),
    [anon_sym_WHILE] = ACTIONS(4588),
    [anon_sym_While] = ACTIONS(4588),
    [anon_sym_repeat] = ACTIONS(4588),
    [anon_sym_REPEAT] = ACTIONS(4588),
    [anon_sym_Repeat] = ACTIONS(4588),
    [anon_sym_exit] = ACTIONS(4588),
    [anon_sym_EXIT] = ACTIONS(4588),
    [anon_sym_Exit] = ACTIONS(4588),
    [anon_sym_continue] = ACTIONS(4588),
    [anon_sym_CONTINUE] = ACTIONS(4588),
    [anon_sym_Continue] = ACTIONS(4588),
    [anon_sym_break] = ACTIONS(4588),
    [anon_sym_BREAK] = ACTIONS(4588),
    [anon_sym_Break] = ACTIONS(4588),
    [anon_sym_with] = ACTIONS(4588),
    [anon_sym_WITH] = ACTIONS(4588),
    [anon_sym_With] = ACTIONS(4588),
    [sym_asserterror_keyword] = ACTIONS(4590),
    [sym_page_keyword] = ACTIONS(4588),
    [anon_sym_codeunit] = ACTIONS(4588),
    [anon_sym_CODEUNIT] = ACTIONS(4588),
    [anon_sym_Codeunit] = ACTIONS(4588),
    [anon_sym_CodeUnit] = ACTIONS(4588),
    [anon_sym_COdeunit] = ACTIONS(4588),
    [anon_sym_codeUnit] = ACTIONS(4588),
    [sym_report_keyword] = ACTIONS(4588),
    [sym_query_keyword] = ACTIONS(4588),
    [anon_sym_xmlport] = ACTIONS(4588),
    [anon_sym_XMLPORT] = ACTIONS(4588),
    [anon_sym_Xmlport] = ACTIONS(4588),
    [anon_sym_XMLport] = ACTIONS(4588),
    [anon_sym_XMLPort] = ACTIONS(4588),
    [anon_sym_XmlPort] = ACTIONS(4588),
    [anon_sym_enum] = ACTIONS(4588),
    [anon_sym_ENUM] = ACTIONS(4588),
    [anon_sym_Enum] = ACTIONS(4588),
    [anon_sym_eNUM] = ACTIONS(4588),
    [anon_sym_eNum] = ACTIONS(4588),
    [anon_sym_ENum] = ACTIONS(4588),
    [sym_quoted_identifier] = ACTIONS(4590),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4590),
    [sym_integer] = ACTIONS(4588),
    [sym_continue_as_identifier] = ACTIONS(4590),
    [sym_preproc_open] = ACTIONS(4590),
    [sym_end_keyword] = ACTIONS(4590),
  },
  [STATE(2264)] = {
    [sym_identifier] = ACTIONS(4419),
    [anon_sym_SEMI] = ACTIONS(4421),
    [anon_sym_DASH] = ACTIONS(4421),
    [aux_sym_boolean_token1] = ACTIONS(4419),
    [aux_sym_boolean_token2] = ACTIONS(4419),
    [sym_decimal] = ACTIONS(4419),
    [anon_sym_LPAREN] = ACTIONS(4421),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4419),
    [anon_sym_LBRACK] = ACTIONS(4421),
    [aux_sym_record_type_token1] = ACTIONS(4419),
    [aux_sym_basic_type_token21] = ACTIONS(4419),
    [aux_sym_basic_type_token22] = ACTIONS(4419),
    [aux_sym_basic_type_token48] = ACTIONS(4419),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4419),
    [anon_sym_POUNDif] = ACTIONS(4421),
    [anon_sym_POUNDIF] = ACTIONS(4421),
    [anon_sym_POUNDIf] = ACTIONS(4421),
    [anon_sym_not] = ACTIONS(4419),
    [anon_sym_NOT] = ACTIONS(4419),
    [anon_sym_Not] = ACTIONS(4419),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4419),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4419),
    [anon_sym_PLUS] = ACTIONS(4421),
    [sym_datetime_literal] = ACTIONS(4421),
    [sym_date_literal] = ACTIONS(4419),
    [sym_time_literal] = ACTIONS(4419),
    [sym_biginteger_literal] = ACTIONS(4421),
    [anon_sym_if] = ACTIONS(4419),
    [anon_sym_IF] = ACTIONS(4419),
    [anon_sym_If] = ACTIONS(4419),
    [anon_sym_else] = ACTIONS(4419),
    [anon_sym_ELSE] = ACTIONS(4419),
    [anon_sym_Else] = ACTIONS(4419),
    [anon_sym_case] = ACTIONS(4419),
    [anon_sym_CASE] = ACTIONS(4419),
    [anon_sym_Case] = ACTIONS(4419),
    [anon_sym_for] = ACTIONS(4419),
    [anon_sym_FOR] = ACTIONS(4419),
    [anon_sym_For] = ACTIONS(4419),
    [anon_sym_foreach] = ACTIONS(4419),
    [anon_sym_FOREACH] = ACTIONS(4419),
    [anon_sym_Foreach] = ACTIONS(4419),
    [anon_sym_while] = ACTIONS(4419),
    [anon_sym_WHILE] = ACTIONS(4419),
    [anon_sym_While] = ACTIONS(4419),
    [anon_sym_repeat] = ACTIONS(4419),
    [anon_sym_REPEAT] = ACTIONS(4419),
    [anon_sym_Repeat] = ACTIONS(4419),
    [anon_sym_exit] = ACTIONS(4419),
    [anon_sym_EXIT] = ACTIONS(4419),
    [anon_sym_Exit] = ACTIONS(4419),
    [anon_sym_continue] = ACTIONS(4419),
    [anon_sym_CONTINUE] = ACTIONS(4419),
    [anon_sym_Continue] = ACTIONS(4419),
    [anon_sym_break] = ACTIONS(4419),
    [anon_sym_BREAK] = ACTIONS(4419),
    [anon_sym_Break] = ACTIONS(4419),
    [anon_sym_with] = ACTIONS(4419),
    [anon_sym_WITH] = ACTIONS(4419),
    [anon_sym_With] = ACTIONS(4419),
    [sym_asserterror_keyword] = ACTIONS(4421),
    [sym_page_keyword] = ACTIONS(4419),
    [anon_sym_codeunit] = ACTIONS(4419),
    [anon_sym_CODEUNIT] = ACTIONS(4419),
    [anon_sym_Codeunit] = ACTIONS(4419),
    [anon_sym_CodeUnit] = ACTIONS(4419),
    [anon_sym_COdeunit] = ACTIONS(4419),
    [anon_sym_codeUnit] = ACTIONS(4419),
    [sym_report_keyword] = ACTIONS(4419),
    [sym_query_keyword] = ACTIONS(4419),
    [anon_sym_xmlport] = ACTIONS(4419),
    [anon_sym_XMLPORT] = ACTIONS(4419),
    [anon_sym_Xmlport] = ACTIONS(4419),
    [anon_sym_XMLport] = ACTIONS(4419),
    [anon_sym_XMLPort] = ACTIONS(4419),
    [anon_sym_XmlPort] = ACTIONS(4419),
    [anon_sym_enum] = ACTIONS(4419),
    [anon_sym_ENUM] = ACTIONS(4419),
    [anon_sym_Enum] = ACTIONS(4419),
    [anon_sym_eNUM] = ACTIONS(4419),
    [anon_sym_eNum] = ACTIONS(4419),
    [anon_sym_ENum] = ACTIONS(4419),
    [sym_quoted_identifier] = ACTIONS(4421),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4421),
    [sym_integer] = ACTIONS(4419),
    [sym_continue_as_identifier] = ACTIONS(4421),
    [sym_preproc_open] = ACTIONS(4421),
    [sym_end_keyword] = ACTIONS(4421),
  },
  [STATE(2265)] = {
    [sym_identifier] = ACTIONS(4229),
    [anon_sym_SEMI] = ACTIONS(4231),
    [anon_sym_DASH] = ACTIONS(4231),
    [aux_sym_boolean_token1] = ACTIONS(4229),
    [aux_sym_boolean_token2] = ACTIONS(4229),
    [sym_decimal] = ACTIONS(4229),
    [anon_sym_LPAREN] = ACTIONS(4231),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4229),
    [anon_sym_LBRACK] = ACTIONS(4231),
    [aux_sym_record_type_token1] = ACTIONS(4229),
    [aux_sym_basic_type_token21] = ACTIONS(4229),
    [aux_sym_basic_type_token22] = ACTIONS(4229),
    [aux_sym_basic_type_token48] = ACTIONS(4229),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4229),
    [anon_sym_POUNDif] = ACTIONS(4231),
    [anon_sym_POUNDIF] = ACTIONS(4231),
    [anon_sym_POUNDIf] = ACTIONS(4231),
    [anon_sym_not] = ACTIONS(4229),
    [anon_sym_NOT] = ACTIONS(4229),
    [anon_sym_Not] = ACTIONS(4229),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4229),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4229),
    [anon_sym_PLUS] = ACTIONS(4231),
    [sym_datetime_literal] = ACTIONS(4231),
    [sym_date_literal] = ACTIONS(4229),
    [sym_time_literal] = ACTIONS(4229),
    [sym_biginteger_literal] = ACTIONS(4231),
    [anon_sym_if] = ACTIONS(4229),
    [anon_sym_IF] = ACTIONS(4229),
    [anon_sym_If] = ACTIONS(4229),
    [anon_sym_else] = ACTIONS(4229),
    [anon_sym_ELSE] = ACTIONS(4229),
    [anon_sym_Else] = ACTIONS(4229),
    [anon_sym_case] = ACTIONS(4229),
    [anon_sym_CASE] = ACTIONS(4229),
    [anon_sym_Case] = ACTIONS(4229),
    [anon_sym_for] = ACTIONS(4229),
    [anon_sym_FOR] = ACTIONS(4229),
    [anon_sym_For] = ACTIONS(4229),
    [anon_sym_foreach] = ACTIONS(4229),
    [anon_sym_FOREACH] = ACTIONS(4229),
    [anon_sym_Foreach] = ACTIONS(4229),
    [anon_sym_while] = ACTIONS(4229),
    [anon_sym_WHILE] = ACTIONS(4229),
    [anon_sym_While] = ACTIONS(4229),
    [anon_sym_repeat] = ACTIONS(4229),
    [anon_sym_REPEAT] = ACTIONS(4229),
    [anon_sym_Repeat] = ACTIONS(4229),
    [anon_sym_exit] = ACTIONS(4229),
    [anon_sym_EXIT] = ACTIONS(4229),
    [anon_sym_Exit] = ACTIONS(4229),
    [anon_sym_continue] = ACTIONS(4229),
    [anon_sym_CONTINUE] = ACTIONS(4229),
    [anon_sym_Continue] = ACTIONS(4229),
    [anon_sym_break] = ACTIONS(4229),
    [anon_sym_BREAK] = ACTIONS(4229),
    [anon_sym_Break] = ACTIONS(4229),
    [anon_sym_with] = ACTIONS(4229),
    [anon_sym_WITH] = ACTIONS(4229),
    [anon_sym_With] = ACTIONS(4229),
    [sym_asserterror_keyword] = ACTIONS(4231),
    [sym_page_keyword] = ACTIONS(4229),
    [anon_sym_codeunit] = ACTIONS(4229),
    [anon_sym_CODEUNIT] = ACTIONS(4229),
    [anon_sym_Codeunit] = ACTIONS(4229),
    [anon_sym_CodeUnit] = ACTIONS(4229),
    [anon_sym_COdeunit] = ACTIONS(4229),
    [anon_sym_codeUnit] = ACTIONS(4229),
    [sym_report_keyword] = ACTIONS(4229),
    [sym_query_keyword] = ACTIONS(4229),
    [anon_sym_xmlport] = ACTIONS(4229),
    [anon_sym_XMLPORT] = ACTIONS(4229),
    [anon_sym_Xmlport] = ACTIONS(4229),
    [anon_sym_XMLport] = ACTIONS(4229),
    [anon_sym_XMLPort] = ACTIONS(4229),
    [anon_sym_XmlPort] = ACTIONS(4229),
    [anon_sym_enum] = ACTIONS(4229),
    [anon_sym_ENUM] = ACTIONS(4229),
    [anon_sym_Enum] = ACTIONS(4229),
    [anon_sym_eNUM] = ACTIONS(4229),
    [anon_sym_eNum] = ACTIONS(4229),
    [anon_sym_ENum] = ACTIONS(4229),
    [sym_quoted_identifier] = ACTIONS(4231),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4231),
    [sym_integer] = ACTIONS(4229),
    [sym_continue_as_identifier] = ACTIONS(4231),
    [sym_preproc_open] = ACTIONS(4231),
    [sym_end_keyword] = ACTIONS(4231),
  },
  [STATE(2266)] = {
    [sym_identifier] = ACTIONS(4592),
    [anon_sym_SEMI] = ACTIONS(5471),
    [anon_sym_DASH] = ACTIONS(4596),
    [aux_sym_boolean_token1] = ACTIONS(4592),
    [aux_sym_boolean_token2] = ACTIONS(4592),
    [sym_decimal] = ACTIONS(4592),
    [anon_sym_LPAREN] = ACTIONS(4596),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(4596),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4592),
    [anon_sym_POUNDif] = ACTIONS(4596),
    [anon_sym_POUNDIF] = ACTIONS(4596),
    [anon_sym_POUNDIf] = ACTIONS(4596),
    [anon_sym_not] = ACTIONS(4592),
    [anon_sym_NOT] = ACTIONS(4592),
    [anon_sym_Not] = ACTIONS(4592),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4592),
    [anon_sym_PLUS] = ACTIONS(4596),
    [sym_datetime_literal] = ACTIONS(4596),
    [sym_date_literal] = ACTIONS(4592),
    [sym_time_literal] = ACTIONS(4592),
    [sym_biginteger_literal] = ACTIONS(4596),
    [anon_sym_if] = ACTIONS(4592),
    [anon_sym_IF] = ACTIONS(4592),
    [anon_sym_If] = ACTIONS(4592),
    [anon_sym_else] = ACTIONS(4592),
    [anon_sym_ELSE] = ACTIONS(4592),
    [anon_sym_Else] = ACTIONS(4592),
    [anon_sym_case] = ACTIONS(4592),
    [anon_sym_CASE] = ACTIONS(4592),
    [anon_sym_Case] = ACTIONS(4592),
    [anon_sym_for] = ACTIONS(4592),
    [anon_sym_FOR] = ACTIONS(4592),
    [anon_sym_For] = ACTIONS(4592),
    [anon_sym_foreach] = ACTIONS(4592),
    [anon_sym_FOREACH] = ACTIONS(4592),
    [anon_sym_Foreach] = ACTIONS(4592),
    [anon_sym_while] = ACTIONS(4592),
    [anon_sym_WHILE] = ACTIONS(4592),
    [anon_sym_While] = ACTIONS(4592),
    [anon_sym_repeat] = ACTIONS(4592),
    [anon_sym_REPEAT] = ACTIONS(4592),
    [anon_sym_Repeat] = ACTIONS(4592),
    [anon_sym_exit] = ACTIONS(4592),
    [anon_sym_EXIT] = ACTIONS(4592),
    [anon_sym_Exit] = ACTIONS(4592),
    [anon_sym_continue] = ACTIONS(4592),
    [anon_sym_CONTINUE] = ACTIONS(4592),
    [anon_sym_Continue] = ACTIONS(4592),
    [anon_sym_break] = ACTIONS(4592),
    [anon_sym_BREAK] = ACTIONS(4592),
    [anon_sym_Break] = ACTIONS(4592),
    [anon_sym_with] = ACTIONS(4592),
    [anon_sym_WITH] = ACTIONS(4592),
    [anon_sym_With] = ACTIONS(4592),
    [sym_asserterror_keyword] = ACTIONS(4596),
    [sym_page_keyword] = ACTIONS(4592),
    [anon_sym_codeunit] = ACTIONS(4592),
    [anon_sym_CODEUNIT] = ACTIONS(4592),
    [anon_sym_Codeunit] = ACTIONS(4592),
    [anon_sym_CodeUnit] = ACTIONS(4592),
    [anon_sym_COdeunit] = ACTIONS(4592),
    [anon_sym_codeUnit] = ACTIONS(4592),
    [sym_report_keyword] = ACTIONS(4592),
    [sym_query_keyword] = ACTIONS(4592),
    [anon_sym_xmlport] = ACTIONS(4592),
    [anon_sym_XMLPORT] = ACTIONS(4592),
    [anon_sym_Xmlport] = ACTIONS(4592),
    [anon_sym_XMLport] = ACTIONS(4592),
    [anon_sym_XMLPort] = ACTIONS(4592),
    [anon_sym_XmlPort] = ACTIONS(4592),
    [anon_sym_enum] = ACTIONS(4592),
    [anon_sym_ENUM] = ACTIONS(4592),
    [anon_sym_Enum] = ACTIONS(4592),
    [anon_sym_eNUM] = ACTIONS(4592),
    [anon_sym_eNum] = ACTIONS(4592),
    [anon_sym_ENum] = ACTIONS(4592),
    [sym_quoted_identifier] = ACTIONS(4596),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4596),
    [sym_integer] = ACTIONS(4592),
    [sym_continue_as_identifier] = ACTIONS(4596),
    [sym_preproc_open] = ACTIONS(4596),
    [sym_end_keyword] = ACTIONS(4596),
  },
  [STATE(2267)] = {
    [sym_identifier] = ACTIONS(4233),
    [anon_sym_SEMI] = ACTIONS(4235),
    [anon_sym_DASH] = ACTIONS(4235),
    [aux_sym_boolean_token1] = ACTIONS(4233),
    [aux_sym_boolean_token2] = ACTIONS(4233),
    [sym_decimal] = ACTIONS(4233),
    [anon_sym_LPAREN] = ACTIONS(4235),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4233),
    [anon_sym_LBRACK] = ACTIONS(4235),
    [aux_sym_record_type_token1] = ACTIONS(4233),
    [aux_sym_basic_type_token21] = ACTIONS(4233),
    [aux_sym_basic_type_token22] = ACTIONS(4233),
    [aux_sym_basic_type_token48] = ACTIONS(4233),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4233),
    [anon_sym_POUNDif] = ACTIONS(4235),
    [anon_sym_POUNDIF] = ACTIONS(4235),
    [anon_sym_POUNDIf] = ACTIONS(4235),
    [anon_sym_not] = ACTIONS(4233),
    [anon_sym_NOT] = ACTIONS(4233),
    [anon_sym_Not] = ACTIONS(4233),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4233),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4233),
    [anon_sym_PLUS] = ACTIONS(4235),
    [sym_datetime_literal] = ACTIONS(4235),
    [sym_date_literal] = ACTIONS(4233),
    [sym_time_literal] = ACTIONS(4233),
    [sym_biginteger_literal] = ACTIONS(4235),
    [anon_sym_if] = ACTIONS(4233),
    [anon_sym_IF] = ACTIONS(4233),
    [anon_sym_If] = ACTIONS(4233),
    [anon_sym_else] = ACTIONS(4233),
    [anon_sym_ELSE] = ACTIONS(4233),
    [anon_sym_Else] = ACTIONS(4233),
    [anon_sym_case] = ACTIONS(4233),
    [anon_sym_CASE] = ACTIONS(4233),
    [anon_sym_Case] = ACTIONS(4233),
    [anon_sym_for] = ACTIONS(4233),
    [anon_sym_FOR] = ACTIONS(4233),
    [anon_sym_For] = ACTIONS(4233),
    [anon_sym_foreach] = ACTIONS(4233),
    [anon_sym_FOREACH] = ACTIONS(4233),
    [anon_sym_Foreach] = ACTIONS(4233),
    [anon_sym_while] = ACTIONS(4233),
    [anon_sym_WHILE] = ACTIONS(4233),
    [anon_sym_While] = ACTIONS(4233),
    [anon_sym_repeat] = ACTIONS(4233),
    [anon_sym_REPEAT] = ACTIONS(4233),
    [anon_sym_Repeat] = ACTIONS(4233),
    [anon_sym_exit] = ACTIONS(4233),
    [anon_sym_EXIT] = ACTIONS(4233),
    [anon_sym_Exit] = ACTIONS(4233),
    [anon_sym_continue] = ACTIONS(4233),
    [anon_sym_CONTINUE] = ACTIONS(4233),
    [anon_sym_Continue] = ACTIONS(4233),
    [anon_sym_break] = ACTIONS(4233),
    [anon_sym_BREAK] = ACTIONS(4233),
    [anon_sym_Break] = ACTIONS(4233),
    [anon_sym_with] = ACTIONS(4233),
    [anon_sym_WITH] = ACTIONS(4233),
    [anon_sym_With] = ACTIONS(4233),
    [sym_asserterror_keyword] = ACTIONS(4235),
    [sym_page_keyword] = ACTIONS(4233),
    [anon_sym_codeunit] = ACTIONS(4233),
    [anon_sym_CODEUNIT] = ACTIONS(4233),
    [anon_sym_Codeunit] = ACTIONS(4233),
    [anon_sym_CodeUnit] = ACTIONS(4233),
    [anon_sym_COdeunit] = ACTIONS(4233),
    [anon_sym_codeUnit] = ACTIONS(4233),
    [sym_report_keyword] = ACTIONS(4233),
    [sym_query_keyword] = ACTIONS(4233),
    [anon_sym_xmlport] = ACTIONS(4233),
    [anon_sym_XMLPORT] = ACTIONS(4233),
    [anon_sym_Xmlport] = ACTIONS(4233),
    [anon_sym_XMLport] = ACTIONS(4233),
    [anon_sym_XMLPort] = ACTIONS(4233),
    [anon_sym_XmlPort] = ACTIONS(4233),
    [anon_sym_enum] = ACTIONS(4233),
    [anon_sym_ENUM] = ACTIONS(4233),
    [anon_sym_Enum] = ACTIONS(4233),
    [anon_sym_eNUM] = ACTIONS(4233),
    [anon_sym_eNum] = ACTIONS(4233),
    [anon_sym_ENum] = ACTIONS(4233),
    [sym_quoted_identifier] = ACTIONS(4235),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4235),
    [sym_integer] = ACTIONS(4233),
    [sym_continue_as_identifier] = ACTIONS(4235),
    [sym_preproc_open] = ACTIONS(4235),
    [sym_end_keyword] = ACTIONS(4235),
  },
  [STATE(2268)] = {
    [sym_identifier] = ACTIONS(4610),
    [anon_sym_SEMI] = ACTIONS(4612),
    [anon_sym_DASH] = ACTIONS(4612),
    [aux_sym_boolean_token1] = ACTIONS(4610),
    [aux_sym_boolean_token2] = ACTIONS(4610),
    [sym_decimal] = ACTIONS(4610),
    [anon_sym_LPAREN] = ACTIONS(4612),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4610),
    [anon_sym_LBRACK] = ACTIONS(4612),
    [aux_sym_record_type_token1] = ACTIONS(4610),
    [aux_sym_basic_type_token21] = ACTIONS(4610),
    [aux_sym_basic_type_token22] = ACTIONS(4610),
    [aux_sym_basic_type_token48] = ACTIONS(4610),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4610),
    [anon_sym_POUNDif] = ACTIONS(4612),
    [anon_sym_POUNDIF] = ACTIONS(4612),
    [anon_sym_POUNDIf] = ACTIONS(4612),
    [anon_sym_not] = ACTIONS(4610),
    [anon_sym_NOT] = ACTIONS(4610),
    [anon_sym_Not] = ACTIONS(4610),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4610),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4610),
    [anon_sym_PLUS] = ACTIONS(4612),
    [sym_datetime_literal] = ACTIONS(4612),
    [sym_date_literal] = ACTIONS(4610),
    [sym_time_literal] = ACTIONS(4610),
    [sym_biginteger_literal] = ACTIONS(4612),
    [anon_sym_if] = ACTIONS(4610),
    [anon_sym_IF] = ACTIONS(4610),
    [anon_sym_If] = ACTIONS(4610),
    [anon_sym_else] = ACTIONS(4610),
    [anon_sym_ELSE] = ACTIONS(4610),
    [anon_sym_Else] = ACTIONS(4610),
    [anon_sym_case] = ACTIONS(4610),
    [anon_sym_CASE] = ACTIONS(4610),
    [anon_sym_Case] = ACTIONS(4610),
    [anon_sym_for] = ACTIONS(4610),
    [anon_sym_FOR] = ACTIONS(4610),
    [anon_sym_For] = ACTIONS(4610),
    [anon_sym_foreach] = ACTIONS(4610),
    [anon_sym_FOREACH] = ACTIONS(4610),
    [anon_sym_Foreach] = ACTIONS(4610),
    [anon_sym_while] = ACTIONS(4610),
    [anon_sym_WHILE] = ACTIONS(4610),
    [anon_sym_While] = ACTIONS(4610),
    [anon_sym_repeat] = ACTIONS(4610),
    [anon_sym_REPEAT] = ACTIONS(4610),
    [anon_sym_Repeat] = ACTIONS(4610),
    [anon_sym_exit] = ACTIONS(4610),
    [anon_sym_EXIT] = ACTIONS(4610),
    [anon_sym_Exit] = ACTIONS(4610),
    [anon_sym_continue] = ACTIONS(4610),
    [anon_sym_CONTINUE] = ACTIONS(4610),
    [anon_sym_Continue] = ACTIONS(4610),
    [anon_sym_break] = ACTIONS(4610),
    [anon_sym_BREAK] = ACTIONS(4610),
    [anon_sym_Break] = ACTIONS(4610),
    [anon_sym_with] = ACTIONS(4610),
    [anon_sym_WITH] = ACTIONS(4610),
    [anon_sym_With] = ACTIONS(4610),
    [sym_asserterror_keyword] = ACTIONS(4612),
    [sym_page_keyword] = ACTIONS(4610),
    [anon_sym_codeunit] = ACTIONS(4610),
    [anon_sym_CODEUNIT] = ACTIONS(4610),
    [anon_sym_Codeunit] = ACTIONS(4610),
    [anon_sym_CodeUnit] = ACTIONS(4610),
    [anon_sym_COdeunit] = ACTIONS(4610),
    [anon_sym_codeUnit] = ACTIONS(4610),
    [sym_report_keyword] = ACTIONS(4610),
    [sym_query_keyword] = ACTIONS(4610),
    [anon_sym_xmlport] = ACTIONS(4610),
    [anon_sym_XMLPORT] = ACTIONS(4610),
    [anon_sym_Xmlport] = ACTIONS(4610),
    [anon_sym_XMLport] = ACTIONS(4610),
    [anon_sym_XMLPort] = ACTIONS(4610),
    [anon_sym_XmlPort] = ACTIONS(4610),
    [anon_sym_enum] = ACTIONS(4610),
    [anon_sym_ENUM] = ACTIONS(4610),
    [anon_sym_Enum] = ACTIONS(4610),
    [anon_sym_eNUM] = ACTIONS(4610),
    [anon_sym_eNum] = ACTIONS(4610),
    [anon_sym_ENum] = ACTIONS(4610),
    [sym_quoted_identifier] = ACTIONS(4612),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4612),
    [sym_integer] = ACTIONS(4610),
    [sym_continue_as_identifier] = ACTIONS(4612),
    [sym_preproc_open] = ACTIONS(4612),
    [sym_end_keyword] = ACTIONS(4612),
  },
  [STATE(2269)] = {
    [sym_identifier] = ACTIONS(4237),
    [anon_sym_SEMI] = ACTIONS(4239),
    [anon_sym_DASH] = ACTIONS(4239),
    [aux_sym_boolean_token1] = ACTIONS(4237),
    [aux_sym_boolean_token2] = ACTIONS(4237),
    [sym_decimal] = ACTIONS(4237),
    [anon_sym_LPAREN] = ACTIONS(4239),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4237),
    [anon_sym_LBRACK] = ACTIONS(4239),
    [aux_sym_record_type_token1] = ACTIONS(4237),
    [aux_sym_basic_type_token21] = ACTIONS(4237),
    [aux_sym_basic_type_token22] = ACTIONS(4237),
    [aux_sym_basic_type_token48] = ACTIONS(4237),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4237),
    [anon_sym_POUNDif] = ACTIONS(4239),
    [anon_sym_POUNDIF] = ACTIONS(4239),
    [anon_sym_POUNDIf] = ACTIONS(4239),
    [anon_sym_not] = ACTIONS(4237),
    [anon_sym_NOT] = ACTIONS(4237),
    [anon_sym_Not] = ACTIONS(4237),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4237),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4237),
    [anon_sym_PLUS] = ACTIONS(4239),
    [sym_datetime_literal] = ACTIONS(4239),
    [sym_date_literal] = ACTIONS(4237),
    [sym_time_literal] = ACTIONS(4237),
    [sym_biginteger_literal] = ACTIONS(4239),
    [anon_sym_if] = ACTIONS(4237),
    [anon_sym_IF] = ACTIONS(4237),
    [anon_sym_If] = ACTIONS(4237),
    [anon_sym_else] = ACTIONS(4237),
    [anon_sym_ELSE] = ACTIONS(4237),
    [anon_sym_Else] = ACTIONS(4237),
    [anon_sym_case] = ACTIONS(4237),
    [anon_sym_CASE] = ACTIONS(4237),
    [anon_sym_Case] = ACTIONS(4237),
    [anon_sym_for] = ACTIONS(4237),
    [anon_sym_FOR] = ACTIONS(4237),
    [anon_sym_For] = ACTIONS(4237),
    [anon_sym_foreach] = ACTIONS(4237),
    [anon_sym_FOREACH] = ACTIONS(4237),
    [anon_sym_Foreach] = ACTIONS(4237),
    [anon_sym_while] = ACTIONS(4237),
    [anon_sym_WHILE] = ACTIONS(4237),
    [anon_sym_While] = ACTIONS(4237),
    [anon_sym_repeat] = ACTIONS(4237),
    [anon_sym_REPEAT] = ACTIONS(4237),
    [anon_sym_Repeat] = ACTIONS(4237),
    [anon_sym_exit] = ACTIONS(4237),
    [anon_sym_EXIT] = ACTIONS(4237),
    [anon_sym_Exit] = ACTIONS(4237),
    [anon_sym_continue] = ACTIONS(4237),
    [anon_sym_CONTINUE] = ACTIONS(4237),
    [anon_sym_Continue] = ACTIONS(4237),
    [anon_sym_break] = ACTIONS(4237),
    [anon_sym_BREAK] = ACTIONS(4237),
    [anon_sym_Break] = ACTIONS(4237),
    [anon_sym_with] = ACTIONS(4237),
    [anon_sym_WITH] = ACTIONS(4237),
    [anon_sym_With] = ACTIONS(4237),
    [sym_asserterror_keyword] = ACTIONS(4239),
    [sym_page_keyword] = ACTIONS(4237),
    [anon_sym_codeunit] = ACTIONS(4237),
    [anon_sym_CODEUNIT] = ACTIONS(4237),
    [anon_sym_Codeunit] = ACTIONS(4237),
    [anon_sym_CodeUnit] = ACTIONS(4237),
    [anon_sym_COdeunit] = ACTIONS(4237),
    [anon_sym_codeUnit] = ACTIONS(4237),
    [sym_report_keyword] = ACTIONS(4237),
    [sym_query_keyword] = ACTIONS(4237),
    [anon_sym_xmlport] = ACTIONS(4237),
    [anon_sym_XMLPORT] = ACTIONS(4237),
    [anon_sym_Xmlport] = ACTIONS(4237),
    [anon_sym_XMLport] = ACTIONS(4237),
    [anon_sym_XMLPort] = ACTIONS(4237),
    [anon_sym_XmlPort] = ACTIONS(4237),
    [anon_sym_enum] = ACTIONS(4237),
    [anon_sym_ENUM] = ACTIONS(4237),
    [anon_sym_Enum] = ACTIONS(4237),
    [anon_sym_eNUM] = ACTIONS(4237),
    [anon_sym_eNum] = ACTIONS(4237),
    [anon_sym_ENum] = ACTIONS(4237),
    [sym_quoted_identifier] = ACTIONS(4239),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4239),
    [sym_integer] = ACTIONS(4237),
    [sym_continue_as_identifier] = ACTIONS(4239),
    [sym_preproc_open] = ACTIONS(4239),
    [sym_end_keyword] = ACTIONS(4239),
  },
  [STATE(2270)] = {
    [sym_identifier] = ACTIONS(4614),
    [anon_sym_SEMI] = ACTIONS(4616),
    [anon_sym_DASH] = ACTIONS(4616),
    [aux_sym_boolean_token1] = ACTIONS(4614),
    [aux_sym_boolean_token2] = ACTIONS(4614),
    [sym_decimal] = ACTIONS(4614),
    [anon_sym_LPAREN] = ACTIONS(4616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4614),
    [anon_sym_LBRACK] = ACTIONS(4616),
    [aux_sym_record_type_token1] = ACTIONS(4614),
    [aux_sym_basic_type_token21] = ACTIONS(4614),
    [aux_sym_basic_type_token22] = ACTIONS(4614),
    [aux_sym_basic_type_token48] = ACTIONS(4614),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4614),
    [anon_sym_POUNDif] = ACTIONS(4616),
    [anon_sym_POUNDIF] = ACTIONS(4616),
    [anon_sym_POUNDIf] = ACTIONS(4616),
    [anon_sym_not] = ACTIONS(4614),
    [anon_sym_NOT] = ACTIONS(4614),
    [anon_sym_Not] = ACTIONS(4614),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4614),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4614),
    [anon_sym_PLUS] = ACTIONS(4616),
    [sym_datetime_literal] = ACTIONS(4616),
    [sym_date_literal] = ACTIONS(4614),
    [sym_time_literal] = ACTIONS(4614),
    [sym_biginteger_literal] = ACTIONS(4616),
    [anon_sym_if] = ACTIONS(4614),
    [anon_sym_IF] = ACTIONS(4614),
    [anon_sym_If] = ACTIONS(4614),
    [anon_sym_else] = ACTIONS(4614),
    [anon_sym_ELSE] = ACTIONS(4614),
    [anon_sym_Else] = ACTIONS(4614),
    [anon_sym_case] = ACTIONS(4614),
    [anon_sym_CASE] = ACTIONS(4614),
    [anon_sym_Case] = ACTIONS(4614),
    [anon_sym_for] = ACTIONS(4614),
    [anon_sym_FOR] = ACTIONS(4614),
    [anon_sym_For] = ACTIONS(4614),
    [anon_sym_foreach] = ACTIONS(4614),
    [anon_sym_FOREACH] = ACTIONS(4614),
    [anon_sym_Foreach] = ACTIONS(4614),
    [anon_sym_while] = ACTIONS(4614),
    [anon_sym_WHILE] = ACTIONS(4614),
    [anon_sym_While] = ACTIONS(4614),
    [anon_sym_repeat] = ACTIONS(4614),
    [anon_sym_REPEAT] = ACTIONS(4614),
    [anon_sym_Repeat] = ACTIONS(4614),
    [anon_sym_exit] = ACTIONS(4614),
    [anon_sym_EXIT] = ACTIONS(4614),
    [anon_sym_Exit] = ACTIONS(4614),
    [anon_sym_continue] = ACTIONS(4614),
    [anon_sym_CONTINUE] = ACTIONS(4614),
    [anon_sym_Continue] = ACTIONS(4614),
    [anon_sym_break] = ACTIONS(4614),
    [anon_sym_BREAK] = ACTIONS(4614),
    [anon_sym_Break] = ACTIONS(4614),
    [anon_sym_with] = ACTIONS(4614),
    [anon_sym_WITH] = ACTIONS(4614),
    [anon_sym_With] = ACTIONS(4614),
    [sym_asserterror_keyword] = ACTIONS(4616),
    [sym_page_keyword] = ACTIONS(4614),
    [anon_sym_codeunit] = ACTIONS(4614),
    [anon_sym_CODEUNIT] = ACTIONS(4614),
    [anon_sym_Codeunit] = ACTIONS(4614),
    [anon_sym_CodeUnit] = ACTIONS(4614),
    [anon_sym_COdeunit] = ACTIONS(4614),
    [anon_sym_codeUnit] = ACTIONS(4614),
    [sym_report_keyword] = ACTIONS(4614),
    [sym_query_keyword] = ACTIONS(4614),
    [anon_sym_xmlport] = ACTIONS(4614),
    [anon_sym_XMLPORT] = ACTIONS(4614),
    [anon_sym_Xmlport] = ACTIONS(4614),
    [anon_sym_XMLport] = ACTIONS(4614),
    [anon_sym_XMLPort] = ACTIONS(4614),
    [anon_sym_XmlPort] = ACTIONS(4614),
    [anon_sym_enum] = ACTIONS(4614),
    [anon_sym_ENUM] = ACTIONS(4614),
    [anon_sym_Enum] = ACTIONS(4614),
    [anon_sym_eNUM] = ACTIONS(4614),
    [anon_sym_eNum] = ACTIONS(4614),
    [anon_sym_ENum] = ACTIONS(4614),
    [sym_quoted_identifier] = ACTIONS(4616),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4616),
    [sym_integer] = ACTIONS(4614),
    [sym_continue_as_identifier] = ACTIONS(4616),
    [sym_preproc_open] = ACTIONS(4616),
    [sym_end_keyword] = ACTIONS(4616),
  },
  [STATE(2271)] = {
    [sym_identifier] = ACTIONS(4423),
    [anon_sym_SEMI] = ACTIONS(4425),
    [anon_sym_DASH] = ACTIONS(4425),
    [aux_sym_boolean_token1] = ACTIONS(4423),
    [aux_sym_boolean_token2] = ACTIONS(4423),
    [sym_decimal] = ACTIONS(4423),
    [anon_sym_LPAREN] = ACTIONS(4425),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4423),
    [anon_sym_LBRACK] = ACTIONS(4425),
    [aux_sym_record_type_token1] = ACTIONS(4423),
    [aux_sym_basic_type_token21] = ACTIONS(4423),
    [aux_sym_basic_type_token22] = ACTIONS(4423),
    [aux_sym_basic_type_token48] = ACTIONS(4423),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4423),
    [anon_sym_POUNDif] = ACTIONS(4425),
    [anon_sym_POUNDIF] = ACTIONS(4425),
    [anon_sym_POUNDIf] = ACTIONS(4425),
    [anon_sym_not] = ACTIONS(4423),
    [anon_sym_NOT] = ACTIONS(4423),
    [anon_sym_Not] = ACTIONS(4423),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4423),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4423),
    [anon_sym_PLUS] = ACTIONS(4425),
    [sym_datetime_literal] = ACTIONS(4425),
    [sym_date_literal] = ACTIONS(4423),
    [sym_time_literal] = ACTIONS(4423),
    [sym_biginteger_literal] = ACTIONS(4425),
    [anon_sym_if] = ACTIONS(4423),
    [anon_sym_IF] = ACTIONS(4423),
    [anon_sym_If] = ACTIONS(4423),
    [anon_sym_else] = ACTIONS(4423),
    [anon_sym_ELSE] = ACTIONS(4423),
    [anon_sym_Else] = ACTIONS(4423),
    [anon_sym_case] = ACTIONS(4423),
    [anon_sym_CASE] = ACTIONS(4423),
    [anon_sym_Case] = ACTIONS(4423),
    [anon_sym_for] = ACTIONS(4423),
    [anon_sym_FOR] = ACTIONS(4423),
    [anon_sym_For] = ACTIONS(4423),
    [anon_sym_foreach] = ACTIONS(4423),
    [anon_sym_FOREACH] = ACTIONS(4423),
    [anon_sym_Foreach] = ACTIONS(4423),
    [anon_sym_while] = ACTIONS(4423),
    [anon_sym_WHILE] = ACTIONS(4423),
    [anon_sym_While] = ACTIONS(4423),
    [anon_sym_repeat] = ACTIONS(4423),
    [anon_sym_REPEAT] = ACTIONS(4423),
    [anon_sym_Repeat] = ACTIONS(4423),
    [anon_sym_exit] = ACTIONS(4423),
    [anon_sym_EXIT] = ACTIONS(4423),
    [anon_sym_Exit] = ACTIONS(4423),
    [anon_sym_continue] = ACTIONS(4423),
    [anon_sym_CONTINUE] = ACTIONS(4423),
    [anon_sym_Continue] = ACTIONS(4423),
    [anon_sym_break] = ACTIONS(4423),
    [anon_sym_BREAK] = ACTIONS(4423),
    [anon_sym_Break] = ACTIONS(4423),
    [anon_sym_with] = ACTIONS(4423),
    [anon_sym_WITH] = ACTIONS(4423),
    [anon_sym_With] = ACTIONS(4423),
    [sym_asserterror_keyword] = ACTIONS(4425),
    [sym_page_keyword] = ACTIONS(4423),
    [anon_sym_codeunit] = ACTIONS(4423),
    [anon_sym_CODEUNIT] = ACTIONS(4423),
    [anon_sym_Codeunit] = ACTIONS(4423),
    [anon_sym_CodeUnit] = ACTIONS(4423),
    [anon_sym_COdeunit] = ACTIONS(4423),
    [anon_sym_codeUnit] = ACTIONS(4423),
    [sym_report_keyword] = ACTIONS(4423),
    [sym_query_keyword] = ACTIONS(4423),
    [anon_sym_xmlport] = ACTIONS(4423),
    [anon_sym_XMLPORT] = ACTIONS(4423),
    [anon_sym_Xmlport] = ACTIONS(4423),
    [anon_sym_XMLport] = ACTIONS(4423),
    [anon_sym_XMLPort] = ACTIONS(4423),
    [anon_sym_XmlPort] = ACTIONS(4423),
    [anon_sym_enum] = ACTIONS(4423),
    [anon_sym_ENUM] = ACTIONS(4423),
    [anon_sym_Enum] = ACTIONS(4423),
    [anon_sym_eNUM] = ACTIONS(4423),
    [anon_sym_eNum] = ACTIONS(4423),
    [anon_sym_ENum] = ACTIONS(4423),
    [sym_quoted_identifier] = ACTIONS(4425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4425),
    [sym_integer] = ACTIONS(4423),
    [sym_continue_as_identifier] = ACTIONS(4425),
    [sym_preproc_open] = ACTIONS(4425),
    [sym_end_keyword] = ACTIONS(4425),
  },
  [STATE(2272)] = {
    [sym_identifier] = ACTIONS(4756),
    [anon_sym_SEMI] = ACTIONS(4758),
    [anon_sym_DASH] = ACTIONS(4758),
    [aux_sym_boolean_token1] = ACTIONS(4756),
    [aux_sym_boolean_token2] = ACTIONS(4756),
    [sym_decimal] = ACTIONS(4756),
    [anon_sym_LPAREN] = ACTIONS(4758),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4756),
    [anon_sym_LBRACK] = ACTIONS(4758),
    [aux_sym_record_type_token1] = ACTIONS(4756),
    [aux_sym_basic_type_token21] = ACTIONS(4756),
    [aux_sym_basic_type_token22] = ACTIONS(4756),
    [aux_sym_basic_type_token48] = ACTIONS(4756),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4756),
    [anon_sym_POUNDif] = ACTIONS(4758),
    [anon_sym_POUNDIF] = ACTIONS(4758),
    [anon_sym_POUNDIf] = ACTIONS(4758),
    [anon_sym_not] = ACTIONS(4756),
    [anon_sym_NOT] = ACTIONS(4756),
    [anon_sym_Not] = ACTIONS(4756),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4756),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4756),
    [anon_sym_PLUS] = ACTIONS(4758),
    [sym_datetime_literal] = ACTIONS(4758),
    [sym_date_literal] = ACTIONS(4756),
    [sym_time_literal] = ACTIONS(4756),
    [sym_biginteger_literal] = ACTIONS(4758),
    [anon_sym_if] = ACTIONS(4756),
    [anon_sym_IF] = ACTIONS(4756),
    [anon_sym_If] = ACTIONS(4756),
    [anon_sym_else] = ACTIONS(4756),
    [anon_sym_ELSE] = ACTIONS(4756),
    [anon_sym_Else] = ACTIONS(4756),
    [anon_sym_case] = ACTIONS(4756),
    [anon_sym_CASE] = ACTIONS(4756),
    [anon_sym_Case] = ACTIONS(4756),
    [anon_sym_for] = ACTIONS(4756),
    [anon_sym_FOR] = ACTIONS(4756),
    [anon_sym_For] = ACTIONS(4756),
    [anon_sym_foreach] = ACTIONS(4756),
    [anon_sym_FOREACH] = ACTIONS(4756),
    [anon_sym_Foreach] = ACTIONS(4756),
    [anon_sym_while] = ACTIONS(4756),
    [anon_sym_WHILE] = ACTIONS(4756),
    [anon_sym_While] = ACTIONS(4756),
    [anon_sym_repeat] = ACTIONS(4756),
    [anon_sym_REPEAT] = ACTIONS(4756),
    [anon_sym_Repeat] = ACTIONS(4756),
    [anon_sym_exit] = ACTIONS(4756),
    [anon_sym_EXIT] = ACTIONS(4756),
    [anon_sym_Exit] = ACTIONS(4756),
    [anon_sym_continue] = ACTIONS(4756),
    [anon_sym_CONTINUE] = ACTIONS(4756),
    [anon_sym_Continue] = ACTIONS(4756),
    [anon_sym_break] = ACTIONS(4756),
    [anon_sym_BREAK] = ACTIONS(4756),
    [anon_sym_Break] = ACTIONS(4756),
    [anon_sym_with] = ACTIONS(4756),
    [anon_sym_WITH] = ACTIONS(4756),
    [anon_sym_With] = ACTIONS(4756),
    [sym_asserterror_keyword] = ACTIONS(4758),
    [sym_page_keyword] = ACTIONS(4756),
    [anon_sym_codeunit] = ACTIONS(4756),
    [anon_sym_CODEUNIT] = ACTIONS(4756),
    [anon_sym_Codeunit] = ACTIONS(4756),
    [anon_sym_CodeUnit] = ACTIONS(4756),
    [anon_sym_COdeunit] = ACTIONS(4756),
    [anon_sym_codeUnit] = ACTIONS(4756),
    [sym_report_keyword] = ACTIONS(4756),
    [sym_query_keyword] = ACTIONS(4756),
    [anon_sym_xmlport] = ACTIONS(4756),
    [anon_sym_XMLPORT] = ACTIONS(4756),
    [anon_sym_Xmlport] = ACTIONS(4756),
    [anon_sym_XMLport] = ACTIONS(4756),
    [anon_sym_XMLPort] = ACTIONS(4756),
    [anon_sym_XmlPort] = ACTIONS(4756),
    [anon_sym_enum] = ACTIONS(4756),
    [anon_sym_ENUM] = ACTIONS(4756),
    [anon_sym_Enum] = ACTIONS(4756),
    [anon_sym_eNUM] = ACTIONS(4756),
    [anon_sym_eNum] = ACTIONS(4756),
    [anon_sym_ENum] = ACTIONS(4756),
    [sym_quoted_identifier] = ACTIONS(4758),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4758),
    [sym_integer] = ACTIONS(4756),
    [sym_continue_as_identifier] = ACTIONS(4758),
    [sym_preproc_open] = ACTIONS(4758),
    [sym_end_keyword] = ACTIONS(4758),
  },
  [STATE(2273)] = {
    [sym_identifier] = ACTIONS(4241),
    [anon_sym_SEMI] = ACTIONS(4243),
    [anon_sym_DASH] = ACTIONS(4243),
    [aux_sym_boolean_token1] = ACTIONS(4241),
    [aux_sym_boolean_token2] = ACTIONS(4241),
    [sym_decimal] = ACTIONS(4241),
    [anon_sym_LPAREN] = ACTIONS(4243),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4241),
    [anon_sym_LBRACK] = ACTIONS(4243),
    [aux_sym_record_type_token1] = ACTIONS(4241),
    [aux_sym_basic_type_token21] = ACTIONS(4241),
    [aux_sym_basic_type_token22] = ACTIONS(4241),
    [aux_sym_basic_type_token48] = ACTIONS(4241),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4241),
    [anon_sym_POUNDif] = ACTIONS(4243),
    [anon_sym_POUNDIF] = ACTIONS(4243),
    [anon_sym_POUNDIf] = ACTIONS(4243),
    [anon_sym_not] = ACTIONS(4241),
    [anon_sym_NOT] = ACTIONS(4241),
    [anon_sym_Not] = ACTIONS(4241),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4241),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4241),
    [anon_sym_PLUS] = ACTIONS(4243),
    [sym_datetime_literal] = ACTIONS(4243),
    [sym_date_literal] = ACTIONS(4241),
    [sym_time_literal] = ACTIONS(4241),
    [sym_biginteger_literal] = ACTIONS(4243),
    [anon_sym_if] = ACTIONS(4241),
    [anon_sym_IF] = ACTIONS(4241),
    [anon_sym_If] = ACTIONS(4241),
    [anon_sym_else] = ACTIONS(4241),
    [anon_sym_ELSE] = ACTIONS(4241),
    [anon_sym_Else] = ACTIONS(4241),
    [anon_sym_case] = ACTIONS(4241),
    [anon_sym_CASE] = ACTIONS(4241),
    [anon_sym_Case] = ACTIONS(4241),
    [anon_sym_for] = ACTIONS(4241),
    [anon_sym_FOR] = ACTIONS(4241),
    [anon_sym_For] = ACTIONS(4241),
    [anon_sym_foreach] = ACTIONS(4241),
    [anon_sym_FOREACH] = ACTIONS(4241),
    [anon_sym_Foreach] = ACTIONS(4241),
    [anon_sym_while] = ACTIONS(4241),
    [anon_sym_WHILE] = ACTIONS(4241),
    [anon_sym_While] = ACTIONS(4241),
    [anon_sym_repeat] = ACTIONS(4241),
    [anon_sym_REPEAT] = ACTIONS(4241),
    [anon_sym_Repeat] = ACTIONS(4241),
    [anon_sym_exit] = ACTIONS(4241),
    [anon_sym_EXIT] = ACTIONS(4241),
    [anon_sym_Exit] = ACTIONS(4241),
    [anon_sym_continue] = ACTIONS(4241),
    [anon_sym_CONTINUE] = ACTIONS(4241),
    [anon_sym_Continue] = ACTIONS(4241),
    [anon_sym_break] = ACTIONS(4241),
    [anon_sym_BREAK] = ACTIONS(4241),
    [anon_sym_Break] = ACTIONS(4241),
    [anon_sym_with] = ACTIONS(4241),
    [anon_sym_WITH] = ACTIONS(4241),
    [anon_sym_With] = ACTIONS(4241),
    [sym_asserterror_keyword] = ACTIONS(4243),
    [sym_page_keyword] = ACTIONS(4241),
    [anon_sym_codeunit] = ACTIONS(4241),
    [anon_sym_CODEUNIT] = ACTIONS(4241),
    [anon_sym_Codeunit] = ACTIONS(4241),
    [anon_sym_CodeUnit] = ACTIONS(4241),
    [anon_sym_COdeunit] = ACTIONS(4241),
    [anon_sym_codeUnit] = ACTIONS(4241),
    [sym_report_keyword] = ACTIONS(4241),
    [sym_query_keyword] = ACTIONS(4241),
    [anon_sym_xmlport] = ACTIONS(4241),
    [anon_sym_XMLPORT] = ACTIONS(4241),
    [anon_sym_Xmlport] = ACTIONS(4241),
    [anon_sym_XMLport] = ACTIONS(4241),
    [anon_sym_XMLPort] = ACTIONS(4241),
    [anon_sym_XmlPort] = ACTIONS(4241),
    [anon_sym_enum] = ACTIONS(4241),
    [anon_sym_ENUM] = ACTIONS(4241),
    [anon_sym_Enum] = ACTIONS(4241),
    [anon_sym_eNUM] = ACTIONS(4241),
    [anon_sym_eNum] = ACTIONS(4241),
    [anon_sym_ENum] = ACTIONS(4241),
    [sym_quoted_identifier] = ACTIONS(4243),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4243),
    [sym_integer] = ACTIONS(4241),
    [sym_continue_as_identifier] = ACTIONS(4243),
    [sym_preproc_open] = ACTIONS(4243),
    [sym_end_keyword] = ACTIONS(4243),
  },
  [STATE(2274)] = {
    [anon_sym_POUNDif] = ACTIONS(5449),
    [anon_sym_POUNDIF] = ACTIONS(5449),
    [anon_sym_POUNDIf] = ACTIONS(5449),
    [anon_sym_POUNDendif] = ACTIONS(5449),
    [anon_sym_POUNDENDIF] = ACTIONS(5449),
    [anon_sym_POUNDEndif] = ACTIONS(5449),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5447),
    [anon_sym_tableextension] = ACTIONS(5449),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5449),
    [anon_sym_Tableextension] = ACTIONS(5449),
    [anon_sym_TableExtension] = ACTIONS(5449),
    [anon_sym_tableExtension] = ACTIONS(5449),
    [sym_page_keyword] = ACTIONS(5447),
    [anon_sym_pageextension] = ACTIONS(5449),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5449),
    [anon_sym_Pageextension] = ACTIONS(5449),
    [anon_sym_PageExtension] = ACTIONS(5449),
    [anon_sym_pageExtension] = ACTIONS(5449),
    [anon_sym_codeunit] = ACTIONS(5449),
    [anon_sym_CODEUNIT] = ACTIONS(5449),
    [anon_sym_Codeunit] = ACTIONS(5449),
    [anon_sym_CodeUnit] = ACTIONS(5449),
    [anon_sym_COdeunit] = ACTIONS(5449),
    [anon_sym_codeUnit] = ACTIONS(5449),
    [sym_report_keyword] = ACTIONS(5447),
    [anon_sym_reportextension] = ACTIONS(5449),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5449),
    [anon_sym_Reportextension] = ACTIONS(5449),
    [anon_sym_ReportExtension] = ACTIONS(5449),
    [anon_sym_reportExtension] = ACTIONS(5449),
    [sym_query_keyword] = ACTIONS(5449),
    [anon_sym_xmlport] = ACTIONS(5449),
    [anon_sym_XMLPORT] = ACTIONS(5449),
    [anon_sym_Xmlport] = ACTIONS(5449),
    [anon_sym_XMLport] = ACTIONS(5449),
    [anon_sym_XMLPort] = ACTIONS(5449),
    [anon_sym_XmlPort] = ACTIONS(5449),
    [anon_sym_enum] = ACTIONS(5447),
    [anon_sym_ENUM] = ACTIONS(5447),
    [anon_sym_Enum] = ACTIONS(5447),
    [anon_sym_eNUM] = ACTIONS(5449),
    [anon_sym_eNum] = ACTIONS(5449),
    [anon_sym_ENum] = ACTIONS(5449),
    [anon_sym_enumextension] = ACTIONS(5449),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5449),
    [anon_sym_Enumextension] = ACTIONS(5449),
    [anon_sym_EnumExtension] = ACTIONS(5449),
    [anon_sym_enumExtension] = ACTIONS(5449),
    [sym_interface_keyword] = ACTIONS(5449),
    [anon_sym_controladdin] = ACTIONS(5449),
    [anon_sym_CONTROLADDIN] = ACTIONS(5449),
    [anon_sym_Controladdin] = ACTIONS(5449),
    [anon_sym_ControlAddIn] = ACTIONS(5449),
    [anon_sym_ControlAddin] = ACTIONS(5449),
    [anon_sym_controlAddIn] = ACTIONS(5449),
    [anon_sym_controlAddin] = ACTIONS(5449),
    [anon_sym_dotnet] = ACTIONS(5449),
    [anon_sym_DOTNET] = ACTIONS(5449),
    [anon_sym_Dotnet] = ACTIONS(5449),
    [anon_sym_DotNet] = ACTIONS(5449),
    [anon_sym_dotNet] = ACTIONS(5449),
    [sym_profile_keyword] = ACTIONS(5447),
    [anon_sym_profileextension] = ACTIONS(5449),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5449),
    [anon_sym_Profileextension] = ACTIONS(5449),
    [anon_sym_ProfileExtension] = ACTIONS(5449),
    [anon_sym_profileExtension] = ACTIONS(5449),
    [anon_sym_permissionset] = ACTIONS(5447),
    [anon_sym_PERMISSIONSET] = ACTIONS(5447),
    [anon_sym_Permissionset] = ACTIONS(5447),
    [anon_sym_PermissionSet] = ACTIONS(5447),
    [anon_sym_permissionSet] = ACTIONS(5447),
    [anon_sym_permissionsetextension] = ACTIONS(5449),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5449),
    [anon_sym_Permissionsetextension] = ACTIONS(5449),
    [anon_sym_PermissionSetExtension] = ACTIONS(5449),
    [anon_sym_permissionSetExtension] = ACTIONS(5449),
    [sym_entitlement_keyword] = ACTIONS(5449),
    [anon_sym_pagecustomization] = ACTIONS(5449),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5449),
    [anon_sym_Pagecustomization] = ACTIONS(5449),
    [anon_sym_PageCustomization] = ACTIONS(5449),
    [anon_sym_pageCustomization] = ACTIONS(5449),
    [sym_namespace_keyword] = ACTIONS(5449),
    [sym_using_keyword] = ACTIONS(5449),
    [sym_fieldgroup_keyword] = ACTIONS(5449),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5449),
    [sym_preproc_close] = ACTIONS(5449),
  },
  [STATE(2275)] = {
    [sym_identifier] = ACTIONS(4427),
    [anon_sym_SEMI] = ACTIONS(4429),
    [anon_sym_DASH] = ACTIONS(4429),
    [aux_sym_boolean_token1] = ACTIONS(4427),
    [aux_sym_boolean_token2] = ACTIONS(4427),
    [sym_decimal] = ACTIONS(4427),
    [anon_sym_LPAREN] = ACTIONS(4429),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4427),
    [anon_sym_LBRACK] = ACTIONS(4429),
    [aux_sym_record_type_token1] = ACTIONS(4427),
    [aux_sym_basic_type_token21] = ACTIONS(4427),
    [aux_sym_basic_type_token22] = ACTIONS(4427),
    [aux_sym_basic_type_token48] = ACTIONS(4427),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4427),
    [anon_sym_POUNDif] = ACTIONS(4429),
    [anon_sym_POUNDIF] = ACTIONS(4429),
    [anon_sym_POUNDIf] = ACTIONS(4429),
    [anon_sym_not] = ACTIONS(4427),
    [anon_sym_NOT] = ACTIONS(4427),
    [anon_sym_Not] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4427),
    [anon_sym_PLUS] = ACTIONS(4429),
    [sym_datetime_literal] = ACTIONS(4429),
    [sym_date_literal] = ACTIONS(4427),
    [sym_time_literal] = ACTIONS(4427),
    [sym_biginteger_literal] = ACTIONS(4429),
    [anon_sym_if] = ACTIONS(4427),
    [anon_sym_IF] = ACTIONS(4427),
    [anon_sym_If] = ACTIONS(4427),
    [anon_sym_else] = ACTIONS(4427),
    [anon_sym_ELSE] = ACTIONS(4427),
    [anon_sym_Else] = ACTIONS(4427),
    [anon_sym_case] = ACTIONS(4427),
    [anon_sym_CASE] = ACTIONS(4427),
    [anon_sym_Case] = ACTIONS(4427),
    [anon_sym_for] = ACTIONS(4427),
    [anon_sym_FOR] = ACTIONS(4427),
    [anon_sym_For] = ACTIONS(4427),
    [anon_sym_foreach] = ACTIONS(4427),
    [anon_sym_FOREACH] = ACTIONS(4427),
    [anon_sym_Foreach] = ACTIONS(4427),
    [anon_sym_while] = ACTIONS(4427),
    [anon_sym_WHILE] = ACTIONS(4427),
    [anon_sym_While] = ACTIONS(4427),
    [anon_sym_repeat] = ACTIONS(4427),
    [anon_sym_REPEAT] = ACTIONS(4427),
    [anon_sym_Repeat] = ACTIONS(4427),
    [anon_sym_exit] = ACTIONS(4427),
    [anon_sym_EXIT] = ACTIONS(4427),
    [anon_sym_Exit] = ACTIONS(4427),
    [anon_sym_continue] = ACTIONS(4427),
    [anon_sym_CONTINUE] = ACTIONS(4427),
    [anon_sym_Continue] = ACTIONS(4427),
    [anon_sym_break] = ACTIONS(4427),
    [anon_sym_BREAK] = ACTIONS(4427),
    [anon_sym_Break] = ACTIONS(4427),
    [anon_sym_with] = ACTIONS(4427),
    [anon_sym_WITH] = ACTIONS(4427),
    [anon_sym_With] = ACTIONS(4427),
    [sym_asserterror_keyword] = ACTIONS(4429),
    [sym_page_keyword] = ACTIONS(4427),
    [anon_sym_codeunit] = ACTIONS(4427),
    [anon_sym_CODEUNIT] = ACTIONS(4427),
    [anon_sym_Codeunit] = ACTIONS(4427),
    [anon_sym_CodeUnit] = ACTIONS(4427),
    [anon_sym_COdeunit] = ACTIONS(4427),
    [anon_sym_codeUnit] = ACTIONS(4427),
    [sym_report_keyword] = ACTIONS(4427),
    [sym_query_keyword] = ACTIONS(4427),
    [anon_sym_xmlport] = ACTIONS(4427),
    [anon_sym_XMLPORT] = ACTIONS(4427),
    [anon_sym_Xmlport] = ACTIONS(4427),
    [anon_sym_XMLport] = ACTIONS(4427),
    [anon_sym_XMLPort] = ACTIONS(4427),
    [anon_sym_XmlPort] = ACTIONS(4427),
    [anon_sym_enum] = ACTIONS(4427),
    [anon_sym_ENUM] = ACTIONS(4427),
    [anon_sym_Enum] = ACTIONS(4427),
    [anon_sym_eNUM] = ACTIONS(4427),
    [anon_sym_eNum] = ACTIONS(4427),
    [anon_sym_ENum] = ACTIONS(4427),
    [sym_quoted_identifier] = ACTIONS(4429),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4429),
    [sym_integer] = ACTIONS(4427),
    [sym_continue_as_identifier] = ACTIONS(4429),
    [sym_preproc_open] = ACTIONS(4429),
    [sym_end_keyword] = ACTIONS(4429),
  },
  [STATE(2276)] = {
    [sym_identifier] = ACTIONS(4431),
    [anon_sym_SEMI] = ACTIONS(4433),
    [anon_sym_DASH] = ACTIONS(4433),
    [aux_sym_boolean_token1] = ACTIONS(4431),
    [aux_sym_boolean_token2] = ACTIONS(4431),
    [sym_decimal] = ACTIONS(4431),
    [anon_sym_LPAREN] = ACTIONS(4433),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4431),
    [anon_sym_LBRACK] = ACTIONS(4433),
    [aux_sym_record_type_token1] = ACTIONS(4431),
    [aux_sym_basic_type_token21] = ACTIONS(4431),
    [aux_sym_basic_type_token22] = ACTIONS(4431),
    [aux_sym_basic_type_token48] = ACTIONS(4431),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4431),
    [anon_sym_POUNDif] = ACTIONS(4433),
    [anon_sym_POUNDIF] = ACTIONS(4433),
    [anon_sym_POUNDIf] = ACTIONS(4433),
    [anon_sym_not] = ACTIONS(4431),
    [anon_sym_NOT] = ACTIONS(4431),
    [anon_sym_Not] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4431),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4431),
    [anon_sym_PLUS] = ACTIONS(4433),
    [sym_datetime_literal] = ACTIONS(4433),
    [sym_date_literal] = ACTIONS(4431),
    [sym_time_literal] = ACTIONS(4431),
    [sym_biginteger_literal] = ACTIONS(4433),
    [anon_sym_if] = ACTIONS(4431),
    [anon_sym_IF] = ACTIONS(4431),
    [anon_sym_If] = ACTIONS(4431),
    [anon_sym_else] = ACTIONS(4431),
    [anon_sym_ELSE] = ACTIONS(4431),
    [anon_sym_Else] = ACTIONS(4431),
    [anon_sym_case] = ACTIONS(4431),
    [anon_sym_CASE] = ACTIONS(4431),
    [anon_sym_Case] = ACTIONS(4431),
    [anon_sym_for] = ACTIONS(4431),
    [anon_sym_FOR] = ACTIONS(4431),
    [anon_sym_For] = ACTIONS(4431),
    [anon_sym_foreach] = ACTIONS(4431),
    [anon_sym_FOREACH] = ACTIONS(4431),
    [anon_sym_Foreach] = ACTIONS(4431),
    [anon_sym_while] = ACTIONS(4431),
    [anon_sym_WHILE] = ACTIONS(4431),
    [anon_sym_While] = ACTIONS(4431),
    [anon_sym_repeat] = ACTIONS(4431),
    [anon_sym_REPEAT] = ACTIONS(4431),
    [anon_sym_Repeat] = ACTIONS(4431),
    [anon_sym_exit] = ACTIONS(4431),
    [anon_sym_EXIT] = ACTIONS(4431),
    [anon_sym_Exit] = ACTIONS(4431),
    [anon_sym_continue] = ACTIONS(4431),
    [anon_sym_CONTINUE] = ACTIONS(4431),
    [anon_sym_Continue] = ACTIONS(4431),
    [anon_sym_break] = ACTIONS(4431),
    [anon_sym_BREAK] = ACTIONS(4431),
    [anon_sym_Break] = ACTIONS(4431),
    [anon_sym_with] = ACTIONS(4431),
    [anon_sym_WITH] = ACTIONS(4431),
    [anon_sym_With] = ACTIONS(4431),
    [sym_asserterror_keyword] = ACTIONS(4433),
    [sym_page_keyword] = ACTIONS(4431),
    [anon_sym_codeunit] = ACTIONS(4431),
    [anon_sym_CODEUNIT] = ACTIONS(4431),
    [anon_sym_Codeunit] = ACTIONS(4431),
    [anon_sym_CodeUnit] = ACTIONS(4431),
    [anon_sym_COdeunit] = ACTIONS(4431),
    [anon_sym_codeUnit] = ACTIONS(4431),
    [sym_report_keyword] = ACTIONS(4431),
    [sym_query_keyword] = ACTIONS(4431),
    [anon_sym_xmlport] = ACTIONS(4431),
    [anon_sym_XMLPORT] = ACTIONS(4431),
    [anon_sym_Xmlport] = ACTIONS(4431),
    [anon_sym_XMLport] = ACTIONS(4431),
    [anon_sym_XMLPort] = ACTIONS(4431),
    [anon_sym_XmlPort] = ACTIONS(4431),
    [anon_sym_enum] = ACTIONS(4431),
    [anon_sym_ENUM] = ACTIONS(4431),
    [anon_sym_Enum] = ACTIONS(4431),
    [anon_sym_eNUM] = ACTIONS(4431),
    [anon_sym_eNum] = ACTIONS(4431),
    [anon_sym_ENum] = ACTIONS(4431),
    [sym_quoted_identifier] = ACTIONS(4433),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4433),
    [sym_integer] = ACTIONS(4431),
    [sym_continue_as_identifier] = ACTIONS(4433),
    [sym_preproc_open] = ACTIONS(4433),
    [sym_end_keyword] = ACTIONS(4433),
  },
  [STATE(2277)] = {
    [sym_identifier] = ACTIONS(4688),
    [anon_sym_SEMI] = ACTIONS(4690),
    [anon_sym_DASH] = ACTIONS(4690),
    [aux_sym_boolean_token1] = ACTIONS(4688),
    [aux_sym_boolean_token2] = ACTIONS(4688),
    [sym_decimal] = ACTIONS(4688),
    [anon_sym_LPAREN] = ACTIONS(4690),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4688),
    [anon_sym_LBRACK] = ACTIONS(4690),
    [aux_sym_record_type_token1] = ACTIONS(4688),
    [aux_sym_basic_type_token21] = ACTIONS(4688),
    [aux_sym_basic_type_token22] = ACTIONS(4688),
    [aux_sym_basic_type_token48] = ACTIONS(4688),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4688),
    [anon_sym_POUNDif] = ACTIONS(4690),
    [anon_sym_POUNDIF] = ACTIONS(4690),
    [anon_sym_POUNDIf] = ACTIONS(4690),
    [anon_sym_not] = ACTIONS(4688),
    [anon_sym_NOT] = ACTIONS(4688),
    [anon_sym_Not] = ACTIONS(4688),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4688),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4688),
    [anon_sym_PLUS] = ACTIONS(4690),
    [sym_datetime_literal] = ACTIONS(4690),
    [sym_date_literal] = ACTIONS(4688),
    [sym_time_literal] = ACTIONS(4688),
    [sym_biginteger_literal] = ACTIONS(4690),
    [anon_sym_if] = ACTIONS(4688),
    [anon_sym_IF] = ACTIONS(4688),
    [anon_sym_If] = ACTIONS(4688),
    [anon_sym_else] = ACTIONS(4688),
    [anon_sym_ELSE] = ACTIONS(4688),
    [anon_sym_Else] = ACTIONS(4688),
    [anon_sym_case] = ACTIONS(4688),
    [anon_sym_CASE] = ACTIONS(4688),
    [anon_sym_Case] = ACTIONS(4688),
    [anon_sym_for] = ACTIONS(4688),
    [anon_sym_FOR] = ACTIONS(4688),
    [anon_sym_For] = ACTIONS(4688),
    [anon_sym_foreach] = ACTIONS(4688),
    [anon_sym_FOREACH] = ACTIONS(4688),
    [anon_sym_Foreach] = ACTIONS(4688),
    [anon_sym_while] = ACTIONS(4688),
    [anon_sym_WHILE] = ACTIONS(4688),
    [anon_sym_While] = ACTIONS(4688),
    [anon_sym_repeat] = ACTIONS(4688),
    [anon_sym_REPEAT] = ACTIONS(4688),
    [anon_sym_Repeat] = ACTIONS(4688),
    [anon_sym_exit] = ACTIONS(4688),
    [anon_sym_EXIT] = ACTIONS(4688),
    [anon_sym_Exit] = ACTIONS(4688),
    [anon_sym_continue] = ACTIONS(4688),
    [anon_sym_CONTINUE] = ACTIONS(4688),
    [anon_sym_Continue] = ACTIONS(4688),
    [anon_sym_break] = ACTIONS(4688),
    [anon_sym_BREAK] = ACTIONS(4688),
    [anon_sym_Break] = ACTIONS(4688),
    [anon_sym_with] = ACTIONS(4688),
    [anon_sym_WITH] = ACTIONS(4688),
    [anon_sym_With] = ACTIONS(4688),
    [sym_asserterror_keyword] = ACTIONS(4690),
    [sym_page_keyword] = ACTIONS(4688),
    [anon_sym_codeunit] = ACTIONS(4688),
    [anon_sym_CODEUNIT] = ACTIONS(4688),
    [anon_sym_Codeunit] = ACTIONS(4688),
    [anon_sym_CodeUnit] = ACTIONS(4688),
    [anon_sym_COdeunit] = ACTIONS(4688),
    [anon_sym_codeUnit] = ACTIONS(4688),
    [sym_report_keyword] = ACTIONS(4688),
    [sym_query_keyword] = ACTIONS(4688),
    [anon_sym_xmlport] = ACTIONS(4688),
    [anon_sym_XMLPORT] = ACTIONS(4688),
    [anon_sym_Xmlport] = ACTIONS(4688),
    [anon_sym_XMLport] = ACTIONS(4688),
    [anon_sym_XMLPort] = ACTIONS(4688),
    [anon_sym_XmlPort] = ACTIONS(4688),
    [anon_sym_enum] = ACTIONS(4688),
    [anon_sym_ENUM] = ACTIONS(4688),
    [anon_sym_Enum] = ACTIONS(4688),
    [anon_sym_eNUM] = ACTIONS(4688),
    [anon_sym_eNum] = ACTIONS(4688),
    [anon_sym_ENum] = ACTIONS(4688),
    [sym_quoted_identifier] = ACTIONS(4690),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4690),
    [sym_integer] = ACTIONS(4688),
    [sym_continue_as_identifier] = ACTIONS(4690),
    [sym_preproc_open] = ACTIONS(4690),
    [sym_end_keyword] = ACTIONS(4690),
  },
  [STATE(2278)] = {
    [sym_identifier] = ACTIONS(4395),
    [anon_sym_SEMI] = ACTIONS(4397),
    [anon_sym_DASH] = ACTIONS(4397),
    [aux_sym_boolean_token1] = ACTIONS(4395),
    [aux_sym_boolean_token2] = ACTIONS(4395),
    [sym_decimal] = ACTIONS(4395),
    [anon_sym_LPAREN] = ACTIONS(4397),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4395),
    [anon_sym_LBRACK] = ACTIONS(4397),
    [aux_sym_record_type_token1] = ACTIONS(4395),
    [aux_sym_basic_type_token21] = ACTIONS(4395),
    [aux_sym_basic_type_token22] = ACTIONS(4395),
    [aux_sym_basic_type_token48] = ACTIONS(4395),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4395),
    [anon_sym_POUNDif] = ACTIONS(4397),
    [anon_sym_POUNDIF] = ACTIONS(4397),
    [anon_sym_POUNDIf] = ACTIONS(4397),
    [anon_sym_not] = ACTIONS(4395),
    [anon_sym_NOT] = ACTIONS(4395),
    [anon_sym_Not] = ACTIONS(4395),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4395),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4395),
    [anon_sym_PLUS] = ACTIONS(4397),
    [sym_datetime_literal] = ACTIONS(4397),
    [sym_date_literal] = ACTIONS(4395),
    [sym_time_literal] = ACTIONS(4395),
    [sym_biginteger_literal] = ACTIONS(4397),
    [anon_sym_if] = ACTIONS(4395),
    [anon_sym_IF] = ACTIONS(4395),
    [anon_sym_If] = ACTIONS(4395),
    [anon_sym_else] = ACTIONS(4395),
    [anon_sym_ELSE] = ACTIONS(4395),
    [anon_sym_Else] = ACTIONS(4395),
    [anon_sym_case] = ACTIONS(4395),
    [anon_sym_CASE] = ACTIONS(4395),
    [anon_sym_Case] = ACTIONS(4395),
    [anon_sym_for] = ACTIONS(4395),
    [anon_sym_FOR] = ACTIONS(4395),
    [anon_sym_For] = ACTIONS(4395),
    [anon_sym_foreach] = ACTIONS(4395),
    [anon_sym_FOREACH] = ACTIONS(4395),
    [anon_sym_Foreach] = ACTIONS(4395),
    [anon_sym_while] = ACTIONS(4395),
    [anon_sym_WHILE] = ACTIONS(4395),
    [anon_sym_While] = ACTIONS(4395),
    [anon_sym_repeat] = ACTIONS(4395),
    [anon_sym_REPEAT] = ACTIONS(4395),
    [anon_sym_Repeat] = ACTIONS(4395),
    [anon_sym_exit] = ACTIONS(4395),
    [anon_sym_EXIT] = ACTIONS(4395),
    [anon_sym_Exit] = ACTIONS(4395),
    [anon_sym_continue] = ACTIONS(4395),
    [anon_sym_CONTINUE] = ACTIONS(4395),
    [anon_sym_Continue] = ACTIONS(4395),
    [anon_sym_break] = ACTIONS(4395),
    [anon_sym_BREAK] = ACTIONS(4395),
    [anon_sym_Break] = ACTIONS(4395),
    [anon_sym_with] = ACTIONS(4395),
    [anon_sym_WITH] = ACTIONS(4395),
    [anon_sym_With] = ACTIONS(4395),
    [sym_asserterror_keyword] = ACTIONS(4397),
    [sym_page_keyword] = ACTIONS(4395),
    [anon_sym_codeunit] = ACTIONS(4395),
    [anon_sym_CODEUNIT] = ACTIONS(4395),
    [anon_sym_Codeunit] = ACTIONS(4395),
    [anon_sym_CodeUnit] = ACTIONS(4395),
    [anon_sym_COdeunit] = ACTIONS(4395),
    [anon_sym_codeUnit] = ACTIONS(4395),
    [sym_report_keyword] = ACTIONS(4395),
    [sym_query_keyword] = ACTIONS(4395),
    [anon_sym_xmlport] = ACTIONS(4395),
    [anon_sym_XMLPORT] = ACTIONS(4395),
    [anon_sym_Xmlport] = ACTIONS(4395),
    [anon_sym_XMLport] = ACTIONS(4395),
    [anon_sym_XMLPort] = ACTIONS(4395),
    [anon_sym_XmlPort] = ACTIONS(4395),
    [anon_sym_enum] = ACTIONS(4395),
    [anon_sym_ENUM] = ACTIONS(4395),
    [anon_sym_Enum] = ACTIONS(4395),
    [anon_sym_eNUM] = ACTIONS(4395),
    [anon_sym_eNum] = ACTIONS(4395),
    [anon_sym_ENum] = ACTIONS(4395),
    [sym_quoted_identifier] = ACTIONS(4397),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4397),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4397),
    [sym_preproc_open] = ACTIONS(4397),
    [sym_end_keyword] = ACTIONS(4397),
  },
  [STATE(2279)] = {
    [sym_identifier] = ACTIONS(4439),
    [anon_sym_SEMI] = ACTIONS(4441),
    [anon_sym_DASH] = ACTIONS(4441),
    [aux_sym_boolean_token1] = ACTIONS(4439),
    [aux_sym_boolean_token2] = ACTIONS(4439),
    [sym_decimal] = ACTIONS(4439),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4439),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [aux_sym_record_type_token1] = ACTIONS(4439),
    [aux_sym_basic_type_token21] = ACTIONS(4439),
    [aux_sym_basic_type_token22] = ACTIONS(4439),
    [aux_sym_basic_type_token48] = ACTIONS(4439),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4439),
    [anon_sym_POUNDif] = ACTIONS(4441),
    [anon_sym_POUNDIF] = ACTIONS(4441),
    [anon_sym_POUNDIf] = ACTIONS(4441),
    [anon_sym_not] = ACTIONS(4439),
    [anon_sym_NOT] = ACTIONS(4439),
    [anon_sym_Not] = ACTIONS(4439),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4439),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4439),
    [anon_sym_PLUS] = ACTIONS(4441),
    [sym_datetime_literal] = ACTIONS(4441),
    [sym_date_literal] = ACTIONS(4439),
    [sym_time_literal] = ACTIONS(4439),
    [sym_biginteger_literal] = ACTIONS(4441),
    [anon_sym_if] = ACTIONS(4439),
    [anon_sym_IF] = ACTIONS(4439),
    [anon_sym_If] = ACTIONS(4439),
    [anon_sym_else] = ACTIONS(4439),
    [anon_sym_ELSE] = ACTIONS(4439),
    [anon_sym_Else] = ACTIONS(4439),
    [anon_sym_case] = ACTIONS(4439),
    [anon_sym_CASE] = ACTIONS(4439),
    [anon_sym_Case] = ACTIONS(4439),
    [anon_sym_for] = ACTIONS(4439),
    [anon_sym_FOR] = ACTIONS(4439),
    [anon_sym_For] = ACTIONS(4439),
    [anon_sym_foreach] = ACTIONS(4439),
    [anon_sym_FOREACH] = ACTIONS(4439),
    [anon_sym_Foreach] = ACTIONS(4439),
    [anon_sym_while] = ACTIONS(4439),
    [anon_sym_WHILE] = ACTIONS(4439),
    [anon_sym_While] = ACTIONS(4439),
    [anon_sym_repeat] = ACTIONS(4439),
    [anon_sym_REPEAT] = ACTIONS(4439),
    [anon_sym_Repeat] = ACTIONS(4439),
    [anon_sym_exit] = ACTIONS(4439),
    [anon_sym_EXIT] = ACTIONS(4439),
    [anon_sym_Exit] = ACTIONS(4439),
    [anon_sym_continue] = ACTIONS(4439),
    [anon_sym_CONTINUE] = ACTIONS(4439),
    [anon_sym_Continue] = ACTIONS(4439),
    [anon_sym_break] = ACTIONS(4439),
    [anon_sym_BREAK] = ACTIONS(4439),
    [anon_sym_Break] = ACTIONS(4439),
    [anon_sym_with] = ACTIONS(4439),
    [anon_sym_WITH] = ACTIONS(4439),
    [anon_sym_With] = ACTIONS(4439),
    [sym_asserterror_keyword] = ACTIONS(4441),
    [sym_page_keyword] = ACTIONS(4439),
    [anon_sym_codeunit] = ACTIONS(4439),
    [anon_sym_CODEUNIT] = ACTIONS(4439),
    [anon_sym_Codeunit] = ACTIONS(4439),
    [anon_sym_CodeUnit] = ACTIONS(4439),
    [anon_sym_COdeunit] = ACTIONS(4439),
    [anon_sym_codeUnit] = ACTIONS(4439),
    [sym_report_keyword] = ACTIONS(4439),
    [sym_query_keyword] = ACTIONS(4439),
    [anon_sym_xmlport] = ACTIONS(4439),
    [anon_sym_XMLPORT] = ACTIONS(4439),
    [anon_sym_Xmlport] = ACTIONS(4439),
    [anon_sym_XMLport] = ACTIONS(4439),
    [anon_sym_XMLPort] = ACTIONS(4439),
    [anon_sym_XmlPort] = ACTIONS(4439),
    [anon_sym_enum] = ACTIONS(4439),
    [anon_sym_ENUM] = ACTIONS(4439),
    [anon_sym_Enum] = ACTIONS(4439),
    [anon_sym_eNUM] = ACTIONS(4439),
    [anon_sym_eNum] = ACTIONS(4439),
    [anon_sym_ENum] = ACTIONS(4439),
    [sym_quoted_identifier] = ACTIONS(4441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4441),
    [sym_integer] = ACTIONS(4439),
    [sym_continue_as_identifier] = ACTIONS(4441),
    [sym_preproc_open] = ACTIONS(4441),
    [sym_end_keyword] = ACTIONS(4441),
  },
  [STATE(2280)] = {
    [sym_identifier] = ACTIONS(4567),
    [anon_sym_SEMI] = ACTIONS(5473),
    [anon_sym_DASH] = ACTIONS(4571),
    [aux_sym_boolean_token1] = ACTIONS(4567),
    [aux_sym_boolean_token2] = ACTIONS(4567),
    [sym_decimal] = ACTIONS(4567),
    [anon_sym_LPAREN] = ACTIONS(4571),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4567),
    [anon_sym_LBRACK] = ACTIONS(4571),
    [aux_sym_record_type_token1] = ACTIONS(4567),
    [aux_sym_basic_type_token21] = ACTIONS(4567),
    [aux_sym_basic_type_token22] = ACTIONS(4567),
    [aux_sym_basic_type_token48] = ACTIONS(4567),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4567),
    [anon_sym_POUNDif] = ACTIONS(4571),
    [anon_sym_POUNDIF] = ACTIONS(4571),
    [anon_sym_POUNDIf] = ACTIONS(4571),
    [anon_sym_not] = ACTIONS(4567),
    [anon_sym_NOT] = ACTIONS(4567),
    [anon_sym_Not] = ACTIONS(4567),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4567),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4567),
    [anon_sym_PLUS] = ACTIONS(4571),
    [sym_datetime_literal] = ACTIONS(4571),
    [sym_date_literal] = ACTIONS(4567),
    [sym_time_literal] = ACTIONS(4567),
    [sym_biginteger_literal] = ACTIONS(4571),
    [anon_sym_if] = ACTIONS(4567),
    [anon_sym_IF] = ACTIONS(4567),
    [anon_sym_If] = ACTIONS(4567),
    [anon_sym_else] = ACTIONS(4567),
    [anon_sym_ELSE] = ACTIONS(4567),
    [anon_sym_Else] = ACTIONS(4567),
    [anon_sym_case] = ACTIONS(4567),
    [anon_sym_CASE] = ACTIONS(4567),
    [anon_sym_Case] = ACTIONS(4567),
    [anon_sym_for] = ACTIONS(4567),
    [anon_sym_FOR] = ACTIONS(4567),
    [anon_sym_For] = ACTIONS(4567),
    [anon_sym_foreach] = ACTIONS(4567),
    [anon_sym_FOREACH] = ACTIONS(4567),
    [anon_sym_Foreach] = ACTIONS(4567),
    [anon_sym_while] = ACTIONS(4567),
    [anon_sym_WHILE] = ACTIONS(4567),
    [anon_sym_While] = ACTIONS(4567),
    [anon_sym_repeat] = ACTIONS(4567),
    [anon_sym_REPEAT] = ACTIONS(4567),
    [anon_sym_Repeat] = ACTIONS(4567),
    [anon_sym_exit] = ACTIONS(4567),
    [anon_sym_EXIT] = ACTIONS(4567),
    [anon_sym_Exit] = ACTIONS(4567),
    [anon_sym_continue] = ACTIONS(4567),
    [anon_sym_CONTINUE] = ACTIONS(4567),
    [anon_sym_Continue] = ACTIONS(4567),
    [anon_sym_break] = ACTIONS(4567),
    [anon_sym_BREAK] = ACTIONS(4567),
    [anon_sym_Break] = ACTIONS(4567),
    [anon_sym_with] = ACTIONS(4567),
    [anon_sym_WITH] = ACTIONS(4567),
    [anon_sym_With] = ACTIONS(4567),
    [sym_asserterror_keyword] = ACTIONS(4571),
    [sym_page_keyword] = ACTIONS(4567),
    [anon_sym_codeunit] = ACTIONS(4567),
    [anon_sym_CODEUNIT] = ACTIONS(4567),
    [anon_sym_Codeunit] = ACTIONS(4567),
    [anon_sym_CodeUnit] = ACTIONS(4567),
    [anon_sym_COdeunit] = ACTIONS(4567),
    [anon_sym_codeUnit] = ACTIONS(4567),
    [sym_report_keyword] = ACTIONS(4567),
    [sym_query_keyword] = ACTIONS(4567),
    [anon_sym_xmlport] = ACTIONS(4567),
    [anon_sym_XMLPORT] = ACTIONS(4567),
    [anon_sym_Xmlport] = ACTIONS(4567),
    [anon_sym_XMLport] = ACTIONS(4567),
    [anon_sym_XMLPort] = ACTIONS(4567),
    [anon_sym_XmlPort] = ACTIONS(4567),
    [anon_sym_enum] = ACTIONS(4567),
    [anon_sym_ENUM] = ACTIONS(4567),
    [anon_sym_Enum] = ACTIONS(4567),
    [anon_sym_eNUM] = ACTIONS(4567),
    [anon_sym_eNum] = ACTIONS(4567),
    [anon_sym_ENum] = ACTIONS(4567),
    [sym_quoted_identifier] = ACTIONS(4571),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4571),
    [sym_integer] = ACTIONS(4567),
    [sym_continue_as_identifier] = ACTIONS(4571),
    [sym_preproc_open] = ACTIONS(4571),
    [sym_end_keyword] = ACTIONS(4571),
  },
  [STATE(2281)] = {
    [sym_identifier] = ACTIONS(4245),
    [anon_sym_SEMI] = ACTIONS(4247),
    [anon_sym_DASH] = ACTIONS(4247),
    [aux_sym_boolean_token1] = ACTIONS(4245),
    [aux_sym_boolean_token2] = ACTIONS(4245),
    [sym_decimal] = ACTIONS(4245),
    [anon_sym_LPAREN] = ACTIONS(4247),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4245),
    [anon_sym_LBRACK] = ACTIONS(4247),
    [aux_sym_record_type_token1] = ACTIONS(4245),
    [aux_sym_basic_type_token21] = ACTIONS(4245),
    [aux_sym_basic_type_token22] = ACTIONS(4245),
    [aux_sym_basic_type_token48] = ACTIONS(4245),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4245),
    [anon_sym_POUNDif] = ACTIONS(4247),
    [anon_sym_POUNDIF] = ACTIONS(4247),
    [anon_sym_POUNDIf] = ACTIONS(4247),
    [anon_sym_not] = ACTIONS(4245),
    [anon_sym_NOT] = ACTIONS(4245),
    [anon_sym_Not] = ACTIONS(4245),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4245),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4245),
    [anon_sym_PLUS] = ACTIONS(4247),
    [sym_datetime_literal] = ACTIONS(4247),
    [sym_date_literal] = ACTIONS(4245),
    [sym_time_literal] = ACTIONS(4245),
    [sym_biginteger_literal] = ACTIONS(4247),
    [anon_sym_if] = ACTIONS(4245),
    [anon_sym_IF] = ACTIONS(4245),
    [anon_sym_If] = ACTIONS(4245),
    [anon_sym_else] = ACTIONS(4245),
    [anon_sym_ELSE] = ACTIONS(4245),
    [anon_sym_Else] = ACTIONS(4245),
    [anon_sym_case] = ACTIONS(4245),
    [anon_sym_CASE] = ACTIONS(4245),
    [anon_sym_Case] = ACTIONS(4245),
    [anon_sym_for] = ACTIONS(4245),
    [anon_sym_FOR] = ACTIONS(4245),
    [anon_sym_For] = ACTIONS(4245),
    [anon_sym_foreach] = ACTIONS(4245),
    [anon_sym_FOREACH] = ACTIONS(4245),
    [anon_sym_Foreach] = ACTIONS(4245),
    [anon_sym_while] = ACTIONS(4245),
    [anon_sym_WHILE] = ACTIONS(4245),
    [anon_sym_While] = ACTIONS(4245),
    [anon_sym_repeat] = ACTIONS(4245),
    [anon_sym_REPEAT] = ACTIONS(4245),
    [anon_sym_Repeat] = ACTIONS(4245),
    [anon_sym_exit] = ACTIONS(4245),
    [anon_sym_EXIT] = ACTIONS(4245),
    [anon_sym_Exit] = ACTIONS(4245),
    [anon_sym_continue] = ACTIONS(4245),
    [anon_sym_CONTINUE] = ACTIONS(4245),
    [anon_sym_Continue] = ACTIONS(4245),
    [anon_sym_break] = ACTIONS(4245),
    [anon_sym_BREAK] = ACTIONS(4245),
    [anon_sym_Break] = ACTIONS(4245),
    [anon_sym_with] = ACTIONS(4245),
    [anon_sym_WITH] = ACTIONS(4245),
    [anon_sym_With] = ACTIONS(4245),
    [sym_asserterror_keyword] = ACTIONS(4247),
    [sym_page_keyword] = ACTIONS(4245),
    [anon_sym_codeunit] = ACTIONS(4245),
    [anon_sym_CODEUNIT] = ACTIONS(4245),
    [anon_sym_Codeunit] = ACTIONS(4245),
    [anon_sym_CodeUnit] = ACTIONS(4245),
    [anon_sym_COdeunit] = ACTIONS(4245),
    [anon_sym_codeUnit] = ACTIONS(4245),
    [sym_report_keyword] = ACTIONS(4245),
    [sym_query_keyword] = ACTIONS(4245),
    [anon_sym_xmlport] = ACTIONS(4245),
    [anon_sym_XMLPORT] = ACTIONS(4245),
    [anon_sym_Xmlport] = ACTIONS(4245),
    [anon_sym_XMLport] = ACTIONS(4245),
    [anon_sym_XMLPort] = ACTIONS(4245),
    [anon_sym_XmlPort] = ACTIONS(4245),
    [anon_sym_enum] = ACTIONS(4245),
    [anon_sym_ENUM] = ACTIONS(4245),
    [anon_sym_Enum] = ACTIONS(4245),
    [anon_sym_eNUM] = ACTIONS(4245),
    [anon_sym_eNum] = ACTIONS(4245),
    [anon_sym_ENum] = ACTIONS(4245),
    [sym_quoted_identifier] = ACTIONS(4247),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4247),
    [sym_integer] = ACTIONS(4245),
    [sym_continue_as_identifier] = ACTIONS(4247),
    [sym_preproc_open] = ACTIONS(4247),
    [sym_end_keyword] = ACTIONS(4247),
  },
  [STATE(2282)] = {
    [sym_identifier] = ACTIONS(4692),
    [anon_sym_SEMI] = ACTIONS(4694),
    [anon_sym_DASH] = ACTIONS(4694),
    [aux_sym_boolean_token1] = ACTIONS(4692),
    [aux_sym_boolean_token2] = ACTIONS(4692),
    [sym_decimal] = ACTIONS(4692),
    [anon_sym_LPAREN] = ACTIONS(4694),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4692),
    [anon_sym_LBRACK] = ACTIONS(4694),
    [aux_sym_record_type_token1] = ACTIONS(4692),
    [aux_sym_basic_type_token21] = ACTIONS(4692),
    [aux_sym_basic_type_token22] = ACTIONS(4692),
    [aux_sym_basic_type_token48] = ACTIONS(4692),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4692),
    [anon_sym_POUNDif] = ACTIONS(4694),
    [anon_sym_POUNDIF] = ACTIONS(4694),
    [anon_sym_POUNDIf] = ACTIONS(4694),
    [anon_sym_not] = ACTIONS(4692),
    [anon_sym_NOT] = ACTIONS(4692),
    [anon_sym_Not] = ACTIONS(4692),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4692),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4692),
    [anon_sym_PLUS] = ACTIONS(4694),
    [sym_datetime_literal] = ACTIONS(4694),
    [sym_date_literal] = ACTIONS(4692),
    [sym_time_literal] = ACTIONS(4692),
    [sym_biginteger_literal] = ACTIONS(4694),
    [anon_sym_if] = ACTIONS(4692),
    [anon_sym_IF] = ACTIONS(4692),
    [anon_sym_If] = ACTIONS(4692),
    [anon_sym_else] = ACTIONS(4692),
    [anon_sym_ELSE] = ACTIONS(4692),
    [anon_sym_Else] = ACTIONS(4692),
    [anon_sym_case] = ACTIONS(4692),
    [anon_sym_CASE] = ACTIONS(4692),
    [anon_sym_Case] = ACTIONS(4692),
    [anon_sym_for] = ACTIONS(4692),
    [anon_sym_FOR] = ACTIONS(4692),
    [anon_sym_For] = ACTIONS(4692),
    [anon_sym_foreach] = ACTIONS(4692),
    [anon_sym_FOREACH] = ACTIONS(4692),
    [anon_sym_Foreach] = ACTIONS(4692),
    [anon_sym_while] = ACTIONS(4692),
    [anon_sym_WHILE] = ACTIONS(4692),
    [anon_sym_While] = ACTIONS(4692),
    [anon_sym_repeat] = ACTIONS(4692),
    [anon_sym_REPEAT] = ACTIONS(4692),
    [anon_sym_Repeat] = ACTIONS(4692),
    [anon_sym_exit] = ACTIONS(4692),
    [anon_sym_EXIT] = ACTIONS(4692),
    [anon_sym_Exit] = ACTIONS(4692),
    [anon_sym_continue] = ACTIONS(4692),
    [anon_sym_CONTINUE] = ACTIONS(4692),
    [anon_sym_Continue] = ACTIONS(4692),
    [anon_sym_break] = ACTIONS(4692),
    [anon_sym_BREAK] = ACTIONS(4692),
    [anon_sym_Break] = ACTIONS(4692),
    [anon_sym_with] = ACTIONS(4692),
    [anon_sym_WITH] = ACTIONS(4692),
    [anon_sym_With] = ACTIONS(4692),
    [sym_asserterror_keyword] = ACTIONS(4694),
    [sym_page_keyword] = ACTIONS(4692),
    [anon_sym_codeunit] = ACTIONS(4692),
    [anon_sym_CODEUNIT] = ACTIONS(4692),
    [anon_sym_Codeunit] = ACTIONS(4692),
    [anon_sym_CodeUnit] = ACTIONS(4692),
    [anon_sym_COdeunit] = ACTIONS(4692),
    [anon_sym_codeUnit] = ACTIONS(4692),
    [sym_report_keyword] = ACTIONS(4692),
    [sym_query_keyword] = ACTIONS(4692),
    [anon_sym_xmlport] = ACTIONS(4692),
    [anon_sym_XMLPORT] = ACTIONS(4692),
    [anon_sym_Xmlport] = ACTIONS(4692),
    [anon_sym_XMLport] = ACTIONS(4692),
    [anon_sym_XMLPort] = ACTIONS(4692),
    [anon_sym_XmlPort] = ACTIONS(4692),
    [anon_sym_enum] = ACTIONS(4692),
    [anon_sym_ENUM] = ACTIONS(4692),
    [anon_sym_Enum] = ACTIONS(4692),
    [anon_sym_eNUM] = ACTIONS(4692),
    [anon_sym_eNum] = ACTIONS(4692),
    [anon_sym_ENum] = ACTIONS(4692),
    [sym_quoted_identifier] = ACTIONS(4694),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4694),
    [sym_integer] = ACTIONS(4692),
    [sym_continue_as_identifier] = ACTIONS(4694),
    [sym_preproc_open] = ACTIONS(4694),
    [sym_end_keyword] = ACTIONS(4694),
  },
  [STATE(2283)] = {
    [sym_identifier] = ACTIONS(4618),
    [anon_sym_SEMI] = ACTIONS(4620),
    [anon_sym_DASH] = ACTIONS(4620),
    [aux_sym_boolean_token1] = ACTIONS(4618),
    [aux_sym_boolean_token2] = ACTIONS(4618),
    [sym_decimal] = ACTIONS(4618),
    [anon_sym_LPAREN] = ACTIONS(4620),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4618),
    [anon_sym_LBRACK] = ACTIONS(4620),
    [aux_sym_record_type_token1] = ACTIONS(4618),
    [aux_sym_basic_type_token21] = ACTIONS(4618),
    [aux_sym_basic_type_token22] = ACTIONS(4618),
    [aux_sym_basic_type_token48] = ACTIONS(4618),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4618),
    [anon_sym_POUNDif] = ACTIONS(4620),
    [anon_sym_POUNDIF] = ACTIONS(4620),
    [anon_sym_POUNDIf] = ACTIONS(4620),
    [anon_sym_not] = ACTIONS(4618),
    [anon_sym_NOT] = ACTIONS(4618),
    [anon_sym_Not] = ACTIONS(4618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4618),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4618),
    [anon_sym_PLUS] = ACTIONS(4620),
    [sym_datetime_literal] = ACTIONS(4620),
    [sym_date_literal] = ACTIONS(4618),
    [sym_time_literal] = ACTIONS(4618),
    [sym_biginteger_literal] = ACTIONS(4620),
    [anon_sym_if] = ACTIONS(4618),
    [anon_sym_IF] = ACTIONS(4618),
    [anon_sym_If] = ACTIONS(4618),
    [anon_sym_else] = ACTIONS(4618),
    [anon_sym_ELSE] = ACTIONS(4618),
    [anon_sym_Else] = ACTIONS(4618),
    [anon_sym_case] = ACTIONS(4618),
    [anon_sym_CASE] = ACTIONS(4618),
    [anon_sym_Case] = ACTIONS(4618),
    [anon_sym_for] = ACTIONS(4618),
    [anon_sym_FOR] = ACTIONS(4618),
    [anon_sym_For] = ACTIONS(4618),
    [anon_sym_foreach] = ACTIONS(4618),
    [anon_sym_FOREACH] = ACTIONS(4618),
    [anon_sym_Foreach] = ACTIONS(4618),
    [anon_sym_while] = ACTIONS(4618),
    [anon_sym_WHILE] = ACTIONS(4618),
    [anon_sym_While] = ACTIONS(4618),
    [anon_sym_repeat] = ACTIONS(4618),
    [anon_sym_REPEAT] = ACTIONS(4618),
    [anon_sym_Repeat] = ACTIONS(4618),
    [anon_sym_exit] = ACTIONS(4618),
    [anon_sym_EXIT] = ACTIONS(4618),
    [anon_sym_Exit] = ACTIONS(4618),
    [anon_sym_continue] = ACTIONS(4618),
    [anon_sym_CONTINUE] = ACTIONS(4618),
    [anon_sym_Continue] = ACTIONS(4618),
    [anon_sym_break] = ACTIONS(4618),
    [anon_sym_BREAK] = ACTIONS(4618),
    [anon_sym_Break] = ACTIONS(4618),
    [anon_sym_with] = ACTIONS(4618),
    [anon_sym_WITH] = ACTIONS(4618),
    [anon_sym_With] = ACTIONS(4618),
    [sym_asserterror_keyword] = ACTIONS(4620),
    [sym_page_keyword] = ACTIONS(4618),
    [anon_sym_codeunit] = ACTIONS(4618),
    [anon_sym_CODEUNIT] = ACTIONS(4618),
    [anon_sym_Codeunit] = ACTIONS(4618),
    [anon_sym_CodeUnit] = ACTIONS(4618),
    [anon_sym_COdeunit] = ACTIONS(4618),
    [anon_sym_codeUnit] = ACTIONS(4618),
    [sym_report_keyword] = ACTIONS(4618),
    [sym_query_keyword] = ACTIONS(4618),
    [anon_sym_xmlport] = ACTIONS(4618),
    [anon_sym_XMLPORT] = ACTIONS(4618),
    [anon_sym_Xmlport] = ACTIONS(4618),
    [anon_sym_XMLport] = ACTIONS(4618),
    [anon_sym_XMLPort] = ACTIONS(4618),
    [anon_sym_XmlPort] = ACTIONS(4618),
    [anon_sym_enum] = ACTIONS(4618),
    [anon_sym_ENUM] = ACTIONS(4618),
    [anon_sym_Enum] = ACTIONS(4618),
    [anon_sym_eNUM] = ACTIONS(4618),
    [anon_sym_eNum] = ACTIONS(4618),
    [anon_sym_ENum] = ACTIONS(4618),
    [sym_quoted_identifier] = ACTIONS(4620),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4620),
    [sym_integer] = ACTIONS(4618),
    [sym_continue_as_identifier] = ACTIONS(4620),
    [sym_preproc_open] = ACTIONS(4620),
    [sym_end_keyword] = ACTIONS(4620),
  },
  [STATE(2284)] = {
    [sym_identifier] = ACTIONS(4443),
    [anon_sym_SEMI] = ACTIONS(4445),
    [anon_sym_DASH] = ACTIONS(4445),
    [aux_sym_boolean_token1] = ACTIONS(4443),
    [aux_sym_boolean_token2] = ACTIONS(4443),
    [sym_decimal] = ACTIONS(4443),
    [anon_sym_LPAREN] = ACTIONS(4445),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4443),
    [anon_sym_LBRACK] = ACTIONS(4445),
    [aux_sym_record_type_token1] = ACTIONS(4443),
    [aux_sym_basic_type_token21] = ACTIONS(4443),
    [aux_sym_basic_type_token22] = ACTIONS(4443),
    [aux_sym_basic_type_token48] = ACTIONS(4443),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4443),
    [anon_sym_POUNDif] = ACTIONS(4445),
    [anon_sym_POUNDIF] = ACTIONS(4445),
    [anon_sym_POUNDIf] = ACTIONS(4445),
    [anon_sym_not] = ACTIONS(4443),
    [anon_sym_NOT] = ACTIONS(4443),
    [anon_sym_Not] = ACTIONS(4443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4443),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4443),
    [anon_sym_PLUS] = ACTIONS(4445),
    [sym_datetime_literal] = ACTIONS(4445),
    [sym_date_literal] = ACTIONS(4443),
    [sym_time_literal] = ACTIONS(4443),
    [sym_biginteger_literal] = ACTIONS(4445),
    [anon_sym_if] = ACTIONS(4443),
    [anon_sym_IF] = ACTIONS(4443),
    [anon_sym_If] = ACTIONS(4443),
    [anon_sym_else] = ACTIONS(4443),
    [anon_sym_ELSE] = ACTIONS(4443),
    [anon_sym_Else] = ACTIONS(4443),
    [anon_sym_case] = ACTIONS(4443),
    [anon_sym_CASE] = ACTIONS(4443),
    [anon_sym_Case] = ACTIONS(4443),
    [anon_sym_for] = ACTIONS(4443),
    [anon_sym_FOR] = ACTIONS(4443),
    [anon_sym_For] = ACTIONS(4443),
    [anon_sym_foreach] = ACTIONS(4443),
    [anon_sym_FOREACH] = ACTIONS(4443),
    [anon_sym_Foreach] = ACTIONS(4443),
    [anon_sym_while] = ACTIONS(4443),
    [anon_sym_WHILE] = ACTIONS(4443),
    [anon_sym_While] = ACTIONS(4443),
    [anon_sym_repeat] = ACTIONS(4443),
    [anon_sym_REPEAT] = ACTIONS(4443),
    [anon_sym_Repeat] = ACTIONS(4443),
    [anon_sym_exit] = ACTIONS(4443),
    [anon_sym_EXIT] = ACTIONS(4443),
    [anon_sym_Exit] = ACTIONS(4443),
    [anon_sym_continue] = ACTIONS(4443),
    [anon_sym_CONTINUE] = ACTIONS(4443),
    [anon_sym_Continue] = ACTIONS(4443),
    [anon_sym_break] = ACTIONS(4443),
    [anon_sym_BREAK] = ACTIONS(4443),
    [anon_sym_Break] = ACTIONS(4443),
    [anon_sym_with] = ACTIONS(4443),
    [anon_sym_WITH] = ACTIONS(4443),
    [anon_sym_With] = ACTIONS(4443),
    [sym_asserterror_keyword] = ACTIONS(4445),
    [sym_page_keyword] = ACTIONS(4443),
    [anon_sym_codeunit] = ACTIONS(4443),
    [anon_sym_CODEUNIT] = ACTIONS(4443),
    [anon_sym_Codeunit] = ACTIONS(4443),
    [anon_sym_CodeUnit] = ACTIONS(4443),
    [anon_sym_COdeunit] = ACTIONS(4443),
    [anon_sym_codeUnit] = ACTIONS(4443),
    [sym_report_keyword] = ACTIONS(4443),
    [sym_query_keyword] = ACTIONS(4443),
    [anon_sym_xmlport] = ACTIONS(4443),
    [anon_sym_XMLPORT] = ACTIONS(4443),
    [anon_sym_Xmlport] = ACTIONS(4443),
    [anon_sym_XMLport] = ACTIONS(4443),
    [anon_sym_XMLPort] = ACTIONS(4443),
    [anon_sym_XmlPort] = ACTIONS(4443),
    [anon_sym_enum] = ACTIONS(4443),
    [anon_sym_ENUM] = ACTIONS(4443),
    [anon_sym_Enum] = ACTIONS(4443),
    [anon_sym_eNUM] = ACTIONS(4443),
    [anon_sym_eNum] = ACTIONS(4443),
    [anon_sym_ENum] = ACTIONS(4443),
    [sym_quoted_identifier] = ACTIONS(4445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4445),
    [sym_integer] = ACTIONS(4443),
    [sym_continue_as_identifier] = ACTIONS(4445),
    [sym_preproc_open] = ACTIONS(4445),
    [sym_end_keyword] = ACTIONS(4445),
  },
  [STATE(2285)] = {
    [sym_identifier] = ACTIONS(4577),
    [anon_sym_SEMI] = ACTIONS(4579),
    [anon_sym_DASH] = ACTIONS(4579),
    [aux_sym_boolean_token1] = ACTIONS(4577),
    [aux_sym_boolean_token2] = ACTIONS(4577),
    [sym_decimal] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(4579),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4579),
    [aux_sym_record_type_token1] = ACTIONS(4577),
    [aux_sym_basic_type_token21] = ACTIONS(4577),
    [aux_sym_basic_type_token22] = ACTIONS(4577),
    [aux_sym_basic_type_token48] = ACTIONS(4577),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4577),
    [anon_sym_POUNDif] = ACTIONS(4579),
    [anon_sym_POUNDIF] = ACTIONS(4579),
    [anon_sym_POUNDIf] = ACTIONS(4579),
    [anon_sym_not] = ACTIONS(4577),
    [anon_sym_NOT] = ACTIONS(4577),
    [anon_sym_Not] = ACTIONS(4577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4577),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4577),
    [anon_sym_PLUS] = ACTIONS(4579),
    [sym_datetime_literal] = ACTIONS(4579),
    [sym_date_literal] = ACTIONS(4577),
    [sym_time_literal] = ACTIONS(4577),
    [sym_biginteger_literal] = ACTIONS(4579),
    [anon_sym_if] = ACTIONS(4577),
    [anon_sym_IF] = ACTIONS(4577),
    [anon_sym_If] = ACTIONS(4577),
    [anon_sym_else] = ACTIONS(4577),
    [anon_sym_ELSE] = ACTIONS(4577),
    [anon_sym_Else] = ACTIONS(4577),
    [anon_sym_case] = ACTIONS(4577),
    [anon_sym_CASE] = ACTIONS(4577),
    [anon_sym_Case] = ACTIONS(4577),
    [anon_sym_for] = ACTIONS(4577),
    [anon_sym_FOR] = ACTIONS(4577),
    [anon_sym_For] = ACTIONS(4577),
    [anon_sym_foreach] = ACTIONS(4577),
    [anon_sym_FOREACH] = ACTIONS(4577),
    [anon_sym_Foreach] = ACTIONS(4577),
    [anon_sym_while] = ACTIONS(4577),
    [anon_sym_WHILE] = ACTIONS(4577),
    [anon_sym_While] = ACTIONS(4577),
    [anon_sym_repeat] = ACTIONS(4577),
    [anon_sym_REPEAT] = ACTIONS(4577),
    [anon_sym_Repeat] = ACTIONS(4577),
    [anon_sym_exit] = ACTIONS(4577),
    [anon_sym_EXIT] = ACTIONS(4577),
    [anon_sym_Exit] = ACTIONS(4577),
    [anon_sym_continue] = ACTIONS(4577),
    [anon_sym_CONTINUE] = ACTIONS(4577),
    [anon_sym_Continue] = ACTIONS(4577),
    [anon_sym_break] = ACTIONS(4577),
    [anon_sym_BREAK] = ACTIONS(4577),
    [anon_sym_Break] = ACTIONS(4577),
    [anon_sym_with] = ACTIONS(4577),
    [anon_sym_WITH] = ACTIONS(4577),
    [anon_sym_With] = ACTIONS(4577),
    [sym_asserterror_keyword] = ACTIONS(4579),
    [sym_page_keyword] = ACTIONS(4577),
    [anon_sym_codeunit] = ACTIONS(4577),
    [anon_sym_CODEUNIT] = ACTIONS(4577),
    [anon_sym_Codeunit] = ACTIONS(4577),
    [anon_sym_CodeUnit] = ACTIONS(4577),
    [anon_sym_COdeunit] = ACTIONS(4577),
    [anon_sym_codeUnit] = ACTIONS(4577),
    [sym_report_keyword] = ACTIONS(4577),
    [sym_query_keyword] = ACTIONS(4577),
    [anon_sym_xmlport] = ACTIONS(4577),
    [anon_sym_XMLPORT] = ACTIONS(4577),
    [anon_sym_Xmlport] = ACTIONS(4577),
    [anon_sym_XMLport] = ACTIONS(4577),
    [anon_sym_XMLPort] = ACTIONS(4577),
    [anon_sym_XmlPort] = ACTIONS(4577),
    [anon_sym_enum] = ACTIONS(4577),
    [anon_sym_ENUM] = ACTIONS(4577),
    [anon_sym_Enum] = ACTIONS(4577),
    [anon_sym_eNUM] = ACTIONS(4577),
    [anon_sym_eNum] = ACTIONS(4577),
    [anon_sym_ENum] = ACTIONS(4577),
    [sym_quoted_identifier] = ACTIONS(4579),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4579),
    [sym_integer] = ACTIONS(4577),
    [sym_continue_as_identifier] = ACTIONS(4579),
    [sym_preproc_open] = ACTIONS(4579),
    [sym_end_keyword] = ACTIONS(4579),
  },
  [STATE(2286)] = {
    [sym_identifier] = ACTIONS(4688),
    [anon_sym_SEMI] = ACTIONS(4690),
    [anon_sym_DASH] = ACTIONS(4690),
    [aux_sym_boolean_token1] = ACTIONS(4688),
    [aux_sym_boolean_token2] = ACTIONS(4688),
    [sym_decimal] = ACTIONS(4688),
    [anon_sym_LPAREN] = ACTIONS(4690),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4688),
    [anon_sym_LBRACK] = ACTIONS(4690),
    [aux_sym_record_type_token1] = ACTIONS(4688),
    [aux_sym_basic_type_token21] = ACTIONS(4688),
    [aux_sym_basic_type_token22] = ACTIONS(4688),
    [aux_sym_basic_type_token48] = ACTIONS(4688),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4688),
    [anon_sym_POUNDif] = ACTIONS(4690),
    [anon_sym_POUNDIF] = ACTIONS(4690),
    [anon_sym_POUNDIf] = ACTIONS(4690),
    [anon_sym_not] = ACTIONS(4688),
    [anon_sym_NOT] = ACTIONS(4688),
    [anon_sym_Not] = ACTIONS(4688),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4688),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4688),
    [anon_sym_PLUS] = ACTIONS(4690),
    [sym_datetime_literal] = ACTIONS(4690),
    [sym_date_literal] = ACTIONS(4688),
    [sym_time_literal] = ACTIONS(4688),
    [sym_biginteger_literal] = ACTIONS(4690),
    [anon_sym_if] = ACTIONS(4688),
    [anon_sym_IF] = ACTIONS(4688),
    [anon_sym_If] = ACTIONS(4688),
    [anon_sym_else] = ACTIONS(4688),
    [anon_sym_ELSE] = ACTIONS(4688),
    [anon_sym_Else] = ACTIONS(4688),
    [anon_sym_case] = ACTIONS(4688),
    [anon_sym_CASE] = ACTIONS(4688),
    [anon_sym_Case] = ACTIONS(4688),
    [anon_sym_for] = ACTIONS(4688),
    [anon_sym_FOR] = ACTIONS(4688),
    [anon_sym_For] = ACTIONS(4688),
    [anon_sym_foreach] = ACTIONS(4688),
    [anon_sym_FOREACH] = ACTIONS(4688),
    [anon_sym_Foreach] = ACTIONS(4688),
    [anon_sym_while] = ACTIONS(4688),
    [anon_sym_WHILE] = ACTIONS(4688),
    [anon_sym_While] = ACTIONS(4688),
    [anon_sym_repeat] = ACTIONS(4688),
    [anon_sym_REPEAT] = ACTIONS(4688),
    [anon_sym_Repeat] = ACTIONS(4688),
    [anon_sym_exit] = ACTIONS(4688),
    [anon_sym_EXIT] = ACTIONS(4688),
    [anon_sym_Exit] = ACTIONS(4688),
    [anon_sym_continue] = ACTIONS(4688),
    [anon_sym_CONTINUE] = ACTIONS(4688),
    [anon_sym_Continue] = ACTIONS(4688),
    [anon_sym_break] = ACTIONS(4688),
    [anon_sym_BREAK] = ACTIONS(4688),
    [anon_sym_Break] = ACTIONS(4688),
    [anon_sym_with] = ACTIONS(4688),
    [anon_sym_WITH] = ACTIONS(4688),
    [anon_sym_With] = ACTIONS(4688),
    [sym_asserterror_keyword] = ACTIONS(4690),
    [sym_page_keyword] = ACTIONS(4688),
    [anon_sym_codeunit] = ACTIONS(4688),
    [anon_sym_CODEUNIT] = ACTIONS(4688),
    [anon_sym_Codeunit] = ACTIONS(4688),
    [anon_sym_CodeUnit] = ACTIONS(4688),
    [anon_sym_COdeunit] = ACTIONS(4688),
    [anon_sym_codeUnit] = ACTIONS(4688),
    [sym_report_keyword] = ACTIONS(4688),
    [sym_query_keyword] = ACTIONS(4688),
    [anon_sym_xmlport] = ACTIONS(4688),
    [anon_sym_XMLPORT] = ACTIONS(4688),
    [anon_sym_Xmlport] = ACTIONS(4688),
    [anon_sym_XMLport] = ACTIONS(4688),
    [anon_sym_XMLPort] = ACTIONS(4688),
    [anon_sym_XmlPort] = ACTIONS(4688),
    [anon_sym_enum] = ACTIONS(4688),
    [anon_sym_ENUM] = ACTIONS(4688),
    [anon_sym_Enum] = ACTIONS(4688),
    [anon_sym_eNUM] = ACTIONS(4688),
    [anon_sym_eNum] = ACTIONS(4688),
    [anon_sym_ENum] = ACTIONS(4688),
    [sym_quoted_identifier] = ACTIONS(4690),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4690),
    [sym_integer] = ACTIONS(4688),
    [sym_continue_as_identifier] = ACTIONS(4690),
    [sym_preproc_open] = ACTIONS(4690),
    [sym_end_keyword] = ACTIONS(4690),
  },
  [STATE(2287)] = {
    [sym_identifier] = ACTIONS(4213),
    [anon_sym_SEMI] = ACTIONS(4215),
    [anon_sym_DASH] = ACTIONS(4215),
    [aux_sym_boolean_token1] = ACTIONS(4213),
    [aux_sym_boolean_token2] = ACTIONS(4213),
    [sym_decimal] = ACTIONS(4213),
    [anon_sym_LPAREN] = ACTIONS(4215),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4213),
    [anon_sym_LBRACK] = ACTIONS(4215),
    [aux_sym_record_type_token1] = ACTIONS(4213),
    [aux_sym_basic_type_token21] = ACTIONS(4213),
    [aux_sym_basic_type_token22] = ACTIONS(4213),
    [aux_sym_basic_type_token48] = ACTIONS(4213),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4213),
    [anon_sym_POUNDif] = ACTIONS(4215),
    [anon_sym_POUNDIF] = ACTIONS(4215),
    [anon_sym_POUNDIf] = ACTIONS(4215),
    [anon_sym_not] = ACTIONS(4213),
    [anon_sym_NOT] = ACTIONS(4213),
    [anon_sym_Not] = ACTIONS(4213),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4213),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4213),
    [anon_sym_PLUS] = ACTIONS(4215),
    [sym_datetime_literal] = ACTIONS(4215),
    [sym_date_literal] = ACTIONS(4213),
    [sym_time_literal] = ACTIONS(4213),
    [sym_biginteger_literal] = ACTIONS(4215),
    [anon_sym_if] = ACTIONS(4213),
    [anon_sym_IF] = ACTIONS(4213),
    [anon_sym_If] = ACTIONS(4213),
    [anon_sym_else] = ACTIONS(4213),
    [anon_sym_ELSE] = ACTIONS(4213),
    [anon_sym_Else] = ACTIONS(4213),
    [anon_sym_case] = ACTIONS(4213),
    [anon_sym_CASE] = ACTIONS(4213),
    [anon_sym_Case] = ACTIONS(4213),
    [anon_sym_for] = ACTIONS(4213),
    [anon_sym_FOR] = ACTIONS(4213),
    [anon_sym_For] = ACTIONS(4213),
    [anon_sym_foreach] = ACTIONS(4213),
    [anon_sym_FOREACH] = ACTIONS(4213),
    [anon_sym_Foreach] = ACTIONS(4213),
    [anon_sym_while] = ACTIONS(4213),
    [anon_sym_WHILE] = ACTIONS(4213),
    [anon_sym_While] = ACTIONS(4213),
    [anon_sym_repeat] = ACTIONS(4213),
    [anon_sym_REPEAT] = ACTIONS(4213),
    [anon_sym_Repeat] = ACTIONS(4213),
    [anon_sym_exit] = ACTIONS(4213),
    [anon_sym_EXIT] = ACTIONS(4213),
    [anon_sym_Exit] = ACTIONS(4213),
    [anon_sym_continue] = ACTIONS(4213),
    [anon_sym_CONTINUE] = ACTIONS(4213),
    [anon_sym_Continue] = ACTIONS(4213),
    [anon_sym_break] = ACTIONS(4213),
    [anon_sym_BREAK] = ACTIONS(4213),
    [anon_sym_Break] = ACTIONS(4213),
    [anon_sym_with] = ACTIONS(4213),
    [anon_sym_WITH] = ACTIONS(4213),
    [anon_sym_With] = ACTIONS(4213),
    [sym_asserterror_keyword] = ACTIONS(4215),
    [sym_page_keyword] = ACTIONS(4213),
    [anon_sym_codeunit] = ACTIONS(4213),
    [anon_sym_CODEUNIT] = ACTIONS(4213),
    [anon_sym_Codeunit] = ACTIONS(4213),
    [anon_sym_CodeUnit] = ACTIONS(4213),
    [anon_sym_COdeunit] = ACTIONS(4213),
    [anon_sym_codeUnit] = ACTIONS(4213),
    [sym_report_keyword] = ACTIONS(4213),
    [sym_query_keyword] = ACTIONS(4213),
    [anon_sym_xmlport] = ACTIONS(4213),
    [anon_sym_XMLPORT] = ACTIONS(4213),
    [anon_sym_Xmlport] = ACTIONS(4213),
    [anon_sym_XMLport] = ACTIONS(4213),
    [anon_sym_XMLPort] = ACTIONS(4213),
    [anon_sym_XmlPort] = ACTIONS(4213),
    [anon_sym_enum] = ACTIONS(4213),
    [anon_sym_ENUM] = ACTIONS(4213),
    [anon_sym_Enum] = ACTIONS(4213),
    [anon_sym_eNUM] = ACTIONS(4213),
    [anon_sym_eNum] = ACTIONS(4213),
    [anon_sym_ENum] = ACTIONS(4213),
    [sym_quoted_identifier] = ACTIONS(4215),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4215),
    [sym_integer] = ACTIONS(4213),
    [sym_continue_as_identifier] = ACTIONS(4215),
    [sym_preproc_open] = ACTIONS(4215),
    [sym_end_keyword] = ACTIONS(4215),
  },
  [STATE(2288)] = {
    [sym_identifier] = ACTIONS(4447),
    [anon_sym_SEMI] = ACTIONS(4449),
    [anon_sym_DASH] = ACTIONS(4449),
    [aux_sym_boolean_token1] = ACTIONS(4447),
    [aux_sym_boolean_token2] = ACTIONS(4447),
    [sym_decimal] = ACTIONS(4447),
    [anon_sym_LPAREN] = ACTIONS(4449),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4447),
    [anon_sym_LBRACK] = ACTIONS(4449),
    [aux_sym_record_type_token1] = ACTIONS(4447),
    [aux_sym_basic_type_token21] = ACTIONS(4447),
    [aux_sym_basic_type_token22] = ACTIONS(4447),
    [aux_sym_basic_type_token48] = ACTIONS(4447),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4447),
    [anon_sym_POUNDif] = ACTIONS(4449),
    [anon_sym_POUNDIF] = ACTIONS(4449),
    [anon_sym_POUNDIf] = ACTIONS(4449),
    [anon_sym_not] = ACTIONS(4447),
    [anon_sym_NOT] = ACTIONS(4447),
    [anon_sym_Not] = ACTIONS(4447),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4447),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4447),
    [anon_sym_PLUS] = ACTIONS(4449),
    [sym_datetime_literal] = ACTIONS(4449),
    [sym_date_literal] = ACTIONS(4447),
    [sym_time_literal] = ACTIONS(4447),
    [sym_biginteger_literal] = ACTIONS(4449),
    [anon_sym_if] = ACTIONS(4447),
    [anon_sym_IF] = ACTIONS(4447),
    [anon_sym_If] = ACTIONS(4447),
    [anon_sym_else] = ACTIONS(4447),
    [anon_sym_ELSE] = ACTIONS(4447),
    [anon_sym_Else] = ACTIONS(4447),
    [anon_sym_case] = ACTIONS(4447),
    [anon_sym_CASE] = ACTIONS(4447),
    [anon_sym_Case] = ACTIONS(4447),
    [anon_sym_for] = ACTIONS(4447),
    [anon_sym_FOR] = ACTIONS(4447),
    [anon_sym_For] = ACTIONS(4447),
    [anon_sym_foreach] = ACTIONS(4447),
    [anon_sym_FOREACH] = ACTIONS(4447),
    [anon_sym_Foreach] = ACTIONS(4447),
    [anon_sym_while] = ACTIONS(4447),
    [anon_sym_WHILE] = ACTIONS(4447),
    [anon_sym_While] = ACTIONS(4447),
    [anon_sym_repeat] = ACTIONS(4447),
    [anon_sym_REPEAT] = ACTIONS(4447),
    [anon_sym_Repeat] = ACTIONS(4447),
    [anon_sym_exit] = ACTIONS(4447),
    [anon_sym_EXIT] = ACTIONS(4447),
    [anon_sym_Exit] = ACTIONS(4447),
    [anon_sym_continue] = ACTIONS(4447),
    [anon_sym_CONTINUE] = ACTIONS(4447),
    [anon_sym_Continue] = ACTIONS(4447),
    [anon_sym_break] = ACTIONS(4447),
    [anon_sym_BREAK] = ACTIONS(4447),
    [anon_sym_Break] = ACTIONS(4447),
    [anon_sym_with] = ACTIONS(4447),
    [anon_sym_WITH] = ACTIONS(4447),
    [anon_sym_With] = ACTIONS(4447),
    [sym_asserterror_keyword] = ACTIONS(4449),
    [sym_page_keyword] = ACTIONS(4447),
    [anon_sym_codeunit] = ACTIONS(4447),
    [anon_sym_CODEUNIT] = ACTIONS(4447),
    [anon_sym_Codeunit] = ACTIONS(4447),
    [anon_sym_CodeUnit] = ACTIONS(4447),
    [anon_sym_COdeunit] = ACTIONS(4447),
    [anon_sym_codeUnit] = ACTIONS(4447),
    [sym_report_keyword] = ACTIONS(4447),
    [sym_query_keyword] = ACTIONS(4447),
    [anon_sym_xmlport] = ACTIONS(4447),
    [anon_sym_XMLPORT] = ACTIONS(4447),
    [anon_sym_Xmlport] = ACTIONS(4447),
    [anon_sym_XMLport] = ACTIONS(4447),
    [anon_sym_XMLPort] = ACTIONS(4447),
    [anon_sym_XmlPort] = ACTIONS(4447),
    [anon_sym_enum] = ACTIONS(4447),
    [anon_sym_ENUM] = ACTIONS(4447),
    [anon_sym_Enum] = ACTIONS(4447),
    [anon_sym_eNUM] = ACTIONS(4447),
    [anon_sym_eNum] = ACTIONS(4447),
    [anon_sym_ENum] = ACTIONS(4447),
    [sym_quoted_identifier] = ACTIONS(4449),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4449),
    [sym_integer] = ACTIONS(4447),
    [sym_continue_as_identifier] = ACTIONS(4449),
    [sym_preproc_open] = ACTIONS(4449),
    [sym_end_keyword] = ACTIONS(4449),
  },
  [STATE(2289)] = {
    [sym_identifier] = ACTIONS(4451),
    [anon_sym_SEMI] = ACTIONS(4453),
    [anon_sym_DASH] = ACTIONS(4453),
    [aux_sym_boolean_token1] = ACTIONS(4451),
    [aux_sym_boolean_token2] = ACTIONS(4451),
    [sym_decimal] = ACTIONS(4451),
    [anon_sym_LPAREN] = ACTIONS(4453),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4451),
    [anon_sym_LBRACK] = ACTIONS(4453),
    [aux_sym_record_type_token1] = ACTIONS(4451),
    [aux_sym_basic_type_token21] = ACTIONS(4451),
    [aux_sym_basic_type_token22] = ACTIONS(4451),
    [aux_sym_basic_type_token48] = ACTIONS(4451),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4451),
    [anon_sym_POUNDif] = ACTIONS(4453),
    [anon_sym_POUNDIF] = ACTIONS(4453),
    [anon_sym_POUNDIf] = ACTIONS(4453),
    [anon_sym_not] = ACTIONS(4451),
    [anon_sym_NOT] = ACTIONS(4451),
    [anon_sym_Not] = ACTIONS(4451),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4451),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4451),
    [anon_sym_PLUS] = ACTIONS(4453),
    [sym_datetime_literal] = ACTIONS(4453),
    [sym_date_literal] = ACTIONS(4451),
    [sym_time_literal] = ACTIONS(4451),
    [sym_biginteger_literal] = ACTIONS(4453),
    [anon_sym_if] = ACTIONS(4451),
    [anon_sym_IF] = ACTIONS(4451),
    [anon_sym_If] = ACTIONS(4451),
    [anon_sym_else] = ACTIONS(4451),
    [anon_sym_ELSE] = ACTIONS(4451),
    [anon_sym_Else] = ACTIONS(4451),
    [anon_sym_case] = ACTIONS(4451),
    [anon_sym_CASE] = ACTIONS(4451),
    [anon_sym_Case] = ACTIONS(4451),
    [anon_sym_for] = ACTIONS(4451),
    [anon_sym_FOR] = ACTIONS(4451),
    [anon_sym_For] = ACTIONS(4451),
    [anon_sym_foreach] = ACTIONS(4451),
    [anon_sym_FOREACH] = ACTIONS(4451),
    [anon_sym_Foreach] = ACTIONS(4451),
    [anon_sym_while] = ACTIONS(4451),
    [anon_sym_WHILE] = ACTIONS(4451),
    [anon_sym_While] = ACTIONS(4451),
    [anon_sym_repeat] = ACTIONS(4451),
    [anon_sym_REPEAT] = ACTIONS(4451),
    [anon_sym_Repeat] = ACTIONS(4451),
    [anon_sym_exit] = ACTIONS(4451),
    [anon_sym_EXIT] = ACTIONS(4451),
    [anon_sym_Exit] = ACTIONS(4451),
    [anon_sym_continue] = ACTIONS(4451),
    [anon_sym_CONTINUE] = ACTIONS(4451),
    [anon_sym_Continue] = ACTIONS(4451),
    [anon_sym_break] = ACTIONS(4451),
    [anon_sym_BREAK] = ACTIONS(4451),
    [anon_sym_Break] = ACTIONS(4451),
    [anon_sym_with] = ACTIONS(4451),
    [anon_sym_WITH] = ACTIONS(4451),
    [anon_sym_With] = ACTIONS(4451),
    [sym_asserterror_keyword] = ACTIONS(4453),
    [sym_page_keyword] = ACTIONS(4451),
    [anon_sym_codeunit] = ACTIONS(4451),
    [anon_sym_CODEUNIT] = ACTIONS(4451),
    [anon_sym_Codeunit] = ACTIONS(4451),
    [anon_sym_CodeUnit] = ACTIONS(4451),
    [anon_sym_COdeunit] = ACTIONS(4451),
    [anon_sym_codeUnit] = ACTIONS(4451),
    [sym_report_keyword] = ACTIONS(4451),
    [sym_query_keyword] = ACTIONS(4451),
    [anon_sym_xmlport] = ACTIONS(4451),
    [anon_sym_XMLPORT] = ACTIONS(4451),
    [anon_sym_Xmlport] = ACTIONS(4451),
    [anon_sym_XMLport] = ACTIONS(4451),
    [anon_sym_XMLPort] = ACTIONS(4451),
    [anon_sym_XmlPort] = ACTIONS(4451),
    [anon_sym_enum] = ACTIONS(4451),
    [anon_sym_ENUM] = ACTIONS(4451),
    [anon_sym_Enum] = ACTIONS(4451),
    [anon_sym_eNUM] = ACTIONS(4451),
    [anon_sym_eNum] = ACTIONS(4451),
    [anon_sym_ENum] = ACTIONS(4451),
    [sym_quoted_identifier] = ACTIONS(4453),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4453),
    [sym_integer] = ACTIONS(4451),
    [sym_continue_as_identifier] = ACTIONS(4453),
    [sym_preproc_open] = ACTIONS(4453),
    [sym_end_keyword] = ACTIONS(4453),
  },
  [STATE(2290)] = {
    [sym_identifier] = ACTIONS(4249),
    [anon_sym_SEMI] = ACTIONS(4251),
    [anon_sym_DASH] = ACTIONS(4251),
    [aux_sym_boolean_token1] = ACTIONS(4249),
    [aux_sym_boolean_token2] = ACTIONS(4249),
    [sym_decimal] = ACTIONS(4249),
    [anon_sym_LPAREN] = ACTIONS(4251),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4249),
    [anon_sym_LBRACK] = ACTIONS(4251),
    [aux_sym_record_type_token1] = ACTIONS(4249),
    [aux_sym_basic_type_token21] = ACTIONS(4249),
    [aux_sym_basic_type_token22] = ACTIONS(4249),
    [aux_sym_basic_type_token48] = ACTIONS(4249),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4249),
    [anon_sym_POUNDif] = ACTIONS(4251),
    [anon_sym_POUNDIF] = ACTIONS(4251),
    [anon_sym_POUNDIf] = ACTIONS(4251),
    [anon_sym_not] = ACTIONS(4249),
    [anon_sym_NOT] = ACTIONS(4249),
    [anon_sym_Not] = ACTIONS(4249),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4249),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4249),
    [anon_sym_PLUS] = ACTIONS(4251),
    [sym_datetime_literal] = ACTIONS(4251),
    [sym_date_literal] = ACTIONS(4249),
    [sym_time_literal] = ACTIONS(4249),
    [sym_biginteger_literal] = ACTIONS(4251),
    [anon_sym_if] = ACTIONS(4249),
    [anon_sym_IF] = ACTIONS(4249),
    [anon_sym_If] = ACTIONS(4249),
    [anon_sym_else] = ACTIONS(4249),
    [anon_sym_ELSE] = ACTIONS(4249),
    [anon_sym_Else] = ACTIONS(4249),
    [anon_sym_case] = ACTIONS(4249),
    [anon_sym_CASE] = ACTIONS(4249),
    [anon_sym_Case] = ACTIONS(4249),
    [anon_sym_for] = ACTIONS(4249),
    [anon_sym_FOR] = ACTIONS(4249),
    [anon_sym_For] = ACTIONS(4249),
    [anon_sym_foreach] = ACTIONS(4249),
    [anon_sym_FOREACH] = ACTIONS(4249),
    [anon_sym_Foreach] = ACTIONS(4249),
    [anon_sym_while] = ACTIONS(4249),
    [anon_sym_WHILE] = ACTIONS(4249),
    [anon_sym_While] = ACTIONS(4249),
    [anon_sym_repeat] = ACTIONS(4249),
    [anon_sym_REPEAT] = ACTIONS(4249),
    [anon_sym_Repeat] = ACTIONS(4249),
    [anon_sym_exit] = ACTIONS(4249),
    [anon_sym_EXIT] = ACTIONS(4249),
    [anon_sym_Exit] = ACTIONS(4249),
    [anon_sym_continue] = ACTIONS(4249),
    [anon_sym_CONTINUE] = ACTIONS(4249),
    [anon_sym_Continue] = ACTIONS(4249),
    [anon_sym_break] = ACTIONS(4249),
    [anon_sym_BREAK] = ACTIONS(4249),
    [anon_sym_Break] = ACTIONS(4249),
    [anon_sym_with] = ACTIONS(4249),
    [anon_sym_WITH] = ACTIONS(4249),
    [anon_sym_With] = ACTIONS(4249),
    [sym_asserterror_keyword] = ACTIONS(4251),
    [sym_page_keyword] = ACTIONS(4249),
    [anon_sym_codeunit] = ACTIONS(4249),
    [anon_sym_CODEUNIT] = ACTIONS(4249),
    [anon_sym_Codeunit] = ACTIONS(4249),
    [anon_sym_CodeUnit] = ACTIONS(4249),
    [anon_sym_COdeunit] = ACTIONS(4249),
    [anon_sym_codeUnit] = ACTIONS(4249),
    [sym_report_keyword] = ACTIONS(4249),
    [sym_query_keyword] = ACTIONS(4249),
    [anon_sym_xmlport] = ACTIONS(4249),
    [anon_sym_XMLPORT] = ACTIONS(4249),
    [anon_sym_Xmlport] = ACTIONS(4249),
    [anon_sym_XMLport] = ACTIONS(4249),
    [anon_sym_XMLPort] = ACTIONS(4249),
    [anon_sym_XmlPort] = ACTIONS(4249),
    [anon_sym_enum] = ACTIONS(4249),
    [anon_sym_ENUM] = ACTIONS(4249),
    [anon_sym_Enum] = ACTIONS(4249),
    [anon_sym_eNUM] = ACTIONS(4249),
    [anon_sym_eNum] = ACTIONS(4249),
    [anon_sym_ENum] = ACTIONS(4249),
    [sym_quoted_identifier] = ACTIONS(4251),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4251),
    [sym_integer] = ACTIONS(4249),
    [sym_continue_as_identifier] = ACTIONS(4251),
    [sym_preproc_open] = ACTIONS(4251),
    [sym_end_keyword] = ACTIONS(4251),
  },
  [STATE(2291)] = {
    [sym_identifier] = ACTIONS(4455),
    [anon_sym_SEMI] = ACTIONS(4457),
    [anon_sym_DASH] = ACTIONS(4457),
    [aux_sym_boolean_token1] = ACTIONS(4455),
    [aux_sym_boolean_token2] = ACTIONS(4455),
    [sym_decimal] = ACTIONS(4455),
    [anon_sym_LPAREN] = ACTIONS(4457),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4455),
    [anon_sym_LBRACK] = ACTIONS(4457),
    [aux_sym_record_type_token1] = ACTIONS(4455),
    [aux_sym_basic_type_token21] = ACTIONS(4455),
    [aux_sym_basic_type_token22] = ACTIONS(4455),
    [aux_sym_basic_type_token48] = ACTIONS(4455),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(4457),
    [anon_sym_POUNDIF] = ACTIONS(4457),
    [anon_sym_POUNDIf] = ACTIONS(4457),
    [anon_sym_not] = ACTIONS(4455),
    [anon_sym_NOT] = ACTIONS(4455),
    [anon_sym_Not] = ACTIONS(4455),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4455),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4455),
    [anon_sym_PLUS] = ACTIONS(4457),
    [sym_datetime_literal] = ACTIONS(4457),
    [sym_date_literal] = ACTIONS(4455),
    [sym_time_literal] = ACTIONS(4455),
    [sym_biginteger_literal] = ACTIONS(4457),
    [anon_sym_if] = ACTIONS(4455),
    [anon_sym_IF] = ACTIONS(4455),
    [anon_sym_If] = ACTIONS(4455),
    [anon_sym_else] = ACTIONS(4455),
    [anon_sym_ELSE] = ACTIONS(4455),
    [anon_sym_Else] = ACTIONS(4455),
    [anon_sym_case] = ACTIONS(4455),
    [anon_sym_CASE] = ACTIONS(4455),
    [anon_sym_Case] = ACTIONS(4455),
    [anon_sym_for] = ACTIONS(4455),
    [anon_sym_FOR] = ACTIONS(4455),
    [anon_sym_For] = ACTIONS(4455),
    [anon_sym_foreach] = ACTIONS(4455),
    [anon_sym_FOREACH] = ACTIONS(4455),
    [anon_sym_Foreach] = ACTIONS(4455),
    [anon_sym_while] = ACTIONS(4455),
    [anon_sym_WHILE] = ACTIONS(4455),
    [anon_sym_While] = ACTIONS(4455),
    [anon_sym_repeat] = ACTIONS(4455),
    [anon_sym_REPEAT] = ACTIONS(4455),
    [anon_sym_Repeat] = ACTIONS(4455),
    [anon_sym_exit] = ACTIONS(4455),
    [anon_sym_EXIT] = ACTIONS(4455),
    [anon_sym_Exit] = ACTIONS(4455),
    [anon_sym_continue] = ACTIONS(4455),
    [anon_sym_CONTINUE] = ACTIONS(4455),
    [anon_sym_Continue] = ACTIONS(4455),
    [anon_sym_break] = ACTIONS(4455),
    [anon_sym_BREAK] = ACTIONS(4455),
    [anon_sym_Break] = ACTIONS(4455),
    [anon_sym_with] = ACTIONS(4455),
    [anon_sym_WITH] = ACTIONS(4455),
    [anon_sym_With] = ACTIONS(4455),
    [sym_asserterror_keyword] = ACTIONS(4457),
    [sym_page_keyword] = ACTIONS(4455),
    [anon_sym_codeunit] = ACTIONS(4455),
    [anon_sym_CODEUNIT] = ACTIONS(4455),
    [anon_sym_Codeunit] = ACTIONS(4455),
    [anon_sym_CodeUnit] = ACTIONS(4455),
    [anon_sym_COdeunit] = ACTIONS(4455),
    [anon_sym_codeUnit] = ACTIONS(4455),
    [sym_report_keyword] = ACTIONS(4455),
    [sym_query_keyword] = ACTIONS(4455),
    [anon_sym_xmlport] = ACTIONS(4455),
    [anon_sym_XMLPORT] = ACTIONS(4455),
    [anon_sym_Xmlport] = ACTIONS(4455),
    [anon_sym_XMLport] = ACTIONS(4455),
    [anon_sym_XMLPort] = ACTIONS(4455),
    [anon_sym_XmlPort] = ACTIONS(4455),
    [anon_sym_enum] = ACTIONS(4455),
    [anon_sym_ENUM] = ACTIONS(4455),
    [anon_sym_Enum] = ACTIONS(4455),
    [anon_sym_eNUM] = ACTIONS(4455),
    [anon_sym_eNum] = ACTIONS(4455),
    [anon_sym_ENum] = ACTIONS(4455),
    [sym_quoted_identifier] = ACTIONS(4457),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4457),
    [sym_integer] = ACTIONS(4455),
    [sym_continue_as_identifier] = ACTIONS(4457),
    [sym_preproc_open] = ACTIONS(4457),
    [sym_end_keyword] = ACTIONS(4457),
  },
  [STATE(2292)] = {
    [sym_identifier] = ACTIONS(4395),
    [anon_sym_SEMI] = ACTIONS(4397),
    [anon_sym_DASH] = ACTIONS(4397),
    [aux_sym_boolean_token1] = ACTIONS(4395),
    [aux_sym_boolean_token2] = ACTIONS(4395),
    [sym_decimal] = ACTIONS(4395),
    [anon_sym_LPAREN] = ACTIONS(4397),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4395),
    [anon_sym_LBRACK] = ACTIONS(4397),
    [aux_sym_record_type_token1] = ACTIONS(4395),
    [aux_sym_basic_type_token21] = ACTIONS(4395),
    [aux_sym_basic_type_token22] = ACTIONS(4395),
    [aux_sym_basic_type_token48] = ACTIONS(4395),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4395),
    [anon_sym_POUNDif] = ACTIONS(4397),
    [anon_sym_POUNDIF] = ACTIONS(4397),
    [anon_sym_POUNDIf] = ACTIONS(4397),
    [anon_sym_not] = ACTIONS(4395),
    [anon_sym_NOT] = ACTIONS(4395),
    [anon_sym_Not] = ACTIONS(4395),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4395),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4395),
    [anon_sym_PLUS] = ACTIONS(4397),
    [sym_datetime_literal] = ACTIONS(4397),
    [sym_date_literal] = ACTIONS(4395),
    [sym_time_literal] = ACTIONS(4395),
    [sym_biginteger_literal] = ACTIONS(4397),
    [anon_sym_if] = ACTIONS(4395),
    [anon_sym_IF] = ACTIONS(4395),
    [anon_sym_If] = ACTIONS(4395),
    [anon_sym_else] = ACTIONS(4395),
    [anon_sym_ELSE] = ACTIONS(4395),
    [anon_sym_Else] = ACTIONS(4395),
    [anon_sym_case] = ACTIONS(4395),
    [anon_sym_CASE] = ACTIONS(4395),
    [anon_sym_Case] = ACTIONS(4395),
    [anon_sym_for] = ACTIONS(4395),
    [anon_sym_FOR] = ACTIONS(4395),
    [anon_sym_For] = ACTIONS(4395),
    [anon_sym_foreach] = ACTIONS(4395),
    [anon_sym_FOREACH] = ACTIONS(4395),
    [anon_sym_Foreach] = ACTIONS(4395),
    [anon_sym_while] = ACTIONS(4395),
    [anon_sym_WHILE] = ACTIONS(4395),
    [anon_sym_While] = ACTIONS(4395),
    [anon_sym_repeat] = ACTIONS(4395),
    [anon_sym_REPEAT] = ACTIONS(4395),
    [anon_sym_Repeat] = ACTIONS(4395),
    [anon_sym_exit] = ACTIONS(4395),
    [anon_sym_EXIT] = ACTIONS(4395),
    [anon_sym_Exit] = ACTIONS(4395),
    [anon_sym_continue] = ACTIONS(4395),
    [anon_sym_CONTINUE] = ACTIONS(4395),
    [anon_sym_Continue] = ACTIONS(4395),
    [anon_sym_break] = ACTIONS(4395),
    [anon_sym_BREAK] = ACTIONS(4395),
    [anon_sym_Break] = ACTIONS(4395),
    [anon_sym_with] = ACTIONS(4395),
    [anon_sym_WITH] = ACTIONS(4395),
    [anon_sym_With] = ACTIONS(4395),
    [sym_asserterror_keyword] = ACTIONS(4397),
    [sym_page_keyword] = ACTIONS(4395),
    [anon_sym_codeunit] = ACTIONS(4395),
    [anon_sym_CODEUNIT] = ACTIONS(4395),
    [anon_sym_Codeunit] = ACTIONS(4395),
    [anon_sym_CodeUnit] = ACTIONS(4395),
    [anon_sym_COdeunit] = ACTIONS(4395),
    [anon_sym_codeUnit] = ACTIONS(4395),
    [sym_report_keyword] = ACTIONS(4395),
    [sym_query_keyword] = ACTIONS(4395),
    [anon_sym_xmlport] = ACTIONS(4395),
    [anon_sym_XMLPORT] = ACTIONS(4395),
    [anon_sym_Xmlport] = ACTIONS(4395),
    [anon_sym_XMLport] = ACTIONS(4395),
    [anon_sym_XMLPort] = ACTIONS(4395),
    [anon_sym_XmlPort] = ACTIONS(4395),
    [anon_sym_enum] = ACTIONS(4395),
    [anon_sym_ENUM] = ACTIONS(4395),
    [anon_sym_Enum] = ACTIONS(4395),
    [anon_sym_eNUM] = ACTIONS(4395),
    [anon_sym_eNum] = ACTIONS(4395),
    [anon_sym_ENum] = ACTIONS(4395),
    [sym_quoted_identifier] = ACTIONS(4397),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4397),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4397),
    [sym_preproc_open] = ACTIONS(4397),
    [sym_end_keyword] = ACTIONS(4397),
  },
  [STATE(2293)] = {
    [sym_identifier] = ACTIONS(4253),
    [anon_sym_SEMI] = ACTIONS(4255),
    [anon_sym_DASH] = ACTIONS(4255),
    [aux_sym_boolean_token1] = ACTIONS(4253),
    [aux_sym_boolean_token2] = ACTIONS(4253),
    [sym_decimal] = ACTIONS(4253),
    [anon_sym_LPAREN] = ACTIONS(4255),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4253),
    [anon_sym_LBRACK] = ACTIONS(4255),
    [aux_sym_record_type_token1] = ACTIONS(4253),
    [aux_sym_basic_type_token21] = ACTIONS(4253),
    [aux_sym_basic_type_token22] = ACTIONS(4253),
    [aux_sym_basic_type_token48] = ACTIONS(4253),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4253),
    [anon_sym_POUNDif] = ACTIONS(4255),
    [anon_sym_POUNDIF] = ACTIONS(4255),
    [anon_sym_POUNDIf] = ACTIONS(4255),
    [anon_sym_not] = ACTIONS(4253),
    [anon_sym_NOT] = ACTIONS(4253),
    [anon_sym_Not] = ACTIONS(4253),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4253),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4253),
    [anon_sym_PLUS] = ACTIONS(4255),
    [sym_datetime_literal] = ACTIONS(4255),
    [sym_date_literal] = ACTIONS(4253),
    [sym_time_literal] = ACTIONS(4253),
    [sym_biginteger_literal] = ACTIONS(4255),
    [anon_sym_if] = ACTIONS(4253),
    [anon_sym_IF] = ACTIONS(4253),
    [anon_sym_If] = ACTIONS(4253),
    [anon_sym_else] = ACTIONS(4253),
    [anon_sym_ELSE] = ACTIONS(4253),
    [anon_sym_Else] = ACTIONS(4253),
    [anon_sym_case] = ACTIONS(4253),
    [anon_sym_CASE] = ACTIONS(4253),
    [anon_sym_Case] = ACTIONS(4253),
    [anon_sym_for] = ACTIONS(4253),
    [anon_sym_FOR] = ACTIONS(4253),
    [anon_sym_For] = ACTIONS(4253),
    [anon_sym_foreach] = ACTIONS(4253),
    [anon_sym_FOREACH] = ACTIONS(4253),
    [anon_sym_Foreach] = ACTIONS(4253),
    [anon_sym_while] = ACTIONS(4253),
    [anon_sym_WHILE] = ACTIONS(4253),
    [anon_sym_While] = ACTIONS(4253),
    [anon_sym_repeat] = ACTIONS(4253),
    [anon_sym_REPEAT] = ACTIONS(4253),
    [anon_sym_Repeat] = ACTIONS(4253),
    [anon_sym_exit] = ACTIONS(4253),
    [anon_sym_EXIT] = ACTIONS(4253),
    [anon_sym_Exit] = ACTIONS(4253),
    [anon_sym_continue] = ACTIONS(4253),
    [anon_sym_CONTINUE] = ACTIONS(4253),
    [anon_sym_Continue] = ACTIONS(4253),
    [anon_sym_break] = ACTIONS(4253),
    [anon_sym_BREAK] = ACTIONS(4253),
    [anon_sym_Break] = ACTIONS(4253),
    [anon_sym_with] = ACTIONS(4253),
    [anon_sym_WITH] = ACTIONS(4253),
    [anon_sym_With] = ACTIONS(4253),
    [sym_asserterror_keyword] = ACTIONS(4255),
    [sym_page_keyword] = ACTIONS(4253),
    [anon_sym_codeunit] = ACTIONS(4253),
    [anon_sym_CODEUNIT] = ACTIONS(4253),
    [anon_sym_Codeunit] = ACTIONS(4253),
    [anon_sym_CodeUnit] = ACTIONS(4253),
    [anon_sym_COdeunit] = ACTIONS(4253),
    [anon_sym_codeUnit] = ACTIONS(4253),
    [sym_report_keyword] = ACTIONS(4253),
    [sym_query_keyword] = ACTIONS(4253),
    [anon_sym_xmlport] = ACTIONS(4253),
    [anon_sym_XMLPORT] = ACTIONS(4253),
    [anon_sym_Xmlport] = ACTIONS(4253),
    [anon_sym_XMLport] = ACTIONS(4253),
    [anon_sym_XMLPort] = ACTIONS(4253),
    [anon_sym_XmlPort] = ACTIONS(4253),
    [anon_sym_enum] = ACTIONS(4253),
    [anon_sym_ENUM] = ACTIONS(4253),
    [anon_sym_Enum] = ACTIONS(4253),
    [anon_sym_eNUM] = ACTIONS(4253),
    [anon_sym_eNum] = ACTIONS(4253),
    [anon_sym_ENum] = ACTIONS(4253),
    [sym_quoted_identifier] = ACTIONS(4255),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4255),
    [sym_integer] = ACTIONS(4253),
    [sym_continue_as_identifier] = ACTIONS(4255),
    [sym_preproc_open] = ACTIONS(4255),
    [sym_end_keyword] = ACTIONS(4255),
  },
  [STATE(2294)] = {
    [sym_identifier] = ACTIONS(4696),
    [anon_sym_SEMI] = ACTIONS(4698),
    [anon_sym_DASH] = ACTIONS(4698),
    [aux_sym_boolean_token1] = ACTIONS(4696),
    [aux_sym_boolean_token2] = ACTIONS(4696),
    [sym_decimal] = ACTIONS(4696),
    [anon_sym_LPAREN] = ACTIONS(4698),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4696),
    [anon_sym_LBRACK] = ACTIONS(4698),
    [aux_sym_record_type_token1] = ACTIONS(4696),
    [aux_sym_basic_type_token21] = ACTIONS(4696),
    [aux_sym_basic_type_token22] = ACTIONS(4696),
    [aux_sym_basic_type_token48] = ACTIONS(4696),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4696),
    [anon_sym_POUNDif] = ACTIONS(4698),
    [anon_sym_POUNDIF] = ACTIONS(4698),
    [anon_sym_POUNDIf] = ACTIONS(4698),
    [anon_sym_not] = ACTIONS(4696),
    [anon_sym_NOT] = ACTIONS(4696),
    [anon_sym_Not] = ACTIONS(4696),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4696),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4696),
    [anon_sym_PLUS] = ACTIONS(4698),
    [sym_datetime_literal] = ACTIONS(4698),
    [sym_date_literal] = ACTIONS(4696),
    [sym_time_literal] = ACTIONS(4696),
    [sym_biginteger_literal] = ACTIONS(4698),
    [anon_sym_if] = ACTIONS(4696),
    [anon_sym_IF] = ACTIONS(4696),
    [anon_sym_If] = ACTIONS(4696),
    [anon_sym_else] = ACTIONS(4696),
    [anon_sym_ELSE] = ACTIONS(4696),
    [anon_sym_Else] = ACTIONS(4696),
    [anon_sym_case] = ACTIONS(4696),
    [anon_sym_CASE] = ACTIONS(4696),
    [anon_sym_Case] = ACTIONS(4696),
    [anon_sym_for] = ACTIONS(4696),
    [anon_sym_FOR] = ACTIONS(4696),
    [anon_sym_For] = ACTIONS(4696),
    [anon_sym_foreach] = ACTIONS(4696),
    [anon_sym_FOREACH] = ACTIONS(4696),
    [anon_sym_Foreach] = ACTIONS(4696),
    [anon_sym_while] = ACTIONS(4696),
    [anon_sym_WHILE] = ACTIONS(4696),
    [anon_sym_While] = ACTIONS(4696),
    [anon_sym_repeat] = ACTIONS(4696),
    [anon_sym_REPEAT] = ACTIONS(4696),
    [anon_sym_Repeat] = ACTIONS(4696),
    [anon_sym_exit] = ACTIONS(4696),
    [anon_sym_EXIT] = ACTIONS(4696),
    [anon_sym_Exit] = ACTIONS(4696),
    [anon_sym_continue] = ACTIONS(4696),
    [anon_sym_CONTINUE] = ACTIONS(4696),
    [anon_sym_Continue] = ACTIONS(4696),
    [anon_sym_break] = ACTIONS(4696),
    [anon_sym_BREAK] = ACTIONS(4696),
    [anon_sym_Break] = ACTIONS(4696),
    [anon_sym_with] = ACTIONS(4696),
    [anon_sym_WITH] = ACTIONS(4696),
    [anon_sym_With] = ACTIONS(4696),
    [sym_asserterror_keyword] = ACTIONS(4698),
    [sym_page_keyword] = ACTIONS(4696),
    [anon_sym_codeunit] = ACTIONS(4696),
    [anon_sym_CODEUNIT] = ACTIONS(4696),
    [anon_sym_Codeunit] = ACTIONS(4696),
    [anon_sym_CodeUnit] = ACTIONS(4696),
    [anon_sym_COdeunit] = ACTIONS(4696),
    [anon_sym_codeUnit] = ACTIONS(4696),
    [sym_report_keyword] = ACTIONS(4696),
    [sym_query_keyword] = ACTIONS(4696),
    [anon_sym_xmlport] = ACTIONS(4696),
    [anon_sym_XMLPORT] = ACTIONS(4696),
    [anon_sym_Xmlport] = ACTIONS(4696),
    [anon_sym_XMLport] = ACTIONS(4696),
    [anon_sym_XMLPort] = ACTIONS(4696),
    [anon_sym_XmlPort] = ACTIONS(4696),
    [anon_sym_enum] = ACTIONS(4696),
    [anon_sym_ENUM] = ACTIONS(4696),
    [anon_sym_Enum] = ACTIONS(4696),
    [anon_sym_eNUM] = ACTIONS(4696),
    [anon_sym_eNum] = ACTIONS(4696),
    [anon_sym_ENum] = ACTIONS(4696),
    [sym_quoted_identifier] = ACTIONS(4698),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4698),
    [sym_integer] = ACTIONS(4696),
    [sym_continue_as_identifier] = ACTIONS(4698),
    [sym_preproc_open] = ACTIONS(4698),
    [sym_end_keyword] = ACTIONS(4698),
  },
  [STATE(2295)] = {
    [sym_identifier] = ACTIONS(4696),
    [anon_sym_SEMI] = ACTIONS(4698),
    [anon_sym_DASH] = ACTIONS(4698),
    [aux_sym_boolean_token1] = ACTIONS(4696),
    [aux_sym_boolean_token2] = ACTIONS(4696),
    [sym_decimal] = ACTIONS(4696),
    [anon_sym_LPAREN] = ACTIONS(4698),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4696),
    [anon_sym_LBRACK] = ACTIONS(4698),
    [aux_sym_record_type_token1] = ACTIONS(4696),
    [aux_sym_basic_type_token21] = ACTIONS(4696),
    [aux_sym_basic_type_token22] = ACTIONS(4696),
    [aux_sym_basic_type_token48] = ACTIONS(4696),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4696),
    [anon_sym_POUNDif] = ACTIONS(4698),
    [anon_sym_POUNDIF] = ACTIONS(4698),
    [anon_sym_POUNDIf] = ACTIONS(4698),
    [anon_sym_not] = ACTIONS(4696),
    [anon_sym_NOT] = ACTIONS(4696),
    [anon_sym_Not] = ACTIONS(4696),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4696),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4696),
    [anon_sym_PLUS] = ACTIONS(4698),
    [sym_datetime_literal] = ACTIONS(4698),
    [sym_date_literal] = ACTIONS(4696),
    [sym_time_literal] = ACTIONS(4696),
    [sym_biginteger_literal] = ACTIONS(4698),
    [anon_sym_if] = ACTIONS(4696),
    [anon_sym_IF] = ACTIONS(4696),
    [anon_sym_If] = ACTIONS(4696),
    [anon_sym_else] = ACTIONS(4696),
    [anon_sym_ELSE] = ACTIONS(4696),
    [anon_sym_Else] = ACTIONS(4696),
    [anon_sym_case] = ACTIONS(4696),
    [anon_sym_CASE] = ACTIONS(4696),
    [anon_sym_Case] = ACTIONS(4696),
    [anon_sym_for] = ACTIONS(4696),
    [anon_sym_FOR] = ACTIONS(4696),
    [anon_sym_For] = ACTIONS(4696),
    [anon_sym_foreach] = ACTIONS(4696),
    [anon_sym_FOREACH] = ACTIONS(4696),
    [anon_sym_Foreach] = ACTIONS(4696),
    [anon_sym_while] = ACTIONS(4696),
    [anon_sym_WHILE] = ACTIONS(4696),
    [anon_sym_While] = ACTIONS(4696),
    [anon_sym_repeat] = ACTIONS(4696),
    [anon_sym_REPEAT] = ACTIONS(4696),
    [anon_sym_Repeat] = ACTIONS(4696),
    [anon_sym_exit] = ACTIONS(4696),
    [anon_sym_EXIT] = ACTIONS(4696),
    [anon_sym_Exit] = ACTIONS(4696),
    [anon_sym_continue] = ACTIONS(4696),
    [anon_sym_CONTINUE] = ACTIONS(4696),
    [anon_sym_Continue] = ACTIONS(4696),
    [anon_sym_break] = ACTIONS(4696),
    [anon_sym_BREAK] = ACTIONS(4696),
    [anon_sym_Break] = ACTIONS(4696),
    [anon_sym_with] = ACTIONS(4696),
    [anon_sym_WITH] = ACTIONS(4696),
    [anon_sym_With] = ACTIONS(4696),
    [sym_asserterror_keyword] = ACTIONS(4698),
    [sym_page_keyword] = ACTIONS(4696),
    [anon_sym_codeunit] = ACTIONS(4696),
    [anon_sym_CODEUNIT] = ACTIONS(4696),
    [anon_sym_Codeunit] = ACTIONS(4696),
    [anon_sym_CodeUnit] = ACTIONS(4696),
    [anon_sym_COdeunit] = ACTIONS(4696),
    [anon_sym_codeUnit] = ACTIONS(4696),
    [sym_report_keyword] = ACTIONS(4696),
    [sym_query_keyword] = ACTIONS(4696),
    [anon_sym_xmlport] = ACTIONS(4696),
    [anon_sym_XMLPORT] = ACTIONS(4696),
    [anon_sym_Xmlport] = ACTIONS(4696),
    [anon_sym_XMLport] = ACTIONS(4696),
    [anon_sym_XMLPort] = ACTIONS(4696),
    [anon_sym_XmlPort] = ACTIONS(4696),
    [anon_sym_enum] = ACTIONS(4696),
    [anon_sym_ENUM] = ACTIONS(4696),
    [anon_sym_Enum] = ACTIONS(4696),
    [anon_sym_eNUM] = ACTIONS(4696),
    [anon_sym_eNum] = ACTIONS(4696),
    [anon_sym_ENum] = ACTIONS(4696),
    [sym_quoted_identifier] = ACTIONS(4698),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4698),
    [sym_integer] = ACTIONS(4696),
    [sym_continue_as_identifier] = ACTIONS(4698),
    [sym_preproc_open] = ACTIONS(4698),
    [sym_end_keyword] = ACTIONS(4698),
  },
  [STATE(2296)] = {
    [sym_identifier] = ACTIONS(4563),
    [anon_sym_SEMI] = ACTIONS(4565),
    [anon_sym_DASH] = ACTIONS(4565),
    [aux_sym_boolean_token1] = ACTIONS(4563),
    [aux_sym_boolean_token2] = ACTIONS(4563),
    [sym_decimal] = ACTIONS(4563),
    [anon_sym_LPAREN] = ACTIONS(4565),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4563),
    [anon_sym_LBRACK] = ACTIONS(4565),
    [aux_sym_record_type_token1] = ACTIONS(4563),
    [aux_sym_basic_type_token21] = ACTIONS(4563),
    [aux_sym_basic_type_token22] = ACTIONS(4563),
    [aux_sym_basic_type_token48] = ACTIONS(4563),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4563),
    [anon_sym_POUNDif] = ACTIONS(4565),
    [anon_sym_POUNDIF] = ACTIONS(4565),
    [anon_sym_POUNDIf] = ACTIONS(4565),
    [anon_sym_not] = ACTIONS(4563),
    [anon_sym_NOT] = ACTIONS(4563),
    [anon_sym_Not] = ACTIONS(4563),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4563),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4563),
    [anon_sym_PLUS] = ACTIONS(4565),
    [sym_datetime_literal] = ACTIONS(4565),
    [sym_date_literal] = ACTIONS(4563),
    [sym_time_literal] = ACTIONS(4563),
    [sym_biginteger_literal] = ACTIONS(4565),
    [anon_sym_if] = ACTIONS(4563),
    [anon_sym_IF] = ACTIONS(4563),
    [anon_sym_If] = ACTIONS(4563),
    [anon_sym_else] = ACTIONS(4563),
    [anon_sym_ELSE] = ACTIONS(4563),
    [anon_sym_Else] = ACTIONS(4563),
    [anon_sym_case] = ACTIONS(4563),
    [anon_sym_CASE] = ACTIONS(4563),
    [anon_sym_Case] = ACTIONS(4563),
    [anon_sym_for] = ACTIONS(4563),
    [anon_sym_FOR] = ACTIONS(4563),
    [anon_sym_For] = ACTIONS(4563),
    [anon_sym_foreach] = ACTIONS(4563),
    [anon_sym_FOREACH] = ACTIONS(4563),
    [anon_sym_Foreach] = ACTIONS(4563),
    [anon_sym_while] = ACTIONS(4563),
    [anon_sym_WHILE] = ACTIONS(4563),
    [anon_sym_While] = ACTIONS(4563),
    [anon_sym_repeat] = ACTIONS(4563),
    [anon_sym_REPEAT] = ACTIONS(4563),
    [anon_sym_Repeat] = ACTIONS(4563),
    [anon_sym_exit] = ACTIONS(4563),
    [anon_sym_EXIT] = ACTIONS(4563),
    [anon_sym_Exit] = ACTIONS(4563),
    [anon_sym_continue] = ACTIONS(4563),
    [anon_sym_CONTINUE] = ACTIONS(4563),
    [anon_sym_Continue] = ACTIONS(4563),
    [anon_sym_break] = ACTIONS(4563),
    [anon_sym_BREAK] = ACTIONS(4563),
    [anon_sym_Break] = ACTIONS(4563),
    [anon_sym_with] = ACTIONS(4563),
    [anon_sym_WITH] = ACTIONS(4563),
    [anon_sym_With] = ACTIONS(4563),
    [sym_asserterror_keyword] = ACTIONS(4565),
    [sym_page_keyword] = ACTIONS(4563),
    [anon_sym_codeunit] = ACTIONS(4563),
    [anon_sym_CODEUNIT] = ACTIONS(4563),
    [anon_sym_Codeunit] = ACTIONS(4563),
    [anon_sym_CodeUnit] = ACTIONS(4563),
    [anon_sym_COdeunit] = ACTIONS(4563),
    [anon_sym_codeUnit] = ACTIONS(4563),
    [sym_report_keyword] = ACTIONS(4563),
    [sym_query_keyword] = ACTIONS(4563),
    [anon_sym_xmlport] = ACTIONS(4563),
    [anon_sym_XMLPORT] = ACTIONS(4563),
    [anon_sym_Xmlport] = ACTIONS(4563),
    [anon_sym_XMLport] = ACTIONS(4563),
    [anon_sym_XMLPort] = ACTIONS(4563),
    [anon_sym_XmlPort] = ACTIONS(4563),
    [anon_sym_enum] = ACTIONS(4563),
    [anon_sym_ENUM] = ACTIONS(4563),
    [anon_sym_Enum] = ACTIONS(4563),
    [anon_sym_eNUM] = ACTIONS(4563),
    [anon_sym_eNum] = ACTIONS(4563),
    [anon_sym_ENum] = ACTIONS(4563),
    [sym_quoted_identifier] = ACTIONS(4565),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4565),
    [sym_integer] = ACTIONS(4563),
    [sym_continue_as_identifier] = ACTIONS(4565),
    [sym_preproc_open] = ACTIONS(4565),
    [sym_end_keyword] = ACTIONS(4565),
  },
  [STATE(2297)] = {
    [sym_identifier] = ACTIONS(4748),
    [anon_sym_SEMI] = ACTIONS(4750),
    [anon_sym_DASH] = ACTIONS(4750),
    [aux_sym_boolean_token1] = ACTIONS(4748),
    [aux_sym_boolean_token2] = ACTIONS(4748),
    [sym_decimal] = ACTIONS(4748),
    [anon_sym_LPAREN] = ACTIONS(4750),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4748),
    [anon_sym_LBRACK] = ACTIONS(4750),
    [aux_sym_record_type_token1] = ACTIONS(4748),
    [aux_sym_basic_type_token21] = ACTIONS(4748),
    [aux_sym_basic_type_token22] = ACTIONS(4748),
    [aux_sym_basic_type_token48] = ACTIONS(4748),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4748),
    [anon_sym_POUNDif] = ACTIONS(4750),
    [anon_sym_POUNDIF] = ACTIONS(4750),
    [anon_sym_POUNDIf] = ACTIONS(4750),
    [anon_sym_not] = ACTIONS(4748),
    [anon_sym_NOT] = ACTIONS(4748),
    [anon_sym_Not] = ACTIONS(4748),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4748),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4748),
    [anon_sym_PLUS] = ACTIONS(4750),
    [sym_datetime_literal] = ACTIONS(4750),
    [sym_date_literal] = ACTIONS(4748),
    [sym_time_literal] = ACTIONS(4748),
    [sym_biginteger_literal] = ACTIONS(4750),
    [anon_sym_if] = ACTIONS(4748),
    [anon_sym_IF] = ACTIONS(4748),
    [anon_sym_If] = ACTIONS(4748),
    [anon_sym_else] = ACTIONS(4748),
    [anon_sym_ELSE] = ACTIONS(4748),
    [anon_sym_Else] = ACTIONS(4748),
    [anon_sym_case] = ACTIONS(4748),
    [anon_sym_CASE] = ACTIONS(4748),
    [anon_sym_Case] = ACTIONS(4748),
    [anon_sym_for] = ACTIONS(4748),
    [anon_sym_FOR] = ACTIONS(4748),
    [anon_sym_For] = ACTIONS(4748),
    [anon_sym_foreach] = ACTIONS(4748),
    [anon_sym_FOREACH] = ACTIONS(4748),
    [anon_sym_Foreach] = ACTIONS(4748),
    [anon_sym_while] = ACTIONS(4748),
    [anon_sym_WHILE] = ACTIONS(4748),
    [anon_sym_While] = ACTIONS(4748),
    [anon_sym_repeat] = ACTIONS(4748),
    [anon_sym_REPEAT] = ACTIONS(4748),
    [anon_sym_Repeat] = ACTIONS(4748),
    [anon_sym_exit] = ACTIONS(4748),
    [anon_sym_EXIT] = ACTIONS(4748),
    [anon_sym_Exit] = ACTIONS(4748),
    [anon_sym_continue] = ACTIONS(4748),
    [anon_sym_CONTINUE] = ACTIONS(4748),
    [anon_sym_Continue] = ACTIONS(4748),
    [anon_sym_break] = ACTIONS(4748),
    [anon_sym_BREAK] = ACTIONS(4748),
    [anon_sym_Break] = ACTIONS(4748),
    [anon_sym_with] = ACTIONS(4748),
    [anon_sym_WITH] = ACTIONS(4748),
    [anon_sym_With] = ACTIONS(4748),
    [sym_asserterror_keyword] = ACTIONS(4750),
    [sym_page_keyword] = ACTIONS(4748),
    [anon_sym_codeunit] = ACTIONS(4748),
    [anon_sym_CODEUNIT] = ACTIONS(4748),
    [anon_sym_Codeunit] = ACTIONS(4748),
    [anon_sym_CodeUnit] = ACTIONS(4748),
    [anon_sym_COdeunit] = ACTIONS(4748),
    [anon_sym_codeUnit] = ACTIONS(4748),
    [sym_report_keyword] = ACTIONS(4748),
    [sym_query_keyword] = ACTIONS(4748),
    [anon_sym_xmlport] = ACTIONS(4748),
    [anon_sym_XMLPORT] = ACTIONS(4748),
    [anon_sym_Xmlport] = ACTIONS(4748),
    [anon_sym_XMLport] = ACTIONS(4748),
    [anon_sym_XMLPort] = ACTIONS(4748),
    [anon_sym_XmlPort] = ACTIONS(4748),
    [anon_sym_enum] = ACTIONS(4748),
    [anon_sym_ENUM] = ACTIONS(4748),
    [anon_sym_Enum] = ACTIONS(4748),
    [anon_sym_eNUM] = ACTIONS(4748),
    [anon_sym_eNum] = ACTIONS(4748),
    [anon_sym_ENum] = ACTIONS(4748),
    [sym_quoted_identifier] = ACTIONS(4750),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4750),
    [sym_integer] = ACTIONS(4748),
    [sym_continue_as_identifier] = ACTIONS(4750),
    [sym_preproc_open] = ACTIONS(4750),
    [sym_end_keyword] = ACTIONS(4750),
  },
  [STATE(2298)] = {
    [sym_identifier] = ACTIONS(4399),
    [anon_sym_SEMI] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [aux_sym_boolean_token1] = ACTIONS(4399),
    [aux_sym_boolean_token2] = ACTIONS(4399),
    [sym_decimal] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4401),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4399),
    [anon_sym_LBRACK] = ACTIONS(4401),
    [aux_sym_record_type_token1] = ACTIONS(4399),
    [aux_sym_basic_type_token21] = ACTIONS(4399),
    [aux_sym_basic_type_token22] = ACTIONS(4399),
    [aux_sym_basic_type_token48] = ACTIONS(4399),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4399),
    [anon_sym_POUNDif] = ACTIONS(4401),
    [anon_sym_POUNDIF] = ACTIONS(4401),
    [anon_sym_POUNDIf] = ACTIONS(4401),
    [anon_sym_not] = ACTIONS(4399),
    [anon_sym_NOT] = ACTIONS(4399),
    [anon_sym_Not] = ACTIONS(4399),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4399),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [sym_datetime_literal] = ACTIONS(4401),
    [sym_date_literal] = ACTIONS(4399),
    [sym_time_literal] = ACTIONS(4399),
    [sym_biginteger_literal] = ACTIONS(4401),
    [anon_sym_if] = ACTIONS(4399),
    [anon_sym_IF] = ACTIONS(4399),
    [anon_sym_If] = ACTIONS(4399),
    [anon_sym_else] = ACTIONS(4399),
    [anon_sym_ELSE] = ACTIONS(4399),
    [anon_sym_Else] = ACTIONS(4399),
    [anon_sym_case] = ACTIONS(4399),
    [anon_sym_CASE] = ACTIONS(4399),
    [anon_sym_Case] = ACTIONS(4399),
    [anon_sym_for] = ACTIONS(4399),
    [anon_sym_FOR] = ACTIONS(4399),
    [anon_sym_For] = ACTIONS(4399),
    [anon_sym_foreach] = ACTIONS(4399),
    [anon_sym_FOREACH] = ACTIONS(4399),
    [anon_sym_Foreach] = ACTIONS(4399),
    [anon_sym_while] = ACTIONS(4399),
    [anon_sym_WHILE] = ACTIONS(4399),
    [anon_sym_While] = ACTIONS(4399),
    [anon_sym_repeat] = ACTIONS(4399),
    [anon_sym_REPEAT] = ACTIONS(4399),
    [anon_sym_Repeat] = ACTIONS(4399),
    [anon_sym_exit] = ACTIONS(4399),
    [anon_sym_EXIT] = ACTIONS(4399),
    [anon_sym_Exit] = ACTIONS(4399),
    [anon_sym_continue] = ACTIONS(4399),
    [anon_sym_CONTINUE] = ACTIONS(4399),
    [anon_sym_Continue] = ACTIONS(4399),
    [anon_sym_break] = ACTIONS(4399),
    [anon_sym_BREAK] = ACTIONS(4399),
    [anon_sym_Break] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4399),
    [anon_sym_WITH] = ACTIONS(4399),
    [anon_sym_With] = ACTIONS(4399),
    [sym_asserterror_keyword] = ACTIONS(4401),
    [sym_page_keyword] = ACTIONS(4399),
    [anon_sym_codeunit] = ACTIONS(4399),
    [anon_sym_CODEUNIT] = ACTIONS(4399),
    [anon_sym_Codeunit] = ACTIONS(4399),
    [anon_sym_CodeUnit] = ACTIONS(4399),
    [anon_sym_COdeunit] = ACTIONS(4399),
    [anon_sym_codeUnit] = ACTIONS(4399),
    [sym_report_keyword] = ACTIONS(4399),
    [sym_query_keyword] = ACTIONS(4399),
    [anon_sym_xmlport] = ACTIONS(4399),
    [anon_sym_XMLPORT] = ACTIONS(4399),
    [anon_sym_Xmlport] = ACTIONS(4399),
    [anon_sym_XMLport] = ACTIONS(4399),
    [anon_sym_XMLPort] = ACTIONS(4399),
    [anon_sym_XmlPort] = ACTIONS(4399),
    [anon_sym_enum] = ACTIONS(4399),
    [anon_sym_ENUM] = ACTIONS(4399),
    [anon_sym_Enum] = ACTIONS(4399),
    [anon_sym_eNUM] = ACTIONS(4399),
    [anon_sym_eNum] = ACTIONS(4399),
    [anon_sym_ENum] = ACTIONS(4399),
    [sym_quoted_identifier] = ACTIONS(4401),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4401),
    [sym_integer] = ACTIONS(4399),
    [sym_continue_as_identifier] = ACTIONS(4401),
    [sym_preproc_open] = ACTIONS(4401),
    [sym_end_keyword] = ACTIONS(4401),
  },
  [STATE(2299)] = {
    [sym_identifier] = ACTIONS(4257),
    [anon_sym_SEMI] = ACTIONS(4259),
    [anon_sym_DASH] = ACTIONS(4259),
    [aux_sym_boolean_token1] = ACTIONS(4257),
    [aux_sym_boolean_token2] = ACTIONS(4257),
    [sym_decimal] = ACTIONS(4257),
    [anon_sym_LPAREN] = ACTIONS(4259),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4257),
    [anon_sym_LBRACK] = ACTIONS(4259),
    [aux_sym_record_type_token1] = ACTIONS(4257),
    [aux_sym_basic_type_token21] = ACTIONS(4257),
    [aux_sym_basic_type_token22] = ACTIONS(4257),
    [aux_sym_basic_type_token48] = ACTIONS(4257),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4257),
    [anon_sym_POUNDif] = ACTIONS(4259),
    [anon_sym_POUNDIF] = ACTIONS(4259),
    [anon_sym_POUNDIf] = ACTIONS(4259),
    [anon_sym_not] = ACTIONS(4257),
    [anon_sym_NOT] = ACTIONS(4257),
    [anon_sym_Not] = ACTIONS(4257),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4257),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4257),
    [anon_sym_PLUS] = ACTIONS(4259),
    [sym_datetime_literal] = ACTIONS(4259),
    [sym_date_literal] = ACTIONS(4257),
    [sym_time_literal] = ACTIONS(4257),
    [sym_biginteger_literal] = ACTIONS(4259),
    [anon_sym_if] = ACTIONS(4257),
    [anon_sym_IF] = ACTIONS(4257),
    [anon_sym_If] = ACTIONS(4257),
    [anon_sym_else] = ACTIONS(4257),
    [anon_sym_ELSE] = ACTIONS(4257),
    [anon_sym_Else] = ACTIONS(4257),
    [anon_sym_case] = ACTIONS(4257),
    [anon_sym_CASE] = ACTIONS(4257),
    [anon_sym_Case] = ACTIONS(4257),
    [anon_sym_for] = ACTIONS(4257),
    [anon_sym_FOR] = ACTIONS(4257),
    [anon_sym_For] = ACTIONS(4257),
    [anon_sym_foreach] = ACTIONS(4257),
    [anon_sym_FOREACH] = ACTIONS(4257),
    [anon_sym_Foreach] = ACTIONS(4257),
    [anon_sym_while] = ACTIONS(4257),
    [anon_sym_WHILE] = ACTIONS(4257),
    [anon_sym_While] = ACTIONS(4257),
    [anon_sym_repeat] = ACTIONS(4257),
    [anon_sym_REPEAT] = ACTIONS(4257),
    [anon_sym_Repeat] = ACTIONS(4257),
    [anon_sym_exit] = ACTIONS(4257),
    [anon_sym_EXIT] = ACTIONS(4257),
    [anon_sym_Exit] = ACTIONS(4257),
    [anon_sym_continue] = ACTIONS(4257),
    [anon_sym_CONTINUE] = ACTIONS(4257),
    [anon_sym_Continue] = ACTIONS(4257),
    [anon_sym_break] = ACTIONS(4257),
    [anon_sym_BREAK] = ACTIONS(4257),
    [anon_sym_Break] = ACTIONS(4257),
    [anon_sym_with] = ACTIONS(4257),
    [anon_sym_WITH] = ACTIONS(4257),
    [anon_sym_With] = ACTIONS(4257),
    [sym_asserterror_keyword] = ACTIONS(4259),
    [sym_page_keyword] = ACTIONS(4257),
    [anon_sym_codeunit] = ACTIONS(4257),
    [anon_sym_CODEUNIT] = ACTIONS(4257),
    [anon_sym_Codeunit] = ACTIONS(4257),
    [anon_sym_CodeUnit] = ACTIONS(4257),
    [anon_sym_COdeunit] = ACTIONS(4257),
    [anon_sym_codeUnit] = ACTIONS(4257),
    [sym_report_keyword] = ACTIONS(4257),
    [sym_query_keyword] = ACTIONS(4257),
    [anon_sym_xmlport] = ACTIONS(4257),
    [anon_sym_XMLPORT] = ACTIONS(4257),
    [anon_sym_Xmlport] = ACTIONS(4257),
    [anon_sym_XMLport] = ACTIONS(4257),
    [anon_sym_XMLPort] = ACTIONS(4257),
    [anon_sym_XmlPort] = ACTIONS(4257),
    [anon_sym_enum] = ACTIONS(4257),
    [anon_sym_ENUM] = ACTIONS(4257),
    [anon_sym_Enum] = ACTIONS(4257),
    [anon_sym_eNUM] = ACTIONS(4257),
    [anon_sym_eNum] = ACTIONS(4257),
    [anon_sym_ENum] = ACTIONS(4257),
    [sym_quoted_identifier] = ACTIONS(4259),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4259),
    [sym_integer] = ACTIONS(4257),
    [sym_continue_as_identifier] = ACTIONS(4259),
    [sym_preproc_open] = ACTIONS(4259),
    [sym_end_keyword] = ACTIONS(4259),
  },
  [STATE(2300)] = {
    [sym_identifier] = ACTIONS(4261),
    [anon_sym_SEMI] = ACTIONS(4263),
    [anon_sym_DASH] = ACTIONS(4263),
    [aux_sym_boolean_token1] = ACTIONS(4261),
    [aux_sym_boolean_token2] = ACTIONS(4261),
    [sym_decimal] = ACTIONS(4261),
    [anon_sym_LPAREN] = ACTIONS(4263),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4261),
    [anon_sym_LBRACK] = ACTIONS(4263),
    [aux_sym_record_type_token1] = ACTIONS(4261),
    [aux_sym_basic_type_token21] = ACTIONS(4261),
    [aux_sym_basic_type_token22] = ACTIONS(4261),
    [aux_sym_basic_type_token48] = ACTIONS(4261),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4261),
    [anon_sym_POUNDif] = ACTIONS(4263),
    [anon_sym_POUNDIF] = ACTIONS(4263),
    [anon_sym_POUNDIf] = ACTIONS(4263),
    [anon_sym_not] = ACTIONS(4261),
    [anon_sym_NOT] = ACTIONS(4261),
    [anon_sym_Not] = ACTIONS(4261),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4261),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4261),
    [anon_sym_PLUS] = ACTIONS(4263),
    [sym_datetime_literal] = ACTIONS(4263),
    [sym_date_literal] = ACTIONS(4261),
    [sym_time_literal] = ACTIONS(4261),
    [sym_biginteger_literal] = ACTIONS(4263),
    [anon_sym_if] = ACTIONS(4261),
    [anon_sym_IF] = ACTIONS(4261),
    [anon_sym_If] = ACTIONS(4261),
    [anon_sym_else] = ACTIONS(4261),
    [anon_sym_ELSE] = ACTIONS(4261),
    [anon_sym_Else] = ACTIONS(4261),
    [anon_sym_case] = ACTIONS(4261),
    [anon_sym_CASE] = ACTIONS(4261),
    [anon_sym_Case] = ACTIONS(4261),
    [anon_sym_for] = ACTIONS(4261),
    [anon_sym_FOR] = ACTIONS(4261),
    [anon_sym_For] = ACTIONS(4261),
    [anon_sym_foreach] = ACTIONS(4261),
    [anon_sym_FOREACH] = ACTIONS(4261),
    [anon_sym_Foreach] = ACTIONS(4261),
    [anon_sym_while] = ACTIONS(4261),
    [anon_sym_WHILE] = ACTIONS(4261),
    [anon_sym_While] = ACTIONS(4261),
    [anon_sym_repeat] = ACTIONS(4261),
    [anon_sym_REPEAT] = ACTIONS(4261),
    [anon_sym_Repeat] = ACTIONS(4261),
    [anon_sym_exit] = ACTIONS(4261),
    [anon_sym_EXIT] = ACTIONS(4261),
    [anon_sym_Exit] = ACTIONS(4261),
    [anon_sym_continue] = ACTIONS(4261),
    [anon_sym_CONTINUE] = ACTIONS(4261),
    [anon_sym_Continue] = ACTIONS(4261),
    [anon_sym_break] = ACTIONS(4261),
    [anon_sym_BREAK] = ACTIONS(4261),
    [anon_sym_Break] = ACTIONS(4261),
    [anon_sym_with] = ACTIONS(4261),
    [anon_sym_WITH] = ACTIONS(4261),
    [anon_sym_With] = ACTIONS(4261),
    [sym_asserterror_keyword] = ACTIONS(4263),
    [sym_page_keyword] = ACTIONS(4261),
    [anon_sym_codeunit] = ACTIONS(4261),
    [anon_sym_CODEUNIT] = ACTIONS(4261),
    [anon_sym_Codeunit] = ACTIONS(4261),
    [anon_sym_CodeUnit] = ACTIONS(4261),
    [anon_sym_COdeunit] = ACTIONS(4261),
    [anon_sym_codeUnit] = ACTIONS(4261),
    [sym_report_keyword] = ACTIONS(4261),
    [sym_query_keyword] = ACTIONS(4261),
    [anon_sym_xmlport] = ACTIONS(4261),
    [anon_sym_XMLPORT] = ACTIONS(4261),
    [anon_sym_Xmlport] = ACTIONS(4261),
    [anon_sym_XMLport] = ACTIONS(4261),
    [anon_sym_XMLPort] = ACTIONS(4261),
    [anon_sym_XmlPort] = ACTIONS(4261),
    [anon_sym_enum] = ACTIONS(4261),
    [anon_sym_ENUM] = ACTIONS(4261),
    [anon_sym_Enum] = ACTIONS(4261),
    [anon_sym_eNUM] = ACTIONS(4261),
    [anon_sym_eNum] = ACTIONS(4261),
    [anon_sym_ENum] = ACTIONS(4261),
    [sym_quoted_identifier] = ACTIONS(4263),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4263),
    [sym_integer] = ACTIONS(4261),
    [sym_continue_as_identifier] = ACTIONS(4263),
    [sym_preproc_open] = ACTIONS(4263),
    [sym_end_keyword] = ACTIONS(4263),
  },
  [STATE(2301)] = {
    [sym_identifier] = ACTIONS(4634),
    [anon_sym_SEMI] = ACTIONS(4636),
    [anon_sym_DASH] = ACTIONS(4636),
    [aux_sym_boolean_token1] = ACTIONS(4634),
    [aux_sym_boolean_token2] = ACTIONS(4634),
    [sym_decimal] = ACTIONS(4634),
    [anon_sym_LPAREN] = ACTIONS(4636),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4634),
    [anon_sym_LBRACK] = ACTIONS(4636),
    [aux_sym_record_type_token1] = ACTIONS(4634),
    [aux_sym_basic_type_token21] = ACTIONS(4634),
    [aux_sym_basic_type_token22] = ACTIONS(4634),
    [aux_sym_basic_type_token48] = ACTIONS(4634),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4634),
    [anon_sym_POUNDif] = ACTIONS(4636),
    [anon_sym_POUNDIF] = ACTIONS(4636),
    [anon_sym_POUNDIf] = ACTIONS(4636),
    [anon_sym_not] = ACTIONS(4634),
    [anon_sym_NOT] = ACTIONS(4634),
    [anon_sym_Not] = ACTIONS(4634),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4634),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4634),
    [anon_sym_PLUS] = ACTIONS(4636),
    [sym_datetime_literal] = ACTIONS(4636),
    [sym_date_literal] = ACTIONS(4634),
    [sym_time_literal] = ACTIONS(4634),
    [sym_biginteger_literal] = ACTIONS(4636),
    [anon_sym_if] = ACTIONS(4634),
    [anon_sym_IF] = ACTIONS(4634),
    [anon_sym_If] = ACTIONS(4634),
    [anon_sym_else] = ACTIONS(4634),
    [anon_sym_ELSE] = ACTIONS(4634),
    [anon_sym_Else] = ACTIONS(4634),
    [anon_sym_case] = ACTIONS(4634),
    [anon_sym_CASE] = ACTIONS(4634),
    [anon_sym_Case] = ACTIONS(4634),
    [anon_sym_for] = ACTIONS(4634),
    [anon_sym_FOR] = ACTIONS(4634),
    [anon_sym_For] = ACTIONS(4634),
    [anon_sym_foreach] = ACTIONS(4634),
    [anon_sym_FOREACH] = ACTIONS(4634),
    [anon_sym_Foreach] = ACTIONS(4634),
    [anon_sym_while] = ACTIONS(4634),
    [anon_sym_WHILE] = ACTIONS(4634),
    [anon_sym_While] = ACTIONS(4634),
    [anon_sym_repeat] = ACTIONS(4634),
    [anon_sym_REPEAT] = ACTIONS(4634),
    [anon_sym_Repeat] = ACTIONS(4634),
    [anon_sym_exit] = ACTIONS(4634),
    [anon_sym_EXIT] = ACTIONS(4634),
    [anon_sym_Exit] = ACTIONS(4634),
    [anon_sym_continue] = ACTIONS(4634),
    [anon_sym_CONTINUE] = ACTIONS(4634),
    [anon_sym_Continue] = ACTIONS(4634),
    [anon_sym_break] = ACTIONS(4634),
    [anon_sym_BREAK] = ACTIONS(4634),
    [anon_sym_Break] = ACTIONS(4634),
    [anon_sym_with] = ACTIONS(4634),
    [anon_sym_WITH] = ACTIONS(4634),
    [anon_sym_With] = ACTIONS(4634),
    [sym_asserterror_keyword] = ACTIONS(4636),
    [sym_page_keyword] = ACTIONS(4634),
    [anon_sym_codeunit] = ACTIONS(4634),
    [anon_sym_CODEUNIT] = ACTIONS(4634),
    [anon_sym_Codeunit] = ACTIONS(4634),
    [anon_sym_CodeUnit] = ACTIONS(4634),
    [anon_sym_COdeunit] = ACTIONS(4634),
    [anon_sym_codeUnit] = ACTIONS(4634),
    [sym_report_keyword] = ACTIONS(4634),
    [sym_query_keyword] = ACTIONS(4634),
    [anon_sym_xmlport] = ACTIONS(4634),
    [anon_sym_XMLPORT] = ACTIONS(4634),
    [anon_sym_Xmlport] = ACTIONS(4634),
    [anon_sym_XMLport] = ACTIONS(4634),
    [anon_sym_XMLPort] = ACTIONS(4634),
    [anon_sym_XmlPort] = ACTIONS(4634),
    [anon_sym_enum] = ACTIONS(4634),
    [anon_sym_ENUM] = ACTIONS(4634),
    [anon_sym_Enum] = ACTIONS(4634),
    [anon_sym_eNUM] = ACTIONS(4634),
    [anon_sym_eNum] = ACTIONS(4634),
    [anon_sym_ENum] = ACTIONS(4634),
    [sym_quoted_identifier] = ACTIONS(4636),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4636),
    [sym_integer] = ACTIONS(4634),
    [sym_continue_as_identifier] = ACTIONS(4636),
    [sym_preproc_open] = ACTIONS(4636),
    [sym_end_keyword] = ACTIONS(4636),
  },
  [STATE(2302)] = {
    [sym_identifier] = ACTIONS(4265),
    [anon_sym_SEMI] = ACTIONS(4267),
    [anon_sym_DASH] = ACTIONS(4267),
    [aux_sym_boolean_token1] = ACTIONS(4265),
    [aux_sym_boolean_token2] = ACTIONS(4265),
    [sym_decimal] = ACTIONS(4265),
    [anon_sym_LPAREN] = ACTIONS(4267),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4265),
    [anon_sym_LBRACK] = ACTIONS(4267),
    [aux_sym_record_type_token1] = ACTIONS(4265),
    [aux_sym_basic_type_token21] = ACTIONS(4265),
    [aux_sym_basic_type_token22] = ACTIONS(4265),
    [aux_sym_basic_type_token48] = ACTIONS(4265),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4265),
    [anon_sym_POUNDif] = ACTIONS(4267),
    [anon_sym_POUNDIF] = ACTIONS(4267),
    [anon_sym_POUNDIf] = ACTIONS(4267),
    [anon_sym_not] = ACTIONS(4265),
    [anon_sym_NOT] = ACTIONS(4265),
    [anon_sym_Not] = ACTIONS(4265),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4265),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4265),
    [anon_sym_PLUS] = ACTIONS(4267),
    [sym_datetime_literal] = ACTIONS(4267),
    [sym_date_literal] = ACTIONS(4265),
    [sym_time_literal] = ACTIONS(4265),
    [sym_biginteger_literal] = ACTIONS(4267),
    [anon_sym_if] = ACTIONS(4265),
    [anon_sym_IF] = ACTIONS(4265),
    [anon_sym_If] = ACTIONS(4265),
    [anon_sym_else] = ACTIONS(4265),
    [anon_sym_ELSE] = ACTIONS(4265),
    [anon_sym_Else] = ACTIONS(4265),
    [anon_sym_case] = ACTIONS(4265),
    [anon_sym_CASE] = ACTIONS(4265),
    [anon_sym_Case] = ACTIONS(4265),
    [anon_sym_for] = ACTIONS(4265),
    [anon_sym_FOR] = ACTIONS(4265),
    [anon_sym_For] = ACTIONS(4265),
    [anon_sym_foreach] = ACTIONS(4265),
    [anon_sym_FOREACH] = ACTIONS(4265),
    [anon_sym_Foreach] = ACTIONS(4265),
    [anon_sym_while] = ACTIONS(4265),
    [anon_sym_WHILE] = ACTIONS(4265),
    [anon_sym_While] = ACTIONS(4265),
    [anon_sym_repeat] = ACTIONS(4265),
    [anon_sym_REPEAT] = ACTIONS(4265),
    [anon_sym_Repeat] = ACTIONS(4265),
    [anon_sym_exit] = ACTIONS(4265),
    [anon_sym_EXIT] = ACTIONS(4265),
    [anon_sym_Exit] = ACTIONS(4265),
    [anon_sym_continue] = ACTIONS(4265),
    [anon_sym_CONTINUE] = ACTIONS(4265),
    [anon_sym_Continue] = ACTIONS(4265),
    [anon_sym_break] = ACTIONS(4265),
    [anon_sym_BREAK] = ACTIONS(4265),
    [anon_sym_Break] = ACTIONS(4265),
    [anon_sym_with] = ACTIONS(4265),
    [anon_sym_WITH] = ACTIONS(4265),
    [anon_sym_With] = ACTIONS(4265),
    [sym_asserterror_keyword] = ACTIONS(4267),
    [sym_page_keyword] = ACTIONS(4265),
    [anon_sym_codeunit] = ACTIONS(4265),
    [anon_sym_CODEUNIT] = ACTIONS(4265),
    [anon_sym_Codeunit] = ACTIONS(4265),
    [anon_sym_CodeUnit] = ACTIONS(4265),
    [anon_sym_COdeunit] = ACTIONS(4265),
    [anon_sym_codeUnit] = ACTIONS(4265),
    [sym_report_keyword] = ACTIONS(4265),
    [sym_query_keyword] = ACTIONS(4265),
    [anon_sym_xmlport] = ACTIONS(4265),
    [anon_sym_XMLPORT] = ACTIONS(4265),
    [anon_sym_Xmlport] = ACTIONS(4265),
    [anon_sym_XMLport] = ACTIONS(4265),
    [anon_sym_XMLPort] = ACTIONS(4265),
    [anon_sym_XmlPort] = ACTIONS(4265),
    [anon_sym_enum] = ACTIONS(4265),
    [anon_sym_ENUM] = ACTIONS(4265),
    [anon_sym_Enum] = ACTIONS(4265),
    [anon_sym_eNUM] = ACTIONS(4265),
    [anon_sym_eNum] = ACTIONS(4265),
    [anon_sym_ENum] = ACTIONS(4265),
    [sym_quoted_identifier] = ACTIONS(4267),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4267),
    [sym_integer] = ACTIONS(4265),
    [sym_continue_as_identifier] = ACTIONS(4267),
    [sym_preproc_open] = ACTIONS(4267),
    [sym_end_keyword] = ACTIONS(4267),
  },
  [STATE(2303)] = {
    [sym_identifier] = ACTIONS(4269),
    [anon_sym_SEMI] = ACTIONS(4271),
    [anon_sym_DASH] = ACTIONS(4271),
    [aux_sym_boolean_token1] = ACTIONS(4269),
    [aux_sym_boolean_token2] = ACTIONS(4269),
    [sym_decimal] = ACTIONS(4269),
    [anon_sym_LPAREN] = ACTIONS(4271),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4269),
    [anon_sym_LBRACK] = ACTIONS(4271),
    [aux_sym_record_type_token1] = ACTIONS(4269),
    [aux_sym_basic_type_token21] = ACTIONS(4269),
    [aux_sym_basic_type_token22] = ACTIONS(4269),
    [aux_sym_basic_type_token48] = ACTIONS(4269),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4269),
    [anon_sym_POUNDif] = ACTIONS(4271),
    [anon_sym_POUNDIF] = ACTIONS(4271),
    [anon_sym_POUNDIf] = ACTIONS(4271),
    [anon_sym_not] = ACTIONS(4269),
    [anon_sym_NOT] = ACTIONS(4269),
    [anon_sym_Not] = ACTIONS(4269),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4269),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4269),
    [anon_sym_PLUS] = ACTIONS(4271),
    [sym_datetime_literal] = ACTIONS(4271),
    [sym_date_literal] = ACTIONS(4269),
    [sym_time_literal] = ACTIONS(4269),
    [sym_biginteger_literal] = ACTIONS(4271),
    [anon_sym_if] = ACTIONS(4269),
    [anon_sym_IF] = ACTIONS(4269),
    [anon_sym_If] = ACTIONS(4269),
    [anon_sym_else] = ACTIONS(4269),
    [anon_sym_ELSE] = ACTIONS(4269),
    [anon_sym_Else] = ACTIONS(4269),
    [anon_sym_case] = ACTIONS(4269),
    [anon_sym_CASE] = ACTIONS(4269),
    [anon_sym_Case] = ACTIONS(4269),
    [anon_sym_for] = ACTIONS(4269),
    [anon_sym_FOR] = ACTIONS(4269),
    [anon_sym_For] = ACTIONS(4269),
    [anon_sym_foreach] = ACTIONS(4269),
    [anon_sym_FOREACH] = ACTIONS(4269),
    [anon_sym_Foreach] = ACTIONS(4269),
    [anon_sym_while] = ACTIONS(4269),
    [anon_sym_WHILE] = ACTIONS(4269),
    [anon_sym_While] = ACTIONS(4269),
    [anon_sym_repeat] = ACTIONS(4269),
    [anon_sym_REPEAT] = ACTIONS(4269),
    [anon_sym_Repeat] = ACTIONS(4269),
    [anon_sym_exit] = ACTIONS(4269),
    [anon_sym_EXIT] = ACTIONS(4269),
    [anon_sym_Exit] = ACTIONS(4269),
    [anon_sym_continue] = ACTIONS(4269),
    [anon_sym_CONTINUE] = ACTIONS(4269),
    [anon_sym_Continue] = ACTIONS(4269),
    [anon_sym_break] = ACTIONS(4269),
    [anon_sym_BREAK] = ACTIONS(4269),
    [anon_sym_Break] = ACTIONS(4269),
    [anon_sym_with] = ACTIONS(4269),
    [anon_sym_WITH] = ACTIONS(4269),
    [anon_sym_With] = ACTIONS(4269),
    [sym_asserterror_keyword] = ACTIONS(4271),
    [sym_page_keyword] = ACTIONS(4269),
    [anon_sym_codeunit] = ACTIONS(4269),
    [anon_sym_CODEUNIT] = ACTIONS(4269),
    [anon_sym_Codeunit] = ACTIONS(4269),
    [anon_sym_CodeUnit] = ACTIONS(4269),
    [anon_sym_COdeunit] = ACTIONS(4269),
    [anon_sym_codeUnit] = ACTIONS(4269),
    [sym_report_keyword] = ACTIONS(4269),
    [sym_query_keyword] = ACTIONS(4269),
    [anon_sym_xmlport] = ACTIONS(4269),
    [anon_sym_XMLPORT] = ACTIONS(4269),
    [anon_sym_Xmlport] = ACTIONS(4269),
    [anon_sym_XMLport] = ACTIONS(4269),
    [anon_sym_XMLPort] = ACTIONS(4269),
    [anon_sym_XmlPort] = ACTIONS(4269),
    [anon_sym_enum] = ACTIONS(4269),
    [anon_sym_ENUM] = ACTIONS(4269),
    [anon_sym_Enum] = ACTIONS(4269),
    [anon_sym_eNUM] = ACTIONS(4269),
    [anon_sym_eNum] = ACTIONS(4269),
    [anon_sym_ENum] = ACTIONS(4269),
    [sym_quoted_identifier] = ACTIONS(4271),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4271),
    [sym_integer] = ACTIONS(4269),
    [sym_continue_as_identifier] = ACTIONS(4271),
    [sym_preproc_open] = ACTIONS(4271),
    [sym_end_keyword] = ACTIONS(4271),
  },
  [STATE(2304)] = {
    [sym_identifier] = ACTIONS(4273),
    [anon_sym_SEMI] = ACTIONS(4275),
    [anon_sym_DASH] = ACTIONS(4275),
    [aux_sym_boolean_token1] = ACTIONS(4273),
    [aux_sym_boolean_token2] = ACTIONS(4273),
    [sym_decimal] = ACTIONS(4273),
    [anon_sym_LPAREN] = ACTIONS(4275),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4273),
    [anon_sym_LBRACK] = ACTIONS(4275),
    [aux_sym_record_type_token1] = ACTIONS(4273),
    [aux_sym_basic_type_token21] = ACTIONS(4273),
    [aux_sym_basic_type_token22] = ACTIONS(4273),
    [aux_sym_basic_type_token48] = ACTIONS(4273),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4273),
    [anon_sym_POUNDif] = ACTIONS(4275),
    [anon_sym_POUNDIF] = ACTIONS(4275),
    [anon_sym_POUNDIf] = ACTIONS(4275),
    [anon_sym_not] = ACTIONS(4273),
    [anon_sym_NOT] = ACTIONS(4273),
    [anon_sym_Not] = ACTIONS(4273),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4273),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4273),
    [anon_sym_PLUS] = ACTIONS(4275),
    [sym_datetime_literal] = ACTIONS(4275),
    [sym_date_literal] = ACTIONS(4273),
    [sym_time_literal] = ACTIONS(4273),
    [sym_biginteger_literal] = ACTIONS(4275),
    [anon_sym_if] = ACTIONS(4273),
    [anon_sym_IF] = ACTIONS(4273),
    [anon_sym_If] = ACTIONS(4273),
    [anon_sym_else] = ACTIONS(4273),
    [anon_sym_ELSE] = ACTIONS(4273),
    [anon_sym_Else] = ACTIONS(4273),
    [anon_sym_case] = ACTIONS(4273),
    [anon_sym_CASE] = ACTIONS(4273),
    [anon_sym_Case] = ACTIONS(4273),
    [anon_sym_for] = ACTIONS(4273),
    [anon_sym_FOR] = ACTIONS(4273),
    [anon_sym_For] = ACTIONS(4273),
    [anon_sym_foreach] = ACTIONS(4273),
    [anon_sym_FOREACH] = ACTIONS(4273),
    [anon_sym_Foreach] = ACTIONS(4273),
    [anon_sym_while] = ACTIONS(4273),
    [anon_sym_WHILE] = ACTIONS(4273),
    [anon_sym_While] = ACTIONS(4273),
    [anon_sym_repeat] = ACTIONS(4273),
    [anon_sym_REPEAT] = ACTIONS(4273),
    [anon_sym_Repeat] = ACTIONS(4273),
    [anon_sym_exit] = ACTIONS(4273),
    [anon_sym_EXIT] = ACTIONS(4273),
    [anon_sym_Exit] = ACTIONS(4273),
    [anon_sym_continue] = ACTIONS(4273),
    [anon_sym_CONTINUE] = ACTIONS(4273),
    [anon_sym_Continue] = ACTIONS(4273),
    [anon_sym_break] = ACTIONS(4273),
    [anon_sym_BREAK] = ACTIONS(4273),
    [anon_sym_Break] = ACTIONS(4273),
    [anon_sym_with] = ACTIONS(4273),
    [anon_sym_WITH] = ACTIONS(4273),
    [anon_sym_With] = ACTIONS(4273),
    [sym_asserterror_keyword] = ACTIONS(4275),
    [sym_page_keyword] = ACTIONS(4273),
    [anon_sym_codeunit] = ACTIONS(4273),
    [anon_sym_CODEUNIT] = ACTIONS(4273),
    [anon_sym_Codeunit] = ACTIONS(4273),
    [anon_sym_CodeUnit] = ACTIONS(4273),
    [anon_sym_COdeunit] = ACTIONS(4273),
    [anon_sym_codeUnit] = ACTIONS(4273),
    [sym_report_keyword] = ACTIONS(4273),
    [sym_query_keyword] = ACTIONS(4273),
    [anon_sym_xmlport] = ACTIONS(4273),
    [anon_sym_XMLPORT] = ACTIONS(4273),
    [anon_sym_Xmlport] = ACTIONS(4273),
    [anon_sym_XMLport] = ACTIONS(4273),
    [anon_sym_XMLPort] = ACTIONS(4273),
    [anon_sym_XmlPort] = ACTIONS(4273),
    [anon_sym_enum] = ACTIONS(4273),
    [anon_sym_ENUM] = ACTIONS(4273),
    [anon_sym_Enum] = ACTIONS(4273),
    [anon_sym_eNUM] = ACTIONS(4273),
    [anon_sym_eNum] = ACTIONS(4273),
    [anon_sym_ENum] = ACTIONS(4273),
    [sym_quoted_identifier] = ACTIONS(4275),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4275),
    [sym_integer] = ACTIONS(4273),
    [sym_continue_as_identifier] = ACTIONS(4275),
    [sym_preproc_open] = ACTIONS(4275),
    [sym_end_keyword] = ACTIONS(4275),
  },
  [STATE(2305)] = {
    [sym_identifier] = ACTIONS(4277),
    [anon_sym_SEMI] = ACTIONS(4279),
    [anon_sym_DASH] = ACTIONS(4279),
    [aux_sym_boolean_token1] = ACTIONS(4277),
    [aux_sym_boolean_token2] = ACTIONS(4277),
    [sym_decimal] = ACTIONS(4277),
    [anon_sym_LPAREN] = ACTIONS(4279),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4277),
    [anon_sym_LBRACK] = ACTIONS(4279),
    [aux_sym_record_type_token1] = ACTIONS(4277),
    [aux_sym_basic_type_token21] = ACTIONS(4277),
    [aux_sym_basic_type_token22] = ACTIONS(4277),
    [aux_sym_basic_type_token48] = ACTIONS(4277),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4277),
    [anon_sym_POUNDif] = ACTIONS(4279),
    [anon_sym_POUNDIF] = ACTIONS(4279),
    [anon_sym_POUNDIf] = ACTIONS(4279),
    [anon_sym_not] = ACTIONS(4277),
    [anon_sym_NOT] = ACTIONS(4277),
    [anon_sym_Not] = ACTIONS(4277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4277),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4277),
    [anon_sym_PLUS] = ACTIONS(4279),
    [sym_datetime_literal] = ACTIONS(4279),
    [sym_date_literal] = ACTIONS(4277),
    [sym_time_literal] = ACTIONS(4277),
    [sym_biginteger_literal] = ACTIONS(4279),
    [anon_sym_if] = ACTIONS(4277),
    [anon_sym_IF] = ACTIONS(4277),
    [anon_sym_If] = ACTIONS(4277),
    [anon_sym_else] = ACTIONS(4277),
    [anon_sym_ELSE] = ACTIONS(4277),
    [anon_sym_Else] = ACTIONS(4277),
    [anon_sym_case] = ACTIONS(4277),
    [anon_sym_CASE] = ACTIONS(4277),
    [anon_sym_Case] = ACTIONS(4277),
    [anon_sym_for] = ACTIONS(4277),
    [anon_sym_FOR] = ACTIONS(4277),
    [anon_sym_For] = ACTIONS(4277),
    [anon_sym_foreach] = ACTIONS(4277),
    [anon_sym_FOREACH] = ACTIONS(4277),
    [anon_sym_Foreach] = ACTIONS(4277),
    [anon_sym_while] = ACTIONS(4277),
    [anon_sym_WHILE] = ACTIONS(4277),
    [anon_sym_While] = ACTIONS(4277),
    [anon_sym_repeat] = ACTIONS(4277),
    [anon_sym_REPEAT] = ACTIONS(4277),
    [anon_sym_Repeat] = ACTIONS(4277),
    [anon_sym_exit] = ACTIONS(4277),
    [anon_sym_EXIT] = ACTIONS(4277),
    [anon_sym_Exit] = ACTIONS(4277),
    [anon_sym_continue] = ACTIONS(4277),
    [anon_sym_CONTINUE] = ACTIONS(4277),
    [anon_sym_Continue] = ACTIONS(4277),
    [anon_sym_break] = ACTIONS(4277),
    [anon_sym_BREAK] = ACTIONS(4277),
    [anon_sym_Break] = ACTIONS(4277),
    [anon_sym_with] = ACTIONS(4277),
    [anon_sym_WITH] = ACTIONS(4277),
    [anon_sym_With] = ACTIONS(4277),
    [sym_asserterror_keyword] = ACTIONS(4279),
    [sym_page_keyword] = ACTIONS(4277),
    [anon_sym_codeunit] = ACTIONS(4277),
    [anon_sym_CODEUNIT] = ACTIONS(4277),
    [anon_sym_Codeunit] = ACTIONS(4277),
    [anon_sym_CodeUnit] = ACTIONS(4277),
    [anon_sym_COdeunit] = ACTIONS(4277),
    [anon_sym_codeUnit] = ACTIONS(4277),
    [sym_report_keyword] = ACTIONS(4277),
    [sym_query_keyword] = ACTIONS(4277),
    [anon_sym_xmlport] = ACTIONS(4277),
    [anon_sym_XMLPORT] = ACTIONS(4277),
    [anon_sym_Xmlport] = ACTIONS(4277),
    [anon_sym_XMLport] = ACTIONS(4277),
    [anon_sym_XMLPort] = ACTIONS(4277),
    [anon_sym_XmlPort] = ACTIONS(4277),
    [anon_sym_enum] = ACTIONS(4277),
    [anon_sym_ENUM] = ACTIONS(4277),
    [anon_sym_Enum] = ACTIONS(4277),
    [anon_sym_eNUM] = ACTIONS(4277),
    [anon_sym_eNum] = ACTIONS(4277),
    [anon_sym_ENum] = ACTIONS(4277),
    [sym_quoted_identifier] = ACTIONS(4279),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4279),
    [sym_integer] = ACTIONS(4277),
    [sym_continue_as_identifier] = ACTIONS(4279),
    [sym_preproc_open] = ACTIONS(4279),
    [sym_end_keyword] = ACTIONS(4279),
  },
  [STATE(2306)] = {
    [sym_identifier] = ACTIONS(4281),
    [anon_sym_SEMI] = ACTIONS(4283),
    [anon_sym_DASH] = ACTIONS(4283),
    [aux_sym_boolean_token1] = ACTIONS(4281),
    [aux_sym_boolean_token2] = ACTIONS(4281),
    [sym_decimal] = ACTIONS(4281),
    [anon_sym_LPAREN] = ACTIONS(4283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4281),
    [anon_sym_LBRACK] = ACTIONS(4283),
    [aux_sym_record_type_token1] = ACTIONS(4281),
    [aux_sym_basic_type_token21] = ACTIONS(4281),
    [aux_sym_basic_type_token22] = ACTIONS(4281),
    [aux_sym_basic_type_token48] = ACTIONS(4281),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4281),
    [anon_sym_POUNDif] = ACTIONS(4283),
    [anon_sym_POUNDIF] = ACTIONS(4283),
    [anon_sym_POUNDIf] = ACTIONS(4283),
    [anon_sym_not] = ACTIONS(4281),
    [anon_sym_NOT] = ACTIONS(4281),
    [anon_sym_Not] = ACTIONS(4281),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4281),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4281),
    [anon_sym_PLUS] = ACTIONS(4283),
    [sym_datetime_literal] = ACTIONS(4283),
    [sym_date_literal] = ACTIONS(4281),
    [sym_time_literal] = ACTIONS(4281),
    [sym_biginteger_literal] = ACTIONS(4283),
    [anon_sym_if] = ACTIONS(4281),
    [anon_sym_IF] = ACTIONS(4281),
    [anon_sym_If] = ACTIONS(4281),
    [anon_sym_else] = ACTIONS(4281),
    [anon_sym_ELSE] = ACTIONS(4281),
    [anon_sym_Else] = ACTIONS(4281),
    [anon_sym_case] = ACTIONS(4281),
    [anon_sym_CASE] = ACTIONS(4281),
    [anon_sym_Case] = ACTIONS(4281),
    [anon_sym_for] = ACTIONS(4281),
    [anon_sym_FOR] = ACTIONS(4281),
    [anon_sym_For] = ACTIONS(4281),
    [anon_sym_foreach] = ACTIONS(4281),
    [anon_sym_FOREACH] = ACTIONS(4281),
    [anon_sym_Foreach] = ACTIONS(4281),
    [anon_sym_while] = ACTIONS(4281),
    [anon_sym_WHILE] = ACTIONS(4281),
    [anon_sym_While] = ACTIONS(4281),
    [anon_sym_repeat] = ACTIONS(4281),
    [anon_sym_REPEAT] = ACTIONS(4281),
    [anon_sym_Repeat] = ACTIONS(4281),
    [anon_sym_exit] = ACTIONS(4281),
    [anon_sym_EXIT] = ACTIONS(4281),
    [anon_sym_Exit] = ACTIONS(4281),
    [anon_sym_continue] = ACTIONS(4281),
    [anon_sym_CONTINUE] = ACTIONS(4281),
    [anon_sym_Continue] = ACTIONS(4281),
    [anon_sym_break] = ACTIONS(4281),
    [anon_sym_BREAK] = ACTIONS(4281),
    [anon_sym_Break] = ACTIONS(4281),
    [anon_sym_with] = ACTIONS(4281),
    [anon_sym_WITH] = ACTIONS(4281),
    [anon_sym_With] = ACTIONS(4281),
    [sym_asserterror_keyword] = ACTIONS(4283),
    [sym_page_keyword] = ACTIONS(4281),
    [anon_sym_codeunit] = ACTIONS(4281),
    [anon_sym_CODEUNIT] = ACTIONS(4281),
    [anon_sym_Codeunit] = ACTIONS(4281),
    [anon_sym_CodeUnit] = ACTIONS(4281),
    [anon_sym_COdeunit] = ACTIONS(4281),
    [anon_sym_codeUnit] = ACTIONS(4281),
    [sym_report_keyword] = ACTIONS(4281),
    [sym_query_keyword] = ACTIONS(4281),
    [anon_sym_xmlport] = ACTIONS(4281),
    [anon_sym_XMLPORT] = ACTIONS(4281),
    [anon_sym_Xmlport] = ACTIONS(4281),
    [anon_sym_XMLport] = ACTIONS(4281),
    [anon_sym_XMLPort] = ACTIONS(4281),
    [anon_sym_XmlPort] = ACTIONS(4281),
    [anon_sym_enum] = ACTIONS(4281),
    [anon_sym_ENUM] = ACTIONS(4281),
    [anon_sym_Enum] = ACTIONS(4281),
    [anon_sym_eNUM] = ACTIONS(4281),
    [anon_sym_eNum] = ACTIONS(4281),
    [anon_sym_ENum] = ACTIONS(4281),
    [sym_quoted_identifier] = ACTIONS(4283),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4283),
    [sym_integer] = ACTIONS(4281),
    [sym_continue_as_identifier] = ACTIONS(4283),
    [sym_preproc_open] = ACTIONS(4283),
    [sym_end_keyword] = ACTIONS(4283),
  },
  [STATE(2307)] = {
    [sym_identifier] = ACTIONS(4285),
    [anon_sym_SEMI] = ACTIONS(4287),
    [anon_sym_DASH] = ACTIONS(4287),
    [aux_sym_boolean_token1] = ACTIONS(4285),
    [aux_sym_boolean_token2] = ACTIONS(4285),
    [sym_decimal] = ACTIONS(4285),
    [anon_sym_LPAREN] = ACTIONS(4287),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4285),
    [anon_sym_LBRACK] = ACTIONS(4287),
    [aux_sym_record_type_token1] = ACTIONS(4285),
    [aux_sym_basic_type_token21] = ACTIONS(4285),
    [aux_sym_basic_type_token22] = ACTIONS(4285),
    [aux_sym_basic_type_token48] = ACTIONS(4285),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4285),
    [anon_sym_POUNDif] = ACTIONS(4287),
    [anon_sym_POUNDIF] = ACTIONS(4287),
    [anon_sym_POUNDIf] = ACTIONS(4287),
    [anon_sym_not] = ACTIONS(4285),
    [anon_sym_NOT] = ACTIONS(4285),
    [anon_sym_Not] = ACTIONS(4285),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4285),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4285),
    [anon_sym_PLUS] = ACTIONS(4287),
    [sym_datetime_literal] = ACTIONS(4287),
    [sym_date_literal] = ACTIONS(4285),
    [sym_time_literal] = ACTIONS(4285),
    [sym_biginteger_literal] = ACTIONS(4287),
    [anon_sym_if] = ACTIONS(4285),
    [anon_sym_IF] = ACTIONS(4285),
    [anon_sym_If] = ACTIONS(4285),
    [anon_sym_else] = ACTIONS(4285),
    [anon_sym_ELSE] = ACTIONS(4285),
    [anon_sym_Else] = ACTIONS(4285),
    [anon_sym_case] = ACTIONS(4285),
    [anon_sym_CASE] = ACTIONS(4285),
    [anon_sym_Case] = ACTIONS(4285),
    [anon_sym_for] = ACTIONS(4285),
    [anon_sym_FOR] = ACTIONS(4285),
    [anon_sym_For] = ACTIONS(4285),
    [anon_sym_foreach] = ACTIONS(4285),
    [anon_sym_FOREACH] = ACTIONS(4285),
    [anon_sym_Foreach] = ACTIONS(4285),
    [anon_sym_while] = ACTIONS(4285),
    [anon_sym_WHILE] = ACTIONS(4285),
    [anon_sym_While] = ACTIONS(4285),
    [anon_sym_repeat] = ACTIONS(4285),
    [anon_sym_REPEAT] = ACTIONS(4285),
    [anon_sym_Repeat] = ACTIONS(4285),
    [anon_sym_exit] = ACTIONS(4285),
    [anon_sym_EXIT] = ACTIONS(4285),
    [anon_sym_Exit] = ACTIONS(4285),
    [anon_sym_continue] = ACTIONS(4285),
    [anon_sym_CONTINUE] = ACTIONS(4285),
    [anon_sym_Continue] = ACTIONS(4285),
    [anon_sym_break] = ACTIONS(4285),
    [anon_sym_BREAK] = ACTIONS(4285),
    [anon_sym_Break] = ACTIONS(4285),
    [anon_sym_with] = ACTIONS(4285),
    [anon_sym_WITH] = ACTIONS(4285),
    [anon_sym_With] = ACTIONS(4285),
    [sym_asserterror_keyword] = ACTIONS(4287),
    [sym_page_keyword] = ACTIONS(4285),
    [anon_sym_codeunit] = ACTIONS(4285),
    [anon_sym_CODEUNIT] = ACTIONS(4285),
    [anon_sym_Codeunit] = ACTIONS(4285),
    [anon_sym_CodeUnit] = ACTIONS(4285),
    [anon_sym_COdeunit] = ACTIONS(4285),
    [anon_sym_codeUnit] = ACTIONS(4285),
    [sym_report_keyword] = ACTIONS(4285),
    [sym_query_keyword] = ACTIONS(4285),
    [anon_sym_xmlport] = ACTIONS(4285),
    [anon_sym_XMLPORT] = ACTIONS(4285),
    [anon_sym_Xmlport] = ACTIONS(4285),
    [anon_sym_XMLport] = ACTIONS(4285),
    [anon_sym_XMLPort] = ACTIONS(4285),
    [anon_sym_XmlPort] = ACTIONS(4285),
    [anon_sym_enum] = ACTIONS(4285),
    [anon_sym_ENUM] = ACTIONS(4285),
    [anon_sym_Enum] = ACTIONS(4285),
    [anon_sym_eNUM] = ACTIONS(4285),
    [anon_sym_eNum] = ACTIONS(4285),
    [anon_sym_ENum] = ACTIONS(4285),
    [sym_quoted_identifier] = ACTIONS(4287),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4287),
    [sym_integer] = ACTIONS(4285),
    [sym_continue_as_identifier] = ACTIONS(4287),
    [sym_preproc_open] = ACTIONS(4287),
    [sym_end_keyword] = ACTIONS(4287),
  },
  [STATE(2308)] = {
    [sym_identifier] = ACTIONS(4780),
    [anon_sym_SEMI] = ACTIONS(4782),
    [anon_sym_DASH] = ACTIONS(4782),
    [aux_sym_boolean_token1] = ACTIONS(4780),
    [aux_sym_boolean_token2] = ACTIONS(4780),
    [sym_decimal] = ACTIONS(4780),
    [anon_sym_LPAREN] = ACTIONS(4782),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4780),
    [anon_sym_LBRACK] = ACTIONS(4782),
    [aux_sym_record_type_token1] = ACTIONS(4780),
    [aux_sym_basic_type_token21] = ACTIONS(4780),
    [aux_sym_basic_type_token22] = ACTIONS(4780),
    [aux_sym_basic_type_token48] = ACTIONS(4780),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4780),
    [anon_sym_POUNDif] = ACTIONS(4782),
    [anon_sym_POUNDIF] = ACTIONS(4782),
    [anon_sym_POUNDIf] = ACTIONS(4782),
    [anon_sym_not] = ACTIONS(4780),
    [anon_sym_NOT] = ACTIONS(4780),
    [anon_sym_Not] = ACTIONS(4780),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4780),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4780),
    [anon_sym_PLUS] = ACTIONS(4782),
    [sym_datetime_literal] = ACTIONS(4782),
    [sym_date_literal] = ACTIONS(4780),
    [sym_time_literal] = ACTIONS(4780),
    [sym_biginteger_literal] = ACTIONS(4782),
    [anon_sym_if] = ACTIONS(4780),
    [anon_sym_IF] = ACTIONS(4780),
    [anon_sym_If] = ACTIONS(4780),
    [anon_sym_else] = ACTIONS(4780),
    [anon_sym_ELSE] = ACTIONS(4780),
    [anon_sym_Else] = ACTIONS(4780),
    [anon_sym_case] = ACTIONS(4780),
    [anon_sym_CASE] = ACTIONS(4780),
    [anon_sym_Case] = ACTIONS(4780),
    [anon_sym_for] = ACTIONS(4780),
    [anon_sym_FOR] = ACTIONS(4780),
    [anon_sym_For] = ACTIONS(4780),
    [anon_sym_foreach] = ACTIONS(4780),
    [anon_sym_FOREACH] = ACTIONS(4780),
    [anon_sym_Foreach] = ACTIONS(4780),
    [anon_sym_while] = ACTIONS(4780),
    [anon_sym_WHILE] = ACTIONS(4780),
    [anon_sym_While] = ACTIONS(4780),
    [anon_sym_repeat] = ACTIONS(4780),
    [anon_sym_REPEAT] = ACTIONS(4780),
    [anon_sym_Repeat] = ACTIONS(4780),
    [anon_sym_exit] = ACTIONS(4780),
    [anon_sym_EXIT] = ACTIONS(4780),
    [anon_sym_Exit] = ACTIONS(4780),
    [anon_sym_continue] = ACTIONS(4780),
    [anon_sym_CONTINUE] = ACTIONS(4780),
    [anon_sym_Continue] = ACTIONS(4780),
    [anon_sym_break] = ACTIONS(4780),
    [anon_sym_BREAK] = ACTIONS(4780),
    [anon_sym_Break] = ACTIONS(4780),
    [anon_sym_with] = ACTIONS(4780),
    [anon_sym_WITH] = ACTIONS(4780),
    [anon_sym_With] = ACTIONS(4780),
    [sym_asserterror_keyword] = ACTIONS(4782),
    [sym_page_keyword] = ACTIONS(4780),
    [anon_sym_codeunit] = ACTIONS(4780),
    [anon_sym_CODEUNIT] = ACTIONS(4780),
    [anon_sym_Codeunit] = ACTIONS(4780),
    [anon_sym_CodeUnit] = ACTIONS(4780),
    [anon_sym_COdeunit] = ACTIONS(4780),
    [anon_sym_codeUnit] = ACTIONS(4780),
    [sym_report_keyword] = ACTIONS(4780),
    [sym_query_keyword] = ACTIONS(4780),
    [anon_sym_xmlport] = ACTIONS(4780),
    [anon_sym_XMLPORT] = ACTIONS(4780),
    [anon_sym_Xmlport] = ACTIONS(4780),
    [anon_sym_XMLport] = ACTIONS(4780),
    [anon_sym_XMLPort] = ACTIONS(4780),
    [anon_sym_XmlPort] = ACTIONS(4780),
    [anon_sym_enum] = ACTIONS(4780),
    [anon_sym_ENUM] = ACTIONS(4780),
    [anon_sym_Enum] = ACTIONS(4780),
    [anon_sym_eNUM] = ACTIONS(4780),
    [anon_sym_eNum] = ACTIONS(4780),
    [anon_sym_ENum] = ACTIONS(4780),
    [sym_quoted_identifier] = ACTIONS(4782),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4782),
    [sym_integer] = ACTIONS(4780),
    [sym_continue_as_identifier] = ACTIONS(4782),
    [sym_preproc_open] = ACTIONS(4782),
    [sym_end_keyword] = ACTIONS(4782),
  },
  [STATE(2309)] = {
    [sym_identifier] = ACTIONS(4598),
    [anon_sym_SEMI] = ACTIONS(4600),
    [anon_sym_DASH] = ACTIONS(4600),
    [aux_sym_boolean_token1] = ACTIONS(4598),
    [aux_sym_boolean_token2] = ACTIONS(4598),
    [sym_decimal] = ACTIONS(4598),
    [anon_sym_LPAREN] = ACTIONS(4600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4598),
    [anon_sym_LBRACK] = ACTIONS(4600),
    [aux_sym_record_type_token1] = ACTIONS(4598),
    [aux_sym_basic_type_token21] = ACTIONS(4598),
    [aux_sym_basic_type_token22] = ACTIONS(4598),
    [aux_sym_basic_type_token48] = ACTIONS(4598),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4598),
    [anon_sym_POUNDif] = ACTIONS(4600),
    [anon_sym_POUNDIF] = ACTIONS(4600),
    [anon_sym_POUNDIf] = ACTIONS(4600),
    [anon_sym_not] = ACTIONS(4598),
    [anon_sym_NOT] = ACTIONS(4598),
    [anon_sym_Not] = ACTIONS(4598),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4598),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4598),
    [anon_sym_PLUS] = ACTIONS(4600),
    [sym_datetime_literal] = ACTIONS(4600),
    [sym_date_literal] = ACTIONS(4598),
    [sym_time_literal] = ACTIONS(4598),
    [sym_biginteger_literal] = ACTIONS(4600),
    [anon_sym_if] = ACTIONS(4598),
    [anon_sym_IF] = ACTIONS(4598),
    [anon_sym_If] = ACTIONS(4598),
    [anon_sym_else] = ACTIONS(4598),
    [anon_sym_ELSE] = ACTIONS(4598),
    [anon_sym_Else] = ACTIONS(4598),
    [anon_sym_case] = ACTIONS(4598),
    [anon_sym_CASE] = ACTIONS(4598),
    [anon_sym_Case] = ACTIONS(4598),
    [anon_sym_for] = ACTIONS(4598),
    [anon_sym_FOR] = ACTIONS(4598),
    [anon_sym_For] = ACTIONS(4598),
    [anon_sym_foreach] = ACTIONS(4598),
    [anon_sym_FOREACH] = ACTIONS(4598),
    [anon_sym_Foreach] = ACTIONS(4598),
    [anon_sym_while] = ACTIONS(4598),
    [anon_sym_WHILE] = ACTIONS(4598),
    [anon_sym_While] = ACTIONS(4598),
    [anon_sym_repeat] = ACTIONS(4598),
    [anon_sym_REPEAT] = ACTIONS(4598),
    [anon_sym_Repeat] = ACTIONS(4598),
    [anon_sym_exit] = ACTIONS(4598),
    [anon_sym_EXIT] = ACTIONS(4598),
    [anon_sym_Exit] = ACTIONS(4598),
    [anon_sym_continue] = ACTIONS(4598),
    [anon_sym_CONTINUE] = ACTIONS(4598),
    [anon_sym_Continue] = ACTIONS(4598),
    [anon_sym_break] = ACTIONS(4598),
    [anon_sym_BREAK] = ACTIONS(4598),
    [anon_sym_Break] = ACTIONS(4598),
    [anon_sym_with] = ACTIONS(4598),
    [anon_sym_WITH] = ACTIONS(4598),
    [anon_sym_With] = ACTIONS(4598),
    [sym_asserterror_keyword] = ACTIONS(4600),
    [sym_page_keyword] = ACTIONS(4598),
    [anon_sym_codeunit] = ACTIONS(4598),
    [anon_sym_CODEUNIT] = ACTIONS(4598),
    [anon_sym_Codeunit] = ACTIONS(4598),
    [anon_sym_CodeUnit] = ACTIONS(4598),
    [anon_sym_COdeunit] = ACTIONS(4598),
    [anon_sym_codeUnit] = ACTIONS(4598),
    [sym_report_keyword] = ACTIONS(4598),
    [sym_query_keyword] = ACTIONS(4598),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4598),
    [anon_sym_ENUM] = ACTIONS(4598),
    [anon_sym_Enum] = ACTIONS(4598),
    [anon_sym_eNUM] = ACTIONS(4598),
    [anon_sym_eNum] = ACTIONS(4598),
    [anon_sym_ENum] = ACTIONS(4598),
    [sym_quoted_identifier] = ACTIONS(4600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4600),
    [sym_integer] = ACTIONS(4598),
    [sym_continue_as_identifier] = ACTIONS(4600),
    [sym_preproc_open] = ACTIONS(4600),
    [sym_end_keyword] = ACTIONS(4600),
  },
  [STATE(2310)] = {
    [sym_identifier] = ACTIONS(4602),
    [anon_sym_SEMI] = ACTIONS(4604),
    [anon_sym_DASH] = ACTIONS(4604),
    [aux_sym_boolean_token1] = ACTIONS(4602),
    [aux_sym_boolean_token2] = ACTIONS(4602),
    [sym_decimal] = ACTIONS(4602),
    [anon_sym_LPAREN] = ACTIONS(4604),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4602),
    [anon_sym_LBRACK] = ACTIONS(4604),
    [aux_sym_record_type_token1] = ACTIONS(4602),
    [aux_sym_basic_type_token21] = ACTIONS(4602),
    [aux_sym_basic_type_token22] = ACTIONS(4602),
    [aux_sym_basic_type_token48] = ACTIONS(4602),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4602),
    [anon_sym_POUNDif] = ACTIONS(4604),
    [anon_sym_POUNDIF] = ACTIONS(4604),
    [anon_sym_POUNDIf] = ACTIONS(4604),
    [anon_sym_not] = ACTIONS(4602),
    [anon_sym_NOT] = ACTIONS(4602),
    [anon_sym_Not] = ACTIONS(4602),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4602),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4602),
    [anon_sym_PLUS] = ACTIONS(4604),
    [sym_datetime_literal] = ACTIONS(4604),
    [sym_date_literal] = ACTIONS(4602),
    [sym_time_literal] = ACTIONS(4602),
    [sym_biginteger_literal] = ACTIONS(4604),
    [anon_sym_if] = ACTIONS(4602),
    [anon_sym_IF] = ACTIONS(4602),
    [anon_sym_If] = ACTIONS(4602),
    [anon_sym_else] = ACTIONS(4602),
    [anon_sym_ELSE] = ACTIONS(4602),
    [anon_sym_Else] = ACTIONS(4602),
    [anon_sym_case] = ACTIONS(4602),
    [anon_sym_CASE] = ACTIONS(4602),
    [anon_sym_Case] = ACTIONS(4602),
    [anon_sym_for] = ACTIONS(4602),
    [anon_sym_FOR] = ACTIONS(4602),
    [anon_sym_For] = ACTIONS(4602),
    [anon_sym_foreach] = ACTIONS(4602),
    [anon_sym_FOREACH] = ACTIONS(4602),
    [anon_sym_Foreach] = ACTIONS(4602),
    [anon_sym_while] = ACTIONS(4602),
    [anon_sym_WHILE] = ACTIONS(4602),
    [anon_sym_While] = ACTIONS(4602),
    [anon_sym_repeat] = ACTIONS(4602),
    [anon_sym_REPEAT] = ACTIONS(4602),
    [anon_sym_Repeat] = ACTIONS(4602),
    [anon_sym_exit] = ACTIONS(4602),
    [anon_sym_EXIT] = ACTIONS(4602),
    [anon_sym_Exit] = ACTIONS(4602),
    [anon_sym_continue] = ACTIONS(4602),
    [anon_sym_CONTINUE] = ACTIONS(4602),
    [anon_sym_Continue] = ACTIONS(4602),
    [anon_sym_break] = ACTIONS(4602),
    [anon_sym_BREAK] = ACTIONS(4602),
    [anon_sym_Break] = ACTIONS(4602),
    [anon_sym_with] = ACTIONS(4602),
    [anon_sym_WITH] = ACTIONS(4602),
    [anon_sym_With] = ACTIONS(4602),
    [sym_asserterror_keyword] = ACTIONS(4604),
    [sym_page_keyword] = ACTIONS(4602),
    [anon_sym_codeunit] = ACTIONS(4602),
    [anon_sym_CODEUNIT] = ACTIONS(4602),
    [anon_sym_Codeunit] = ACTIONS(4602),
    [anon_sym_CodeUnit] = ACTIONS(4602),
    [anon_sym_COdeunit] = ACTIONS(4602),
    [anon_sym_codeUnit] = ACTIONS(4602),
    [sym_report_keyword] = ACTIONS(4602),
    [sym_query_keyword] = ACTIONS(4602),
    [anon_sym_xmlport] = ACTIONS(4602),
    [anon_sym_XMLPORT] = ACTIONS(4602),
    [anon_sym_Xmlport] = ACTIONS(4602),
    [anon_sym_XMLport] = ACTIONS(4602),
    [anon_sym_XMLPort] = ACTIONS(4602),
    [anon_sym_XmlPort] = ACTIONS(4602),
    [anon_sym_enum] = ACTIONS(4602),
    [anon_sym_ENUM] = ACTIONS(4602),
    [anon_sym_Enum] = ACTIONS(4602),
    [anon_sym_eNUM] = ACTIONS(4602),
    [anon_sym_eNum] = ACTIONS(4602),
    [anon_sym_ENum] = ACTIONS(4602),
    [sym_quoted_identifier] = ACTIONS(4604),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4604),
    [sym_integer] = ACTIONS(4602),
    [sym_continue_as_identifier] = ACTIONS(4604),
    [sym_preproc_open] = ACTIONS(4604),
    [sym_end_keyword] = ACTIONS(4604),
  },
  [STATE(2311)] = {
    [sym_identifier] = ACTIONS(4772),
    [anon_sym_SEMI] = ACTIONS(4774),
    [anon_sym_DASH] = ACTIONS(4774),
    [aux_sym_boolean_token1] = ACTIONS(4772),
    [aux_sym_boolean_token2] = ACTIONS(4772),
    [sym_decimal] = ACTIONS(4772),
    [anon_sym_LPAREN] = ACTIONS(4774),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4772),
    [anon_sym_LBRACK] = ACTIONS(4774),
    [aux_sym_record_type_token1] = ACTIONS(4772),
    [aux_sym_basic_type_token21] = ACTIONS(4772),
    [aux_sym_basic_type_token22] = ACTIONS(4772),
    [aux_sym_basic_type_token48] = ACTIONS(4772),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4772),
    [anon_sym_POUNDif] = ACTIONS(4774),
    [anon_sym_POUNDIF] = ACTIONS(4774),
    [anon_sym_POUNDIf] = ACTIONS(4774),
    [anon_sym_not] = ACTIONS(4772),
    [anon_sym_NOT] = ACTIONS(4772),
    [anon_sym_Not] = ACTIONS(4772),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4772),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4772),
    [anon_sym_PLUS] = ACTIONS(4774),
    [sym_datetime_literal] = ACTIONS(4774),
    [sym_date_literal] = ACTIONS(4772),
    [sym_time_literal] = ACTIONS(4772),
    [sym_biginteger_literal] = ACTIONS(4774),
    [anon_sym_if] = ACTIONS(4772),
    [anon_sym_IF] = ACTIONS(4772),
    [anon_sym_If] = ACTIONS(4772),
    [anon_sym_else] = ACTIONS(4772),
    [anon_sym_ELSE] = ACTIONS(4772),
    [anon_sym_Else] = ACTIONS(4772),
    [anon_sym_case] = ACTIONS(4772),
    [anon_sym_CASE] = ACTIONS(4772),
    [anon_sym_Case] = ACTIONS(4772),
    [anon_sym_for] = ACTIONS(4772),
    [anon_sym_FOR] = ACTIONS(4772),
    [anon_sym_For] = ACTIONS(4772),
    [anon_sym_foreach] = ACTIONS(4772),
    [anon_sym_FOREACH] = ACTIONS(4772),
    [anon_sym_Foreach] = ACTIONS(4772),
    [anon_sym_while] = ACTIONS(4772),
    [anon_sym_WHILE] = ACTIONS(4772),
    [anon_sym_While] = ACTIONS(4772),
    [anon_sym_repeat] = ACTIONS(4772),
    [anon_sym_REPEAT] = ACTIONS(4772),
    [anon_sym_Repeat] = ACTIONS(4772),
    [anon_sym_exit] = ACTIONS(4772),
    [anon_sym_EXIT] = ACTIONS(4772),
    [anon_sym_Exit] = ACTIONS(4772),
    [anon_sym_continue] = ACTIONS(4772),
    [anon_sym_CONTINUE] = ACTIONS(4772),
    [anon_sym_Continue] = ACTIONS(4772),
    [anon_sym_break] = ACTIONS(4772),
    [anon_sym_BREAK] = ACTIONS(4772),
    [anon_sym_Break] = ACTIONS(4772),
    [anon_sym_with] = ACTIONS(4772),
    [anon_sym_WITH] = ACTIONS(4772),
    [anon_sym_With] = ACTIONS(4772),
    [sym_asserterror_keyword] = ACTIONS(4774),
    [sym_page_keyword] = ACTIONS(4772),
    [anon_sym_codeunit] = ACTIONS(4772),
    [anon_sym_CODEUNIT] = ACTIONS(4772),
    [anon_sym_Codeunit] = ACTIONS(4772),
    [anon_sym_CodeUnit] = ACTIONS(4772),
    [anon_sym_COdeunit] = ACTIONS(4772),
    [anon_sym_codeUnit] = ACTIONS(4772),
    [sym_report_keyword] = ACTIONS(4772),
    [sym_query_keyword] = ACTIONS(4772),
    [anon_sym_xmlport] = ACTIONS(4772),
    [anon_sym_XMLPORT] = ACTIONS(4772),
    [anon_sym_Xmlport] = ACTIONS(4772),
    [anon_sym_XMLport] = ACTIONS(4772),
    [anon_sym_XMLPort] = ACTIONS(4772),
    [anon_sym_XmlPort] = ACTIONS(4772),
    [anon_sym_enum] = ACTIONS(4772),
    [anon_sym_ENUM] = ACTIONS(4772),
    [anon_sym_Enum] = ACTIONS(4772),
    [anon_sym_eNUM] = ACTIONS(4772),
    [anon_sym_eNum] = ACTIONS(4772),
    [anon_sym_ENum] = ACTIONS(4772),
    [sym_quoted_identifier] = ACTIONS(4774),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4774),
    [sym_integer] = ACTIONS(4772),
    [sym_continue_as_identifier] = ACTIONS(4774),
    [sym_preproc_open] = ACTIONS(4774),
    [sym_end_keyword] = ACTIONS(4774),
  },
  [STATE(2312)] = {
    [sym_identifier] = ACTIONS(4289),
    [anon_sym_SEMI] = ACTIONS(4291),
    [anon_sym_DASH] = ACTIONS(4291),
    [aux_sym_boolean_token1] = ACTIONS(4289),
    [aux_sym_boolean_token2] = ACTIONS(4289),
    [sym_decimal] = ACTIONS(4289),
    [anon_sym_LPAREN] = ACTIONS(4291),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4289),
    [anon_sym_LBRACK] = ACTIONS(4291),
    [aux_sym_record_type_token1] = ACTIONS(4289),
    [aux_sym_basic_type_token21] = ACTIONS(4289),
    [aux_sym_basic_type_token22] = ACTIONS(4289),
    [aux_sym_basic_type_token48] = ACTIONS(4289),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4289),
    [anon_sym_POUNDif] = ACTIONS(4291),
    [anon_sym_POUNDIF] = ACTIONS(4291),
    [anon_sym_POUNDIf] = ACTIONS(4291),
    [anon_sym_not] = ACTIONS(4289),
    [anon_sym_NOT] = ACTIONS(4289),
    [anon_sym_Not] = ACTIONS(4289),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4289),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4289),
    [anon_sym_PLUS] = ACTIONS(4291),
    [sym_datetime_literal] = ACTIONS(4291),
    [sym_date_literal] = ACTIONS(4289),
    [sym_time_literal] = ACTIONS(4289),
    [sym_biginteger_literal] = ACTIONS(4291),
    [anon_sym_if] = ACTIONS(4289),
    [anon_sym_IF] = ACTIONS(4289),
    [anon_sym_If] = ACTIONS(4289),
    [anon_sym_else] = ACTIONS(4289),
    [anon_sym_ELSE] = ACTIONS(4289),
    [anon_sym_Else] = ACTIONS(4289),
    [anon_sym_case] = ACTIONS(4289),
    [anon_sym_CASE] = ACTIONS(4289),
    [anon_sym_Case] = ACTIONS(4289),
    [anon_sym_for] = ACTIONS(4289),
    [anon_sym_FOR] = ACTIONS(4289),
    [anon_sym_For] = ACTIONS(4289),
    [anon_sym_foreach] = ACTIONS(4289),
    [anon_sym_FOREACH] = ACTIONS(4289),
    [anon_sym_Foreach] = ACTIONS(4289),
    [anon_sym_while] = ACTIONS(4289),
    [anon_sym_WHILE] = ACTIONS(4289),
    [anon_sym_While] = ACTIONS(4289),
    [anon_sym_repeat] = ACTIONS(4289),
    [anon_sym_REPEAT] = ACTIONS(4289),
    [anon_sym_Repeat] = ACTIONS(4289),
    [anon_sym_exit] = ACTIONS(4289),
    [anon_sym_EXIT] = ACTIONS(4289),
    [anon_sym_Exit] = ACTIONS(4289),
    [anon_sym_continue] = ACTIONS(4289),
    [anon_sym_CONTINUE] = ACTIONS(4289),
    [anon_sym_Continue] = ACTIONS(4289),
    [anon_sym_break] = ACTIONS(4289),
    [anon_sym_BREAK] = ACTIONS(4289),
    [anon_sym_Break] = ACTIONS(4289),
    [anon_sym_with] = ACTIONS(4289),
    [anon_sym_WITH] = ACTIONS(4289),
    [anon_sym_With] = ACTIONS(4289),
    [sym_asserterror_keyword] = ACTIONS(4291),
    [sym_page_keyword] = ACTIONS(4289),
    [anon_sym_codeunit] = ACTIONS(4289),
    [anon_sym_CODEUNIT] = ACTIONS(4289),
    [anon_sym_Codeunit] = ACTIONS(4289),
    [anon_sym_CodeUnit] = ACTIONS(4289),
    [anon_sym_COdeunit] = ACTIONS(4289),
    [anon_sym_codeUnit] = ACTIONS(4289),
    [sym_report_keyword] = ACTIONS(4289),
    [sym_query_keyword] = ACTIONS(4289),
    [anon_sym_xmlport] = ACTIONS(4289),
    [anon_sym_XMLPORT] = ACTIONS(4289),
    [anon_sym_Xmlport] = ACTIONS(4289),
    [anon_sym_XMLport] = ACTIONS(4289),
    [anon_sym_XMLPort] = ACTIONS(4289),
    [anon_sym_XmlPort] = ACTIONS(4289),
    [anon_sym_enum] = ACTIONS(4289),
    [anon_sym_ENUM] = ACTIONS(4289),
    [anon_sym_Enum] = ACTIONS(4289),
    [anon_sym_eNUM] = ACTIONS(4289),
    [anon_sym_eNum] = ACTIONS(4289),
    [anon_sym_ENum] = ACTIONS(4289),
    [sym_quoted_identifier] = ACTIONS(4291),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4291),
    [sym_integer] = ACTIONS(4289),
    [sym_continue_as_identifier] = ACTIONS(4291),
    [sym_preproc_open] = ACTIONS(4291),
    [sym_end_keyword] = ACTIONS(4291),
  },
  [STATE(2313)] = {
    [sym_identifier] = ACTIONS(4700),
    [anon_sym_SEMI] = ACTIONS(4702),
    [anon_sym_DASH] = ACTIONS(4702),
    [aux_sym_boolean_token1] = ACTIONS(4700),
    [aux_sym_boolean_token2] = ACTIONS(4700),
    [sym_decimal] = ACTIONS(4700),
    [anon_sym_LPAREN] = ACTIONS(4702),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4700),
    [anon_sym_LBRACK] = ACTIONS(4702),
    [aux_sym_record_type_token1] = ACTIONS(4700),
    [aux_sym_basic_type_token21] = ACTIONS(4700),
    [aux_sym_basic_type_token22] = ACTIONS(4700),
    [aux_sym_basic_type_token48] = ACTIONS(4700),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4700),
    [anon_sym_POUNDif] = ACTIONS(4702),
    [anon_sym_POUNDIF] = ACTIONS(4702),
    [anon_sym_POUNDIf] = ACTIONS(4702),
    [anon_sym_not] = ACTIONS(4700),
    [anon_sym_NOT] = ACTIONS(4700),
    [anon_sym_Not] = ACTIONS(4700),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4700),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4700),
    [anon_sym_PLUS] = ACTIONS(4702),
    [sym_datetime_literal] = ACTIONS(4702),
    [sym_date_literal] = ACTIONS(4700),
    [sym_time_literal] = ACTIONS(4700),
    [sym_biginteger_literal] = ACTIONS(4702),
    [anon_sym_if] = ACTIONS(4700),
    [anon_sym_IF] = ACTIONS(4700),
    [anon_sym_If] = ACTIONS(4700),
    [anon_sym_else] = ACTIONS(4700),
    [anon_sym_ELSE] = ACTIONS(4700),
    [anon_sym_Else] = ACTIONS(4700),
    [anon_sym_case] = ACTIONS(4700),
    [anon_sym_CASE] = ACTIONS(4700),
    [anon_sym_Case] = ACTIONS(4700),
    [anon_sym_for] = ACTIONS(4700),
    [anon_sym_FOR] = ACTIONS(4700),
    [anon_sym_For] = ACTIONS(4700),
    [anon_sym_foreach] = ACTIONS(4700),
    [anon_sym_FOREACH] = ACTIONS(4700),
    [anon_sym_Foreach] = ACTIONS(4700),
    [anon_sym_while] = ACTIONS(4700),
    [anon_sym_WHILE] = ACTIONS(4700),
    [anon_sym_While] = ACTIONS(4700),
    [anon_sym_repeat] = ACTIONS(4700),
    [anon_sym_REPEAT] = ACTIONS(4700),
    [anon_sym_Repeat] = ACTIONS(4700),
    [anon_sym_exit] = ACTIONS(4700),
    [anon_sym_EXIT] = ACTIONS(4700),
    [anon_sym_Exit] = ACTIONS(4700),
    [anon_sym_continue] = ACTIONS(4700),
    [anon_sym_CONTINUE] = ACTIONS(4700),
    [anon_sym_Continue] = ACTIONS(4700),
    [anon_sym_break] = ACTIONS(4700),
    [anon_sym_BREAK] = ACTIONS(4700),
    [anon_sym_Break] = ACTIONS(4700),
    [anon_sym_with] = ACTIONS(4700),
    [anon_sym_WITH] = ACTIONS(4700),
    [anon_sym_With] = ACTIONS(4700),
    [sym_asserterror_keyword] = ACTIONS(4702),
    [sym_page_keyword] = ACTIONS(4700),
    [anon_sym_codeunit] = ACTIONS(4700),
    [anon_sym_CODEUNIT] = ACTIONS(4700),
    [anon_sym_Codeunit] = ACTIONS(4700),
    [anon_sym_CodeUnit] = ACTIONS(4700),
    [anon_sym_COdeunit] = ACTIONS(4700),
    [anon_sym_codeUnit] = ACTIONS(4700),
    [sym_report_keyword] = ACTIONS(4700),
    [sym_query_keyword] = ACTIONS(4700),
    [anon_sym_xmlport] = ACTIONS(4700),
    [anon_sym_XMLPORT] = ACTIONS(4700),
    [anon_sym_Xmlport] = ACTIONS(4700),
    [anon_sym_XMLport] = ACTIONS(4700),
    [anon_sym_XMLPort] = ACTIONS(4700),
    [anon_sym_XmlPort] = ACTIONS(4700),
    [anon_sym_enum] = ACTIONS(4700),
    [anon_sym_ENUM] = ACTIONS(4700),
    [anon_sym_Enum] = ACTIONS(4700),
    [anon_sym_eNUM] = ACTIONS(4700),
    [anon_sym_eNum] = ACTIONS(4700),
    [anon_sym_ENum] = ACTIONS(4700),
    [sym_quoted_identifier] = ACTIONS(4702),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4702),
    [sym_integer] = ACTIONS(4700),
    [sym_continue_as_identifier] = ACTIONS(4702),
    [sym_preproc_open] = ACTIONS(4702),
    [sym_end_keyword] = ACTIONS(4702),
  },
  [STATE(2314)] = {
    [sym_identifier] = ACTIONS(4704),
    [anon_sym_SEMI] = ACTIONS(4706),
    [anon_sym_DASH] = ACTIONS(4706),
    [aux_sym_boolean_token1] = ACTIONS(4704),
    [aux_sym_boolean_token2] = ACTIONS(4704),
    [sym_decimal] = ACTIONS(4704),
    [anon_sym_LPAREN] = ACTIONS(4706),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4704),
    [anon_sym_LBRACK] = ACTIONS(4706),
    [aux_sym_record_type_token1] = ACTIONS(4704),
    [aux_sym_basic_type_token21] = ACTIONS(4704),
    [aux_sym_basic_type_token22] = ACTIONS(4704),
    [aux_sym_basic_type_token48] = ACTIONS(4704),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4704),
    [anon_sym_POUNDif] = ACTIONS(4706),
    [anon_sym_POUNDIF] = ACTIONS(4706),
    [anon_sym_POUNDIf] = ACTIONS(4706),
    [anon_sym_not] = ACTIONS(4704),
    [anon_sym_NOT] = ACTIONS(4704),
    [anon_sym_Not] = ACTIONS(4704),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4704),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4704),
    [anon_sym_PLUS] = ACTIONS(4706),
    [sym_datetime_literal] = ACTIONS(4706),
    [sym_date_literal] = ACTIONS(4704),
    [sym_time_literal] = ACTIONS(4704),
    [sym_biginteger_literal] = ACTIONS(4706),
    [anon_sym_if] = ACTIONS(4704),
    [anon_sym_IF] = ACTIONS(4704),
    [anon_sym_If] = ACTIONS(4704),
    [anon_sym_else] = ACTIONS(4704),
    [anon_sym_ELSE] = ACTIONS(4704),
    [anon_sym_Else] = ACTIONS(4704),
    [anon_sym_case] = ACTIONS(4704),
    [anon_sym_CASE] = ACTIONS(4704),
    [anon_sym_Case] = ACTIONS(4704),
    [anon_sym_for] = ACTIONS(4704),
    [anon_sym_FOR] = ACTIONS(4704),
    [anon_sym_For] = ACTIONS(4704),
    [anon_sym_foreach] = ACTIONS(4704),
    [anon_sym_FOREACH] = ACTIONS(4704),
    [anon_sym_Foreach] = ACTIONS(4704),
    [anon_sym_while] = ACTIONS(4704),
    [anon_sym_WHILE] = ACTIONS(4704),
    [anon_sym_While] = ACTIONS(4704),
    [anon_sym_repeat] = ACTIONS(4704),
    [anon_sym_REPEAT] = ACTIONS(4704),
    [anon_sym_Repeat] = ACTIONS(4704),
    [anon_sym_exit] = ACTIONS(4704),
    [anon_sym_EXIT] = ACTIONS(4704),
    [anon_sym_Exit] = ACTIONS(4704),
    [anon_sym_continue] = ACTIONS(4704),
    [anon_sym_CONTINUE] = ACTIONS(4704),
    [anon_sym_Continue] = ACTIONS(4704),
    [anon_sym_break] = ACTIONS(4704),
    [anon_sym_BREAK] = ACTIONS(4704),
    [anon_sym_Break] = ACTIONS(4704),
    [anon_sym_with] = ACTIONS(4704),
    [anon_sym_WITH] = ACTIONS(4704),
    [anon_sym_With] = ACTIONS(4704),
    [sym_asserterror_keyword] = ACTIONS(4706),
    [sym_page_keyword] = ACTIONS(4704),
    [anon_sym_codeunit] = ACTIONS(4704),
    [anon_sym_CODEUNIT] = ACTIONS(4704),
    [anon_sym_Codeunit] = ACTIONS(4704),
    [anon_sym_CodeUnit] = ACTIONS(4704),
    [anon_sym_COdeunit] = ACTIONS(4704),
    [anon_sym_codeUnit] = ACTIONS(4704),
    [sym_report_keyword] = ACTIONS(4704),
    [sym_query_keyword] = ACTIONS(4704),
    [anon_sym_xmlport] = ACTIONS(4704),
    [anon_sym_XMLPORT] = ACTIONS(4704),
    [anon_sym_Xmlport] = ACTIONS(4704),
    [anon_sym_XMLport] = ACTIONS(4704),
    [anon_sym_XMLPort] = ACTIONS(4704),
    [anon_sym_XmlPort] = ACTIONS(4704),
    [anon_sym_enum] = ACTIONS(4704),
    [anon_sym_ENUM] = ACTIONS(4704),
    [anon_sym_Enum] = ACTIONS(4704),
    [anon_sym_eNUM] = ACTIONS(4704),
    [anon_sym_eNum] = ACTIONS(4704),
    [anon_sym_ENum] = ACTIONS(4704),
    [sym_quoted_identifier] = ACTIONS(4706),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4706),
    [sym_integer] = ACTIONS(4704),
    [sym_continue_as_identifier] = ACTIONS(4706),
    [sym_preproc_open] = ACTIONS(4706),
    [sym_end_keyword] = ACTIONS(4706),
  },
  [STATE(2315)] = {
    [sym_identifier] = ACTIONS(4293),
    [anon_sym_SEMI] = ACTIONS(4295),
    [anon_sym_DASH] = ACTIONS(4295),
    [aux_sym_boolean_token1] = ACTIONS(4293),
    [aux_sym_boolean_token2] = ACTIONS(4293),
    [sym_decimal] = ACTIONS(4293),
    [anon_sym_LPAREN] = ACTIONS(4295),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4293),
    [anon_sym_LBRACK] = ACTIONS(4295),
    [aux_sym_record_type_token1] = ACTIONS(4293),
    [aux_sym_basic_type_token21] = ACTIONS(4293),
    [aux_sym_basic_type_token22] = ACTIONS(4293),
    [aux_sym_basic_type_token48] = ACTIONS(4293),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4293),
    [anon_sym_POUNDif] = ACTIONS(4295),
    [anon_sym_POUNDIF] = ACTIONS(4295),
    [anon_sym_POUNDIf] = ACTIONS(4295),
    [anon_sym_not] = ACTIONS(4293),
    [anon_sym_NOT] = ACTIONS(4293),
    [anon_sym_Not] = ACTIONS(4293),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4293),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4293),
    [anon_sym_PLUS] = ACTIONS(4295),
    [sym_datetime_literal] = ACTIONS(4295),
    [sym_date_literal] = ACTIONS(4293),
    [sym_time_literal] = ACTIONS(4293),
    [sym_biginteger_literal] = ACTIONS(4295),
    [anon_sym_if] = ACTIONS(4293),
    [anon_sym_IF] = ACTIONS(4293),
    [anon_sym_If] = ACTIONS(4293),
    [anon_sym_else] = ACTIONS(4293),
    [anon_sym_ELSE] = ACTIONS(4293),
    [anon_sym_Else] = ACTIONS(4293),
    [anon_sym_case] = ACTIONS(4293),
    [anon_sym_CASE] = ACTIONS(4293),
    [anon_sym_Case] = ACTIONS(4293),
    [anon_sym_for] = ACTIONS(4293),
    [anon_sym_FOR] = ACTIONS(4293),
    [anon_sym_For] = ACTIONS(4293),
    [anon_sym_foreach] = ACTIONS(4293),
    [anon_sym_FOREACH] = ACTIONS(4293),
    [anon_sym_Foreach] = ACTIONS(4293),
    [anon_sym_while] = ACTIONS(4293),
    [anon_sym_WHILE] = ACTIONS(4293),
    [anon_sym_While] = ACTIONS(4293),
    [anon_sym_repeat] = ACTIONS(4293),
    [anon_sym_REPEAT] = ACTIONS(4293),
    [anon_sym_Repeat] = ACTIONS(4293),
    [anon_sym_exit] = ACTIONS(4293),
    [anon_sym_EXIT] = ACTIONS(4293),
    [anon_sym_Exit] = ACTIONS(4293),
    [anon_sym_continue] = ACTIONS(4293),
    [anon_sym_CONTINUE] = ACTIONS(4293),
    [anon_sym_Continue] = ACTIONS(4293),
    [anon_sym_break] = ACTIONS(4293),
    [anon_sym_BREAK] = ACTIONS(4293),
    [anon_sym_Break] = ACTIONS(4293),
    [anon_sym_with] = ACTIONS(4293),
    [anon_sym_WITH] = ACTIONS(4293),
    [anon_sym_With] = ACTIONS(4293),
    [sym_asserterror_keyword] = ACTIONS(4295),
    [sym_page_keyword] = ACTIONS(4293),
    [anon_sym_codeunit] = ACTIONS(4293),
    [anon_sym_CODEUNIT] = ACTIONS(4293),
    [anon_sym_Codeunit] = ACTIONS(4293),
    [anon_sym_CodeUnit] = ACTIONS(4293),
    [anon_sym_COdeunit] = ACTIONS(4293),
    [anon_sym_codeUnit] = ACTIONS(4293),
    [sym_report_keyword] = ACTIONS(4293),
    [sym_query_keyword] = ACTIONS(4293),
    [anon_sym_xmlport] = ACTIONS(4293),
    [anon_sym_XMLPORT] = ACTIONS(4293),
    [anon_sym_Xmlport] = ACTIONS(4293),
    [anon_sym_XMLport] = ACTIONS(4293),
    [anon_sym_XMLPort] = ACTIONS(4293),
    [anon_sym_XmlPort] = ACTIONS(4293),
    [anon_sym_enum] = ACTIONS(4293),
    [anon_sym_ENUM] = ACTIONS(4293),
    [anon_sym_Enum] = ACTIONS(4293),
    [anon_sym_eNUM] = ACTIONS(4293),
    [anon_sym_eNum] = ACTIONS(4293),
    [anon_sym_ENum] = ACTIONS(4293),
    [sym_quoted_identifier] = ACTIONS(4295),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4295),
    [sym_integer] = ACTIONS(4293),
    [sym_continue_as_identifier] = ACTIONS(4295),
    [sym_preproc_open] = ACTIONS(4295),
    [sym_end_keyword] = ACTIONS(4295),
  },
  [STATE(2316)] = {
    [sym_identifier] = ACTIONS(4297),
    [anon_sym_SEMI] = ACTIONS(4299),
    [anon_sym_DASH] = ACTIONS(4299),
    [aux_sym_boolean_token1] = ACTIONS(4297),
    [aux_sym_boolean_token2] = ACTIONS(4297),
    [sym_decimal] = ACTIONS(4297),
    [anon_sym_LPAREN] = ACTIONS(4299),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4297),
    [anon_sym_LBRACK] = ACTIONS(4299),
    [aux_sym_record_type_token1] = ACTIONS(4297),
    [aux_sym_basic_type_token21] = ACTIONS(4297),
    [aux_sym_basic_type_token22] = ACTIONS(4297),
    [aux_sym_basic_type_token48] = ACTIONS(4297),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4297),
    [anon_sym_POUNDif] = ACTIONS(4299),
    [anon_sym_POUNDIF] = ACTIONS(4299),
    [anon_sym_POUNDIf] = ACTIONS(4299),
    [anon_sym_not] = ACTIONS(4297),
    [anon_sym_NOT] = ACTIONS(4297),
    [anon_sym_Not] = ACTIONS(4297),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4297),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4297),
    [anon_sym_PLUS] = ACTIONS(4299),
    [sym_datetime_literal] = ACTIONS(4299),
    [sym_date_literal] = ACTIONS(4297),
    [sym_time_literal] = ACTIONS(4297),
    [sym_biginteger_literal] = ACTIONS(4299),
    [anon_sym_if] = ACTIONS(4297),
    [anon_sym_IF] = ACTIONS(4297),
    [anon_sym_If] = ACTIONS(4297),
    [anon_sym_else] = ACTIONS(4297),
    [anon_sym_ELSE] = ACTIONS(4297),
    [anon_sym_Else] = ACTIONS(4297),
    [anon_sym_case] = ACTIONS(4297),
    [anon_sym_CASE] = ACTIONS(4297),
    [anon_sym_Case] = ACTIONS(4297),
    [anon_sym_for] = ACTIONS(4297),
    [anon_sym_FOR] = ACTIONS(4297),
    [anon_sym_For] = ACTIONS(4297),
    [anon_sym_foreach] = ACTIONS(4297),
    [anon_sym_FOREACH] = ACTIONS(4297),
    [anon_sym_Foreach] = ACTIONS(4297),
    [anon_sym_while] = ACTIONS(4297),
    [anon_sym_WHILE] = ACTIONS(4297),
    [anon_sym_While] = ACTIONS(4297),
    [anon_sym_repeat] = ACTIONS(4297),
    [anon_sym_REPEAT] = ACTIONS(4297),
    [anon_sym_Repeat] = ACTIONS(4297),
    [anon_sym_exit] = ACTIONS(4297),
    [anon_sym_EXIT] = ACTIONS(4297),
    [anon_sym_Exit] = ACTIONS(4297),
    [anon_sym_continue] = ACTIONS(4297),
    [anon_sym_CONTINUE] = ACTIONS(4297),
    [anon_sym_Continue] = ACTIONS(4297),
    [anon_sym_break] = ACTIONS(4297),
    [anon_sym_BREAK] = ACTIONS(4297),
    [anon_sym_Break] = ACTIONS(4297),
    [anon_sym_with] = ACTIONS(4297),
    [anon_sym_WITH] = ACTIONS(4297),
    [anon_sym_With] = ACTIONS(4297),
    [sym_asserterror_keyword] = ACTIONS(4299),
    [sym_page_keyword] = ACTIONS(4297),
    [anon_sym_codeunit] = ACTIONS(4297),
    [anon_sym_CODEUNIT] = ACTIONS(4297),
    [anon_sym_Codeunit] = ACTIONS(4297),
    [anon_sym_CodeUnit] = ACTIONS(4297),
    [anon_sym_COdeunit] = ACTIONS(4297),
    [anon_sym_codeUnit] = ACTIONS(4297),
    [sym_report_keyword] = ACTIONS(4297),
    [sym_query_keyword] = ACTIONS(4297),
    [anon_sym_xmlport] = ACTIONS(4297),
    [anon_sym_XMLPORT] = ACTIONS(4297),
    [anon_sym_Xmlport] = ACTIONS(4297),
    [anon_sym_XMLport] = ACTIONS(4297),
    [anon_sym_XMLPort] = ACTIONS(4297),
    [anon_sym_XmlPort] = ACTIONS(4297),
    [anon_sym_enum] = ACTIONS(4297),
    [anon_sym_ENUM] = ACTIONS(4297),
    [anon_sym_Enum] = ACTIONS(4297),
    [anon_sym_eNUM] = ACTIONS(4297),
    [anon_sym_eNum] = ACTIONS(4297),
    [anon_sym_ENum] = ACTIONS(4297),
    [sym_quoted_identifier] = ACTIONS(4299),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4299),
    [sym_integer] = ACTIONS(4297),
    [sym_continue_as_identifier] = ACTIONS(4299),
    [sym_preproc_open] = ACTIONS(4299),
    [sym_end_keyword] = ACTIONS(4299),
  },
  [STATE(2317)] = {
    [sym_identifier] = ACTIONS(4301),
    [anon_sym_SEMI] = ACTIONS(4303),
    [anon_sym_DASH] = ACTIONS(4303),
    [aux_sym_boolean_token1] = ACTIONS(4301),
    [aux_sym_boolean_token2] = ACTIONS(4301),
    [sym_decimal] = ACTIONS(4301),
    [anon_sym_LPAREN] = ACTIONS(4303),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4301),
    [anon_sym_LBRACK] = ACTIONS(4303),
    [aux_sym_record_type_token1] = ACTIONS(4301),
    [aux_sym_basic_type_token21] = ACTIONS(4301),
    [aux_sym_basic_type_token22] = ACTIONS(4301),
    [aux_sym_basic_type_token48] = ACTIONS(4301),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4301),
    [anon_sym_POUNDif] = ACTIONS(4303),
    [anon_sym_POUNDIF] = ACTIONS(4303),
    [anon_sym_POUNDIf] = ACTIONS(4303),
    [anon_sym_not] = ACTIONS(4301),
    [anon_sym_NOT] = ACTIONS(4301),
    [anon_sym_Not] = ACTIONS(4301),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4301),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4301),
    [anon_sym_PLUS] = ACTIONS(4303),
    [sym_datetime_literal] = ACTIONS(4303),
    [sym_date_literal] = ACTIONS(4301),
    [sym_time_literal] = ACTIONS(4301),
    [sym_biginteger_literal] = ACTIONS(4303),
    [anon_sym_if] = ACTIONS(4301),
    [anon_sym_IF] = ACTIONS(4301),
    [anon_sym_If] = ACTIONS(4301),
    [anon_sym_else] = ACTIONS(4301),
    [anon_sym_ELSE] = ACTIONS(4301),
    [anon_sym_Else] = ACTIONS(4301),
    [anon_sym_case] = ACTIONS(4301),
    [anon_sym_CASE] = ACTIONS(4301),
    [anon_sym_Case] = ACTIONS(4301),
    [anon_sym_for] = ACTIONS(4301),
    [anon_sym_FOR] = ACTIONS(4301),
    [anon_sym_For] = ACTIONS(4301),
    [anon_sym_foreach] = ACTIONS(4301),
    [anon_sym_FOREACH] = ACTIONS(4301),
    [anon_sym_Foreach] = ACTIONS(4301),
    [anon_sym_while] = ACTIONS(4301),
    [anon_sym_WHILE] = ACTIONS(4301),
    [anon_sym_While] = ACTIONS(4301),
    [anon_sym_repeat] = ACTIONS(4301),
    [anon_sym_REPEAT] = ACTIONS(4301),
    [anon_sym_Repeat] = ACTIONS(4301),
    [anon_sym_exit] = ACTIONS(4301),
    [anon_sym_EXIT] = ACTIONS(4301),
    [anon_sym_Exit] = ACTIONS(4301),
    [anon_sym_continue] = ACTIONS(4301),
    [anon_sym_CONTINUE] = ACTIONS(4301),
    [anon_sym_Continue] = ACTIONS(4301),
    [anon_sym_break] = ACTIONS(4301),
    [anon_sym_BREAK] = ACTIONS(4301),
    [anon_sym_Break] = ACTIONS(4301),
    [anon_sym_with] = ACTIONS(4301),
    [anon_sym_WITH] = ACTIONS(4301),
    [anon_sym_With] = ACTIONS(4301),
    [sym_asserterror_keyword] = ACTIONS(4303),
    [sym_page_keyword] = ACTIONS(4301),
    [anon_sym_codeunit] = ACTIONS(4301),
    [anon_sym_CODEUNIT] = ACTIONS(4301),
    [anon_sym_Codeunit] = ACTIONS(4301),
    [anon_sym_CodeUnit] = ACTIONS(4301),
    [anon_sym_COdeunit] = ACTIONS(4301),
    [anon_sym_codeUnit] = ACTIONS(4301),
    [sym_report_keyword] = ACTIONS(4301),
    [sym_query_keyword] = ACTIONS(4301),
    [anon_sym_xmlport] = ACTIONS(4301),
    [anon_sym_XMLPORT] = ACTIONS(4301),
    [anon_sym_Xmlport] = ACTIONS(4301),
    [anon_sym_XMLport] = ACTIONS(4301),
    [anon_sym_XMLPort] = ACTIONS(4301),
    [anon_sym_XmlPort] = ACTIONS(4301),
    [anon_sym_enum] = ACTIONS(4301),
    [anon_sym_ENUM] = ACTIONS(4301),
    [anon_sym_Enum] = ACTIONS(4301),
    [anon_sym_eNUM] = ACTIONS(4301),
    [anon_sym_eNum] = ACTIONS(4301),
    [anon_sym_ENum] = ACTIONS(4301),
    [sym_quoted_identifier] = ACTIONS(4303),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4303),
    [sym_integer] = ACTIONS(4301),
    [sym_continue_as_identifier] = ACTIONS(4303),
    [sym_preproc_open] = ACTIONS(4303),
    [sym_end_keyword] = ACTIONS(4303),
  },
  [STATE(2318)] = {
    [sym_identifier] = ACTIONS(4305),
    [anon_sym_SEMI] = ACTIONS(4307),
    [anon_sym_DASH] = ACTIONS(4307),
    [aux_sym_boolean_token1] = ACTIONS(4305),
    [aux_sym_boolean_token2] = ACTIONS(4305),
    [sym_decimal] = ACTIONS(4305),
    [anon_sym_LPAREN] = ACTIONS(4307),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4305),
    [anon_sym_LBRACK] = ACTIONS(4307),
    [aux_sym_record_type_token1] = ACTIONS(4305),
    [aux_sym_basic_type_token21] = ACTIONS(4305),
    [aux_sym_basic_type_token22] = ACTIONS(4305),
    [aux_sym_basic_type_token48] = ACTIONS(4305),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4305),
    [anon_sym_POUNDif] = ACTIONS(4307),
    [anon_sym_POUNDIF] = ACTIONS(4307),
    [anon_sym_POUNDIf] = ACTIONS(4307),
    [anon_sym_not] = ACTIONS(4305),
    [anon_sym_NOT] = ACTIONS(4305),
    [anon_sym_Not] = ACTIONS(4305),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4305),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4305),
    [anon_sym_PLUS] = ACTIONS(4307),
    [sym_datetime_literal] = ACTIONS(4307),
    [sym_date_literal] = ACTIONS(4305),
    [sym_time_literal] = ACTIONS(4305),
    [sym_biginteger_literal] = ACTIONS(4307),
    [anon_sym_if] = ACTIONS(4305),
    [anon_sym_IF] = ACTIONS(4305),
    [anon_sym_If] = ACTIONS(4305),
    [anon_sym_else] = ACTIONS(4305),
    [anon_sym_ELSE] = ACTIONS(4305),
    [anon_sym_Else] = ACTIONS(4305),
    [anon_sym_case] = ACTIONS(4305),
    [anon_sym_CASE] = ACTIONS(4305),
    [anon_sym_Case] = ACTIONS(4305),
    [anon_sym_for] = ACTIONS(4305),
    [anon_sym_FOR] = ACTIONS(4305),
    [anon_sym_For] = ACTIONS(4305),
    [anon_sym_foreach] = ACTIONS(4305),
    [anon_sym_FOREACH] = ACTIONS(4305),
    [anon_sym_Foreach] = ACTIONS(4305),
    [anon_sym_while] = ACTIONS(4305),
    [anon_sym_WHILE] = ACTIONS(4305),
    [anon_sym_While] = ACTIONS(4305),
    [anon_sym_repeat] = ACTIONS(4305),
    [anon_sym_REPEAT] = ACTIONS(4305),
    [anon_sym_Repeat] = ACTIONS(4305),
    [anon_sym_exit] = ACTIONS(4305),
    [anon_sym_EXIT] = ACTIONS(4305),
    [anon_sym_Exit] = ACTIONS(4305),
    [anon_sym_continue] = ACTIONS(4305),
    [anon_sym_CONTINUE] = ACTIONS(4305),
    [anon_sym_Continue] = ACTIONS(4305),
    [anon_sym_break] = ACTIONS(4305),
    [anon_sym_BREAK] = ACTIONS(4305),
    [anon_sym_Break] = ACTIONS(4305),
    [anon_sym_with] = ACTIONS(4305),
    [anon_sym_WITH] = ACTIONS(4305),
    [anon_sym_With] = ACTIONS(4305),
    [sym_asserterror_keyword] = ACTIONS(4307),
    [sym_page_keyword] = ACTIONS(4305),
    [anon_sym_codeunit] = ACTIONS(4305),
    [anon_sym_CODEUNIT] = ACTIONS(4305),
    [anon_sym_Codeunit] = ACTIONS(4305),
    [anon_sym_CodeUnit] = ACTIONS(4305),
    [anon_sym_COdeunit] = ACTIONS(4305),
    [anon_sym_codeUnit] = ACTIONS(4305),
    [sym_report_keyword] = ACTIONS(4305),
    [sym_query_keyword] = ACTIONS(4305),
    [anon_sym_xmlport] = ACTIONS(4305),
    [anon_sym_XMLPORT] = ACTIONS(4305),
    [anon_sym_Xmlport] = ACTIONS(4305),
    [anon_sym_XMLport] = ACTIONS(4305),
    [anon_sym_XMLPort] = ACTIONS(4305),
    [anon_sym_XmlPort] = ACTIONS(4305),
    [anon_sym_enum] = ACTIONS(4305),
    [anon_sym_ENUM] = ACTIONS(4305),
    [anon_sym_Enum] = ACTIONS(4305),
    [anon_sym_eNUM] = ACTIONS(4305),
    [anon_sym_eNum] = ACTIONS(4305),
    [anon_sym_ENum] = ACTIONS(4305),
    [sym_quoted_identifier] = ACTIONS(4307),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4307),
    [sym_integer] = ACTIONS(4305),
    [sym_continue_as_identifier] = ACTIONS(4307),
    [sym_preproc_open] = ACTIONS(4307),
    [sym_end_keyword] = ACTIONS(4307),
  },
  [STATE(2319)] = {
    [sym_identifier] = ACTIONS(4700),
    [anon_sym_SEMI] = ACTIONS(4702),
    [anon_sym_DASH] = ACTIONS(4702),
    [aux_sym_boolean_token1] = ACTIONS(4700),
    [aux_sym_boolean_token2] = ACTIONS(4700),
    [sym_decimal] = ACTIONS(4700),
    [anon_sym_LPAREN] = ACTIONS(4702),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4700),
    [anon_sym_LBRACK] = ACTIONS(4702),
    [aux_sym_record_type_token1] = ACTIONS(4700),
    [aux_sym_basic_type_token21] = ACTIONS(4700),
    [aux_sym_basic_type_token22] = ACTIONS(4700),
    [aux_sym_basic_type_token48] = ACTIONS(4700),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4700),
    [anon_sym_POUNDif] = ACTIONS(4702),
    [anon_sym_POUNDIF] = ACTIONS(4702),
    [anon_sym_POUNDIf] = ACTIONS(4702),
    [anon_sym_not] = ACTIONS(4700),
    [anon_sym_NOT] = ACTIONS(4700),
    [anon_sym_Not] = ACTIONS(4700),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4700),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4700),
    [anon_sym_PLUS] = ACTIONS(4702),
    [sym_datetime_literal] = ACTIONS(4702),
    [sym_date_literal] = ACTIONS(4700),
    [sym_time_literal] = ACTIONS(4700),
    [sym_biginteger_literal] = ACTIONS(4702),
    [anon_sym_if] = ACTIONS(4700),
    [anon_sym_IF] = ACTIONS(4700),
    [anon_sym_If] = ACTIONS(4700),
    [anon_sym_else] = ACTIONS(4700),
    [anon_sym_ELSE] = ACTIONS(4700),
    [anon_sym_Else] = ACTIONS(4700),
    [anon_sym_case] = ACTIONS(4700),
    [anon_sym_CASE] = ACTIONS(4700),
    [anon_sym_Case] = ACTIONS(4700),
    [anon_sym_for] = ACTIONS(4700),
    [anon_sym_FOR] = ACTIONS(4700),
    [anon_sym_For] = ACTIONS(4700),
    [anon_sym_foreach] = ACTIONS(4700),
    [anon_sym_FOREACH] = ACTIONS(4700),
    [anon_sym_Foreach] = ACTIONS(4700),
    [anon_sym_while] = ACTIONS(4700),
    [anon_sym_WHILE] = ACTIONS(4700),
    [anon_sym_While] = ACTIONS(4700),
    [anon_sym_repeat] = ACTIONS(4700),
    [anon_sym_REPEAT] = ACTIONS(4700),
    [anon_sym_Repeat] = ACTIONS(4700),
    [anon_sym_exit] = ACTIONS(4700),
    [anon_sym_EXIT] = ACTIONS(4700),
    [anon_sym_Exit] = ACTIONS(4700),
    [anon_sym_continue] = ACTIONS(4700),
    [anon_sym_CONTINUE] = ACTIONS(4700),
    [anon_sym_Continue] = ACTIONS(4700),
    [anon_sym_break] = ACTIONS(4700),
    [anon_sym_BREAK] = ACTIONS(4700),
    [anon_sym_Break] = ACTIONS(4700),
    [anon_sym_with] = ACTIONS(4700),
    [anon_sym_WITH] = ACTIONS(4700),
    [anon_sym_With] = ACTIONS(4700),
    [sym_asserterror_keyword] = ACTIONS(4702),
    [sym_page_keyword] = ACTIONS(4700),
    [anon_sym_codeunit] = ACTIONS(4700),
    [anon_sym_CODEUNIT] = ACTIONS(4700),
    [anon_sym_Codeunit] = ACTIONS(4700),
    [anon_sym_CodeUnit] = ACTIONS(4700),
    [anon_sym_COdeunit] = ACTIONS(4700),
    [anon_sym_codeUnit] = ACTIONS(4700),
    [sym_report_keyword] = ACTIONS(4700),
    [sym_query_keyword] = ACTIONS(4700),
    [anon_sym_xmlport] = ACTIONS(4700),
    [anon_sym_XMLPORT] = ACTIONS(4700),
    [anon_sym_Xmlport] = ACTIONS(4700),
    [anon_sym_XMLport] = ACTIONS(4700),
    [anon_sym_XMLPort] = ACTIONS(4700),
    [anon_sym_XmlPort] = ACTIONS(4700),
    [anon_sym_enum] = ACTIONS(4700),
    [anon_sym_ENUM] = ACTIONS(4700),
    [anon_sym_Enum] = ACTIONS(4700),
    [anon_sym_eNUM] = ACTIONS(4700),
    [anon_sym_eNum] = ACTIONS(4700),
    [anon_sym_ENum] = ACTIONS(4700),
    [sym_quoted_identifier] = ACTIONS(4702),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4702),
    [sym_integer] = ACTIONS(4700),
    [sym_continue_as_identifier] = ACTIONS(4702),
    [sym_preproc_open] = ACTIONS(4702),
    [sym_end_keyword] = ACTIONS(4702),
  },
  [STATE(2320)] = {
    [sym_identifier] = ACTIONS(4708),
    [anon_sym_SEMI] = ACTIONS(4710),
    [anon_sym_DASH] = ACTIONS(4710),
    [aux_sym_boolean_token1] = ACTIONS(4708),
    [aux_sym_boolean_token2] = ACTIONS(4708),
    [sym_decimal] = ACTIONS(4708),
    [anon_sym_LPAREN] = ACTIONS(4710),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4708),
    [anon_sym_LBRACK] = ACTIONS(4710),
    [aux_sym_record_type_token1] = ACTIONS(4708),
    [aux_sym_basic_type_token21] = ACTIONS(4708),
    [aux_sym_basic_type_token22] = ACTIONS(4708),
    [aux_sym_basic_type_token48] = ACTIONS(4708),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4708),
    [anon_sym_POUNDif] = ACTIONS(4710),
    [anon_sym_POUNDIF] = ACTIONS(4710),
    [anon_sym_POUNDIf] = ACTIONS(4710),
    [anon_sym_not] = ACTIONS(4708),
    [anon_sym_NOT] = ACTIONS(4708),
    [anon_sym_Not] = ACTIONS(4708),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4708),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4708),
    [anon_sym_PLUS] = ACTIONS(4710),
    [sym_datetime_literal] = ACTIONS(4710),
    [sym_date_literal] = ACTIONS(4708),
    [sym_time_literal] = ACTIONS(4708),
    [sym_biginteger_literal] = ACTIONS(4710),
    [anon_sym_if] = ACTIONS(4708),
    [anon_sym_IF] = ACTIONS(4708),
    [anon_sym_If] = ACTIONS(4708),
    [anon_sym_else] = ACTIONS(4708),
    [anon_sym_ELSE] = ACTIONS(4708),
    [anon_sym_Else] = ACTIONS(4708),
    [anon_sym_case] = ACTIONS(4708),
    [anon_sym_CASE] = ACTIONS(4708),
    [anon_sym_Case] = ACTIONS(4708),
    [anon_sym_for] = ACTIONS(4708),
    [anon_sym_FOR] = ACTIONS(4708),
    [anon_sym_For] = ACTIONS(4708),
    [anon_sym_foreach] = ACTIONS(4708),
    [anon_sym_FOREACH] = ACTIONS(4708),
    [anon_sym_Foreach] = ACTIONS(4708),
    [anon_sym_while] = ACTIONS(4708),
    [anon_sym_WHILE] = ACTIONS(4708),
    [anon_sym_While] = ACTIONS(4708),
    [anon_sym_repeat] = ACTIONS(4708),
    [anon_sym_REPEAT] = ACTIONS(4708),
    [anon_sym_Repeat] = ACTIONS(4708),
    [anon_sym_exit] = ACTIONS(4708),
    [anon_sym_EXIT] = ACTIONS(4708),
    [anon_sym_Exit] = ACTIONS(4708),
    [anon_sym_continue] = ACTIONS(4708),
    [anon_sym_CONTINUE] = ACTIONS(4708),
    [anon_sym_Continue] = ACTIONS(4708),
    [anon_sym_break] = ACTIONS(4708),
    [anon_sym_BREAK] = ACTIONS(4708),
    [anon_sym_Break] = ACTIONS(4708),
    [anon_sym_with] = ACTIONS(4708),
    [anon_sym_WITH] = ACTIONS(4708),
    [anon_sym_With] = ACTIONS(4708),
    [sym_asserterror_keyword] = ACTIONS(4710),
    [sym_page_keyword] = ACTIONS(4708),
    [anon_sym_codeunit] = ACTIONS(4708),
    [anon_sym_CODEUNIT] = ACTIONS(4708),
    [anon_sym_Codeunit] = ACTIONS(4708),
    [anon_sym_CodeUnit] = ACTIONS(4708),
    [anon_sym_COdeunit] = ACTIONS(4708),
    [anon_sym_codeUnit] = ACTIONS(4708),
    [sym_report_keyword] = ACTIONS(4708),
    [sym_query_keyword] = ACTIONS(4708),
    [anon_sym_xmlport] = ACTIONS(4708),
    [anon_sym_XMLPORT] = ACTIONS(4708),
    [anon_sym_Xmlport] = ACTIONS(4708),
    [anon_sym_XMLport] = ACTIONS(4708),
    [anon_sym_XMLPort] = ACTIONS(4708),
    [anon_sym_XmlPort] = ACTIONS(4708),
    [anon_sym_enum] = ACTIONS(4708),
    [anon_sym_ENUM] = ACTIONS(4708),
    [anon_sym_Enum] = ACTIONS(4708),
    [anon_sym_eNUM] = ACTIONS(4708),
    [anon_sym_eNum] = ACTIONS(4708),
    [anon_sym_ENum] = ACTIONS(4708),
    [sym_quoted_identifier] = ACTIONS(4710),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4710),
    [sym_integer] = ACTIONS(4708),
    [sym_continue_as_identifier] = ACTIONS(4710),
    [sym_preproc_open] = ACTIONS(4710),
    [sym_end_keyword] = ACTIONS(4710),
  },
  [STATE(2321)] = {
    [sym_identifier] = ACTIONS(4309),
    [anon_sym_SEMI] = ACTIONS(4311),
    [anon_sym_DASH] = ACTIONS(4311),
    [aux_sym_boolean_token1] = ACTIONS(4309),
    [aux_sym_boolean_token2] = ACTIONS(4309),
    [sym_decimal] = ACTIONS(4309),
    [anon_sym_LPAREN] = ACTIONS(4311),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4309),
    [anon_sym_LBRACK] = ACTIONS(4311),
    [aux_sym_record_type_token1] = ACTIONS(4309),
    [aux_sym_basic_type_token21] = ACTIONS(4309),
    [aux_sym_basic_type_token22] = ACTIONS(4309),
    [aux_sym_basic_type_token48] = ACTIONS(4309),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4309),
    [anon_sym_POUNDif] = ACTIONS(4311),
    [anon_sym_POUNDIF] = ACTIONS(4311),
    [anon_sym_POUNDIf] = ACTIONS(4311),
    [anon_sym_not] = ACTIONS(4309),
    [anon_sym_NOT] = ACTIONS(4309),
    [anon_sym_Not] = ACTIONS(4309),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4309),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4309),
    [anon_sym_PLUS] = ACTIONS(4311),
    [sym_datetime_literal] = ACTIONS(4311),
    [sym_date_literal] = ACTIONS(4309),
    [sym_time_literal] = ACTIONS(4309),
    [sym_biginteger_literal] = ACTIONS(4311),
    [anon_sym_if] = ACTIONS(4309),
    [anon_sym_IF] = ACTIONS(4309),
    [anon_sym_If] = ACTIONS(4309),
    [anon_sym_else] = ACTIONS(4309),
    [anon_sym_ELSE] = ACTIONS(4309),
    [anon_sym_Else] = ACTIONS(4309),
    [anon_sym_case] = ACTIONS(4309),
    [anon_sym_CASE] = ACTIONS(4309),
    [anon_sym_Case] = ACTIONS(4309),
    [anon_sym_for] = ACTIONS(4309),
    [anon_sym_FOR] = ACTIONS(4309),
    [anon_sym_For] = ACTIONS(4309),
    [anon_sym_foreach] = ACTIONS(4309),
    [anon_sym_FOREACH] = ACTIONS(4309),
    [anon_sym_Foreach] = ACTIONS(4309),
    [anon_sym_while] = ACTIONS(4309),
    [anon_sym_WHILE] = ACTIONS(4309),
    [anon_sym_While] = ACTIONS(4309),
    [anon_sym_repeat] = ACTIONS(4309),
    [anon_sym_REPEAT] = ACTIONS(4309),
    [anon_sym_Repeat] = ACTIONS(4309),
    [anon_sym_exit] = ACTIONS(4309),
    [anon_sym_EXIT] = ACTIONS(4309),
    [anon_sym_Exit] = ACTIONS(4309),
    [anon_sym_continue] = ACTIONS(4309),
    [anon_sym_CONTINUE] = ACTIONS(4309),
    [anon_sym_Continue] = ACTIONS(4309),
    [anon_sym_break] = ACTIONS(4309),
    [anon_sym_BREAK] = ACTIONS(4309),
    [anon_sym_Break] = ACTIONS(4309),
    [anon_sym_with] = ACTIONS(4309),
    [anon_sym_WITH] = ACTIONS(4309),
    [anon_sym_With] = ACTIONS(4309),
    [sym_asserterror_keyword] = ACTIONS(4311),
    [sym_page_keyword] = ACTIONS(4309),
    [anon_sym_codeunit] = ACTIONS(4309),
    [anon_sym_CODEUNIT] = ACTIONS(4309),
    [anon_sym_Codeunit] = ACTIONS(4309),
    [anon_sym_CodeUnit] = ACTIONS(4309),
    [anon_sym_COdeunit] = ACTIONS(4309),
    [anon_sym_codeUnit] = ACTIONS(4309),
    [sym_report_keyword] = ACTIONS(4309),
    [sym_query_keyword] = ACTIONS(4309),
    [anon_sym_xmlport] = ACTIONS(4309),
    [anon_sym_XMLPORT] = ACTIONS(4309),
    [anon_sym_Xmlport] = ACTIONS(4309),
    [anon_sym_XMLport] = ACTIONS(4309),
    [anon_sym_XMLPort] = ACTIONS(4309),
    [anon_sym_XmlPort] = ACTIONS(4309),
    [anon_sym_enum] = ACTIONS(4309),
    [anon_sym_ENUM] = ACTIONS(4309),
    [anon_sym_Enum] = ACTIONS(4309),
    [anon_sym_eNUM] = ACTIONS(4309),
    [anon_sym_eNum] = ACTIONS(4309),
    [anon_sym_ENum] = ACTIONS(4309),
    [sym_quoted_identifier] = ACTIONS(4311),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4311),
    [sym_integer] = ACTIONS(4309),
    [sym_continue_as_identifier] = ACTIONS(4311),
    [sym_preproc_open] = ACTIONS(4311),
    [sym_end_keyword] = ACTIONS(4311),
  },
  [STATE(2322)] = {
    [sym_identifier] = ACTIONS(4748),
    [anon_sym_SEMI] = ACTIONS(4750),
    [anon_sym_DASH] = ACTIONS(4750),
    [aux_sym_boolean_token1] = ACTIONS(4748),
    [aux_sym_boolean_token2] = ACTIONS(4748),
    [sym_decimal] = ACTIONS(4748),
    [anon_sym_LPAREN] = ACTIONS(4750),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4748),
    [anon_sym_LBRACK] = ACTIONS(4750),
    [aux_sym_record_type_token1] = ACTIONS(4748),
    [aux_sym_basic_type_token21] = ACTIONS(4748),
    [aux_sym_basic_type_token22] = ACTIONS(4748),
    [aux_sym_basic_type_token48] = ACTIONS(4748),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4748),
    [anon_sym_POUNDif] = ACTIONS(4750),
    [anon_sym_POUNDIF] = ACTIONS(4750),
    [anon_sym_POUNDIf] = ACTIONS(4750),
    [anon_sym_not] = ACTIONS(4748),
    [anon_sym_NOT] = ACTIONS(4748),
    [anon_sym_Not] = ACTIONS(4748),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4748),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4748),
    [anon_sym_PLUS] = ACTIONS(4750),
    [sym_datetime_literal] = ACTIONS(4750),
    [sym_date_literal] = ACTIONS(4748),
    [sym_time_literal] = ACTIONS(4748),
    [sym_biginteger_literal] = ACTIONS(4750),
    [anon_sym_if] = ACTIONS(4748),
    [anon_sym_IF] = ACTIONS(4748),
    [anon_sym_If] = ACTIONS(4748),
    [anon_sym_else] = ACTIONS(4748),
    [anon_sym_ELSE] = ACTIONS(4748),
    [anon_sym_Else] = ACTIONS(4748),
    [anon_sym_case] = ACTIONS(4748),
    [anon_sym_CASE] = ACTIONS(4748),
    [anon_sym_Case] = ACTIONS(4748),
    [anon_sym_for] = ACTIONS(4748),
    [anon_sym_FOR] = ACTIONS(4748),
    [anon_sym_For] = ACTIONS(4748),
    [anon_sym_foreach] = ACTIONS(4748),
    [anon_sym_FOREACH] = ACTIONS(4748),
    [anon_sym_Foreach] = ACTIONS(4748),
    [anon_sym_while] = ACTIONS(4748),
    [anon_sym_WHILE] = ACTIONS(4748),
    [anon_sym_While] = ACTIONS(4748),
    [anon_sym_repeat] = ACTIONS(4748),
    [anon_sym_REPEAT] = ACTIONS(4748),
    [anon_sym_Repeat] = ACTIONS(4748),
    [anon_sym_exit] = ACTIONS(4748),
    [anon_sym_EXIT] = ACTIONS(4748),
    [anon_sym_Exit] = ACTIONS(4748),
    [anon_sym_continue] = ACTIONS(4748),
    [anon_sym_CONTINUE] = ACTIONS(4748),
    [anon_sym_Continue] = ACTIONS(4748),
    [anon_sym_break] = ACTIONS(4748),
    [anon_sym_BREAK] = ACTIONS(4748),
    [anon_sym_Break] = ACTIONS(4748),
    [anon_sym_with] = ACTIONS(4748),
    [anon_sym_WITH] = ACTIONS(4748),
    [anon_sym_With] = ACTIONS(4748),
    [sym_asserterror_keyword] = ACTIONS(4750),
    [sym_page_keyword] = ACTIONS(4748),
    [anon_sym_codeunit] = ACTIONS(4748),
    [anon_sym_CODEUNIT] = ACTIONS(4748),
    [anon_sym_Codeunit] = ACTIONS(4748),
    [anon_sym_CodeUnit] = ACTIONS(4748),
    [anon_sym_COdeunit] = ACTIONS(4748),
    [anon_sym_codeUnit] = ACTIONS(4748),
    [sym_report_keyword] = ACTIONS(4748),
    [sym_query_keyword] = ACTIONS(4748),
    [anon_sym_xmlport] = ACTIONS(4748),
    [anon_sym_XMLPORT] = ACTIONS(4748),
    [anon_sym_Xmlport] = ACTIONS(4748),
    [anon_sym_XMLport] = ACTIONS(4748),
    [anon_sym_XMLPort] = ACTIONS(4748),
    [anon_sym_XmlPort] = ACTIONS(4748),
    [anon_sym_enum] = ACTIONS(4748),
    [anon_sym_ENUM] = ACTIONS(4748),
    [anon_sym_Enum] = ACTIONS(4748),
    [anon_sym_eNUM] = ACTIONS(4748),
    [anon_sym_eNum] = ACTIONS(4748),
    [anon_sym_ENum] = ACTIONS(4748),
    [sym_quoted_identifier] = ACTIONS(4750),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4750),
    [sym_integer] = ACTIONS(4748),
    [sym_continue_as_identifier] = ACTIONS(4750),
    [sym_preproc_open] = ACTIONS(4750),
    [sym_end_keyword] = ACTIONS(4750),
  },
  [STATE(2323)] = {
    [sym_identifier] = ACTIONS(4708),
    [anon_sym_SEMI] = ACTIONS(4710),
    [anon_sym_DASH] = ACTIONS(4710),
    [aux_sym_boolean_token1] = ACTIONS(4708),
    [aux_sym_boolean_token2] = ACTIONS(4708),
    [sym_decimal] = ACTIONS(4708),
    [anon_sym_LPAREN] = ACTIONS(4710),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4708),
    [anon_sym_LBRACK] = ACTIONS(4710),
    [aux_sym_record_type_token1] = ACTIONS(4708),
    [aux_sym_basic_type_token21] = ACTIONS(4708),
    [aux_sym_basic_type_token22] = ACTIONS(4708),
    [aux_sym_basic_type_token48] = ACTIONS(4708),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4708),
    [anon_sym_POUNDif] = ACTIONS(4710),
    [anon_sym_POUNDIF] = ACTIONS(4710),
    [anon_sym_POUNDIf] = ACTIONS(4710),
    [anon_sym_not] = ACTIONS(4708),
    [anon_sym_NOT] = ACTIONS(4708),
    [anon_sym_Not] = ACTIONS(4708),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4708),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4708),
    [anon_sym_PLUS] = ACTIONS(4710),
    [sym_datetime_literal] = ACTIONS(4710),
    [sym_date_literal] = ACTIONS(4708),
    [sym_time_literal] = ACTIONS(4708),
    [sym_biginteger_literal] = ACTIONS(4710),
    [anon_sym_if] = ACTIONS(4708),
    [anon_sym_IF] = ACTIONS(4708),
    [anon_sym_If] = ACTIONS(4708),
    [anon_sym_else] = ACTIONS(4708),
    [anon_sym_ELSE] = ACTIONS(4708),
    [anon_sym_Else] = ACTIONS(4708),
    [anon_sym_case] = ACTIONS(4708),
    [anon_sym_CASE] = ACTIONS(4708),
    [anon_sym_Case] = ACTIONS(4708),
    [anon_sym_for] = ACTIONS(4708),
    [anon_sym_FOR] = ACTIONS(4708),
    [anon_sym_For] = ACTIONS(4708),
    [anon_sym_foreach] = ACTIONS(4708),
    [anon_sym_FOREACH] = ACTIONS(4708),
    [anon_sym_Foreach] = ACTIONS(4708),
    [anon_sym_while] = ACTIONS(4708),
    [anon_sym_WHILE] = ACTIONS(4708),
    [anon_sym_While] = ACTIONS(4708),
    [anon_sym_repeat] = ACTIONS(4708),
    [anon_sym_REPEAT] = ACTIONS(4708),
    [anon_sym_Repeat] = ACTIONS(4708),
    [anon_sym_exit] = ACTIONS(4708),
    [anon_sym_EXIT] = ACTIONS(4708),
    [anon_sym_Exit] = ACTIONS(4708),
    [anon_sym_continue] = ACTIONS(4708),
    [anon_sym_CONTINUE] = ACTIONS(4708),
    [anon_sym_Continue] = ACTIONS(4708),
    [anon_sym_break] = ACTIONS(4708),
    [anon_sym_BREAK] = ACTIONS(4708),
    [anon_sym_Break] = ACTIONS(4708),
    [anon_sym_with] = ACTIONS(4708),
    [anon_sym_WITH] = ACTIONS(4708),
    [anon_sym_With] = ACTIONS(4708),
    [sym_asserterror_keyword] = ACTIONS(4710),
    [sym_page_keyword] = ACTIONS(4708),
    [anon_sym_codeunit] = ACTIONS(4708),
    [anon_sym_CODEUNIT] = ACTIONS(4708),
    [anon_sym_Codeunit] = ACTIONS(4708),
    [anon_sym_CodeUnit] = ACTIONS(4708),
    [anon_sym_COdeunit] = ACTIONS(4708),
    [anon_sym_codeUnit] = ACTIONS(4708),
    [sym_report_keyword] = ACTIONS(4708),
    [sym_query_keyword] = ACTIONS(4708),
    [anon_sym_xmlport] = ACTIONS(4708),
    [anon_sym_XMLPORT] = ACTIONS(4708),
    [anon_sym_Xmlport] = ACTIONS(4708),
    [anon_sym_XMLport] = ACTIONS(4708),
    [anon_sym_XMLPort] = ACTIONS(4708),
    [anon_sym_XmlPort] = ACTIONS(4708),
    [anon_sym_enum] = ACTIONS(4708),
    [anon_sym_ENUM] = ACTIONS(4708),
    [anon_sym_Enum] = ACTIONS(4708),
    [anon_sym_eNUM] = ACTIONS(4708),
    [anon_sym_eNum] = ACTIONS(4708),
    [anon_sym_ENum] = ACTIONS(4708),
    [sym_quoted_identifier] = ACTIONS(4710),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4710),
    [sym_integer] = ACTIONS(4708),
    [sym_continue_as_identifier] = ACTIONS(4710),
    [sym_preproc_open] = ACTIONS(4710),
    [sym_end_keyword] = ACTIONS(4710),
  },
  [STATE(2324)] = {
    [sym_identifier] = ACTIONS(4313),
    [anon_sym_SEMI] = ACTIONS(4315),
    [anon_sym_DASH] = ACTIONS(4315),
    [aux_sym_boolean_token1] = ACTIONS(4313),
    [aux_sym_boolean_token2] = ACTIONS(4313),
    [sym_decimal] = ACTIONS(4313),
    [anon_sym_LPAREN] = ACTIONS(4315),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4313),
    [anon_sym_LBRACK] = ACTIONS(4315),
    [aux_sym_record_type_token1] = ACTIONS(4313),
    [aux_sym_basic_type_token21] = ACTIONS(4313),
    [aux_sym_basic_type_token22] = ACTIONS(4313),
    [aux_sym_basic_type_token48] = ACTIONS(4313),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4313),
    [anon_sym_POUNDif] = ACTIONS(4315),
    [anon_sym_POUNDIF] = ACTIONS(4315),
    [anon_sym_POUNDIf] = ACTIONS(4315),
    [anon_sym_not] = ACTIONS(4313),
    [anon_sym_NOT] = ACTIONS(4313),
    [anon_sym_Not] = ACTIONS(4313),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4313),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4313),
    [anon_sym_PLUS] = ACTIONS(4315),
    [sym_datetime_literal] = ACTIONS(4315),
    [sym_date_literal] = ACTIONS(4313),
    [sym_time_literal] = ACTIONS(4313),
    [sym_biginteger_literal] = ACTIONS(4315),
    [anon_sym_if] = ACTIONS(4313),
    [anon_sym_IF] = ACTIONS(4313),
    [anon_sym_If] = ACTIONS(4313),
    [anon_sym_else] = ACTIONS(4313),
    [anon_sym_ELSE] = ACTIONS(4313),
    [anon_sym_Else] = ACTIONS(4313),
    [anon_sym_case] = ACTIONS(4313),
    [anon_sym_CASE] = ACTIONS(4313),
    [anon_sym_Case] = ACTIONS(4313),
    [anon_sym_for] = ACTIONS(4313),
    [anon_sym_FOR] = ACTIONS(4313),
    [anon_sym_For] = ACTIONS(4313),
    [anon_sym_foreach] = ACTIONS(4313),
    [anon_sym_FOREACH] = ACTIONS(4313),
    [anon_sym_Foreach] = ACTIONS(4313),
    [anon_sym_while] = ACTIONS(4313),
    [anon_sym_WHILE] = ACTIONS(4313),
    [anon_sym_While] = ACTIONS(4313),
    [anon_sym_repeat] = ACTIONS(4313),
    [anon_sym_REPEAT] = ACTIONS(4313),
    [anon_sym_Repeat] = ACTIONS(4313),
    [anon_sym_exit] = ACTIONS(4313),
    [anon_sym_EXIT] = ACTIONS(4313),
    [anon_sym_Exit] = ACTIONS(4313),
    [anon_sym_continue] = ACTIONS(4313),
    [anon_sym_CONTINUE] = ACTIONS(4313),
    [anon_sym_Continue] = ACTIONS(4313),
    [anon_sym_break] = ACTIONS(4313),
    [anon_sym_BREAK] = ACTIONS(4313),
    [anon_sym_Break] = ACTIONS(4313),
    [anon_sym_with] = ACTIONS(4313),
    [anon_sym_WITH] = ACTIONS(4313),
    [anon_sym_With] = ACTIONS(4313),
    [sym_asserterror_keyword] = ACTIONS(4315),
    [sym_page_keyword] = ACTIONS(4313),
    [anon_sym_codeunit] = ACTIONS(4313),
    [anon_sym_CODEUNIT] = ACTIONS(4313),
    [anon_sym_Codeunit] = ACTIONS(4313),
    [anon_sym_CodeUnit] = ACTIONS(4313),
    [anon_sym_COdeunit] = ACTIONS(4313),
    [anon_sym_codeUnit] = ACTIONS(4313),
    [sym_report_keyword] = ACTIONS(4313),
    [sym_query_keyword] = ACTIONS(4313),
    [anon_sym_xmlport] = ACTIONS(4313),
    [anon_sym_XMLPORT] = ACTIONS(4313),
    [anon_sym_Xmlport] = ACTIONS(4313),
    [anon_sym_XMLport] = ACTIONS(4313),
    [anon_sym_XMLPort] = ACTIONS(4313),
    [anon_sym_XmlPort] = ACTIONS(4313),
    [anon_sym_enum] = ACTIONS(4313),
    [anon_sym_ENUM] = ACTIONS(4313),
    [anon_sym_Enum] = ACTIONS(4313),
    [anon_sym_eNUM] = ACTIONS(4313),
    [anon_sym_eNum] = ACTIONS(4313),
    [anon_sym_ENum] = ACTIONS(4313),
    [sym_quoted_identifier] = ACTIONS(4315),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4315),
    [sym_integer] = ACTIONS(4313),
    [sym_continue_as_identifier] = ACTIONS(4315),
    [sym_preproc_open] = ACTIONS(4315),
    [sym_end_keyword] = ACTIONS(4315),
  },
  [STATE(2325)] = {
    [sym_identifier] = ACTIONS(4317),
    [anon_sym_SEMI] = ACTIONS(4319),
    [anon_sym_DASH] = ACTIONS(4319),
    [aux_sym_boolean_token1] = ACTIONS(4317),
    [aux_sym_boolean_token2] = ACTIONS(4317),
    [sym_decimal] = ACTIONS(4317),
    [anon_sym_LPAREN] = ACTIONS(4319),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4317),
    [anon_sym_LBRACK] = ACTIONS(4319),
    [aux_sym_record_type_token1] = ACTIONS(4317),
    [aux_sym_basic_type_token21] = ACTIONS(4317),
    [aux_sym_basic_type_token22] = ACTIONS(4317),
    [aux_sym_basic_type_token48] = ACTIONS(4317),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4317),
    [anon_sym_POUNDif] = ACTIONS(4319),
    [anon_sym_POUNDIF] = ACTIONS(4319),
    [anon_sym_POUNDIf] = ACTIONS(4319),
    [anon_sym_not] = ACTIONS(4317),
    [anon_sym_NOT] = ACTIONS(4317),
    [anon_sym_Not] = ACTIONS(4317),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4317),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4317),
    [anon_sym_PLUS] = ACTIONS(4319),
    [sym_datetime_literal] = ACTIONS(4319),
    [sym_date_literal] = ACTIONS(4317),
    [sym_time_literal] = ACTIONS(4317),
    [sym_biginteger_literal] = ACTIONS(4319),
    [anon_sym_if] = ACTIONS(4317),
    [anon_sym_IF] = ACTIONS(4317),
    [anon_sym_If] = ACTIONS(4317),
    [anon_sym_else] = ACTIONS(4317),
    [anon_sym_ELSE] = ACTIONS(4317),
    [anon_sym_Else] = ACTIONS(4317),
    [anon_sym_case] = ACTIONS(4317),
    [anon_sym_CASE] = ACTIONS(4317),
    [anon_sym_Case] = ACTIONS(4317),
    [anon_sym_for] = ACTIONS(4317),
    [anon_sym_FOR] = ACTIONS(4317),
    [anon_sym_For] = ACTIONS(4317),
    [anon_sym_foreach] = ACTIONS(4317),
    [anon_sym_FOREACH] = ACTIONS(4317),
    [anon_sym_Foreach] = ACTIONS(4317),
    [anon_sym_while] = ACTIONS(4317),
    [anon_sym_WHILE] = ACTIONS(4317),
    [anon_sym_While] = ACTIONS(4317),
    [anon_sym_repeat] = ACTIONS(4317),
    [anon_sym_REPEAT] = ACTIONS(4317),
    [anon_sym_Repeat] = ACTIONS(4317),
    [anon_sym_exit] = ACTIONS(4317),
    [anon_sym_EXIT] = ACTIONS(4317),
    [anon_sym_Exit] = ACTIONS(4317),
    [anon_sym_continue] = ACTIONS(4317),
    [anon_sym_CONTINUE] = ACTIONS(4317),
    [anon_sym_Continue] = ACTIONS(4317),
    [anon_sym_break] = ACTIONS(4317),
    [anon_sym_BREAK] = ACTIONS(4317),
    [anon_sym_Break] = ACTIONS(4317),
    [anon_sym_with] = ACTIONS(4317),
    [anon_sym_WITH] = ACTIONS(4317),
    [anon_sym_With] = ACTIONS(4317),
    [sym_asserterror_keyword] = ACTIONS(4319),
    [sym_page_keyword] = ACTIONS(4317),
    [anon_sym_codeunit] = ACTIONS(4317),
    [anon_sym_CODEUNIT] = ACTIONS(4317),
    [anon_sym_Codeunit] = ACTIONS(4317),
    [anon_sym_CodeUnit] = ACTIONS(4317),
    [anon_sym_COdeunit] = ACTIONS(4317),
    [anon_sym_codeUnit] = ACTIONS(4317),
    [sym_report_keyword] = ACTIONS(4317),
    [sym_query_keyword] = ACTIONS(4317),
    [anon_sym_xmlport] = ACTIONS(4317),
    [anon_sym_XMLPORT] = ACTIONS(4317),
    [anon_sym_Xmlport] = ACTIONS(4317),
    [anon_sym_XMLport] = ACTIONS(4317),
    [anon_sym_XMLPort] = ACTIONS(4317),
    [anon_sym_XmlPort] = ACTIONS(4317),
    [anon_sym_enum] = ACTIONS(4317),
    [anon_sym_ENUM] = ACTIONS(4317),
    [anon_sym_Enum] = ACTIONS(4317),
    [anon_sym_eNUM] = ACTIONS(4317),
    [anon_sym_eNum] = ACTIONS(4317),
    [anon_sym_ENum] = ACTIONS(4317),
    [sym_quoted_identifier] = ACTIONS(4319),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4319),
    [sym_integer] = ACTIONS(4317),
    [sym_continue_as_identifier] = ACTIONS(4319),
    [sym_preproc_open] = ACTIONS(4319),
    [sym_end_keyword] = ACTIONS(4319),
  },
  [STATE(2326)] = {
    [sym_identifier] = ACTIONS(4716),
    [anon_sym_SEMI] = ACTIONS(4718),
    [anon_sym_DASH] = ACTIONS(4718),
    [aux_sym_boolean_token1] = ACTIONS(4716),
    [aux_sym_boolean_token2] = ACTIONS(4716),
    [sym_decimal] = ACTIONS(4716),
    [anon_sym_LPAREN] = ACTIONS(4718),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4716),
    [anon_sym_LBRACK] = ACTIONS(4718),
    [aux_sym_record_type_token1] = ACTIONS(4716),
    [aux_sym_basic_type_token21] = ACTIONS(4716),
    [aux_sym_basic_type_token22] = ACTIONS(4716),
    [aux_sym_basic_type_token48] = ACTIONS(4716),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4716),
    [anon_sym_POUNDif] = ACTIONS(4718),
    [anon_sym_POUNDIF] = ACTIONS(4718),
    [anon_sym_POUNDIf] = ACTIONS(4718),
    [anon_sym_not] = ACTIONS(4716),
    [anon_sym_NOT] = ACTIONS(4716),
    [anon_sym_Not] = ACTIONS(4716),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4716),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4716),
    [anon_sym_PLUS] = ACTIONS(4718),
    [sym_datetime_literal] = ACTIONS(4718),
    [sym_date_literal] = ACTIONS(4716),
    [sym_time_literal] = ACTIONS(4716),
    [sym_biginteger_literal] = ACTIONS(4718),
    [anon_sym_if] = ACTIONS(4716),
    [anon_sym_IF] = ACTIONS(4716),
    [anon_sym_If] = ACTIONS(4716),
    [anon_sym_else] = ACTIONS(4716),
    [anon_sym_ELSE] = ACTIONS(4716),
    [anon_sym_Else] = ACTIONS(4716),
    [anon_sym_case] = ACTIONS(4716),
    [anon_sym_CASE] = ACTIONS(4716),
    [anon_sym_Case] = ACTIONS(4716),
    [anon_sym_for] = ACTIONS(4716),
    [anon_sym_FOR] = ACTIONS(4716),
    [anon_sym_For] = ACTIONS(4716),
    [anon_sym_foreach] = ACTIONS(4716),
    [anon_sym_FOREACH] = ACTIONS(4716),
    [anon_sym_Foreach] = ACTIONS(4716),
    [anon_sym_while] = ACTIONS(4716),
    [anon_sym_WHILE] = ACTIONS(4716),
    [anon_sym_While] = ACTIONS(4716),
    [anon_sym_repeat] = ACTIONS(4716),
    [anon_sym_REPEAT] = ACTIONS(4716),
    [anon_sym_Repeat] = ACTIONS(4716),
    [anon_sym_exit] = ACTIONS(4716),
    [anon_sym_EXIT] = ACTIONS(4716),
    [anon_sym_Exit] = ACTIONS(4716),
    [anon_sym_continue] = ACTIONS(4716),
    [anon_sym_CONTINUE] = ACTIONS(4716),
    [anon_sym_Continue] = ACTIONS(4716),
    [anon_sym_break] = ACTIONS(4716),
    [anon_sym_BREAK] = ACTIONS(4716),
    [anon_sym_Break] = ACTIONS(4716),
    [anon_sym_with] = ACTIONS(4716),
    [anon_sym_WITH] = ACTIONS(4716),
    [anon_sym_With] = ACTIONS(4716),
    [sym_asserterror_keyword] = ACTIONS(4718),
    [sym_page_keyword] = ACTIONS(4716),
    [anon_sym_codeunit] = ACTIONS(4716),
    [anon_sym_CODEUNIT] = ACTIONS(4716),
    [anon_sym_Codeunit] = ACTIONS(4716),
    [anon_sym_CodeUnit] = ACTIONS(4716),
    [anon_sym_COdeunit] = ACTIONS(4716),
    [anon_sym_codeUnit] = ACTIONS(4716),
    [sym_report_keyword] = ACTIONS(4716),
    [sym_query_keyword] = ACTIONS(4716),
    [anon_sym_xmlport] = ACTIONS(4716),
    [anon_sym_XMLPORT] = ACTIONS(4716),
    [anon_sym_Xmlport] = ACTIONS(4716),
    [anon_sym_XMLport] = ACTIONS(4716),
    [anon_sym_XMLPort] = ACTIONS(4716),
    [anon_sym_XmlPort] = ACTIONS(4716),
    [anon_sym_enum] = ACTIONS(4716),
    [anon_sym_ENUM] = ACTIONS(4716),
    [anon_sym_Enum] = ACTIONS(4716),
    [anon_sym_eNUM] = ACTIONS(4716),
    [anon_sym_eNum] = ACTIONS(4716),
    [anon_sym_ENum] = ACTIONS(4716),
    [sym_quoted_identifier] = ACTIONS(4718),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4718),
    [sym_integer] = ACTIONS(4716),
    [sym_continue_as_identifier] = ACTIONS(4718),
    [sym_preproc_open] = ACTIONS(4718),
    [sym_end_keyword] = ACTIONS(4718),
  },
  [STATE(2327)] = {
    [sym_identifier] = ACTIONS(4622),
    [anon_sym_SEMI] = ACTIONS(4624),
    [anon_sym_DASH] = ACTIONS(4624),
    [aux_sym_boolean_token1] = ACTIONS(4622),
    [aux_sym_boolean_token2] = ACTIONS(4622),
    [sym_decimal] = ACTIONS(4622),
    [anon_sym_LPAREN] = ACTIONS(4624),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4622),
    [anon_sym_LBRACK] = ACTIONS(4624),
    [aux_sym_record_type_token1] = ACTIONS(4622),
    [aux_sym_basic_type_token21] = ACTIONS(4622),
    [aux_sym_basic_type_token22] = ACTIONS(4622),
    [aux_sym_basic_type_token48] = ACTIONS(4622),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4622),
    [anon_sym_POUNDif] = ACTIONS(4624),
    [anon_sym_POUNDIF] = ACTIONS(4624),
    [anon_sym_POUNDIf] = ACTIONS(4624),
    [anon_sym_not] = ACTIONS(4622),
    [anon_sym_NOT] = ACTIONS(4622),
    [anon_sym_Not] = ACTIONS(4622),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4622),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4622),
    [anon_sym_PLUS] = ACTIONS(4624),
    [sym_datetime_literal] = ACTIONS(4624),
    [sym_date_literal] = ACTIONS(4622),
    [sym_time_literal] = ACTIONS(4622),
    [sym_biginteger_literal] = ACTIONS(4624),
    [anon_sym_if] = ACTIONS(4622),
    [anon_sym_IF] = ACTIONS(4622),
    [anon_sym_If] = ACTIONS(4622),
    [anon_sym_else] = ACTIONS(4622),
    [anon_sym_ELSE] = ACTIONS(4622),
    [anon_sym_Else] = ACTIONS(4622),
    [anon_sym_case] = ACTIONS(4622),
    [anon_sym_CASE] = ACTIONS(4622),
    [anon_sym_Case] = ACTIONS(4622),
    [anon_sym_for] = ACTIONS(4622),
    [anon_sym_FOR] = ACTIONS(4622),
    [anon_sym_For] = ACTIONS(4622),
    [anon_sym_foreach] = ACTIONS(4622),
    [anon_sym_FOREACH] = ACTIONS(4622),
    [anon_sym_Foreach] = ACTIONS(4622),
    [anon_sym_while] = ACTIONS(4622),
    [anon_sym_WHILE] = ACTIONS(4622),
    [anon_sym_While] = ACTIONS(4622),
    [anon_sym_repeat] = ACTIONS(4622),
    [anon_sym_REPEAT] = ACTIONS(4622),
    [anon_sym_Repeat] = ACTIONS(4622),
    [anon_sym_exit] = ACTIONS(4622),
    [anon_sym_EXIT] = ACTIONS(4622),
    [anon_sym_Exit] = ACTIONS(4622),
    [anon_sym_continue] = ACTIONS(4622),
    [anon_sym_CONTINUE] = ACTIONS(4622),
    [anon_sym_Continue] = ACTIONS(4622),
    [anon_sym_break] = ACTIONS(4622),
    [anon_sym_BREAK] = ACTIONS(4622),
    [anon_sym_Break] = ACTIONS(4622),
    [anon_sym_with] = ACTIONS(4622),
    [anon_sym_WITH] = ACTIONS(4622),
    [anon_sym_With] = ACTIONS(4622),
    [sym_asserterror_keyword] = ACTIONS(4624),
    [sym_page_keyword] = ACTIONS(4622),
    [anon_sym_codeunit] = ACTIONS(4622),
    [anon_sym_CODEUNIT] = ACTIONS(4622),
    [anon_sym_Codeunit] = ACTIONS(4622),
    [anon_sym_CodeUnit] = ACTIONS(4622),
    [anon_sym_COdeunit] = ACTIONS(4622),
    [anon_sym_codeUnit] = ACTIONS(4622),
    [sym_report_keyword] = ACTIONS(4622),
    [sym_query_keyword] = ACTIONS(4622),
    [anon_sym_xmlport] = ACTIONS(4622),
    [anon_sym_XMLPORT] = ACTIONS(4622),
    [anon_sym_Xmlport] = ACTIONS(4622),
    [anon_sym_XMLport] = ACTIONS(4622),
    [anon_sym_XMLPort] = ACTIONS(4622),
    [anon_sym_XmlPort] = ACTIONS(4622),
    [anon_sym_enum] = ACTIONS(4622),
    [anon_sym_ENUM] = ACTIONS(4622),
    [anon_sym_Enum] = ACTIONS(4622),
    [anon_sym_eNUM] = ACTIONS(4622),
    [anon_sym_eNum] = ACTIONS(4622),
    [anon_sym_ENum] = ACTIONS(4622),
    [sym_quoted_identifier] = ACTIONS(4624),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4624),
    [sym_integer] = ACTIONS(4622),
    [sym_continue_as_identifier] = ACTIONS(4624),
    [sym_preproc_open] = ACTIONS(4624),
    [sym_end_keyword] = ACTIONS(4624),
  },
  [STATE(2328)] = {
    [sym_identifier] = ACTIONS(4321),
    [anon_sym_SEMI] = ACTIONS(4323),
    [anon_sym_DASH] = ACTIONS(4323),
    [aux_sym_boolean_token1] = ACTIONS(4321),
    [aux_sym_boolean_token2] = ACTIONS(4321),
    [sym_decimal] = ACTIONS(4321),
    [anon_sym_LPAREN] = ACTIONS(4323),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4321),
    [anon_sym_LBRACK] = ACTIONS(4323),
    [aux_sym_record_type_token1] = ACTIONS(4321),
    [aux_sym_basic_type_token21] = ACTIONS(4321),
    [aux_sym_basic_type_token22] = ACTIONS(4321),
    [aux_sym_basic_type_token48] = ACTIONS(4321),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4321),
    [anon_sym_POUNDif] = ACTIONS(4323),
    [anon_sym_POUNDIF] = ACTIONS(4323),
    [anon_sym_POUNDIf] = ACTIONS(4323),
    [anon_sym_not] = ACTIONS(4321),
    [anon_sym_NOT] = ACTIONS(4321),
    [anon_sym_Not] = ACTIONS(4321),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4321),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4321),
    [anon_sym_PLUS] = ACTIONS(4323),
    [sym_datetime_literal] = ACTIONS(4323),
    [sym_date_literal] = ACTIONS(4321),
    [sym_time_literal] = ACTIONS(4321),
    [sym_biginteger_literal] = ACTIONS(4323),
    [anon_sym_if] = ACTIONS(4321),
    [anon_sym_IF] = ACTIONS(4321),
    [anon_sym_If] = ACTIONS(4321),
    [anon_sym_else] = ACTIONS(4321),
    [anon_sym_ELSE] = ACTIONS(4321),
    [anon_sym_Else] = ACTIONS(4321),
    [anon_sym_case] = ACTIONS(4321),
    [anon_sym_CASE] = ACTIONS(4321),
    [anon_sym_Case] = ACTIONS(4321),
    [anon_sym_for] = ACTIONS(4321),
    [anon_sym_FOR] = ACTIONS(4321),
    [anon_sym_For] = ACTIONS(4321),
    [anon_sym_foreach] = ACTIONS(4321),
    [anon_sym_FOREACH] = ACTIONS(4321),
    [anon_sym_Foreach] = ACTIONS(4321),
    [anon_sym_while] = ACTIONS(4321),
    [anon_sym_WHILE] = ACTIONS(4321),
    [anon_sym_While] = ACTIONS(4321),
    [anon_sym_repeat] = ACTIONS(4321),
    [anon_sym_REPEAT] = ACTIONS(4321),
    [anon_sym_Repeat] = ACTIONS(4321),
    [anon_sym_exit] = ACTIONS(4321),
    [anon_sym_EXIT] = ACTIONS(4321),
    [anon_sym_Exit] = ACTIONS(4321),
    [anon_sym_continue] = ACTIONS(4321),
    [anon_sym_CONTINUE] = ACTIONS(4321),
    [anon_sym_Continue] = ACTIONS(4321),
    [anon_sym_break] = ACTIONS(4321),
    [anon_sym_BREAK] = ACTIONS(4321),
    [anon_sym_Break] = ACTIONS(4321),
    [anon_sym_with] = ACTIONS(4321),
    [anon_sym_WITH] = ACTIONS(4321),
    [anon_sym_With] = ACTIONS(4321),
    [sym_asserterror_keyword] = ACTIONS(4323),
    [sym_page_keyword] = ACTIONS(4321),
    [anon_sym_codeunit] = ACTIONS(4321),
    [anon_sym_CODEUNIT] = ACTIONS(4321),
    [anon_sym_Codeunit] = ACTIONS(4321),
    [anon_sym_CodeUnit] = ACTIONS(4321),
    [anon_sym_COdeunit] = ACTIONS(4321),
    [anon_sym_codeUnit] = ACTIONS(4321),
    [sym_report_keyword] = ACTIONS(4321),
    [sym_query_keyword] = ACTIONS(4321),
    [anon_sym_xmlport] = ACTIONS(4321),
    [anon_sym_XMLPORT] = ACTIONS(4321),
    [anon_sym_Xmlport] = ACTIONS(4321),
    [anon_sym_XMLport] = ACTIONS(4321),
    [anon_sym_XMLPort] = ACTIONS(4321),
    [anon_sym_XmlPort] = ACTIONS(4321),
    [anon_sym_enum] = ACTIONS(4321),
    [anon_sym_ENUM] = ACTIONS(4321),
    [anon_sym_Enum] = ACTIONS(4321),
    [anon_sym_eNUM] = ACTIONS(4321),
    [anon_sym_eNum] = ACTIONS(4321),
    [anon_sym_ENum] = ACTIONS(4321),
    [sym_quoted_identifier] = ACTIONS(4323),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4323),
    [sym_integer] = ACTIONS(4321),
    [sym_continue_as_identifier] = ACTIONS(4323),
    [sym_preproc_open] = ACTIONS(4323),
    [sym_end_keyword] = ACTIONS(4323),
  },
  [STATE(2329)] = {
    [sym_identifier] = ACTIONS(4325),
    [anon_sym_SEMI] = ACTIONS(4327),
    [anon_sym_DASH] = ACTIONS(4327),
    [aux_sym_boolean_token1] = ACTIONS(4325),
    [aux_sym_boolean_token2] = ACTIONS(4325),
    [sym_decimal] = ACTIONS(4325),
    [anon_sym_LPAREN] = ACTIONS(4327),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4325),
    [anon_sym_LBRACK] = ACTIONS(4327),
    [aux_sym_record_type_token1] = ACTIONS(4325),
    [aux_sym_basic_type_token21] = ACTIONS(4325),
    [aux_sym_basic_type_token22] = ACTIONS(4325),
    [aux_sym_basic_type_token48] = ACTIONS(4325),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4325),
    [anon_sym_POUNDif] = ACTIONS(4327),
    [anon_sym_POUNDIF] = ACTIONS(4327),
    [anon_sym_POUNDIf] = ACTIONS(4327),
    [anon_sym_not] = ACTIONS(4325),
    [anon_sym_NOT] = ACTIONS(4325),
    [anon_sym_Not] = ACTIONS(4325),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4325),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4325),
    [anon_sym_PLUS] = ACTIONS(4327),
    [sym_datetime_literal] = ACTIONS(4327),
    [sym_date_literal] = ACTIONS(4325),
    [sym_time_literal] = ACTIONS(4325),
    [sym_biginteger_literal] = ACTIONS(4327),
    [anon_sym_if] = ACTIONS(4325),
    [anon_sym_IF] = ACTIONS(4325),
    [anon_sym_If] = ACTIONS(4325),
    [anon_sym_else] = ACTIONS(4325),
    [anon_sym_ELSE] = ACTIONS(4325),
    [anon_sym_Else] = ACTIONS(4325),
    [anon_sym_case] = ACTIONS(4325),
    [anon_sym_CASE] = ACTIONS(4325),
    [anon_sym_Case] = ACTIONS(4325),
    [anon_sym_for] = ACTIONS(4325),
    [anon_sym_FOR] = ACTIONS(4325),
    [anon_sym_For] = ACTIONS(4325),
    [anon_sym_foreach] = ACTIONS(4325),
    [anon_sym_FOREACH] = ACTIONS(4325),
    [anon_sym_Foreach] = ACTIONS(4325),
    [anon_sym_while] = ACTIONS(4325),
    [anon_sym_WHILE] = ACTIONS(4325),
    [anon_sym_While] = ACTIONS(4325),
    [anon_sym_repeat] = ACTIONS(4325),
    [anon_sym_REPEAT] = ACTIONS(4325),
    [anon_sym_Repeat] = ACTIONS(4325),
    [anon_sym_exit] = ACTIONS(4325),
    [anon_sym_EXIT] = ACTIONS(4325),
    [anon_sym_Exit] = ACTIONS(4325),
    [anon_sym_continue] = ACTIONS(4325),
    [anon_sym_CONTINUE] = ACTIONS(4325),
    [anon_sym_Continue] = ACTIONS(4325),
    [anon_sym_break] = ACTIONS(4325),
    [anon_sym_BREAK] = ACTIONS(4325),
    [anon_sym_Break] = ACTIONS(4325),
    [anon_sym_with] = ACTIONS(4325),
    [anon_sym_WITH] = ACTIONS(4325),
    [anon_sym_With] = ACTIONS(4325),
    [sym_asserterror_keyword] = ACTIONS(4327),
    [sym_page_keyword] = ACTIONS(4325),
    [anon_sym_codeunit] = ACTIONS(4325),
    [anon_sym_CODEUNIT] = ACTIONS(4325),
    [anon_sym_Codeunit] = ACTIONS(4325),
    [anon_sym_CodeUnit] = ACTIONS(4325),
    [anon_sym_COdeunit] = ACTIONS(4325),
    [anon_sym_codeUnit] = ACTIONS(4325),
    [sym_report_keyword] = ACTIONS(4325),
    [sym_query_keyword] = ACTIONS(4325),
    [anon_sym_xmlport] = ACTIONS(4325),
    [anon_sym_XMLPORT] = ACTIONS(4325),
    [anon_sym_Xmlport] = ACTIONS(4325),
    [anon_sym_XMLport] = ACTIONS(4325),
    [anon_sym_XMLPort] = ACTIONS(4325),
    [anon_sym_XmlPort] = ACTIONS(4325),
    [anon_sym_enum] = ACTIONS(4325),
    [anon_sym_ENUM] = ACTIONS(4325),
    [anon_sym_Enum] = ACTIONS(4325),
    [anon_sym_eNUM] = ACTIONS(4325),
    [anon_sym_eNum] = ACTIONS(4325),
    [anon_sym_ENum] = ACTIONS(4325),
    [sym_quoted_identifier] = ACTIONS(4327),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4327),
    [sym_integer] = ACTIONS(4325),
    [sym_continue_as_identifier] = ACTIONS(4327),
    [sym_preproc_open] = ACTIONS(4327),
    [sym_end_keyword] = ACTIONS(4327),
  },
  [STATE(2330)] = {
    [sym_identifier] = ACTIONS(4329),
    [anon_sym_SEMI] = ACTIONS(4331),
    [anon_sym_DASH] = ACTIONS(4331),
    [aux_sym_boolean_token1] = ACTIONS(4329),
    [aux_sym_boolean_token2] = ACTIONS(4329),
    [sym_decimal] = ACTIONS(4329),
    [anon_sym_LPAREN] = ACTIONS(4331),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4329),
    [anon_sym_LBRACK] = ACTIONS(4331),
    [aux_sym_record_type_token1] = ACTIONS(4329),
    [aux_sym_basic_type_token21] = ACTIONS(4329),
    [aux_sym_basic_type_token22] = ACTIONS(4329),
    [aux_sym_basic_type_token48] = ACTIONS(4329),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4329),
    [anon_sym_POUNDif] = ACTIONS(4331),
    [anon_sym_POUNDIF] = ACTIONS(4331),
    [anon_sym_POUNDIf] = ACTIONS(4331),
    [anon_sym_not] = ACTIONS(4329),
    [anon_sym_NOT] = ACTIONS(4329),
    [anon_sym_Not] = ACTIONS(4329),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4329),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4329),
    [anon_sym_PLUS] = ACTIONS(4331),
    [sym_datetime_literal] = ACTIONS(4331),
    [sym_date_literal] = ACTIONS(4329),
    [sym_time_literal] = ACTIONS(4329),
    [sym_biginteger_literal] = ACTIONS(4331),
    [anon_sym_if] = ACTIONS(4329),
    [anon_sym_IF] = ACTIONS(4329),
    [anon_sym_If] = ACTIONS(4329),
    [anon_sym_else] = ACTIONS(4329),
    [anon_sym_ELSE] = ACTIONS(4329),
    [anon_sym_Else] = ACTIONS(4329),
    [anon_sym_case] = ACTIONS(4329),
    [anon_sym_CASE] = ACTIONS(4329),
    [anon_sym_Case] = ACTIONS(4329),
    [anon_sym_for] = ACTIONS(4329),
    [anon_sym_FOR] = ACTIONS(4329),
    [anon_sym_For] = ACTIONS(4329),
    [anon_sym_foreach] = ACTIONS(4329),
    [anon_sym_FOREACH] = ACTIONS(4329),
    [anon_sym_Foreach] = ACTIONS(4329),
    [anon_sym_while] = ACTIONS(4329),
    [anon_sym_WHILE] = ACTIONS(4329),
    [anon_sym_While] = ACTIONS(4329),
    [anon_sym_repeat] = ACTIONS(4329),
    [anon_sym_REPEAT] = ACTIONS(4329),
    [anon_sym_Repeat] = ACTIONS(4329),
    [anon_sym_exit] = ACTIONS(4329),
    [anon_sym_EXIT] = ACTIONS(4329),
    [anon_sym_Exit] = ACTIONS(4329),
    [anon_sym_continue] = ACTIONS(4329),
    [anon_sym_CONTINUE] = ACTIONS(4329),
    [anon_sym_Continue] = ACTIONS(4329),
    [anon_sym_break] = ACTIONS(4329),
    [anon_sym_BREAK] = ACTIONS(4329),
    [anon_sym_Break] = ACTIONS(4329),
    [anon_sym_with] = ACTIONS(4329),
    [anon_sym_WITH] = ACTIONS(4329),
    [anon_sym_With] = ACTIONS(4329),
    [sym_asserterror_keyword] = ACTIONS(4331),
    [sym_page_keyword] = ACTIONS(4329),
    [anon_sym_codeunit] = ACTIONS(4329),
    [anon_sym_CODEUNIT] = ACTIONS(4329),
    [anon_sym_Codeunit] = ACTIONS(4329),
    [anon_sym_CodeUnit] = ACTIONS(4329),
    [anon_sym_COdeunit] = ACTIONS(4329),
    [anon_sym_codeUnit] = ACTIONS(4329),
    [sym_report_keyword] = ACTIONS(4329),
    [sym_query_keyword] = ACTIONS(4329),
    [anon_sym_xmlport] = ACTIONS(4329),
    [anon_sym_XMLPORT] = ACTIONS(4329),
    [anon_sym_Xmlport] = ACTIONS(4329),
    [anon_sym_XMLport] = ACTIONS(4329),
    [anon_sym_XMLPort] = ACTIONS(4329),
    [anon_sym_XmlPort] = ACTIONS(4329),
    [anon_sym_enum] = ACTIONS(4329),
    [anon_sym_ENUM] = ACTIONS(4329),
    [anon_sym_Enum] = ACTIONS(4329),
    [anon_sym_eNUM] = ACTIONS(4329),
    [anon_sym_eNum] = ACTIONS(4329),
    [anon_sym_ENum] = ACTIONS(4329),
    [sym_quoted_identifier] = ACTIONS(4331),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4331),
    [sym_integer] = ACTIONS(4329),
    [sym_continue_as_identifier] = ACTIONS(4331),
    [sym_preproc_open] = ACTIONS(4331),
    [sym_end_keyword] = ACTIONS(4331),
  },
  [STATE(2331)] = {
    [sym_identifier] = ACTIONS(4333),
    [anon_sym_SEMI] = ACTIONS(4335),
    [anon_sym_DASH] = ACTIONS(4335),
    [aux_sym_boolean_token1] = ACTIONS(4333),
    [aux_sym_boolean_token2] = ACTIONS(4333),
    [sym_decimal] = ACTIONS(4333),
    [anon_sym_LPAREN] = ACTIONS(4335),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4333),
    [anon_sym_LBRACK] = ACTIONS(4335),
    [aux_sym_record_type_token1] = ACTIONS(4333),
    [aux_sym_basic_type_token21] = ACTIONS(4333),
    [aux_sym_basic_type_token22] = ACTIONS(4333),
    [aux_sym_basic_type_token48] = ACTIONS(4333),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4333),
    [anon_sym_POUNDif] = ACTIONS(4335),
    [anon_sym_POUNDIF] = ACTIONS(4335),
    [anon_sym_POUNDIf] = ACTIONS(4335),
    [anon_sym_not] = ACTIONS(4333),
    [anon_sym_NOT] = ACTIONS(4333),
    [anon_sym_Not] = ACTIONS(4333),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4333),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4333),
    [anon_sym_PLUS] = ACTIONS(4335),
    [sym_datetime_literal] = ACTIONS(4335),
    [sym_date_literal] = ACTIONS(4333),
    [sym_time_literal] = ACTIONS(4333),
    [sym_biginteger_literal] = ACTIONS(4335),
    [anon_sym_if] = ACTIONS(4333),
    [anon_sym_IF] = ACTIONS(4333),
    [anon_sym_If] = ACTIONS(4333),
    [anon_sym_else] = ACTIONS(4333),
    [anon_sym_ELSE] = ACTIONS(4333),
    [anon_sym_Else] = ACTIONS(4333),
    [anon_sym_case] = ACTIONS(4333),
    [anon_sym_CASE] = ACTIONS(4333),
    [anon_sym_Case] = ACTIONS(4333),
    [anon_sym_for] = ACTIONS(4333),
    [anon_sym_FOR] = ACTIONS(4333),
    [anon_sym_For] = ACTIONS(4333),
    [anon_sym_foreach] = ACTIONS(4333),
    [anon_sym_FOREACH] = ACTIONS(4333),
    [anon_sym_Foreach] = ACTIONS(4333),
    [anon_sym_while] = ACTIONS(4333),
    [anon_sym_WHILE] = ACTIONS(4333),
    [anon_sym_While] = ACTIONS(4333),
    [anon_sym_repeat] = ACTIONS(4333),
    [anon_sym_REPEAT] = ACTIONS(4333),
    [anon_sym_Repeat] = ACTIONS(4333),
    [anon_sym_exit] = ACTIONS(4333),
    [anon_sym_EXIT] = ACTIONS(4333),
    [anon_sym_Exit] = ACTIONS(4333),
    [anon_sym_continue] = ACTIONS(4333),
    [anon_sym_CONTINUE] = ACTIONS(4333),
    [anon_sym_Continue] = ACTIONS(4333),
    [anon_sym_break] = ACTIONS(4333),
    [anon_sym_BREAK] = ACTIONS(4333),
    [anon_sym_Break] = ACTIONS(4333),
    [anon_sym_with] = ACTIONS(4333),
    [anon_sym_WITH] = ACTIONS(4333),
    [anon_sym_With] = ACTIONS(4333),
    [sym_asserterror_keyword] = ACTIONS(4335),
    [sym_page_keyword] = ACTIONS(4333),
    [anon_sym_codeunit] = ACTIONS(4333),
    [anon_sym_CODEUNIT] = ACTIONS(4333),
    [anon_sym_Codeunit] = ACTIONS(4333),
    [anon_sym_CodeUnit] = ACTIONS(4333),
    [anon_sym_COdeunit] = ACTIONS(4333),
    [anon_sym_codeUnit] = ACTIONS(4333),
    [sym_report_keyword] = ACTIONS(4333),
    [sym_query_keyword] = ACTIONS(4333),
    [anon_sym_xmlport] = ACTIONS(4333),
    [anon_sym_XMLPORT] = ACTIONS(4333),
    [anon_sym_Xmlport] = ACTIONS(4333),
    [anon_sym_XMLport] = ACTIONS(4333),
    [anon_sym_XMLPort] = ACTIONS(4333),
    [anon_sym_XmlPort] = ACTIONS(4333),
    [anon_sym_enum] = ACTIONS(4333),
    [anon_sym_ENUM] = ACTIONS(4333),
    [anon_sym_Enum] = ACTIONS(4333),
    [anon_sym_eNUM] = ACTIONS(4333),
    [anon_sym_eNum] = ACTIONS(4333),
    [anon_sym_ENum] = ACTIONS(4333),
    [sym_quoted_identifier] = ACTIONS(4335),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4335),
    [sym_integer] = ACTIONS(4333),
    [sym_continue_as_identifier] = ACTIONS(4335),
    [sym_preproc_open] = ACTIONS(4335),
    [sym_end_keyword] = ACTIONS(4335),
  },
  [STATE(2332)] = {
    [sym_identifier] = ACTIONS(4337),
    [anon_sym_SEMI] = ACTIONS(4339),
    [anon_sym_DASH] = ACTIONS(4339),
    [aux_sym_boolean_token1] = ACTIONS(4337),
    [aux_sym_boolean_token2] = ACTIONS(4337),
    [sym_decimal] = ACTIONS(4337),
    [anon_sym_LPAREN] = ACTIONS(4339),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4337),
    [anon_sym_LBRACK] = ACTIONS(4339),
    [aux_sym_record_type_token1] = ACTIONS(4337),
    [aux_sym_basic_type_token21] = ACTIONS(4337),
    [aux_sym_basic_type_token22] = ACTIONS(4337),
    [aux_sym_basic_type_token48] = ACTIONS(4337),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4337),
    [anon_sym_POUNDif] = ACTIONS(4339),
    [anon_sym_POUNDIF] = ACTIONS(4339),
    [anon_sym_POUNDIf] = ACTIONS(4339),
    [anon_sym_not] = ACTIONS(4337),
    [anon_sym_NOT] = ACTIONS(4337),
    [anon_sym_Not] = ACTIONS(4337),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4337),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4337),
    [anon_sym_PLUS] = ACTIONS(4339),
    [sym_datetime_literal] = ACTIONS(4339),
    [sym_date_literal] = ACTIONS(4337),
    [sym_time_literal] = ACTIONS(4337),
    [sym_biginteger_literal] = ACTIONS(4339),
    [anon_sym_if] = ACTIONS(4337),
    [anon_sym_IF] = ACTIONS(4337),
    [anon_sym_If] = ACTIONS(4337),
    [anon_sym_else] = ACTIONS(4337),
    [anon_sym_ELSE] = ACTIONS(4337),
    [anon_sym_Else] = ACTIONS(4337),
    [anon_sym_case] = ACTIONS(4337),
    [anon_sym_CASE] = ACTIONS(4337),
    [anon_sym_Case] = ACTIONS(4337),
    [anon_sym_for] = ACTIONS(4337),
    [anon_sym_FOR] = ACTIONS(4337),
    [anon_sym_For] = ACTIONS(4337),
    [anon_sym_foreach] = ACTIONS(4337),
    [anon_sym_FOREACH] = ACTIONS(4337),
    [anon_sym_Foreach] = ACTIONS(4337),
    [anon_sym_while] = ACTIONS(4337),
    [anon_sym_WHILE] = ACTIONS(4337),
    [anon_sym_While] = ACTIONS(4337),
    [anon_sym_repeat] = ACTIONS(4337),
    [anon_sym_REPEAT] = ACTIONS(4337),
    [anon_sym_Repeat] = ACTIONS(4337),
    [anon_sym_exit] = ACTIONS(4337),
    [anon_sym_EXIT] = ACTIONS(4337),
    [anon_sym_Exit] = ACTIONS(4337),
    [anon_sym_continue] = ACTIONS(4337),
    [anon_sym_CONTINUE] = ACTIONS(4337),
    [anon_sym_Continue] = ACTIONS(4337),
    [anon_sym_break] = ACTIONS(4337),
    [anon_sym_BREAK] = ACTIONS(4337),
    [anon_sym_Break] = ACTIONS(4337),
    [anon_sym_with] = ACTIONS(4337),
    [anon_sym_WITH] = ACTIONS(4337),
    [anon_sym_With] = ACTIONS(4337),
    [sym_asserterror_keyword] = ACTIONS(4339),
    [sym_page_keyword] = ACTIONS(4337),
    [anon_sym_codeunit] = ACTIONS(4337),
    [anon_sym_CODEUNIT] = ACTIONS(4337),
    [anon_sym_Codeunit] = ACTIONS(4337),
    [anon_sym_CodeUnit] = ACTIONS(4337),
    [anon_sym_COdeunit] = ACTIONS(4337),
    [anon_sym_codeUnit] = ACTIONS(4337),
    [sym_report_keyword] = ACTIONS(4337),
    [sym_query_keyword] = ACTIONS(4337),
    [anon_sym_xmlport] = ACTIONS(4337),
    [anon_sym_XMLPORT] = ACTIONS(4337),
    [anon_sym_Xmlport] = ACTIONS(4337),
    [anon_sym_XMLport] = ACTIONS(4337),
    [anon_sym_XMLPort] = ACTIONS(4337),
    [anon_sym_XmlPort] = ACTIONS(4337),
    [anon_sym_enum] = ACTIONS(4337),
    [anon_sym_ENUM] = ACTIONS(4337),
    [anon_sym_Enum] = ACTIONS(4337),
    [anon_sym_eNUM] = ACTIONS(4337),
    [anon_sym_eNum] = ACTIONS(4337),
    [anon_sym_ENum] = ACTIONS(4337),
    [sym_quoted_identifier] = ACTIONS(4339),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4339),
    [sym_integer] = ACTIONS(4337),
    [sym_continue_as_identifier] = ACTIONS(4339),
    [sym_preproc_open] = ACTIONS(4339),
    [sym_end_keyword] = ACTIONS(4339),
  },
  [STATE(2333)] = {
    [sym_identifier] = ACTIONS(4720),
    [anon_sym_SEMI] = ACTIONS(4722),
    [anon_sym_DASH] = ACTIONS(4722),
    [aux_sym_boolean_token1] = ACTIONS(4720),
    [aux_sym_boolean_token2] = ACTIONS(4720),
    [sym_decimal] = ACTIONS(4720),
    [anon_sym_LPAREN] = ACTIONS(4722),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4720),
    [anon_sym_LBRACK] = ACTIONS(4722),
    [aux_sym_record_type_token1] = ACTIONS(4720),
    [aux_sym_basic_type_token21] = ACTIONS(4720),
    [aux_sym_basic_type_token22] = ACTIONS(4720),
    [aux_sym_basic_type_token48] = ACTIONS(4720),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4720),
    [anon_sym_POUNDif] = ACTIONS(4722),
    [anon_sym_POUNDIF] = ACTIONS(4722),
    [anon_sym_POUNDIf] = ACTIONS(4722),
    [anon_sym_not] = ACTIONS(4720),
    [anon_sym_NOT] = ACTIONS(4720),
    [anon_sym_Not] = ACTIONS(4720),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4720),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4720),
    [anon_sym_PLUS] = ACTIONS(4722),
    [sym_datetime_literal] = ACTIONS(4722),
    [sym_date_literal] = ACTIONS(4720),
    [sym_time_literal] = ACTIONS(4720),
    [sym_biginteger_literal] = ACTIONS(4722),
    [anon_sym_if] = ACTIONS(4720),
    [anon_sym_IF] = ACTIONS(4720),
    [anon_sym_If] = ACTIONS(4720),
    [anon_sym_else] = ACTIONS(4720),
    [anon_sym_ELSE] = ACTIONS(4720),
    [anon_sym_Else] = ACTIONS(4720),
    [anon_sym_case] = ACTIONS(4720),
    [anon_sym_CASE] = ACTIONS(4720),
    [anon_sym_Case] = ACTIONS(4720),
    [anon_sym_for] = ACTIONS(4720),
    [anon_sym_FOR] = ACTIONS(4720),
    [anon_sym_For] = ACTIONS(4720),
    [anon_sym_foreach] = ACTIONS(4720),
    [anon_sym_FOREACH] = ACTIONS(4720),
    [anon_sym_Foreach] = ACTIONS(4720),
    [anon_sym_while] = ACTIONS(4720),
    [anon_sym_WHILE] = ACTIONS(4720),
    [anon_sym_While] = ACTIONS(4720),
    [anon_sym_repeat] = ACTIONS(4720),
    [anon_sym_REPEAT] = ACTIONS(4720),
    [anon_sym_Repeat] = ACTIONS(4720),
    [anon_sym_exit] = ACTIONS(4720),
    [anon_sym_EXIT] = ACTIONS(4720),
    [anon_sym_Exit] = ACTIONS(4720),
    [anon_sym_continue] = ACTIONS(4720),
    [anon_sym_CONTINUE] = ACTIONS(4720),
    [anon_sym_Continue] = ACTIONS(4720),
    [anon_sym_break] = ACTIONS(4720),
    [anon_sym_BREAK] = ACTIONS(4720),
    [anon_sym_Break] = ACTIONS(4720),
    [anon_sym_with] = ACTIONS(4720),
    [anon_sym_WITH] = ACTIONS(4720),
    [anon_sym_With] = ACTIONS(4720),
    [sym_asserterror_keyword] = ACTIONS(4722),
    [sym_page_keyword] = ACTIONS(4720),
    [anon_sym_codeunit] = ACTIONS(4720),
    [anon_sym_CODEUNIT] = ACTIONS(4720),
    [anon_sym_Codeunit] = ACTIONS(4720),
    [anon_sym_CodeUnit] = ACTIONS(4720),
    [anon_sym_COdeunit] = ACTIONS(4720),
    [anon_sym_codeUnit] = ACTIONS(4720),
    [sym_report_keyword] = ACTIONS(4720),
    [sym_query_keyword] = ACTIONS(4720),
    [anon_sym_xmlport] = ACTIONS(4720),
    [anon_sym_XMLPORT] = ACTIONS(4720),
    [anon_sym_Xmlport] = ACTIONS(4720),
    [anon_sym_XMLport] = ACTIONS(4720),
    [anon_sym_XMLPort] = ACTIONS(4720),
    [anon_sym_XmlPort] = ACTIONS(4720),
    [anon_sym_enum] = ACTIONS(4720),
    [anon_sym_ENUM] = ACTIONS(4720),
    [anon_sym_Enum] = ACTIONS(4720),
    [anon_sym_eNUM] = ACTIONS(4720),
    [anon_sym_eNum] = ACTIONS(4720),
    [anon_sym_ENum] = ACTIONS(4720),
    [sym_quoted_identifier] = ACTIONS(4722),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4722),
    [sym_integer] = ACTIONS(4720),
    [sym_continue_as_identifier] = ACTIONS(4722),
    [sym_preproc_open] = ACTIONS(4722),
    [sym_end_keyword] = ACTIONS(4722),
  },
  [STATE(2334)] = {
    [sym_identifier] = ACTIONS(4341),
    [anon_sym_SEMI] = ACTIONS(4343),
    [anon_sym_DASH] = ACTIONS(4343),
    [aux_sym_boolean_token1] = ACTIONS(4341),
    [aux_sym_boolean_token2] = ACTIONS(4341),
    [sym_decimal] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4343),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4341),
    [anon_sym_LBRACK] = ACTIONS(4343),
    [aux_sym_record_type_token1] = ACTIONS(4341),
    [aux_sym_basic_type_token21] = ACTIONS(4341),
    [aux_sym_basic_type_token22] = ACTIONS(4341),
    [aux_sym_basic_type_token48] = ACTIONS(4341),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4341),
    [anon_sym_POUNDif] = ACTIONS(4343),
    [anon_sym_POUNDIF] = ACTIONS(4343),
    [anon_sym_POUNDIf] = ACTIONS(4343),
    [anon_sym_not] = ACTIONS(4341),
    [anon_sym_NOT] = ACTIONS(4341),
    [anon_sym_Not] = ACTIONS(4341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4341),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4343),
    [sym_datetime_literal] = ACTIONS(4343),
    [sym_date_literal] = ACTIONS(4341),
    [sym_time_literal] = ACTIONS(4341),
    [sym_biginteger_literal] = ACTIONS(4343),
    [anon_sym_if] = ACTIONS(4341),
    [anon_sym_IF] = ACTIONS(4341),
    [anon_sym_If] = ACTIONS(4341),
    [anon_sym_else] = ACTIONS(4341),
    [anon_sym_ELSE] = ACTIONS(4341),
    [anon_sym_Else] = ACTIONS(4341),
    [anon_sym_case] = ACTIONS(4341),
    [anon_sym_CASE] = ACTIONS(4341),
    [anon_sym_Case] = ACTIONS(4341),
    [anon_sym_for] = ACTIONS(4341),
    [anon_sym_FOR] = ACTIONS(4341),
    [anon_sym_For] = ACTIONS(4341),
    [anon_sym_foreach] = ACTIONS(4341),
    [anon_sym_FOREACH] = ACTIONS(4341),
    [anon_sym_Foreach] = ACTIONS(4341),
    [anon_sym_while] = ACTIONS(4341),
    [anon_sym_WHILE] = ACTIONS(4341),
    [anon_sym_While] = ACTIONS(4341),
    [anon_sym_repeat] = ACTIONS(4341),
    [anon_sym_REPEAT] = ACTIONS(4341),
    [anon_sym_Repeat] = ACTIONS(4341),
    [anon_sym_exit] = ACTIONS(4341),
    [anon_sym_EXIT] = ACTIONS(4341),
    [anon_sym_Exit] = ACTIONS(4341),
    [anon_sym_continue] = ACTIONS(4341),
    [anon_sym_CONTINUE] = ACTIONS(4341),
    [anon_sym_Continue] = ACTIONS(4341),
    [anon_sym_break] = ACTIONS(4341),
    [anon_sym_BREAK] = ACTIONS(4341),
    [anon_sym_Break] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4341),
    [anon_sym_WITH] = ACTIONS(4341),
    [anon_sym_With] = ACTIONS(4341),
    [sym_asserterror_keyword] = ACTIONS(4343),
    [sym_page_keyword] = ACTIONS(4341),
    [anon_sym_codeunit] = ACTIONS(4341),
    [anon_sym_CODEUNIT] = ACTIONS(4341),
    [anon_sym_Codeunit] = ACTIONS(4341),
    [anon_sym_CodeUnit] = ACTIONS(4341),
    [anon_sym_COdeunit] = ACTIONS(4341),
    [anon_sym_codeUnit] = ACTIONS(4341),
    [sym_report_keyword] = ACTIONS(4341),
    [sym_query_keyword] = ACTIONS(4341),
    [anon_sym_xmlport] = ACTIONS(4341),
    [anon_sym_XMLPORT] = ACTIONS(4341),
    [anon_sym_Xmlport] = ACTIONS(4341),
    [anon_sym_XMLport] = ACTIONS(4341),
    [anon_sym_XMLPort] = ACTIONS(4341),
    [anon_sym_XmlPort] = ACTIONS(4341),
    [anon_sym_enum] = ACTIONS(4341),
    [anon_sym_ENUM] = ACTIONS(4341),
    [anon_sym_Enum] = ACTIONS(4341),
    [anon_sym_eNUM] = ACTIONS(4341),
    [anon_sym_eNum] = ACTIONS(4341),
    [anon_sym_ENum] = ACTIONS(4341),
    [sym_quoted_identifier] = ACTIONS(4343),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4343),
    [sym_integer] = ACTIONS(4341),
    [sym_continue_as_identifier] = ACTIONS(4343),
    [sym_preproc_open] = ACTIONS(4343),
    [sym_end_keyword] = ACTIONS(4343),
  },
  [STATE(2335)] = {
    [sym_identifier] = ACTIONS(4345),
    [anon_sym_SEMI] = ACTIONS(4347),
    [anon_sym_DASH] = ACTIONS(4347),
    [aux_sym_boolean_token1] = ACTIONS(4345),
    [aux_sym_boolean_token2] = ACTIONS(4345),
    [sym_decimal] = ACTIONS(4345),
    [anon_sym_LPAREN] = ACTIONS(4347),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4345),
    [anon_sym_LBRACK] = ACTIONS(4347),
    [aux_sym_record_type_token1] = ACTIONS(4345),
    [aux_sym_basic_type_token21] = ACTIONS(4345),
    [aux_sym_basic_type_token22] = ACTIONS(4345),
    [aux_sym_basic_type_token48] = ACTIONS(4345),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4345),
    [anon_sym_POUNDif] = ACTIONS(4347),
    [anon_sym_POUNDIF] = ACTIONS(4347),
    [anon_sym_POUNDIf] = ACTIONS(4347),
    [anon_sym_not] = ACTIONS(4345),
    [anon_sym_NOT] = ACTIONS(4345),
    [anon_sym_Not] = ACTIONS(4345),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4345),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4345),
    [anon_sym_PLUS] = ACTIONS(4347),
    [sym_datetime_literal] = ACTIONS(4347),
    [sym_date_literal] = ACTIONS(4345),
    [sym_time_literal] = ACTIONS(4345),
    [sym_biginteger_literal] = ACTIONS(4347),
    [anon_sym_if] = ACTIONS(4345),
    [anon_sym_IF] = ACTIONS(4345),
    [anon_sym_If] = ACTIONS(4345),
    [anon_sym_else] = ACTIONS(4345),
    [anon_sym_ELSE] = ACTIONS(4345),
    [anon_sym_Else] = ACTIONS(4345),
    [anon_sym_case] = ACTIONS(4345),
    [anon_sym_CASE] = ACTIONS(4345),
    [anon_sym_Case] = ACTIONS(4345),
    [anon_sym_for] = ACTIONS(4345),
    [anon_sym_FOR] = ACTIONS(4345),
    [anon_sym_For] = ACTIONS(4345),
    [anon_sym_foreach] = ACTIONS(4345),
    [anon_sym_FOREACH] = ACTIONS(4345),
    [anon_sym_Foreach] = ACTIONS(4345),
    [anon_sym_while] = ACTIONS(4345),
    [anon_sym_WHILE] = ACTIONS(4345),
    [anon_sym_While] = ACTIONS(4345),
    [anon_sym_repeat] = ACTIONS(4345),
    [anon_sym_REPEAT] = ACTIONS(4345),
    [anon_sym_Repeat] = ACTIONS(4345),
    [anon_sym_exit] = ACTIONS(4345),
    [anon_sym_EXIT] = ACTIONS(4345),
    [anon_sym_Exit] = ACTIONS(4345),
    [anon_sym_continue] = ACTIONS(4345),
    [anon_sym_CONTINUE] = ACTIONS(4345),
    [anon_sym_Continue] = ACTIONS(4345),
    [anon_sym_break] = ACTIONS(4345),
    [anon_sym_BREAK] = ACTIONS(4345),
    [anon_sym_Break] = ACTIONS(4345),
    [anon_sym_with] = ACTIONS(4345),
    [anon_sym_WITH] = ACTIONS(4345),
    [anon_sym_With] = ACTIONS(4345),
    [sym_asserterror_keyword] = ACTIONS(4347),
    [sym_page_keyword] = ACTIONS(4345),
    [anon_sym_codeunit] = ACTIONS(4345),
    [anon_sym_CODEUNIT] = ACTIONS(4345),
    [anon_sym_Codeunit] = ACTIONS(4345),
    [anon_sym_CodeUnit] = ACTIONS(4345),
    [anon_sym_COdeunit] = ACTIONS(4345),
    [anon_sym_codeUnit] = ACTIONS(4345),
    [sym_report_keyword] = ACTIONS(4345),
    [sym_query_keyword] = ACTIONS(4345),
    [anon_sym_xmlport] = ACTIONS(4345),
    [anon_sym_XMLPORT] = ACTIONS(4345),
    [anon_sym_Xmlport] = ACTIONS(4345),
    [anon_sym_XMLport] = ACTIONS(4345),
    [anon_sym_XMLPort] = ACTIONS(4345),
    [anon_sym_XmlPort] = ACTIONS(4345),
    [anon_sym_enum] = ACTIONS(4345),
    [anon_sym_ENUM] = ACTIONS(4345),
    [anon_sym_Enum] = ACTIONS(4345),
    [anon_sym_eNUM] = ACTIONS(4345),
    [anon_sym_eNum] = ACTIONS(4345),
    [anon_sym_ENum] = ACTIONS(4345),
    [sym_quoted_identifier] = ACTIONS(4347),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4347),
    [sym_integer] = ACTIONS(4345),
    [sym_continue_as_identifier] = ACTIONS(4347),
    [sym_preproc_open] = ACTIONS(4347),
    [sym_end_keyword] = ACTIONS(4347),
  },
  [STATE(2336)] = {
    [sym_identifier] = ACTIONS(4724),
    [anon_sym_SEMI] = ACTIONS(4726),
    [anon_sym_DASH] = ACTIONS(4726),
    [aux_sym_boolean_token1] = ACTIONS(4724),
    [aux_sym_boolean_token2] = ACTIONS(4724),
    [sym_decimal] = ACTIONS(4724),
    [anon_sym_LPAREN] = ACTIONS(4726),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4724),
    [anon_sym_LBRACK] = ACTIONS(4726),
    [aux_sym_record_type_token1] = ACTIONS(4724),
    [aux_sym_basic_type_token21] = ACTIONS(4724),
    [aux_sym_basic_type_token22] = ACTIONS(4724),
    [aux_sym_basic_type_token48] = ACTIONS(4724),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4724),
    [anon_sym_POUNDif] = ACTIONS(4726),
    [anon_sym_POUNDIF] = ACTIONS(4726),
    [anon_sym_POUNDIf] = ACTIONS(4726),
    [anon_sym_not] = ACTIONS(4724),
    [anon_sym_NOT] = ACTIONS(4724),
    [anon_sym_Not] = ACTIONS(4724),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4724),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4724),
    [anon_sym_PLUS] = ACTIONS(4726),
    [sym_datetime_literal] = ACTIONS(4726),
    [sym_date_literal] = ACTIONS(4724),
    [sym_time_literal] = ACTIONS(4724),
    [sym_biginteger_literal] = ACTIONS(4726),
    [anon_sym_if] = ACTIONS(4724),
    [anon_sym_IF] = ACTIONS(4724),
    [anon_sym_If] = ACTIONS(4724),
    [anon_sym_else] = ACTIONS(4724),
    [anon_sym_ELSE] = ACTIONS(4724),
    [anon_sym_Else] = ACTIONS(4724),
    [anon_sym_case] = ACTIONS(4724),
    [anon_sym_CASE] = ACTIONS(4724),
    [anon_sym_Case] = ACTIONS(4724),
    [anon_sym_for] = ACTIONS(4724),
    [anon_sym_FOR] = ACTIONS(4724),
    [anon_sym_For] = ACTIONS(4724),
    [anon_sym_foreach] = ACTIONS(4724),
    [anon_sym_FOREACH] = ACTIONS(4724),
    [anon_sym_Foreach] = ACTIONS(4724),
    [anon_sym_while] = ACTIONS(4724),
    [anon_sym_WHILE] = ACTIONS(4724),
    [anon_sym_While] = ACTIONS(4724),
    [anon_sym_repeat] = ACTIONS(4724),
    [anon_sym_REPEAT] = ACTIONS(4724),
    [anon_sym_Repeat] = ACTIONS(4724),
    [anon_sym_exit] = ACTIONS(4724),
    [anon_sym_EXIT] = ACTIONS(4724),
    [anon_sym_Exit] = ACTIONS(4724),
    [anon_sym_continue] = ACTIONS(4724),
    [anon_sym_CONTINUE] = ACTIONS(4724),
    [anon_sym_Continue] = ACTIONS(4724),
    [anon_sym_break] = ACTIONS(4724),
    [anon_sym_BREAK] = ACTIONS(4724),
    [anon_sym_Break] = ACTIONS(4724),
    [anon_sym_with] = ACTIONS(4724),
    [anon_sym_WITH] = ACTIONS(4724),
    [anon_sym_With] = ACTIONS(4724),
    [sym_asserterror_keyword] = ACTIONS(4726),
    [sym_page_keyword] = ACTIONS(4724),
    [anon_sym_codeunit] = ACTIONS(4724),
    [anon_sym_CODEUNIT] = ACTIONS(4724),
    [anon_sym_Codeunit] = ACTIONS(4724),
    [anon_sym_CodeUnit] = ACTIONS(4724),
    [anon_sym_COdeunit] = ACTIONS(4724),
    [anon_sym_codeUnit] = ACTIONS(4724),
    [sym_report_keyword] = ACTIONS(4724),
    [sym_query_keyword] = ACTIONS(4724),
    [anon_sym_xmlport] = ACTIONS(4724),
    [anon_sym_XMLPORT] = ACTIONS(4724),
    [anon_sym_Xmlport] = ACTIONS(4724),
    [anon_sym_XMLport] = ACTIONS(4724),
    [anon_sym_XMLPort] = ACTIONS(4724),
    [anon_sym_XmlPort] = ACTIONS(4724),
    [anon_sym_enum] = ACTIONS(4724),
    [anon_sym_ENUM] = ACTIONS(4724),
    [anon_sym_Enum] = ACTIONS(4724),
    [anon_sym_eNUM] = ACTIONS(4724),
    [anon_sym_eNum] = ACTIONS(4724),
    [anon_sym_ENum] = ACTIONS(4724),
    [sym_quoted_identifier] = ACTIONS(4726),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4726),
    [sym_integer] = ACTIONS(4724),
    [sym_continue_as_identifier] = ACTIONS(4726),
    [sym_preproc_open] = ACTIONS(4726),
    [sym_end_keyword] = ACTIONS(4726),
  },
  [STATE(2337)] = {
    [sym_identifier] = ACTIONS(4720),
    [anon_sym_SEMI] = ACTIONS(4722),
    [anon_sym_DASH] = ACTIONS(4722),
    [aux_sym_boolean_token1] = ACTIONS(4720),
    [aux_sym_boolean_token2] = ACTIONS(4720),
    [sym_decimal] = ACTIONS(4720),
    [anon_sym_LPAREN] = ACTIONS(4722),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4720),
    [anon_sym_LBRACK] = ACTIONS(4722),
    [aux_sym_record_type_token1] = ACTIONS(4720),
    [aux_sym_basic_type_token21] = ACTIONS(4720),
    [aux_sym_basic_type_token22] = ACTIONS(4720),
    [aux_sym_basic_type_token48] = ACTIONS(4720),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4720),
    [anon_sym_POUNDif] = ACTIONS(4722),
    [anon_sym_POUNDIF] = ACTIONS(4722),
    [anon_sym_POUNDIf] = ACTIONS(4722),
    [anon_sym_not] = ACTIONS(4720),
    [anon_sym_NOT] = ACTIONS(4720),
    [anon_sym_Not] = ACTIONS(4720),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4720),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4720),
    [anon_sym_PLUS] = ACTIONS(4722),
    [sym_datetime_literal] = ACTIONS(4722),
    [sym_date_literal] = ACTIONS(4720),
    [sym_time_literal] = ACTIONS(4720),
    [sym_biginteger_literal] = ACTIONS(4722),
    [anon_sym_if] = ACTIONS(4720),
    [anon_sym_IF] = ACTIONS(4720),
    [anon_sym_If] = ACTIONS(4720),
    [anon_sym_else] = ACTIONS(4720),
    [anon_sym_ELSE] = ACTIONS(4720),
    [anon_sym_Else] = ACTIONS(4720),
    [anon_sym_case] = ACTIONS(4720),
    [anon_sym_CASE] = ACTIONS(4720),
    [anon_sym_Case] = ACTIONS(4720),
    [anon_sym_for] = ACTIONS(4720),
    [anon_sym_FOR] = ACTIONS(4720),
    [anon_sym_For] = ACTIONS(4720),
    [anon_sym_foreach] = ACTIONS(4720),
    [anon_sym_FOREACH] = ACTIONS(4720),
    [anon_sym_Foreach] = ACTIONS(4720),
    [anon_sym_while] = ACTIONS(4720),
    [anon_sym_WHILE] = ACTIONS(4720),
    [anon_sym_While] = ACTIONS(4720),
    [anon_sym_repeat] = ACTIONS(4720),
    [anon_sym_REPEAT] = ACTIONS(4720),
    [anon_sym_Repeat] = ACTIONS(4720),
    [anon_sym_exit] = ACTIONS(4720),
    [anon_sym_EXIT] = ACTIONS(4720),
    [anon_sym_Exit] = ACTIONS(4720),
    [anon_sym_continue] = ACTIONS(4720),
    [anon_sym_CONTINUE] = ACTIONS(4720),
    [anon_sym_Continue] = ACTIONS(4720),
    [anon_sym_break] = ACTIONS(4720),
    [anon_sym_BREAK] = ACTIONS(4720),
    [anon_sym_Break] = ACTIONS(4720),
    [anon_sym_with] = ACTIONS(4720),
    [anon_sym_WITH] = ACTIONS(4720),
    [anon_sym_With] = ACTIONS(4720),
    [sym_asserterror_keyword] = ACTIONS(4722),
    [sym_page_keyword] = ACTIONS(4720),
    [anon_sym_codeunit] = ACTIONS(4720),
    [anon_sym_CODEUNIT] = ACTIONS(4720),
    [anon_sym_Codeunit] = ACTIONS(4720),
    [anon_sym_CodeUnit] = ACTIONS(4720),
    [anon_sym_COdeunit] = ACTIONS(4720),
    [anon_sym_codeUnit] = ACTIONS(4720),
    [sym_report_keyword] = ACTIONS(4720),
    [sym_query_keyword] = ACTIONS(4720),
    [anon_sym_xmlport] = ACTIONS(4720),
    [anon_sym_XMLPORT] = ACTIONS(4720),
    [anon_sym_Xmlport] = ACTIONS(4720),
    [anon_sym_XMLport] = ACTIONS(4720),
    [anon_sym_XMLPort] = ACTIONS(4720),
    [anon_sym_XmlPort] = ACTIONS(4720),
    [anon_sym_enum] = ACTIONS(4720),
    [anon_sym_ENUM] = ACTIONS(4720),
    [anon_sym_Enum] = ACTIONS(4720),
    [anon_sym_eNUM] = ACTIONS(4720),
    [anon_sym_eNum] = ACTIONS(4720),
    [anon_sym_ENum] = ACTIONS(4720),
    [sym_quoted_identifier] = ACTIONS(4722),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4722),
    [sym_integer] = ACTIONS(4720),
    [sym_continue_as_identifier] = ACTIONS(4722),
    [sym_preproc_open] = ACTIONS(4722),
    [sym_end_keyword] = ACTIONS(4722),
  },
  [STATE(2338)] = {
    [sym_identifier] = ACTIONS(4728),
    [anon_sym_SEMI] = ACTIONS(4730),
    [anon_sym_DASH] = ACTIONS(4730),
    [aux_sym_boolean_token1] = ACTIONS(4728),
    [aux_sym_boolean_token2] = ACTIONS(4728),
    [sym_decimal] = ACTIONS(4728),
    [anon_sym_LPAREN] = ACTIONS(4730),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4728),
    [anon_sym_LBRACK] = ACTIONS(4730),
    [aux_sym_record_type_token1] = ACTIONS(4728),
    [aux_sym_basic_type_token21] = ACTIONS(4728),
    [aux_sym_basic_type_token22] = ACTIONS(4728),
    [aux_sym_basic_type_token48] = ACTIONS(4728),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4728),
    [anon_sym_POUNDif] = ACTIONS(4730),
    [anon_sym_POUNDIF] = ACTIONS(4730),
    [anon_sym_POUNDIf] = ACTIONS(4730),
    [anon_sym_not] = ACTIONS(4728),
    [anon_sym_NOT] = ACTIONS(4728),
    [anon_sym_Not] = ACTIONS(4728),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4728),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4728),
    [anon_sym_PLUS] = ACTIONS(4730),
    [sym_datetime_literal] = ACTIONS(4730),
    [sym_date_literal] = ACTIONS(4728),
    [sym_time_literal] = ACTIONS(4728),
    [sym_biginteger_literal] = ACTIONS(4730),
    [anon_sym_if] = ACTIONS(4728),
    [anon_sym_IF] = ACTIONS(4728),
    [anon_sym_If] = ACTIONS(4728),
    [anon_sym_else] = ACTIONS(4728),
    [anon_sym_ELSE] = ACTIONS(4728),
    [anon_sym_Else] = ACTIONS(4728),
    [anon_sym_case] = ACTIONS(4728),
    [anon_sym_CASE] = ACTIONS(4728),
    [anon_sym_Case] = ACTIONS(4728),
    [anon_sym_for] = ACTIONS(4728),
    [anon_sym_FOR] = ACTIONS(4728),
    [anon_sym_For] = ACTIONS(4728),
    [anon_sym_foreach] = ACTIONS(4728),
    [anon_sym_FOREACH] = ACTIONS(4728),
    [anon_sym_Foreach] = ACTIONS(4728),
    [anon_sym_while] = ACTIONS(4728),
    [anon_sym_WHILE] = ACTIONS(4728),
    [anon_sym_While] = ACTIONS(4728),
    [anon_sym_repeat] = ACTIONS(4728),
    [anon_sym_REPEAT] = ACTIONS(4728),
    [anon_sym_Repeat] = ACTIONS(4728),
    [anon_sym_exit] = ACTIONS(4728),
    [anon_sym_EXIT] = ACTIONS(4728),
    [anon_sym_Exit] = ACTIONS(4728),
    [anon_sym_continue] = ACTIONS(4728),
    [anon_sym_CONTINUE] = ACTIONS(4728),
    [anon_sym_Continue] = ACTIONS(4728),
    [anon_sym_break] = ACTIONS(4728),
    [anon_sym_BREAK] = ACTIONS(4728),
    [anon_sym_Break] = ACTIONS(4728),
    [anon_sym_with] = ACTIONS(4728),
    [anon_sym_WITH] = ACTIONS(4728),
    [anon_sym_With] = ACTIONS(4728),
    [sym_asserterror_keyword] = ACTIONS(4730),
    [sym_page_keyword] = ACTIONS(4728),
    [anon_sym_codeunit] = ACTIONS(4728),
    [anon_sym_CODEUNIT] = ACTIONS(4728),
    [anon_sym_Codeunit] = ACTIONS(4728),
    [anon_sym_CodeUnit] = ACTIONS(4728),
    [anon_sym_COdeunit] = ACTIONS(4728),
    [anon_sym_codeUnit] = ACTIONS(4728),
    [sym_report_keyword] = ACTIONS(4728),
    [sym_query_keyword] = ACTIONS(4728),
    [anon_sym_xmlport] = ACTIONS(4728),
    [anon_sym_XMLPORT] = ACTIONS(4728),
    [anon_sym_Xmlport] = ACTIONS(4728),
    [anon_sym_XMLport] = ACTIONS(4728),
    [anon_sym_XMLPort] = ACTIONS(4728),
    [anon_sym_XmlPort] = ACTIONS(4728),
    [anon_sym_enum] = ACTIONS(4728),
    [anon_sym_ENUM] = ACTIONS(4728),
    [anon_sym_Enum] = ACTIONS(4728),
    [anon_sym_eNUM] = ACTIONS(4728),
    [anon_sym_eNum] = ACTIONS(4728),
    [anon_sym_ENum] = ACTIONS(4728),
    [sym_quoted_identifier] = ACTIONS(4730),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4730),
    [sym_integer] = ACTIONS(4728),
    [sym_continue_as_identifier] = ACTIONS(4730),
    [sym_preproc_open] = ACTIONS(4730),
    [sym_end_keyword] = ACTIONS(4730),
  },
  [STATE(2339)] = {
    [sym_identifier] = ACTIONS(4732),
    [anon_sym_SEMI] = ACTIONS(4734),
    [anon_sym_DASH] = ACTIONS(4734),
    [aux_sym_boolean_token1] = ACTIONS(4732),
    [aux_sym_boolean_token2] = ACTIONS(4732),
    [sym_decimal] = ACTIONS(4732),
    [anon_sym_LPAREN] = ACTIONS(4734),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4732),
    [anon_sym_LBRACK] = ACTIONS(4734),
    [aux_sym_record_type_token1] = ACTIONS(4732),
    [aux_sym_basic_type_token21] = ACTIONS(4732),
    [aux_sym_basic_type_token22] = ACTIONS(4732),
    [aux_sym_basic_type_token48] = ACTIONS(4732),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4732),
    [anon_sym_POUNDif] = ACTIONS(4734),
    [anon_sym_POUNDIF] = ACTIONS(4734),
    [anon_sym_POUNDIf] = ACTIONS(4734),
    [anon_sym_not] = ACTIONS(4732),
    [anon_sym_NOT] = ACTIONS(4732),
    [anon_sym_Not] = ACTIONS(4732),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4732),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4732),
    [anon_sym_PLUS] = ACTIONS(4734),
    [sym_datetime_literal] = ACTIONS(4734),
    [sym_date_literal] = ACTIONS(4732),
    [sym_time_literal] = ACTIONS(4732),
    [sym_biginteger_literal] = ACTIONS(4734),
    [anon_sym_if] = ACTIONS(4732),
    [anon_sym_IF] = ACTIONS(4732),
    [anon_sym_If] = ACTIONS(4732),
    [anon_sym_else] = ACTIONS(4732),
    [anon_sym_ELSE] = ACTIONS(4732),
    [anon_sym_Else] = ACTIONS(4732),
    [anon_sym_case] = ACTIONS(4732),
    [anon_sym_CASE] = ACTIONS(4732),
    [anon_sym_Case] = ACTIONS(4732),
    [anon_sym_for] = ACTIONS(4732),
    [anon_sym_FOR] = ACTIONS(4732),
    [anon_sym_For] = ACTIONS(4732),
    [anon_sym_foreach] = ACTIONS(4732),
    [anon_sym_FOREACH] = ACTIONS(4732),
    [anon_sym_Foreach] = ACTIONS(4732),
    [anon_sym_while] = ACTIONS(4732),
    [anon_sym_WHILE] = ACTIONS(4732),
    [anon_sym_While] = ACTIONS(4732),
    [anon_sym_repeat] = ACTIONS(4732),
    [anon_sym_REPEAT] = ACTIONS(4732),
    [anon_sym_Repeat] = ACTIONS(4732),
    [anon_sym_exit] = ACTIONS(4732),
    [anon_sym_EXIT] = ACTIONS(4732),
    [anon_sym_Exit] = ACTIONS(4732),
    [anon_sym_continue] = ACTIONS(4732),
    [anon_sym_CONTINUE] = ACTIONS(4732),
    [anon_sym_Continue] = ACTIONS(4732),
    [anon_sym_break] = ACTIONS(4732),
    [anon_sym_BREAK] = ACTIONS(4732),
    [anon_sym_Break] = ACTIONS(4732),
    [anon_sym_with] = ACTIONS(4732),
    [anon_sym_WITH] = ACTIONS(4732),
    [anon_sym_With] = ACTIONS(4732),
    [sym_asserterror_keyword] = ACTIONS(4734),
    [sym_page_keyword] = ACTIONS(4732),
    [anon_sym_codeunit] = ACTIONS(4732),
    [anon_sym_CODEUNIT] = ACTIONS(4732),
    [anon_sym_Codeunit] = ACTIONS(4732),
    [anon_sym_CodeUnit] = ACTIONS(4732),
    [anon_sym_COdeunit] = ACTIONS(4732),
    [anon_sym_codeUnit] = ACTIONS(4732),
    [sym_report_keyword] = ACTIONS(4732),
    [sym_query_keyword] = ACTIONS(4732),
    [anon_sym_xmlport] = ACTIONS(4732),
    [anon_sym_XMLPORT] = ACTIONS(4732),
    [anon_sym_Xmlport] = ACTIONS(4732),
    [anon_sym_XMLport] = ACTIONS(4732),
    [anon_sym_XMLPort] = ACTIONS(4732),
    [anon_sym_XmlPort] = ACTIONS(4732),
    [anon_sym_enum] = ACTIONS(4732),
    [anon_sym_ENUM] = ACTIONS(4732),
    [anon_sym_Enum] = ACTIONS(4732),
    [anon_sym_eNUM] = ACTIONS(4732),
    [anon_sym_eNum] = ACTIONS(4732),
    [anon_sym_ENum] = ACTIONS(4732),
    [sym_quoted_identifier] = ACTIONS(4734),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4734),
    [sym_integer] = ACTIONS(4732),
    [sym_continue_as_identifier] = ACTIONS(4734),
    [sym_preproc_open] = ACTIONS(4734),
    [sym_end_keyword] = ACTIONS(4734),
  },
  [STATE(2340)] = {
    [sym_identifier] = ACTIONS(4728),
    [anon_sym_SEMI] = ACTIONS(4730),
    [anon_sym_DASH] = ACTIONS(4730),
    [aux_sym_boolean_token1] = ACTIONS(4728),
    [aux_sym_boolean_token2] = ACTIONS(4728),
    [sym_decimal] = ACTIONS(4728),
    [anon_sym_LPAREN] = ACTIONS(4730),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4728),
    [anon_sym_LBRACK] = ACTIONS(4730),
    [aux_sym_record_type_token1] = ACTIONS(4728),
    [aux_sym_basic_type_token21] = ACTIONS(4728),
    [aux_sym_basic_type_token22] = ACTIONS(4728),
    [aux_sym_basic_type_token48] = ACTIONS(4728),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4728),
    [anon_sym_POUNDif] = ACTIONS(4730),
    [anon_sym_POUNDIF] = ACTIONS(4730),
    [anon_sym_POUNDIf] = ACTIONS(4730),
    [anon_sym_not] = ACTIONS(4728),
    [anon_sym_NOT] = ACTIONS(4728),
    [anon_sym_Not] = ACTIONS(4728),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4728),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4728),
    [anon_sym_PLUS] = ACTIONS(4730),
    [sym_datetime_literal] = ACTIONS(4730),
    [sym_date_literal] = ACTIONS(4728),
    [sym_time_literal] = ACTIONS(4728),
    [sym_biginteger_literal] = ACTIONS(4730),
    [anon_sym_if] = ACTIONS(4728),
    [anon_sym_IF] = ACTIONS(4728),
    [anon_sym_If] = ACTIONS(4728),
    [anon_sym_else] = ACTIONS(4728),
    [anon_sym_ELSE] = ACTIONS(4728),
    [anon_sym_Else] = ACTIONS(4728),
    [anon_sym_case] = ACTIONS(4728),
    [anon_sym_CASE] = ACTIONS(4728),
    [anon_sym_Case] = ACTIONS(4728),
    [anon_sym_for] = ACTIONS(4728),
    [anon_sym_FOR] = ACTIONS(4728),
    [anon_sym_For] = ACTIONS(4728),
    [anon_sym_foreach] = ACTIONS(4728),
    [anon_sym_FOREACH] = ACTIONS(4728),
    [anon_sym_Foreach] = ACTIONS(4728),
    [anon_sym_while] = ACTIONS(4728),
    [anon_sym_WHILE] = ACTIONS(4728),
    [anon_sym_While] = ACTIONS(4728),
    [anon_sym_repeat] = ACTIONS(4728),
    [anon_sym_REPEAT] = ACTIONS(4728),
    [anon_sym_Repeat] = ACTIONS(4728),
    [anon_sym_exit] = ACTIONS(4728),
    [anon_sym_EXIT] = ACTIONS(4728),
    [anon_sym_Exit] = ACTIONS(4728),
    [anon_sym_continue] = ACTIONS(4728),
    [anon_sym_CONTINUE] = ACTIONS(4728),
    [anon_sym_Continue] = ACTIONS(4728),
    [anon_sym_break] = ACTIONS(4728),
    [anon_sym_BREAK] = ACTIONS(4728),
    [anon_sym_Break] = ACTIONS(4728),
    [anon_sym_with] = ACTIONS(4728),
    [anon_sym_WITH] = ACTIONS(4728),
    [anon_sym_With] = ACTIONS(4728),
    [sym_asserterror_keyword] = ACTIONS(4730),
    [sym_page_keyword] = ACTIONS(4728),
    [anon_sym_codeunit] = ACTIONS(4728),
    [anon_sym_CODEUNIT] = ACTIONS(4728),
    [anon_sym_Codeunit] = ACTIONS(4728),
    [anon_sym_CodeUnit] = ACTIONS(4728),
    [anon_sym_COdeunit] = ACTIONS(4728),
    [anon_sym_codeUnit] = ACTIONS(4728),
    [sym_report_keyword] = ACTIONS(4728),
    [sym_query_keyword] = ACTIONS(4728),
    [anon_sym_xmlport] = ACTIONS(4728),
    [anon_sym_XMLPORT] = ACTIONS(4728),
    [anon_sym_Xmlport] = ACTIONS(4728),
    [anon_sym_XMLport] = ACTIONS(4728),
    [anon_sym_XMLPort] = ACTIONS(4728),
    [anon_sym_XmlPort] = ACTIONS(4728),
    [anon_sym_enum] = ACTIONS(4728),
    [anon_sym_ENUM] = ACTIONS(4728),
    [anon_sym_Enum] = ACTIONS(4728),
    [anon_sym_eNUM] = ACTIONS(4728),
    [anon_sym_eNum] = ACTIONS(4728),
    [anon_sym_ENum] = ACTIONS(4728),
    [sym_quoted_identifier] = ACTIONS(4730),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4730),
    [sym_integer] = ACTIONS(4728),
    [sym_continue_as_identifier] = ACTIONS(4730),
    [sym_preproc_open] = ACTIONS(4730),
    [sym_end_keyword] = ACTIONS(4730),
  },
  [STATE(2341)] = {
    [sym_identifier] = ACTIONS(4349),
    [anon_sym_SEMI] = ACTIONS(4351),
    [anon_sym_DASH] = ACTIONS(4351),
    [aux_sym_boolean_token1] = ACTIONS(4349),
    [aux_sym_boolean_token2] = ACTIONS(4349),
    [sym_decimal] = ACTIONS(4349),
    [anon_sym_LPAREN] = ACTIONS(4351),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4349),
    [anon_sym_LBRACK] = ACTIONS(4351),
    [aux_sym_record_type_token1] = ACTIONS(4349),
    [aux_sym_basic_type_token21] = ACTIONS(4349),
    [aux_sym_basic_type_token22] = ACTIONS(4349),
    [aux_sym_basic_type_token48] = ACTIONS(4349),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4349),
    [anon_sym_POUNDif] = ACTIONS(4351),
    [anon_sym_POUNDIF] = ACTIONS(4351),
    [anon_sym_POUNDIf] = ACTIONS(4351),
    [anon_sym_not] = ACTIONS(4349),
    [anon_sym_NOT] = ACTIONS(4349),
    [anon_sym_Not] = ACTIONS(4349),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4349),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4349),
    [anon_sym_PLUS] = ACTIONS(4351),
    [sym_datetime_literal] = ACTIONS(4351),
    [sym_date_literal] = ACTIONS(4349),
    [sym_time_literal] = ACTIONS(4349),
    [sym_biginteger_literal] = ACTIONS(4351),
    [anon_sym_if] = ACTIONS(4349),
    [anon_sym_IF] = ACTIONS(4349),
    [anon_sym_If] = ACTIONS(4349),
    [anon_sym_else] = ACTIONS(4349),
    [anon_sym_ELSE] = ACTIONS(4349),
    [anon_sym_Else] = ACTIONS(4349),
    [anon_sym_case] = ACTIONS(4349),
    [anon_sym_CASE] = ACTIONS(4349),
    [anon_sym_Case] = ACTIONS(4349),
    [anon_sym_for] = ACTIONS(4349),
    [anon_sym_FOR] = ACTIONS(4349),
    [anon_sym_For] = ACTIONS(4349),
    [anon_sym_foreach] = ACTIONS(4349),
    [anon_sym_FOREACH] = ACTIONS(4349),
    [anon_sym_Foreach] = ACTIONS(4349),
    [anon_sym_while] = ACTIONS(4349),
    [anon_sym_WHILE] = ACTIONS(4349),
    [anon_sym_While] = ACTIONS(4349),
    [anon_sym_repeat] = ACTIONS(4349),
    [anon_sym_REPEAT] = ACTIONS(4349),
    [anon_sym_Repeat] = ACTIONS(4349),
    [anon_sym_exit] = ACTIONS(4349),
    [anon_sym_EXIT] = ACTIONS(4349),
    [anon_sym_Exit] = ACTIONS(4349),
    [anon_sym_continue] = ACTIONS(4349),
    [anon_sym_CONTINUE] = ACTIONS(4349),
    [anon_sym_Continue] = ACTIONS(4349),
    [anon_sym_break] = ACTIONS(4349),
    [anon_sym_BREAK] = ACTIONS(4349),
    [anon_sym_Break] = ACTIONS(4349),
    [anon_sym_with] = ACTIONS(4349),
    [anon_sym_WITH] = ACTIONS(4349),
    [anon_sym_With] = ACTIONS(4349),
    [sym_asserterror_keyword] = ACTIONS(4351),
    [sym_page_keyword] = ACTIONS(4349),
    [anon_sym_codeunit] = ACTIONS(4349),
    [anon_sym_CODEUNIT] = ACTIONS(4349),
    [anon_sym_Codeunit] = ACTIONS(4349),
    [anon_sym_CodeUnit] = ACTIONS(4349),
    [anon_sym_COdeunit] = ACTIONS(4349),
    [anon_sym_codeUnit] = ACTIONS(4349),
    [sym_report_keyword] = ACTIONS(4349),
    [sym_query_keyword] = ACTIONS(4349),
    [anon_sym_xmlport] = ACTIONS(4349),
    [anon_sym_XMLPORT] = ACTIONS(4349),
    [anon_sym_Xmlport] = ACTIONS(4349),
    [anon_sym_XMLport] = ACTIONS(4349),
    [anon_sym_XMLPort] = ACTIONS(4349),
    [anon_sym_XmlPort] = ACTIONS(4349),
    [anon_sym_enum] = ACTIONS(4349),
    [anon_sym_ENUM] = ACTIONS(4349),
    [anon_sym_Enum] = ACTIONS(4349),
    [anon_sym_eNUM] = ACTIONS(4349),
    [anon_sym_eNum] = ACTIONS(4349),
    [anon_sym_ENum] = ACTIONS(4349),
    [sym_quoted_identifier] = ACTIONS(4351),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4351),
    [sym_integer] = ACTIONS(4349),
    [sym_continue_as_identifier] = ACTIONS(4351),
    [sym_preproc_open] = ACTIONS(4351),
    [sym_end_keyword] = ACTIONS(4351),
  },
  [STATE(2342)] = {
    [sym_identifier] = ACTIONS(4353),
    [anon_sym_SEMI] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [aux_sym_boolean_token1] = ACTIONS(4353),
    [aux_sym_boolean_token2] = ACTIONS(4353),
    [sym_decimal] = ACTIONS(4353),
    [anon_sym_LPAREN] = ACTIONS(4355),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4353),
    [anon_sym_LBRACK] = ACTIONS(4355),
    [aux_sym_record_type_token1] = ACTIONS(4353),
    [aux_sym_basic_type_token21] = ACTIONS(4353),
    [aux_sym_basic_type_token22] = ACTIONS(4353),
    [aux_sym_basic_type_token48] = ACTIONS(4353),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4353),
    [anon_sym_POUNDif] = ACTIONS(4355),
    [anon_sym_POUNDIF] = ACTIONS(4355),
    [anon_sym_POUNDIf] = ACTIONS(4355),
    [anon_sym_not] = ACTIONS(4353),
    [anon_sym_NOT] = ACTIONS(4353),
    [anon_sym_Not] = ACTIONS(4353),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4353),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4353),
    [anon_sym_PLUS] = ACTIONS(4355),
    [sym_datetime_literal] = ACTIONS(4355),
    [sym_date_literal] = ACTIONS(4353),
    [sym_time_literal] = ACTIONS(4353),
    [sym_biginteger_literal] = ACTIONS(4355),
    [anon_sym_if] = ACTIONS(4353),
    [anon_sym_IF] = ACTIONS(4353),
    [anon_sym_If] = ACTIONS(4353),
    [anon_sym_else] = ACTIONS(4353),
    [anon_sym_ELSE] = ACTIONS(4353),
    [anon_sym_Else] = ACTIONS(4353),
    [anon_sym_case] = ACTIONS(4353),
    [anon_sym_CASE] = ACTIONS(4353),
    [anon_sym_Case] = ACTIONS(4353),
    [anon_sym_for] = ACTIONS(4353),
    [anon_sym_FOR] = ACTIONS(4353),
    [anon_sym_For] = ACTIONS(4353),
    [anon_sym_foreach] = ACTIONS(4353),
    [anon_sym_FOREACH] = ACTIONS(4353),
    [anon_sym_Foreach] = ACTIONS(4353),
    [anon_sym_while] = ACTIONS(4353),
    [anon_sym_WHILE] = ACTIONS(4353),
    [anon_sym_While] = ACTIONS(4353),
    [anon_sym_repeat] = ACTIONS(4353),
    [anon_sym_REPEAT] = ACTIONS(4353),
    [anon_sym_Repeat] = ACTIONS(4353),
    [anon_sym_exit] = ACTIONS(4353),
    [anon_sym_EXIT] = ACTIONS(4353),
    [anon_sym_Exit] = ACTIONS(4353),
    [anon_sym_continue] = ACTIONS(4353),
    [anon_sym_CONTINUE] = ACTIONS(4353),
    [anon_sym_Continue] = ACTIONS(4353),
    [anon_sym_break] = ACTIONS(4353),
    [anon_sym_BREAK] = ACTIONS(4353),
    [anon_sym_Break] = ACTIONS(4353),
    [anon_sym_with] = ACTIONS(4353),
    [anon_sym_WITH] = ACTIONS(4353),
    [anon_sym_With] = ACTIONS(4353),
    [sym_asserterror_keyword] = ACTIONS(4355),
    [sym_page_keyword] = ACTIONS(4353),
    [anon_sym_codeunit] = ACTIONS(4353),
    [anon_sym_CODEUNIT] = ACTIONS(4353),
    [anon_sym_Codeunit] = ACTIONS(4353),
    [anon_sym_CodeUnit] = ACTIONS(4353),
    [anon_sym_COdeunit] = ACTIONS(4353),
    [anon_sym_codeUnit] = ACTIONS(4353),
    [sym_report_keyword] = ACTIONS(4353),
    [sym_query_keyword] = ACTIONS(4353),
    [anon_sym_xmlport] = ACTIONS(4353),
    [anon_sym_XMLPORT] = ACTIONS(4353),
    [anon_sym_Xmlport] = ACTIONS(4353),
    [anon_sym_XMLport] = ACTIONS(4353),
    [anon_sym_XMLPort] = ACTIONS(4353),
    [anon_sym_XmlPort] = ACTIONS(4353),
    [anon_sym_enum] = ACTIONS(4353),
    [anon_sym_ENUM] = ACTIONS(4353),
    [anon_sym_Enum] = ACTIONS(4353),
    [anon_sym_eNUM] = ACTIONS(4353),
    [anon_sym_eNum] = ACTIONS(4353),
    [anon_sym_ENum] = ACTIONS(4353),
    [sym_quoted_identifier] = ACTIONS(4355),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4355),
    [sym_integer] = ACTIONS(4353),
    [sym_continue_as_identifier] = ACTIONS(4355),
    [sym_preproc_open] = ACTIONS(4355),
    [sym_end_keyword] = ACTIONS(4355),
  },
  [STATE(2343)] = {
    [sym_identifier] = ACTIONS(4357),
    [anon_sym_SEMI] = ACTIONS(4359),
    [anon_sym_DASH] = ACTIONS(4359),
    [aux_sym_boolean_token1] = ACTIONS(4357),
    [aux_sym_boolean_token2] = ACTIONS(4357),
    [sym_decimal] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4359),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4357),
    [anon_sym_LBRACK] = ACTIONS(4359),
    [aux_sym_record_type_token1] = ACTIONS(4357),
    [aux_sym_basic_type_token21] = ACTIONS(4357),
    [aux_sym_basic_type_token22] = ACTIONS(4357),
    [aux_sym_basic_type_token48] = ACTIONS(4357),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4357),
    [anon_sym_POUNDif] = ACTIONS(4359),
    [anon_sym_POUNDIF] = ACTIONS(4359),
    [anon_sym_POUNDIf] = ACTIONS(4359),
    [anon_sym_not] = ACTIONS(4357),
    [anon_sym_NOT] = ACTIONS(4357),
    [anon_sym_Not] = ACTIONS(4357),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4357),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4359),
    [sym_datetime_literal] = ACTIONS(4359),
    [sym_date_literal] = ACTIONS(4357),
    [sym_time_literal] = ACTIONS(4357),
    [sym_biginteger_literal] = ACTIONS(4359),
    [anon_sym_if] = ACTIONS(4357),
    [anon_sym_IF] = ACTIONS(4357),
    [anon_sym_If] = ACTIONS(4357),
    [anon_sym_else] = ACTIONS(4357),
    [anon_sym_ELSE] = ACTIONS(4357),
    [anon_sym_Else] = ACTIONS(4357),
    [anon_sym_case] = ACTIONS(4357),
    [anon_sym_CASE] = ACTIONS(4357),
    [anon_sym_Case] = ACTIONS(4357),
    [anon_sym_for] = ACTIONS(4357),
    [anon_sym_FOR] = ACTIONS(4357),
    [anon_sym_For] = ACTIONS(4357),
    [anon_sym_foreach] = ACTIONS(4357),
    [anon_sym_FOREACH] = ACTIONS(4357),
    [anon_sym_Foreach] = ACTIONS(4357),
    [anon_sym_while] = ACTIONS(4357),
    [anon_sym_WHILE] = ACTIONS(4357),
    [anon_sym_While] = ACTIONS(4357),
    [anon_sym_repeat] = ACTIONS(4357),
    [anon_sym_REPEAT] = ACTIONS(4357),
    [anon_sym_Repeat] = ACTIONS(4357),
    [anon_sym_exit] = ACTIONS(4357),
    [anon_sym_EXIT] = ACTIONS(4357),
    [anon_sym_Exit] = ACTIONS(4357),
    [anon_sym_continue] = ACTIONS(4357),
    [anon_sym_CONTINUE] = ACTIONS(4357),
    [anon_sym_Continue] = ACTIONS(4357),
    [anon_sym_break] = ACTIONS(4357),
    [anon_sym_BREAK] = ACTIONS(4357),
    [anon_sym_Break] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4357),
    [anon_sym_WITH] = ACTIONS(4357),
    [anon_sym_With] = ACTIONS(4357),
    [sym_asserterror_keyword] = ACTIONS(4359),
    [sym_page_keyword] = ACTIONS(4357),
    [anon_sym_codeunit] = ACTIONS(4357),
    [anon_sym_CODEUNIT] = ACTIONS(4357),
    [anon_sym_Codeunit] = ACTIONS(4357),
    [anon_sym_CodeUnit] = ACTIONS(4357),
    [anon_sym_COdeunit] = ACTIONS(4357),
    [anon_sym_codeUnit] = ACTIONS(4357),
    [sym_report_keyword] = ACTIONS(4357),
    [sym_query_keyword] = ACTIONS(4357),
    [anon_sym_xmlport] = ACTIONS(4357),
    [anon_sym_XMLPORT] = ACTIONS(4357),
    [anon_sym_Xmlport] = ACTIONS(4357),
    [anon_sym_XMLport] = ACTIONS(4357),
    [anon_sym_XMLPort] = ACTIONS(4357),
    [anon_sym_XmlPort] = ACTIONS(4357),
    [anon_sym_enum] = ACTIONS(4357),
    [anon_sym_ENUM] = ACTIONS(4357),
    [anon_sym_Enum] = ACTIONS(4357),
    [anon_sym_eNUM] = ACTIONS(4357),
    [anon_sym_eNum] = ACTIONS(4357),
    [anon_sym_ENum] = ACTIONS(4357),
    [sym_quoted_identifier] = ACTIONS(4359),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4359),
    [sym_integer] = ACTIONS(4357),
    [sym_continue_as_identifier] = ACTIONS(4359),
    [sym_preproc_open] = ACTIONS(4359),
    [sym_end_keyword] = ACTIONS(4359),
  },
  [STATE(2344)] = {
    [sym_identifier] = ACTIONS(4361),
    [anon_sym_SEMI] = ACTIONS(4363),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(4361),
    [aux_sym_boolean_token2] = ACTIONS(4361),
    [sym_decimal] = ACTIONS(4361),
    [anon_sym_LPAREN] = ACTIONS(4363),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4361),
    [anon_sym_LBRACK] = ACTIONS(4363),
    [aux_sym_record_type_token1] = ACTIONS(4361),
    [aux_sym_basic_type_token21] = ACTIONS(4361),
    [aux_sym_basic_type_token22] = ACTIONS(4361),
    [aux_sym_basic_type_token48] = ACTIONS(4361),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4361),
    [anon_sym_POUNDif] = ACTIONS(4363),
    [anon_sym_POUNDIF] = ACTIONS(4363),
    [anon_sym_POUNDIf] = ACTIONS(4363),
    [anon_sym_not] = ACTIONS(4361),
    [anon_sym_NOT] = ACTIONS(4361),
    [anon_sym_Not] = ACTIONS(4361),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4361),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4361),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4363),
    [sym_date_literal] = ACTIONS(4361),
    [sym_time_literal] = ACTIONS(4361),
    [sym_biginteger_literal] = ACTIONS(4363),
    [anon_sym_if] = ACTIONS(4361),
    [anon_sym_IF] = ACTIONS(4361),
    [anon_sym_If] = ACTIONS(4361),
    [anon_sym_else] = ACTIONS(4361),
    [anon_sym_ELSE] = ACTIONS(4361),
    [anon_sym_Else] = ACTIONS(4361),
    [anon_sym_case] = ACTIONS(4361),
    [anon_sym_CASE] = ACTIONS(4361),
    [anon_sym_Case] = ACTIONS(4361),
    [anon_sym_for] = ACTIONS(4361),
    [anon_sym_FOR] = ACTIONS(4361),
    [anon_sym_For] = ACTIONS(4361),
    [anon_sym_foreach] = ACTIONS(4361),
    [anon_sym_FOREACH] = ACTIONS(4361),
    [anon_sym_Foreach] = ACTIONS(4361),
    [anon_sym_while] = ACTIONS(4361),
    [anon_sym_WHILE] = ACTIONS(4361),
    [anon_sym_While] = ACTIONS(4361),
    [anon_sym_repeat] = ACTIONS(4361),
    [anon_sym_REPEAT] = ACTIONS(4361),
    [anon_sym_Repeat] = ACTIONS(4361),
    [anon_sym_exit] = ACTIONS(4361),
    [anon_sym_EXIT] = ACTIONS(4361),
    [anon_sym_Exit] = ACTIONS(4361),
    [anon_sym_continue] = ACTIONS(4361),
    [anon_sym_CONTINUE] = ACTIONS(4361),
    [anon_sym_Continue] = ACTIONS(4361),
    [anon_sym_break] = ACTIONS(4361),
    [anon_sym_BREAK] = ACTIONS(4361),
    [anon_sym_Break] = ACTIONS(4361),
    [anon_sym_with] = ACTIONS(4361),
    [anon_sym_WITH] = ACTIONS(4361),
    [anon_sym_With] = ACTIONS(4361),
    [sym_asserterror_keyword] = ACTIONS(4363),
    [sym_page_keyword] = ACTIONS(4361),
    [anon_sym_codeunit] = ACTIONS(4361),
    [anon_sym_CODEUNIT] = ACTIONS(4361),
    [anon_sym_Codeunit] = ACTIONS(4361),
    [anon_sym_CodeUnit] = ACTIONS(4361),
    [anon_sym_COdeunit] = ACTIONS(4361),
    [anon_sym_codeUnit] = ACTIONS(4361),
    [sym_report_keyword] = ACTIONS(4361),
    [sym_query_keyword] = ACTIONS(4361),
    [anon_sym_xmlport] = ACTIONS(4361),
    [anon_sym_XMLPORT] = ACTIONS(4361),
    [anon_sym_Xmlport] = ACTIONS(4361),
    [anon_sym_XMLport] = ACTIONS(4361),
    [anon_sym_XMLPort] = ACTIONS(4361),
    [anon_sym_XmlPort] = ACTIONS(4361),
    [anon_sym_enum] = ACTIONS(4361),
    [anon_sym_ENUM] = ACTIONS(4361),
    [anon_sym_Enum] = ACTIONS(4361),
    [anon_sym_eNUM] = ACTIONS(4361),
    [anon_sym_eNum] = ACTIONS(4361),
    [anon_sym_ENum] = ACTIONS(4361),
    [sym_quoted_identifier] = ACTIONS(4363),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4363),
    [sym_integer] = ACTIONS(4361),
    [sym_continue_as_identifier] = ACTIONS(4363),
    [sym_preproc_open] = ACTIONS(4363),
    [sym_end_keyword] = ACTIONS(4363),
  },
  [STATE(2345)] = {
    [sym_identifier] = ACTIONS(4365),
    [anon_sym_SEMI] = ACTIONS(4367),
    [anon_sym_DASH] = ACTIONS(4367),
    [aux_sym_boolean_token1] = ACTIONS(4365),
    [aux_sym_boolean_token2] = ACTIONS(4365),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4365),
    [anon_sym_LBRACK] = ACTIONS(4367),
    [aux_sym_record_type_token1] = ACTIONS(4365),
    [aux_sym_basic_type_token21] = ACTIONS(4365),
    [aux_sym_basic_type_token22] = ACTIONS(4365),
    [aux_sym_basic_type_token48] = ACTIONS(4365),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4365),
    [anon_sym_POUNDif] = ACTIONS(4367),
    [anon_sym_POUNDIF] = ACTIONS(4367),
    [anon_sym_POUNDIf] = ACTIONS(4367),
    [anon_sym_not] = ACTIONS(4365),
    [anon_sym_NOT] = ACTIONS(4365),
    [anon_sym_Not] = ACTIONS(4365),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4365),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4365),
    [anon_sym_PLUS] = ACTIONS(4367),
    [sym_datetime_literal] = ACTIONS(4367),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4367),
    [anon_sym_if] = ACTIONS(4365),
    [anon_sym_IF] = ACTIONS(4365),
    [anon_sym_If] = ACTIONS(4365),
    [anon_sym_else] = ACTIONS(4365),
    [anon_sym_ELSE] = ACTIONS(4365),
    [anon_sym_Else] = ACTIONS(4365),
    [anon_sym_case] = ACTIONS(4365),
    [anon_sym_CASE] = ACTIONS(4365),
    [anon_sym_Case] = ACTIONS(4365),
    [anon_sym_for] = ACTIONS(4365),
    [anon_sym_FOR] = ACTIONS(4365),
    [anon_sym_For] = ACTIONS(4365),
    [anon_sym_foreach] = ACTIONS(4365),
    [anon_sym_FOREACH] = ACTIONS(4365),
    [anon_sym_Foreach] = ACTIONS(4365),
    [anon_sym_while] = ACTIONS(4365),
    [anon_sym_WHILE] = ACTIONS(4365),
    [anon_sym_While] = ACTIONS(4365),
    [anon_sym_repeat] = ACTIONS(4365),
    [anon_sym_REPEAT] = ACTIONS(4365),
    [anon_sym_Repeat] = ACTIONS(4365),
    [anon_sym_exit] = ACTIONS(4365),
    [anon_sym_EXIT] = ACTIONS(4365),
    [anon_sym_Exit] = ACTIONS(4365),
    [anon_sym_continue] = ACTIONS(4365),
    [anon_sym_CONTINUE] = ACTIONS(4365),
    [anon_sym_Continue] = ACTIONS(4365),
    [anon_sym_break] = ACTIONS(4365),
    [anon_sym_BREAK] = ACTIONS(4365),
    [anon_sym_Break] = ACTIONS(4365),
    [anon_sym_with] = ACTIONS(4365),
    [anon_sym_WITH] = ACTIONS(4365),
    [anon_sym_With] = ACTIONS(4365),
    [sym_asserterror_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(4365),
    [anon_sym_codeunit] = ACTIONS(4365),
    [anon_sym_CODEUNIT] = ACTIONS(4365),
    [anon_sym_Codeunit] = ACTIONS(4365),
    [anon_sym_CodeUnit] = ACTIONS(4365),
    [anon_sym_COdeunit] = ACTIONS(4365),
    [anon_sym_codeUnit] = ACTIONS(4365),
    [sym_report_keyword] = ACTIONS(4365),
    [sym_query_keyword] = ACTIONS(4365),
    [anon_sym_xmlport] = ACTIONS(4365),
    [anon_sym_XMLPORT] = ACTIONS(4365),
    [anon_sym_Xmlport] = ACTIONS(4365),
    [anon_sym_XMLport] = ACTIONS(4365),
    [anon_sym_XMLPort] = ACTIONS(4365),
    [anon_sym_XmlPort] = ACTIONS(4365),
    [anon_sym_enum] = ACTIONS(4365),
    [anon_sym_ENUM] = ACTIONS(4365),
    [anon_sym_Enum] = ACTIONS(4365),
    [anon_sym_eNUM] = ACTIONS(4365),
    [anon_sym_eNum] = ACTIONS(4365),
    [anon_sym_ENum] = ACTIONS(4365),
    [sym_quoted_identifier] = ACTIONS(4367),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4367),
    [sym_integer] = ACTIONS(4365),
    [sym_continue_as_identifier] = ACTIONS(4367),
    [sym_preproc_open] = ACTIONS(4367),
    [sym_end_keyword] = ACTIONS(4367),
  },
  [STATE(2346)] = {
    [sym_identifier] = ACTIONS(4369),
    [anon_sym_SEMI] = ACTIONS(4371),
    [anon_sym_DASH] = ACTIONS(4371),
    [aux_sym_boolean_token1] = ACTIONS(4369),
    [aux_sym_boolean_token2] = ACTIONS(4369),
    [sym_decimal] = ACTIONS(4369),
    [anon_sym_LPAREN] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4369),
    [anon_sym_LBRACK] = ACTIONS(4371),
    [aux_sym_record_type_token1] = ACTIONS(4369),
    [aux_sym_basic_type_token21] = ACTIONS(4369),
    [aux_sym_basic_type_token22] = ACTIONS(4369),
    [aux_sym_basic_type_token48] = ACTIONS(4369),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4369),
    [anon_sym_POUNDif] = ACTIONS(4371),
    [anon_sym_POUNDIF] = ACTIONS(4371),
    [anon_sym_POUNDIf] = ACTIONS(4371),
    [anon_sym_not] = ACTIONS(4369),
    [anon_sym_NOT] = ACTIONS(4369),
    [anon_sym_Not] = ACTIONS(4369),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4369),
    [anon_sym_PLUS] = ACTIONS(4371),
    [sym_datetime_literal] = ACTIONS(4371),
    [sym_date_literal] = ACTIONS(4369),
    [sym_time_literal] = ACTIONS(4369),
    [sym_biginteger_literal] = ACTIONS(4371),
    [anon_sym_if] = ACTIONS(4369),
    [anon_sym_IF] = ACTIONS(4369),
    [anon_sym_If] = ACTIONS(4369),
    [anon_sym_else] = ACTIONS(4369),
    [anon_sym_ELSE] = ACTIONS(4369),
    [anon_sym_Else] = ACTIONS(4369),
    [anon_sym_case] = ACTIONS(4369),
    [anon_sym_CASE] = ACTIONS(4369),
    [anon_sym_Case] = ACTIONS(4369),
    [anon_sym_for] = ACTIONS(4369),
    [anon_sym_FOR] = ACTIONS(4369),
    [anon_sym_For] = ACTIONS(4369),
    [anon_sym_foreach] = ACTIONS(4369),
    [anon_sym_FOREACH] = ACTIONS(4369),
    [anon_sym_Foreach] = ACTIONS(4369),
    [anon_sym_while] = ACTIONS(4369),
    [anon_sym_WHILE] = ACTIONS(4369),
    [anon_sym_While] = ACTIONS(4369),
    [anon_sym_repeat] = ACTIONS(4369),
    [anon_sym_REPEAT] = ACTIONS(4369),
    [anon_sym_Repeat] = ACTIONS(4369),
    [anon_sym_exit] = ACTIONS(4369),
    [anon_sym_EXIT] = ACTIONS(4369),
    [anon_sym_Exit] = ACTIONS(4369),
    [anon_sym_continue] = ACTIONS(4369),
    [anon_sym_CONTINUE] = ACTIONS(4369),
    [anon_sym_Continue] = ACTIONS(4369),
    [anon_sym_break] = ACTIONS(4369),
    [anon_sym_BREAK] = ACTIONS(4369),
    [anon_sym_Break] = ACTIONS(4369),
    [anon_sym_with] = ACTIONS(4369),
    [anon_sym_WITH] = ACTIONS(4369),
    [anon_sym_With] = ACTIONS(4369),
    [sym_asserterror_keyword] = ACTIONS(4371),
    [sym_page_keyword] = ACTIONS(4369),
    [anon_sym_codeunit] = ACTIONS(4369),
    [anon_sym_CODEUNIT] = ACTIONS(4369),
    [anon_sym_Codeunit] = ACTIONS(4369),
    [anon_sym_CodeUnit] = ACTIONS(4369),
    [anon_sym_COdeunit] = ACTIONS(4369),
    [anon_sym_codeUnit] = ACTIONS(4369),
    [sym_report_keyword] = ACTIONS(4369),
    [sym_query_keyword] = ACTIONS(4369),
    [anon_sym_xmlport] = ACTIONS(4369),
    [anon_sym_XMLPORT] = ACTIONS(4369),
    [anon_sym_Xmlport] = ACTIONS(4369),
    [anon_sym_XMLport] = ACTIONS(4369),
    [anon_sym_XMLPort] = ACTIONS(4369),
    [anon_sym_XmlPort] = ACTIONS(4369),
    [anon_sym_enum] = ACTIONS(4369),
    [anon_sym_ENUM] = ACTIONS(4369),
    [anon_sym_Enum] = ACTIONS(4369),
    [anon_sym_eNUM] = ACTIONS(4369),
    [anon_sym_eNum] = ACTIONS(4369),
    [anon_sym_ENum] = ACTIONS(4369),
    [sym_quoted_identifier] = ACTIONS(4371),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4371),
    [sym_integer] = ACTIONS(4369),
    [sym_continue_as_identifier] = ACTIONS(4371),
    [sym_preproc_open] = ACTIONS(4371),
    [sym_end_keyword] = ACTIONS(4371),
  },
  [STATE(2347)] = {
    [sym_identifier] = ACTIONS(4391),
    [anon_sym_SEMI] = ACTIONS(4393),
    [anon_sym_DASH] = ACTIONS(4393),
    [aux_sym_boolean_token1] = ACTIONS(4391),
    [aux_sym_boolean_token2] = ACTIONS(4391),
    [sym_decimal] = ACTIONS(4391),
    [anon_sym_LPAREN] = ACTIONS(4393),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4391),
    [anon_sym_LBRACK] = ACTIONS(4393),
    [aux_sym_record_type_token1] = ACTIONS(4391),
    [aux_sym_basic_type_token21] = ACTIONS(4391),
    [aux_sym_basic_type_token22] = ACTIONS(4391),
    [aux_sym_basic_type_token48] = ACTIONS(4391),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4391),
    [anon_sym_POUNDif] = ACTIONS(4393),
    [anon_sym_POUNDIF] = ACTIONS(4393),
    [anon_sym_POUNDIf] = ACTIONS(4393),
    [anon_sym_not] = ACTIONS(4391),
    [anon_sym_NOT] = ACTIONS(4391),
    [anon_sym_Not] = ACTIONS(4391),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4391),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4391),
    [anon_sym_PLUS] = ACTIONS(4393),
    [sym_datetime_literal] = ACTIONS(4393),
    [sym_date_literal] = ACTIONS(4391),
    [sym_time_literal] = ACTIONS(4391),
    [sym_biginteger_literal] = ACTIONS(4393),
    [anon_sym_if] = ACTIONS(4391),
    [anon_sym_IF] = ACTIONS(4391),
    [anon_sym_If] = ACTIONS(4391),
    [anon_sym_else] = ACTIONS(4391),
    [anon_sym_ELSE] = ACTIONS(4391),
    [anon_sym_Else] = ACTIONS(4391),
    [anon_sym_case] = ACTIONS(4391),
    [anon_sym_CASE] = ACTIONS(4391),
    [anon_sym_Case] = ACTIONS(4391),
    [anon_sym_for] = ACTIONS(4391),
    [anon_sym_FOR] = ACTIONS(4391),
    [anon_sym_For] = ACTIONS(4391),
    [anon_sym_foreach] = ACTIONS(4391),
    [anon_sym_FOREACH] = ACTIONS(4391),
    [anon_sym_Foreach] = ACTIONS(4391),
    [anon_sym_while] = ACTIONS(4391),
    [anon_sym_WHILE] = ACTIONS(4391),
    [anon_sym_While] = ACTIONS(4391),
    [anon_sym_repeat] = ACTIONS(4391),
    [anon_sym_REPEAT] = ACTIONS(4391),
    [anon_sym_Repeat] = ACTIONS(4391),
    [anon_sym_exit] = ACTIONS(4391),
    [anon_sym_EXIT] = ACTIONS(4391),
    [anon_sym_Exit] = ACTIONS(4391),
    [anon_sym_continue] = ACTIONS(4391),
    [anon_sym_CONTINUE] = ACTIONS(4391),
    [anon_sym_Continue] = ACTIONS(4391),
    [anon_sym_break] = ACTIONS(4391),
    [anon_sym_BREAK] = ACTIONS(4391),
    [anon_sym_Break] = ACTIONS(4391),
    [anon_sym_with] = ACTIONS(4391),
    [anon_sym_WITH] = ACTIONS(4391),
    [anon_sym_With] = ACTIONS(4391),
    [sym_asserterror_keyword] = ACTIONS(4393),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(4391),
    [anon_sym_CODEUNIT] = ACTIONS(4391),
    [anon_sym_Codeunit] = ACTIONS(4391),
    [anon_sym_CodeUnit] = ACTIONS(4391),
    [anon_sym_COdeunit] = ACTIONS(4391),
    [anon_sym_codeUnit] = ACTIONS(4391),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(4391),
    [anon_sym_XMLPORT] = ACTIONS(4391),
    [anon_sym_Xmlport] = ACTIONS(4391),
    [anon_sym_XMLport] = ACTIONS(4391),
    [anon_sym_XMLPort] = ACTIONS(4391),
    [anon_sym_XmlPort] = ACTIONS(4391),
    [anon_sym_enum] = ACTIONS(4391),
    [anon_sym_ENUM] = ACTIONS(4391),
    [anon_sym_Enum] = ACTIONS(4391),
    [anon_sym_eNUM] = ACTIONS(4391),
    [anon_sym_eNum] = ACTIONS(4391),
    [anon_sym_ENum] = ACTIONS(4391),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4393),
    [sym_integer] = ACTIONS(4391),
    [sym_continue_as_identifier] = ACTIONS(4393),
    [sym_preproc_open] = ACTIONS(4393),
    [sym_end_keyword] = ACTIONS(4393),
  },
  [STATE(2348)] = {
    [sym_identifier] = ACTIONS(4752),
    [anon_sym_SEMI] = ACTIONS(4754),
    [anon_sym_DASH] = ACTIONS(4754),
    [aux_sym_boolean_token1] = ACTIONS(4752),
    [aux_sym_boolean_token2] = ACTIONS(4752),
    [sym_decimal] = ACTIONS(4752),
    [anon_sym_LPAREN] = ACTIONS(4754),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4752),
    [anon_sym_LBRACK] = ACTIONS(4754),
    [aux_sym_record_type_token1] = ACTIONS(4752),
    [aux_sym_basic_type_token21] = ACTIONS(4752),
    [aux_sym_basic_type_token22] = ACTIONS(4752),
    [aux_sym_basic_type_token48] = ACTIONS(4752),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4752),
    [anon_sym_POUNDif] = ACTIONS(4754),
    [anon_sym_POUNDIF] = ACTIONS(4754),
    [anon_sym_POUNDIf] = ACTIONS(4754),
    [anon_sym_not] = ACTIONS(4752),
    [anon_sym_NOT] = ACTIONS(4752),
    [anon_sym_Not] = ACTIONS(4752),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4752),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4752),
    [anon_sym_PLUS] = ACTIONS(4754),
    [sym_datetime_literal] = ACTIONS(4754),
    [sym_date_literal] = ACTIONS(4752),
    [sym_time_literal] = ACTIONS(4752),
    [sym_biginteger_literal] = ACTIONS(4754),
    [anon_sym_if] = ACTIONS(4752),
    [anon_sym_IF] = ACTIONS(4752),
    [anon_sym_If] = ACTIONS(4752),
    [anon_sym_else] = ACTIONS(4752),
    [anon_sym_ELSE] = ACTIONS(4752),
    [anon_sym_Else] = ACTIONS(4752),
    [anon_sym_case] = ACTIONS(4752),
    [anon_sym_CASE] = ACTIONS(4752),
    [anon_sym_Case] = ACTIONS(4752),
    [anon_sym_for] = ACTIONS(4752),
    [anon_sym_FOR] = ACTIONS(4752),
    [anon_sym_For] = ACTIONS(4752),
    [anon_sym_foreach] = ACTIONS(4752),
    [anon_sym_FOREACH] = ACTIONS(4752),
    [anon_sym_Foreach] = ACTIONS(4752),
    [anon_sym_while] = ACTIONS(4752),
    [anon_sym_WHILE] = ACTIONS(4752),
    [anon_sym_While] = ACTIONS(4752),
    [anon_sym_repeat] = ACTIONS(4752),
    [anon_sym_REPEAT] = ACTIONS(4752),
    [anon_sym_Repeat] = ACTIONS(4752),
    [anon_sym_exit] = ACTIONS(4752),
    [anon_sym_EXIT] = ACTIONS(4752),
    [anon_sym_Exit] = ACTIONS(4752),
    [anon_sym_continue] = ACTIONS(4752),
    [anon_sym_CONTINUE] = ACTIONS(4752),
    [anon_sym_Continue] = ACTIONS(4752),
    [anon_sym_break] = ACTIONS(4752),
    [anon_sym_BREAK] = ACTIONS(4752),
    [anon_sym_Break] = ACTIONS(4752),
    [anon_sym_with] = ACTIONS(4752),
    [anon_sym_WITH] = ACTIONS(4752),
    [anon_sym_With] = ACTIONS(4752),
    [sym_asserterror_keyword] = ACTIONS(4754),
    [sym_page_keyword] = ACTIONS(4752),
    [anon_sym_codeunit] = ACTIONS(4752),
    [anon_sym_CODEUNIT] = ACTIONS(4752),
    [anon_sym_Codeunit] = ACTIONS(4752),
    [anon_sym_CodeUnit] = ACTIONS(4752),
    [anon_sym_COdeunit] = ACTIONS(4752),
    [anon_sym_codeUnit] = ACTIONS(4752),
    [sym_report_keyword] = ACTIONS(4752),
    [sym_query_keyword] = ACTIONS(4752),
    [anon_sym_xmlport] = ACTIONS(4752),
    [anon_sym_XMLPORT] = ACTIONS(4752),
    [anon_sym_Xmlport] = ACTIONS(4752),
    [anon_sym_XMLport] = ACTIONS(4752),
    [anon_sym_XMLPort] = ACTIONS(4752),
    [anon_sym_XmlPort] = ACTIONS(4752),
    [anon_sym_enum] = ACTIONS(4752),
    [anon_sym_ENUM] = ACTIONS(4752),
    [anon_sym_Enum] = ACTIONS(4752),
    [anon_sym_eNUM] = ACTIONS(4752),
    [anon_sym_eNum] = ACTIONS(4752),
    [anon_sym_ENum] = ACTIONS(4752),
    [sym_quoted_identifier] = ACTIONS(4754),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4754),
    [sym_integer] = ACTIONS(4752),
    [sym_continue_as_identifier] = ACTIONS(4754),
    [sym_preproc_open] = ACTIONS(4754),
    [sym_end_keyword] = ACTIONS(4754),
  },
  [STATE(2349)] = {
    [sym_identifier] = ACTIONS(4459),
    [anon_sym_SEMI] = ACTIONS(4461),
    [anon_sym_DASH] = ACTIONS(4461),
    [aux_sym_boolean_token1] = ACTIONS(4459),
    [aux_sym_boolean_token2] = ACTIONS(4459),
    [sym_decimal] = ACTIONS(4459),
    [anon_sym_LPAREN] = ACTIONS(4461),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4459),
    [anon_sym_LBRACK] = ACTIONS(4461),
    [aux_sym_record_type_token1] = ACTIONS(4459),
    [aux_sym_basic_type_token21] = ACTIONS(4459),
    [aux_sym_basic_type_token22] = ACTIONS(4459),
    [aux_sym_basic_type_token48] = ACTIONS(4459),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4459),
    [anon_sym_POUNDif] = ACTIONS(4461),
    [anon_sym_POUNDIF] = ACTIONS(4461),
    [anon_sym_POUNDIf] = ACTIONS(4461),
    [anon_sym_not] = ACTIONS(4459),
    [anon_sym_NOT] = ACTIONS(4459),
    [anon_sym_Not] = ACTIONS(4459),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4459),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4459),
    [anon_sym_PLUS] = ACTIONS(4461),
    [sym_datetime_literal] = ACTIONS(4461),
    [sym_date_literal] = ACTIONS(4459),
    [sym_time_literal] = ACTIONS(4459),
    [sym_biginteger_literal] = ACTIONS(4461),
    [anon_sym_if] = ACTIONS(4459),
    [anon_sym_IF] = ACTIONS(4459),
    [anon_sym_If] = ACTIONS(4459),
    [anon_sym_else] = ACTIONS(4459),
    [anon_sym_ELSE] = ACTIONS(4459),
    [anon_sym_Else] = ACTIONS(4459),
    [anon_sym_case] = ACTIONS(4459),
    [anon_sym_CASE] = ACTIONS(4459),
    [anon_sym_Case] = ACTIONS(4459),
    [anon_sym_for] = ACTIONS(4459),
    [anon_sym_FOR] = ACTIONS(4459),
    [anon_sym_For] = ACTIONS(4459),
    [anon_sym_foreach] = ACTIONS(4459),
    [anon_sym_FOREACH] = ACTIONS(4459),
    [anon_sym_Foreach] = ACTIONS(4459),
    [anon_sym_while] = ACTIONS(4459),
    [anon_sym_WHILE] = ACTIONS(4459),
    [anon_sym_While] = ACTIONS(4459),
    [anon_sym_repeat] = ACTIONS(4459),
    [anon_sym_REPEAT] = ACTIONS(4459),
    [anon_sym_Repeat] = ACTIONS(4459),
    [anon_sym_exit] = ACTIONS(4459),
    [anon_sym_EXIT] = ACTIONS(4459),
    [anon_sym_Exit] = ACTIONS(4459),
    [anon_sym_continue] = ACTIONS(4459),
    [anon_sym_CONTINUE] = ACTIONS(4459),
    [anon_sym_Continue] = ACTIONS(4459),
    [anon_sym_break] = ACTIONS(4459),
    [anon_sym_BREAK] = ACTIONS(4459),
    [anon_sym_Break] = ACTIONS(4459),
    [anon_sym_with] = ACTIONS(4459),
    [anon_sym_WITH] = ACTIONS(4459),
    [anon_sym_With] = ACTIONS(4459),
    [sym_asserterror_keyword] = ACTIONS(4461),
    [sym_page_keyword] = ACTIONS(4459),
    [anon_sym_codeunit] = ACTIONS(4459),
    [anon_sym_CODEUNIT] = ACTIONS(4459),
    [anon_sym_Codeunit] = ACTIONS(4459),
    [anon_sym_CodeUnit] = ACTIONS(4459),
    [anon_sym_COdeunit] = ACTIONS(4459),
    [anon_sym_codeUnit] = ACTIONS(4459),
    [sym_report_keyword] = ACTIONS(4459),
    [sym_query_keyword] = ACTIONS(4459),
    [anon_sym_xmlport] = ACTIONS(4459),
    [anon_sym_XMLPORT] = ACTIONS(4459),
    [anon_sym_Xmlport] = ACTIONS(4459),
    [anon_sym_XMLport] = ACTIONS(4459),
    [anon_sym_XMLPort] = ACTIONS(4459),
    [anon_sym_XmlPort] = ACTIONS(4459),
    [anon_sym_enum] = ACTIONS(4459),
    [anon_sym_ENUM] = ACTIONS(4459),
    [anon_sym_Enum] = ACTIONS(4459),
    [anon_sym_eNUM] = ACTIONS(4459),
    [anon_sym_eNum] = ACTIONS(4459),
    [anon_sym_ENum] = ACTIONS(4459),
    [sym_quoted_identifier] = ACTIONS(4461),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4461),
    [sym_integer] = ACTIONS(4459),
    [sym_continue_as_identifier] = ACTIONS(4461),
    [sym_preproc_open] = ACTIONS(4461),
    [sym_end_keyword] = ACTIONS(4461),
  },
  [STATE(2350)] = {
    [sym_identifier] = ACTIONS(4471),
    [anon_sym_SEMI] = ACTIONS(4473),
    [anon_sym_DASH] = ACTIONS(4473),
    [aux_sym_boolean_token1] = ACTIONS(4471),
    [aux_sym_boolean_token2] = ACTIONS(4471),
    [sym_decimal] = ACTIONS(4471),
    [anon_sym_LPAREN] = ACTIONS(4473),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4471),
    [anon_sym_LBRACK] = ACTIONS(4473),
    [aux_sym_record_type_token1] = ACTIONS(4471),
    [aux_sym_basic_type_token21] = ACTIONS(4471),
    [aux_sym_basic_type_token22] = ACTIONS(4471),
    [aux_sym_basic_type_token48] = ACTIONS(4471),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4471),
    [anon_sym_POUNDif] = ACTIONS(4473),
    [anon_sym_POUNDIF] = ACTIONS(4473),
    [anon_sym_POUNDIf] = ACTIONS(4473),
    [anon_sym_not] = ACTIONS(4471),
    [anon_sym_NOT] = ACTIONS(4471),
    [anon_sym_Not] = ACTIONS(4471),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4471),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4471),
    [anon_sym_PLUS] = ACTIONS(4473),
    [sym_datetime_literal] = ACTIONS(4473),
    [sym_date_literal] = ACTIONS(4471),
    [sym_time_literal] = ACTIONS(4471),
    [sym_biginteger_literal] = ACTIONS(4473),
    [anon_sym_if] = ACTIONS(4471),
    [anon_sym_IF] = ACTIONS(4471),
    [anon_sym_If] = ACTIONS(4471),
    [anon_sym_else] = ACTIONS(4471),
    [anon_sym_ELSE] = ACTIONS(4471),
    [anon_sym_Else] = ACTIONS(4471),
    [anon_sym_case] = ACTIONS(4471),
    [anon_sym_CASE] = ACTIONS(4471),
    [anon_sym_Case] = ACTIONS(4471),
    [anon_sym_for] = ACTIONS(4471),
    [anon_sym_FOR] = ACTIONS(4471),
    [anon_sym_For] = ACTIONS(4471),
    [anon_sym_foreach] = ACTIONS(4471),
    [anon_sym_FOREACH] = ACTIONS(4471),
    [anon_sym_Foreach] = ACTIONS(4471),
    [anon_sym_while] = ACTIONS(4471),
    [anon_sym_WHILE] = ACTIONS(4471),
    [anon_sym_While] = ACTIONS(4471),
    [anon_sym_repeat] = ACTIONS(4471),
    [anon_sym_REPEAT] = ACTIONS(4471),
    [anon_sym_Repeat] = ACTIONS(4471),
    [anon_sym_exit] = ACTIONS(4471),
    [anon_sym_EXIT] = ACTIONS(4471),
    [anon_sym_Exit] = ACTIONS(4471),
    [anon_sym_continue] = ACTIONS(4471),
    [anon_sym_CONTINUE] = ACTIONS(4471),
    [anon_sym_Continue] = ACTIONS(4471),
    [anon_sym_break] = ACTIONS(4471),
    [anon_sym_BREAK] = ACTIONS(4471),
    [anon_sym_Break] = ACTIONS(4471),
    [anon_sym_with] = ACTIONS(4471),
    [anon_sym_WITH] = ACTIONS(4471),
    [anon_sym_With] = ACTIONS(4471),
    [sym_asserterror_keyword] = ACTIONS(4473),
    [sym_page_keyword] = ACTIONS(4471),
    [anon_sym_codeunit] = ACTIONS(4471),
    [anon_sym_CODEUNIT] = ACTIONS(4471),
    [anon_sym_Codeunit] = ACTIONS(4471),
    [anon_sym_CodeUnit] = ACTIONS(4471),
    [anon_sym_COdeunit] = ACTIONS(4471),
    [anon_sym_codeUnit] = ACTIONS(4471),
    [sym_report_keyword] = ACTIONS(4471),
    [sym_query_keyword] = ACTIONS(4471),
    [anon_sym_xmlport] = ACTIONS(4471),
    [anon_sym_XMLPORT] = ACTIONS(4471),
    [anon_sym_Xmlport] = ACTIONS(4471),
    [anon_sym_XMLport] = ACTIONS(4471),
    [anon_sym_XMLPort] = ACTIONS(4471),
    [anon_sym_XmlPort] = ACTIONS(4471),
    [anon_sym_enum] = ACTIONS(4471),
    [anon_sym_ENUM] = ACTIONS(4471),
    [anon_sym_Enum] = ACTIONS(4471),
    [anon_sym_eNUM] = ACTIONS(4471),
    [anon_sym_eNum] = ACTIONS(4471),
    [anon_sym_ENum] = ACTIONS(4471),
    [sym_quoted_identifier] = ACTIONS(4473),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4473),
    [sym_integer] = ACTIONS(4471),
    [sym_continue_as_identifier] = ACTIONS(4473),
    [sym_preproc_open] = ACTIONS(4473),
    [sym_end_keyword] = ACTIONS(4473),
  },
  [STATE(2351)] = {
    [sym_identifier] = ACTIONS(4475),
    [anon_sym_SEMI] = ACTIONS(4477),
    [anon_sym_DASH] = ACTIONS(4477),
    [aux_sym_boolean_token1] = ACTIONS(4475),
    [aux_sym_boolean_token2] = ACTIONS(4475),
    [sym_decimal] = ACTIONS(4475),
    [anon_sym_LPAREN] = ACTIONS(4477),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4475),
    [anon_sym_LBRACK] = ACTIONS(4477),
    [aux_sym_record_type_token1] = ACTIONS(4475),
    [aux_sym_basic_type_token21] = ACTIONS(4475),
    [aux_sym_basic_type_token22] = ACTIONS(4475),
    [aux_sym_basic_type_token48] = ACTIONS(4475),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4475),
    [anon_sym_POUNDif] = ACTIONS(4477),
    [anon_sym_POUNDIF] = ACTIONS(4477),
    [anon_sym_POUNDIf] = ACTIONS(4477),
    [anon_sym_not] = ACTIONS(4475),
    [anon_sym_NOT] = ACTIONS(4475),
    [anon_sym_Not] = ACTIONS(4475),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4475),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4475),
    [anon_sym_PLUS] = ACTIONS(4477),
    [sym_datetime_literal] = ACTIONS(4477),
    [sym_date_literal] = ACTIONS(4475),
    [sym_time_literal] = ACTIONS(4475),
    [sym_biginteger_literal] = ACTIONS(4477),
    [anon_sym_if] = ACTIONS(4475),
    [anon_sym_IF] = ACTIONS(4475),
    [anon_sym_If] = ACTIONS(4475),
    [anon_sym_else] = ACTIONS(4475),
    [anon_sym_ELSE] = ACTIONS(4475),
    [anon_sym_Else] = ACTIONS(4475),
    [anon_sym_case] = ACTIONS(4475),
    [anon_sym_CASE] = ACTIONS(4475),
    [anon_sym_Case] = ACTIONS(4475),
    [anon_sym_for] = ACTIONS(4475),
    [anon_sym_FOR] = ACTIONS(4475),
    [anon_sym_For] = ACTIONS(4475),
    [anon_sym_foreach] = ACTIONS(4475),
    [anon_sym_FOREACH] = ACTIONS(4475),
    [anon_sym_Foreach] = ACTIONS(4475),
    [anon_sym_while] = ACTIONS(4475),
    [anon_sym_WHILE] = ACTIONS(4475),
    [anon_sym_While] = ACTIONS(4475),
    [anon_sym_repeat] = ACTIONS(4475),
    [anon_sym_REPEAT] = ACTIONS(4475),
    [anon_sym_Repeat] = ACTIONS(4475),
    [anon_sym_exit] = ACTIONS(4475),
    [anon_sym_EXIT] = ACTIONS(4475),
    [anon_sym_Exit] = ACTIONS(4475),
    [anon_sym_continue] = ACTIONS(4475),
    [anon_sym_CONTINUE] = ACTIONS(4475),
    [anon_sym_Continue] = ACTIONS(4475),
    [anon_sym_break] = ACTIONS(4475),
    [anon_sym_BREAK] = ACTIONS(4475),
    [anon_sym_Break] = ACTIONS(4475),
    [anon_sym_with] = ACTIONS(4475),
    [anon_sym_WITH] = ACTIONS(4475),
    [anon_sym_With] = ACTIONS(4475),
    [sym_asserterror_keyword] = ACTIONS(4477),
    [sym_page_keyword] = ACTIONS(4475),
    [anon_sym_codeunit] = ACTIONS(4475),
    [anon_sym_CODEUNIT] = ACTIONS(4475),
    [anon_sym_Codeunit] = ACTIONS(4475),
    [anon_sym_CodeUnit] = ACTIONS(4475),
    [anon_sym_COdeunit] = ACTIONS(4475),
    [anon_sym_codeUnit] = ACTIONS(4475),
    [sym_report_keyword] = ACTIONS(4475),
    [sym_query_keyword] = ACTIONS(4475),
    [anon_sym_xmlport] = ACTIONS(4475),
    [anon_sym_XMLPORT] = ACTIONS(4475),
    [anon_sym_Xmlport] = ACTIONS(4475),
    [anon_sym_XMLport] = ACTIONS(4475),
    [anon_sym_XMLPort] = ACTIONS(4475),
    [anon_sym_XmlPort] = ACTIONS(4475),
    [anon_sym_enum] = ACTIONS(4475),
    [anon_sym_ENUM] = ACTIONS(4475),
    [anon_sym_Enum] = ACTIONS(4475),
    [anon_sym_eNUM] = ACTIONS(4475),
    [anon_sym_eNum] = ACTIONS(4475),
    [anon_sym_ENum] = ACTIONS(4475),
    [sym_quoted_identifier] = ACTIONS(4477),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4477),
    [sym_integer] = ACTIONS(4475),
    [sym_continue_as_identifier] = ACTIONS(4477),
    [sym_preproc_open] = ACTIONS(4477),
    [sym_end_keyword] = ACTIONS(4477),
  },
  [STATE(2352)] = {
    [sym_identifier] = ACTIONS(4479),
    [anon_sym_SEMI] = ACTIONS(4481),
    [anon_sym_DASH] = ACTIONS(4481),
    [aux_sym_boolean_token1] = ACTIONS(4479),
    [aux_sym_boolean_token2] = ACTIONS(4479),
    [sym_decimal] = ACTIONS(4479),
    [anon_sym_LPAREN] = ACTIONS(4481),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4479),
    [anon_sym_LBRACK] = ACTIONS(4481),
    [aux_sym_record_type_token1] = ACTIONS(4479),
    [aux_sym_basic_type_token21] = ACTIONS(4479),
    [aux_sym_basic_type_token22] = ACTIONS(4479),
    [aux_sym_basic_type_token48] = ACTIONS(4479),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4479),
    [anon_sym_POUNDif] = ACTIONS(4481),
    [anon_sym_POUNDIF] = ACTIONS(4481),
    [anon_sym_POUNDIf] = ACTIONS(4481),
    [anon_sym_not] = ACTIONS(4479),
    [anon_sym_NOT] = ACTIONS(4479),
    [anon_sym_Not] = ACTIONS(4479),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4479),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4479),
    [anon_sym_PLUS] = ACTIONS(4481),
    [sym_datetime_literal] = ACTIONS(4481),
    [sym_date_literal] = ACTIONS(4479),
    [sym_time_literal] = ACTIONS(4479),
    [sym_biginteger_literal] = ACTIONS(4481),
    [anon_sym_if] = ACTIONS(4479),
    [anon_sym_IF] = ACTIONS(4479),
    [anon_sym_If] = ACTIONS(4479),
    [anon_sym_else] = ACTIONS(4479),
    [anon_sym_ELSE] = ACTIONS(4479),
    [anon_sym_Else] = ACTIONS(4479),
    [anon_sym_case] = ACTIONS(4479),
    [anon_sym_CASE] = ACTIONS(4479),
    [anon_sym_Case] = ACTIONS(4479),
    [anon_sym_for] = ACTIONS(4479),
    [anon_sym_FOR] = ACTIONS(4479),
    [anon_sym_For] = ACTIONS(4479),
    [anon_sym_foreach] = ACTIONS(4479),
    [anon_sym_FOREACH] = ACTIONS(4479),
    [anon_sym_Foreach] = ACTIONS(4479),
    [anon_sym_while] = ACTIONS(4479),
    [anon_sym_WHILE] = ACTIONS(4479),
    [anon_sym_While] = ACTIONS(4479),
    [anon_sym_repeat] = ACTIONS(4479),
    [anon_sym_REPEAT] = ACTIONS(4479),
    [anon_sym_Repeat] = ACTIONS(4479),
    [anon_sym_exit] = ACTIONS(4479),
    [anon_sym_EXIT] = ACTIONS(4479),
    [anon_sym_Exit] = ACTIONS(4479),
    [anon_sym_continue] = ACTIONS(4479),
    [anon_sym_CONTINUE] = ACTIONS(4479),
    [anon_sym_Continue] = ACTIONS(4479),
    [anon_sym_break] = ACTIONS(4479),
    [anon_sym_BREAK] = ACTIONS(4479),
    [anon_sym_Break] = ACTIONS(4479),
    [anon_sym_with] = ACTIONS(4479),
    [anon_sym_WITH] = ACTIONS(4479),
    [anon_sym_With] = ACTIONS(4479),
    [sym_asserterror_keyword] = ACTIONS(4481),
    [sym_page_keyword] = ACTIONS(4479),
    [anon_sym_codeunit] = ACTIONS(4479),
    [anon_sym_CODEUNIT] = ACTIONS(4479),
    [anon_sym_Codeunit] = ACTIONS(4479),
    [anon_sym_CodeUnit] = ACTIONS(4479),
    [anon_sym_COdeunit] = ACTIONS(4479),
    [anon_sym_codeUnit] = ACTIONS(4479),
    [sym_report_keyword] = ACTIONS(4479),
    [sym_query_keyword] = ACTIONS(4479),
    [anon_sym_xmlport] = ACTIONS(4479),
    [anon_sym_XMLPORT] = ACTIONS(4479),
    [anon_sym_Xmlport] = ACTIONS(4479),
    [anon_sym_XMLport] = ACTIONS(4479),
    [anon_sym_XMLPort] = ACTIONS(4479),
    [anon_sym_XmlPort] = ACTIONS(4479),
    [anon_sym_enum] = ACTIONS(4479),
    [anon_sym_ENUM] = ACTIONS(4479),
    [anon_sym_Enum] = ACTIONS(4479),
    [anon_sym_eNUM] = ACTIONS(4479),
    [anon_sym_eNum] = ACTIONS(4479),
    [anon_sym_ENum] = ACTIONS(4479),
    [sym_quoted_identifier] = ACTIONS(4481),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4481),
    [sym_integer] = ACTIONS(4479),
    [sym_continue_as_identifier] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4481),
    [sym_end_keyword] = ACTIONS(4481),
  },
  [STATE(2353)] = {
    [sym_identifier] = ACTIONS(4483),
    [anon_sym_SEMI] = ACTIONS(4485),
    [anon_sym_DASH] = ACTIONS(4485),
    [aux_sym_boolean_token1] = ACTIONS(4483),
    [aux_sym_boolean_token2] = ACTIONS(4483),
    [sym_decimal] = ACTIONS(4483),
    [anon_sym_LPAREN] = ACTIONS(4485),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4483),
    [anon_sym_LBRACK] = ACTIONS(4485),
    [aux_sym_record_type_token1] = ACTIONS(4483),
    [aux_sym_basic_type_token21] = ACTIONS(4483),
    [aux_sym_basic_type_token22] = ACTIONS(4483),
    [aux_sym_basic_type_token48] = ACTIONS(4483),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4483),
    [anon_sym_POUNDif] = ACTIONS(4485),
    [anon_sym_POUNDIF] = ACTIONS(4485),
    [anon_sym_POUNDIf] = ACTIONS(4485),
    [anon_sym_not] = ACTIONS(4483),
    [anon_sym_NOT] = ACTIONS(4483),
    [anon_sym_Not] = ACTIONS(4483),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4483),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4483),
    [anon_sym_PLUS] = ACTIONS(4485),
    [sym_datetime_literal] = ACTIONS(4485),
    [sym_date_literal] = ACTIONS(4483),
    [sym_time_literal] = ACTIONS(4483),
    [sym_biginteger_literal] = ACTIONS(4485),
    [anon_sym_if] = ACTIONS(4483),
    [anon_sym_IF] = ACTIONS(4483),
    [anon_sym_If] = ACTIONS(4483),
    [anon_sym_else] = ACTIONS(4483),
    [anon_sym_ELSE] = ACTIONS(4483),
    [anon_sym_Else] = ACTIONS(4483),
    [anon_sym_case] = ACTIONS(4483),
    [anon_sym_CASE] = ACTIONS(4483),
    [anon_sym_Case] = ACTIONS(4483),
    [anon_sym_for] = ACTIONS(4483),
    [anon_sym_FOR] = ACTIONS(4483),
    [anon_sym_For] = ACTIONS(4483),
    [anon_sym_foreach] = ACTIONS(4483),
    [anon_sym_FOREACH] = ACTIONS(4483),
    [anon_sym_Foreach] = ACTIONS(4483),
    [anon_sym_while] = ACTIONS(4483),
    [anon_sym_WHILE] = ACTIONS(4483),
    [anon_sym_While] = ACTIONS(4483),
    [anon_sym_repeat] = ACTIONS(4483),
    [anon_sym_REPEAT] = ACTIONS(4483),
    [anon_sym_Repeat] = ACTIONS(4483),
    [anon_sym_exit] = ACTIONS(4483),
    [anon_sym_EXIT] = ACTIONS(4483),
    [anon_sym_Exit] = ACTIONS(4483),
    [anon_sym_continue] = ACTIONS(4483),
    [anon_sym_CONTINUE] = ACTIONS(4483),
    [anon_sym_Continue] = ACTIONS(4483),
    [anon_sym_break] = ACTIONS(4483),
    [anon_sym_BREAK] = ACTIONS(4483),
    [anon_sym_Break] = ACTIONS(4483),
    [anon_sym_with] = ACTIONS(4483),
    [anon_sym_WITH] = ACTIONS(4483),
    [anon_sym_With] = ACTIONS(4483),
    [sym_asserterror_keyword] = ACTIONS(4485),
    [sym_page_keyword] = ACTIONS(4483),
    [anon_sym_codeunit] = ACTIONS(4483),
    [anon_sym_CODEUNIT] = ACTIONS(4483),
    [anon_sym_Codeunit] = ACTIONS(4483),
    [anon_sym_CodeUnit] = ACTIONS(4483),
    [anon_sym_COdeunit] = ACTIONS(4483),
    [anon_sym_codeUnit] = ACTIONS(4483),
    [sym_report_keyword] = ACTIONS(4483),
    [sym_query_keyword] = ACTIONS(4483),
    [anon_sym_xmlport] = ACTIONS(4483),
    [anon_sym_XMLPORT] = ACTIONS(4483),
    [anon_sym_Xmlport] = ACTIONS(4483),
    [anon_sym_XMLport] = ACTIONS(4483),
    [anon_sym_XMLPort] = ACTIONS(4483),
    [anon_sym_XmlPort] = ACTIONS(4483),
    [anon_sym_enum] = ACTIONS(4483),
    [anon_sym_ENUM] = ACTIONS(4483),
    [anon_sym_Enum] = ACTIONS(4483),
    [anon_sym_eNUM] = ACTIONS(4483),
    [anon_sym_eNum] = ACTIONS(4483),
    [anon_sym_ENum] = ACTIONS(4483),
    [sym_quoted_identifier] = ACTIONS(4485),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4485),
    [sym_integer] = ACTIONS(4483),
    [sym_continue_as_identifier] = ACTIONS(4485),
    [sym_preproc_open] = ACTIONS(4485),
    [sym_end_keyword] = ACTIONS(4485),
  },
  [STATE(2354)] = {
    [sym_identifier] = ACTIONS(4487),
    [anon_sym_SEMI] = ACTIONS(4489),
    [anon_sym_DASH] = ACTIONS(4489),
    [aux_sym_boolean_token1] = ACTIONS(4487),
    [aux_sym_boolean_token2] = ACTIONS(4487),
    [sym_decimal] = ACTIONS(4487),
    [anon_sym_LPAREN] = ACTIONS(4489),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4487),
    [anon_sym_LBRACK] = ACTIONS(4489),
    [aux_sym_record_type_token1] = ACTIONS(4487),
    [aux_sym_basic_type_token21] = ACTIONS(4487),
    [aux_sym_basic_type_token22] = ACTIONS(4487),
    [aux_sym_basic_type_token48] = ACTIONS(4487),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4487),
    [anon_sym_POUNDif] = ACTIONS(4489),
    [anon_sym_POUNDIF] = ACTIONS(4489),
    [anon_sym_POUNDIf] = ACTIONS(4489),
    [anon_sym_not] = ACTIONS(4487),
    [anon_sym_NOT] = ACTIONS(4487),
    [anon_sym_Not] = ACTIONS(4487),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4487),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4487),
    [anon_sym_PLUS] = ACTIONS(4489),
    [sym_datetime_literal] = ACTIONS(4489),
    [sym_date_literal] = ACTIONS(4487),
    [sym_time_literal] = ACTIONS(4487),
    [sym_biginteger_literal] = ACTIONS(4489),
    [anon_sym_if] = ACTIONS(4487),
    [anon_sym_IF] = ACTIONS(4487),
    [anon_sym_If] = ACTIONS(4487),
    [anon_sym_else] = ACTIONS(4487),
    [anon_sym_ELSE] = ACTIONS(4487),
    [anon_sym_Else] = ACTIONS(4487),
    [anon_sym_case] = ACTIONS(4487),
    [anon_sym_CASE] = ACTIONS(4487),
    [anon_sym_Case] = ACTIONS(4487),
    [anon_sym_for] = ACTIONS(4487),
    [anon_sym_FOR] = ACTIONS(4487),
    [anon_sym_For] = ACTIONS(4487),
    [anon_sym_foreach] = ACTIONS(4487),
    [anon_sym_FOREACH] = ACTIONS(4487),
    [anon_sym_Foreach] = ACTIONS(4487),
    [anon_sym_while] = ACTIONS(4487),
    [anon_sym_WHILE] = ACTIONS(4487),
    [anon_sym_While] = ACTIONS(4487),
    [anon_sym_repeat] = ACTIONS(4487),
    [anon_sym_REPEAT] = ACTIONS(4487),
    [anon_sym_Repeat] = ACTIONS(4487),
    [anon_sym_exit] = ACTIONS(4487),
    [anon_sym_EXIT] = ACTIONS(4487),
    [anon_sym_Exit] = ACTIONS(4487),
    [anon_sym_continue] = ACTIONS(4487),
    [anon_sym_CONTINUE] = ACTIONS(4487),
    [anon_sym_Continue] = ACTIONS(4487),
    [anon_sym_break] = ACTIONS(4487),
    [anon_sym_BREAK] = ACTIONS(4487),
    [anon_sym_Break] = ACTIONS(4487),
    [anon_sym_with] = ACTIONS(4487),
    [anon_sym_WITH] = ACTIONS(4487),
    [anon_sym_With] = ACTIONS(4487),
    [sym_asserterror_keyword] = ACTIONS(4489),
    [sym_page_keyword] = ACTIONS(4487),
    [anon_sym_codeunit] = ACTIONS(4487),
    [anon_sym_CODEUNIT] = ACTIONS(4487),
    [anon_sym_Codeunit] = ACTIONS(4487),
    [anon_sym_CodeUnit] = ACTIONS(4487),
    [anon_sym_COdeunit] = ACTIONS(4487),
    [anon_sym_codeUnit] = ACTIONS(4487),
    [sym_report_keyword] = ACTIONS(4487),
    [sym_query_keyword] = ACTIONS(4487),
    [anon_sym_xmlport] = ACTIONS(4487),
    [anon_sym_XMLPORT] = ACTIONS(4487),
    [anon_sym_Xmlport] = ACTIONS(4487),
    [anon_sym_XMLport] = ACTIONS(4487),
    [anon_sym_XMLPort] = ACTIONS(4487),
    [anon_sym_XmlPort] = ACTIONS(4487),
    [anon_sym_enum] = ACTIONS(4487),
    [anon_sym_ENUM] = ACTIONS(4487),
    [anon_sym_Enum] = ACTIONS(4487),
    [anon_sym_eNUM] = ACTIONS(4487),
    [anon_sym_eNum] = ACTIONS(4487),
    [anon_sym_ENum] = ACTIONS(4487),
    [sym_quoted_identifier] = ACTIONS(4489),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4489),
    [sym_integer] = ACTIONS(4487),
    [sym_continue_as_identifier] = ACTIONS(4489),
    [sym_preproc_open] = ACTIONS(4489),
    [sym_end_keyword] = ACTIONS(4489),
  },
  [STATE(2355)] = {
    [sym_identifier] = ACTIONS(4626),
    [anon_sym_SEMI] = ACTIONS(4628),
    [anon_sym_DASH] = ACTIONS(4628),
    [aux_sym_boolean_token1] = ACTIONS(4626),
    [aux_sym_boolean_token2] = ACTIONS(4626),
    [sym_decimal] = ACTIONS(4626),
    [anon_sym_LPAREN] = ACTIONS(4628),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4626),
    [anon_sym_LBRACK] = ACTIONS(4628),
    [aux_sym_record_type_token1] = ACTIONS(4626),
    [aux_sym_basic_type_token21] = ACTIONS(4626),
    [aux_sym_basic_type_token22] = ACTIONS(4626),
    [aux_sym_basic_type_token48] = ACTIONS(4626),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4626),
    [anon_sym_POUNDif] = ACTIONS(4628),
    [anon_sym_POUNDIF] = ACTIONS(4628),
    [anon_sym_POUNDIf] = ACTIONS(4628),
    [anon_sym_not] = ACTIONS(4626),
    [anon_sym_NOT] = ACTIONS(4626),
    [anon_sym_Not] = ACTIONS(4626),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4626),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4626),
    [anon_sym_PLUS] = ACTIONS(4628),
    [sym_datetime_literal] = ACTIONS(4628),
    [sym_date_literal] = ACTIONS(4626),
    [sym_time_literal] = ACTIONS(4626),
    [sym_biginteger_literal] = ACTIONS(4628),
    [anon_sym_if] = ACTIONS(4626),
    [anon_sym_IF] = ACTIONS(4626),
    [anon_sym_If] = ACTIONS(4626),
    [anon_sym_else] = ACTIONS(4626),
    [anon_sym_ELSE] = ACTIONS(4626),
    [anon_sym_Else] = ACTIONS(4626),
    [anon_sym_case] = ACTIONS(4626),
    [anon_sym_CASE] = ACTIONS(4626),
    [anon_sym_Case] = ACTIONS(4626),
    [anon_sym_for] = ACTIONS(4626),
    [anon_sym_FOR] = ACTIONS(4626),
    [anon_sym_For] = ACTIONS(4626),
    [anon_sym_foreach] = ACTIONS(4626),
    [anon_sym_FOREACH] = ACTIONS(4626),
    [anon_sym_Foreach] = ACTIONS(4626),
    [anon_sym_while] = ACTIONS(4626),
    [anon_sym_WHILE] = ACTIONS(4626),
    [anon_sym_While] = ACTIONS(4626),
    [anon_sym_repeat] = ACTIONS(4626),
    [anon_sym_REPEAT] = ACTIONS(4626),
    [anon_sym_Repeat] = ACTIONS(4626),
    [anon_sym_exit] = ACTIONS(4626),
    [anon_sym_EXIT] = ACTIONS(4626),
    [anon_sym_Exit] = ACTIONS(4626),
    [anon_sym_continue] = ACTIONS(4626),
    [anon_sym_CONTINUE] = ACTIONS(4626),
    [anon_sym_Continue] = ACTIONS(4626),
    [anon_sym_break] = ACTIONS(4626),
    [anon_sym_BREAK] = ACTIONS(4626),
    [anon_sym_Break] = ACTIONS(4626),
    [anon_sym_with] = ACTIONS(4626),
    [anon_sym_WITH] = ACTIONS(4626),
    [anon_sym_With] = ACTIONS(4626),
    [sym_asserterror_keyword] = ACTIONS(4628),
    [sym_page_keyword] = ACTIONS(4626),
    [anon_sym_codeunit] = ACTIONS(4626),
    [anon_sym_CODEUNIT] = ACTIONS(4626),
    [anon_sym_Codeunit] = ACTIONS(4626),
    [anon_sym_CodeUnit] = ACTIONS(4626),
    [anon_sym_COdeunit] = ACTIONS(4626),
    [anon_sym_codeUnit] = ACTIONS(4626),
    [sym_report_keyword] = ACTIONS(4626),
    [sym_query_keyword] = ACTIONS(4626),
    [anon_sym_xmlport] = ACTIONS(4626),
    [anon_sym_XMLPORT] = ACTIONS(4626),
    [anon_sym_Xmlport] = ACTIONS(4626),
    [anon_sym_XMLport] = ACTIONS(4626),
    [anon_sym_XMLPort] = ACTIONS(4626),
    [anon_sym_XmlPort] = ACTIONS(4626),
    [anon_sym_enum] = ACTIONS(4626),
    [anon_sym_ENUM] = ACTIONS(4626),
    [anon_sym_Enum] = ACTIONS(4626),
    [anon_sym_eNUM] = ACTIONS(4626),
    [anon_sym_eNum] = ACTIONS(4626),
    [anon_sym_ENum] = ACTIONS(4626),
    [sym_quoted_identifier] = ACTIONS(4628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4628),
    [sym_integer] = ACTIONS(4626),
    [sym_continue_as_identifier] = ACTIONS(4628),
    [sym_preproc_open] = ACTIONS(4628),
    [sym_end_keyword] = ACTIONS(4628),
  },
  [STATE(2356)] = {
    [sym_identifier] = ACTIONS(4491),
    [anon_sym_SEMI] = ACTIONS(4493),
    [anon_sym_DASH] = ACTIONS(4493),
    [aux_sym_boolean_token1] = ACTIONS(4491),
    [aux_sym_boolean_token2] = ACTIONS(4491),
    [sym_decimal] = ACTIONS(4491),
    [anon_sym_LPAREN] = ACTIONS(4493),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4491),
    [anon_sym_LBRACK] = ACTIONS(4493),
    [aux_sym_record_type_token1] = ACTIONS(4491),
    [aux_sym_basic_type_token21] = ACTIONS(4491),
    [aux_sym_basic_type_token22] = ACTIONS(4491),
    [aux_sym_basic_type_token48] = ACTIONS(4491),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4491),
    [anon_sym_POUNDif] = ACTIONS(4493),
    [anon_sym_POUNDIF] = ACTIONS(4493),
    [anon_sym_POUNDIf] = ACTIONS(4493),
    [anon_sym_not] = ACTIONS(4491),
    [anon_sym_NOT] = ACTIONS(4491),
    [anon_sym_Not] = ACTIONS(4491),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4491),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4491),
    [anon_sym_PLUS] = ACTIONS(4493),
    [sym_datetime_literal] = ACTIONS(4493),
    [sym_date_literal] = ACTIONS(4491),
    [sym_time_literal] = ACTIONS(4491),
    [sym_biginteger_literal] = ACTIONS(4493),
    [anon_sym_if] = ACTIONS(4491),
    [anon_sym_IF] = ACTIONS(4491),
    [anon_sym_If] = ACTIONS(4491),
    [anon_sym_else] = ACTIONS(4491),
    [anon_sym_ELSE] = ACTIONS(4491),
    [anon_sym_Else] = ACTIONS(4491),
    [anon_sym_case] = ACTIONS(4491),
    [anon_sym_CASE] = ACTIONS(4491),
    [anon_sym_Case] = ACTIONS(4491),
    [anon_sym_for] = ACTIONS(4491),
    [anon_sym_FOR] = ACTIONS(4491),
    [anon_sym_For] = ACTIONS(4491),
    [anon_sym_foreach] = ACTIONS(4491),
    [anon_sym_FOREACH] = ACTIONS(4491),
    [anon_sym_Foreach] = ACTIONS(4491),
    [anon_sym_while] = ACTIONS(4491),
    [anon_sym_WHILE] = ACTIONS(4491),
    [anon_sym_While] = ACTIONS(4491),
    [anon_sym_repeat] = ACTIONS(4491),
    [anon_sym_REPEAT] = ACTIONS(4491),
    [anon_sym_Repeat] = ACTIONS(4491),
    [anon_sym_exit] = ACTIONS(4491),
    [anon_sym_EXIT] = ACTIONS(4491),
    [anon_sym_Exit] = ACTIONS(4491),
    [anon_sym_continue] = ACTIONS(4491),
    [anon_sym_CONTINUE] = ACTIONS(4491),
    [anon_sym_Continue] = ACTIONS(4491),
    [anon_sym_break] = ACTIONS(4491),
    [anon_sym_BREAK] = ACTIONS(4491),
    [anon_sym_Break] = ACTIONS(4491),
    [anon_sym_with] = ACTIONS(4491),
    [anon_sym_WITH] = ACTIONS(4491),
    [anon_sym_With] = ACTIONS(4491),
    [sym_asserterror_keyword] = ACTIONS(4493),
    [sym_page_keyword] = ACTIONS(4491),
    [anon_sym_codeunit] = ACTIONS(4491),
    [anon_sym_CODEUNIT] = ACTIONS(4491),
    [anon_sym_Codeunit] = ACTIONS(4491),
    [anon_sym_CodeUnit] = ACTIONS(4491),
    [anon_sym_COdeunit] = ACTIONS(4491),
    [anon_sym_codeUnit] = ACTIONS(4491),
    [sym_report_keyword] = ACTIONS(4491),
    [sym_query_keyword] = ACTIONS(4491),
    [anon_sym_xmlport] = ACTIONS(4491),
    [anon_sym_XMLPORT] = ACTIONS(4491),
    [anon_sym_Xmlport] = ACTIONS(4491),
    [anon_sym_XMLport] = ACTIONS(4491),
    [anon_sym_XMLPort] = ACTIONS(4491),
    [anon_sym_XmlPort] = ACTIONS(4491),
    [anon_sym_enum] = ACTIONS(4491),
    [anon_sym_ENUM] = ACTIONS(4491),
    [anon_sym_Enum] = ACTIONS(4491),
    [anon_sym_eNUM] = ACTIONS(4491),
    [anon_sym_eNum] = ACTIONS(4491),
    [anon_sym_ENum] = ACTIONS(4491),
    [sym_quoted_identifier] = ACTIONS(4493),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4493),
    [sym_integer] = ACTIONS(4491),
    [sym_continue_as_identifier] = ACTIONS(4493),
    [sym_preproc_open] = ACTIONS(4493),
    [sym_end_keyword] = ACTIONS(4493),
  },
  [STATE(2357)] = {
    [sym_identifier] = ACTIONS(4495),
    [anon_sym_SEMI] = ACTIONS(4497),
    [anon_sym_DASH] = ACTIONS(4497),
    [aux_sym_boolean_token1] = ACTIONS(4495),
    [aux_sym_boolean_token2] = ACTIONS(4495),
    [sym_decimal] = ACTIONS(4495),
    [anon_sym_LPAREN] = ACTIONS(4497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4495),
    [anon_sym_LBRACK] = ACTIONS(4497),
    [aux_sym_record_type_token1] = ACTIONS(4495),
    [aux_sym_basic_type_token21] = ACTIONS(4495),
    [aux_sym_basic_type_token22] = ACTIONS(4495),
    [aux_sym_basic_type_token48] = ACTIONS(4495),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4495),
    [anon_sym_POUNDif] = ACTIONS(4497),
    [anon_sym_POUNDIF] = ACTIONS(4497),
    [anon_sym_POUNDIf] = ACTIONS(4497),
    [anon_sym_not] = ACTIONS(4495),
    [anon_sym_NOT] = ACTIONS(4495),
    [anon_sym_Not] = ACTIONS(4495),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4495),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4495),
    [anon_sym_PLUS] = ACTIONS(4497),
    [sym_datetime_literal] = ACTIONS(4497),
    [sym_date_literal] = ACTIONS(4495),
    [sym_time_literal] = ACTIONS(4495),
    [sym_biginteger_literal] = ACTIONS(4497),
    [anon_sym_if] = ACTIONS(4495),
    [anon_sym_IF] = ACTIONS(4495),
    [anon_sym_If] = ACTIONS(4495),
    [anon_sym_else] = ACTIONS(4495),
    [anon_sym_ELSE] = ACTIONS(4495),
    [anon_sym_Else] = ACTIONS(4495),
    [anon_sym_case] = ACTIONS(4495),
    [anon_sym_CASE] = ACTIONS(4495),
    [anon_sym_Case] = ACTIONS(4495),
    [anon_sym_for] = ACTIONS(4495),
    [anon_sym_FOR] = ACTIONS(4495),
    [anon_sym_For] = ACTIONS(4495),
    [anon_sym_foreach] = ACTIONS(4495),
    [anon_sym_FOREACH] = ACTIONS(4495),
    [anon_sym_Foreach] = ACTIONS(4495),
    [anon_sym_while] = ACTIONS(4495),
    [anon_sym_WHILE] = ACTIONS(4495),
    [anon_sym_While] = ACTIONS(4495),
    [anon_sym_repeat] = ACTIONS(4495),
    [anon_sym_REPEAT] = ACTIONS(4495),
    [anon_sym_Repeat] = ACTIONS(4495),
    [anon_sym_exit] = ACTIONS(4495),
    [anon_sym_EXIT] = ACTIONS(4495),
    [anon_sym_Exit] = ACTIONS(4495),
    [anon_sym_continue] = ACTIONS(4495),
    [anon_sym_CONTINUE] = ACTIONS(4495),
    [anon_sym_Continue] = ACTIONS(4495),
    [anon_sym_break] = ACTIONS(4495),
    [anon_sym_BREAK] = ACTIONS(4495),
    [anon_sym_Break] = ACTIONS(4495),
    [anon_sym_with] = ACTIONS(4495),
    [anon_sym_WITH] = ACTIONS(4495),
    [anon_sym_With] = ACTIONS(4495),
    [sym_asserterror_keyword] = ACTIONS(4497),
    [sym_page_keyword] = ACTIONS(4495),
    [anon_sym_codeunit] = ACTIONS(4495),
    [anon_sym_CODEUNIT] = ACTIONS(4495),
    [anon_sym_Codeunit] = ACTIONS(4495),
    [anon_sym_CodeUnit] = ACTIONS(4495),
    [anon_sym_COdeunit] = ACTIONS(4495),
    [anon_sym_codeUnit] = ACTIONS(4495),
    [sym_report_keyword] = ACTIONS(4495),
    [sym_query_keyword] = ACTIONS(4495),
    [anon_sym_xmlport] = ACTIONS(4495),
    [anon_sym_XMLPORT] = ACTIONS(4495),
    [anon_sym_Xmlport] = ACTIONS(4495),
    [anon_sym_XMLport] = ACTIONS(4495),
    [anon_sym_XMLPort] = ACTIONS(4495),
    [anon_sym_XmlPort] = ACTIONS(4495),
    [anon_sym_enum] = ACTIONS(4495),
    [anon_sym_ENUM] = ACTIONS(4495),
    [anon_sym_Enum] = ACTIONS(4495),
    [anon_sym_eNUM] = ACTIONS(4495),
    [anon_sym_eNum] = ACTIONS(4495),
    [anon_sym_ENum] = ACTIONS(4495),
    [sym_quoted_identifier] = ACTIONS(4497),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4497),
    [sym_integer] = ACTIONS(4495),
    [sym_continue_as_identifier] = ACTIONS(4497),
    [sym_preproc_open] = ACTIONS(4497),
    [sym_end_keyword] = ACTIONS(4497),
  },
  [STATE(2358)] = {
    [sym_identifier] = ACTIONS(4736),
    [anon_sym_SEMI] = ACTIONS(4738),
    [anon_sym_DASH] = ACTIONS(4738),
    [aux_sym_boolean_token1] = ACTIONS(4736),
    [aux_sym_boolean_token2] = ACTIONS(4736),
    [sym_decimal] = ACTIONS(4736),
    [anon_sym_LPAREN] = ACTIONS(4738),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4736),
    [anon_sym_LBRACK] = ACTIONS(4738),
    [aux_sym_record_type_token1] = ACTIONS(4736),
    [aux_sym_basic_type_token21] = ACTIONS(4736),
    [aux_sym_basic_type_token22] = ACTIONS(4736),
    [aux_sym_basic_type_token48] = ACTIONS(4736),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4736),
    [anon_sym_POUNDif] = ACTIONS(4738),
    [anon_sym_POUNDIF] = ACTIONS(4738),
    [anon_sym_POUNDIf] = ACTIONS(4738),
    [anon_sym_not] = ACTIONS(4736),
    [anon_sym_NOT] = ACTIONS(4736),
    [anon_sym_Not] = ACTIONS(4736),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4736),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4736),
    [anon_sym_PLUS] = ACTIONS(4738),
    [sym_datetime_literal] = ACTIONS(4738),
    [sym_date_literal] = ACTIONS(4736),
    [sym_time_literal] = ACTIONS(4736),
    [sym_biginteger_literal] = ACTIONS(4738),
    [anon_sym_if] = ACTIONS(4736),
    [anon_sym_IF] = ACTIONS(4736),
    [anon_sym_If] = ACTIONS(4736),
    [anon_sym_else] = ACTIONS(4736),
    [anon_sym_ELSE] = ACTIONS(4736),
    [anon_sym_Else] = ACTIONS(4736),
    [anon_sym_case] = ACTIONS(4736),
    [anon_sym_CASE] = ACTIONS(4736),
    [anon_sym_Case] = ACTIONS(4736),
    [anon_sym_for] = ACTIONS(4736),
    [anon_sym_FOR] = ACTIONS(4736),
    [anon_sym_For] = ACTIONS(4736),
    [anon_sym_foreach] = ACTIONS(4736),
    [anon_sym_FOREACH] = ACTIONS(4736),
    [anon_sym_Foreach] = ACTIONS(4736),
    [anon_sym_while] = ACTIONS(4736),
    [anon_sym_WHILE] = ACTIONS(4736),
    [anon_sym_While] = ACTIONS(4736),
    [anon_sym_repeat] = ACTIONS(4736),
    [anon_sym_REPEAT] = ACTIONS(4736),
    [anon_sym_Repeat] = ACTIONS(4736),
    [anon_sym_exit] = ACTIONS(4736),
    [anon_sym_EXIT] = ACTIONS(4736),
    [anon_sym_Exit] = ACTIONS(4736),
    [anon_sym_continue] = ACTIONS(4736),
    [anon_sym_CONTINUE] = ACTIONS(4736),
    [anon_sym_Continue] = ACTIONS(4736),
    [anon_sym_break] = ACTIONS(4736),
    [anon_sym_BREAK] = ACTIONS(4736),
    [anon_sym_Break] = ACTIONS(4736),
    [anon_sym_with] = ACTIONS(4736),
    [anon_sym_WITH] = ACTIONS(4736),
    [anon_sym_With] = ACTIONS(4736),
    [sym_asserterror_keyword] = ACTIONS(4738),
    [sym_page_keyword] = ACTIONS(4736),
    [anon_sym_codeunit] = ACTIONS(4736),
    [anon_sym_CODEUNIT] = ACTIONS(4736),
    [anon_sym_Codeunit] = ACTIONS(4736),
    [anon_sym_CodeUnit] = ACTIONS(4736),
    [anon_sym_COdeunit] = ACTIONS(4736),
    [anon_sym_codeUnit] = ACTIONS(4736),
    [sym_report_keyword] = ACTIONS(4736),
    [sym_query_keyword] = ACTIONS(4736),
    [anon_sym_xmlport] = ACTIONS(4736),
    [anon_sym_XMLPORT] = ACTIONS(4736),
    [anon_sym_Xmlport] = ACTIONS(4736),
    [anon_sym_XMLport] = ACTIONS(4736),
    [anon_sym_XMLPort] = ACTIONS(4736),
    [anon_sym_XmlPort] = ACTIONS(4736),
    [anon_sym_enum] = ACTIONS(4736),
    [anon_sym_ENUM] = ACTIONS(4736),
    [anon_sym_Enum] = ACTIONS(4736),
    [anon_sym_eNUM] = ACTIONS(4736),
    [anon_sym_eNum] = ACTIONS(4736),
    [anon_sym_ENum] = ACTIONS(4736),
    [sym_quoted_identifier] = ACTIONS(4738),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4738),
    [sym_integer] = ACTIONS(4736),
    [sym_continue_as_identifier] = ACTIONS(4738),
    [sym_preproc_open] = ACTIONS(4738),
    [sym_end_keyword] = ACTIONS(4738),
  },
  [STATE(2359)] = {
    [sym_identifier] = ACTIONS(4740),
    [anon_sym_SEMI] = ACTIONS(4742),
    [anon_sym_DASH] = ACTIONS(4742),
    [aux_sym_boolean_token1] = ACTIONS(4740),
    [aux_sym_boolean_token2] = ACTIONS(4740),
    [sym_decimal] = ACTIONS(4740),
    [anon_sym_LPAREN] = ACTIONS(4742),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4740),
    [anon_sym_LBRACK] = ACTIONS(4742),
    [aux_sym_record_type_token1] = ACTIONS(4740),
    [aux_sym_basic_type_token21] = ACTIONS(4740),
    [aux_sym_basic_type_token22] = ACTIONS(4740),
    [aux_sym_basic_type_token48] = ACTIONS(4740),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4740),
    [anon_sym_POUNDif] = ACTIONS(4742),
    [anon_sym_POUNDIF] = ACTIONS(4742),
    [anon_sym_POUNDIf] = ACTIONS(4742),
    [anon_sym_not] = ACTIONS(4740),
    [anon_sym_NOT] = ACTIONS(4740),
    [anon_sym_Not] = ACTIONS(4740),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4740),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4740),
    [anon_sym_PLUS] = ACTIONS(4742),
    [sym_datetime_literal] = ACTIONS(4742),
    [sym_date_literal] = ACTIONS(4740),
    [sym_time_literal] = ACTIONS(4740),
    [sym_biginteger_literal] = ACTIONS(4742),
    [anon_sym_if] = ACTIONS(4740),
    [anon_sym_IF] = ACTIONS(4740),
    [anon_sym_If] = ACTIONS(4740),
    [anon_sym_else] = ACTIONS(4740),
    [anon_sym_ELSE] = ACTIONS(4740),
    [anon_sym_Else] = ACTIONS(4740),
    [anon_sym_case] = ACTIONS(4740),
    [anon_sym_CASE] = ACTIONS(4740),
    [anon_sym_Case] = ACTIONS(4740),
    [anon_sym_for] = ACTIONS(4740),
    [anon_sym_FOR] = ACTIONS(4740),
    [anon_sym_For] = ACTIONS(4740),
    [anon_sym_foreach] = ACTIONS(4740),
    [anon_sym_FOREACH] = ACTIONS(4740),
    [anon_sym_Foreach] = ACTIONS(4740),
    [anon_sym_while] = ACTIONS(4740),
    [anon_sym_WHILE] = ACTIONS(4740),
    [anon_sym_While] = ACTIONS(4740),
    [anon_sym_repeat] = ACTIONS(4740),
    [anon_sym_REPEAT] = ACTIONS(4740),
    [anon_sym_Repeat] = ACTIONS(4740),
    [anon_sym_exit] = ACTIONS(4740),
    [anon_sym_EXIT] = ACTIONS(4740),
    [anon_sym_Exit] = ACTIONS(4740),
    [anon_sym_continue] = ACTIONS(4740),
    [anon_sym_CONTINUE] = ACTIONS(4740),
    [anon_sym_Continue] = ACTIONS(4740),
    [anon_sym_break] = ACTIONS(4740),
    [anon_sym_BREAK] = ACTIONS(4740),
    [anon_sym_Break] = ACTIONS(4740),
    [anon_sym_with] = ACTIONS(4740),
    [anon_sym_WITH] = ACTIONS(4740),
    [anon_sym_With] = ACTIONS(4740),
    [sym_asserterror_keyword] = ACTIONS(4742),
    [sym_page_keyword] = ACTIONS(4740),
    [anon_sym_codeunit] = ACTIONS(4740),
    [anon_sym_CODEUNIT] = ACTIONS(4740),
    [anon_sym_Codeunit] = ACTIONS(4740),
    [anon_sym_CodeUnit] = ACTIONS(4740),
    [anon_sym_COdeunit] = ACTIONS(4740),
    [anon_sym_codeUnit] = ACTIONS(4740),
    [sym_report_keyword] = ACTIONS(4740),
    [sym_query_keyword] = ACTIONS(4740),
    [anon_sym_xmlport] = ACTIONS(4740),
    [anon_sym_XMLPORT] = ACTIONS(4740),
    [anon_sym_Xmlport] = ACTIONS(4740),
    [anon_sym_XMLport] = ACTIONS(4740),
    [anon_sym_XMLPort] = ACTIONS(4740),
    [anon_sym_XmlPort] = ACTIONS(4740),
    [anon_sym_enum] = ACTIONS(4740),
    [anon_sym_ENUM] = ACTIONS(4740),
    [anon_sym_Enum] = ACTIONS(4740),
    [anon_sym_eNUM] = ACTIONS(4740),
    [anon_sym_eNum] = ACTIONS(4740),
    [anon_sym_ENum] = ACTIONS(4740),
    [sym_quoted_identifier] = ACTIONS(4742),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4742),
    [sym_integer] = ACTIONS(4740),
    [sym_continue_as_identifier] = ACTIONS(4742),
    [sym_preproc_open] = ACTIONS(4742),
    [sym_end_keyword] = ACTIONS(4742),
  },
  [STATE(2360)] = {
    [sym_identifier] = ACTIONS(4744),
    [anon_sym_SEMI] = ACTIONS(4746),
    [anon_sym_DASH] = ACTIONS(4746),
    [aux_sym_boolean_token1] = ACTIONS(4744),
    [aux_sym_boolean_token2] = ACTIONS(4744),
    [sym_decimal] = ACTIONS(4744),
    [anon_sym_LPAREN] = ACTIONS(4746),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4744),
    [anon_sym_LBRACK] = ACTIONS(4746),
    [aux_sym_record_type_token1] = ACTIONS(4744),
    [aux_sym_basic_type_token21] = ACTIONS(4744),
    [aux_sym_basic_type_token22] = ACTIONS(4744),
    [aux_sym_basic_type_token48] = ACTIONS(4744),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4744),
    [anon_sym_POUNDif] = ACTIONS(4746),
    [anon_sym_POUNDIF] = ACTIONS(4746),
    [anon_sym_POUNDIf] = ACTIONS(4746),
    [anon_sym_not] = ACTIONS(4744),
    [anon_sym_NOT] = ACTIONS(4744),
    [anon_sym_Not] = ACTIONS(4744),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4744),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4744),
    [anon_sym_PLUS] = ACTIONS(4746),
    [sym_datetime_literal] = ACTIONS(4746),
    [sym_date_literal] = ACTIONS(4744),
    [sym_time_literal] = ACTIONS(4744),
    [sym_biginteger_literal] = ACTIONS(4746),
    [anon_sym_if] = ACTIONS(4744),
    [anon_sym_IF] = ACTIONS(4744),
    [anon_sym_If] = ACTIONS(4744),
    [anon_sym_else] = ACTIONS(4744),
    [anon_sym_ELSE] = ACTIONS(4744),
    [anon_sym_Else] = ACTIONS(4744),
    [anon_sym_case] = ACTIONS(4744),
    [anon_sym_CASE] = ACTIONS(4744),
    [anon_sym_Case] = ACTIONS(4744),
    [anon_sym_for] = ACTIONS(4744),
    [anon_sym_FOR] = ACTIONS(4744),
    [anon_sym_For] = ACTIONS(4744),
    [anon_sym_foreach] = ACTIONS(4744),
    [anon_sym_FOREACH] = ACTIONS(4744),
    [anon_sym_Foreach] = ACTIONS(4744),
    [anon_sym_while] = ACTIONS(4744),
    [anon_sym_WHILE] = ACTIONS(4744),
    [anon_sym_While] = ACTIONS(4744),
    [anon_sym_repeat] = ACTIONS(4744),
    [anon_sym_REPEAT] = ACTIONS(4744),
    [anon_sym_Repeat] = ACTIONS(4744),
    [anon_sym_exit] = ACTIONS(4744),
    [anon_sym_EXIT] = ACTIONS(4744),
    [anon_sym_Exit] = ACTIONS(4744),
    [anon_sym_continue] = ACTIONS(4744),
    [anon_sym_CONTINUE] = ACTIONS(4744),
    [anon_sym_Continue] = ACTIONS(4744),
    [anon_sym_break] = ACTIONS(4744),
    [anon_sym_BREAK] = ACTIONS(4744),
    [anon_sym_Break] = ACTIONS(4744),
    [anon_sym_with] = ACTIONS(4744),
    [anon_sym_WITH] = ACTIONS(4744),
    [anon_sym_With] = ACTIONS(4744),
    [sym_asserterror_keyword] = ACTIONS(4746),
    [sym_page_keyword] = ACTIONS(4744),
    [anon_sym_codeunit] = ACTIONS(4744),
    [anon_sym_CODEUNIT] = ACTIONS(4744),
    [anon_sym_Codeunit] = ACTIONS(4744),
    [anon_sym_CodeUnit] = ACTIONS(4744),
    [anon_sym_COdeunit] = ACTIONS(4744),
    [anon_sym_codeUnit] = ACTIONS(4744),
    [sym_report_keyword] = ACTIONS(4744),
    [sym_query_keyword] = ACTIONS(4744),
    [anon_sym_xmlport] = ACTIONS(4744),
    [anon_sym_XMLPORT] = ACTIONS(4744),
    [anon_sym_Xmlport] = ACTIONS(4744),
    [anon_sym_XMLport] = ACTIONS(4744),
    [anon_sym_XMLPort] = ACTIONS(4744),
    [anon_sym_XmlPort] = ACTIONS(4744),
    [anon_sym_enum] = ACTIONS(4744),
    [anon_sym_ENUM] = ACTIONS(4744),
    [anon_sym_Enum] = ACTIONS(4744),
    [anon_sym_eNUM] = ACTIONS(4744),
    [anon_sym_eNum] = ACTIONS(4744),
    [anon_sym_ENum] = ACTIONS(4744),
    [sym_quoted_identifier] = ACTIONS(4746),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4746),
    [sym_integer] = ACTIONS(4744),
    [sym_continue_as_identifier] = ACTIONS(4746),
    [sym_preproc_open] = ACTIONS(4746),
    [sym_end_keyword] = ACTIONS(4746),
  },
  [STATE(2361)] = {
    [sym_identifier] = ACTIONS(4499),
    [anon_sym_SEMI] = ACTIONS(4501),
    [anon_sym_DASH] = ACTIONS(4501),
    [aux_sym_boolean_token1] = ACTIONS(4499),
    [aux_sym_boolean_token2] = ACTIONS(4499),
    [sym_decimal] = ACTIONS(4499),
    [anon_sym_LPAREN] = ACTIONS(4501),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4499),
    [anon_sym_LBRACK] = ACTIONS(4501),
    [aux_sym_record_type_token1] = ACTIONS(4499),
    [aux_sym_basic_type_token21] = ACTIONS(4499),
    [aux_sym_basic_type_token22] = ACTIONS(4499),
    [aux_sym_basic_type_token48] = ACTIONS(4499),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4499),
    [anon_sym_POUNDif] = ACTIONS(4501),
    [anon_sym_POUNDIF] = ACTIONS(4501),
    [anon_sym_POUNDIf] = ACTIONS(4501),
    [anon_sym_not] = ACTIONS(4499),
    [anon_sym_NOT] = ACTIONS(4499),
    [anon_sym_Not] = ACTIONS(4499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4499),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4499),
    [anon_sym_PLUS] = ACTIONS(4501),
    [sym_datetime_literal] = ACTIONS(4501),
    [sym_date_literal] = ACTIONS(4499),
    [sym_time_literal] = ACTIONS(4499),
    [sym_biginteger_literal] = ACTIONS(4501),
    [anon_sym_if] = ACTIONS(4499),
    [anon_sym_IF] = ACTIONS(4499),
    [anon_sym_If] = ACTIONS(4499),
    [anon_sym_else] = ACTIONS(4499),
    [anon_sym_ELSE] = ACTIONS(4499),
    [anon_sym_Else] = ACTIONS(4499),
    [anon_sym_case] = ACTIONS(4499),
    [anon_sym_CASE] = ACTIONS(4499),
    [anon_sym_Case] = ACTIONS(4499),
    [anon_sym_for] = ACTIONS(4499),
    [anon_sym_FOR] = ACTIONS(4499),
    [anon_sym_For] = ACTIONS(4499),
    [anon_sym_foreach] = ACTIONS(4499),
    [anon_sym_FOREACH] = ACTIONS(4499),
    [anon_sym_Foreach] = ACTIONS(4499),
    [anon_sym_while] = ACTIONS(4499),
    [anon_sym_WHILE] = ACTIONS(4499),
    [anon_sym_While] = ACTIONS(4499),
    [anon_sym_repeat] = ACTIONS(4499),
    [anon_sym_REPEAT] = ACTIONS(4499),
    [anon_sym_Repeat] = ACTIONS(4499),
    [anon_sym_exit] = ACTIONS(4499),
    [anon_sym_EXIT] = ACTIONS(4499),
    [anon_sym_Exit] = ACTIONS(4499),
    [anon_sym_continue] = ACTIONS(4499),
    [anon_sym_CONTINUE] = ACTIONS(4499),
    [anon_sym_Continue] = ACTIONS(4499),
    [anon_sym_break] = ACTIONS(4499),
    [anon_sym_BREAK] = ACTIONS(4499),
    [anon_sym_Break] = ACTIONS(4499),
    [anon_sym_with] = ACTIONS(4499),
    [anon_sym_WITH] = ACTIONS(4499),
    [anon_sym_With] = ACTIONS(4499),
    [sym_asserterror_keyword] = ACTIONS(4501),
    [sym_page_keyword] = ACTIONS(4499),
    [anon_sym_codeunit] = ACTIONS(4499),
    [anon_sym_CODEUNIT] = ACTIONS(4499),
    [anon_sym_Codeunit] = ACTIONS(4499),
    [anon_sym_CodeUnit] = ACTIONS(4499),
    [anon_sym_COdeunit] = ACTIONS(4499),
    [anon_sym_codeUnit] = ACTIONS(4499),
    [sym_report_keyword] = ACTIONS(4499),
    [sym_query_keyword] = ACTIONS(4499),
    [anon_sym_xmlport] = ACTIONS(4499),
    [anon_sym_XMLPORT] = ACTIONS(4499),
    [anon_sym_Xmlport] = ACTIONS(4499),
    [anon_sym_XMLport] = ACTIONS(4499),
    [anon_sym_XMLPort] = ACTIONS(4499),
    [anon_sym_XmlPort] = ACTIONS(4499),
    [anon_sym_enum] = ACTIONS(4499),
    [anon_sym_ENUM] = ACTIONS(4499),
    [anon_sym_Enum] = ACTIONS(4499),
    [anon_sym_eNUM] = ACTIONS(4499),
    [anon_sym_eNum] = ACTIONS(4499),
    [anon_sym_ENum] = ACTIONS(4499),
    [sym_quoted_identifier] = ACTIONS(4501),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4501),
    [sym_integer] = ACTIONS(4499),
    [sym_continue_as_identifier] = ACTIONS(4501),
    [sym_preproc_open] = ACTIONS(4501),
    [sym_end_keyword] = ACTIONS(4501),
  },
  [STATE(2362)] = {
    [sym_identifier] = ACTIONS(4626),
    [anon_sym_SEMI] = ACTIONS(4628),
    [anon_sym_DASH] = ACTIONS(4628),
    [aux_sym_boolean_token1] = ACTIONS(4626),
    [aux_sym_boolean_token2] = ACTIONS(4626),
    [sym_decimal] = ACTIONS(4626),
    [anon_sym_LPAREN] = ACTIONS(4628),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4626),
    [anon_sym_LBRACK] = ACTIONS(4628),
    [aux_sym_record_type_token1] = ACTIONS(4626),
    [aux_sym_basic_type_token21] = ACTIONS(4626),
    [aux_sym_basic_type_token22] = ACTIONS(4626),
    [aux_sym_basic_type_token48] = ACTIONS(4626),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4626),
    [anon_sym_POUNDif] = ACTIONS(4628),
    [anon_sym_POUNDIF] = ACTIONS(4628),
    [anon_sym_POUNDIf] = ACTIONS(4628),
    [anon_sym_not] = ACTIONS(4626),
    [anon_sym_NOT] = ACTIONS(4626),
    [anon_sym_Not] = ACTIONS(4626),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4626),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4626),
    [anon_sym_PLUS] = ACTIONS(4628),
    [sym_datetime_literal] = ACTIONS(4628),
    [sym_date_literal] = ACTIONS(4626),
    [sym_time_literal] = ACTIONS(4626),
    [sym_biginteger_literal] = ACTIONS(4628),
    [anon_sym_if] = ACTIONS(4626),
    [anon_sym_IF] = ACTIONS(4626),
    [anon_sym_If] = ACTIONS(4626),
    [anon_sym_else] = ACTIONS(4626),
    [anon_sym_ELSE] = ACTIONS(4626),
    [anon_sym_Else] = ACTIONS(4626),
    [anon_sym_case] = ACTIONS(4626),
    [anon_sym_CASE] = ACTIONS(4626),
    [anon_sym_Case] = ACTIONS(4626),
    [anon_sym_for] = ACTIONS(4626),
    [anon_sym_FOR] = ACTIONS(4626),
    [anon_sym_For] = ACTIONS(4626),
    [anon_sym_foreach] = ACTIONS(4626),
    [anon_sym_FOREACH] = ACTIONS(4626),
    [anon_sym_Foreach] = ACTIONS(4626),
    [anon_sym_while] = ACTIONS(4626),
    [anon_sym_WHILE] = ACTIONS(4626),
    [anon_sym_While] = ACTIONS(4626),
    [anon_sym_repeat] = ACTIONS(4626),
    [anon_sym_REPEAT] = ACTIONS(4626),
    [anon_sym_Repeat] = ACTIONS(4626),
    [anon_sym_exit] = ACTIONS(4626),
    [anon_sym_EXIT] = ACTIONS(4626),
    [anon_sym_Exit] = ACTIONS(4626),
    [anon_sym_continue] = ACTIONS(4626),
    [anon_sym_CONTINUE] = ACTIONS(4626),
    [anon_sym_Continue] = ACTIONS(4626),
    [anon_sym_break] = ACTIONS(4626),
    [anon_sym_BREAK] = ACTIONS(4626),
    [anon_sym_Break] = ACTIONS(4626),
    [anon_sym_with] = ACTIONS(4626),
    [anon_sym_WITH] = ACTIONS(4626),
    [anon_sym_With] = ACTIONS(4626),
    [sym_asserterror_keyword] = ACTIONS(4628),
    [sym_page_keyword] = ACTIONS(4626),
    [anon_sym_codeunit] = ACTIONS(4626),
    [anon_sym_CODEUNIT] = ACTIONS(4626),
    [anon_sym_Codeunit] = ACTIONS(4626),
    [anon_sym_CodeUnit] = ACTIONS(4626),
    [anon_sym_COdeunit] = ACTIONS(4626),
    [anon_sym_codeUnit] = ACTIONS(4626),
    [sym_report_keyword] = ACTIONS(4626),
    [sym_query_keyword] = ACTIONS(4626),
    [anon_sym_xmlport] = ACTIONS(4626),
    [anon_sym_XMLPORT] = ACTIONS(4626),
    [anon_sym_Xmlport] = ACTIONS(4626),
    [anon_sym_XMLport] = ACTIONS(4626),
    [anon_sym_XMLPort] = ACTIONS(4626),
    [anon_sym_XmlPort] = ACTIONS(4626),
    [anon_sym_enum] = ACTIONS(4626),
    [anon_sym_ENUM] = ACTIONS(4626),
    [anon_sym_Enum] = ACTIONS(4626),
    [anon_sym_eNUM] = ACTIONS(4626),
    [anon_sym_eNum] = ACTIONS(4626),
    [anon_sym_ENum] = ACTIONS(4626),
    [sym_quoted_identifier] = ACTIONS(4628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4628),
    [sym_integer] = ACTIONS(4626),
    [sym_continue_as_identifier] = ACTIONS(4628),
    [sym_preproc_open] = ACTIONS(4628),
    [sym_end_keyword] = ACTIONS(4628),
  },
  [STATE(2363)] = {
    [sym_identifier] = ACTIONS(4503),
    [anon_sym_SEMI] = ACTIONS(4505),
    [anon_sym_DASH] = ACTIONS(4505),
    [aux_sym_boolean_token1] = ACTIONS(4503),
    [aux_sym_boolean_token2] = ACTIONS(4503),
    [sym_decimal] = ACTIONS(4503),
    [anon_sym_LPAREN] = ACTIONS(4505),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4503),
    [anon_sym_LBRACK] = ACTIONS(4505),
    [aux_sym_record_type_token1] = ACTIONS(4503),
    [aux_sym_basic_type_token21] = ACTIONS(4503),
    [aux_sym_basic_type_token22] = ACTIONS(4503),
    [aux_sym_basic_type_token48] = ACTIONS(4503),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4503),
    [anon_sym_POUNDif] = ACTIONS(4505),
    [anon_sym_POUNDIF] = ACTIONS(4505),
    [anon_sym_POUNDIf] = ACTIONS(4505),
    [anon_sym_not] = ACTIONS(4503),
    [anon_sym_NOT] = ACTIONS(4503),
    [anon_sym_Not] = ACTIONS(4503),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4503),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4503),
    [anon_sym_PLUS] = ACTIONS(4505),
    [sym_datetime_literal] = ACTIONS(4505),
    [sym_date_literal] = ACTIONS(4503),
    [sym_time_literal] = ACTIONS(4503),
    [sym_biginteger_literal] = ACTIONS(4505),
    [anon_sym_if] = ACTIONS(4503),
    [anon_sym_IF] = ACTIONS(4503),
    [anon_sym_If] = ACTIONS(4503),
    [anon_sym_else] = ACTIONS(4503),
    [anon_sym_ELSE] = ACTIONS(4503),
    [anon_sym_Else] = ACTIONS(4503),
    [anon_sym_case] = ACTIONS(4503),
    [anon_sym_CASE] = ACTIONS(4503),
    [anon_sym_Case] = ACTIONS(4503),
    [anon_sym_for] = ACTIONS(4503),
    [anon_sym_FOR] = ACTIONS(4503),
    [anon_sym_For] = ACTIONS(4503),
    [anon_sym_foreach] = ACTIONS(4503),
    [anon_sym_FOREACH] = ACTIONS(4503),
    [anon_sym_Foreach] = ACTIONS(4503),
    [anon_sym_while] = ACTIONS(4503),
    [anon_sym_WHILE] = ACTIONS(4503),
    [anon_sym_While] = ACTIONS(4503),
    [anon_sym_repeat] = ACTIONS(4503),
    [anon_sym_REPEAT] = ACTIONS(4503),
    [anon_sym_Repeat] = ACTIONS(4503),
    [anon_sym_exit] = ACTIONS(4503),
    [anon_sym_EXIT] = ACTIONS(4503),
    [anon_sym_Exit] = ACTIONS(4503),
    [anon_sym_continue] = ACTIONS(4503),
    [anon_sym_CONTINUE] = ACTIONS(4503),
    [anon_sym_Continue] = ACTIONS(4503),
    [anon_sym_break] = ACTIONS(4503),
    [anon_sym_BREAK] = ACTIONS(4503),
    [anon_sym_Break] = ACTIONS(4503),
    [anon_sym_with] = ACTIONS(4503),
    [anon_sym_WITH] = ACTIONS(4503),
    [anon_sym_With] = ACTIONS(4503),
    [sym_asserterror_keyword] = ACTIONS(4505),
    [sym_page_keyword] = ACTIONS(4503),
    [anon_sym_codeunit] = ACTIONS(4503),
    [anon_sym_CODEUNIT] = ACTIONS(4503),
    [anon_sym_Codeunit] = ACTIONS(4503),
    [anon_sym_CodeUnit] = ACTIONS(4503),
    [anon_sym_COdeunit] = ACTIONS(4503),
    [anon_sym_codeUnit] = ACTIONS(4503),
    [sym_report_keyword] = ACTIONS(4503),
    [sym_query_keyword] = ACTIONS(4503),
    [anon_sym_xmlport] = ACTIONS(4503),
    [anon_sym_XMLPORT] = ACTIONS(4503),
    [anon_sym_Xmlport] = ACTIONS(4503),
    [anon_sym_XMLport] = ACTIONS(4503),
    [anon_sym_XMLPort] = ACTIONS(4503),
    [anon_sym_XmlPort] = ACTIONS(4503),
    [anon_sym_enum] = ACTIONS(4503),
    [anon_sym_ENUM] = ACTIONS(4503),
    [anon_sym_Enum] = ACTIONS(4503),
    [anon_sym_eNUM] = ACTIONS(4503),
    [anon_sym_eNum] = ACTIONS(4503),
    [anon_sym_ENum] = ACTIONS(4503),
    [sym_quoted_identifier] = ACTIONS(4505),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4505),
    [sym_integer] = ACTIONS(4503),
    [sym_continue_as_identifier] = ACTIONS(4505),
    [sym_preproc_open] = ACTIONS(4505),
    [sym_end_keyword] = ACTIONS(4505),
  },
  [STATE(2364)] = {
    [sym_identifier] = ACTIONS(4507),
    [anon_sym_SEMI] = ACTIONS(4509),
    [anon_sym_DASH] = ACTIONS(4509),
    [aux_sym_boolean_token1] = ACTIONS(4507),
    [aux_sym_boolean_token2] = ACTIONS(4507),
    [sym_decimal] = ACTIONS(4507),
    [anon_sym_LPAREN] = ACTIONS(4509),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4507),
    [anon_sym_LBRACK] = ACTIONS(4509),
    [aux_sym_record_type_token1] = ACTIONS(4507),
    [aux_sym_basic_type_token21] = ACTIONS(4507),
    [aux_sym_basic_type_token22] = ACTIONS(4507),
    [aux_sym_basic_type_token48] = ACTIONS(4507),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4507),
    [anon_sym_POUNDif] = ACTIONS(4509),
    [anon_sym_POUNDIF] = ACTIONS(4509),
    [anon_sym_POUNDIf] = ACTIONS(4509),
    [anon_sym_not] = ACTIONS(4507),
    [anon_sym_NOT] = ACTIONS(4507),
    [anon_sym_Not] = ACTIONS(4507),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4507),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4507),
    [anon_sym_PLUS] = ACTIONS(4509),
    [sym_datetime_literal] = ACTIONS(4509),
    [sym_date_literal] = ACTIONS(4507),
    [sym_time_literal] = ACTIONS(4507),
    [sym_biginteger_literal] = ACTIONS(4509),
    [anon_sym_if] = ACTIONS(4507),
    [anon_sym_IF] = ACTIONS(4507),
    [anon_sym_If] = ACTIONS(4507),
    [anon_sym_else] = ACTIONS(4507),
    [anon_sym_ELSE] = ACTIONS(4507),
    [anon_sym_Else] = ACTIONS(4507),
    [anon_sym_case] = ACTIONS(4507),
    [anon_sym_CASE] = ACTIONS(4507),
    [anon_sym_Case] = ACTIONS(4507),
    [anon_sym_for] = ACTIONS(4507),
    [anon_sym_FOR] = ACTIONS(4507),
    [anon_sym_For] = ACTIONS(4507),
    [anon_sym_foreach] = ACTIONS(4507),
    [anon_sym_FOREACH] = ACTIONS(4507),
    [anon_sym_Foreach] = ACTIONS(4507),
    [anon_sym_while] = ACTIONS(4507),
    [anon_sym_WHILE] = ACTIONS(4507),
    [anon_sym_While] = ACTIONS(4507),
    [anon_sym_repeat] = ACTIONS(4507),
    [anon_sym_REPEAT] = ACTIONS(4507),
    [anon_sym_Repeat] = ACTIONS(4507),
    [anon_sym_exit] = ACTIONS(4507),
    [anon_sym_EXIT] = ACTIONS(4507),
    [anon_sym_Exit] = ACTIONS(4507),
    [anon_sym_continue] = ACTIONS(4507),
    [anon_sym_CONTINUE] = ACTIONS(4507),
    [anon_sym_Continue] = ACTIONS(4507),
    [anon_sym_break] = ACTIONS(4507),
    [anon_sym_BREAK] = ACTIONS(4507),
    [anon_sym_Break] = ACTIONS(4507),
    [anon_sym_with] = ACTIONS(4507),
    [anon_sym_WITH] = ACTIONS(4507),
    [anon_sym_With] = ACTIONS(4507),
    [sym_asserterror_keyword] = ACTIONS(4509),
    [sym_page_keyword] = ACTIONS(4507),
    [anon_sym_codeunit] = ACTIONS(4507),
    [anon_sym_CODEUNIT] = ACTIONS(4507),
    [anon_sym_Codeunit] = ACTIONS(4507),
    [anon_sym_CodeUnit] = ACTIONS(4507),
    [anon_sym_COdeunit] = ACTIONS(4507),
    [anon_sym_codeUnit] = ACTIONS(4507),
    [sym_report_keyword] = ACTIONS(4507),
    [sym_query_keyword] = ACTIONS(4507),
    [anon_sym_xmlport] = ACTIONS(4507),
    [anon_sym_XMLPORT] = ACTIONS(4507),
    [anon_sym_Xmlport] = ACTIONS(4507),
    [anon_sym_XMLport] = ACTIONS(4507),
    [anon_sym_XMLPort] = ACTIONS(4507),
    [anon_sym_XmlPort] = ACTIONS(4507),
    [anon_sym_enum] = ACTIONS(4507),
    [anon_sym_ENUM] = ACTIONS(4507),
    [anon_sym_Enum] = ACTIONS(4507),
    [anon_sym_eNUM] = ACTIONS(4507),
    [anon_sym_eNum] = ACTIONS(4507),
    [anon_sym_ENum] = ACTIONS(4507),
    [sym_quoted_identifier] = ACTIONS(4509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4509),
    [sym_integer] = ACTIONS(4507),
    [sym_continue_as_identifier] = ACTIONS(4509),
    [sym_preproc_open] = ACTIONS(4509),
    [sym_end_keyword] = ACTIONS(4509),
  },
  [STATE(2365)] = {
    [sym_identifier] = ACTIONS(4511),
    [anon_sym_SEMI] = ACTIONS(4513),
    [anon_sym_DASH] = ACTIONS(4513),
    [aux_sym_boolean_token1] = ACTIONS(4511),
    [aux_sym_boolean_token2] = ACTIONS(4511),
    [sym_decimal] = ACTIONS(4511),
    [anon_sym_LPAREN] = ACTIONS(4513),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4511),
    [anon_sym_LBRACK] = ACTIONS(4513),
    [aux_sym_record_type_token1] = ACTIONS(4511),
    [aux_sym_basic_type_token21] = ACTIONS(4511),
    [aux_sym_basic_type_token22] = ACTIONS(4511),
    [aux_sym_basic_type_token48] = ACTIONS(4511),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4511),
    [anon_sym_POUNDif] = ACTIONS(4513),
    [anon_sym_POUNDIF] = ACTIONS(4513),
    [anon_sym_POUNDIf] = ACTIONS(4513),
    [anon_sym_not] = ACTIONS(4511),
    [anon_sym_NOT] = ACTIONS(4511),
    [anon_sym_Not] = ACTIONS(4511),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4511),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4511),
    [anon_sym_PLUS] = ACTIONS(4513),
    [sym_datetime_literal] = ACTIONS(4513),
    [sym_date_literal] = ACTIONS(4511),
    [sym_time_literal] = ACTIONS(4511),
    [sym_biginteger_literal] = ACTIONS(4513),
    [anon_sym_if] = ACTIONS(4511),
    [anon_sym_IF] = ACTIONS(4511),
    [anon_sym_If] = ACTIONS(4511),
    [anon_sym_else] = ACTIONS(4511),
    [anon_sym_ELSE] = ACTIONS(4511),
    [anon_sym_Else] = ACTIONS(4511),
    [anon_sym_case] = ACTIONS(4511),
    [anon_sym_CASE] = ACTIONS(4511),
    [anon_sym_Case] = ACTIONS(4511),
    [anon_sym_for] = ACTIONS(4511),
    [anon_sym_FOR] = ACTIONS(4511),
    [anon_sym_For] = ACTIONS(4511),
    [anon_sym_foreach] = ACTIONS(4511),
    [anon_sym_FOREACH] = ACTIONS(4511),
    [anon_sym_Foreach] = ACTIONS(4511),
    [anon_sym_while] = ACTIONS(4511),
    [anon_sym_WHILE] = ACTIONS(4511),
    [anon_sym_While] = ACTIONS(4511),
    [anon_sym_repeat] = ACTIONS(4511),
    [anon_sym_REPEAT] = ACTIONS(4511),
    [anon_sym_Repeat] = ACTIONS(4511),
    [anon_sym_exit] = ACTIONS(4511),
    [anon_sym_EXIT] = ACTIONS(4511),
    [anon_sym_Exit] = ACTIONS(4511),
    [anon_sym_continue] = ACTIONS(4511),
    [anon_sym_CONTINUE] = ACTIONS(4511),
    [anon_sym_Continue] = ACTIONS(4511),
    [anon_sym_break] = ACTIONS(4511),
    [anon_sym_BREAK] = ACTIONS(4511),
    [anon_sym_Break] = ACTIONS(4511),
    [anon_sym_with] = ACTIONS(4511),
    [anon_sym_WITH] = ACTIONS(4511),
    [anon_sym_With] = ACTIONS(4511),
    [sym_asserterror_keyword] = ACTIONS(4513),
    [sym_page_keyword] = ACTIONS(4511),
    [anon_sym_codeunit] = ACTIONS(4511),
    [anon_sym_CODEUNIT] = ACTIONS(4511),
    [anon_sym_Codeunit] = ACTIONS(4511),
    [anon_sym_CodeUnit] = ACTIONS(4511),
    [anon_sym_COdeunit] = ACTIONS(4511),
    [anon_sym_codeUnit] = ACTIONS(4511),
    [sym_report_keyword] = ACTIONS(4511),
    [sym_query_keyword] = ACTIONS(4511),
    [anon_sym_xmlport] = ACTIONS(4511),
    [anon_sym_XMLPORT] = ACTIONS(4511),
    [anon_sym_Xmlport] = ACTIONS(4511),
    [anon_sym_XMLport] = ACTIONS(4511),
    [anon_sym_XMLPort] = ACTIONS(4511),
    [anon_sym_XmlPort] = ACTIONS(4511),
    [anon_sym_enum] = ACTIONS(4511),
    [anon_sym_ENUM] = ACTIONS(4511),
    [anon_sym_Enum] = ACTIONS(4511),
    [anon_sym_eNUM] = ACTIONS(4511),
    [anon_sym_eNum] = ACTIONS(4511),
    [anon_sym_ENum] = ACTIONS(4511),
    [sym_quoted_identifier] = ACTIONS(4513),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4513),
    [sym_integer] = ACTIONS(4511),
    [sym_continue_as_identifier] = ACTIONS(4513),
    [sym_preproc_open] = ACTIONS(4513),
    [sym_end_keyword] = ACTIONS(4513),
  },
  [STATE(2366)] = {
    [sym_identifier] = ACTIONS(4515),
    [anon_sym_SEMI] = ACTIONS(4517),
    [anon_sym_DASH] = ACTIONS(4517),
    [aux_sym_boolean_token1] = ACTIONS(4515),
    [aux_sym_boolean_token2] = ACTIONS(4515),
    [sym_decimal] = ACTIONS(4515),
    [anon_sym_LPAREN] = ACTIONS(4517),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4515),
    [anon_sym_LBRACK] = ACTIONS(4517),
    [aux_sym_record_type_token1] = ACTIONS(4515),
    [aux_sym_basic_type_token21] = ACTIONS(4515),
    [aux_sym_basic_type_token22] = ACTIONS(4515),
    [aux_sym_basic_type_token48] = ACTIONS(4515),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4515),
    [anon_sym_POUNDif] = ACTIONS(4517),
    [anon_sym_POUNDIF] = ACTIONS(4517),
    [anon_sym_POUNDIf] = ACTIONS(4517),
    [anon_sym_not] = ACTIONS(4515),
    [anon_sym_NOT] = ACTIONS(4515),
    [anon_sym_Not] = ACTIONS(4515),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4515),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4515),
    [anon_sym_PLUS] = ACTIONS(4517),
    [sym_datetime_literal] = ACTIONS(4517),
    [sym_date_literal] = ACTIONS(4515),
    [sym_time_literal] = ACTIONS(4515),
    [sym_biginteger_literal] = ACTIONS(4517),
    [anon_sym_if] = ACTIONS(4515),
    [anon_sym_IF] = ACTIONS(4515),
    [anon_sym_If] = ACTIONS(4515),
    [anon_sym_else] = ACTIONS(4515),
    [anon_sym_ELSE] = ACTIONS(4515),
    [anon_sym_Else] = ACTIONS(4515),
    [anon_sym_case] = ACTIONS(4515),
    [anon_sym_CASE] = ACTIONS(4515),
    [anon_sym_Case] = ACTIONS(4515),
    [anon_sym_for] = ACTIONS(4515),
    [anon_sym_FOR] = ACTIONS(4515),
    [anon_sym_For] = ACTIONS(4515),
    [anon_sym_foreach] = ACTIONS(4515),
    [anon_sym_FOREACH] = ACTIONS(4515),
    [anon_sym_Foreach] = ACTIONS(4515),
    [anon_sym_while] = ACTIONS(4515),
    [anon_sym_WHILE] = ACTIONS(4515),
    [anon_sym_While] = ACTIONS(4515),
    [anon_sym_repeat] = ACTIONS(4515),
    [anon_sym_REPEAT] = ACTIONS(4515),
    [anon_sym_Repeat] = ACTIONS(4515),
    [anon_sym_exit] = ACTIONS(4515),
    [anon_sym_EXIT] = ACTIONS(4515),
    [anon_sym_Exit] = ACTIONS(4515),
    [anon_sym_continue] = ACTIONS(4515),
    [anon_sym_CONTINUE] = ACTIONS(4515),
    [anon_sym_Continue] = ACTIONS(4515),
    [anon_sym_break] = ACTIONS(4515),
    [anon_sym_BREAK] = ACTIONS(4515),
    [anon_sym_Break] = ACTIONS(4515),
    [anon_sym_with] = ACTIONS(4515),
    [anon_sym_WITH] = ACTIONS(4515),
    [anon_sym_With] = ACTIONS(4515),
    [sym_asserterror_keyword] = ACTIONS(4517),
    [sym_page_keyword] = ACTIONS(4515),
    [anon_sym_codeunit] = ACTIONS(4515),
    [anon_sym_CODEUNIT] = ACTIONS(4515),
    [anon_sym_Codeunit] = ACTIONS(4515),
    [anon_sym_CodeUnit] = ACTIONS(4515),
    [anon_sym_COdeunit] = ACTIONS(4515),
    [anon_sym_codeUnit] = ACTIONS(4515),
    [sym_report_keyword] = ACTIONS(4515),
    [sym_query_keyword] = ACTIONS(4515),
    [anon_sym_xmlport] = ACTIONS(4515),
    [anon_sym_XMLPORT] = ACTIONS(4515),
    [anon_sym_Xmlport] = ACTIONS(4515),
    [anon_sym_XMLport] = ACTIONS(4515),
    [anon_sym_XMLPort] = ACTIONS(4515),
    [anon_sym_XmlPort] = ACTIONS(4515),
    [anon_sym_enum] = ACTIONS(4515),
    [anon_sym_ENUM] = ACTIONS(4515),
    [anon_sym_Enum] = ACTIONS(4515),
    [anon_sym_eNUM] = ACTIONS(4515),
    [anon_sym_eNum] = ACTIONS(4515),
    [anon_sym_ENum] = ACTIONS(4515),
    [sym_quoted_identifier] = ACTIONS(4517),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4517),
    [sym_integer] = ACTIONS(4515),
    [sym_continue_as_identifier] = ACTIONS(4517),
    [sym_preproc_open] = ACTIONS(4517),
    [sym_end_keyword] = ACTIONS(4517),
  },
  [STATE(2367)] = {
    [sym_identifier] = ACTIONS(4519),
    [anon_sym_SEMI] = ACTIONS(4521),
    [anon_sym_DASH] = ACTIONS(4521),
    [aux_sym_boolean_token1] = ACTIONS(4519),
    [aux_sym_boolean_token2] = ACTIONS(4519),
    [sym_decimal] = ACTIONS(4519),
    [anon_sym_LPAREN] = ACTIONS(4521),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4521),
    [aux_sym_record_type_token1] = ACTIONS(4519),
    [aux_sym_basic_type_token21] = ACTIONS(4519),
    [aux_sym_basic_type_token22] = ACTIONS(4519),
    [aux_sym_basic_type_token48] = ACTIONS(4519),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4519),
    [anon_sym_POUNDif] = ACTIONS(4521),
    [anon_sym_POUNDIF] = ACTIONS(4521),
    [anon_sym_POUNDIf] = ACTIONS(4521),
    [anon_sym_not] = ACTIONS(4519),
    [anon_sym_NOT] = ACTIONS(4519),
    [anon_sym_Not] = ACTIONS(4519),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4519),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4519),
    [anon_sym_PLUS] = ACTIONS(4521),
    [sym_datetime_literal] = ACTIONS(4521),
    [sym_date_literal] = ACTIONS(4519),
    [sym_time_literal] = ACTIONS(4519),
    [sym_biginteger_literal] = ACTIONS(4521),
    [anon_sym_if] = ACTIONS(4519),
    [anon_sym_IF] = ACTIONS(4519),
    [anon_sym_If] = ACTIONS(4519),
    [anon_sym_else] = ACTIONS(4519),
    [anon_sym_ELSE] = ACTIONS(4519),
    [anon_sym_Else] = ACTIONS(4519),
    [anon_sym_case] = ACTIONS(4519),
    [anon_sym_CASE] = ACTIONS(4519),
    [anon_sym_Case] = ACTIONS(4519),
    [anon_sym_for] = ACTIONS(4519),
    [anon_sym_FOR] = ACTIONS(4519),
    [anon_sym_For] = ACTIONS(4519),
    [anon_sym_foreach] = ACTIONS(4519),
    [anon_sym_FOREACH] = ACTIONS(4519),
    [anon_sym_Foreach] = ACTIONS(4519),
    [anon_sym_while] = ACTIONS(4519),
    [anon_sym_WHILE] = ACTIONS(4519),
    [anon_sym_While] = ACTIONS(4519),
    [anon_sym_repeat] = ACTIONS(4519),
    [anon_sym_REPEAT] = ACTIONS(4519),
    [anon_sym_Repeat] = ACTIONS(4519),
    [anon_sym_exit] = ACTIONS(4519),
    [anon_sym_EXIT] = ACTIONS(4519),
    [anon_sym_Exit] = ACTIONS(4519),
    [anon_sym_continue] = ACTIONS(4519),
    [anon_sym_CONTINUE] = ACTIONS(4519),
    [anon_sym_Continue] = ACTIONS(4519),
    [anon_sym_break] = ACTIONS(4519),
    [anon_sym_BREAK] = ACTIONS(4519),
    [anon_sym_Break] = ACTIONS(4519),
    [anon_sym_with] = ACTIONS(4519),
    [anon_sym_WITH] = ACTIONS(4519),
    [anon_sym_With] = ACTIONS(4519),
    [sym_asserterror_keyword] = ACTIONS(4521),
    [sym_page_keyword] = ACTIONS(4519),
    [anon_sym_codeunit] = ACTIONS(4519),
    [anon_sym_CODEUNIT] = ACTIONS(4519),
    [anon_sym_Codeunit] = ACTIONS(4519),
    [anon_sym_CodeUnit] = ACTIONS(4519),
    [anon_sym_COdeunit] = ACTIONS(4519),
    [anon_sym_codeUnit] = ACTIONS(4519),
    [sym_report_keyword] = ACTIONS(4519),
    [sym_query_keyword] = ACTIONS(4519),
    [anon_sym_xmlport] = ACTIONS(4519),
    [anon_sym_XMLPORT] = ACTIONS(4519),
    [anon_sym_Xmlport] = ACTIONS(4519),
    [anon_sym_XMLport] = ACTIONS(4519),
    [anon_sym_XMLPort] = ACTIONS(4519),
    [anon_sym_XmlPort] = ACTIONS(4519),
    [anon_sym_enum] = ACTIONS(4519),
    [anon_sym_ENUM] = ACTIONS(4519),
    [anon_sym_Enum] = ACTIONS(4519),
    [anon_sym_eNUM] = ACTIONS(4519),
    [anon_sym_eNum] = ACTIONS(4519),
    [anon_sym_ENum] = ACTIONS(4519),
    [sym_quoted_identifier] = ACTIONS(4521),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4521),
    [sym_integer] = ACTIONS(4519),
    [sym_continue_as_identifier] = ACTIONS(4521),
    [sym_preproc_open] = ACTIONS(4521),
    [sym_end_keyword] = ACTIONS(4521),
  },
  [STATE(2368)] = {
    [sym_identifier] = ACTIONS(4523),
    [anon_sym_SEMI] = ACTIONS(4525),
    [anon_sym_DASH] = ACTIONS(4525),
    [aux_sym_boolean_token1] = ACTIONS(4523),
    [aux_sym_boolean_token2] = ACTIONS(4523),
    [sym_decimal] = ACTIONS(4523),
    [anon_sym_LPAREN] = ACTIONS(4525),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4523),
    [anon_sym_LBRACK] = ACTIONS(4525),
    [aux_sym_record_type_token1] = ACTIONS(4523),
    [aux_sym_basic_type_token21] = ACTIONS(4523),
    [aux_sym_basic_type_token22] = ACTIONS(4523),
    [aux_sym_basic_type_token48] = ACTIONS(4523),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4523),
    [anon_sym_POUNDif] = ACTIONS(4525),
    [anon_sym_POUNDIF] = ACTIONS(4525),
    [anon_sym_POUNDIf] = ACTIONS(4525),
    [anon_sym_not] = ACTIONS(4523),
    [anon_sym_NOT] = ACTIONS(4523),
    [anon_sym_Not] = ACTIONS(4523),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4523),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4523),
    [anon_sym_PLUS] = ACTIONS(4525),
    [sym_datetime_literal] = ACTIONS(4525),
    [sym_date_literal] = ACTIONS(4523),
    [sym_time_literal] = ACTIONS(4523),
    [sym_biginteger_literal] = ACTIONS(4525),
    [anon_sym_if] = ACTIONS(4523),
    [anon_sym_IF] = ACTIONS(4523),
    [anon_sym_If] = ACTIONS(4523),
    [anon_sym_else] = ACTIONS(4523),
    [anon_sym_ELSE] = ACTIONS(4523),
    [anon_sym_Else] = ACTIONS(4523),
    [anon_sym_case] = ACTIONS(4523),
    [anon_sym_CASE] = ACTIONS(4523),
    [anon_sym_Case] = ACTIONS(4523),
    [anon_sym_for] = ACTIONS(4523),
    [anon_sym_FOR] = ACTIONS(4523),
    [anon_sym_For] = ACTIONS(4523),
    [anon_sym_foreach] = ACTIONS(4523),
    [anon_sym_FOREACH] = ACTIONS(4523),
    [anon_sym_Foreach] = ACTIONS(4523),
    [anon_sym_while] = ACTIONS(4523),
    [anon_sym_WHILE] = ACTIONS(4523),
    [anon_sym_While] = ACTIONS(4523),
    [anon_sym_repeat] = ACTIONS(4523),
    [anon_sym_REPEAT] = ACTIONS(4523),
    [anon_sym_Repeat] = ACTIONS(4523),
    [anon_sym_exit] = ACTIONS(4523),
    [anon_sym_EXIT] = ACTIONS(4523),
    [anon_sym_Exit] = ACTIONS(4523),
    [anon_sym_continue] = ACTIONS(4523),
    [anon_sym_CONTINUE] = ACTIONS(4523),
    [anon_sym_Continue] = ACTIONS(4523),
    [anon_sym_break] = ACTIONS(4523),
    [anon_sym_BREAK] = ACTIONS(4523),
    [anon_sym_Break] = ACTIONS(4523),
    [anon_sym_with] = ACTIONS(4523),
    [anon_sym_WITH] = ACTIONS(4523),
    [anon_sym_With] = ACTIONS(4523),
    [sym_asserterror_keyword] = ACTIONS(4525),
    [sym_page_keyword] = ACTIONS(4523),
    [anon_sym_codeunit] = ACTIONS(4523),
    [anon_sym_CODEUNIT] = ACTIONS(4523),
    [anon_sym_Codeunit] = ACTIONS(4523),
    [anon_sym_CodeUnit] = ACTIONS(4523),
    [anon_sym_COdeunit] = ACTIONS(4523),
    [anon_sym_codeUnit] = ACTIONS(4523),
    [sym_report_keyword] = ACTIONS(4523),
    [sym_query_keyword] = ACTIONS(4523),
    [anon_sym_xmlport] = ACTIONS(4523),
    [anon_sym_XMLPORT] = ACTIONS(4523),
    [anon_sym_Xmlport] = ACTIONS(4523),
    [anon_sym_XMLport] = ACTIONS(4523),
    [anon_sym_XMLPort] = ACTIONS(4523),
    [anon_sym_XmlPort] = ACTIONS(4523),
    [anon_sym_enum] = ACTIONS(4523),
    [anon_sym_ENUM] = ACTIONS(4523),
    [anon_sym_Enum] = ACTIONS(4523),
    [anon_sym_eNUM] = ACTIONS(4523),
    [anon_sym_eNum] = ACTIONS(4523),
    [anon_sym_ENum] = ACTIONS(4523),
    [sym_quoted_identifier] = ACTIONS(4525),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4525),
    [sym_integer] = ACTIONS(4523),
    [sym_continue_as_identifier] = ACTIONS(4525),
    [sym_preproc_open] = ACTIONS(4525),
    [sym_end_keyword] = ACTIONS(4525),
  },
  [STATE(2369)] = {
    [sym_identifier] = ACTIONS(4527),
    [anon_sym_SEMI] = ACTIONS(4529),
    [anon_sym_DASH] = ACTIONS(4529),
    [aux_sym_boolean_token1] = ACTIONS(4527),
    [aux_sym_boolean_token2] = ACTIONS(4527),
    [sym_decimal] = ACTIONS(4527),
    [anon_sym_LPAREN] = ACTIONS(4529),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4527),
    [anon_sym_LBRACK] = ACTIONS(4529),
    [aux_sym_record_type_token1] = ACTIONS(4527),
    [aux_sym_basic_type_token21] = ACTIONS(4527),
    [aux_sym_basic_type_token22] = ACTIONS(4527),
    [aux_sym_basic_type_token48] = ACTIONS(4527),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4527),
    [anon_sym_POUNDif] = ACTIONS(4529),
    [anon_sym_POUNDIF] = ACTIONS(4529),
    [anon_sym_POUNDIf] = ACTIONS(4529),
    [anon_sym_not] = ACTIONS(4527),
    [anon_sym_NOT] = ACTIONS(4527),
    [anon_sym_Not] = ACTIONS(4527),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4527),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4527),
    [anon_sym_PLUS] = ACTIONS(4529),
    [sym_datetime_literal] = ACTIONS(4529),
    [sym_date_literal] = ACTIONS(4527),
    [sym_time_literal] = ACTIONS(4527),
    [sym_biginteger_literal] = ACTIONS(4529),
    [anon_sym_if] = ACTIONS(4527),
    [anon_sym_IF] = ACTIONS(4527),
    [anon_sym_If] = ACTIONS(4527),
    [anon_sym_else] = ACTIONS(4527),
    [anon_sym_ELSE] = ACTIONS(4527),
    [anon_sym_Else] = ACTIONS(4527),
    [anon_sym_case] = ACTIONS(4527),
    [anon_sym_CASE] = ACTIONS(4527),
    [anon_sym_Case] = ACTIONS(4527),
    [anon_sym_for] = ACTIONS(4527),
    [anon_sym_FOR] = ACTIONS(4527),
    [anon_sym_For] = ACTIONS(4527),
    [anon_sym_foreach] = ACTIONS(4527),
    [anon_sym_FOREACH] = ACTIONS(4527),
    [anon_sym_Foreach] = ACTIONS(4527),
    [anon_sym_while] = ACTIONS(4527),
    [anon_sym_WHILE] = ACTIONS(4527),
    [anon_sym_While] = ACTIONS(4527),
    [anon_sym_repeat] = ACTIONS(4527),
    [anon_sym_REPEAT] = ACTIONS(4527),
    [anon_sym_Repeat] = ACTIONS(4527),
    [anon_sym_exit] = ACTIONS(4527),
    [anon_sym_EXIT] = ACTIONS(4527),
    [anon_sym_Exit] = ACTIONS(4527),
    [anon_sym_continue] = ACTIONS(4527),
    [anon_sym_CONTINUE] = ACTIONS(4527),
    [anon_sym_Continue] = ACTIONS(4527),
    [anon_sym_break] = ACTIONS(4527),
    [anon_sym_BREAK] = ACTIONS(4527),
    [anon_sym_Break] = ACTIONS(4527),
    [anon_sym_with] = ACTIONS(4527),
    [anon_sym_WITH] = ACTIONS(4527),
    [anon_sym_With] = ACTIONS(4527),
    [sym_asserterror_keyword] = ACTIONS(4529),
    [sym_page_keyword] = ACTIONS(4527),
    [anon_sym_codeunit] = ACTIONS(4527),
    [anon_sym_CODEUNIT] = ACTIONS(4527),
    [anon_sym_Codeunit] = ACTIONS(4527),
    [anon_sym_CodeUnit] = ACTIONS(4527),
    [anon_sym_COdeunit] = ACTIONS(4527),
    [anon_sym_codeUnit] = ACTIONS(4527),
    [sym_report_keyword] = ACTIONS(4527),
    [sym_query_keyword] = ACTIONS(4527),
    [anon_sym_xmlport] = ACTIONS(4527),
    [anon_sym_XMLPORT] = ACTIONS(4527),
    [anon_sym_Xmlport] = ACTIONS(4527),
    [anon_sym_XMLport] = ACTIONS(4527),
    [anon_sym_XMLPort] = ACTIONS(4527),
    [anon_sym_XmlPort] = ACTIONS(4527),
    [anon_sym_enum] = ACTIONS(4527),
    [anon_sym_ENUM] = ACTIONS(4527),
    [anon_sym_Enum] = ACTIONS(4527),
    [anon_sym_eNUM] = ACTIONS(4527),
    [anon_sym_eNum] = ACTIONS(4527),
    [anon_sym_ENum] = ACTIONS(4527),
    [sym_quoted_identifier] = ACTIONS(4529),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4529),
    [sym_integer] = ACTIONS(4527),
    [sym_continue_as_identifier] = ACTIONS(4529),
    [sym_preproc_open] = ACTIONS(4529),
    [sym_end_keyword] = ACTIONS(4529),
  },
  [STATE(2370)] = {
    [sym_identifier] = ACTIONS(4531),
    [anon_sym_SEMI] = ACTIONS(4533),
    [anon_sym_DASH] = ACTIONS(4533),
    [aux_sym_boolean_token1] = ACTIONS(4531),
    [aux_sym_boolean_token2] = ACTIONS(4531),
    [sym_decimal] = ACTIONS(4531),
    [anon_sym_LPAREN] = ACTIONS(4533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4531),
    [anon_sym_LBRACK] = ACTIONS(4533),
    [aux_sym_record_type_token1] = ACTIONS(4531),
    [aux_sym_basic_type_token21] = ACTIONS(4531),
    [aux_sym_basic_type_token22] = ACTIONS(4531),
    [aux_sym_basic_type_token48] = ACTIONS(4531),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4531),
    [anon_sym_POUNDif] = ACTIONS(4533),
    [anon_sym_POUNDIF] = ACTIONS(4533),
    [anon_sym_POUNDIf] = ACTIONS(4533),
    [anon_sym_not] = ACTIONS(4531),
    [anon_sym_NOT] = ACTIONS(4531),
    [anon_sym_Not] = ACTIONS(4531),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4531),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4531),
    [anon_sym_PLUS] = ACTIONS(4533),
    [sym_datetime_literal] = ACTIONS(4533),
    [sym_date_literal] = ACTIONS(4531),
    [sym_time_literal] = ACTIONS(4531),
    [sym_biginteger_literal] = ACTIONS(4533),
    [anon_sym_if] = ACTIONS(4531),
    [anon_sym_IF] = ACTIONS(4531),
    [anon_sym_If] = ACTIONS(4531),
    [anon_sym_else] = ACTIONS(4531),
    [anon_sym_ELSE] = ACTIONS(4531),
    [anon_sym_Else] = ACTIONS(4531),
    [anon_sym_case] = ACTIONS(4531),
    [anon_sym_CASE] = ACTIONS(4531),
    [anon_sym_Case] = ACTIONS(4531),
    [anon_sym_for] = ACTIONS(4531),
    [anon_sym_FOR] = ACTIONS(4531),
    [anon_sym_For] = ACTIONS(4531),
    [anon_sym_foreach] = ACTIONS(4531),
    [anon_sym_FOREACH] = ACTIONS(4531),
    [anon_sym_Foreach] = ACTIONS(4531),
    [anon_sym_while] = ACTIONS(4531),
    [anon_sym_WHILE] = ACTIONS(4531),
    [anon_sym_While] = ACTIONS(4531),
    [anon_sym_repeat] = ACTIONS(4531),
    [anon_sym_REPEAT] = ACTIONS(4531),
    [anon_sym_Repeat] = ACTIONS(4531),
    [anon_sym_exit] = ACTIONS(4531),
    [anon_sym_EXIT] = ACTIONS(4531),
    [anon_sym_Exit] = ACTIONS(4531),
    [anon_sym_continue] = ACTIONS(4531),
    [anon_sym_CONTINUE] = ACTIONS(4531),
    [anon_sym_Continue] = ACTIONS(4531),
    [anon_sym_break] = ACTIONS(4531),
    [anon_sym_BREAK] = ACTIONS(4531),
    [anon_sym_Break] = ACTIONS(4531),
    [anon_sym_with] = ACTIONS(4531),
    [anon_sym_WITH] = ACTIONS(4531),
    [anon_sym_With] = ACTIONS(4531),
    [sym_asserterror_keyword] = ACTIONS(4533),
    [sym_page_keyword] = ACTIONS(4531),
    [anon_sym_codeunit] = ACTIONS(4531),
    [anon_sym_CODEUNIT] = ACTIONS(4531),
    [anon_sym_Codeunit] = ACTIONS(4531),
    [anon_sym_CodeUnit] = ACTIONS(4531),
    [anon_sym_COdeunit] = ACTIONS(4531),
    [anon_sym_codeUnit] = ACTIONS(4531),
    [sym_report_keyword] = ACTIONS(4531),
    [sym_query_keyword] = ACTIONS(4531),
    [anon_sym_xmlport] = ACTIONS(4531),
    [anon_sym_XMLPORT] = ACTIONS(4531),
    [anon_sym_Xmlport] = ACTIONS(4531),
    [anon_sym_XMLport] = ACTIONS(4531),
    [anon_sym_XMLPort] = ACTIONS(4531),
    [anon_sym_XmlPort] = ACTIONS(4531),
    [anon_sym_enum] = ACTIONS(4531),
    [anon_sym_ENUM] = ACTIONS(4531),
    [anon_sym_Enum] = ACTIONS(4531),
    [anon_sym_eNUM] = ACTIONS(4531),
    [anon_sym_eNum] = ACTIONS(4531),
    [anon_sym_ENum] = ACTIONS(4531),
    [sym_quoted_identifier] = ACTIONS(4533),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4533),
    [sym_integer] = ACTIONS(4531),
    [sym_continue_as_identifier] = ACTIONS(4533),
    [sym_preproc_open] = ACTIONS(4533),
    [sym_end_keyword] = ACTIONS(4533),
  },
  [STATE(2371)] = {
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_SEMI] = ACTIONS(4537),
    [anon_sym_DASH] = ACTIONS(4537),
    [aux_sym_boolean_token1] = ACTIONS(4535),
    [aux_sym_boolean_token2] = ACTIONS(4535),
    [sym_decimal] = ACTIONS(4535),
    [anon_sym_LPAREN] = ACTIONS(4537),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4535),
    [anon_sym_LBRACK] = ACTIONS(4537),
    [aux_sym_record_type_token1] = ACTIONS(4535),
    [aux_sym_basic_type_token21] = ACTIONS(4535),
    [aux_sym_basic_type_token22] = ACTIONS(4535),
    [aux_sym_basic_type_token48] = ACTIONS(4535),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4535),
    [anon_sym_POUNDif] = ACTIONS(4537),
    [anon_sym_POUNDIF] = ACTIONS(4537),
    [anon_sym_POUNDIf] = ACTIONS(4537),
    [anon_sym_not] = ACTIONS(4535),
    [anon_sym_NOT] = ACTIONS(4535),
    [anon_sym_Not] = ACTIONS(4535),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4535),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4535),
    [anon_sym_PLUS] = ACTIONS(4537),
    [sym_datetime_literal] = ACTIONS(4537),
    [sym_date_literal] = ACTIONS(4535),
    [sym_time_literal] = ACTIONS(4535),
    [sym_biginteger_literal] = ACTIONS(4537),
    [anon_sym_if] = ACTIONS(4535),
    [anon_sym_IF] = ACTIONS(4535),
    [anon_sym_If] = ACTIONS(4535),
    [anon_sym_else] = ACTIONS(4535),
    [anon_sym_ELSE] = ACTIONS(4535),
    [anon_sym_Else] = ACTIONS(4535),
    [anon_sym_case] = ACTIONS(4535),
    [anon_sym_CASE] = ACTIONS(4535),
    [anon_sym_Case] = ACTIONS(4535),
    [anon_sym_for] = ACTIONS(4535),
    [anon_sym_FOR] = ACTIONS(4535),
    [anon_sym_For] = ACTIONS(4535),
    [anon_sym_foreach] = ACTIONS(4535),
    [anon_sym_FOREACH] = ACTIONS(4535),
    [anon_sym_Foreach] = ACTIONS(4535),
    [anon_sym_while] = ACTIONS(4535),
    [anon_sym_WHILE] = ACTIONS(4535),
    [anon_sym_While] = ACTIONS(4535),
    [anon_sym_repeat] = ACTIONS(4535),
    [anon_sym_REPEAT] = ACTIONS(4535),
    [anon_sym_Repeat] = ACTIONS(4535),
    [anon_sym_exit] = ACTIONS(4535),
    [anon_sym_EXIT] = ACTIONS(4535),
    [anon_sym_Exit] = ACTIONS(4535),
    [anon_sym_continue] = ACTIONS(4535),
    [anon_sym_CONTINUE] = ACTIONS(4535),
    [anon_sym_Continue] = ACTIONS(4535),
    [anon_sym_break] = ACTIONS(4535),
    [anon_sym_BREAK] = ACTIONS(4535),
    [anon_sym_Break] = ACTIONS(4535),
    [anon_sym_with] = ACTIONS(4535),
    [anon_sym_WITH] = ACTIONS(4535),
    [anon_sym_With] = ACTIONS(4535),
    [sym_asserterror_keyword] = ACTIONS(4537),
    [sym_page_keyword] = ACTIONS(4535),
    [anon_sym_codeunit] = ACTIONS(4535),
    [anon_sym_CODEUNIT] = ACTIONS(4535),
    [anon_sym_Codeunit] = ACTIONS(4535),
    [anon_sym_CodeUnit] = ACTIONS(4535),
    [anon_sym_COdeunit] = ACTIONS(4535),
    [anon_sym_codeUnit] = ACTIONS(4535),
    [sym_report_keyword] = ACTIONS(4535),
    [sym_query_keyword] = ACTIONS(4535),
    [anon_sym_xmlport] = ACTIONS(4535),
    [anon_sym_XMLPORT] = ACTIONS(4535),
    [anon_sym_Xmlport] = ACTIONS(4535),
    [anon_sym_XMLport] = ACTIONS(4535),
    [anon_sym_XMLPort] = ACTIONS(4535),
    [anon_sym_XmlPort] = ACTIONS(4535),
    [anon_sym_enum] = ACTIONS(4535),
    [anon_sym_ENUM] = ACTIONS(4535),
    [anon_sym_Enum] = ACTIONS(4535),
    [anon_sym_eNUM] = ACTIONS(4535),
    [anon_sym_eNum] = ACTIONS(4535),
    [anon_sym_ENum] = ACTIONS(4535),
    [sym_quoted_identifier] = ACTIONS(4537),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4537),
    [sym_integer] = ACTIONS(4535),
    [sym_continue_as_identifier] = ACTIONS(4537),
    [sym_preproc_open] = ACTIONS(4537),
    [sym_end_keyword] = ACTIONS(4537),
  },
  [STATE(2372)] = {
    [sym_identifier] = ACTIONS(4539),
    [anon_sym_SEMI] = ACTIONS(4541),
    [anon_sym_DASH] = ACTIONS(4541),
    [aux_sym_boolean_token1] = ACTIONS(4539),
    [aux_sym_boolean_token2] = ACTIONS(4539),
    [sym_decimal] = ACTIONS(4539),
    [anon_sym_LPAREN] = ACTIONS(4541),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4539),
    [anon_sym_LBRACK] = ACTIONS(4541),
    [aux_sym_record_type_token1] = ACTIONS(4539),
    [aux_sym_basic_type_token21] = ACTIONS(4539),
    [aux_sym_basic_type_token22] = ACTIONS(4539),
    [aux_sym_basic_type_token48] = ACTIONS(4539),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4539),
    [anon_sym_POUNDif] = ACTIONS(4541),
    [anon_sym_POUNDIF] = ACTIONS(4541),
    [anon_sym_POUNDIf] = ACTIONS(4541),
    [anon_sym_not] = ACTIONS(4539),
    [anon_sym_NOT] = ACTIONS(4539),
    [anon_sym_Not] = ACTIONS(4539),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4539),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4539),
    [anon_sym_PLUS] = ACTIONS(4541),
    [sym_datetime_literal] = ACTIONS(4541),
    [sym_date_literal] = ACTIONS(4539),
    [sym_time_literal] = ACTIONS(4539),
    [sym_biginteger_literal] = ACTIONS(4541),
    [anon_sym_if] = ACTIONS(4539),
    [anon_sym_IF] = ACTIONS(4539),
    [anon_sym_If] = ACTIONS(4539),
    [anon_sym_else] = ACTIONS(4539),
    [anon_sym_ELSE] = ACTIONS(4539),
    [anon_sym_Else] = ACTIONS(4539),
    [anon_sym_case] = ACTIONS(4539),
    [anon_sym_CASE] = ACTIONS(4539),
    [anon_sym_Case] = ACTIONS(4539),
    [anon_sym_for] = ACTIONS(4539),
    [anon_sym_FOR] = ACTIONS(4539),
    [anon_sym_For] = ACTIONS(4539),
    [anon_sym_foreach] = ACTIONS(4539),
    [anon_sym_FOREACH] = ACTIONS(4539),
    [anon_sym_Foreach] = ACTIONS(4539),
    [anon_sym_while] = ACTIONS(4539),
    [anon_sym_WHILE] = ACTIONS(4539),
    [anon_sym_While] = ACTIONS(4539),
    [anon_sym_repeat] = ACTIONS(4539),
    [anon_sym_REPEAT] = ACTIONS(4539),
    [anon_sym_Repeat] = ACTIONS(4539),
    [anon_sym_exit] = ACTIONS(4539),
    [anon_sym_EXIT] = ACTIONS(4539),
    [anon_sym_Exit] = ACTIONS(4539),
    [anon_sym_continue] = ACTIONS(4539),
    [anon_sym_CONTINUE] = ACTIONS(4539),
    [anon_sym_Continue] = ACTIONS(4539),
    [anon_sym_break] = ACTIONS(4539),
    [anon_sym_BREAK] = ACTIONS(4539),
    [anon_sym_Break] = ACTIONS(4539),
    [anon_sym_with] = ACTIONS(4539),
    [anon_sym_WITH] = ACTIONS(4539),
    [anon_sym_With] = ACTIONS(4539),
    [sym_asserterror_keyword] = ACTIONS(4541),
    [sym_page_keyword] = ACTIONS(4539),
    [anon_sym_codeunit] = ACTIONS(4539),
    [anon_sym_CODEUNIT] = ACTIONS(4539),
    [anon_sym_Codeunit] = ACTIONS(4539),
    [anon_sym_CodeUnit] = ACTIONS(4539),
    [anon_sym_COdeunit] = ACTIONS(4539),
    [anon_sym_codeUnit] = ACTIONS(4539),
    [sym_report_keyword] = ACTIONS(4539),
    [sym_query_keyword] = ACTIONS(4539),
    [anon_sym_xmlport] = ACTIONS(4539),
    [anon_sym_XMLPORT] = ACTIONS(4539),
    [anon_sym_Xmlport] = ACTIONS(4539),
    [anon_sym_XMLport] = ACTIONS(4539),
    [anon_sym_XMLPort] = ACTIONS(4539),
    [anon_sym_XmlPort] = ACTIONS(4539),
    [anon_sym_enum] = ACTIONS(4539),
    [anon_sym_ENUM] = ACTIONS(4539),
    [anon_sym_Enum] = ACTIONS(4539),
    [anon_sym_eNUM] = ACTIONS(4539),
    [anon_sym_eNum] = ACTIONS(4539),
    [anon_sym_ENum] = ACTIONS(4539),
    [sym_quoted_identifier] = ACTIONS(4541),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4541),
    [sym_integer] = ACTIONS(4539),
    [sym_continue_as_identifier] = ACTIONS(4541),
    [sym_preproc_open] = ACTIONS(4541),
    [sym_end_keyword] = ACTIONS(4541),
  },
  [STATE(2373)] = {
    [sym_identifier] = ACTIONS(4543),
    [anon_sym_SEMI] = ACTIONS(4545),
    [anon_sym_DASH] = ACTIONS(4545),
    [aux_sym_boolean_token1] = ACTIONS(4543),
    [aux_sym_boolean_token2] = ACTIONS(4543),
    [sym_decimal] = ACTIONS(4543),
    [anon_sym_LPAREN] = ACTIONS(4545),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4543),
    [anon_sym_LBRACK] = ACTIONS(4545),
    [aux_sym_record_type_token1] = ACTIONS(4543),
    [aux_sym_basic_type_token21] = ACTIONS(4543),
    [aux_sym_basic_type_token22] = ACTIONS(4543),
    [aux_sym_basic_type_token48] = ACTIONS(4543),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4543),
    [anon_sym_POUNDif] = ACTIONS(4545),
    [anon_sym_POUNDIF] = ACTIONS(4545),
    [anon_sym_POUNDIf] = ACTIONS(4545),
    [anon_sym_not] = ACTIONS(4543),
    [anon_sym_NOT] = ACTIONS(4543),
    [anon_sym_Not] = ACTIONS(4543),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4543),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4543),
    [anon_sym_PLUS] = ACTIONS(4545),
    [sym_datetime_literal] = ACTIONS(4545),
    [sym_date_literal] = ACTIONS(4543),
    [sym_time_literal] = ACTIONS(4543),
    [sym_biginteger_literal] = ACTIONS(4545),
    [anon_sym_if] = ACTIONS(4543),
    [anon_sym_IF] = ACTIONS(4543),
    [anon_sym_If] = ACTIONS(4543),
    [anon_sym_else] = ACTIONS(4543),
    [anon_sym_ELSE] = ACTIONS(4543),
    [anon_sym_Else] = ACTIONS(4543),
    [anon_sym_case] = ACTIONS(4543),
    [anon_sym_CASE] = ACTIONS(4543),
    [anon_sym_Case] = ACTIONS(4543),
    [anon_sym_for] = ACTIONS(4543),
    [anon_sym_FOR] = ACTIONS(4543),
    [anon_sym_For] = ACTIONS(4543),
    [anon_sym_foreach] = ACTIONS(4543),
    [anon_sym_FOREACH] = ACTIONS(4543),
    [anon_sym_Foreach] = ACTIONS(4543),
    [anon_sym_while] = ACTIONS(4543),
    [anon_sym_WHILE] = ACTIONS(4543),
    [anon_sym_While] = ACTIONS(4543),
    [anon_sym_repeat] = ACTIONS(4543),
    [anon_sym_REPEAT] = ACTIONS(4543),
    [anon_sym_Repeat] = ACTIONS(4543),
    [anon_sym_exit] = ACTIONS(4543),
    [anon_sym_EXIT] = ACTIONS(4543),
    [anon_sym_Exit] = ACTIONS(4543),
    [anon_sym_continue] = ACTIONS(4543),
    [anon_sym_CONTINUE] = ACTIONS(4543),
    [anon_sym_Continue] = ACTIONS(4543),
    [anon_sym_break] = ACTIONS(4543),
    [anon_sym_BREAK] = ACTIONS(4543),
    [anon_sym_Break] = ACTIONS(4543),
    [anon_sym_with] = ACTIONS(4543),
    [anon_sym_WITH] = ACTIONS(4543),
    [anon_sym_With] = ACTIONS(4543),
    [sym_asserterror_keyword] = ACTIONS(4545),
    [sym_page_keyword] = ACTIONS(4543),
    [anon_sym_codeunit] = ACTIONS(4543),
    [anon_sym_CODEUNIT] = ACTIONS(4543),
    [anon_sym_Codeunit] = ACTIONS(4543),
    [anon_sym_CodeUnit] = ACTIONS(4543),
    [anon_sym_COdeunit] = ACTIONS(4543),
    [anon_sym_codeUnit] = ACTIONS(4543),
    [sym_report_keyword] = ACTIONS(4543),
    [sym_query_keyword] = ACTIONS(4543),
    [anon_sym_xmlport] = ACTIONS(4543),
    [anon_sym_XMLPORT] = ACTIONS(4543),
    [anon_sym_Xmlport] = ACTIONS(4543),
    [anon_sym_XMLport] = ACTIONS(4543),
    [anon_sym_XMLPort] = ACTIONS(4543),
    [anon_sym_XmlPort] = ACTIONS(4543),
    [anon_sym_enum] = ACTIONS(4543),
    [anon_sym_ENUM] = ACTIONS(4543),
    [anon_sym_Enum] = ACTIONS(4543),
    [anon_sym_eNUM] = ACTIONS(4543),
    [anon_sym_eNum] = ACTIONS(4543),
    [anon_sym_ENum] = ACTIONS(4543),
    [sym_quoted_identifier] = ACTIONS(4545),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4545),
    [sym_integer] = ACTIONS(4543),
    [sym_continue_as_identifier] = ACTIONS(4545),
    [sym_preproc_open] = ACTIONS(4545),
    [sym_end_keyword] = ACTIONS(4545),
  },
  [STATE(2374)] = {
    [sym_identifier] = ACTIONS(4815),
    [anon_sym_SEMI] = ACTIONS(4817),
    [anon_sym_DASH] = ACTIONS(4817),
    [aux_sym_boolean_token1] = ACTIONS(4815),
    [aux_sym_boolean_token2] = ACTIONS(4815),
    [sym_decimal] = ACTIONS(4815),
    [anon_sym_LPAREN] = ACTIONS(4817),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4817),
    [aux_sym_record_type_token1] = ACTIONS(4815),
    [aux_sym_basic_type_token21] = ACTIONS(4815),
    [aux_sym_basic_type_token22] = ACTIONS(4815),
    [aux_sym_basic_type_token48] = ACTIONS(4815),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(4815),
    [anon_sym_POUNDif] = ACTIONS(4817),
    [anon_sym_POUNDIF] = ACTIONS(4817),
    [anon_sym_POUNDIf] = ACTIONS(4817),
    [anon_sym_not] = ACTIONS(4815),
    [anon_sym_NOT] = ACTIONS(4815),
    [anon_sym_Not] = ACTIONS(4815),
    [anon_sym_POUNDelse] = ACTIONS(4817),
    [anon_sym_POUNDELSE] = ACTIONS(4817),
    [anon_sym_POUNDElse] = ACTIONS(4817),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4815),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4815),
    [anon_sym_PLUS] = ACTIONS(4817),
    [sym_datetime_literal] = ACTIONS(4817),
    [sym_date_literal] = ACTIONS(4815),
    [sym_time_literal] = ACTIONS(4815),
    [sym_biginteger_literal] = ACTIONS(4817),
    [anon_sym_if] = ACTIONS(4815),
    [anon_sym_IF] = ACTIONS(4815),
    [anon_sym_If] = ACTIONS(4815),
    [anon_sym_case] = ACTIONS(4815),
    [anon_sym_CASE] = ACTIONS(4815),
    [anon_sym_Case] = ACTIONS(4815),
    [anon_sym_for] = ACTIONS(4815),
    [anon_sym_FOR] = ACTIONS(4815),
    [anon_sym_For] = ACTIONS(4815),
    [anon_sym_foreach] = ACTIONS(4815),
    [anon_sym_FOREACH] = ACTIONS(4815),
    [anon_sym_Foreach] = ACTIONS(4815),
    [anon_sym_while] = ACTIONS(4815),
    [anon_sym_WHILE] = ACTIONS(4815),
    [anon_sym_While] = ACTIONS(4815),
    [anon_sym_repeat] = ACTIONS(4815),
    [anon_sym_REPEAT] = ACTIONS(4815),
    [anon_sym_Repeat] = ACTIONS(4815),
    [anon_sym_exit] = ACTIONS(4815),
    [anon_sym_EXIT] = ACTIONS(4815),
    [anon_sym_Exit] = ACTIONS(4815),
    [anon_sym_continue] = ACTIONS(4815),
    [anon_sym_CONTINUE] = ACTIONS(4815),
    [anon_sym_Continue] = ACTIONS(4815),
    [anon_sym_break] = ACTIONS(4815),
    [anon_sym_BREAK] = ACTIONS(4815),
    [anon_sym_Break] = ACTIONS(4815),
    [anon_sym_with] = ACTIONS(4815),
    [anon_sym_WITH] = ACTIONS(4815),
    [anon_sym_With] = ACTIONS(4815),
    [sym_asserterror_keyword] = ACTIONS(4817),
    [sym_page_keyword] = ACTIONS(4815),
    [anon_sym_codeunit] = ACTIONS(4815),
    [anon_sym_CODEUNIT] = ACTIONS(4815),
    [anon_sym_Codeunit] = ACTIONS(4815),
    [anon_sym_CodeUnit] = ACTIONS(4815),
    [anon_sym_COdeunit] = ACTIONS(4815),
    [anon_sym_codeUnit] = ACTIONS(4815),
    [sym_report_keyword] = ACTIONS(4815),
    [sym_query_keyword] = ACTIONS(4815),
    [anon_sym_xmlport] = ACTIONS(4815),
    [anon_sym_XMLPORT] = ACTIONS(4815),
    [anon_sym_Xmlport] = ACTIONS(4815),
    [anon_sym_XMLport] = ACTIONS(4815),
    [anon_sym_XMLPort] = ACTIONS(4815),
    [anon_sym_XmlPort] = ACTIONS(4815),
    [anon_sym_enum] = ACTIONS(4815),
    [anon_sym_ENUM] = ACTIONS(4815),
    [anon_sym_Enum] = ACTIONS(4815),
    [anon_sym_eNUM] = ACTIONS(4815),
    [anon_sym_eNum] = ACTIONS(4815),
    [anon_sym_ENum] = ACTIONS(4815),
    [sym_quoted_identifier] = ACTIONS(4817),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4817),
    [sym_integer] = ACTIONS(4815),
    [sym_continue_as_identifier] = ACTIONS(4817),
    [sym_preproc_open] = ACTIONS(4817),
    [sym_begin_keyword] = ACTIONS(4817),
  },
  [STATE(2375)] = {
    [sym_identifier] = ACTIONS(4547),
    [anon_sym_SEMI] = ACTIONS(4549),
    [anon_sym_DASH] = ACTIONS(4549),
    [aux_sym_boolean_token1] = ACTIONS(4547),
    [aux_sym_boolean_token2] = ACTIONS(4547),
    [sym_decimal] = ACTIONS(4547),
    [anon_sym_LPAREN] = ACTIONS(4549),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4547),
    [anon_sym_LBRACK] = ACTIONS(4549),
    [aux_sym_record_type_token1] = ACTIONS(4547),
    [aux_sym_basic_type_token21] = ACTIONS(4547),
    [aux_sym_basic_type_token22] = ACTIONS(4547),
    [aux_sym_basic_type_token48] = ACTIONS(4547),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4547),
    [anon_sym_POUNDif] = ACTIONS(4549),
    [anon_sym_POUNDIF] = ACTIONS(4549),
    [anon_sym_POUNDIf] = ACTIONS(4549),
    [anon_sym_not] = ACTIONS(4547),
    [anon_sym_NOT] = ACTIONS(4547),
    [anon_sym_Not] = ACTIONS(4547),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4547),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4547),
    [anon_sym_PLUS] = ACTIONS(4549),
    [sym_datetime_literal] = ACTIONS(4549),
    [sym_date_literal] = ACTIONS(4547),
    [sym_time_literal] = ACTIONS(4547),
    [sym_biginteger_literal] = ACTIONS(4549),
    [anon_sym_if] = ACTIONS(4547),
    [anon_sym_IF] = ACTIONS(4547),
    [anon_sym_If] = ACTIONS(4547),
    [anon_sym_else] = ACTIONS(4547),
    [anon_sym_ELSE] = ACTIONS(4547),
    [anon_sym_Else] = ACTIONS(4547),
    [anon_sym_case] = ACTIONS(4547),
    [anon_sym_CASE] = ACTIONS(4547),
    [anon_sym_Case] = ACTIONS(4547),
    [anon_sym_for] = ACTIONS(4547),
    [anon_sym_FOR] = ACTIONS(4547),
    [anon_sym_For] = ACTIONS(4547),
    [anon_sym_foreach] = ACTIONS(4547),
    [anon_sym_FOREACH] = ACTIONS(4547),
    [anon_sym_Foreach] = ACTIONS(4547),
    [anon_sym_while] = ACTIONS(4547),
    [anon_sym_WHILE] = ACTIONS(4547),
    [anon_sym_While] = ACTIONS(4547),
    [anon_sym_repeat] = ACTIONS(4547),
    [anon_sym_REPEAT] = ACTIONS(4547),
    [anon_sym_Repeat] = ACTIONS(4547),
    [anon_sym_exit] = ACTIONS(4547),
    [anon_sym_EXIT] = ACTIONS(4547),
    [anon_sym_Exit] = ACTIONS(4547),
    [anon_sym_continue] = ACTIONS(4547),
    [anon_sym_CONTINUE] = ACTIONS(4547),
    [anon_sym_Continue] = ACTIONS(4547),
    [anon_sym_break] = ACTIONS(4547),
    [anon_sym_BREAK] = ACTIONS(4547),
    [anon_sym_Break] = ACTIONS(4547),
    [anon_sym_with] = ACTIONS(4547),
    [anon_sym_WITH] = ACTIONS(4547),
    [anon_sym_With] = ACTIONS(4547),
    [sym_asserterror_keyword] = ACTIONS(4549),
    [sym_page_keyword] = ACTIONS(4547),
    [anon_sym_codeunit] = ACTIONS(4547),
    [anon_sym_CODEUNIT] = ACTIONS(4547),
    [anon_sym_Codeunit] = ACTIONS(4547),
    [anon_sym_CodeUnit] = ACTIONS(4547),
    [anon_sym_COdeunit] = ACTIONS(4547),
    [anon_sym_codeUnit] = ACTIONS(4547),
    [sym_report_keyword] = ACTIONS(4547),
    [sym_query_keyword] = ACTIONS(4547),
    [anon_sym_xmlport] = ACTIONS(4547),
    [anon_sym_XMLPORT] = ACTIONS(4547),
    [anon_sym_Xmlport] = ACTIONS(4547),
    [anon_sym_XMLport] = ACTIONS(4547),
    [anon_sym_XMLPort] = ACTIONS(4547),
    [anon_sym_XmlPort] = ACTIONS(4547),
    [anon_sym_enum] = ACTIONS(4547),
    [anon_sym_ENUM] = ACTIONS(4547),
    [anon_sym_Enum] = ACTIONS(4547),
    [anon_sym_eNUM] = ACTIONS(4547),
    [anon_sym_eNum] = ACTIONS(4547),
    [anon_sym_ENum] = ACTIONS(4547),
    [sym_quoted_identifier] = ACTIONS(4549),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4549),
    [sym_integer] = ACTIONS(4547),
    [sym_continue_as_identifier] = ACTIONS(4549),
    [sym_preproc_open] = ACTIONS(4549),
    [sym_end_keyword] = ACTIONS(4549),
  },
  [STATE(2376)] = {
    [sym_identifier] = ACTIONS(4551),
    [anon_sym_SEMI] = ACTIONS(4553),
    [anon_sym_DASH] = ACTIONS(4553),
    [aux_sym_boolean_token1] = ACTIONS(4551),
    [aux_sym_boolean_token2] = ACTIONS(4551),
    [sym_decimal] = ACTIONS(4551),
    [anon_sym_LPAREN] = ACTIONS(4553),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4551),
    [anon_sym_LBRACK] = ACTIONS(4553),
    [aux_sym_record_type_token1] = ACTIONS(4551),
    [aux_sym_basic_type_token21] = ACTIONS(4551),
    [aux_sym_basic_type_token22] = ACTIONS(4551),
    [aux_sym_basic_type_token48] = ACTIONS(4551),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4551),
    [anon_sym_POUNDif] = ACTIONS(4553),
    [anon_sym_POUNDIF] = ACTIONS(4553),
    [anon_sym_POUNDIf] = ACTIONS(4553),
    [anon_sym_not] = ACTIONS(4551),
    [anon_sym_NOT] = ACTIONS(4551),
    [anon_sym_Not] = ACTIONS(4551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4551),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4551),
    [anon_sym_PLUS] = ACTIONS(4553),
    [sym_datetime_literal] = ACTIONS(4553),
    [sym_date_literal] = ACTIONS(4551),
    [sym_time_literal] = ACTIONS(4551),
    [sym_biginteger_literal] = ACTIONS(4553),
    [anon_sym_if] = ACTIONS(4551),
    [anon_sym_IF] = ACTIONS(4551),
    [anon_sym_If] = ACTIONS(4551),
    [anon_sym_else] = ACTIONS(4551),
    [anon_sym_ELSE] = ACTIONS(4551),
    [anon_sym_Else] = ACTIONS(4551),
    [anon_sym_case] = ACTIONS(4551),
    [anon_sym_CASE] = ACTIONS(4551),
    [anon_sym_Case] = ACTIONS(4551),
    [anon_sym_for] = ACTIONS(4551),
    [anon_sym_FOR] = ACTIONS(4551),
    [anon_sym_For] = ACTIONS(4551),
    [anon_sym_foreach] = ACTIONS(4551),
    [anon_sym_FOREACH] = ACTIONS(4551),
    [anon_sym_Foreach] = ACTIONS(4551),
    [anon_sym_while] = ACTIONS(4551),
    [anon_sym_WHILE] = ACTIONS(4551),
    [anon_sym_While] = ACTIONS(4551),
    [anon_sym_repeat] = ACTIONS(4551),
    [anon_sym_REPEAT] = ACTIONS(4551),
    [anon_sym_Repeat] = ACTIONS(4551),
    [anon_sym_exit] = ACTIONS(4551),
    [anon_sym_EXIT] = ACTIONS(4551),
    [anon_sym_Exit] = ACTIONS(4551),
    [anon_sym_continue] = ACTIONS(4551),
    [anon_sym_CONTINUE] = ACTIONS(4551),
    [anon_sym_Continue] = ACTIONS(4551),
    [anon_sym_break] = ACTIONS(4551),
    [anon_sym_BREAK] = ACTIONS(4551),
    [anon_sym_Break] = ACTIONS(4551),
    [anon_sym_with] = ACTIONS(4551),
    [anon_sym_WITH] = ACTIONS(4551),
    [anon_sym_With] = ACTIONS(4551),
    [sym_asserterror_keyword] = ACTIONS(4553),
    [sym_page_keyword] = ACTIONS(4551),
    [anon_sym_codeunit] = ACTIONS(4551),
    [anon_sym_CODEUNIT] = ACTIONS(4551),
    [anon_sym_Codeunit] = ACTIONS(4551),
    [anon_sym_CodeUnit] = ACTIONS(4551),
    [anon_sym_COdeunit] = ACTIONS(4551),
    [anon_sym_codeUnit] = ACTIONS(4551),
    [sym_report_keyword] = ACTIONS(4551),
    [sym_query_keyword] = ACTIONS(4551),
    [anon_sym_xmlport] = ACTIONS(4551),
    [anon_sym_XMLPORT] = ACTIONS(4551),
    [anon_sym_Xmlport] = ACTIONS(4551),
    [anon_sym_XMLport] = ACTIONS(4551),
    [anon_sym_XMLPort] = ACTIONS(4551),
    [anon_sym_XmlPort] = ACTIONS(4551),
    [anon_sym_enum] = ACTIONS(4551),
    [anon_sym_ENUM] = ACTIONS(4551),
    [anon_sym_Enum] = ACTIONS(4551),
    [anon_sym_eNUM] = ACTIONS(4551),
    [anon_sym_eNum] = ACTIONS(4551),
    [anon_sym_ENum] = ACTIONS(4551),
    [sym_quoted_identifier] = ACTIONS(4553),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4553),
    [sym_integer] = ACTIONS(4551),
    [sym_continue_as_identifier] = ACTIONS(4553),
    [sym_preproc_open] = ACTIONS(4553),
    [sym_end_keyword] = ACTIONS(4553),
  },
  [STATE(2377)] = {
    [sym_identifier] = ACTIONS(4559),
    [anon_sym_SEMI] = ACTIONS(4561),
    [anon_sym_DASH] = ACTIONS(4561),
    [aux_sym_boolean_token1] = ACTIONS(4559),
    [aux_sym_boolean_token2] = ACTIONS(4559),
    [sym_decimal] = ACTIONS(4559),
    [anon_sym_LPAREN] = ACTIONS(4561),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4559),
    [anon_sym_LBRACK] = ACTIONS(4561),
    [aux_sym_record_type_token1] = ACTIONS(4559),
    [aux_sym_basic_type_token21] = ACTIONS(4559),
    [aux_sym_basic_type_token22] = ACTIONS(4559),
    [aux_sym_basic_type_token48] = ACTIONS(4559),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4559),
    [anon_sym_POUNDif] = ACTIONS(4561),
    [anon_sym_POUNDIF] = ACTIONS(4561),
    [anon_sym_POUNDIf] = ACTIONS(4561),
    [anon_sym_not] = ACTIONS(4559),
    [anon_sym_NOT] = ACTIONS(4559),
    [anon_sym_Not] = ACTIONS(4559),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4559),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4559),
    [anon_sym_PLUS] = ACTIONS(4561),
    [sym_datetime_literal] = ACTIONS(4561),
    [sym_date_literal] = ACTIONS(4559),
    [sym_time_literal] = ACTIONS(4559),
    [sym_biginteger_literal] = ACTIONS(4561),
    [anon_sym_if] = ACTIONS(4559),
    [anon_sym_IF] = ACTIONS(4559),
    [anon_sym_If] = ACTIONS(4559),
    [anon_sym_else] = ACTIONS(4559),
    [anon_sym_ELSE] = ACTIONS(4559),
    [anon_sym_Else] = ACTIONS(4559),
    [anon_sym_case] = ACTIONS(4559),
    [anon_sym_CASE] = ACTIONS(4559),
    [anon_sym_Case] = ACTIONS(4559),
    [anon_sym_for] = ACTIONS(4559),
    [anon_sym_FOR] = ACTIONS(4559),
    [anon_sym_For] = ACTIONS(4559),
    [anon_sym_foreach] = ACTIONS(4559),
    [anon_sym_FOREACH] = ACTIONS(4559),
    [anon_sym_Foreach] = ACTIONS(4559),
    [anon_sym_while] = ACTIONS(4559),
    [anon_sym_WHILE] = ACTIONS(4559),
    [anon_sym_While] = ACTIONS(4559),
    [anon_sym_repeat] = ACTIONS(4559),
    [anon_sym_REPEAT] = ACTIONS(4559),
    [anon_sym_Repeat] = ACTIONS(4559),
    [anon_sym_exit] = ACTIONS(4559),
    [anon_sym_EXIT] = ACTIONS(4559),
    [anon_sym_Exit] = ACTIONS(4559),
    [anon_sym_continue] = ACTIONS(4559),
    [anon_sym_CONTINUE] = ACTIONS(4559),
    [anon_sym_Continue] = ACTIONS(4559),
    [anon_sym_break] = ACTIONS(4559),
    [anon_sym_BREAK] = ACTIONS(4559),
    [anon_sym_Break] = ACTIONS(4559),
    [anon_sym_with] = ACTIONS(4559),
    [anon_sym_WITH] = ACTIONS(4559),
    [anon_sym_With] = ACTIONS(4559),
    [sym_asserterror_keyword] = ACTIONS(4561),
    [sym_page_keyword] = ACTIONS(4559),
    [anon_sym_codeunit] = ACTIONS(4559),
    [anon_sym_CODEUNIT] = ACTIONS(4559),
    [anon_sym_Codeunit] = ACTIONS(4559),
    [anon_sym_CodeUnit] = ACTIONS(4559),
    [anon_sym_COdeunit] = ACTIONS(4559),
    [anon_sym_codeUnit] = ACTIONS(4559),
    [sym_report_keyword] = ACTIONS(4559),
    [sym_query_keyword] = ACTIONS(4559),
    [anon_sym_xmlport] = ACTIONS(4559),
    [anon_sym_XMLPORT] = ACTIONS(4559),
    [anon_sym_Xmlport] = ACTIONS(4559),
    [anon_sym_XMLport] = ACTIONS(4559),
    [anon_sym_XMLPort] = ACTIONS(4559),
    [anon_sym_XmlPort] = ACTIONS(4559),
    [anon_sym_enum] = ACTIONS(4559),
    [anon_sym_ENUM] = ACTIONS(4559),
    [anon_sym_Enum] = ACTIONS(4559),
    [anon_sym_eNUM] = ACTIONS(4559),
    [anon_sym_eNum] = ACTIONS(4559),
    [anon_sym_ENum] = ACTIONS(4559),
    [sym_quoted_identifier] = ACTIONS(4561),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4561),
    [sym_integer] = ACTIONS(4559),
    [sym_continue_as_identifier] = ACTIONS(4561),
    [sym_preproc_open] = ACTIONS(4561),
    [sym_end_keyword] = ACTIONS(4561),
  },
  [STATE(2378)] = {
    [sym_identifier] = ACTIONS(4638),
    [anon_sym_SEMI] = ACTIONS(4640),
    [anon_sym_DASH] = ACTIONS(4640),
    [aux_sym_boolean_token1] = ACTIONS(4638),
    [aux_sym_boolean_token2] = ACTIONS(4638),
    [sym_decimal] = ACTIONS(4638),
    [anon_sym_LPAREN] = ACTIONS(4640),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4638),
    [anon_sym_LBRACK] = ACTIONS(4640),
    [aux_sym_record_type_token1] = ACTIONS(4638),
    [aux_sym_basic_type_token21] = ACTIONS(4638),
    [aux_sym_basic_type_token22] = ACTIONS(4638),
    [aux_sym_basic_type_token48] = ACTIONS(4638),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4638),
    [anon_sym_POUNDif] = ACTIONS(4640),
    [anon_sym_POUNDIF] = ACTIONS(4640),
    [anon_sym_POUNDIf] = ACTIONS(4640),
    [anon_sym_not] = ACTIONS(4638),
    [anon_sym_NOT] = ACTIONS(4638),
    [anon_sym_Not] = ACTIONS(4638),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4638),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4638),
    [anon_sym_PLUS] = ACTIONS(4640),
    [sym_datetime_literal] = ACTIONS(4640),
    [sym_date_literal] = ACTIONS(4638),
    [sym_time_literal] = ACTIONS(4638),
    [sym_biginteger_literal] = ACTIONS(4640),
    [anon_sym_if] = ACTIONS(4638),
    [anon_sym_IF] = ACTIONS(4638),
    [anon_sym_If] = ACTIONS(4638),
    [anon_sym_else] = ACTIONS(4638),
    [anon_sym_ELSE] = ACTIONS(4638),
    [anon_sym_Else] = ACTIONS(4638),
    [anon_sym_case] = ACTIONS(4638),
    [anon_sym_CASE] = ACTIONS(4638),
    [anon_sym_Case] = ACTIONS(4638),
    [anon_sym_for] = ACTIONS(4638),
    [anon_sym_FOR] = ACTIONS(4638),
    [anon_sym_For] = ACTIONS(4638),
    [anon_sym_foreach] = ACTIONS(4638),
    [anon_sym_FOREACH] = ACTIONS(4638),
    [anon_sym_Foreach] = ACTIONS(4638),
    [anon_sym_while] = ACTIONS(4638),
    [anon_sym_WHILE] = ACTIONS(4638),
    [anon_sym_While] = ACTIONS(4638),
    [anon_sym_repeat] = ACTIONS(4638),
    [anon_sym_REPEAT] = ACTIONS(4638),
    [anon_sym_Repeat] = ACTIONS(4638),
    [anon_sym_exit] = ACTIONS(4638),
    [anon_sym_EXIT] = ACTIONS(4638),
    [anon_sym_Exit] = ACTIONS(4638),
    [anon_sym_continue] = ACTIONS(4638),
    [anon_sym_CONTINUE] = ACTIONS(4638),
    [anon_sym_Continue] = ACTIONS(4638),
    [anon_sym_break] = ACTIONS(4638),
    [anon_sym_BREAK] = ACTIONS(4638),
    [anon_sym_Break] = ACTIONS(4638),
    [anon_sym_with] = ACTIONS(4638),
    [anon_sym_WITH] = ACTIONS(4638),
    [anon_sym_With] = ACTIONS(4638),
    [sym_asserterror_keyword] = ACTIONS(4640),
    [sym_page_keyword] = ACTIONS(4638),
    [anon_sym_codeunit] = ACTIONS(4638),
    [anon_sym_CODEUNIT] = ACTIONS(4638),
    [anon_sym_Codeunit] = ACTIONS(4638),
    [anon_sym_CodeUnit] = ACTIONS(4638),
    [anon_sym_COdeunit] = ACTIONS(4638),
    [anon_sym_codeUnit] = ACTIONS(4638),
    [sym_report_keyword] = ACTIONS(4638),
    [sym_query_keyword] = ACTIONS(4638),
    [anon_sym_xmlport] = ACTIONS(4638),
    [anon_sym_XMLPORT] = ACTIONS(4638),
    [anon_sym_Xmlport] = ACTIONS(4638),
    [anon_sym_XMLport] = ACTIONS(4638),
    [anon_sym_XMLPort] = ACTIONS(4638),
    [anon_sym_XmlPort] = ACTIONS(4638),
    [anon_sym_enum] = ACTIONS(4638),
    [anon_sym_ENUM] = ACTIONS(4638),
    [anon_sym_Enum] = ACTIONS(4638),
    [anon_sym_eNUM] = ACTIONS(4638),
    [anon_sym_eNum] = ACTIONS(4638),
    [anon_sym_ENum] = ACTIONS(4638),
    [sym_quoted_identifier] = ACTIONS(4640),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4640),
    [sym_integer] = ACTIONS(4638),
    [sym_continue_as_identifier] = ACTIONS(4640),
    [sym_preproc_open] = ACTIONS(4640),
    [sym_end_keyword] = ACTIONS(4640),
  },
  [STATE(2379)] = {
    [sym_identifier] = ACTIONS(4642),
    [anon_sym_SEMI] = ACTIONS(4644),
    [anon_sym_DASH] = ACTIONS(4644),
    [aux_sym_boolean_token1] = ACTIONS(4642),
    [aux_sym_boolean_token2] = ACTIONS(4642),
    [sym_decimal] = ACTIONS(4642),
    [anon_sym_LPAREN] = ACTIONS(4644),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4642),
    [anon_sym_LBRACK] = ACTIONS(4644),
    [aux_sym_record_type_token1] = ACTIONS(4642),
    [aux_sym_basic_type_token21] = ACTIONS(4642),
    [aux_sym_basic_type_token22] = ACTIONS(4642),
    [aux_sym_basic_type_token48] = ACTIONS(4642),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4642),
    [anon_sym_POUNDif] = ACTIONS(4644),
    [anon_sym_POUNDIF] = ACTIONS(4644),
    [anon_sym_POUNDIf] = ACTIONS(4644),
    [anon_sym_not] = ACTIONS(4642),
    [anon_sym_NOT] = ACTIONS(4642),
    [anon_sym_Not] = ACTIONS(4642),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4642),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4642),
    [anon_sym_PLUS] = ACTIONS(4644),
    [sym_datetime_literal] = ACTIONS(4644),
    [sym_date_literal] = ACTIONS(4642),
    [sym_time_literal] = ACTIONS(4642),
    [sym_biginteger_literal] = ACTIONS(4644),
    [anon_sym_if] = ACTIONS(4642),
    [anon_sym_IF] = ACTIONS(4642),
    [anon_sym_If] = ACTIONS(4642),
    [anon_sym_else] = ACTIONS(4642),
    [anon_sym_ELSE] = ACTIONS(4642),
    [anon_sym_Else] = ACTIONS(4642),
    [anon_sym_case] = ACTIONS(4642),
    [anon_sym_CASE] = ACTIONS(4642),
    [anon_sym_Case] = ACTIONS(4642),
    [anon_sym_for] = ACTIONS(4642),
    [anon_sym_FOR] = ACTIONS(4642),
    [anon_sym_For] = ACTIONS(4642),
    [anon_sym_foreach] = ACTIONS(4642),
    [anon_sym_FOREACH] = ACTIONS(4642),
    [anon_sym_Foreach] = ACTIONS(4642),
    [anon_sym_while] = ACTIONS(4642),
    [anon_sym_WHILE] = ACTIONS(4642),
    [anon_sym_While] = ACTIONS(4642),
    [anon_sym_repeat] = ACTIONS(4642),
    [anon_sym_REPEAT] = ACTIONS(4642),
    [anon_sym_Repeat] = ACTIONS(4642),
    [anon_sym_exit] = ACTIONS(4642),
    [anon_sym_EXIT] = ACTIONS(4642),
    [anon_sym_Exit] = ACTIONS(4642),
    [anon_sym_continue] = ACTIONS(4642),
    [anon_sym_CONTINUE] = ACTIONS(4642),
    [anon_sym_Continue] = ACTIONS(4642),
    [anon_sym_break] = ACTIONS(4642),
    [anon_sym_BREAK] = ACTIONS(4642),
    [anon_sym_Break] = ACTIONS(4642),
    [anon_sym_with] = ACTIONS(4642),
    [anon_sym_WITH] = ACTIONS(4642),
    [anon_sym_With] = ACTIONS(4642),
    [sym_asserterror_keyword] = ACTIONS(4644),
    [sym_page_keyword] = ACTIONS(4642),
    [anon_sym_codeunit] = ACTIONS(4642),
    [anon_sym_CODEUNIT] = ACTIONS(4642),
    [anon_sym_Codeunit] = ACTIONS(4642),
    [anon_sym_CodeUnit] = ACTIONS(4642),
    [anon_sym_COdeunit] = ACTIONS(4642),
    [anon_sym_codeUnit] = ACTIONS(4642),
    [sym_report_keyword] = ACTIONS(4642),
    [sym_query_keyword] = ACTIONS(4642),
    [anon_sym_xmlport] = ACTIONS(4642),
    [anon_sym_XMLPORT] = ACTIONS(4642),
    [anon_sym_Xmlport] = ACTIONS(4642),
    [anon_sym_XMLport] = ACTIONS(4642),
    [anon_sym_XMLPort] = ACTIONS(4642),
    [anon_sym_XmlPort] = ACTIONS(4642),
    [anon_sym_enum] = ACTIONS(4642),
    [anon_sym_ENUM] = ACTIONS(4642),
    [anon_sym_Enum] = ACTIONS(4642),
    [anon_sym_eNUM] = ACTIONS(4642),
    [anon_sym_eNum] = ACTIONS(4642),
    [anon_sym_ENum] = ACTIONS(4642),
    [sym_quoted_identifier] = ACTIONS(4644),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4644),
    [sym_integer] = ACTIONS(4642),
    [sym_continue_as_identifier] = ACTIONS(4644),
    [sym_preproc_open] = ACTIONS(4644),
    [sym_end_keyword] = ACTIONS(4644),
  },
  [STATE(2380)] = {
    [sym_identifier] = ACTIONS(4646),
    [anon_sym_SEMI] = ACTIONS(4648),
    [anon_sym_DASH] = ACTIONS(4648),
    [aux_sym_boolean_token1] = ACTIONS(4646),
    [aux_sym_boolean_token2] = ACTIONS(4646),
    [sym_decimal] = ACTIONS(4646),
    [anon_sym_LPAREN] = ACTIONS(4648),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4646),
    [anon_sym_LBRACK] = ACTIONS(4648),
    [aux_sym_record_type_token1] = ACTIONS(4646),
    [aux_sym_basic_type_token21] = ACTIONS(4646),
    [aux_sym_basic_type_token22] = ACTIONS(4646),
    [aux_sym_basic_type_token48] = ACTIONS(4646),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4646),
    [anon_sym_POUNDif] = ACTIONS(4648),
    [anon_sym_POUNDIF] = ACTIONS(4648),
    [anon_sym_POUNDIf] = ACTIONS(4648),
    [anon_sym_not] = ACTIONS(4646),
    [anon_sym_NOT] = ACTIONS(4646),
    [anon_sym_Not] = ACTIONS(4646),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4646),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4646),
    [anon_sym_PLUS] = ACTIONS(4648),
    [sym_datetime_literal] = ACTIONS(4648),
    [sym_date_literal] = ACTIONS(4646),
    [sym_time_literal] = ACTIONS(4646),
    [sym_biginteger_literal] = ACTIONS(4648),
    [anon_sym_if] = ACTIONS(4646),
    [anon_sym_IF] = ACTIONS(4646),
    [anon_sym_If] = ACTIONS(4646),
    [anon_sym_else] = ACTIONS(4646),
    [anon_sym_ELSE] = ACTIONS(4646),
    [anon_sym_Else] = ACTIONS(4646),
    [anon_sym_case] = ACTIONS(4646),
    [anon_sym_CASE] = ACTIONS(4646),
    [anon_sym_Case] = ACTIONS(4646),
    [anon_sym_for] = ACTIONS(4646),
    [anon_sym_FOR] = ACTIONS(4646),
    [anon_sym_For] = ACTIONS(4646),
    [anon_sym_foreach] = ACTIONS(4646),
    [anon_sym_FOREACH] = ACTIONS(4646),
    [anon_sym_Foreach] = ACTIONS(4646),
    [anon_sym_while] = ACTIONS(4646),
    [anon_sym_WHILE] = ACTIONS(4646),
    [anon_sym_While] = ACTIONS(4646),
    [anon_sym_repeat] = ACTIONS(4646),
    [anon_sym_REPEAT] = ACTIONS(4646),
    [anon_sym_Repeat] = ACTIONS(4646),
    [anon_sym_exit] = ACTIONS(4646),
    [anon_sym_EXIT] = ACTIONS(4646),
    [anon_sym_Exit] = ACTIONS(4646),
    [anon_sym_continue] = ACTIONS(4646),
    [anon_sym_CONTINUE] = ACTIONS(4646),
    [anon_sym_Continue] = ACTIONS(4646),
    [anon_sym_break] = ACTIONS(4646),
    [anon_sym_BREAK] = ACTIONS(4646),
    [anon_sym_Break] = ACTIONS(4646),
    [anon_sym_with] = ACTIONS(4646),
    [anon_sym_WITH] = ACTIONS(4646),
    [anon_sym_With] = ACTIONS(4646),
    [sym_asserterror_keyword] = ACTIONS(4648),
    [sym_page_keyword] = ACTIONS(4646),
    [anon_sym_codeunit] = ACTIONS(4646),
    [anon_sym_CODEUNIT] = ACTIONS(4646),
    [anon_sym_Codeunit] = ACTIONS(4646),
    [anon_sym_CodeUnit] = ACTIONS(4646),
    [anon_sym_COdeunit] = ACTIONS(4646),
    [anon_sym_codeUnit] = ACTIONS(4646),
    [sym_report_keyword] = ACTIONS(4646),
    [sym_query_keyword] = ACTIONS(4646),
    [anon_sym_xmlport] = ACTIONS(4646),
    [anon_sym_XMLPORT] = ACTIONS(4646),
    [anon_sym_Xmlport] = ACTIONS(4646),
    [anon_sym_XMLport] = ACTIONS(4646),
    [anon_sym_XMLPort] = ACTIONS(4646),
    [anon_sym_XmlPort] = ACTIONS(4646),
    [anon_sym_enum] = ACTIONS(4646),
    [anon_sym_ENUM] = ACTIONS(4646),
    [anon_sym_Enum] = ACTIONS(4646),
    [anon_sym_eNUM] = ACTIONS(4646),
    [anon_sym_eNum] = ACTIONS(4646),
    [anon_sym_ENum] = ACTIONS(4646),
    [sym_quoted_identifier] = ACTIONS(4648),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4648),
    [sym_integer] = ACTIONS(4646),
    [sym_continue_as_identifier] = ACTIONS(4648),
    [sym_preproc_open] = ACTIONS(4648),
    [sym_end_keyword] = ACTIONS(4648),
  },
  [STATE(2381)] = {
    [sym_identifier] = ACTIONS(4189),
    [anon_sym_SEMI] = ACTIONS(4191),
    [anon_sym_DASH] = ACTIONS(4191),
    [aux_sym_boolean_token1] = ACTIONS(4189),
    [aux_sym_boolean_token2] = ACTIONS(4189),
    [sym_decimal] = ACTIONS(4189),
    [anon_sym_LPAREN] = ACTIONS(4191),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4189),
    [anon_sym_LBRACK] = ACTIONS(4191),
    [aux_sym_record_type_token1] = ACTIONS(4189),
    [aux_sym_basic_type_token21] = ACTIONS(4189),
    [aux_sym_basic_type_token22] = ACTIONS(4189),
    [aux_sym_basic_type_token48] = ACTIONS(4189),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4189),
    [anon_sym_POUNDif] = ACTIONS(4191),
    [anon_sym_POUNDIF] = ACTIONS(4191),
    [anon_sym_POUNDIf] = ACTIONS(4191),
    [anon_sym_not] = ACTIONS(4189),
    [anon_sym_NOT] = ACTIONS(4189),
    [anon_sym_Not] = ACTIONS(4189),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4189),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4189),
    [anon_sym_PLUS] = ACTIONS(4191),
    [sym_datetime_literal] = ACTIONS(4191),
    [sym_date_literal] = ACTIONS(4189),
    [sym_time_literal] = ACTIONS(4189),
    [sym_biginteger_literal] = ACTIONS(4191),
    [anon_sym_if] = ACTIONS(4189),
    [anon_sym_IF] = ACTIONS(4189),
    [anon_sym_If] = ACTIONS(4189),
    [anon_sym_else] = ACTIONS(4189),
    [anon_sym_ELSE] = ACTIONS(4189),
    [anon_sym_Else] = ACTIONS(4189),
    [anon_sym_case] = ACTIONS(4189),
    [anon_sym_CASE] = ACTIONS(4189),
    [anon_sym_Case] = ACTIONS(4189),
    [anon_sym_for] = ACTIONS(4189),
    [anon_sym_FOR] = ACTIONS(4189),
    [anon_sym_For] = ACTIONS(4189),
    [anon_sym_foreach] = ACTIONS(4189),
    [anon_sym_FOREACH] = ACTIONS(4189),
    [anon_sym_Foreach] = ACTIONS(4189),
    [anon_sym_while] = ACTIONS(4189),
    [anon_sym_WHILE] = ACTIONS(4189),
    [anon_sym_While] = ACTIONS(4189),
    [anon_sym_repeat] = ACTIONS(4189),
    [anon_sym_REPEAT] = ACTIONS(4189),
    [anon_sym_Repeat] = ACTIONS(4189),
    [anon_sym_exit] = ACTIONS(4189),
    [anon_sym_EXIT] = ACTIONS(4189),
    [anon_sym_Exit] = ACTIONS(4189),
    [anon_sym_continue] = ACTIONS(4189),
    [anon_sym_CONTINUE] = ACTIONS(4189),
    [anon_sym_Continue] = ACTIONS(4189),
    [anon_sym_break] = ACTIONS(4189),
    [anon_sym_BREAK] = ACTIONS(4189),
    [anon_sym_Break] = ACTIONS(4189),
    [anon_sym_with] = ACTIONS(4189),
    [anon_sym_WITH] = ACTIONS(4189),
    [anon_sym_With] = ACTIONS(4189),
    [sym_asserterror_keyword] = ACTIONS(4191),
    [sym_page_keyword] = ACTIONS(4189),
    [anon_sym_codeunit] = ACTIONS(4189),
    [anon_sym_CODEUNIT] = ACTIONS(4189),
    [anon_sym_Codeunit] = ACTIONS(4189),
    [anon_sym_CodeUnit] = ACTIONS(4189),
    [anon_sym_COdeunit] = ACTIONS(4189),
    [anon_sym_codeUnit] = ACTIONS(4189),
    [sym_report_keyword] = ACTIONS(4189),
    [sym_query_keyword] = ACTIONS(4189),
    [anon_sym_xmlport] = ACTIONS(4189),
    [anon_sym_XMLPORT] = ACTIONS(4189),
    [anon_sym_Xmlport] = ACTIONS(4189),
    [anon_sym_XMLport] = ACTIONS(4189),
    [anon_sym_XMLPort] = ACTIONS(4189),
    [anon_sym_XmlPort] = ACTIONS(4189),
    [anon_sym_enum] = ACTIONS(4189),
    [anon_sym_ENUM] = ACTIONS(4189),
    [anon_sym_Enum] = ACTIONS(4189),
    [anon_sym_eNUM] = ACTIONS(4189),
    [anon_sym_eNum] = ACTIONS(4189),
    [anon_sym_ENum] = ACTIONS(4189),
    [sym_quoted_identifier] = ACTIONS(4191),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4191),
    [sym_integer] = ACTIONS(4189),
    [sym_continue_as_identifier] = ACTIONS(4191),
    [sym_preproc_open] = ACTIONS(4191),
    [sym_end_keyword] = ACTIONS(4191),
  },
  [STATE(2382)] = {
    [sym_identifier] = ACTIONS(4177),
    [anon_sym_SEMI] = ACTIONS(4179),
    [anon_sym_DASH] = ACTIONS(4179),
    [aux_sym_boolean_token1] = ACTIONS(4177),
    [aux_sym_boolean_token2] = ACTIONS(4177),
    [sym_decimal] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4179),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4177),
    [anon_sym_LBRACK] = ACTIONS(4179),
    [aux_sym_record_type_token1] = ACTIONS(4177),
    [aux_sym_basic_type_token21] = ACTIONS(4177),
    [aux_sym_basic_type_token22] = ACTIONS(4177),
    [aux_sym_basic_type_token48] = ACTIONS(4177),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4177),
    [anon_sym_POUNDif] = ACTIONS(4179),
    [anon_sym_POUNDIF] = ACTIONS(4179),
    [anon_sym_POUNDIf] = ACTIONS(4179),
    [anon_sym_not] = ACTIONS(4177),
    [anon_sym_NOT] = ACTIONS(4177),
    [anon_sym_Not] = ACTIONS(4177),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4177),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4179),
    [sym_datetime_literal] = ACTIONS(4179),
    [sym_date_literal] = ACTIONS(4177),
    [sym_time_literal] = ACTIONS(4177),
    [sym_biginteger_literal] = ACTIONS(4179),
    [anon_sym_if] = ACTIONS(4177),
    [anon_sym_IF] = ACTIONS(4177),
    [anon_sym_If] = ACTIONS(4177),
    [anon_sym_else] = ACTIONS(4177),
    [anon_sym_ELSE] = ACTIONS(4177),
    [anon_sym_Else] = ACTIONS(4177),
    [anon_sym_case] = ACTIONS(4177),
    [anon_sym_CASE] = ACTIONS(4177),
    [anon_sym_Case] = ACTIONS(4177),
    [anon_sym_for] = ACTIONS(4177),
    [anon_sym_FOR] = ACTIONS(4177),
    [anon_sym_For] = ACTIONS(4177),
    [anon_sym_foreach] = ACTIONS(4177),
    [anon_sym_FOREACH] = ACTIONS(4177),
    [anon_sym_Foreach] = ACTIONS(4177),
    [anon_sym_while] = ACTIONS(4177),
    [anon_sym_WHILE] = ACTIONS(4177),
    [anon_sym_While] = ACTIONS(4177),
    [anon_sym_repeat] = ACTIONS(4177),
    [anon_sym_REPEAT] = ACTIONS(4177),
    [anon_sym_Repeat] = ACTIONS(4177),
    [anon_sym_exit] = ACTIONS(4177),
    [anon_sym_EXIT] = ACTIONS(4177),
    [anon_sym_Exit] = ACTIONS(4177),
    [anon_sym_continue] = ACTIONS(4177),
    [anon_sym_CONTINUE] = ACTIONS(4177),
    [anon_sym_Continue] = ACTIONS(4177),
    [anon_sym_break] = ACTIONS(4177),
    [anon_sym_BREAK] = ACTIONS(4177),
    [anon_sym_Break] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4177),
    [anon_sym_WITH] = ACTIONS(4177),
    [anon_sym_With] = ACTIONS(4177),
    [sym_asserterror_keyword] = ACTIONS(4179),
    [sym_page_keyword] = ACTIONS(4177),
    [anon_sym_codeunit] = ACTIONS(4177),
    [anon_sym_CODEUNIT] = ACTIONS(4177),
    [anon_sym_Codeunit] = ACTIONS(4177),
    [anon_sym_CodeUnit] = ACTIONS(4177),
    [anon_sym_COdeunit] = ACTIONS(4177),
    [anon_sym_codeUnit] = ACTIONS(4177),
    [sym_report_keyword] = ACTIONS(4177),
    [sym_query_keyword] = ACTIONS(4177),
    [anon_sym_xmlport] = ACTIONS(4177),
    [anon_sym_XMLPORT] = ACTIONS(4177),
    [anon_sym_Xmlport] = ACTIONS(4177),
    [anon_sym_XMLport] = ACTIONS(4177),
    [anon_sym_XMLPort] = ACTIONS(4177),
    [anon_sym_XmlPort] = ACTIONS(4177),
    [anon_sym_enum] = ACTIONS(4177),
    [anon_sym_ENUM] = ACTIONS(4177),
    [anon_sym_Enum] = ACTIONS(4177),
    [anon_sym_eNUM] = ACTIONS(4177),
    [anon_sym_eNum] = ACTIONS(4177),
    [anon_sym_ENum] = ACTIONS(4177),
    [sym_quoted_identifier] = ACTIONS(4179),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4179),
    [sym_integer] = ACTIONS(4177),
    [sym_continue_as_identifier] = ACTIONS(4179),
    [sym_preproc_open] = ACTIONS(4179),
    [sym_end_keyword] = ACTIONS(4179),
  },
  [STATE(2383)] = {
    [sym_identifier] = ACTIONS(4650),
    [anon_sym_SEMI] = ACTIONS(4652),
    [anon_sym_DASH] = ACTIONS(4652),
    [aux_sym_boolean_token1] = ACTIONS(4650),
    [aux_sym_boolean_token2] = ACTIONS(4650),
    [sym_decimal] = ACTIONS(4650),
    [anon_sym_LPAREN] = ACTIONS(4652),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4650),
    [anon_sym_LBRACK] = ACTIONS(4652),
    [aux_sym_record_type_token1] = ACTIONS(4650),
    [aux_sym_basic_type_token21] = ACTIONS(4650),
    [aux_sym_basic_type_token22] = ACTIONS(4650),
    [aux_sym_basic_type_token48] = ACTIONS(4650),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4650),
    [anon_sym_POUNDif] = ACTIONS(4652),
    [anon_sym_POUNDIF] = ACTIONS(4652),
    [anon_sym_POUNDIf] = ACTIONS(4652),
    [anon_sym_not] = ACTIONS(4650),
    [anon_sym_NOT] = ACTIONS(4650),
    [anon_sym_Not] = ACTIONS(4650),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4650),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4650),
    [anon_sym_PLUS] = ACTIONS(4652),
    [sym_datetime_literal] = ACTIONS(4652),
    [sym_date_literal] = ACTIONS(4650),
    [sym_time_literal] = ACTIONS(4650),
    [sym_biginteger_literal] = ACTIONS(4652),
    [anon_sym_if] = ACTIONS(4650),
    [anon_sym_IF] = ACTIONS(4650),
    [anon_sym_If] = ACTIONS(4650),
    [anon_sym_else] = ACTIONS(4650),
    [anon_sym_ELSE] = ACTIONS(4650),
    [anon_sym_Else] = ACTIONS(4650),
    [anon_sym_case] = ACTIONS(4650),
    [anon_sym_CASE] = ACTIONS(4650),
    [anon_sym_Case] = ACTIONS(4650),
    [anon_sym_for] = ACTIONS(4650),
    [anon_sym_FOR] = ACTIONS(4650),
    [anon_sym_For] = ACTIONS(4650),
    [anon_sym_foreach] = ACTIONS(4650),
    [anon_sym_FOREACH] = ACTIONS(4650),
    [anon_sym_Foreach] = ACTIONS(4650),
    [anon_sym_while] = ACTIONS(4650),
    [anon_sym_WHILE] = ACTIONS(4650),
    [anon_sym_While] = ACTIONS(4650),
    [anon_sym_repeat] = ACTIONS(4650),
    [anon_sym_REPEAT] = ACTIONS(4650),
    [anon_sym_Repeat] = ACTIONS(4650),
    [anon_sym_exit] = ACTIONS(4650),
    [anon_sym_EXIT] = ACTIONS(4650),
    [anon_sym_Exit] = ACTIONS(4650),
    [anon_sym_continue] = ACTIONS(4650),
    [anon_sym_CONTINUE] = ACTIONS(4650),
    [anon_sym_Continue] = ACTIONS(4650),
    [anon_sym_break] = ACTIONS(4650),
    [anon_sym_BREAK] = ACTIONS(4650),
    [anon_sym_Break] = ACTIONS(4650),
    [anon_sym_with] = ACTIONS(4650),
    [anon_sym_WITH] = ACTIONS(4650),
    [anon_sym_With] = ACTIONS(4650),
    [sym_asserterror_keyword] = ACTIONS(4652),
    [sym_page_keyword] = ACTIONS(4650),
    [anon_sym_codeunit] = ACTIONS(4650),
    [anon_sym_CODEUNIT] = ACTIONS(4650),
    [anon_sym_Codeunit] = ACTIONS(4650),
    [anon_sym_CodeUnit] = ACTIONS(4650),
    [anon_sym_COdeunit] = ACTIONS(4650),
    [anon_sym_codeUnit] = ACTIONS(4650),
    [sym_report_keyword] = ACTIONS(4650),
    [sym_query_keyword] = ACTIONS(4650),
    [anon_sym_xmlport] = ACTIONS(4650),
    [anon_sym_XMLPORT] = ACTIONS(4650),
    [anon_sym_Xmlport] = ACTIONS(4650),
    [anon_sym_XMLport] = ACTIONS(4650),
    [anon_sym_XMLPort] = ACTIONS(4650),
    [anon_sym_XmlPort] = ACTIONS(4650),
    [anon_sym_enum] = ACTIONS(4650),
    [anon_sym_ENUM] = ACTIONS(4650),
    [anon_sym_Enum] = ACTIONS(4650),
    [anon_sym_eNUM] = ACTIONS(4650),
    [anon_sym_eNum] = ACTIONS(4650),
    [anon_sym_ENum] = ACTIONS(4650),
    [sym_quoted_identifier] = ACTIONS(4652),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4652),
    [sym_integer] = ACTIONS(4650),
    [sym_continue_as_identifier] = ACTIONS(4652),
    [sym_preproc_open] = ACTIONS(4652),
    [sym_end_keyword] = ACTIONS(4652),
  },
  [STATE(2384)] = {
    [sym_identifier] = ACTIONS(4646),
    [anon_sym_SEMI] = ACTIONS(4648),
    [anon_sym_DASH] = ACTIONS(4648),
    [aux_sym_boolean_token1] = ACTIONS(4646),
    [aux_sym_boolean_token2] = ACTIONS(4646),
    [sym_decimal] = ACTIONS(4646),
    [anon_sym_LPAREN] = ACTIONS(4648),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4646),
    [anon_sym_LBRACK] = ACTIONS(4648),
    [aux_sym_record_type_token1] = ACTIONS(4646),
    [aux_sym_basic_type_token21] = ACTIONS(4646),
    [aux_sym_basic_type_token22] = ACTIONS(4646),
    [aux_sym_basic_type_token48] = ACTIONS(4646),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4646),
    [anon_sym_POUNDif] = ACTIONS(4648),
    [anon_sym_POUNDIF] = ACTIONS(4648),
    [anon_sym_POUNDIf] = ACTIONS(4648),
    [anon_sym_not] = ACTIONS(4646),
    [anon_sym_NOT] = ACTIONS(4646),
    [anon_sym_Not] = ACTIONS(4646),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4646),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4646),
    [anon_sym_PLUS] = ACTIONS(4648),
    [sym_datetime_literal] = ACTIONS(4648),
    [sym_date_literal] = ACTIONS(4646),
    [sym_time_literal] = ACTIONS(4646),
    [sym_biginteger_literal] = ACTIONS(4648),
    [anon_sym_if] = ACTIONS(4646),
    [anon_sym_IF] = ACTIONS(4646),
    [anon_sym_If] = ACTIONS(4646),
    [anon_sym_else] = ACTIONS(4646),
    [anon_sym_ELSE] = ACTIONS(4646),
    [anon_sym_Else] = ACTIONS(4646),
    [anon_sym_case] = ACTIONS(4646),
    [anon_sym_CASE] = ACTIONS(4646),
    [anon_sym_Case] = ACTIONS(4646),
    [anon_sym_for] = ACTIONS(4646),
    [anon_sym_FOR] = ACTIONS(4646),
    [anon_sym_For] = ACTIONS(4646),
    [anon_sym_foreach] = ACTIONS(4646),
    [anon_sym_FOREACH] = ACTIONS(4646),
    [anon_sym_Foreach] = ACTIONS(4646),
    [anon_sym_while] = ACTIONS(4646),
    [anon_sym_WHILE] = ACTIONS(4646),
    [anon_sym_While] = ACTIONS(4646),
    [anon_sym_repeat] = ACTIONS(4646),
    [anon_sym_REPEAT] = ACTIONS(4646),
    [anon_sym_Repeat] = ACTIONS(4646),
    [anon_sym_exit] = ACTIONS(4646),
    [anon_sym_EXIT] = ACTIONS(4646),
    [anon_sym_Exit] = ACTIONS(4646),
    [anon_sym_continue] = ACTIONS(4646),
    [anon_sym_CONTINUE] = ACTIONS(4646),
    [anon_sym_Continue] = ACTIONS(4646),
    [anon_sym_break] = ACTIONS(4646),
    [anon_sym_BREAK] = ACTIONS(4646),
    [anon_sym_Break] = ACTIONS(4646),
    [anon_sym_with] = ACTIONS(4646),
    [anon_sym_WITH] = ACTIONS(4646),
    [anon_sym_With] = ACTIONS(4646),
    [sym_asserterror_keyword] = ACTIONS(4648),
    [sym_page_keyword] = ACTIONS(4646),
    [anon_sym_codeunit] = ACTIONS(4646),
    [anon_sym_CODEUNIT] = ACTIONS(4646),
    [anon_sym_Codeunit] = ACTIONS(4646),
    [anon_sym_CodeUnit] = ACTIONS(4646),
    [anon_sym_COdeunit] = ACTIONS(4646),
    [anon_sym_codeUnit] = ACTIONS(4646),
    [sym_report_keyword] = ACTIONS(4646),
    [sym_query_keyword] = ACTIONS(4646),
    [anon_sym_xmlport] = ACTIONS(4646),
    [anon_sym_XMLPORT] = ACTIONS(4646),
    [anon_sym_Xmlport] = ACTIONS(4646),
    [anon_sym_XMLport] = ACTIONS(4646),
    [anon_sym_XMLPort] = ACTIONS(4646),
    [anon_sym_XmlPort] = ACTIONS(4646),
    [anon_sym_enum] = ACTIONS(4646),
    [anon_sym_ENUM] = ACTIONS(4646),
    [anon_sym_Enum] = ACTIONS(4646),
    [anon_sym_eNUM] = ACTIONS(4646),
    [anon_sym_eNum] = ACTIONS(4646),
    [anon_sym_ENum] = ACTIONS(4646),
    [sym_quoted_identifier] = ACTIONS(4648),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4648),
    [sym_integer] = ACTIONS(4646),
    [sym_continue_as_identifier] = ACTIONS(4648),
    [sym_preproc_open] = ACTIONS(4648),
    [sym_end_keyword] = ACTIONS(4648),
  },
  [STATE(2385)] = {
    [sym_identifier] = ACTIONS(4764),
    [anon_sym_SEMI] = ACTIONS(4766),
    [anon_sym_DASH] = ACTIONS(4766),
    [aux_sym_boolean_token1] = ACTIONS(4764),
    [aux_sym_boolean_token2] = ACTIONS(4764),
    [sym_decimal] = ACTIONS(4764),
    [anon_sym_LPAREN] = ACTIONS(4766),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4764),
    [anon_sym_LBRACK] = ACTIONS(4766),
    [aux_sym_record_type_token1] = ACTIONS(4764),
    [aux_sym_basic_type_token21] = ACTIONS(4764),
    [aux_sym_basic_type_token22] = ACTIONS(4764),
    [aux_sym_basic_type_token48] = ACTIONS(4764),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4764),
    [anon_sym_POUNDif] = ACTIONS(4766),
    [anon_sym_POUNDIF] = ACTIONS(4766),
    [anon_sym_POUNDIf] = ACTIONS(4766),
    [anon_sym_not] = ACTIONS(4764),
    [anon_sym_NOT] = ACTIONS(4764),
    [anon_sym_Not] = ACTIONS(4764),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4764),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4764),
    [anon_sym_PLUS] = ACTIONS(4766),
    [sym_datetime_literal] = ACTIONS(4766),
    [sym_date_literal] = ACTIONS(4764),
    [sym_time_literal] = ACTIONS(4764),
    [sym_biginteger_literal] = ACTIONS(4766),
    [anon_sym_if] = ACTIONS(4764),
    [anon_sym_IF] = ACTIONS(4764),
    [anon_sym_If] = ACTIONS(4764),
    [anon_sym_else] = ACTIONS(4764),
    [anon_sym_ELSE] = ACTIONS(4764),
    [anon_sym_Else] = ACTIONS(4764),
    [anon_sym_case] = ACTIONS(4764),
    [anon_sym_CASE] = ACTIONS(4764),
    [anon_sym_Case] = ACTIONS(4764),
    [anon_sym_for] = ACTIONS(4764),
    [anon_sym_FOR] = ACTIONS(4764),
    [anon_sym_For] = ACTIONS(4764),
    [anon_sym_foreach] = ACTIONS(4764),
    [anon_sym_FOREACH] = ACTIONS(4764),
    [anon_sym_Foreach] = ACTIONS(4764),
    [anon_sym_while] = ACTIONS(4764),
    [anon_sym_WHILE] = ACTIONS(4764),
    [anon_sym_While] = ACTIONS(4764),
    [anon_sym_repeat] = ACTIONS(4764),
    [anon_sym_REPEAT] = ACTIONS(4764),
    [anon_sym_Repeat] = ACTIONS(4764),
    [anon_sym_exit] = ACTIONS(4764),
    [anon_sym_EXIT] = ACTIONS(4764),
    [anon_sym_Exit] = ACTIONS(4764),
    [anon_sym_continue] = ACTIONS(4764),
    [anon_sym_CONTINUE] = ACTIONS(4764),
    [anon_sym_Continue] = ACTIONS(4764),
    [anon_sym_break] = ACTIONS(4764),
    [anon_sym_BREAK] = ACTIONS(4764),
    [anon_sym_Break] = ACTIONS(4764),
    [anon_sym_with] = ACTIONS(4764),
    [anon_sym_WITH] = ACTIONS(4764),
    [anon_sym_With] = ACTIONS(4764),
    [sym_asserterror_keyword] = ACTIONS(4766),
    [sym_page_keyword] = ACTIONS(4764),
    [anon_sym_codeunit] = ACTIONS(4764),
    [anon_sym_CODEUNIT] = ACTIONS(4764),
    [anon_sym_Codeunit] = ACTIONS(4764),
    [anon_sym_CodeUnit] = ACTIONS(4764),
    [anon_sym_COdeunit] = ACTIONS(4764),
    [anon_sym_codeUnit] = ACTIONS(4764),
    [sym_report_keyword] = ACTIONS(4764),
    [sym_query_keyword] = ACTIONS(4764),
    [anon_sym_xmlport] = ACTIONS(4764),
    [anon_sym_XMLPORT] = ACTIONS(4764),
    [anon_sym_Xmlport] = ACTIONS(4764),
    [anon_sym_XMLport] = ACTIONS(4764),
    [anon_sym_XMLPort] = ACTIONS(4764),
    [anon_sym_XmlPort] = ACTIONS(4764),
    [anon_sym_enum] = ACTIONS(4764),
    [anon_sym_ENUM] = ACTIONS(4764),
    [anon_sym_Enum] = ACTIONS(4764),
    [anon_sym_eNUM] = ACTIONS(4764),
    [anon_sym_eNum] = ACTIONS(4764),
    [anon_sym_ENum] = ACTIONS(4764),
    [sym_quoted_identifier] = ACTIONS(4766),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4766),
    [sym_integer] = ACTIONS(4764),
    [sym_continue_as_identifier] = ACTIONS(4766),
    [sym_preproc_open] = ACTIONS(4766),
    [sym_end_keyword] = ACTIONS(4766),
  },
  [STATE(2386)] = {
    [sym_identifier] = ACTIONS(4189),
    [anon_sym_SEMI] = ACTIONS(4191),
    [anon_sym_DASH] = ACTIONS(4191),
    [aux_sym_boolean_token1] = ACTIONS(4189),
    [aux_sym_boolean_token2] = ACTIONS(4189),
    [sym_decimal] = ACTIONS(4189),
    [anon_sym_LPAREN] = ACTIONS(4191),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4189),
    [anon_sym_LBRACK] = ACTIONS(4191),
    [aux_sym_record_type_token1] = ACTIONS(4189),
    [aux_sym_basic_type_token21] = ACTIONS(4189),
    [aux_sym_basic_type_token22] = ACTIONS(4189),
    [aux_sym_basic_type_token48] = ACTIONS(4189),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4189),
    [anon_sym_POUNDif] = ACTIONS(4191),
    [anon_sym_POUNDIF] = ACTIONS(4191),
    [anon_sym_POUNDIf] = ACTIONS(4191),
    [anon_sym_not] = ACTIONS(4189),
    [anon_sym_NOT] = ACTIONS(4189),
    [anon_sym_Not] = ACTIONS(4189),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4189),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4189),
    [anon_sym_PLUS] = ACTIONS(4191),
    [sym_datetime_literal] = ACTIONS(4191),
    [sym_date_literal] = ACTIONS(4189),
    [sym_time_literal] = ACTIONS(4189),
    [sym_biginteger_literal] = ACTIONS(4191),
    [anon_sym_if] = ACTIONS(4189),
    [anon_sym_IF] = ACTIONS(4189),
    [anon_sym_If] = ACTIONS(4189),
    [anon_sym_else] = ACTIONS(4189),
    [anon_sym_ELSE] = ACTIONS(4189),
    [anon_sym_Else] = ACTIONS(4189),
    [anon_sym_case] = ACTIONS(4189),
    [anon_sym_CASE] = ACTIONS(4189),
    [anon_sym_Case] = ACTIONS(4189),
    [anon_sym_for] = ACTIONS(4189),
    [anon_sym_FOR] = ACTIONS(4189),
    [anon_sym_For] = ACTIONS(4189),
    [anon_sym_foreach] = ACTIONS(4189),
    [anon_sym_FOREACH] = ACTIONS(4189),
    [anon_sym_Foreach] = ACTIONS(4189),
    [anon_sym_while] = ACTIONS(4189),
    [anon_sym_WHILE] = ACTIONS(4189),
    [anon_sym_While] = ACTIONS(4189),
    [anon_sym_repeat] = ACTIONS(4189),
    [anon_sym_REPEAT] = ACTIONS(4189),
    [anon_sym_Repeat] = ACTIONS(4189),
    [anon_sym_exit] = ACTIONS(4189),
    [anon_sym_EXIT] = ACTIONS(4189),
    [anon_sym_Exit] = ACTIONS(4189),
    [anon_sym_continue] = ACTIONS(4189),
    [anon_sym_CONTINUE] = ACTIONS(4189),
    [anon_sym_Continue] = ACTIONS(4189),
    [anon_sym_break] = ACTIONS(4189),
    [anon_sym_BREAK] = ACTIONS(4189),
    [anon_sym_Break] = ACTIONS(4189),
    [anon_sym_with] = ACTIONS(4189),
    [anon_sym_WITH] = ACTIONS(4189),
    [anon_sym_With] = ACTIONS(4189),
    [sym_asserterror_keyword] = ACTIONS(4191),
    [sym_page_keyword] = ACTIONS(4189),
    [anon_sym_codeunit] = ACTIONS(4189),
    [anon_sym_CODEUNIT] = ACTIONS(4189),
    [anon_sym_Codeunit] = ACTIONS(4189),
    [anon_sym_CodeUnit] = ACTIONS(4189),
    [anon_sym_COdeunit] = ACTIONS(4189),
    [anon_sym_codeUnit] = ACTIONS(4189),
    [sym_report_keyword] = ACTIONS(4189),
    [sym_query_keyword] = ACTIONS(4189),
    [anon_sym_xmlport] = ACTIONS(4189),
    [anon_sym_XMLPORT] = ACTIONS(4189),
    [anon_sym_Xmlport] = ACTIONS(4189),
    [anon_sym_XMLport] = ACTIONS(4189),
    [anon_sym_XMLPort] = ACTIONS(4189),
    [anon_sym_XmlPort] = ACTIONS(4189),
    [anon_sym_enum] = ACTIONS(4189),
    [anon_sym_ENUM] = ACTIONS(4189),
    [anon_sym_Enum] = ACTIONS(4189),
    [anon_sym_eNUM] = ACTIONS(4189),
    [anon_sym_eNum] = ACTIONS(4189),
    [anon_sym_ENum] = ACTIONS(4189),
    [sym_quoted_identifier] = ACTIONS(4191),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4191),
    [sym_integer] = ACTIONS(4189),
    [sym_continue_as_identifier] = ACTIONS(4191),
    [sym_preproc_open] = ACTIONS(4191),
    [sym_end_keyword] = ACTIONS(4191),
  },
  [STATE(2387)] = {
    [sym_identifier] = ACTIONS(4177),
    [anon_sym_SEMI] = ACTIONS(4179),
    [anon_sym_DASH] = ACTIONS(4179),
    [aux_sym_boolean_token1] = ACTIONS(4177),
    [aux_sym_boolean_token2] = ACTIONS(4177),
    [sym_decimal] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4179),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4177),
    [anon_sym_LBRACK] = ACTIONS(4179),
    [aux_sym_record_type_token1] = ACTIONS(4177),
    [aux_sym_basic_type_token21] = ACTIONS(4177),
    [aux_sym_basic_type_token22] = ACTIONS(4177),
    [aux_sym_basic_type_token48] = ACTIONS(4177),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4177),
    [anon_sym_POUNDif] = ACTIONS(4179),
    [anon_sym_POUNDIF] = ACTIONS(4179),
    [anon_sym_POUNDIf] = ACTIONS(4179),
    [anon_sym_not] = ACTIONS(4177),
    [anon_sym_NOT] = ACTIONS(4177),
    [anon_sym_Not] = ACTIONS(4177),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4177),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4179),
    [sym_datetime_literal] = ACTIONS(4179),
    [sym_date_literal] = ACTIONS(4177),
    [sym_time_literal] = ACTIONS(4177),
    [sym_biginteger_literal] = ACTIONS(4179),
    [anon_sym_if] = ACTIONS(4177),
    [anon_sym_IF] = ACTIONS(4177),
    [anon_sym_If] = ACTIONS(4177),
    [anon_sym_else] = ACTIONS(4177),
    [anon_sym_ELSE] = ACTIONS(4177),
    [anon_sym_Else] = ACTIONS(4177),
    [anon_sym_case] = ACTIONS(4177),
    [anon_sym_CASE] = ACTIONS(4177),
    [anon_sym_Case] = ACTIONS(4177),
    [anon_sym_for] = ACTIONS(4177),
    [anon_sym_FOR] = ACTIONS(4177),
    [anon_sym_For] = ACTIONS(4177),
    [anon_sym_foreach] = ACTIONS(4177),
    [anon_sym_FOREACH] = ACTIONS(4177),
    [anon_sym_Foreach] = ACTIONS(4177),
    [anon_sym_while] = ACTIONS(4177),
    [anon_sym_WHILE] = ACTIONS(4177),
    [anon_sym_While] = ACTIONS(4177),
    [anon_sym_repeat] = ACTIONS(4177),
    [anon_sym_REPEAT] = ACTIONS(4177),
    [anon_sym_Repeat] = ACTIONS(4177),
    [anon_sym_exit] = ACTIONS(4177),
    [anon_sym_EXIT] = ACTIONS(4177),
    [anon_sym_Exit] = ACTIONS(4177),
    [anon_sym_continue] = ACTIONS(4177),
    [anon_sym_CONTINUE] = ACTIONS(4177),
    [anon_sym_Continue] = ACTIONS(4177),
    [anon_sym_break] = ACTIONS(4177),
    [anon_sym_BREAK] = ACTIONS(4177),
    [anon_sym_Break] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4177),
    [anon_sym_WITH] = ACTIONS(4177),
    [anon_sym_With] = ACTIONS(4177),
    [sym_asserterror_keyword] = ACTIONS(4179),
    [sym_page_keyword] = ACTIONS(4177),
    [anon_sym_codeunit] = ACTIONS(4177),
    [anon_sym_CODEUNIT] = ACTIONS(4177),
    [anon_sym_Codeunit] = ACTIONS(4177),
    [anon_sym_CodeUnit] = ACTIONS(4177),
    [anon_sym_COdeunit] = ACTIONS(4177),
    [anon_sym_codeUnit] = ACTIONS(4177),
    [sym_report_keyword] = ACTIONS(4177),
    [sym_query_keyword] = ACTIONS(4177),
    [anon_sym_xmlport] = ACTIONS(4177),
    [anon_sym_XMLPORT] = ACTIONS(4177),
    [anon_sym_Xmlport] = ACTIONS(4177),
    [anon_sym_XMLport] = ACTIONS(4177),
    [anon_sym_XMLPort] = ACTIONS(4177),
    [anon_sym_XmlPort] = ACTIONS(4177),
    [anon_sym_enum] = ACTIONS(4177),
    [anon_sym_ENUM] = ACTIONS(4177),
    [anon_sym_Enum] = ACTIONS(4177),
    [anon_sym_eNUM] = ACTIONS(4177),
    [anon_sym_eNum] = ACTIONS(4177),
    [anon_sym_ENum] = ACTIONS(4177),
    [sym_quoted_identifier] = ACTIONS(4179),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4179),
    [sym_integer] = ACTIONS(4177),
    [sym_continue_as_identifier] = ACTIONS(4179),
    [sym_preproc_open] = ACTIONS(4179),
    [sym_end_keyword] = ACTIONS(4179),
  },
  [STATE(2388)] = {
    [sym_identifier] = ACTIONS(4768),
    [anon_sym_SEMI] = ACTIONS(4770),
    [anon_sym_DASH] = ACTIONS(4770),
    [aux_sym_boolean_token1] = ACTIONS(4768),
    [aux_sym_boolean_token2] = ACTIONS(4768),
    [sym_decimal] = ACTIONS(4768),
    [anon_sym_LPAREN] = ACTIONS(4770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4768),
    [anon_sym_LBRACK] = ACTIONS(4770),
    [aux_sym_record_type_token1] = ACTIONS(4768),
    [aux_sym_basic_type_token21] = ACTIONS(4768),
    [aux_sym_basic_type_token22] = ACTIONS(4768),
    [aux_sym_basic_type_token48] = ACTIONS(4768),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4768),
    [anon_sym_POUNDif] = ACTIONS(4770),
    [anon_sym_POUNDIF] = ACTIONS(4770),
    [anon_sym_POUNDIf] = ACTIONS(4770),
    [anon_sym_not] = ACTIONS(4768),
    [anon_sym_NOT] = ACTIONS(4768),
    [anon_sym_Not] = ACTIONS(4768),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4768),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4768),
    [anon_sym_PLUS] = ACTIONS(4770),
    [sym_datetime_literal] = ACTIONS(4770),
    [sym_date_literal] = ACTIONS(4768),
    [sym_time_literal] = ACTIONS(4768),
    [sym_biginteger_literal] = ACTIONS(4770),
    [anon_sym_if] = ACTIONS(4768),
    [anon_sym_IF] = ACTIONS(4768),
    [anon_sym_If] = ACTIONS(4768),
    [anon_sym_else] = ACTIONS(4768),
    [anon_sym_ELSE] = ACTIONS(4768),
    [anon_sym_Else] = ACTIONS(4768),
    [anon_sym_case] = ACTIONS(4768),
    [anon_sym_CASE] = ACTIONS(4768),
    [anon_sym_Case] = ACTIONS(4768),
    [anon_sym_for] = ACTIONS(4768),
    [anon_sym_FOR] = ACTIONS(4768),
    [anon_sym_For] = ACTIONS(4768),
    [anon_sym_foreach] = ACTIONS(4768),
    [anon_sym_FOREACH] = ACTIONS(4768),
    [anon_sym_Foreach] = ACTIONS(4768),
    [anon_sym_while] = ACTIONS(4768),
    [anon_sym_WHILE] = ACTIONS(4768),
    [anon_sym_While] = ACTIONS(4768),
    [anon_sym_repeat] = ACTIONS(4768),
    [anon_sym_REPEAT] = ACTIONS(4768),
    [anon_sym_Repeat] = ACTIONS(4768),
    [anon_sym_exit] = ACTIONS(4768),
    [anon_sym_EXIT] = ACTIONS(4768),
    [anon_sym_Exit] = ACTIONS(4768),
    [anon_sym_continue] = ACTIONS(4768),
    [anon_sym_CONTINUE] = ACTIONS(4768),
    [anon_sym_Continue] = ACTIONS(4768),
    [anon_sym_break] = ACTIONS(4768),
    [anon_sym_BREAK] = ACTIONS(4768),
    [anon_sym_Break] = ACTIONS(4768),
    [anon_sym_with] = ACTIONS(4768),
    [anon_sym_WITH] = ACTIONS(4768),
    [anon_sym_With] = ACTIONS(4768),
    [sym_asserterror_keyword] = ACTIONS(4770),
    [sym_page_keyword] = ACTIONS(4768),
    [anon_sym_codeunit] = ACTIONS(4768),
    [anon_sym_CODEUNIT] = ACTIONS(4768),
    [anon_sym_Codeunit] = ACTIONS(4768),
    [anon_sym_CodeUnit] = ACTIONS(4768),
    [anon_sym_COdeunit] = ACTIONS(4768),
    [anon_sym_codeUnit] = ACTIONS(4768),
    [sym_report_keyword] = ACTIONS(4768),
    [sym_query_keyword] = ACTIONS(4768),
    [anon_sym_xmlport] = ACTIONS(4768),
    [anon_sym_XMLPORT] = ACTIONS(4768),
    [anon_sym_Xmlport] = ACTIONS(4768),
    [anon_sym_XMLport] = ACTIONS(4768),
    [anon_sym_XMLPort] = ACTIONS(4768),
    [anon_sym_XmlPort] = ACTIONS(4768),
    [anon_sym_enum] = ACTIONS(4768),
    [anon_sym_ENUM] = ACTIONS(4768),
    [anon_sym_Enum] = ACTIONS(4768),
    [anon_sym_eNUM] = ACTIONS(4768),
    [anon_sym_eNum] = ACTIONS(4768),
    [anon_sym_ENum] = ACTIONS(4768),
    [sym_quoted_identifier] = ACTIONS(4770),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4770),
    [sym_integer] = ACTIONS(4768),
    [sym_continue_as_identifier] = ACTIONS(4770),
    [sym_preproc_open] = ACTIONS(4770),
    [sym_end_keyword] = ACTIONS(4770),
  },
  [STATE(2389)] = {
    [sym_identifier] = ACTIONS(4573),
    [anon_sym_SEMI] = ACTIONS(4575),
    [anon_sym_DASH] = ACTIONS(4575),
    [aux_sym_boolean_token1] = ACTIONS(4573),
    [aux_sym_boolean_token2] = ACTIONS(4573),
    [sym_decimal] = ACTIONS(4573),
    [anon_sym_LPAREN] = ACTIONS(4575),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4573),
    [anon_sym_LBRACK] = ACTIONS(4575),
    [aux_sym_record_type_token1] = ACTIONS(4573),
    [aux_sym_basic_type_token21] = ACTIONS(4573),
    [aux_sym_basic_type_token22] = ACTIONS(4573),
    [aux_sym_basic_type_token48] = ACTIONS(4573),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4573),
    [anon_sym_POUNDif] = ACTIONS(4575),
    [anon_sym_POUNDIF] = ACTIONS(4575),
    [anon_sym_POUNDIf] = ACTIONS(4575),
    [anon_sym_not] = ACTIONS(4573),
    [anon_sym_NOT] = ACTIONS(4573),
    [anon_sym_Not] = ACTIONS(4573),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4573),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4573),
    [anon_sym_PLUS] = ACTIONS(4575),
    [sym_datetime_literal] = ACTIONS(4575),
    [sym_date_literal] = ACTIONS(4573),
    [sym_time_literal] = ACTIONS(4573),
    [sym_biginteger_literal] = ACTIONS(4575),
    [anon_sym_if] = ACTIONS(4573),
    [anon_sym_IF] = ACTIONS(4573),
    [anon_sym_If] = ACTIONS(4573),
    [anon_sym_else] = ACTIONS(4573),
    [anon_sym_ELSE] = ACTIONS(4573),
    [anon_sym_Else] = ACTIONS(4573),
    [anon_sym_case] = ACTIONS(4573),
    [anon_sym_CASE] = ACTIONS(4573),
    [anon_sym_Case] = ACTIONS(4573),
    [anon_sym_for] = ACTIONS(4573),
    [anon_sym_FOR] = ACTIONS(4573),
    [anon_sym_For] = ACTIONS(4573),
    [anon_sym_foreach] = ACTIONS(4573),
    [anon_sym_FOREACH] = ACTIONS(4573),
    [anon_sym_Foreach] = ACTIONS(4573),
    [anon_sym_while] = ACTIONS(4573),
    [anon_sym_WHILE] = ACTIONS(4573),
    [anon_sym_While] = ACTIONS(4573),
    [anon_sym_repeat] = ACTIONS(4573),
    [anon_sym_REPEAT] = ACTIONS(4573),
    [anon_sym_Repeat] = ACTIONS(4573),
    [anon_sym_exit] = ACTIONS(4573),
    [anon_sym_EXIT] = ACTIONS(4573),
    [anon_sym_Exit] = ACTIONS(4573),
    [anon_sym_continue] = ACTIONS(4573),
    [anon_sym_CONTINUE] = ACTIONS(4573),
    [anon_sym_Continue] = ACTIONS(4573),
    [anon_sym_break] = ACTIONS(4573),
    [anon_sym_BREAK] = ACTIONS(4573),
    [anon_sym_Break] = ACTIONS(4573),
    [anon_sym_with] = ACTIONS(4573),
    [anon_sym_WITH] = ACTIONS(4573),
    [anon_sym_With] = ACTIONS(4573),
    [sym_asserterror_keyword] = ACTIONS(4575),
    [sym_page_keyword] = ACTIONS(4573),
    [anon_sym_codeunit] = ACTIONS(4573),
    [anon_sym_CODEUNIT] = ACTIONS(4573),
    [anon_sym_Codeunit] = ACTIONS(4573),
    [anon_sym_CodeUnit] = ACTIONS(4573),
    [anon_sym_COdeunit] = ACTIONS(4573),
    [anon_sym_codeUnit] = ACTIONS(4573),
    [sym_report_keyword] = ACTIONS(4573),
    [sym_query_keyword] = ACTIONS(4573),
    [anon_sym_xmlport] = ACTIONS(4573),
    [anon_sym_XMLPORT] = ACTIONS(4573),
    [anon_sym_Xmlport] = ACTIONS(4573),
    [anon_sym_XMLport] = ACTIONS(4573),
    [anon_sym_XMLPort] = ACTIONS(4573),
    [anon_sym_XmlPort] = ACTIONS(4573),
    [anon_sym_enum] = ACTIONS(4573),
    [anon_sym_ENUM] = ACTIONS(4573),
    [anon_sym_Enum] = ACTIONS(4573),
    [anon_sym_eNUM] = ACTIONS(4573),
    [anon_sym_eNum] = ACTIONS(4573),
    [anon_sym_ENum] = ACTIONS(4573),
    [sym_quoted_identifier] = ACTIONS(4575),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4575),
    [sym_integer] = ACTIONS(4573),
    [sym_continue_as_identifier] = ACTIONS(4575),
    [sym_preproc_open] = ACTIONS(4575),
    [sym_end_keyword] = ACTIONS(4575),
  },
  [STATE(2390)] = {
    [sym_identifier] = ACTIONS(4784),
    [anon_sym_SEMI] = ACTIONS(4786),
    [anon_sym_DASH] = ACTIONS(4786),
    [aux_sym_boolean_token1] = ACTIONS(4784),
    [aux_sym_boolean_token2] = ACTIONS(4784),
    [sym_decimal] = ACTIONS(4784),
    [anon_sym_LPAREN] = ACTIONS(4786),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4784),
    [anon_sym_LBRACK] = ACTIONS(4786),
    [aux_sym_record_type_token1] = ACTIONS(4784),
    [aux_sym_basic_type_token21] = ACTIONS(4784),
    [aux_sym_basic_type_token22] = ACTIONS(4784),
    [aux_sym_basic_type_token48] = ACTIONS(4784),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4784),
    [anon_sym_POUNDif] = ACTIONS(4786),
    [anon_sym_POUNDIF] = ACTIONS(4786),
    [anon_sym_POUNDIf] = ACTIONS(4786),
    [anon_sym_not] = ACTIONS(4784),
    [anon_sym_NOT] = ACTIONS(4784),
    [anon_sym_Not] = ACTIONS(4784),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4784),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4784),
    [anon_sym_PLUS] = ACTIONS(4786),
    [sym_datetime_literal] = ACTIONS(4786),
    [sym_date_literal] = ACTIONS(4784),
    [sym_time_literal] = ACTIONS(4784),
    [sym_biginteger_literal] = ACTIONS(4786),
    [anon_sym_if] = ACTIONS(4784),
    [anon_sym_IF] = ACTIONS(4784),
    [anon_sym_If] = ACTIONS(4784),
    [anon_sym_else] = ACTIONS(4784),
    [anon_sym_ELSE] = ACTIONS(4784),
    [anon_sym_Else] = ACTIONS(4784),
    [anon_sym_case] = ACTIONS(4784),
    [anon_sym_CASE] = ACTIONS(4784),
    [anon_sym_Case] = ACTIONS(4784),
    [anon_sym_for] = ACTIONS(4784),
    [anon_sym_FOR] = ACTIONS(4784),
    [anon_sym_For] = ACTIONS(4784),
    [anon_sym_foreach] = ACTIONS(4784),
    [anon_sym_FOREACH] = ACTIONS(4784),
    [anon_sym_Foreach] = ACTIONS(4784),
    [anon_sym_while] = ACTIONS(4784),
    [anon_sym_WHILE] = ACTIONS(4784),
    [anon_sym_While] = ACTIONS(4784),
    [anon_sym_repeat] = ACTIONS(4784),
    [anon_sym_REPEAT] = ACTIONS(4784),
    [anon_sym_Repeat] = ACTIONS(4784),
    [anon_sym_exit] = ACTIONS(4784),
    [anon_sym_EXIT] = ACTIONS(4784),
    [anon_sym_Exit] = ACTIONS(4784),
    [anon_sym_continue] = ACTIONS(4784),
    [anon_sym_CONTINUE] = ACTIONS(4784),
    [anon_sym_Continue] = ACTIONS(4784),
    [anon_sym_break] = ACTIONS(4784),
    [anon_sym_BREAK] = ACTIONS(4784),
    [anon_sym_Break] = ACTIONS(4784),
    [anon_sym_with] = ACTIONS(4784),
    [anon_sym_WITH] = ACTIONS(4784),
    [anon_sym_With] = ACTIONS(4784),
    [sym_asserterror_keyword] = ACTIONS(4786),
    [sym_page_keyword] = ACTIONS(4784),
    [anon_sym_codeunit] = ACTIONS(4784),
    [anon_sym_CODEUNIT] = ACTIONS(4784),
    [anon_sym_Codeunit] = ACTIONS(4784),
    [anon_sym_CodeUnit] = ACTIONS(4784),
    [anon_sym_COdeunit] = ACTIONS(4784),
    [anon_sym_codeUnit] = ACTIONS(4784),
    [sym_report_keyword] = ACTIONS(4784),
    [sym_query_keyword] = ACTIONS(4784),
    [anon_sym_xmlport] = ACTIONS(4784),
    [anon_sym_XMLPORT] = ACTIONS(4784),
    [anon_sym_Xmlport] = ACTIONS(4784),
    [anon_sym_XMLport] = ACTIONS(4784),
    [anon_sym_XMLPort] = ACTIONS(4784),
    [anon_sym_XmlPort] = ACTIONS(4784),
    [anon_sym_enum] = ACTIONS(4784),
    [anon_sym_ENUM] = ACTIONS(4784),
    [anon_sym_Enum] = ACTIONS(4784),
    [anon_sym_eNUM] = ACTIONS(4784),
    [anon_sym_eNum] = ACTIONS(4784),
    [anon_sym_ENum] = ACTIONS(4784),
    [sym_quoted_identifier] = ACTIONS(4786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4786),
    [sym_integer] = ACTIONS(4784),
    [sym_continue_as_identifier] = ACTIONS(4786),
    [sym_preproc_open] = ACTIONS(4786),
    [sym_end_keyword] = ACTIONS(4786),
  },
  [STATE(2391)] = {
    [sym_identifier] = ACTIONS(4654),
    [anon_sym_SEMI] = ACTIONS(4656),
    [anon_sym_DASH] = ACTIONS(4656),
    [aux_sym_boolean_token1] = ACTIONS(4654),
    [aux_sym_boolean_token2] = ACTIONS(4654),
    [sym_decimal] = ACTIONS(4654),
    [anon_sym_LPAREN] = ACTIONS(4656),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4654),
    [anon_sym_LBRACK] = ACTIONS(4656),
    [aux_sym_record_type_token1] = ACTIONS(4654),
    [aux_sym_basic_type_token21] = ACTIONS(4654),
    [aux_sym_basic_type_token22] = ACTIONS(4654),
    [aux_sym_basic_type_token48] = ACTIONS(4654),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4654),
    [anon_sym_POUNDif] = ACTIONS(4656),
    [anon_sym_POUNDIF] = ACTIONS(4656),
    [anon_sym_POUNDIf] = ACTIONS(4656),
    [anon_sym_not] = ACTIONS(4654),
    [anon_sym_NOT] = ACTIONS(4654),
    [anon_sym_Not] = ACTIONS(4654),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4654),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4654),
    [anon_sym_PLUS] = ACTIONS(4656),
    [sym_datetime_literal] = ACTIONS(4656),
    [sym_date_literal] = ACTIONS(4654),
    [sym_time_literal] = ACTIONS(4654),
    [sym_biginteger_literal] = ACTIONS(4656),
    [anon_sym_if] = ACTIONS(4654),
    [anon_sym_IF] = ACTIONS(4654),
    [anon_sym_If] = ACTIONS(4654),
    [anon_sym_else] = ACTIONS(4654),
    [anon_sym_ELSE] = ACTIONS(4654),
    [anon_sym_Else] = ACTIONS(4654),
    [anon_sym_case] = ACTIONS(4654),
    [anon_sym_CASE] = ACTIONS(4654),
    [anon_sym_Case] = ACTIONS(4654),
    [anon_sym_for] = ACTIONS(4654),
    [anon_sym_FOR] = ACTIONS(4654),
    [anon_sym_For] = ACTIONS(4654),
    [anon_sym_foreach] = ACTIONS(4654),
    [anon_sym_FOREACH] = ACTIONS(4654),
    [anon_sym_Foreach] = ACTIONS(4654),
    [anon_sym_while] = ACTIONS(4654),
    [anon_sym_WHILE] = ACTIONS(4654),
    [anon_sym_While] = ACTIONS(4654),
    [anon_sym_repeat] = ACTIONS(4654),
    [anon_sym_REPEAT] = ACTIONS(4654),
    [anon_sym_Repeat] = ACTIONS(4654),
    [anon_sym_exit] = ACTIONS(4654),
    [anon_sym_EXIT] = ACTIONS(4654),
    [anon_sym_Exit] = ACTIONS(4654),
    [anon_sym_continue] = ACTIONS(4654),
    [anon_sym_CONTINUE] = ACTIONS(4654),
    [anon_sym_Continue] = ACTIONS(4654),
    [anon_sym_break] = ACTIONS(4654),
    [anon_sym_BREAK] = ACTIONS(4654),
    [anon_sym_Break] = ACTIONS(4654),
    [anon_sym_with] = ACTIONS(4654),
    [anon_sym_WITH] = ACTIONS(4654),
    [anon_sym_With] = ACTIONS(4654),
    [sym_asserterror_keyword] = ACTIONS(4656),
    [sym_page_keyword] = ACTIONS(4654),
    [anon_sym_codeunit] = ACTIONS(4654),
    [anon_sym_CODEUNIT] = ACTIONS(4654),
    [anon_sym_Codeunit] = ACTIONS(4654),
    [anon_sym_CodeUnit] = ACTIONS(4654),
    [anon_sym_COdeunit] = ACTIONS(4654),
    [anon_sym_codeUnit] = ACTIONS(4654),
    [sym_report_keyword] = ACTIONS(4654),
    [sym_query_keyword] = ACTIONS(4654),
    [anon_sym_xmlport] = ACTIONS(4654),
    [anon_sym_XMLPORT] = ACTIONS(4654),
    [anon_sym_Xmlport] = ACTIONS(4654),
    [anon_sym_XMLport] = ACTIONS(4654),
    [anon_sym_XMLPort] = ACTIONS(4654),
    [anon_sym_XmlPort] = ACTIONS(4654),
    [anon_sym_enum] = ACTIONS(4654),
    [anon_sym_ENUM] = ACTIONS(4654),
    [anon_sym_Enum] = ACTIONS(4654),
    [anon_sym_eNUM] = ACTIONS(4654),
    [anon_sym_eNum] = ACTIONS(4654),
    [anon_sym_ENum] = ACTIONS(4654),
    [sym_quoted_identifier] = ACTIONS(4656),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4656),
    [sym_integer] = ACTIONS(4654),
    [sym_continue_as_identifier] = ACTIONS(4656),
    [sym_preproc_open] = ACTIONS(4656),
    [sym_end_keyword] = ACTIONS(4656),
  },
  [STATE(2392)] = {
    [sym_identifier] = ACTIONS(4668),
    [anon_sym_SEMI] = ACTIONS(4670),
    [anon_sym_DASH] = ACTIONS(4670),
    [aux_sym_boolean_token1] = ACTIONS(4668),
    [aux_sym_boolean_token2] = ACTIONS(4668),
    [sym_decimal] = ACTIONS(4668),
    [anon_sym_LPAREN] = ACTIONS(4670),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4668),
    [anon_sym_LBRACK] = ACTIONS(4670),
    [aux_sym_record_type_token1] = ACTIONS(4668),
    [aux_sym_basic_type_token21] = ACTIONS(4668),
    [aux_sym_basic_type_token22] = ACTIONS(4668),
    [aux_sym_basic_type_token48] = ACTIONS(4668),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4668),
    [anon_sym_POUNDif] = ACTIONS(4670),
    [anon_sym_POUNDIF] = ACTIONS(4670),
    [anon_sym_POUNDIf] = ACTIONS(4670),
    [anon_sym_not] = ACTIONS(4668),
    [anon_sym_NOT] = ACTIONS(4668),
    [anon_sym_Not] = ACTIONS(4668),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4668),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4668),
    [anon_sym_PLUS] = ACTIONS(4670),
    [sym_datetime_literal] = ACTIONS(4670),
    [sym_date_literal] = ACTIONS(4668),
    [sym_time_literal] = ACTIONS(4668),
    [sym_biginteger_literal] = ACTIONS(4670),
    [anon_sym_if] = ACTIONS(4668),
    [anon_sym_IF] = ACTIONS(4668),
    [anon_sym_If] = ACTIONS(4668),
    [anon_sym_else] = ACTIONS(4668),
    [anon_sym_ELSE] = ACTIONS(4668),
    [anon_sym_Else] = ACTIONS(4668),
    [anon_sym_case] = ACTIONS(4668),
    [anon_sym_CASE] = ACTIONS(4668),
    [anon_sym_Case] = ACTIONS(4668),
    [anon_sym_for] = ACTIONS(4668),
    [anon_sym_FOR] = ACTIONS(4668),
    [anon_sym_For] = ACTIONS(4668),
    [anon_sym_foreach] = ACTIONS(4668),
    [anon_sym_FOREACH] = ACTIONS(4668),
    [anon_sym_Foreach] = ACTIONS(4668),
    [anon_sym_while] = ACTIONS(4668),
    [anon_sym_WHILE] = ACTIONS(4668),
    [anon_sym_While] = ACTIONS(4668),
    [anon_sym_repeat] = ACTIONS(4668),
    [anon_sym_REPEAT] = ACTIONS(4668),
    [anon_sym_Repeat] = ACTIONS(4668),
    [anon_sym_exit] = ACTIONS(4668),
    [anon_sym_EXIT] = ACTIONS(4668),
    [anon_sym_Exit] = ACTIONS(4668),
    [anon_sym_continue] = ACTIONS(4668),
    [anon_sym_CONTINUE] = ACTIONS(4668),
    [anon_sym_Continue] = ACTIONS(4668),
    [anon_sym_break] = ACTIONS(4668),
    [anon_sym_BREAK] = ACTIONS(4668),
    [anon_sym_Break] = ACTIONS(4668),
    [anon_sym_with] = ACTIONS(4668),
    [anon_sym_WITH] = ACTIONS(4668),
    [anon_sym_With] = ACTIONS(4668),
    [sym_asserterror_keyword] = ACTIONS(4670),
    [sym_page_keyword] = ACTIONS(4668),
    [anon_sym_codeunit] = ACTIONS(4668),
    [anon_sym_CODEUNIT] = ACTIONS(4668),
    [anon_sym_Codeunit] = ACTIONS(4668),
    [anon_sym_CodeUnit] = ACTIONS(4668),
    [anon_sym_COdeunit] = ACTIONS(4668),
    [anon_sym_codeUnit] = ACTIONS(4668),
    [sym_report_keyword] = ACTIONS(4668),
    [sym_query_keyword] = ACTIONS(4668),
    [anon_sym_xmlport] = ACTIONS(4668),
    [anon_sym_XMLPORT] = ACTIONS(4668),
    [anon_sym_Xmlport] = ACTIONS(4668),
    [anon_sym_XMLport] = ACTIONS(4668),
    [anon_sym_XMLPort] = ACTIONS(4668),
    [anon_sym_XmlPort] = ACTIONS(4668),
    [anon_sym_enum] = ACTIONS(4668),
    [anon_sym_ENUM] = ACTIONS(4668),
    [anon_sym_Enum] = ACTIONS(4668),
    [anon_sym_eNUM] = ACTIONS(4668),
    [anon_sym_eNum] = ACTIONS(4668),
    [anon_sym_ENum] = ACTIONS(4668),
    [sym_quoted_identifier] = ACTIONS(4670),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4670),
    [sym_integer] = ACTIONS(4668),
    [sym_continue_as_identifier] = ACTIONS(4670),
    [sym_preproc_open] = ACTIONS(4670),
    [sym_end_keyword] = ACTIONS(4670),
  },
  [STATE(2393)] = {
    [sym_identifier] = ACTIONS(4373),
    [anon_sym_SEMI] = ACTIONS(5475),
    [anon_sym_DASH] = ACTIONS(4377),
    [aux_sym_boolean_token1] = ACTIONS(4373),
    [aux_sym_boolean_token2] = ACTIONS(4373),
    [sym_decimal] = ACTIONS(4373),
    [anon_sym_LPAREN] = ACTIONS(4377),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4373),
    [anon_sym_LBRACK] = ACTIONS(4377),
    [aux_sym_record_type_token1] = ACTIONS(4373),
    [aux_sym_basic_type_token21] = ACTIONS(4373),
    [aux_sym_basic_type_token22] = ACTIONS(4373),
    [aux_sym_basic_type_token48] = ACTIONS(4373),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4373),
    [anon_sym_POUNDif] = ACTIONS(4377),
    [anon_sym_POUNDIF] = ACTIONS(4377),
    [anon_sym_POUNDIf] = ACTIONS(4377),
    [anon_sym_not] = ACTIONS(4373),
    [anon_sym_NOT] = ACTIONS(4373),
    [anon_sym_Not] = ACTIONS(4373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4373),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4373),
    [anon_sym_PLUS] = ACTIONS(4377),
    [sym_datetime_literal] = ACTIONS(4377),
    [sym_date_literal] = ACTIONS(4373),
    [sym_time_literal] = ACTIONS(4373),
    [sym_biginteger_literal] = ACTIONS(4377),
    [anon_sym_if] = ACTIONS(4373),
    [anon_sym_IF] = ACTIONS(4373),
    [anon_sym_If] = ACTIONS(4373),
    [anon_sym_else] = ACTIONS(4373),
    [anon_sym_ELSE] = ACTIONS(4373),
    [anon_sym_Else] = ACTIONS(4373),
    [anon_sym_case] = ACTIONS(4373),
    [anon_sym_CASE] = ACTIONS(4373),
    [anon_sym_Case] = ACTIONS(4373),
    [anon_sym_for] = ACTIONS(4373),
    [anon_sym_FOR] = ACTIONS(4373),
    [anon_sym_For] = ACTIONS(4373),
    [anon_sym_foreach] = ACTIONS(4373),
    [anon_sym_FOREACH] = ACTIONS(4373),
    [anon_sym_Foreach] = ACTIONS(4373),
    [anon_sym_while] = ACTIONS(4373),
    [anon_sym_WHILE] = ACTIONS(4373),
    [anon_sym_While] = ACTIONS(4373),
    [anon_sym_repeat] = ACTIONS(4373),
    [anon_sym_REPEAT] = ACTIONS(4373),
    [anon_sym_Repeat] = ACTIONS(4373),
    [anon_sym_exit] = ACTIONS(4373),
    [anon_sym_EXIT] = ACTIONS(4373),
    [anon_sym_Exit] = ACTIONS(4373),
    [anon_sym_continue] = ACTIONS(4373),
    [anon_sym_CONTINUE] = ACTIONS(4373),
    [anon_sym_Continue] = ACTIONS(4373),
    [anon_sym_break] = ACTIONS(4373),
    [anon_sym_BREAK] = ACTIONS(4373),
    [anon_sym_Break] = ACTIONS(4373),
    [anon_sym_with] = ACTIONS(4373),
    [anon_sym_WITH] = ACTIONS(4373),
    [anon_sym_With] = ACTIONS(4373),
    [sym_asserterror_keyword] = ACTIONS(4377),
    [sym_page_keyword] = ACTIONS(4373),
    [anon_sym_codeunit] = ACTIONS(4373),
    [anon_sym_CODEUNIT] = ACTIONS(4373),
    [anon_sym_Codeunit] = ACTIONS(4373),
    [anon_sym_CodeUnit] = ACTIONS(4373),
    [anon_sym_COdeunit] = ACTIONS(4373),
    [anon_sym_codeUnit] = ACTIONS(4373),
    [sym_report_keyword] = ACTIONS(4373),
    [sym_query_keyword] = ACTIONS(4373),
    [anon_sym_xmlport] = ACTIONS(4373),
    [anon_sym_XMLPORT] = ACTIONS(4373),
    [anon_sym_Xmlport] = ACTIONS(4373),
    [anon_sym_XMLport] = ACTIONS(4373),
    [anon_sym_XMLPort] = ACTIONS(4373),
    [anon_sym_XmlPort] = ACTIONS(4373),
    [anon_sym_enum] = ACTIONS(4373),
    [anon_sym_ENUM] = ACTIONS(4373),
    [anon_sym_Enum] = ACTIONS(4373),
    [anon_sym_eNUM] = ACTIONS(4373),
    [anon_sym_eNum] = ACTIONS(4373),
    [anon_sym_ENum] = ACTIONS(4373),
    [sym_quoted_identifier] = ACTIONS(4377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4377),
    [sym_integer] = ACTIONS(4373),
    [sym_continue_as_identifier] = ACTIONS(4377),
    [sym_preproc_open] = ACTIONS(4377),
    [sym_end_keyword] = ACTIONS(4377),
  },
  [STATE(2394)] = {
    [sym_identifier] = ACTIONS(4373),
    [anon_sym_SEMI] = ACTIONS(4377),
    [anon_sym_DASH] = ACTIONS(4377),
    [aux_sym_boolean_token1] = ACTIONS(4373),
    [aux_sym_boolean_token2] = ACTIONS(4373),
    [sym_decimal] = ACTIONS(4373),
    [anon_sym_LPAREN] = ACTIONS(4377),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4373),
    [anon_sym_LBRACK] = ACTIONS(4377),
    [aux_sym_record_type_token1] = ACTIONS(4373),
    [aux_sym_basic_type_token21] = ACTIONS(4373),
    [aux_sym_basic_type_token22] = ACTIONS(4373),
    [aux_sym_basic_type_token48] = ACTIONS(4373),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4373),
    [anon_sym_POUNDif] = ACTIONS(4377),
    [anon_sym_POUNDIF] = ACTIONS(4377),
    [anon_sym_POUNDIf] = ACTIONS(4377),
    [anon_sym_not] = ACTIONS(4373),
    [anon_sym_NOT] = ACTIONS(4373),
    [anon_sym_Not] = ACTIONS(4373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4373),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4373),
    [anon_sym_PLUS] = ACTIONS(4377),
    [sym_datetime_literal] = ACTIONS(4377),
    [sym_date_literal] = ACTIONS(4373),
    [sym_time_literal] = ACTIONS(4373),
    [sym_biginteger_literal] = ACTIONS(4377),
    [anon_sym_if] = ACTIONS(4373),
    [anon_sym_IF] = ACTIONS(4373),
    [anon_sym_If] = ACTIONS(4373),
    [anon_sym_else] = ACTIONS(4373),
    [anon_sym_ELSE] = ACTIONS(4373),
    [anon_sym_Else] = ACTIONS(4373),
    [anon_sym_case] = ACTIONS(4373),
    [anon_sym_CASE] = ACTIONS(4373),
    [anon_sym_Case] = ACTIONS(4373),
    [anon_sym_for] = ACTIONS(4373),
    [anon_sym_FOR] = ACTIONS(4373),
    [anon_sym_For] = ACTIONS(4373),
    [anon_sym_foreach] = ACTIONS(4373),
    [anon_sym_FOREACH] = ACTIONS(4373),
    [anon_sym_Foreach] = ACTIONS(4373),
    [anon_sym_while] = ACTIONS(4373),
    [anon_sym_WHILE] = ACTIONS(4373),
    [anon_sym_While] = ACTIONS(4373),
    [anon_sym_repeat] = ACTIONS(4373),
    [anon_sym_REPEAT] = ACTIONS(4373),
    [anon_sym_Repeat] = ACTIONS(4373),
    [anon_sym_exit] = ACTIONS(4373),
    [anon_sym_EXIT] = ACTIONS(4373),
    [anon_sym_Exit] = ACTIONS(4373),
    [anon_sym_continue] = ACTIONS(4373),
    [anon_sym_CONTINUE] = ACTIONS(4373),
    [anon_sym_Continue] = ACTIONS(4373),
    [anon_sym_break] = ACTIONS(4373),
    [anon_sym_BREAK] = ACTIONS(4373),
    [anon_sym_Break] = ACTIONS(4373),
    [anon_sym_with] = ACTIONS(4373),
    [anon_sym_WITH] = ACTIONS(4373),
    [anon_sym_With] = ACTIONS(4373),
    [sym_asserterror_keyword] = ACTIONS(4377),
    [sym_page_keyword] = ACTIONS(4373),
    [anon_sym_codeunit] = ACTIONS(4373),
    [anon_sym_CODEUNIT] = ACTIONS(4373),
    [anon_sym_Codeunit] = ACTIONS(4373),
    [anon_sym_CodeUnit] = ACTIONS(4373),
    [anon_sym_COdeunit] = ACTIONS(4373),
    [anon_sym_codeUnit] = ACTIONS(4373),
    [sym_report_keyword] = ACTIONS(4373),
    [sym_query_keyword] = ACTIONS(4373),
    [anon_sym_xmlport] = ACTIONS(4373),
    [anon_sym_XMLPORT] = ACTIONS(4373),
    [anon_sym_Xmlport] = ACTIONS(4373),
    [anon_sym_XMLport] = ACTIONS(4373),
    [anon_sym_XMLPort] = ACTIONS(4373),
    [anon_sym_XmlPort] = ACTIONS(4373),
    [anon_sym_enum] = ACTIONS(4373),
    [anon_sym_ENUM] = ACTIONS(4373),
    [anon_sym_Enum] = ACTIONS(4373),
    [anon_sym_eNUM] = ACTIONS(4373),
    [anon_sym_eNum] = ACTIONS(4373),
    [anon_sym_ENum] = ACTIONS(4373),
    [sym_quoted_identifier] = ACTIONS(4377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4377),
    [sym_integer] = ACTIONS(4373),
    [sym_continue_as_identifier] = ACTIONS(4377),
    [sym_preproc_open] = ACTIONS(4377),
    [sym_end_keyword] = ACTIONS(4377),
  },
  [STATE(2395)] = {
    [sym_identifier] = ACTIONS(4672),
    [anon_sym_SEMI] = ACTIONS(4674),
    [anon_sym_DASH] = ACTIONS(4674),
    [aux_sym_boolean_token1] = ACTIONS(4672),
    [aux_sym_boolean_token2] = ACTIONS(4672),
    [sym_decimal] = ACTIONS(4672),
    [anon_sym_LPAREN] = ACTIONS(4674),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4672),
    [anon_sym_LBRACK] = ACTIONS(4674),
    [aux_sym_record_type_token1] = ACTIONS(4672),
    [aux_sym_basic_type_token21] = ACTIONS(4672),
    [aux_sym_basic_type_token22] = ACTIONS(4672),
    [aux_sym_basic_type_token48] = ACTIONS(4672),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4672),
    [anon_sym_POUNDif] = ACTIONS(4674),
    [anon_sym_POUNDIF] = ACTIONS(4674),
    [anon_sym_POUNDIf] = ACTIONS(4674),
    [anon_sym_not] = ACTIONS(4672),
    [anon_sym_NOT] = ACTIONS(4672),
    [anon_sym_Not] = ACTIONS(4672),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4672),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4672),
    [anon_sym_PLUS] = ACTIONS(4674),
    [sym_datetime_literal] = ACTIONS(4674),
    [sym_date_literal] = ACTIONS(4672),
    [sym_time_literal] = ACTIONS(4672),
    [sym_biginteger_literal] = ACTIONS(4674),
    [anon_sym_if] = ACTIONS(4672),
    [anon_sym_IF] = ACTIONS(4672),
    [anon_sym_If] = ACTIONS(4672),
    [anon_sym_else] = ACTIONS(4672),
    [anon_sym_ELSE] = ACTIONS(4672),
    [anon_sym_Else] = ACTIONS(4672),
    [anon_sym_case] = ACTIONS(4672),
    [anon_sym_CASE] = ACTIONS(4672),
    [anon_sym_Case] = ACTIONS(4672),
    [anon_sym_for] = ACTIONS(4672),
    [anon_sym_FOR] = ACTIONS(4672),
    [anon_sym_For] = ACTIONS(4672),
    [anon_sym_foreach] = ACTIONS(4672),
    [anon_sym_FOREACH] = ACTIONS(4672),
    [anon_sym_Foreach] = ACTIONS(4672),
    [anon_sym_while] = ACTIONS(4672),
    [anon_sym_WHILE] = ACTIONS(4672),
    [anon_sym_While] = ACTIONS(4672),
    [anon_sym_repeat] = ACTIONS(4672),
    [anon_sym_REPEAT] = ACTIONS(4672),
    [anon_sym_Repeat] = ACTIONS(4672),
    [anon_sym_exit] = ACTIONS(4672),
    [anon_sym_EXIT] = ACTIONS(4672),
    [anon_sym_Exit] = ACTIONS(4672),
    [anon_sym_continue] = ACTIONS(4672),
    [anon_sym_CONTINUE] = ACTIONS(4672),
    [anon_sym_Continue] = ACTIONS(4672),
    [anon_sym_break] = ACTIONS(4672),
    [anon_sym_BREAK] = ACTIONS(4672),
    [anon_sym_Break] = ACTIONS(4672),
    [anon_sym_with] = ACTIONS(4672),
    [anon_sym_WITH] = ACTIONS(4672),
    [anon_sym_With] = ACTIONS(4672),
    [sym_asserterror_keyword] = ACTIONS(4674),
    [sym_page_keyword] = ACTIONS(4672),
    [anon_sym_codeunit] = ACTIONS(4672),
    [anon_sym_CODEUNIT] = ACTIONS(4672),
    [anon_sym_Codeunit] = ACTIONS(4672),
    [anon_sym_CodeUnit] = ACTIONS(4672),
    [anon_sym_COdeunit] = ACTIONS(4672),
    [anon_sym_codeUnit] = ACTIONS(4672),
    [sym_report_keyword] = ACTIONS(4672),
    [sym_query_keyword] = ACTIONS(4672),
    [anon_sym_xmlport] = ACTIONS(4672),
    [anon_sym_XMLPORT] = ACTIONS(4672),
    [anon_sym_Xmlport] = ACTIONS(4672),
    [anon_sym_XMLport] = ACTIONS(4672),
    [anon_sym_XMLPort] = ACTIONS(4672),
    [anon_sym_XmlPort] = ACTIONS(4672),
    [anon_sym_enum] = ACTIONS(4672),
    [anon_sym_ENUM] = ACTIONS(4672),
    [anon_sym_Enum] = ACTIONS(4672),
    [anon_sym_eNUM] = ACTIONS(4672),
    [anon_sym_eNum] = ACTIONS(4672),
    [anon_sym_ENum] = ACTIONS(4672),
    [sym_quoted_identifier] = ACTIONS(4674),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4674),
    [sym_integer] = ACTIONS(4672),
    [sym_continue_as_identifier] = ACTIONS(4674),
    [sym_preproc_open] = ACTIONS(4674),
    [sym_end_keyword] = ACTIONS(4674),
  },
  [STATE(2396)] = {
    [sym_identifier] = ACTIONS(4676),
    [anon_sym_SEMI] = ACTIONS(4678),
    [anon_sym_DASH] = ACTIONS(4678),
    [aux_sym_boolean_token1] = ACTIONS(4676),
    [aux_sym_boolean_token2] = ACTIONS(4676),
    [sym_decimal] = ACTIONS(4676),
    [anon_sym_LPAREN] = ACTIONS(4678),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4676),
    [anon_sym_LBRACK] = ACTIONS(4678),
    [aux_sym_record_type_token1] = ACTIONS(4676),
    [aux_sym_basic_type_token21] = ACTIONS(4676),
    [aux_sym_basic_type_token22] = ACTIONS(4676),
    [aux_sym_basic_type_token48] = ACTIONS(4676),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4676),
    [anon_sym_POUNDif] = ACTIONS(4678),
    [anon_sym_POUNDIF] = ACTIONS(4678),
    [anon_sym_POUNDIf] = ACTIONS(4678),
    [anon_sym_not] = ACTIONS(4676),
    [anon_sym_NOT] = ACTIONS(4676),
    [anon_sym_Not] = ACTIONS(4676),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4676),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4676),
    [anon_sym_PLUS] = ACTIONS(4678),
    [sym_datetime_literal] = ACTIONS(4678),
    [sym_date_literal] = ACTIONS(4676),
    [sym_time_literal] = ACTIONS(4676),
    [sym_biginteger_literal] = ACTIONS(4678),
    [anon_sym_if] = ACTIONS(4676),
    [anon_sym_IF] = ACTIONS(4676),
    [anon_sym_If] = ACTIONS(4676),
    [anon_sym_else] = ACTIONS(4676),
    [anon_sym_ELSE] = ACTIONS(4676),
    [anon_sym_Else] = ACTIONS(4676),
    [anon_sym_case] = ACTIONS(4676),
    [anon_sym_CASE] = ACTIONS(4676),
    [anon_sym_Case] = ACTIONS(4676),
    [anon_sym_for] = ACTIONS(4676),
    [anon_sym_FOR] = ACTIONS(4676),
    [anon_sym_For] = ACTIONS(4676),
    [anon_sym_foreach] = ACTIONS(4676),
    [anon_sym_FOREACH] = ACTIONS(4676),
    [anon_sym_Foreach] = ACTIONS(4676),
    [anon_sym_while] = ACTIONS(4676),
    [anon_sym_WHILE] = ACTIONS(4676),
    [anon_sym_While] = ACTIONS(4676),
    [anon_sym_repeat] = ACTIONS(4676),
    [anon_sym_REPEAT] = ACTIONS(4676),
    [anon_sym_Repeat] = ACTIONS(4676),
    [anon_sym_exit] = ACTIONS(4676),
    [anon_sym_EXIT] = ACTIONS(4676),
    [anon_sym_Exit] = ACTIONS(4676),
    [anon_sym_continue] = ACTIONS(4676),
    [anon_sym_CONTINUE] = ACTIONS(4676),
    [anon_sym_Continue] = ACTIONS(4676),
    [anon_sym_break] = ACTIONS(4676),
    [anon_sym_BREAK] = ACTIONS(4676),
    [anon_sym_Break] = ACTIONS(4676),
    [anon_sym_with] = ACTIONS(4676),
    [anon_sym_WITH] = ACTIONS(4676),
    [anon_sym_With] = ACTIONS(4676),
    [sym_asserterror_keyword] = ACTIONS(4678),
    [sym_page_keyword] = ACTIONS(4676),
    [anon_sym_codeunit] = ACTIONS(4676),
    [anon_sym_CODEUNIT] = ACTIONS(4676),
    [anon_sym_Codeunit] = ACTIONS(4676),
    [anon_sym_CodeUnit] = ACTIONS(4676),
    [anon_sym_COdeunit] = ACTIONS(4676),
    [anon_sym_codeUnit] = ACTIONS(4676),
    [sym_report_keyword] = ACTIONS(4676),
    [sym_query_keyword] = ACTIONS(4676),
    [anon_sym_xmlport] = ACTIONS(4676),
    [anon_sym_XMLPORT] = ACTIONS(4676),
    [anon_sym_Xmlport] = ACTIONS(4676),
    [anon_sym_XMLport] = ACTIONS(4676),
    [anon_sym_XMLPort] = ACTIONS(4676),
    [anon_sym_XmlPort] = ACTIONS(4676),
    [anon_sym_enum] = ACTIONS(4676),
    [anon_sym_ENUM] = ACTIONS(4676),
    [anon_sym_Enum] = ACTIONS(4676),
    [anon_sym_eNUM] = ACTIONS(4676),
    [anon_sym_eNum] = ACTIONS(4676),
    [anon_sym_ENum] = ACTIONS(4676),
    [sym_quoted_identifier] = ACTIONS(4678),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4678),
    [sym_integer] = ACTIONS(4676),
    [sym_continue_as_identifier] = ACTIONS(4678),
    [sym_preproc_open] = ACTIONS(4678),
    [sym_end_keyword] = ACTIONS(4678),
  },
  [STATE(2397)] = {
    [sym_identifier] = ACTIONS(4780),
    [anon_sym_SEMI] = ACTIONS(4782),
    [anon_sym_DASH] = ACTIONS(4782),
    [aux_sym_boolean_token1] = ACTIONS(4780),
    [aux_sym_boolean_token2] = ACTIONS(4780),
    [sym_decimal] = ACTIONS(4780),
    [anon_sym_LPAREN] = ACTIONS(4782),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4780),
    [anon_sym_LBRACK] = ACTIONS(4782),
    [aux_sym_record_type_token1] = ACTIONS(4780),
    [aux_sym_basic_type_token21] = ACTIONS(4780),
    [aux_sym_basic_type_token22] = ACTIONS(4780),
    [aux_sym_basic_type_token48] = ACTIONS(4780),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4780),
    [anon_sym_POUNDif] = ACTIONS(4782),
    [anon_sym_POUNDIF] = ACTIONS(4782),
    [anon_sym_POUNDIf] = ACTIONS(4782),
    [anon_sym_not] = ACTIONS(4780),
    [anon_sym_NOT] = ACTIONS(4780),
    [anon_sym_Not] = ACTIONS(4780),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4780),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4780),
    [anon_sym_PLUS] = ACTIONS(4782),
    [sym_datetime_literal] = ACTIONS(4782),
    [sym_date_literal] = ACTIONS(4780),
    [sym_time_literal] = ACTIONS(4780),
    [sym_biginteger_literal] = ACTIONS(4782),
    [anon_sym_if] = ACTIONS(4780),
    [anon_sym_IF] = ACTIONS(4780),
    [anon_sym_If] = ACTIONS(4780),
    [anon_sym_else] = ACTIONS(4780),
    [anon_sym_ELSE] = ACTIONS(4780),
    [anon_sym_Else] = ACTIONS(4780),
    [anon_sym_case] = ACTIONS(4780),
    [anon_sym_CASE] = ACTIONS(4780),
    [anon_sym_Case] = ACTIONS(4780),
    [anon_sym_for] = ACTIONS(4780),
    [anon_sym_FOR] = ACTIONS(4780),
    [anon_sym_For] = ACTIONS(4780),
    [anon_sym_foreach] = ACTIONS(4780),
    [anon_sym_FOREACH] = ACTIONS(4780),
    [anon_sym_Foreach] = ACTIONS(4780),
    [anon_sym_while] = ACTIONS(4780),
    [anon_sym_WHILE] = ACTIONS(4780),
    [anon_sym_While] = ACTIONS(4780),
    [anon_sym_repeat] = ACTIONS(4780),
    [anon_sym_REPEAT] = ACTIONS(4780),
    [anon_sym_Repeat] = ACTIONS(4780),
    [anon_sym_exit] = ACTIONS(4780),
    [anon_sym_EXIT] = ACTIONS(4780),
    [anon_sym_Exit] = ACTIONS(4780),
    [anon_sym_continue] = ACTIONS(4780),
    [anon_sym_CONTINUE] = ACTIONS(4780),
    [anon_sym_Continue] = ACTIONS(4780),
    [anon_sym_break] = ACTIONS(4780),
    [anon_sym_BREAK] = ACTIONS(4780),
    [anon_sym_Break] = ACTIONS(4780),
    [anon_sym_with] = ACTIONS(4780),
    [anon_sym_WITH] = ACTIONS(4780),
    [anon_sym_With] = ACTIONS(4780),
    [sym_asserterror_keyword] = ACTIONS(4782),
    [sym_page_keyword] = ACTIONS(4780),
    [anon_sym_codeunit] = ACTIONS(4780),
    [anon_sym_CODEUNIT] = ACTIONS(4780),
    [anon_sym_Codeunit] = ACTIONS(4780),
    [anon_sym_CodeUnit] = ACTIONS(4780),
    [anon_sym_COdeunit] = ACTIONS(4780),
    [anon_sym_codeUnit] = ACTIONS(4780),
    [sym_report_keyword] = ACTIONS(4780),
    [sym_query_keyword] = ACTIONS(4780),
    [anon_sym_xmlport] = ACTIONS(4780),
    [anon_sym_XMLPORT] = ACTIONS(4780),
    [anon_sym_Xmlport] = ACTIONS(4780),
    [anon_sym_XMLport] = ACTIONS(4780),
    [anon_sym_XMLPort] = ACTIONS(4780),
    [anon_sym_XmlPort] = ACTIONS(4780),
    [anon_sym_enum] = ACTIONS(4780),
    [anon_sym_ENUM] = ACTIONS(4780),
    [anon_sym_Enum] = ACTIONS(4780),
    [anon_sym_eNUM] = ACTIONS(4780),
    [anon_sym_eNum] = ACTIONS(4780),
    [anon_sym_ENum] = ACTIONS(4780),
    [sym_quoted_identifier] = ACTIONS(4782),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4782),
    [sym_integer] = ACTIONS(4780),
    [sym_continue_as_identifier] = ACTIONS(4782),
    [sym_preproc_open] = ACTIONS(4782),
    [sym_end_keyword] = ACTIONS(4782),
  },
  [STATE(2398)] = {
    [sym_identifier] = ACTIONS(4379),
    [anon_sym_SEMI] = ACTIONS(4381),
    [anon_sym_DASH] = ACTIONS(4381),
    [aux_sym_boolean_token1] = ACTIONS(4379),
    [aux_sym_boolean_token2] = ACTIONS(4379),
    [sym_decimal] = ACTIONS(4379),
    [anon_sym_LPAREN] = ACTIONS(4381),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4379),
    [anon_sym_LBRACK] = ACTIONS(4381),
    [aux_sym_record_type_token1] = ACTIONS(4379),
    [aux_sym_basic_type_token21] = ACTIONS(4379),
    [aux_sym_basic_type_token22] = ACTIONS(4379),
    [aux_sym_basic_type_token48] = ACTIONS(4379),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4379),
    [anon_sym_POUNDif] = ACTIONS(4381),
    [anon_sym_POUNDIF] = ACTIONS(4381),
    [anon_sym_POUNDIf] = ACTIONS(4381),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4379),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4379),
    [anon_sym_PLUS] = ACTIONS(4381),
    [sym_datetime_literal] = ACTIONS(4381),
    [sym_date_literal] = ACTIONS(4379),
    [sym_time_literal] = ACTIONS(4379),
    [sym_biginteger_literal] = ACTIONS(4381),
    [anon_sym_if] = ACTIONS(4379),
    [anon_sym_IF] = ACTIONS(4379),
    [anon_sym_If] = ACTIONS(4379),
    [anon_sym_else] = ACTIONS(4379),
    [anon_sym_ELSE] = ACTIONS(4379),
    [anon_sym_Else] = ACTIONS(4379),
    [anon_sym_case] = ACTIONS(4379),
    [anon_sym_CASE] = ACTIONS(4379),
    [anon_sym_Case] = ACTIONS(4379),
    [anon_sym_for] = ACTIONS(4379),
    [anon_sym_FOR] = ACTIONS(4379),
    [anon_sym_For] = ACTIONS(4379),
    [anon_sym_foreach] = ACTIONS(4379),
    [anon_sym_FOREACH] = ACTIONS(4379),
    [anon_sym_Foreach] = ACTIONS(4379),
    [anon_sym_while] = ACTIONS(4379),
    [anon_sym_WHILE] = ACTIONS(4379),
    [anon_sym_While] = ACTIONS(4379),
    [anon_sym_repeat] = ACTIONS(4379),
    [anon_sym_REPEAT] = ACTIONS(4379),
    [anon_sym_Repeat] = ACTIONS(4379),
    [anon_sym_exit] = ACTIONS(4379),
    [anon_sym_EXIT] = ACTIONS(4379),
    [anon_sym_Exit] = ACTIONS(4379),
    [anon_sym_continue] = ACTIONS(4379),
    [anon_sym_CONTINUE] = ACTIONS(4379),
    [anon_sym_Continue] = ACTIONS(4379),
    [anon_sym_break] = ACTIONS(4379),
    [anon_sym_BREAK] = ACTIONS(4379),
    [anon_sym_Break] = ACTIONS(4379),
    [anon_sym_with] = ACTIONS(4379),
    [anon_sym_WITH] = ACTIONS(4379),
    [anon_sym_With] = ACTIONS(4379),
    [sym_asserterror_keyword] = ACTIONS(4381),
    [sym_page_keyword] = ACTIONS(4379),
    [anon_sym_codeunit] = ACTIONS(4379),
    [anon_sym_CODEUNIT] = ACTIONS(4379),
    [anon_sym_Codeunit] = ACTIONS(4379),
    [anon_sym_CodeUnit] = ACTIONS(4379),
    [anon_sym_COdeunit] = ACTIONS(4379),
    [anon_sym_codeUnit] = ACTIONS(4379),
    [sym_report_keyword] = ACTIONS(4379),
    [sym_query_keyword] = ACTIONS(4379),
    [anon_sym_xmlport] = ACTIONS(4379),
    [anon_sym_XMLPORT] = ACTIONS(4379),
    [anon_sym_Xmlport] = ACTIONS(4379),
    [anon_sym_XMLport] = ACTIONS(4379),
    [anon_sym_XMLPort] = ACTIONS(4379),
    [anon_sym_XmlPort] = ACTIONS(4379),
    [anon_sym_enum] = ACTIONS(4379),
    [anon_sym_ENUM] = ACTIONS(4379),
    [anon_sym_Enum] = ACTIONS(4379),
    [anon_sym_eNUM] = ACTIONS(4379),
    [anon_sym_eNum] = ACTIONS(4379),
    [anon_sym_ENum] = ACTIONS(4379),
    [sym_quoted_identifier] = ACTIONS(4381),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4381),
    [sym_integer] = ACTIONS(4379),
    [sym_continue_as_identifier] = ACTIONS(4381),
    [sym_preproc_open] = ACTIONS(4381),
    [sym_end_keyword] = ACTIONS(4381),
  },
  [STATE(2399)] = {
    [sym_identifier] = ACTIONS(4630),
    [anon_sym_SEMI] = ACTIONS(4632),
    [anon_sym_DASH] = ACTIONS(4632),
    [aux_sym_boolean_token1] = ACTIONS(4630),
    [aux_sym_boolean_token2] = ACTIONS(4630),
    [sym_decimal] = ACTIONS(4630),
    [anon_sym_LPAREN] = ACTIONS(4632),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4630),
    [anon_sym_LBRACK] = ACTIONS(4632),
    [aux_sym_record_type_token1] = ACTIONS(4630),
    [aux_sym_basic_type_token21] = ACTIONS(4630),
    [aux_sym_basic_type_token22] = ACTIONS(4630),
    [aux_sym_basic_type_token48] = ACTIONS(4630),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4630),
    [anon_sym_POUNDif] = ACTIONS(4632),
    [anon_sym_POUNDIF] = ACTIONS(4632),
    [anon_sym_POUNDIf] = ACTIONS(4632),
    [anon_sym_not] = ACTIONS(4630),
    [anon_sym_NOT] = ACTIONS(4630),
    [anon_sym_Not] = ACTIONS(4630),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4630),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4630),
    [anon_sym_PLUS] = ACTIONS(4632),
    [sym_datetime_literal] = ACTIONS(4632),
    [sym_date_literal] = ACTIONS(4630),
    [sym_time_literal] = ACTIONS(4630),
    [sym_biginteger_literal] = ACTIONS(4632),
    [anon_sym_if] = ACTIONS(4630),
    [anon_sym_IF] = ACTIONS(4630),
    [anon_sym_If] = ACTIONS(4630),
    [anon_sym_else] = ACTIONS(4630),
    [anon_sym_ELSE] = ACTIONS(4630),
    [anon_sym_Else] = ACTIONS(4630),
    [anon_sym_case] = ACTIONS(4630),
    [anon_sym_CASE] = ACTIONS(4630),
    [anon_sym_Case] = ACTIONS(4630),
    [anon_sym_for] = ACTIONS(4630),
    [anon_sym_FOR] = ACTIONS(4630),
    [anon_sym_For] = ACTIONS(4630),
    [anon_sym_foreach] = ACTIONS(4630),
    [anon_sym_FOREACH] = ACTIONS(4630),
    [anon_sym_Foreach] = ACTIONS(4630),
    [anon_sym_while] = ACTIONS(4630),
    [anon_sym_WHILE] = ACTIONS(4630),
    [anon_sym_While] = ACTIONS(4630),
    [anon_sym_repeat] = ACTIONS(4630),
    [anon_sym_REPEAT] = ACTIONS(4630),
    [anon_sym_Repeat] = ACTIONS(4630),
    [anon_sym_exit] = ACTIONS(4630),
    [anon_sym_EXIT] = ACTIONS(4630),
    [anon_sym_Exit] = ACTIONS(4630),
    [anon_sym_continue] = ACTIONS(4630),
    [anon_sym_CONTINUE] = ACTIONS(4630),
    [anon_sym_Continue] = ACTIONS(4630),
    [anon_sym_break] = ACTIONS(4630),
    [anon_sym_BREAK] = ACTIONS(4630),
    [anon_sym_Break] = ACTIONS(4630),
    [anon_sym_with] = ACTIONS(4630),
    [anon_sym_WITH] = ACTIONS(4630),
    [anon_sym_With] = ACTIONS(4630),
    [sym_asserterror_keyword] = ACTIONS(4632),
    [sym_page_keyword] = ACTIONS(4630),
    [anon_sym_codeunit] = ACTIONS(4630),
    [anon_sym_CODEUNIT] = ACTIONS(4630),
    [anon_sym_Codeunit] = ACTIONS(4630),
    [anon_sym_CodeUnit] = ACTIONS(4630),
    [anon_sym_COdeunit] = ACTIONS(4630),
    [anon_sym_codeUnit] = ACTIONS(4630),
    [sym_report_keyword] = ACTIONS(4630),
    [sym_query_keyword] = ACTIONS(4630),
    [anon_sym_xmlport] = ACTIONS(4630),
    [anon_sym_XMLPORT] = ACTIONS(4630),
    [anon_sym_Xmlport] = ACTIONS(4630),
    [anon_sym_XMLport] = ACTIONS(4630),
    [anon_sym_XMLPort] = ACTIONS(4630),
    [anon_sym_XmlPort] = ACTIONS(4630),
    [anon_sym_enum] = ACTIONS(4630),
    [anon_sym_ENUM] = ACTIONS(4630),
    [anon_sym_Enum] = ACTIONS(4630),
    [anon_sym_eNUM] = ACTIONS(4630),
    [anon_sym_eNum] = ACTIONS(4630),
    [anon_sym_ENum] = ACTIONS(4630),
    [sym_quoted_identifier] = ACTIONS(4632),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4632),
    [sym_integer] = ACTIONS(4630),
    [sym_continue_as_identifier] = ACTIONS(4632),
    [sym_preproc_open] = ACTIONS(4632),
    [sym_end_keyword] = ACTIONS(4632),
  },
  [STATE(2400)] = {
    [sym_identifier] = ACTIONS(4383),
    [anon_sym_SEMI] = ACTIONS(5477),
    [anon_sym_DASH] = ACTIONS(4387),
    [aux_sym_boolean_token1] = ACTIONS(4383),
    [aux_sym_boolean_token2] = ACTIONS(4383),
    [sym_decimal] = ACTIONS(4383),
    [anon_sym_LPAREN] = ACTIONS(4387),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4383),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_record_type_token1] = ACTIONS(4383),
    [aux_sym_basic_type_token21] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_basic_type_token48] = ACTIONS(4383),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4383),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [anon_sym_not] = ACTIONS(4383),
    [anon_sym_NOT] = ACTIONS(4383),
    [anon_sym_Not] = ACTIONS(4383),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4383),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4383),
    [anon_sym_PLUS] = ACTIONS(4387),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4383),
    [sym_time_literal] = ACTIONS(4383),
    [sym_biginteger_literal] = ACTIONS(4387),
    [anon_sym_if] = ACTIONS(4383),
    [anon_sym_IF] = ACTIONS(4383),
    [anon_sym_If] = ACTIONS(4383),
    [anon_sym_else] = ACTIONS(4383),
    [anon_sym_ELSE] = ACTIONS(4383),
    [anon_sym_Else] = ACTIONS(4383),
    [anon_sym_case] = ACTIONS(4383),
    [anon_sym_CASE] = ACTIONS(4383),
    [anon_sym_Case] = ACTIONS(4383),
    [anon_sym_for] = ACTIONS(4383),
    [anon_sym_FOR] = ACTIONS(4383),
    [anon_sym_For] = ACTIONS(4383),
    [anon_sym_foreach] = ACTIONS(4383),
    [anon_sym_FOREACH] = ACTIONS(4383),
    [anon_sym_Foreach] = ACTIONS(4383),
    [anon_sym_while] = ACTIONS(4383),
    [anon_sym_WHILE] = ACTIONS(4383),
    [anon_sym_While] = ACTIONS(4383),
    [anon_sym_repeat] = ACTIONS(4383),
    [anon_sym_REPEAT] = ACTIONS(4383),
    [anon_sym_Repeat] = ACTIONS(4383),
    [anon_sym_exit] = ACTIONS(4383),
    [anon_sym_EXIT] = ACTIONS(4383),
    [anon_sym_Exit] = ACTIONS(4383),
    [anon_sym_continue] = ACTIONS(4383),
    [anon_sym_CONTINUE] = ACTIONS(4383),
    [anon_sym_Continue] = ACTIONS(4383),
    [anon_sym_break] = ACTIONS(4383),
    [anon_sym_BREAK] = ACTIONS(4383),
    [anon_sym_Break] = ACTIONS(4383),
    [anon_sym_with] = ACTIONS(4383),
    [anon_sym_WITH] = ACTIONS(4383),
    [anon_sym_With] = ACTIONS(4383),
    [sym_asserterror_keyword] = ACTIONS(4387),
    [sym_page_keyword] = ACTIONS(4383),
    [anon_sym_codeunit] = ACTIONS(4383),
    [anon_sym_CODEUNIT] = ACTIONS(4383),
    [anon_sym_Codeunit] = ACTIONS(4383),
    [anon_sym_CodeUnit] = ACTIONS(4383),
    [anon_sym_COdeunit] = ACTIONS(4383),
    [anon_sym_codeUnit] = ACTIONS(4383),
    [sym_report_keyword] = ACTIONS(4383),
    [sym_query_keyword] = ACTIONS(4383),
    [anon_sym_xmlport] = ACTIONS(4383),
    [anon_sym_XMLPORT] = ACTIONS(4383),
    [anon_sym_Xmlport] = ACTIONS(4383),
    [anon_sym_XMLport] = ACTIONS(4383),
    [anon_sym_XMLPort] = ACTIONS(4383),
    [anon_sym_XmlPort] = ACTIONS(4383),
    [anon_sym_enum] = ACTIONS(4383),
    [anon_sym_ENUM] = ACTIONS(4383),
    [anon_sym_Enum] = ACTIONS(4383),
    [anon_sym_eNUM] = ACTIONS(4383),
    [anon_sym_eNum] = ACTIONS(4383),
    [anon_sym_ENum] = ACTIONS(4383),
    [sym_quoted_identifier] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4383),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
    [sym_end_keyword] = ACTIONS(4387),
  },
  [STATE(2401)] = {
    [sym_identifier] = ACTIONS(4383),
    [anon_sym_SEMI] = ACTIONS(5479),
    [anon_sym_DASH] = ACTIONS(4387),
    [aux_sym_boolean_token1] = ACTIONS(4383),
    [aux_sym_boolean_token2] = ACTIONS(4383),
    [sym_decimal] = ACTIONS(4383),
    [anon_sym_LPAREN] = ACTIONS(4387),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4383),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_record_type_token1] = ACTIONS(4383),
    [aux_sym_basic_type_token21] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_basic_type_token48] = ACTIONS(4383),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4383),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [anon_sym_not] = ACTIONS(4383),
    [anon_sym_NOT] = ACTIONS(4383),
    [anon_sym_Not] = ACTIONS(4383),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4383),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4383),
    [anon_sym_PLUS] = ACTIONS(4387),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4383),
    [sym_time_literal] = ACTIONS(4383),
    [sym_biginteger_literal] = ACTIONS(4387),
    [anon_sym_if] = ACTIONS(4383),
    [anon_sym_IF] = ACTIONS(4383),
    [anon_sym_If] = ACTIONS(4383),
    [anon_sym_else] = ACTIONS(4383),
    [anon_sym_ELSE] = ACTIONS(4383),
    [anon_sym_Else] = ACTIONS(4383),
    [anon_sym_case] = ACTIONS(4383),
    [anon_sym_CASE] = ACTIONS(4383),
    [anon_sym_Case] = ACTIONS(4383),
    [anon_sym_for] = ACTIONS(4383),
    [anon_sym_FOR] = ACTIONS(4383),
    [anon_sym_For] = ACTIONS(4383),
    [anon_sym_foreach] = ACTIONS(4383),
    [anon_sym_FOREACH] = ACTIONS(4383),
    [anon_sym_Foreach] = ACTIONS(4383),
    [anon_sym_while] = ACTIONS(4383),
    [anon_sym_WHILE] = ACTIONS(4383),
    [anon_sym_While] = ACTIONS(4383),
    [anon_sym_repeat] = ACTIONS(4383),
    [anon_sym_REPEAT] = ACTIONS(4383),
    [anon_sym_Repeat] = ACTIONS(4383),
    [anon_sym_exit] = ACTIONS(4383),
    [anon_sym_EXIT] = ACTIONS(4383),
    [anon_sym_Exit] = ACTIONS(4383),
    [anon_sym_continue] = ACTIONS(4383),
    [anon_sym_CONTINUE] = ACTIONS(4383),
    [anon_sym_Continue] = ACTIONS(4383),
    [anon_sym_break] = ACTIONS(4383),
    [anon_sym_BREAK] = ACTIONS(4383),
    [anon_sym_Break] = ACTIONS(4383),
    [anon_sym_with] = ACTIONS(4383),
    [anon_sym_WITH] = ACTIONS(4383),
    [anon_sym_With] = ACTIONS(4383),
    [sym_asserterror_keyword] = ACTIONS(4387),
    [sym_page_keyword] = ACTIONS(4383),
    [anon_sym_codeunit] = ACTIONS(4383),
    [anon_sym_CODEUNIT] = ACTIONS(4383),
    [anon_sym_Codeunit] = ACTIONS(4383),
    [anon_sym_CodeUnit] = ACTIONS(4383),
    [anon_sym_COdeunit] = ACTIONS(4383),
    [anon_sym_codeUnit] = ACTIONS(4383),
    [sym_report_keyword] = ACTIONS(4383),
    [sym_query_keyword] = ACTIONS(4383),
    [anon_sym_xmlport] = ACTIONS(4383),
    [anon_sym_XMLPORT] = ACTIONS(4383),
    [anon_sym_Xmlport] = ACTIONS(4383),
    [anon_sym_XMLport] = ACTIONS(4383),
    [anon_sym_XMLPort] = ACTIONS(4383),
    [anon_sym_XmlPort] = ACTIONS(4383),
    [anon_sym_enum] = ACTIONS(4383),
    [anon_sym_ENUM] = ACTIONS(4383),
    [anon_sym_Enum] = ACTIONS(4383),
    [anon_sym_eNUM] = ACTIONS(4383),
    [anon_sym_eNum] = ACTIONS(4383),
    [anon_sym_ENum] = ACTIONS(4383),
    [sym_quoted_identifier] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4383),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
    [sym_end_keyword] = ACTIONS(4387),
  },
  [STATE(2402)] = {
    [sym_identifier] = ACTIONS(4383),
    [anon_sym_SEMI] = ACTIONS(4387),
    [anon_sym_DASH] = ACTIONS(4387),
    [aux_sym_boolean_token1] = ACTIONS(4383),
    [aux_sym_boolean_token2] = ACTIONS(4383),
    [sym_decimal] = ACTIONS(4383),
    [anon_sym_LPAREN] = ACTIONS(4387),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4383),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_record_type_token1] = ACTIONS(4383),
    [aux_sym_basic_type_token21] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_basic_type_token48] = ACTIONS(4383),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4383),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [anon_sym_not] = ACTIONS(4383),
    [anon_sym_NOT] = ACTIONS(4383),
    [anon_sym_Not] = ACTIONS(4383),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4383),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4383),
    [anon_sym_PLUS] = ACTIONS(4387),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4383),
    [sym_time_literal] = ACTIONS(4383),
    [sym_biginteger_literal] = ACTIONS(4387),
    [anon_sym_if] = ACTIONS(4383),
    [anon_sym_IF] = ACTIONS(4383),
    [anon_sym_If] = ACTIONS(4383),
    [anon_sym_else] = ACTIONS(4383),
    [anon_sym_ELSE] = ACTIONS(4383),
    [anon_sym_Else] = ACTIONS(4383),
    [anon_sym_case] = ACTIONS(4383),
    [anon_sym_CASE] = ACTIONS(4383),
    [anon_sym_Case] = ACTIONS(4383),
    [anon_sym_for] = ACTIONS(4383),
    [anon_sym_FOR] = ACTIONS(4383),
    [anon_sym_For] = ACTIONS(4383),
    [anon_sym_foreach] = ACTIONS(4383),
    [anon_sym_FOREACH] = ACTIONS(4383),
    [anon_sym_Foreach] = ACTIONS(4383),
    [anon_sym_while] = ACTIONS(4383),
    [anon_sym_WHILE] = ACTIONS(4383),
    [anon_sym_While] = ACTIONS(4383),
    [anon_sym_repeat] = ACTIONS(4383),
    [anon_sym_REPEAT] = ACTIONS(4383),
    [anon_sym_Repeat] = ACTIONS(4383),
    [anon_sym_exit] = ACTIONS(4383),
    [anon_sym_EXIT] = ACTIONS(4383),
    [anon_sym_Exit] = ACTIONS(4383),
    [anon_sym_continue] = ACTIONS(4383),
    [anon_sym_CONTINUE] = ACTIONS(4383),
    [anon_sym_Continue] = ACTIONS(4383),
    [anon_sym_break] = ACTIONS(4383),
    [anon_sym_BREAK] = ACTIONS(4383),
    [anon_sym_Break] = ACTIONS(4383),
    [anon_sym_with] = ACTIONS(4383),
    [anon_sym_WITH] = ACTIONS(4383),
    [anon_sym_With] = ACTIONS(4383),
    [sym_asserterror_keyword] = ACTIONS(4387),
    [sym_page_keyword] = ACTIONS(4383),
    [anon_sym_codeunit] = ACTIONS(4383),
    [anon_sym_CODEUNIT] = ACTIONS(4383),
    [anon_sym_Codeunit] = ACTIONS(4383),
    [anon_sym_CodeUnit] = ACTIONS(4383),
    [anon_sym_COdeunit] = ACTIONS(4383),
    [anon_sym_codeUnit] = ACTIONS(4383),
    [sym_report_keyword] = ACTIONS(4383),
    [sym_query_keyword] = ACTIONS(4383),
    [anon_sym_xmlport] = ACTIONS(4383),
    [anon_sym_XMLPORT] = ACTIONS(4383),
    [anon_sym_Xmlport] = ACTIONS(4383),
    [anon_sym_XMLport] = ACTIONS(4383),
    [anon_sym_XMLPort] = ACTIONS(4383),
    [anon_sym_XmlPort] = ACTIONS(4383),
    [anon_sym_enum] = ACTIONS(4383),
    [anon_sym_ENUM] = ACTIONS(4383),
    [anon_sym_Enum] = ACTIONS(4383),
    [anon_sym_eNUM] = ACTIONS(4383),
    [anon_sym_eNum] = ACTIONS(4383),
    [anon_sym_ENum] = ACTIONS(4383),
    [sym_quoted_identifier] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4383),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
    [sym_end_keyword] = ACTIONS(4387),
  },
  [STATE(2403)] = {
    [sym_identifier] = ACTIONS(4411),
    [anon_sym_SEMI] = ACTIONS(4413),
    [anon_sym_DASH] = ACTIONS(4413),
    [aux_sym_boolean_token1] = ACTIONS(4411),
    [aux_sym_boolean_token2] = ACTIONS(4411),
    [sym_decimal] = ACTIONS(4411),
    [anon_sym_LPAREN] = ACTIONS(4413),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4411),
    [anon_sym_LBRACK] = ACTIONS(4413),
    [aux_sym_record_type_token1] = ACTIONS(4411),
    [aux_sym_basic_type_token21] = ACTIONS(4411),
    [aux_sym_basic_type_token22] = ACTIONS(4411),
    [aux_sym_basic_type_token48] = ACTIONS(4411),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4411),
    [anon_sym_POUNDif] = ACTIONS(4413),
    [anon_sym_POUNDIF] = ACTIONS(4413),
    [anon_sym_POUNDIf] = ACTIONS(4413),
    [anon_sym_not] = ACTIONS(4411),
    [anon_sym_NOT] = ACTIONS(4411),
    [anon_sym_Not] = ACTIONS(4411),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4411),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4411),
    [anon_sym_PLUS] = ACTIONS(4413),
    [sym_datetime_literal] = ACTIONS(4413),
    [sym_date_literal] = ACTIONS(4411),
    [sym_time_literal] = ACTIONS(4411),
    [sym_biginteger_literal] = ACTIONS(4413),
    [anon_sym_if] = ACTIONS(4411),
    [anon_sym_IF] = ACTIONS(4411),
    [anon_sym_If] = ACTIONS(4411),
    [anon_sym_else] = ACTIONS(4411),
    [anon_sym_ELSE] = ACTIONS(4411),
    [anon_sym_Else] = ACTIONS(4411),
    [anon_sym_case] = ACTIONS(4411),
    [anon_sym_CASE] = ACTIONS(4411),
    [anon_sym_Case] = ACTIONS(4411),
    [anon_sym_for] = ACTIONS(4411),
    [anon_sym_FOR] = ACTIONS(4411),
    [anon_sym_For] = ACTIONS(4411),
    [anon_sym_foreach] = ACTIONS(4411),
    [anon_sym_FOREACH] = ACTIONS(4411),
    [anon_sym_Foreach] = ACTIONS(4411),
    [anon_sym_while] = ACTIONS(4411),
    [anon_sym_WHILE] = ACTIONS(4411),
    [anon_sym_While] = ACTIONS(4411),
    [anon_sym_repeat] = ACTIONS(4411),
    [anon_sym_REPEAT] = ACTIONS(4411),
    [anon_sym_Repeat] = ACTIONS(4411),
    [anon_sym_exit] = ACTIONS(4411),
    [anon_sym_EXIT] = ACTIONS(4411),
    [anon_sym_Exit] = ACTIONS(4411),
    [anon_sym_continue] = ACTIONS(4411),
    [anon_sym_CONTINUE] = ACTIONS(4411),
    [anon_sym_Continue] = ACTIONS(4411),
    [anon_sym_break] = ACTIONS(4411),
    [anon_sym_BREAK] = ACTIONS(4411),
    [anon_sym_Break] = ACTIONS(4411),
    [anon_sym_with] = ACTIONS(4411),
    [anon_sym_WITH] = ACTIONS(4411),
    [anon_sym_With] = ACTIONS(4411),
    [sym_asserterror_keyword] = ACTIONS(4413),
    [sym_page_keyword] = ACTIONS(4411),
    [anon_sym_codeunit] = ACTIONS(4411),
    [anon_sym_CODEUNIT] = ACTIONS(4411),
    [anon_sym_Codeunit] = ACTIONS(4411),
    [anon_sym_CodeUnit] = ACTIONS(4411),
    [anon_sym_COdeunit] = ACTIONS(4411),
    [anon_sym_codeUnit] = ACTIONS(4411),
    [sym_report_keyword] = ACTIONS(4411),
    [sym_query_keyword] = ACTIONS(4411),
    [anon_sym_xmlport] = ACTIONS(4411),
    [anon_sym_XMLPORT] = ACTIONS(4411),
    [anon_sym_Xmlport] = ACTIONS(4411),
    [anon_sym_XMLport] = ACTIONS(4411),
    [anon_sym_XMLPort] = ACTIONS(4411),
    [anon_sym_XmlPort] = ACTIONS(4411),
    [anon_sym_enum] = ACTIONS(4411),
    [anon_sym_ENUM] = ACTIONS(4411),
    [anon_sym_Enum] = ACTIONS(4411),
    [anon_sym_eNUM] = ACTIONS(4411),
    [anon_sym_eNum] = ACTIONS(4411),
    [anon_sym_ENum] = ACTIONS(4411),
    [sym_quoted_identifier] = ACTIONS(4413),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4413),
    [sym_integer] = ACTIONS(4411),
    [sym_continue_as_identifier] = ACTIONS(4413),
    [sym_preproc_open] = ACTIONS(4413),
    [sym_end_keyword] = ACTIONS(4413),
  },
  [STATE(2404)] = {
    [sym_identifier] = ACTIONS(2843),
    [anon_sym_SEMI] = ACTIONS(2841),
    [anon_sym_DASH] = ACTIONS(2841),
    [aux_sym_boolean_token1] = ACTIONS(2843),
    [aux_sym_boolean_token2] = ACTIONS(2843),
    [sym_decimal] = ACTIONS(2843),
    [anon_sym_LPAREN] = ACTIONS(2841),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2843),
    [anon_sym_LBRACK] = ACTIONS(2841),
    [aux_sym_record_type_token1] = ACTIONS(2843),
    [aux_sym_basic_type_token21] = ACTIONS(2843),
    [aux_sym_basic_type_token22] = ACTIONS(2843),
    [aux_sym_basic_type_token48] = ACTIONS(2843),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2843),
    [anon_sym_POUNDif] = ACTIONS(2841),
    [anon_sym_POUNDIF] = ACTIONS(2841),
    [anon_sym_POUNDIf] = ACTIONS(2841),
    [anon_sym_not] = ACTIONS(2843),
    [anon_sym_NOT] = ACTIONS(2843),
    [anon_sym_Not] = ACTIONS(2843),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2843),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2843),
    [anon_sym_PLUS] = ACTIONS(2841),
    [sym_datetime_literal] = ACTIONS(2841),
    [sym_date_literal] = ACTIONS(2843),
    [sym_time_literal] = ACTIONS(2843),
    [sym_biginteger_literal] = ACTIONS(2841),
    [anon_sym_if] = ACTIONS(2843),
    [anon_sym_IF] = ACTIONS(2843),
    [anon_sym_If] = ACTIONS(2843),
    [anon_sym_else] = ACTIONS(2843),
    [anon_sym_ELSE] = ACTIONS(2843),
    [anon_sym_Else] = ACTIONS(2843),
    [anon_sym_case] = ACTIONS(2843),
    [anon_sym_CASE] = ACTIONS(2843),
    [anon_sym_Case] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2843),
    [anon_sym_FOR] = ACTIONS(2843),
    [anon_sym_For] = ACTIONS(2843),
    [anon_sym_foreach] = ACTIONS(2843),
    [anon_sym_FOREACH] = ACTIONS(2843),
    [anon_sym_Foreach] = ACTIONS(2843),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_WHILE] = ACTIONS(2843),
    [anon_sym_While] = ACTIONS(2843),
    [anon_sym_repeat] = ACTIONS(2843),
    [anon_sym_REPEAT] = ACTIONS(2843),
    [anon_sym_Repeat] = ACTIONS(2843),
    [anon_sym_exit] = ACTIONS(2843),
    [anon_sym_EXIT] = ACTIONS(2843),
    [anon_sym_Exit] = ACTIONS(2843),
    [anon_sym_continue] = ACTIONS(2843),
    [anon_sym_CONTINUE] = ACTIONS(2843),
    [anon_sym_Continue] = ACTIONS(2843),
    [anon_sym_break] = ACTIONS(2843),
    [anon_sym_BREAK] = ACTIONS(2843),
    [anon_sym_Break] = ACTIONS(2843),
    [anon_sym_with] = ACTIONS(2843),
    [anon_sym_WITH] = ACTIONS(2843),
    [anon_sym_With] = ACTIONS(2843),
    [sym_asserterror_keyword] = ACTIONS(2841),
    [sym_page_keyword] = ACTIONS(2843),
    [anon_sym_codeunit] = ACTIONS(2843),
    [anon_sym_CODEUNIT] = ACTIONS(2843),
    [anon_sym_Codeunit] = ACTIONS(2843),
    [anon_sym_CodeUnit] = ACTIONS(2843),
    [anon_sym_COdeunit] = ACTIONS(2843),
    [anon_sym_codeUnit] = ACTIONS(2843),
    [sym_report_keyword] = ACTIONS(2843),
    [sym_query_keyword] = ACTIONS(2843),
    [anon_sym_xmlport] = ACTIONS(2843),
    [anon_sym_XMLPORT] = ACTIONS(2843),
    [anon_sym_Xmlport] = ACTIONS(2843),
    [anon_sym_XMLport] = ACTIONS(2843),
    [anon_sym_XMLPort] = ACTIONS(2843),
    [anon_sym_XmlPort] = ACTIONS(2843),
    [anon_sym_enum] = ACTIONS(2843),
    [anon_sym_ENUM] = ACTIONS(2843),
    [anon_sym_Enum] = ACTIONS(2843),
    [anon_sym_eNUM] = ACTIONS(2843),
    [anon_sym_eNum] = ACTIONS(2843),
    [anon_sym_ENum] = ACTIONS(2843),
    [sym_quoted_identifier] = ACTIONS(2841),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2841),
    [sym_integer] = ACTIONS(2843),
    [sym_continue_as_identifier] = ACTIONS(2841),
    [sym_preproc_open] = ACTIONS(2841),
    [sym_end_keyword] = ACTIONS(2841),
  },
  [STATE(2405)] = {
    [sym_identifier] = ACTIONS(4712),
    [anon_sym_SEMI] = ACTIONS(4714),
    [anon_sym_DASH] = ACTIONS(4714),
    [aux_sym_boolean_token1] = ACTIONS(4712),
    [aux_sym_boolean_token2] = ACTIONS(4712),
    [sym_decimal] = ACTIONS(4712),
    [anon_sym_LPAREN] = ACTIONS(4714),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4712),
    [anon_sym_LBRACK] = ACTIONS(4714),
    [aux_sym_record_type_token1] = ACTIONS(4712),
    [aux_sym_basic_type_token21] = ACTIONS(4712),
    [aux_sym_basic_type_token22] = ACTIONS(4712),
    [aux_sym_basic_type_token48] = ACTIONS(4712),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4712),
    [anon_sym_POUNDif] = ACTIONS(4714),
    [anon_sym_POUNDIF] = ACTIONS(4714),
    [anon_sym_POUNDIf] = ACTIONS(4714),
    [anon_sym_not] = ACTIONS(4712),
    [anon_sym_NOT] = ACTIONS(4712),
    [anon_sym_Not] = ACTIONS(4712),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4712),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4712),
    [anon_sym_PLUS] = ACTIONS(4714),
    [sym_datetime_literal] = ACTIONS(4714),
    [sym_date_literal] = ACTIONS(4712),
    [sym_time_literal] = ACTIONS(4712),
    [sym_biginteger_literal] = ACTIONS(4714),
    [anon_sym_if] = ACTIONS(4712),
    [anon_sym_IF] = ACTIONS(4712),
    [anon_sym_If] = ACTIONS(4712),
    [anon_sym_else] = ACTIONS(4712),
    [anon_sym_ELSE] = ACTIONS(4712),
    [anon_sym_Else] = ACTIONS(4712),
    [anon_sym_case] = ACTIONS(4712),
    [anon_sym_CASE] = ACTIONS(4712),
    [anon_sym_Case] = ACTIONS(4712),
    [anon_sym_for] = ACTIONS(4712),
    [anon_sym_FOR] = ACTIONS(4712),
    [anon_sym_For] = ACTIONS(4712),
    [anon_sym_foreach] = ACTIONS(4712),
    [anon_sym_FOREACH] = ACTIONS(4712),
    [anon_sym_Foreach] = ACTIONS(4712),
    [anon_sym_while] = ACTIONS(4712),
    [anon_sym_WHILE] = ACTIONS(4712),
    [anon_sym_While] = ACTIONS(4712),
    [anon_sym_repeat] = ACTIONS(4712),
    [anon_sym_REPEAT] = ACTIONS(4712),
    [anon_sym_Repeat] = ACTIONS(4712),
    [anon_sym_exit] = ACTIONS(4712),
    [anon_sym_EXIT] = ACTIONS(4712),
    [anon_sym_Exit] = ACTIONS(4712),
    [anon_sym_continue] = ACTIONS(4712),
    [anon_sym_CONTINUE] = ACTIONS(4712),
    [anon_sym_Continue] = ACTIONS(4712),
    [anon_sym_break] = ACTIONS(4712),
    [anon_sym_BREAK] = ACTIONS(4712),
    [anon_sym_Break] = ACTIONS(4712),
    [anon_sym_with] = ACTIONS(4712),
    [anon_sym_WITH] = ACTIONS(4712),
    [anon_sym_With] = ACTIONS(4712),
    [sym_asserterror_keyword] = ACTIONS(4714),
    [sym_page_keyword] = ACTIONS(4712),
    [anon_sym_codeunit] = ACTIONS(4712),
    [anon_sym_CODEUNIT] = ACTIONS(4712),
    [anon_sym_Codeunit] = ACTIONS(4712),
    [anon_sym_CodeUnit] = ACTIONS(4712),
    [anon_sym_COdeunit] = ACTIONS(4712),
    [anon_sym_codeUnit] = ACTIONS(4712),
    [sym_report_keyword] = ACTIONS(4712),
    [sym_query_keyword] = ACTIONS(4712),
    [anon_sym_xmlport] = ACTIONS(4712),
    [anon_sym_XMLPORT] = ACTIONS(4712),
    [anon_sym_Xmlport] = ACTIONS(4712),
    [anon_sym_XMLport] = ACTIONS(4712),
    [anon_sym_XMLPort] = ACTIONS(4712),
    [anon_sym_XmlPort] = ACTIONS(4712),
    [anon_sym_enum] = ACTIONS(4712),
    [anon_sym_ENUM] = ACTIONS(4712),
    [anon_sym_Enum] = ACTIONS(4712),
    [anon_sym_eNUM] = ACTIONS(4712),
    [anon_sym_eNum] = ACTIONS(4712),
    [anon_sym_ENum] = ACTIONS(4712),
    [sym_quoted_identifier] = ACTIONS(4714),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4714),
    [sym_integer] = ACTIONS(4712),
    [sym_continue_as_identifier] = ACTIONS(4714),
    [sym_preproc_open] = ACTIONS(4714),
    [sym_end_keyword] = ACTIONS(4714),
  },
  [STATE(2406)] = {
    [sym_argument_list] = STATE(2117),
    [sym_identifier] = ACTIONS(4658),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_COMMA] = ACTIONS(4660),
    [anon_sym_COLON] = ACTIONS(4658),
    [anon_sym_DASH] = ACTIONS(4662),
    [aux_sym_boolean_token1] = ACTIONS(4658),
    [aux_sym_boolean_token2] = ACTIONS(4658),
    [sym_decimal] = ACTIONS(4658),
    [anon_sym_LPAREN] = ACTIONS(5335),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4658),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(4665),
    [aux_sym_record_type_token1] = ACTIONS(4658),
    [aux_sym_basic_type_token21] = ACTIONS(4658),
    [aux_sym_basic_type_token22] = ACTIONS(4658),
    [aux_sym_basic_type_token48] = ACTIONS(4658),
    [anon_sym_COLON_COLON] = ACTIONS(5337),
    [anon_sym_POUNDif] = ACTIONS(4660),
    [anon_sym_POUNDIF] = ACTIONS(4660),
    [anon_sym_POUNDIf] = ACTIONS(4660),
    [anon_sym_not] = ACTIONS(4658),
    [anon_sym_NOT] = ACTIONS(4658),
    [anon_sym_Not] = ACTIONS(4658),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4658),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4658),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(4662),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(4660),
    [sym_date_literal] = ACTIONS(4658),
    [sym_time_literal] = ACTIONS(4658),
    [sym_biginteger_literal] = ACTIONS(4660),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(4658),
    [anon_sym_codeunit] = ACTIONS(4658),
    [anon_sym_CODEUNIT] = ACTIONS(4658),
    [anon_sym_Codeunit] = ACTIONS(4658),
    [anon_sym_CodeUnit] = ACTIONS(4658),
    [anon_sym_COdeunit] = ACTIONS(4658),
    [anon_sym_codeUnit] = ACTIONS(4658),
    [sym_report_keyword] = ACTIONS(4658),
    [sym_query_keyword] = ACTIONS(4658),
    [anon_sym_xmlport] = ACTIONS(4658),
    [anon_sym_XMLPORT] = ACTIONS(4658),
    [anon_sym_Xmlport] = ACTIONS(4658),
    [anon_sym_XMLport] = ACTIONS(4658),
    [anon_sym_XMLPort] = ACTIONS(4658),
    [anon_sym_XmlPort] = ACTIONS(4658),
    [anon_sym_enum] = ACTIONS(4658),
    [anon_sym_ENUM] = ACTIONS(4658),
    [anon_sym_Enum] = ACTIONS(4658),
    [anon_sym_eNUM] = ACTIONS(4658),
    [anon_sym_eNum] = ACTIONS(4658),
    [anon_sym_ENum] = ACTIONS(4658),
    [sym_quoted_identifier] = ACTIONS(4660),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4660),
    [sym_integer] = ACTIONS(4658),
    [sym_continue_as_identifier] = ACTIONS(4660),
    [sym_preproc_open] = ACTIONS(4660),
  },
  [STATE(2407)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(1398),
    [sym_assignment_expression] = STATE(6338),
    [sym_preproc_conditional_case] = STATE(2414),
    [sym_case_branch] = STATE(2414),
    [sym_preproc_split_case_branch] = STATE(4637),
    [aux_sym__case_pattern] = STATE(2620),
    [sym_preproc_conditional_case_patterns] = STATE(2620),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(12256),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(156),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_case_statement_repeat1] = STATE(2414),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5481),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(2408)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(1398),
    [sym_assignment_expression] = STATE(6338),
    [sym_preproc_conditional_case] = STATE(2413),
    [sym_case_branch] = STATE(2413),
    [sym_preproc_split_case_branch] = STATE(4637),
    [aux_sym__case_pattern] = STATE(2620),
    [sym_preproc_conditional_case_patterns] = STATE(2620),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(11397),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(156),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_case_statement_repeat1] = STATE(2413),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5483),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(2409)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(1398),
    [sym_assignment_expression] = STATE(6338),
    [sym_preproc_conditional_case] = STATE(2443),
    [sym_case_branch] = STATE(2443),
    [sym_preproc_split_case_branch] = STATE(4637),
    [aux_sym__case_pattern] = STATE(2620),
    [sym_preproc_conditional_case_patterns] = STATE(2620),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(11799),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(156),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_case_statement_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5485),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(2410)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(1398),
    [sym_assignment_expression] = STATE(6338),
    [sym_preproc_conditional_case] = STATE(2409),
    [sym_case_branch] = STATE(2409),
    [sym_preproc_split_case_branch] = STATE(4637),
    [aux_sym__case_pattern] = STATE(2620),
    [sym_preproc_conditional_case_patterns] = STATE(2620),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(12103),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(156),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_case_statement_repeat1] = STATE(2409),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5487),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(2411)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(1398),
    [sym_assignment_expression] = STATE(6338),
    [sym_preproc_conditional_case] = STATE(2412),
    [sym_case_branch] = STATE(2412),
    [sym_preproc_split_case_branch] = STATE(4637),
    [aux_sym__case_pattern] = STATE(2620),
    [sym_preproc_conditional_case_patterns] = STATE(2620),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(11536),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(156),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_case_statement_repeat1] = STATE(2412),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5489),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(2412)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(1398),
    [sym_assignment_expression] = STATE(6338),
    [sym_preproc_conditional_case] = STATE(2443),
    [sym_case_branch] = STATE(2443),
    [sym_preproc_split_case_branch] = STATE(4637),
    [aux_sym__case_pattern] = STATE(2620),
    [sym_preproc_conditional_case_patterns] = STATE(2620),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(11922),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(156),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_case_statement_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5491),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(2413)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(1398),
    [sym_assignment_expression] = STATE(6338),
    [sym_preproc_conditional_case] = STATE(2443),
    [sym_case_branch] = STATE(2443),
    [sym_preproc_split_case_branch] = STATE(4637),
    [aux_sym__case_pattern] = STATE(2620),
    [sym_preproc_conditional_case_patterns] = STATE(2620),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(12043),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(156),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_case_statement_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5493),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(2414)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(1398),
    [sym_assignment_expression] = STATE(6338),
    [sym_preproc_conditional_case] = STATE(2443),
    [sym_case_branch] = STATE(2443),
    [sym_preproc_split_case_branch] = STATE(4637),
    [aux_sym__case_pattern] = STATE(2620),
    [sym_preproc_conditional_case_patterns] = STATE(2620),
    [sym__single_pattern] = STATE(4761),
    [sym_case_else_branch] = STATE(12581),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_else_keyword] = STATE(156),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_case_statement_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5495),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(2415)] = {
    [aux_sym_option_member_list_repeat2] = STATE(2415),
    [sym_identifier] = ACTIONS(565),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_EQ] = ACTIONS(567),
    [anon_sym_COMMA] = ACTIONS(5497),
    [anon_sym_DASH] = ACTIONS(565),
    [aux_sym_boolean_token1] = ACTIONS(565),
    [aux_sym_boolean_token2] = ACTIONS(565),
    [aux_sym_where_condition_token1] = ACTIONS(565),
    [anon_sym_DOT_DOT] = ACTIONS(567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(565),
    [anon_sym_STAR] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [aux_sym_record_type_token1] = ACTIONS(565),
    [aux_sym_basic_type_token21] = ACTIONS(565),
    [aux_sym_basic_type_token22] = ACTIONS(565),
    [aux_sym_basic_type_token48] = ACTIONS(565),
    [aux_sym_basic_type_token53] = ACTIONS(565),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(565),
    [aux_sym_separator_action_token1] = ACTIONS(565),
    [aux_sym_type_declaration_token1] = ACTIONS(565),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(567),
    [aux_sym__expression_token1] = ACTIONS(567),
    [aux_sym__expression_token2] = ACTIONS(567),
    [aux_sym_keyword_identifier_token1] = ACTIONS(565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(565),
    [anon_sym_SLASH] = ACTIONS(565),
    [anon_sym_div] = ACTIONS(565),
    [anon_sym_DIV] = ACTIONS(565),
    [anon_sym_Div] = ACTIONS(565),
    [anon_sym_mod] = ACTIONS(565),
    [anon_sym_MOD] = ACTIONS(565),
    [anon_sym_Mod] = ACTIONS(565),
    [anon_sym_PLUS] = ACTIONS(565),
    [anon_sym_GT_EQ] = ACTIONS(567),
    [anon_sym_LT_EQ] = ACTIONS(567),
    [anon_sym_GT] = ACTIONS(565),
    [anon_sym_LT] = ACTIONS(565),
    [anon_sym_LT_GT] = ACTIONS(567),
    [anon_sym_and] = ACTIONS(565),
    [anon_sym_AND] = ACTIONS(565),
    [anon_sym_And] = ACTIONS(565),
    [anon_sym_or] = ACTIONS(565),
    [anon_sym_OR] = ACTIONS(565),
    [anon_sym_Or] = ACTIONS(565),
    [anon_sym_xor] = ACTIONS(565),
    [anon_sym_XOR] = ACTIONS(565),
    [anon_sym_Xor] = ACTIONS(565),
    [anon_sym_QMARK] = ACTIONS(567),
    [anon_sym_in] = ACTIONS(565),
    [anon_sym_IN] = ACTIONS(565),
    [anon_sym_In] = ACTIONS(565),
    [anon_sym_to] = ACTIONS(565),
    [anon_sym_TO] = ACTIONS(565),
    [anon_sym_To] = ACTIONS(565),
    [anon_sym_downto] = ACTIONS(565),
    [anon_sym_DOWNTO] = ACTIONS(565),
    [anon_sym_Downto] = ACTIONS(565),
    [sym_page_keyword] = ACTIONS(565),
    [anon_sym_codeunit] = ACTIONS(565),
    [anon_sym_CODEUNIT] = ACTIONS(565),
    [anon_sym_Codeunit] = ACTIONS(565),
    [anon_sym_CodeUnit] = ACTIONS(565),
    [anon_sym_COdeunit] = ACTIONS(565),
    [anon_sym_codeUnit] = ACTIONS(565),
    [sym_report_keyword] = ACTIONS(565),
    [sym_query_keyword] = ACTIONS(565),
    [anon_sym_xmlport] = ACTIONS(565),
    [anon_sym_XMLPORT] = ACTIONS(565),
    [anon_sym_Xmlport] = ACTIONS(565),
    [anon_sym_XMLport] = ACTIONS(565),
    [anon_sym_XMLPort] = ACTIONS(565),
    [anon_sym_XmlPort] = ACTIONS(565),
    [anon_sym_enum] = ACTIONS(565),
    [anon_sym_ENUM] = ACTIONS(565),
    [anon_sym_Enum] = ACTIONS(565),
    [anon_sym_eNUM] = ACTIONS(565),
    [anon_sym_eNum] = ACTIONS(565),
    [anon_sym_ENum] = ACTIONS(565),
    [sym_local_keyword] = ACTIONS(565),
    [sym_internal_keyword] = ACTIONS(565),
    [sym_protected_keyword] = ACTIONS(565),
    [sym_key_keyword] = ACTIONS(565),
    [sym_dataset_keyword] = ACTIONS(565),
    [sym_quoted_identifier] = ACTIONS(567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(567),
    [sym_integer] = ACTIONS(567),
  },
  [STATE(2416)] = {
    [sym_identifier] = ACTIONS(4658),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_COMMA] = ACTIONS(4660),
    [anon_sym_COLON] = ACTIONS(4658),
    [anon_sym_DASH] = ACTIONS(4662),
    [aux_sym_boolean_token1] = ACTIONS(4658),
    [aux_sym_boolean_token2] = ACTIONS(4658),
    [sym_decimal] = ACTIONS(4658),
    [anon_sym_LPAREN] = ACTIONS(4660),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4658),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(4665),
    [aux_sym_record_type_token1] = ACTIONS(4658),
    [aux_sym_basic_type_token21] = ACTIONS(4658),
    [aux_sym_basic_type_token22] = ACTIONS(4658),
    [aux_sym_basic_type_token48] = ACTIONS(4658),
    [anon_sym_COLON_COLON] = ACTIONS(5337),
    [anon_sym_POUNDif] = ACTIONS(4660),
    [anon_sym_POUNDIF] = ACTIONS(4660),
    [anon_sym_POUNDIf] = ACTIONS(4660),
    [anon_sym_not] = ACTIONS(4658),
    [anon_sym_NOT] = ACTIONS(4658),
    [anon_sym_Not] = ACTIONS(4658),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4658),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4658),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(4662),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(4660),
    [sym_date_literal] = ACTIONS(4658),
    [sym_time_literal] = ACTIONS(4658),
    [sym_biginteger_literal] = ACTIONS(4660),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(4658),
    [anon_sym_codeunit] = ACTIONS(4658),
    [anon_sym_CODEUNIT] = ACTIONS(4658),
    [anon_sym_Codeunit] = ACTIONS(4658),
    [anon_sym_CodeUnit] = ACTIONS(4658),
    [anon_sym_COdeunit] = ACTIONS(4658),
    [anon_sym_codeUnit] = ACTIONS(4658),
    [sym_report_keyword] = ACTIONS(4658),
    [sym_query_keyword] = ACTIONS(4658),
    [anon_sym_xmlport] = ACTIONS(4658),
    [anon_sym_XMLPORT] = ACTIONS(4658),
    [anon_sym_Xmlport] = ACTIONS(4658),
    [anon_sym_XMLport] = ACTIONS(4658),
    [anon_sym_XMLPort] = ACTIONS(4658),
    [anon_sym_XmlPort] = ACTIONS(4658),
    [anon_sym_enum] = ACTIONS(4658),
    [anon_sym_ENUM] = ACTIONS(4658),
    [anon_sym_Enum] = ACTIONS(4658),
    [anon_sym_eNUM] = ACTIONS(4658),
    [anon_sym_eNum] = ACTIONS(4658),
    [anon_sym_ENum] = ACTIONS(4658),
    [sym_quoted_identifier] = ACTIONS(4660),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4660),
    [sym_integer] = ACTIONS(4658),
    [sym_continue_as_identifier] = ACTIONS(4660),
    [sym_preproc_open] = ACTIONS(4660),
  },
  [STATE(2417)] = {
    [sym_identifier] = ACTIONS(4815),
    [anon_sym_SEMI] = ACTIONS(4817),
    [anon_sym_DASH] = ACTIONS(4817),
    [aux_sym_boolean_token1] = ACTIONS(4815),
    [aux_sym_boolean_token2] = ACTIONS(4815),
    [sym_decimal] = ACTIONS(4815),
    [anon_sym_LPAREN] = ACTIONS(4817),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4817),
    [aux_sym_record_type_token1] = ACTIONS(4815),
    [aux_sym_basic_type_token21] = ACTIONS(4815),
    [aux_sym_basic_type_token22] = ACTIONS(4815),
    [aux_sym_basic_type_token48] = ACTIONS(4815),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(4815),
    [anon_sym_POUNDif] = ACTIONS(4817),
    [anon_sym_POUNDIF] = ACTIONS(4817),
    [anon_sym_POUNDIf] = ACTIONS(4817),
    [anon_sym_not] = ACTIONS(4815),
    [anon_sym_NOT] = ACTIONS(4815),
    [anon_sym_Not] = ACTIONS(4815),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4815),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4815),
    [anon_sym_PLUS] = ACTIONS(4817),
    [sym_datetime_literal] = ACTIONS(4817),
    [sym_date_literal] = ACTIONS(4815),
    [sym_time_literal] = ACTIONS(4815),
    [sym_biginteger_literal] = ACTIONS(4817),
    [anon_sym_if] = ACTIONS(4815),
    [anon_sym_IF] = ACTIONS(4815),
    [anon_sym_If] = ACTIONS(4815),
    [anon_sym_case] = ACTIONS(4815),
    [anon_sym_CASE] = ACTIONS(4815),
    [anon_sym_Case] = ACTIONS(4815),
    [anon_sym_for] = ACTIONS(4815),
    [anon_sym_FOR] = ACTIONS(4815),
    [anon_sym_For] = ACTIONS(4815),
    [anon_sym_foreach] = ACTIONS(4815),
    [anon_sym_FOREACH] = ACTIONS(4815),
    [anon_sym_Foreach] = ACTIONS(4815),
    [anon_sym_while] = ACTIONS(4815),
    [anon_sym_WHILE] = ACTIONS(4815),
    [anon_sym_While] = ACTIONS(4815),
    [anon_sym_repeat] = ACTIONS(4815),
    [anon_sym_REPEAT] = ACTIONS(4815),
    [anon_sym_Repeat] = ACTIONS(4815),
    [anon_sym_exit] = ACTIONS(4815),
    [anon_sym_EXIT] = ACTIONS(4815),
    [anon_sym_Exit] = ACTIONS(4815),
    [anon_sym_continue] = ACTIONS(4815),
    [anon_sym_CONTINUE] = ACTIONS(4815),
    [anon_sym_Continue] = ACTIONS(4815),
    [anon_sym_break] = ACTIONS(4815),
    [anon_sym_BREAK] = ACTIONS(4815),
    [anon_sym_Break] = ACTIONS(4815),
    [anon_sym_with] = ACTIONS(4815),
    [anon_sym_WITH] = ACTIONS(4815),
    [anon_sym_With] = ACTIONS(4815),
    [sym_asserterror_keyword] = ACTIONS(4817),
    [sym_page_keyword] = ACTIONS(4815),
    [anon_sym_codeunit] = ACTIONS(4815),
    [anon_sym_CODEUNIT] = ACTIONS(4815),
    [anon_sym_Codeunit] = ACTIONS(4815),
    [anon_sym_CodeUnit] = ACTIONS(4815),
    [anon_sym_COdeunit] = ACTIONS(4815),
    [anon_sym_codeUnit] = ACTIONS(4815),
    [sym_report_keyword] = ACTIONS(4815),
    [sym_query_keyword] = ACTIONS(4815),
    [anon_sym_xmlport] = ACTIONS(4815),
    [anon_sym_XMLPORT] = ACTIONS(4815),
    [anon_sym_Xmlport] = ACTIONS(4815),
    [anon_sym_XMLport] = ACTIONS(4815),
    [anon_sym_XMLPort] = ACTIONS(4815),
    [anon_sym_XmlPort] = ACTIONS(4815),
    [anon_sym_enum] = ACTIONS(4815),
    [anon_sym_ENUM] = ACTIONS(4815),
    [anon_sym_Enum] = ACTIONS(4815),
    [anon_sym_eNUM] = ACTIONS(4815),
    [anon_sym_eNum] = ACTIONS(4815),
    [anon_sym_ENum] = ACTIONS(4815),
    [sym_quoted_identifier] = ACTIONS(4817),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4817),
    [sym_integer] = ACTIONS(4815),
    [sym_continue_as_identifier] = ACTIONS(4817),
    [sym_preproc_open] = ACTIONS(4817),
    [sym_begin_keyword] = ACTIONS(4817),
    [sym_preproc_split_begin] = ACTIONS(4817),
  },
  [STATE(2418)] = {
    [sym__body_element] = STATE(2454),
    [sym_empty_statement] = STATE(2454),
    [sym_property] = STATE(2454),
    [sym_fields_section] = STATE(2454),
    [sym_keys_section] = STATE(2454),
    [sym_fieldgroups_section] = STATE(2454),
    [sym_enum_value_declaration] = STATE(2454),
    [sym_labels_section] = STATE(2454),
    [sym_layout_section] = STATE(2454),
    [sym_modify_modification] = STATE(2454),
    [sym_actions_section] = STATE(2454),
    [sym_views_section] = STATE(2454),
    [sym_dataset_section] = STATE(2454),
    [sym_requestpage_section] = STATE(2454),
    [sym_rendering_section] = STATE(2454),
    [sym_elements_section] = STATE(2454),
    [sym_schema_section] = STATE(2454),
    [sym_assembly_declaration] = STATE(2454),
    [sym_event_declaration] = STATE(2454),
    [sym_procedure] = STATE(2454),
    [sym_preproc_split_procedure] = STATE(2454),
    [sym__procedure_header] = STATE(8113),
    [sym_procedure_modifier] = STATE(12270),
    [sym_trigger_declaration] = STATE(2454),
    [sym_var_section] = STATE(2454),
    [sym_var_attribute_item] = STATE(2454),
    [sym_variable_declaration] = STATE(2454),
    [sym_attribute_item] = STATE(5230),
    [sym_preproc_conditional] = STATE(2454),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_elif] = STATE(2572),
    [sym_preproc_else] = STATE(2688),
    [sym_preproc_endif] = STATE(7594),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2454),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(7984),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(5512),
    [anon_sym_POUNDELIF] = ACTIONS(5512),
    [anon_sym_POUNDElif] = ACTIONS(5512),
    [anon_sym_POUNDelse] = ACTIONS(5514),
    [anon_sym_POUNDELSE] = ACTIONS(5514),
    [anon_sym_POUNDElse] = ACTIONS(5514),
    [anon_sym_POUNDendif] = ACTIONS(5516),
    [anon_sym_POUNDENDIF] = ACTIONS(5516),
    [anon_sym_POUNDEndif] = ACTIONS(5516),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5518),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5516),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2419)] = {
    [sym__body_element] = STATE(2450),
    [sym_empty_statement] = STATE(2450),
    [sym_property] = STATE(2450),
    [sym_fields_section] = STATE(2450),
    [sym_keys_section] = STATE(2450),
    [sym_fieldgroups_section] = STATE(2450),
    [sym_enum_value_declaration] = STATE(2450),
    [sym_labels_section] = STATE(2450),
    [sym_layout_section] = STATE(2450),
    [sym_modify_modification] = STATE(2450),
    [sym_actions_section] = STATE(2450),
    [sym_views_section] = STATE(2450),
    [sym_dataset_section] = STATE(2450),
    [sym_requestpage_section] = STATE(2450),
    [sym_rendering_section] = STATE(2450),
    [sym_elements_section] = STATE(2450),
    [sym_schema_section] = STATE(2450),
    [sym_assembly_declaration] = STATE(2450),
    [sym_event_declaration] = STATE(2450),
    [sym_procedure] = STATE(2450),
    [sym_preproc_split_procedure] = STATE(2450),
    [sym__procedure_header] = STATE(8100),
    [sym_procedure_modifier] = STATE(12270),
    [sym_trigger_declaration] = STATE(2450),
    [sym_var_section] = STATE(2450),
    [sym_var_attribute_item] = STATE(2450),
    [sym_variable_declaration] = STATE(2450),
    [sym_attribute_item] = STATE(5230),
    [sym_preproc_conditional] = STATE(2450),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_elif] = STATE(2572),
    [sym_preproc_else] = STATE(2694),
    [sym_preproc_endif] = STATE(7519),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2450),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(7864),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(5512),
    [anon_sym_POUNDELIF] = ACTIONS(5512),
    [anon_sym_POUNDElif] = ACTIONS(5512),
    [anon_sym_POUNDelse] = ACTIONS(5514),
    [anon_sym_POUNDELSE] = ACTIONS(5514),
    [anon_sym_POUNDElse] = ACTIONS(5514),
    [anon_sym_POUNDendif] = ACTIONS(5560),
    [anon_sym_POUNDENDIF] = ACTIONS(5560),
    [anon_sym_POUNDEndif] = ACTIONS(5560),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5518),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5560),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2420)] = {
    [sym__body_element] = STATE(2452),
    [sym_empty_statement] = STATE(2452),
    [sym_property] = STATE(2452),
    [sym_fields_section] = STATE(2452),
    [sym_keys_section] = STATE(2452),
    [sym_fieldgroups_section] = STATE(2452),
    [sym_enum_value_declaration] = STATE(2452),
    [sym_labels_section] = STATE(2452),
    [sym_layout_section] = STATE(2452),
    [sym_modify_modification] = STATE(2452),
    [sym_actions_section] = STATE(2452),
    [sym_views_section] = STATE(2452),
    [sym_dataset_section] = STATE(2452),
    [sym_requestpage_section] = STATE(2452),
    [sym_rendering_section] = STATE(2452),
    [sym_elements_section] = STATE(2452),
    [sym_schema_section] = STATE(2452),
    [sym_assembly_declaration] = STATE(2452),
    [sym_event_declaration] = STATE(2452),
    [sym_procedure] = STATE(2452),
    [sym_preproc_split_procedure] = STATE(2452),
    [sym__procedure_header] = STATE(8067),
    [sym_procedure_modifier] = STATE(12270),
    [sym_trigger_declaration] = STATE(2452),
    [sym_var_section] = STATE(2452),
    [sym_var_attribute_item] = STATE(2452),
    [sym_variable_declaration] = STATE(2452),
    [sym_attribute_item] = STATE(5230),
    [sym_preproc_conditional] = STATE(2452),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_elif] = STATE(2572),
    [sym_preproc_else] = STATE(2689),
    [sym_preproc_endif] = STATE(3800),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2452),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(7838),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(5512),
    [anon_sym_POUNDELIF] = ACTIONS(5512),
    [anon_sym_POUNDElif] = ACTIONS(5512),
    [anon_sym_POUNDelse] = ACTIONS(5514),
    [anon_sym_POUNDELSE] = ACTIONS(5514),
    [anon_sym_POUNDElse] = ACTIONS(5514),
    [anon_sym_POUNDendif] = ACTIONS(5562),
    [anon_sym_POUNDENDIF] = ACTIONS(5562),
    [anon_sym_POUNDEndif] = ACTIONS(5562),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5518),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5562),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2421)] = {
    [sym_identifier] = ACTIONS(5564),
    [anon_sym_SEMI] = ACTIONS(5566),
    [anon_sym_DASH] = ACTIONS(5566),
    [aux_sym_boolean_token1] = ACTIONS(5564),
    [aux_sym_boolean_token2] = ACTIONS(5564),
    [sym_decimal] = ACTIONS(5564),
    [anon_sym_LPAREN] = ACTIONS(5566),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5564),
    [anon_sym_LBRACK] = ACTIONS(5566),
    [aux_sym_record_type_token1] = ACTIONS(5564),
    [aux_sym_basic_type_token21] = ACTIONS(5564),
    [aux_sym_basic_type_token22] = ACTIONS(5564),
    [aux_sym_basic_type_token48] = ACTIONS(5564),
    [anon_sym_POUNDif] = ACTIONS(5566),
    [anon_sym_POUNDIF] = ACTIONS(5566),
    [anon_sym_POUNDIf] = ACTIONS(5566),
    [anon_sym_not] = ACTIONS(5564),
    [anon_sym_NOT] = ACTIONS(5564),
    [anon_sym_Not] = ACTIONS(5564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5564),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5564),
    [anon_sym_PLUS] = ACTIONS(5566),
    [sym_datetime_literal] = ACTIONS(5566),
    [sym_date_literal] = ACTIONS(5564),
    [sym_time_literal] = ACTIONS(5564),
    [sym_biginteger_literal] = ACTIONS(5566),
    [anon_sym_if] = ACTIONS(5564),
    [anon_sym_IF] = ACTIONS(5564),
    [anon_sym_If] = ACTIONS(5564),
    [anon_sym_case] = ACTIONS(5564),
    [anon_sym_CASE] = ACTIONS(5564),
    [anon_sym_Case] = ACTIONS(5564),
    [anon_sym_for] = ACTIONS(5564),
    [anon_sym_FOR] = ACTIONS(5564),
    [anon_sym_For] = ACTIONS(5564),
    [anon_sym_foreach] = ACTIONS(5564),
    [anon_sym_FOREACH] = ACTIONS(5564),
    [anon_sym_Foreach] = ACTIONS(5564),
    [anon_sym_while] = ACTIONS(5564),
    [anon_sym_WHILE] = ACTIONS(5564),
    [anon_sym_While] = ACTIONS(5564),
    [anon_sym_repeat] = ACTIONS(5564),
    [anon_sym_REPEAT] = ACTIONS(5564),
    [anon_sym_Repeat] = ACTIONS(5564),
    [anon_sym_until] = ACTIONS(5564),
    [anon_sym_UNTIL] = ACTIONS(5564),
    [anon_sym_Until] = ACTIONS(5564),
    [anon_sym_exit] = ACTIONS(5564),
    [anon_sym_EXIT] = ACTIONS(5564),
    [anon_sym_Exit] = ACTIONS(5564),
    [anon_sym_continue] = ACTIONS(5564),
    [anon_sym_CONTINUE] = ACTIONS(5564),
    [anon_sym_Continue] = ACTIONS(5564),
    [anon_sym_break] = ACTIONS(5564),
    [anon_sym_BREAK] = ACTIONS(5564),
    [anon_sym_Break] = ACTIONS(5564),
    [anon_sym_with] = ACTIONS(5564),
    [anon_sym_WITH] = ACTIONS(5564),
    [anon_sym_With] = ACTIONS(5564),
    [sym_asserterror_keyword] = ACTIONS(5566),
    [sym_page_keyword] = ACTIONS(5564),
    [anon_sym_codeunit] = ACTIONS(5564),
    [anon_sym_CODEUNIT] = ACTIONS(5564),
    [anon_sym_Codeunit] = ACTIONS(5564),
    [anon_sym_CodeUnit] = ACTIONS(5564),
    [anon_sym_COdeunit] = ACTIONS(5564),
    [anon_sym_codeUnit] = ACTIONS(5564),
    [sym_report_keyword] = ACTIONS(5564),
    [sym_query_keyword] = ACTIONS(5564),
    [anon_sym_xmlport] = ACTIONS(5564),
    [anon_sym_XMLPORT] = ACTIONS(5564),
    [anon_sym_Xmlport] = ACTIONS(5564),
    [anon_sym_XMLport] = ACTIONS(5564),
    [anon_sym_XMLPort] = ACTIONS(5564),
    [anon_sym_XmlPort] = ACTIONS(5564),
    [anon_sym_enum] = ACTIONS(5564),
    [anon_sym_ENUM] = ACTIONS(5564),
    [anon_sym_Enum] = ACTIONS(5564),
    [anon_sym_eNUM] = ACTIONS(5564),
    [anon_sym_eNum] = ACTIONS(5564),
    [anon_sym_ENum] = ACTIONS(5564),
    [sym_quoted_identifier] = ACTIONS(5566),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5566),
    [sym_integer] = ACTIONS(5564),
    [sym_continue_as_identifier] = ACTIONS(5566),
    [sym_preproc_open] = ACTIONS(5566),
  },
  [STATE(2422)] = {
    [sym__body_element] = STATE(2453),
    [sym_empty_statement] = STATE(2453),
    [sym_property] = STATE(2453),
    [sym_fields_section] = STATE(2453),
    [sym_keys_section] = STATE(2453),
    [sym_fieldgroups_section] = STATE(2453),
    [sym_enum_value_declaration] = STATE(2453),
    [sym_labels_section] = STATE(2453),
    [sym_layout_section] = STATE(2453),
    [sym_modify_modification] = STATE(2453),
    [sym_actions_section] = STATE(2453),
    [sym_views_section] = STATE(2453),
    [sym_dataset_section] = STATE(2453),
    [sym_requestpage_section] = STATE(2453),
    [sym_rendering_section] = STATE(2453),
    [sym_elements_section] = STATE(2453),
    [sym_schema_section] = STATE(2453),
    [sym_assembly_declaration] = STATE(2453),
    [sym_event_declaration] = STATE(2453),
    [sym_procedure] = STATE(2453),
    [sym_preproc_split_procedure] = STATE(2453),
    [sym__procedure_header] = STATE(8096),
    [sym_procedure_modifier] = STATE(12270),
    [sym_trigger_declaration] = STATE(2453),
    [sym_var_section] = STATE(2453),
    [sym_var_attribute_item] = STATE(2453),
    [sym_variable_declaration] = STATE(2453),
    [sym_attribute_item] = STATE(5230),
    [sym_preproc_conditional] = STATE(2453),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_elif] = STATE(2572),
    [sym_preproc_else] = STATE(2679),
    [sym_preproc_endif] = STATE(2910),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2453),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(8164),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(5512),
    [anon_sym_POUNDELIF] = ACTIONS(5512),
    [anon_sym_POUNDElif] = ACTIONS(5512),
    [anon_sym_POUNDelse] = ACTIONS(5514),
    [anon_sym_POUNDELSE] = ACTIONS(5514),
    [anon_sym_POUNDElse] = ACTIONS(5514),
    [anon_sym_POUNDendif] = ACTIONS(5568),
    [anon_sym_POUNDENDIF] = ACTIONS(5568),
    [anon_sym_POUNDEndif] = ACTIONS(5568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5518),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5568),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2423)] = {
    [sym__body_element] = STATE(2448),
    [sym_empty_statement] = STATE(2448),
    [sym_property] = STATE(2448),
    [sym_fields_section] = STATE(2448),
    [sym_keys_section] = STATE(2448),
    [sym_fieldgroups_section] = STATE(2448),
    [sym_enum_value_declaration] = STATE(2448),
    [sym_labels_section] = STATE(2448),
    [sym_layout_section] = STATE(2448),
    [sym_modify_modification] = STATE(2448),
    [sym_actions_section] = STATE(2448),
    [sym_views_section] = STATE(2448),
    [sym_dataset_section] = STATE(2448),
    [sym_requestpage_section] = STATE(2448),
    [sym_rendering_section] = STATE(2448),
    [sym_elements_section] = STATE(2448),
    [sym_schema_section] = STATE(2448),
    [sym_assembly_declaration] = STATE(2448),
    [sym_event_declaration] = STATE(2448),
    [sym_procedure] = STATE(2448),
    [sym_preproc_split_procedure] = STATE(2448),
    [sym__procedure_header] = STATE(8118),
    [sym_procedure_modifier] = STATE(12270),
    [sym_trigger_declaration] = STATE(2448),
    [sym_var_section] = STATE(2448),
    [sym_var_attribute_item] = STATE(2448),
    [sym_variable_declaration] = STATE(2448),
    [sym_attribute_item] = STATE(5230),
    [sym_preproc_conditional] = STATE(2448),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_elif] = STATE(2572),
    [sym_preproc_else] = STATE(2708),
    [sym_preproc_endif] = STATE(5869),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2448),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(8032),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(5512),
    [anon_sym_POUNDELIF] = ACTIONS(5512),
    [anon_sym_POUNDElif] = ACTIONS(5512),
    [anon_sym_POUNDelse] = ACTIONS(5514),
    [anon_sym_POUNDELSE] = ACTIONS(5514),
    [anon_sym_POUNDElse] = ACTIONS(5514),
    [anon_sym_POUNDendif] = ACTIONS(5570),
    [anon_sym_POUNDENDIF] = ACTIONS(5570),
    [anon_sym_POUNDEndif] = ACTIONS(5570),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5518),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5570),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2424)] = {
    [sym__body_element] = STATE(2451),
    [sym_empty_statement] = STATE(2451),
    [sym_property] = STATE(2451),
    [sym_fields_section] = STATE(2451),
    [sym_keys_section] = STATE(2451),
    [sym_fieldgroups_section] = STATE(2451),
    [sym_enum_value_declaration] = STATE(2451),
    [sym_labels_section] = STATE(2451),
    [sym_layout_section] = STATE(2451),
    [sym_modify_modification] = STATE(2451),
    [sym_actions_section] = STATE(2451),
    [sym_views_section] = STATE(2451),
    [sym_dataset_section] = STATE(2451),
    [sym_requestpage_section] = STATE(2451),
    [sym_rendering_section] = STATE(2451),
    [sym_elements_section] = STATE(2451),
    [sym_schema_section] = STATE(2451),
    [sym_assembly_declaration] = STATE(2451),
    [sym_event_declaration] = STATE(2451),
    [sym_procedure] = STATE(2451),
    [sym_preproc_split_procedure] = STATE(2451),
    [sym__procedure_header] = STATE(8125),
    [sym_procedure_modifier] = STATE(12270),
    [sym_trigger_declaration] = STATE(2451),
    [sym_var_section] = STATE(2451),
    [sym_var_attribute_item] = STATE(2451),
    [sym_variable_declaration] = STATE(2451),
    [sym_attribute_item] = STATE(5230),
    [sym_preproc_conditional] = STATE(2451),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_elif] = STATE(2572),
    [sym_preproc_else] = STATE(2669),
    [sym_preproc_endif] = STATE(4766),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2451),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(8044),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(5512),
    [anon_sym_POUNDELIF] = ACTIONS(5512),
    [anon_sym_POUNDElif] = ACTIONS(5512),
    [anon_sym_POUNDelse] = ACTIONS(5514),
    [anon_sym_POUNDELSE] = ACTIONS(5514),
    [anon_sym_POUNDElse] = ACTIONS(5514),
    [anon_sym_POUNDendif] = ACTIONS(5572),
    [anon_sym_POUNDENDIF] = ACTIONS(5572),
    [anon_sym_POUNDEndif] = ACTIONS(5572),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5518),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5572),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2425)] = {
    [sym__body_element] = STATE(2449),
    [sym_empty_statement] = STATE(2449),
    [sym_property] = STATE(2449),
    [sym_fields_section] = STATE(2449),
    [sym_keys_section] = STATE(2449),
    [sym_fieldgroups_section] = STATE(2449),
    [sym_enum_value_declaration] = STATE(2449),
    [sym_labels_section] = STATE(2449),
    [sym_layout_section] = STATE(2449),
    [sym_modify_modification] = STATE(2449),
    [sym_actions_section] = STATE(2449),
    [sym_views_section] = STATE(2449),
    [sym_dataset_section] = STATE(2449),
    [sym_requestpage_section] = STATE(2449),
    [sym_rendering_section] = STATE(2449),
    [sym_elements_section] = STATE(2449),
    [sym_schema_section] = STATE(2449),
    [sym_assembly_declaration] = STATE(2449),
    [sym_event_declaration] = STATE(2449),
    [sym_procedure] = STATE(2449),
    [sym_preproc_split_procedure] = STATE(2449),
    [sym__procedure_header] = STATE(8116),
    [sym_procedure_modifier] = STATE(12270),
    [sym_trigger_declaration] = STATE(2449),
    [sym_var_section] = STATE(2449),
    [sym_var_attribute_item] = STATE(2449),
    [sym_variable_declaration] = STATE(2449),
    [sym_attribute_item] = STATE(5230),
    [sym_preproc_conditional] = STATE(2449),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_elif] = STATE(2572),
    [sym_preproc_else] = STATE(2702),
    [sym_preproc_endif] = STATE(5091),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2449),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(8016),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(5512),
    [anon_sym_POUNDELIF] = ACTIONS(5512),
    [anon_sym_POUNDElif] = ACTIONS(5512),
    [anon_sym_POUNDelse] = ACTIONS(5514),
    [anon_sym_POUNDELSE] = ACTIONS(5514),
    [anon_sym_POUNDElse] = ACTIONS(5514),
    [anon_sym_POUNDendif] = ACTIONS(5574),
    [anon_sym_POUNDENDIF] = ACTIONS(5574),
    [anon_sym_POUNDEndif] = ACTIONS(5574),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5518),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5574),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2426)] = {
    [sym__body_element] = STATE(2455),
    [sym_empty_statement] = STATE(2455),
    [sym_property] = STATE(2455),
    [sym_fields_section] = STATE(2455),
    [sym_keys_section] = STATE(2455),
    [sym_fieldgroups_section] = STATE(2455),
    [sym_enum_value_declaration] = STATE(2455),
    [sym_labels_section] = STATE(2455),
    [sym_layout_section] = STATE(2455),
    [sym_modify_modification] = STATE(2455),
    [sym_actions_section] = STATE(2455),
    [sym_views_section] = STATE(2455),
    [sym_dataset_section] = STATE(2455),
    [sym_requestpage_section] = STATE(2455),
    [sym_rendering_section] = STATE(2455),
    [sym_elements_section] = STATE(2455),
    [sym_schema_section] = STATE(2455),
    [sym_assembly_declaration] = STATE(2455),
    [sym_event_declaration] = STATE(2455),
    [sym_procedure] = STATE(2455),
    [sym_preproc_split_procedure] = STATE(2455),
    [sym__procedure_header] = STATE(8103),
    [sym_procedure_modifier] = STATE(12270),
    [sym_trigger_declaration] = STATE(2455),
    [sym_var_section] = STATE(2455),
    [sym_var_attribute_item] = STATE(2455),
    [sym_variable_declaration] = STATE(2455),
    [sym_attribute_item] = STATE(5230),
    [sym_preproc_conditional] = STATE(2455),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_elif] = STATE(2572),
    [sym_preproc_else] = STATE(2715),
    [sym_preproc_endif] = STATE(7097),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2455),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(7928),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(5512),
    [anon_sym_POUNDELIF] = ACTIONS(5512),
    [anon_sym_POUNDElif] = ACTIONS(5512),
    [anon_sym_POUNDelse] = ACTIONS(5514),
    [anon_sym_POUNDELSE] = ACTIONS(5514),
    [anon_sym_POUNDElse] = ACTIONS(5514),
    [anon_sym_POUNDendif] = ACTIONS(5576),
    [anon_sym_POUNDENDIF] = ACTIONS(5576),
    [anon_sym_POUNDEndif] = ACTIONS(5576),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5518),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5576),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2427)] = {
    [sym_identifier] = ACTIONS(4819),
    [anon_sym_SEMI] = ACTIONS(4821),
    [anon_sym_DASH] = ACTIONS(4821),
    [aux_sym_boolean_token1] = ACTIONS(4819),
    [aux_sym_boolean_token2] = ACTIONS(4819),
    [sym_decimal] = ACTIONS(4819),
    [anon_sym_LPAREN] = ACTIONS(4821),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [aux_sym_record_type_token1] = ACTIONS(4819),
    [aux_sym_basic_type_token21] = ACTIONS(4819),
    [aux_sym_basic_type_token22] = ACTIONS(4819),
    [aux_sym_basic_type_token48] = ACTIONS(4819),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(4819),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4819),
    [anon_sym_POUNDif] = ACTIONS(4821),
    [anon_sym_POUNDIF] = ACTIONS(4821),
    [anon_sym_POUNDIf] = ACTIONS(4821),
    [anon_sym_not] = ACTIONS(4819),
    [anon_sym_NOT] = ACTIONS(4819),
    [anon_sym_Not] = ACTIONS(4819),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4819),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4819),
    [anon_sym_PLUS] = ACTIONS(4821),
    [sym_datetime_literal] = ACTIONS(4821),
    [sym_date_literal] = ACTIONS(4819),
    [sym_time_literal] = ACTIONS(4819),
    [sym_biginteger_literal] = ACTIONS(4821),
    [anon_sym_if] = ACTIONS(4819),
    [anon_sym_IF] = ACTIONS(4819),
    [anon_sym_If] = ACTIONS(4819),
    [anon_sym_case] = ACTIONS(4819),
    [anon_sym_CASE] = ACTIONS(4819),
    [anon_sym_Case] = ACTIONS(4819),
    [anon_sym_for] = ACTIONS(4819),
    [anon_sym_FOR] = ACTIONS(4819),
    [anon_sym_For] = ACTIONS(4819),
    [anon_sym_foreach] = ACTIONS(4819),
    [anon_sym_FOREACH] = ACTIONS(4819),
    [anon_sym_Foreach] = ACTIONS(4819),
    [anon_sym_while] = ACTIONS(4819),
    [anon_sym_WHILE] = ACTIONS(4819),
    [anon_sym_While] = ACTIONS(4819),
    [anon_sym_repeat] = ACTIONS(4819),
    [anon_sym_REPEAT] = ACTIONS(4819),
    [anon_sym_Repeat] = ACTIONS(4819),
    [anon_sym_exit] = ACTIONS(4819),
    [anon_sym_EXIT] = ACTIONS(4819),
    [anon_sym_Exit] = ACTIONS(4819),
    [anon_sym_continue] = ACTIONS(4819),
    [anon_sym_CONTINUE] = ACTIONS(4819),
    [anon_sym_Continue] = ACTIONS(4819),
    [anon_sym_break] = ACTIONS(4819),
    [anon_sym_BREAK] = ACTIONS(4819),
    [anon_sym_Break] = ACTIONS(4819),
    [anon_sym_with] = ACTIONS(4819),
    [anon_sym_WITH] = ACTIONS(4819),
    [anon_sym_With] = ACTIONS(4819),
    [sym_asserterror_keyword] = ACTIONS(4821),
    [sym_page_keyword] = ACTIONS(4819),
    [anon_sym_codeunit] = ACTIONS(4819),
    [anon_sym_CODEUNIT] = ACTIONS(4819),
    [anon_sym_Codeunit] = ACTIONS(4819),
    [anon_sym_CodeUnit] = ACTIONS(4819),
    [anon_sym_COdeunit] = ACTIONS(4819),
    [anon_sym_codeUnit] = ACTIONS(4819),
    [sym_report_keyword] = ACTIONS(4819),
    [sym_query_keyword] = ACTIONS(4819),
    [anon_sym_xmlport] = ACTIONS(4819),
    [anon_sym_XMLPORT] = ACTIONS(4819),
    [anon_sym_Xmlport] = ACTIONS(4819),
    [anon_sym_XMLport] = ACTIONS(4819),
    [anon_sym_XMLPort] = ACTIONS(4819),
    [anon_sym_XmlPort] = ACTIONS(4819),
    [anon_sym_enum] = ACTIONS(4819),
    [anon_sym_ENUM] = ACTIONS(4819),
    [anon_sym_Enum] = ACTIONS(4819),
    [anon_sym_eNUM] = ACTIONS(4819),
    [anon_sym_eNum] = ACTIONS(4819),
    [anon_sym_ENum] = ACTIONS(4819),
    [sym_quoted_identifier] = ACTIONS(4821),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4821),
    [sym_integer] = ACTIONS(4819),
    [sym_continue_as_identifier] = ACTIONS(4821),
    [sym_preproc_open] = ACTIONS(4821),
    [sym_begin_keyword] = ACTIONS(4821),
  },
  [STATE(2428)] = {
    [sym__body_element] = STATE(2432),
    [sym_empty_statement] = STATE(2432),
    [sym_property] = STATE(5928),
    [sym_fields_section] = STATE(2432),
    [sym_keys_section] = STATE(2432),
    [sym_fieldgroups_section] = STATE(2432),
    [sym_enum_value_declaration] = STATE(2432),
    [sym_labels_section] = STATE(2432),
    [sym_layout_section] = STATE(2432),
    [sym_modify_modification] = STATE(2432),
    [sym_actions_section] = STATE(2432),
    [sym__action_element] = STATE(2432),
    [sym_action_area_section] = STATE(2432),
    [sym_action_group_section] = STATE(2432),
    [sym_action_declaration] = STATE(2432),
    [sym_separator_action] = STATE(2432),
    [sym_actionref_declaration] = STATE(2432),
    [sym_systemaction_declaration] = STATE(2432),
    [sym_fileuploadaction_declaration] = STATE(2432),
    [sym_customaction_declaration] = STATE(2432),
    [sym_addfirst_action_modification] = STATE(2432),
    [sym_addlast_action_modification] = STATE(2432),
    [sym_addafter_action_modification] = STATE(2432),
    [sym_addbefore_action_modification] = STATE(2432),
    [sym_modify_action_modification] = STATE(2432),
    [sym_views_section] = STATE(2432),
    [sym_dataset_section] = STATE(2432),
    [sym_requestpage_section] = STATE(2432),
    [sym_rendering_section] = STATE(2432),
    [sym_elements_section] = STATE(2432),
    [sym_schema_section] = STATE(2432),
    [sym_assembly_declaration] = STATE(2432),
    [sym_event_declaration] = STATE(2432),
    [sym_procedure] = STATE(2432),
    [sym_preproc_split_procedure] = STATE(2432),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(5928),
    [sym_var_section] = STATE(2432),
    [sym_attribute_item] = STATE(5928),
    [sym_preproc_conditional] = STATE(2432),
    [sym_preproc_if] = STATE(1394),
    [sym_preproc_conditional_actions] = STATE(2432),
    [aux_sym_action_group_section_repeat1] = STATE(2432),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(5578),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5580),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5582),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token22] = ACTIONS(5584),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(5586),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5588),
    [aux_sym_modify_modification_token1] = ACTIONS(5590),
    [aux_sym_separator_action_token1] = ACTIONS(5592),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5594),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5596),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5598),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5600),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(5602),
    [sym_local_keyword] = ACTIONS(5604),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5604),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(5606),
    [sym_group_keyword] = ACTIONS(5608),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(2429)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_elif] = STATE(2560),
    [sym_preproc_else] = STATE(2660),
    [sym_preproc_endif] = STATE(2605),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [aux_sym_preproc_split_case_branch_repeat2] = STATE(8144),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDelif] = ACTIONS(5620),
    [anon_sym_POUNDELIF] = ACTIONS(5620),
    [anon_sym_POUNDElif] = ACTIONS(5620),
    [anon_sym_POUNDelse] = ACTIONS(5622),
    [anon_sym_POUNDELSE] = ACTIONS(5622),
    [anon_sym_POUNDElse] = ACTIONS(5622),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2430)] = {
    [sym_identifier] = ACTIONS(4658),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_COMMA] = ACTIONS(4660),
    [anon_sym_COLON] = ACTIONS(4658),
    [anon_sym_DASH] = ACTIONS(4662),
    [aux_sym_boolean_token1] = ACTIONS(4658),
    [aux_sym_boolean_token2] = ACTIONS(4658),
    [sym_decimal] = ACTIONS(4658),
    [anon_sym_LPAREN] = ACTIONS(4660),
    [anon_sym_DOT_DOT] = ACTIONS(2436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4658),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(4665),
    [aux_sym_record_type_token1] = ACTIONS(4658),
    [aux_sym_basic_type_token21] = ACTIONS(4658),
    [aux_sym_basic_type_token22] = ACTIONS(4658),
    [aux_sym_basic_type_token48] = ACTIONS(4658),
    [anon_sym_POUNDif] = ACTIONS(4660),
    [anon_sym_POUNDIF] = ACTIONS(4660),
    [anon_sym_POUNDIf] = ACTIONS(4660),
    [anon_sym_not] = ACTIONS(4658),
    [anon_sym_NOT] = ACTIONS(4658),
    [anon_sym_Not] = ACTIONS(4658),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4658),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4658),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(4662),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(4660),
    [sym_date_literal] = ACTIONS(4658),
    [sym_time_literal] = ACTIONS(4658),
    [sym_biginteger_literal] = ACTIONS(4660),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(4658),
    [anon_sym_codeunit] = ACTIONS(4658),
    [anon_sym_CODEUNIT] = ACTIONS(4658),
    [anon_sym_Codeunit] = ACTIONS(4658),
    [anon_sym_CodeUnit] = ACTIONS(4658),
    [anon_sym_COdeunit] = ACTIONS(4658),
    [anon_sym_codeUnit] = ACTIONS(4658),
    [sym_report_keyword] = ACTIONS(4658),
    [sym_query_keyword] = ACTIONS(4658),
    [anon_sym_xmlport] = ACTIONS(4658),
    [anon_sym_XMLPORT] = ACTIONS(4658),
    [anon_sym_Xmlport] = ACTIONS(4658),
    [anon_sym_XMLport] = ACTIONS(4658),
    [anon_sym_XMLPort] = ACTIONS(4658),
    [anon_sym_XmlPort] = ACTIONS(4658),
    [anon_sym_enum] = ACTIONS(4658),
    [anon_sym_ENUM] = ACTIONS(4658),
    [anon_sym_Enum] = ACTIONS(4658),
    [anon_sym_eNUM] = ACTIONS(4658),
    [anon_sym_eNum] = ACTIONS(4658),
    [anon_sym_ENum] = ACTIONS(4658),
    [sym_quoted_identifier] = ACTIONS(4660),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4660),
    [sym_integer] = ACTIONS(4658),
    [sym_continue_as_identifier] = ACTIONS(4660),
    [sym_preproc_open] = ACTIONS(4660),
  },
  [STATE(2431)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_elif] = STATE(2560),
    [sym_preproc_else] = STATE(2638),
    [sym_preproc_endif] = STATE(2586),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [aux_sym_preproc_split_case_branch_repeat2] = STATE(8083),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDelif] = ACTIONS(5620),
    [anon_sym_POUNDELIF] = ACTIONS(5620),
    [anon_sym_POUNDElif] = ACTIONS(5620),
    [anon_sym_POUNDelse] = ACTIONS(5622),
    [anon_sym_POUNDELSE] = ACTIONS(5622),
    [anon_sym_POUNDElse] = ACTIONS(5622),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2432)] = {
    [sym__body_element] = STATE(2439),
    [sym_empty_statement] = STATE(2439),
    [sym_property] = STATE(5928),
    [sym_fields_section] = STATE(2439),
    [sym_keys_section] = STATE(2439),
    [sym_fieldgroups_section] = STATE(2439),
    [sym_enum_value_declaration] = STATE(2439),
    [sym_labels_section] = STATE(2439),
    [sym_layout_section] = STATE(2439),
    [sym_modify_modification] = STATE(2439),
    [sym_actions_section] = STATE(2439),
    [sym__action_element] = STATE(2439),
    [sym_action_area_section] = STATE(2439),
    [sym_action_group_section] = STATE(2439),
    [sym_action_declaration] = STATE(2439),
    [sym_separator_action] = STATE(2439),
    [sym_actionref_declaration] = STATE(2439),
    [sym_systemaction_declaration] = STATE(2439),
    [sym_fileuploadaction_declaration] = STATE(2439),
    [sym_customaction_declaration] = STATE(2439),
    [sym_addfirst_action_modification] = STATE(2439),
    [sym_addlast_action_modification] = STATE(2439),
    [sym_addafter_action_modification] = STATE(2439),
    [sym_addbefore_action_modification] = STATE(2439),
    [sym_modify_action_modification] = STATE(2439),
    [sym_views_section] = STATE(2439),
    [sym_dataset_section] = STATE(2439),
    [sym_requestpage_section] = STATE(2439),
    [sym_rendering_section] = STATE(2439),
    [sym_elements_section] = STATE(2439),
    [sym_schema_section] = STATE(2439),
    [sym_assembly_declaration] = STATE(2439),
    [sym_event_declaration] = STATE(2439),
    [sym_procedure] = STATE(2439),
    [sym_preproc_split_procedure] = STATE(2439),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(5928),
    [sym_var_section] = STATE(2439),
    [sym_attribute_item] = STATE(5928),
    [sym_preproc_conditional] = STATE(2439),
    [sym_preproc_if] = STATE(1394),
    [sym_preproc_conditional_actions] = STATE(2439),
    [aux_sym_action_group_section_repeat1] = STATE(2439),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(5632),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5580),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5582),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token22] = ACTIONS(5584),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(5586),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5588),
    [aux_sym_modify_modification_token1] = ACTIONS(5590),
    [aux_sym_separator_action_token1] = ACTIONS(5592),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5594),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5596),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5598),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5600),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(5602),
    [sym_local_keyword] = ACTIONS(5604),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5604),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(5606),
    [sym_group_keyword] = ACTIONS(5608),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(2433)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_elif] = STATE(2560),
    [sym_preproc_else] = STATE(2646),
    [sym_preproc_endif] = STATE(4830),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2440),
    [aux_sym_preproc_split_case_branch_repeat2] = STATE(8086),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDelif] = ACTIONS(5620),
    [anon_sym_POUNDELIF] = ACTIONS(5620),
    [anon_sym_POUNDElif] = ACTIONS(5620),
    [anon_sym_POUNDelse] = ACTIONS(5622),
    [anon_sym_POUNDELSE] = ACTIONS(5622),
    [anon_sym_POUNDElse] = ACTIONS(5622),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2434)] = {
    [sym__body_element] = STATE(2439),
    [sym_empty_statement] = STATE(2439),
    [sym_property] = STATE(5928),
    [sym_fields_section] = STATE(2439),
    [sym_keys_section] = STATE(2439),
    [sym_fieldgroups_section] = STATE(2439),
    [sym_enum_value_declaration] = STATE(2439),
    [sym_labels_section] = STATE(2439),
    [sym_layout_section] = STATE(2439),
    [sym_modify_modification] = STATE(2439),
    [sym_actions_section] = STATE(2439),
    [sym__action_element] = STATE(2439),
    [sym_action_area_section] = STATE(2439),
    [sym_action_group_section] = STATE(2439),
    [sym_action_declaration] = STATE(2439),
    [sym_separator_action] = STATE(2439),
    [sym_actionref_declaration] = STATE(2439),
    [sym_systemaction_declaration] = STATE(2439),
    [sym_fileuploadaction_declaration] = STATE(2439),
    [sym_customaction_declaration] = STATE(2439),
    [sym_addfirst_action_modification] = STATE(2439),
    [sym_addlast_action_modification] = STATE(2439),
    [sym_addafter_action_modification] = STATE(2439),
    [sym_addbefore_action_modification] = STATE(2439),
    [sym_modify_action_modification] = STATE(2439),
    [sym_views_section] = STATE(2439),
    [sym_dataset_section] = STATE(2439),
    [sym_requestpage_section] = STATE(2439),
    [sym_rendering_section] = STATE(2439),
    [sym_elements_section] = STATE(2439),
    [sym_schema_section] = STATE(2439),
    [sym_assembly_declaration] = STATE(2439),
    [sym_event_declaration] = STATE(2439),
    [sym_procedure] = STATE(2439),
    [sym_preproc_split_procedure] = STATE(2439),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(5928),
    [sym_var_section] = STATE(2439),
    [sym_attribute_item] = STATE(5928),
    [sym_preproc_conditional] = STATE(2439),
    [sym_preproc_if] = STATE(1394),
    [sym_preproc_conditional_actions] = STATE(2439),
    [aux_sym_action_group_section_repeat1] = STATE(2439),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(5634),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5580),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5582),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token22] = ACTIONS(5584),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(5586),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5588),
    [aux_sym_modify_modification_token1] = ACTIONS(5590),
    [aux_sym_separator_action_token1] = ACTIONS(5592),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5594),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5596),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5598),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5600),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(5602),
    [sym_local_keyword] = ACTIONS(5604),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5604),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(5606),
    [sym_group_keyword] = ACTIONS(5608),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(2435)] = {
    [sym_identifier] = ACTIONS(5636),
    [anon_sym_SEMI] = ACTIONS(5638),
    [anon_sym_DASH] = ACTIONS(5638),
    [aux_sym_boolean_token1] = ACTIONS(5636),
    [aux_sym_boolean_token2] = ACTIONS(5636),
    [sym_decimal] = ACTIONS(5636),
    [anon_sym_LPAREN] = ACTIONS(5638),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5636),
    [anon_sym_LBRACK] = ACTIONS(5638),
    [aux_sym_record_type_token1] = ACTIONS(5636),
    [aux_sym_basic_type_token21] = ACTIONS(5636),
    [aux_sym_basic_type_token22] = ACTIONS(5636),
    [aux_sym_basic_type_token48] = ACTIONS(5636),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(5636),
    [anon_sym_POUNDif] = ACTIONS(5638),
    [anon_sym_POUNDIF] = ACTIONS(5638),
    [anon_sym_POUNDIf] = ACTIONS(5638),
    [anon_sym_not] = ACTIONS(5636),
    [anon_sym_NOT] = ACTIONS(5636),
    [anon_sym_Not] = ACTIONS(5636),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5636),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5636),
    [anon_sym_PLUS] = ACTIONS(5638),
    [sym_datetime_literal] = ACTIONS(5638),
    [sym_date_literal] = ACTIONS(5636),
    [sym_time_literal] = ACTIONS(5636),
    [sym_biginteger_literal] = ACTIONS(5638),
    [anon_sym_if] = ACTIONS(5636),
    [anon_sym_IF] = ACTIONS(5636),
    [anon_sym_If] = ACTIONS(5636),
    [anon_sym_case] = ACTIONS(5636),
    [anon_sym_CASE] = ACTIONS(5636),
    [anon_sym_Case] = ACTIONS(5636),
    [anon_sym_for] = ACTIONS(5636),
    [anon_sym_FOR] = ACTIONS(5636),
    [anon_sym_For] = ACTIONS(5636),
    [anon_sym_foreach] = ACTIONS(5636),
    [anon_sym_FOREACH] = ACTIONS(5636),
    [anon_sym_Foreach] = ACTIONS(5636),
    [anon_sym_while] = ACTIONS(5636),
    [anon_sym_WHILE] = ACTIONS(5636),
    [anon_sym_While] = ACTIONS(5636),
    [anon_sym_repeat] = ACTIONS(5636),
    [anon_sym_REPEAT] = ACTIONS(5636),
    [anon_sym_Repeat] = ACTIONS(5636),
    [anon_sym_exit] = ACTIONS(5636),
    [anon_sym_EXIT] = ACTIONS(5636),
    [anon_sym_Exit] = ACTIONS(5636),
    [anon_sym_continue] = ACTIONS(5636),
    [anon_sym_CONTINUE] = ACTIONS(5636),
    [anon_sym_Continue] = ACTIONS(5636),
    [anon_sym_break] = ACTIONS(5636),
    [anon_sym_BREAK] = ACTIONS(5636),
    [anon_sym_Break] = ACTIONS(5636),
    [anon_sym_with] = ACTIONS(5636),
    [anon_sym_WITH] = ACTIONS(5636),
    [anon_sym_With] = ACTIONS(5636),
    [sym_asserterror_keyword] = ACTIONS(5638),
    [sym_page_keyword] = ACTIONS(5636),
    [anon_sym_codeunit] = ACTIONS(5636),
    [anon_sym_CODEUNIT] = ACTIONS(5636),
    [anon_sym_Codeunit] = ACTIONS(5636),
    [anon_sym_CodeUnit] = ACTIONS(5636),
    [anon_sym_COdeunit] = ACTIONS(5636),
    [anon_sym_codeUnit] = ACTIONS(5636),
    [sym_report_keyword] = ACTIONS(5636),
    [sym_query_keyword] = ACTIONS(5636),
    [anon_sym_xmlport] = ACTIONS(5636),
    [anon_sym_XMLPORT] = ACTIONS(5636),
    [anon_sym_Xmlport] = ACTIONS(5636),
    [anon_sym_XMLport] = ACTIONS(5636),
    [anon_sym_XMLPort] = ACTIONS(5636),
    [anon_sym_XmlPort] = ACTIONS(5636),
    [anon_sym_enum] = ACTIONS(5636),
    [anon_sym_ENUM] = ACTIONS(5636),
    [anon_sym_Enum] = ACTIONS(5636),
    [anon_sym_eNUM] = ACTIONS(5636),
    [anon_sym_eNum] = ACTIONS(5636),
    [anon_sym_ENum] = ACTIONS(5636),
    [sym_quoted_identifier] = ACTIONS(5638),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5638),
    [sym_integer] = ACTIONS(5636),
    [sym_continue_as_identifier] = ACTIONS(5638),
    [sym_preproc_open] = ACTIONS(5638),
    [sym_begin_keyword] = ACTIONS(5638),
  },
  [STATE(2436)] = {
    [sym__body_element] = STATE(2438),
    [sym_empty_statement] = STATE(2438),
    [sym_property] = STATE(5928),
    [sym_fields_section] = STATE(2438),
    [sym_keys_section] = STATE(2438),
    [sym_fieldgroups_section] = STATE(2438),
    [sym_enum_value_declaration] = STATE(2438),
    [sym_labels_section] = STATE(2438),
    [sym_layout_section] = STATE(2438),
    [sym_modify_modification] = STATE(2438),
    [sym_actions_section] = STATE(2438),
    [sym__action_element] = STATE(2438),
    [sym_action_area_section] = STATE(2438),
    [sym_action_group_section] = STATE(2438),
    [sym_action_declaration] = STATE(2438),
    [sym_separator_action] = STATE(2438),
    [sym_actionref_declaration] = STATE(2438),
    [sym_systemaction_declaration] = STATE(2438),
    [sym_fileuploadaction_declaration] = STATE(2438),
    [sym_customaction_declaration] = STATE(2438),
    [sym_addfirst_action_modification] = STATE(2438),
    [sym_addlast_action_modification] = STATE(2438),
    [sym_addafter_action_modification] = STATE(2438),
    [sym_addbefore_action_modification] = STATE(2438),
    [sym_modify_action_modification] = STATE(2438),
    [sym_views_section] = STATE(2438),
    [sym_dataset_section] = STATE(2438),
    [sym_requestpage_section] = STATE(2438),
    [sym_rendering_section] = STATE(2438),
    [sym_elements_section] = STATE(2438),
    [sym_schema_section] = STATE(2438),
    [sym_assembly_declaration] = STATE(2438),
    [sym_event_declaration] = STATE(2438),
    [sym_procedure] = STATE(2438),
    [sym_preproc_split_procedure] = STATE(2438),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(5928),
    [sym_var_section] = STATE(2438),
    [sym_attribute_item] = STATE(5928),
    [sym_preproc_conditional] = STATE(2438),
    [sym_preproc_if] = STATE(1394),
    [sym_preproc_conditional_actions] = STATE(2438),
    [aux_sym_action_group_section_repeat1] = STATE(2438),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(5640),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5580),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5582),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token22] = ACTIONS(5584),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(5586),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5588),
    [aux_sym_modify_modification_token1] = ACTIONS(5590),
    [aux_sym_separator_action_token1] = ACTIONS(5592),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5594),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5596),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5598),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5600),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(5602),
    [sym_local_keyword] = ACTIONS(5604),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5604),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(5606),
    [sym_group_keyword] = ACTIONS(5608),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(2437)] = {
    [sym__body_element] = STATE(2434),
    [sym_empty_statement] = STATE(2434),
    [sym_property] = STATE(5928),
    [sym_fields_section] = STATE(2434),
    [sym_keys_section] = STATE(2434),
    [sym_fieldgroups_section] = STATE(2434),
    [sym_enum_value_declaration] = STATE(2434),
    [sym_labels_section] = STATE(2434),
    [sym_layout_section] = STATE(2434),
    [sym_modify_modification] = STATE(2434),
    [sym_actions_section] = STATE(2434),
    [sym__action_element] = STATE(2434),
    [sym_action_area_section] = STATE(2434),
    [sym_action_group_section] = STATE(2434),
    [sym_action_declaration] = STATE(2434),
    [sym_separator_action] = STATE(2434),
    [sym_actionref_declaration] = STATE(2434),
    [sym_systemaction_declaration] = STATE(2434),
    [sym_fileuploadaction_declaration] = STATE(2434),
    [sym_customaction_declaration] = STATE(2434),
    [sym_addfirst_action_modification] = STATE(2434),
    [sym_addlast_action_modification] = STATE(2434),
    [sym_addafter_action_modification] = STATE(2434),
    [sym_addbefore_action_modification] = STATE(2434),
    [sym_modify_action_modification] = STATE(2434),
    [sym_views_section] = STATE(2434),
    [sym_dataset_section] = STATE(2434),
    [sym_requestpage_section] = STATE(2434),
    [sym_rendering_section] = STATE(2434),
    [sym_elements_section] = STATE(2434),
    [sym_schema_section] = STATE(2434),
    [sym_assembly_declaration] = STATE(2434),
    [sym_event_declaration] = STATE(2434),
    [sym_procedure] = STATE(2434),
    [sym_preproc_split_procedure] = STATE(2434),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(5928),
    [sym_var_section] = STATE(2434),
    [sym_attribute_item] = STATE(5928),
    [sym_preproc_conditional] = STATE(2434),
    [sym_preproc_if] = STATE(1394),
    [sym_preproc_conditional_actions] = STATE(2434),
    [aux_sym_action_group_section_repeat1] = STATE(2434),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(5642),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5580),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5582),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token22] = ACTIONS(5584),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(5586),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5588),
    [aux_sym_modify_modification_token1] = ACTIONS(5590),
    [aux_sym_separator_action_token1] = ACTIONS(5592),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5594),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5596),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5598),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5600),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(5602),
    [sym_local_keyword] = ACTIONS(5604),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5604),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(5606),
    [sym_group_keyword] = ACTIONS(5608),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(2438)] = {
    [sym__body_element] = STATE(2439),
    [sym_empty_statement] = STATE(2439),
    [sym_property] = STATE(5928),
    [sym_fields_section] = STATE(2439),
    [sym_keys_section] = STATE(2439),
    [sym_fieldgroups_section] = STATE(2439),
    [sym_enum_value_declaration] = STATE(2439),
    [sym_labels_section] = STATE(2439),
    [sym_layout_section] = STATE(2439),
    [sym_modify_modification] = STATE(2439),
    [sym_actions_section] = STATE(2439),
    [sym__action_element] = STATE(2439),
    [sym_action_area_section] = STATE(2439),
    [sym_action_group_section] = STATE(2439),
    [sym_action_declaration] = STATE(2439),
    [sym_separator_action] = STATE(2439),
    [sym_actionref_declaration] = STATE(2439),
    [sym_systemaction_declaration] = STATE(2439),
    [sym_fileuploadaction_declaration] = STATE(2439),
    [sym_customaction_declaration] = STATE(2439),
    [sym_addfirst_action_modification] = STATE(2439),
    [sym_addlast_action_modification] = STATE(2439),
    [sym_addafter_action_modification] = STATE(2439),
    [sym_addbefore_action_modification] = STATE(2439),
    [sym_modify_action_modification] = STATE(2439),
    [sym_views_section] = STATE(2439),
    [sym_dataset_section] = STATE(2439),
    [sym_requestpage_section] = STATE(2439),
    [sym_rendering_section] = STATE(2439),
    [sym_elements_section] = STATE(2439),
    [sym_schema_section] = STATE(2439),
    [sym_assembly_declaration] = STATE(2439),
    [sym_event_declaration] = STATE(2439),
    [sym_procedure] = STATE(2439),
    [sym_preproc_split_procedure] = STATE(2439),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(5928),
    [sym_var_section] = STATE(2439),
    [sym_attribute_item] = STATE(5928),
    [sym_preproc_conditional] = STATE(2439),
    [sym_preproc_if] = STATE(1394),
    [sym_preproc_conditional_actions] = STATE(2439),
    [aux_sym_action_group_section_repeat1] = STATE(2439),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(5644),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5580),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5582),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_basic_type_token22] = ACTIONS(5584),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_addafter_modification_token1] = ACTIONS(5586),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5588),
    [aux_sym_modify_modification_token1] = ACTIONS(5590),
    [aux_sym_separator_action_token1] = ACTIONS(5592),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5594),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5596),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5598),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5600),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(5602),
    [sym_local_keyword] = ACTIONS(5604),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5604),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_area_keyword] = ACTIONS(5606),
    [sym_group_keyword] = ACTIONS(5608),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(2439)] = {
    [sym__body_element] = STATE(2439),
    [sym_empty_statement] = STATE(2439),
    [sym_property] = STATE(5928),
    [sym_fields_section] = STATE(2439),
    [sym_keys_section] = STATE(2439),
    [sym_fieldgroups_section] = STATE(2439),
    [sym_enum_value_declaration] = STATE(2439),
    [sym_labels_section] = STATE(2439),
    [sym_layout_section] = STATE(2439),
    [sym_modify_modification] = STATE(2439),
    [sym_actions_section] = STATE(2439),
    [sym__action_element] = STATE(2439),
    [sym_action_area_section] = STATE(2439),
    [sym_action_group_section] = STATE(2439),
    [sym_action_declaration] = STATE(2439),
    [sym_separator_action] = STATE(2439),
    [sym_actionref_declaration] = STATE(2439),
    [sym_systemaction_declaration] = STATE(2439),
    [sym_fileuploadaction_declaration] = STATE(2439),
    [sym_customaction_declaration] = STATE(2439),
    [sym_addfirst_action_modification] = STATE(2439),
    [sym_addlast_action_modification] = STATE(2439),
    [sym_addafter_action_modification] = STATE(2439),
    [sym_addbefore_action_modification] = STATE(2439),
    [sym_modify_action_modification] = STATE(2439),
    [sym_views_section] = STATE(2439),
    [sym_dataset_section] = STATE(2439),
    [sym_requestpage_section] = STATE(2439),
    [sym_rendering_section] = STATE(2439),
    [sym_elements_section] = STATE(2439),
    [sym_schema_section] = STATE(2439),
    [sym_assembly_declaration] = STATE(2439),
    [sym_event_declaration] = STATE(2439),
    [sym_procedure] = STATE(2439),
    [sym_preproc_split_procedure] = STATE(2439),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(5928),
    [sym_var_section] = STATE(2439),
    [sym_attribute_item] = STATE(5928),
    [sym_preproc_conditional] = STATE(2439),
    [sym_preproc_if] = STATE(1394),
    [sym_preproc_conditional_actions] = STATE(2439),
    [aux_sym_action_group_section_repeat1] = STATE(2439),
    [anon_sym_SEMI] = ACTIONS(5646),
    [anon_sym_RBRACE] = ACTIONS(5649),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5651),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5654),
    [anon_sym_LBRACK] = ACTIONS(5657),
    [aux_sym_basic_type_token22] = ACTIONS(5660),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5663),
    [aux_sym_addafter_modification_token1] = ACTIONS(5666),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5669),
    [aux_sym_modify_modification_token1] = ACTIONS(5672),
    [aux_sym_separator_action_token1] = ACTIONS(5675),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5678),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5681),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5684),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5687),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5690),
    [anon_sym_POUNDif] = ACTIONS(5693),
    [anon_sym_POUNDIF] = ACTIONS(5693),
    [anon_sym_POUNDIf] = ACTIONS(5693),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5696),
    [sym_trigger_keyword] = ACTIONS(5699),
    [sym_var_keyword] = ACTIONS(5702),
    [sym_local_keyword] = ACTIONS(5705),
    [sym_internal_keyword] = ACTIONS(5708),
    [sym_protected_keyword] = ACTIONS(5705),
    [sym_event_keyword] = ACTIONS(5711),
    [sym_fields_keyword] = ACTIONS(5714),
    [sym_keys_keyword] = ACTIONS(5717),
    [sym_fieldgroups_keyword] = ACTIONS(5720),
    [sym_actions_keyword] = ACTIONS(5723),
    [sym_layout_keyword] = ACTIONS(5726),
    [sym_area_keyword] = ACTIONS(5729),
    [sym_group_keyword] = ACTIONS(5732),
    [sym_dataset_keyword] = ACTIONS(5735),
    [sym_elements_keyword] = ACTIONS(5738),
    [sym_labels_keyword] = ACTIONS(5741),
    [sym_rendering_keyword] = ACTIONS(5744),
    [sym_requestpage_keyword] = ACTIONS(5747),
    [sym_schema_keyword] = ACTIONS(5750),
    [sym_views_keyword] = ACTIONS(5753),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5756),
    [sym_preproc_open] = ACTIONS(5693),
  },
  [STATE(2440)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_elif] = STATE(2560),
    [sym_preproc_else] = STATE(2658),
    [sym_preproc_endif] = STATE(4797),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [aux_sym_preproc_split_case_branch_repeat2] = STATE(8115),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDelif] = ACTIONS(5620),
    [anon_sym_POUNDELIF] = ACTIONS(5620),
    [anon_sym_POUNDElif] = ACTIONS(5620),
    [anon_sym_POUNDelse] = ACTIONS(5622),
    [anon_sym_POUNDELSE] = ACTIONS(5622),
    [anon_sym_POUNDElse] = ACTIONS(5622),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2441)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_elif] = STATE(2560),
    [sym_preproc_else] = STATE(2642),
    [sym_preproc_endif] = STATE(2597),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2429),
    [aux_sym_preproc_split_case_branch_repeat2] = STATE(8143),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDelif] = ACTIONS(5620),
    [anon_sym_POUNDELIF] = ACTIONS(5620),
    [anon_sym_POUNDElif] = ACTIONS(5620),
    [anon_sym_POUNDelse] = ACTIONS(5622),
    [anon_sym_POUNDELSE] = ACTIONS(5622),
    [anon_sym_POUNDElse] = ACTIONS(5622),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2442)] = {
    [sym_identifier] = ACTIONS(2843),
    [anon_sym_SEMI] = ACTIONS(2841),
    [anon_sym_DASH] = ACTIONS(2841),
    [aux_sym_boolean_token1] = ACTIONS(2843),
    [aux_sym_boolean_token2] = ACTIONS(2843),
    [sym_decimal] = ACTIONS(2843),
    [anon_sym_LPAREN] = ACTIONS(2841),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2843),
    [anon_sym_LBRACK] = ACTIONS(2841),
    [aux_sym_record_type_token1] = ACTIONS(2843),
    [aux_sym_basic_type_token21] = ACTIONS(2843),
    [aux_sym_basic_type_token22] = ACTIONS(2843),
    [aux_sym_basic_type_token48] = ACTIONS(2843),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(2843),
    [anon_sym_POUNDif] = ACTIONS(2841),
    [anon_sym_POUNDIF] = ACTIONS(2841),
    [anon_sym_POUNDIf] = ACTIONS(2841),
    [anon_sym_not] = ACTIONS(2843),
    [anon_sym_NOT] = ACTIONS(2843),
    [anon_sym_Not] = ACTIONS(2843),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2843),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2843),
    [anon_sym_PLUS] = ACTIONS(2841),
    [sym_datetime_literal] = ACTIONS(2841),
    [sym_date_literal] = ACTIONS(2843),
    [sym_time_literal] = ACTIONS(2843),
    [sym_biginteger_literal] = ACTIONS(2841),
    [anon_sym_if] = ACTIONS(2843),
    [anon_sym_IF] = ACTIONS(2843),
    [anon_sym_If] = ACTIONS(2843),
    [anon_sym_case] = ACTIONS(2843),
    [anon_sym_CASE] = ACTIONS(2843),
    [anon_sym_Case] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2843),
    [anon_sym_FOR] = ACTIONS(2843),
    [anon_sym_For] = ACTIONS(2843),
    [anon_sym_foreach] = ACTIONS(2843),
    [anon_sym_FOREACH] = ACTIONS(2843),
    [anon_sym_Foreach] = ACTIONS(2843),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_WHILE] = ACTIONS(2843),
    [anon_sym_While] = ACTIONS(2843),
    [anon_sym_repeat] = ACTIONS(2843),
    [anon_sym_REPEAT] = ACTIONS(2843),
    [anon_sym_Repeat] = ACTIONS(2843),
    [anon_sym_exit] = ACTIONS(2843),
    [anon_sym_EXIT] = ACTIONS(2843),
    [anon_sym_Exit] = ACTIONS(2843),
    [anon_sym_continue] = ACTIONS(2843),
    [anon_sym_CONTINUE] = ACTIONS(2843),
    [anon_sym_Continue] = ACTIONS(2843),
    [anon_sym_break] = ACTIONS(2843),
    [anon_sym_BREAK] = ACTIONS(2843),
    [anon_sym_Break] = ACTIONS(2843),
    [anon_sym_with] = ACTIONS(2843),
    [anon_sym_WITH] = ACTIONS(2843),
    [anon_sym_With] = ACTIONS(2843),
    [sym_asserterror_keyword] = ACTIONS(2841),
    [sym_page_keyword] = ACTIONS(2843),
    [anon_sym_codeunit] = ACTIONS(2843),
    [anon_sym_CODEUNIT] = ACTIONS(2843),
    [anon_sym_Codeunit] = ACTIONS(2843),
    [anon_sym_CodeUnit] = ACTIONS(2843),
    [anon_sym_COdeunit] = ACTIONS(2843),
    [anon_sym_codeUnit] = ACTIONS(2843),
    [sym_report_keyword] = ACTIONS(2843),
    [sym_query_keyword] = ACTIONS(2843),
    [anon_sym_xmlport] = ACTIONS(2843),
    [anon_sym_XMLPORT] = ACTIONS(2843),
    [anon_sym_Xmlport] = ACTIONS(2843),
    [anon_sym_XMLport] = ACTIONS(2843),
    [anon_sym_XMLPort] = ACTIONS(2843),
    [anon_sym_XmlPort] = ACTIONS(2843),
    [anon_sym_enum] = ACTIONS(2843),
    [anon_sym_ENUM] = ACTIONS(2843),
    [anon_sym_Enum] = ACTIONS(2843),
    [anon_sym_eNUM] = ACTIONS(2843),
    [anon_sym_eNum] = ACTIONS(2843),
    [anon_sym_ENum] = ACTIONS(2843),
    [sym_quoted_identifier] = ACTIONS(2841),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2841),
    [sym_integer] = ACTIONS(2843),
    [sym_continue_as_identifier] = ACTIONS(2841),
    [sym_preproc_open] = ACTIONS(2841),
    [sym_begin_keyword] = ACTIONS(2841),
  },
  [STATE(2443)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(1398),
    [sym_assignment_expression] = STATE(6338),
    [sym_preproc_conditional_case] = STATE(2443),
    [sym_case_branch] = STATE(2443),
    [sym_preproc_split_case_branch] = STATE(4637),
    [aux_sym__case_pattern] = STATE(2620),
    [sym_preproc_conditional_case_patterns] = STATE(2620),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [aux_sym_case_statement_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(5759),
    [anon_sym_DASH] = ACTIONS(5762),
    [aux_sym_boolean_token1] = ACTIONS(5765),
    [aux_sym_boolean_token2] = ACTIONS(5765),
    [sym_decimal] = ACTIONS(5768),
    [anon_sym_LPAREN] = ACTIONS(5771),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5774),
    [anon_sym_LBRACK] = ACTIONS(5777),
    [aux_sym_record_type_token1] = ACTIONS(5774),
    [aux_sym_basic_type_token21] = ACTIONS(5774),
    [aux_sym_basic_type_token22] = ACTIONS(5774),
    [aux_sym_basic_type_token48] = ACTIONS(5774),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5780),
    [anon_sym_POUNDif] = ACTIONS(5782),
    [anon_sym_POUNDIF] = ACTIONS(5782),
    [anon_sym_POUNDIf] = ACTIONS(5782),
    [anon_sym_not] = ACTIONS(5785),
    [anon_sym_NOT] = ACTIONS(5785),
    [anon_sym_Not] = ACTIONS(5785),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5774),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5788),
    [anon_sym_PLUS] = ACTIONS(5762),
    [sym_datetime_literal] = ACTIONS(5791),
    [sym_date_literal] = ACTIONS(5768),
    [sym_time_literal] = ACTIONS(5768),
    [sym_biginteger_literal] = ACTIONS(5791),
    [anon_sym_else] = ACTIONS(5780),
    [anon_sym_ELSE] = ACTIONS(5780),
    [anon_sym_Else] = ACTIONS(5780),
    [sym_page_keyword] = ACTIONS(5788),
    [anon_sym_codeunit] = ACTIONS(5794),
    [anon_sym_CODEUNIT] = ACTIONS(5794),
    [anon_sym_Codeunit] = ACTIONS(5794),
    [anon_sym_CodeUnit] = ACTIONS(5794),
    [anon_sym_COdeunit] = ACTIONS(5794),
    [anon_sym_codeUnit] = ACTIONS(5794),
    [sym_report_keyword] = ACTIONS(5788),
    [sym_query_keyword] = ACTIONS(5788),
    [anon_sym_xmlport] = ACTIONS(5797),
    [anon_sym_XMLPORT] = ACTIONS(5797),
    [anon_sym_Xmlport] = ACTIONS(5797),
    [anon_sym_XMLport] = ACTIONS(5797),
    [anon_sym_XMLPort] = ACTIONS(5797),
    [anon_sym_XmlPort] = ACTIONS(5797),
    [anon_sym_enum] = ACTIONS(5800),
    [anon_sym_ENUM] = ACTIONS(5800),
    [anon_sym_Enum] = ACTIONS(5800),
    [anon_sym_eNUM] = ACTIONS(5800),
    [anon_sym_eNum] = ACTIONS(5800),
    [anon_sym_ENum] = ACTIONS(5800),
    [sym_quoted_identifier] = ACTIONS(5803),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5791),
    [sym_integer] = ACTIONS(5768),
    [sym_continue_as_identifier] = ACTIONS(5806),
    [sym_preproc_open] = ACTIONS(5782),
  },
  [STATE(2444)] = {
    [sym_identifier] = ACTIONS(4874),
    [anon_sym_SEMI] = ACTIONS(4876),
    [anon_sym_DASH] = ACTIONS(4876),
    [aux_sym_boolean_token1] = ACTIONS(4874),
    [aux_sym_boolean_token2] = ACTIONS(4874),
    [sym_decimal] = ACTIONS(4874),
    [anon_sym_LPAREN] = ACTIONS(4876),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4874),
    [anon_sym_LBRACK] = ACTIONS(4876),
    [aux_sym_record_type_token1] = ACTIONS(4874),
    [aux_sym_basic_type_token21] = ACTIONS(4874),
    [aux_sym_basic_type_token22] = ACTIONS(4874),
    [aux_sym_basic_type_token48] = ACTIONS(4874),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4874),
    [anon_sym_POUNDif] = ACTIONS(4876),
    [anon_sym_POUNDIF] = ACTIONS(4876),
    [anon_sym_POUNDIf] = ACTIONS(4876),
    [anon_sym_not] = ACTIONS(4874),
    [anon_sym_NOT] = ACTIONS(4874),
    [anon_sym_Not] = ACTIONS(4874),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4874),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4874),
    [anon_sym_PLUS] = ACTIONS(4876),
    [sym_datetime_literal] = ACTIONS(4876),
    [sym_date_literal] = ACTIONS(4874),
    [sym_time_literal] = ACTIONS(4874),
    [sym_biginteger_literal] = ACTIONS(4876),
    [anon_sym_if] = ACTIONS(4874),
    [anon_sym_IF] = ACTIONS(4874),
    [anon_sym_If] = ACTIONS(4874),
    [anon_sym_case] = ACTIONS(4874),
    [anon_sym_CASE] = ACTIONS(4874),
    [anon_sym_Case] = ACTIONS(4874),
    [anon_sym_for] = ACTIONS(4874),
    [anon_sym_FOR] = ACTIONS(4874),
    [anon_sym_For] = ACTIONS(4874),
    [anon_sym_foreach] = ACTIONS(4874),
    [anon_sym_FOREACH] = ACTIONS(4874),
    [anon_sym_Foreach] = ACTIONS(4874),
    [anon_sym_while] = ACTIONS(4874),
    [anon_sym_WHILE] = ACTIONS(4874),
    [anon_sym_While] = ACTIONS(4874),
    [anon_sym_repeat] = ACTIONS(4874),
    [anon_sym_REPEAT] = ACTIONS(4874),
    [anon_sym_Repeat] = ACTIONS(4874),
    [anon_sym_exit] = ACTIONS(4874),
    [anon_sym_EXIT] = ACTIONS(4874),
    [anon_sym_Exit] = ACTIONS(4874),
    [anon_sym_continue] = ACTIONS(4874),
    [anon_sym_CONTINUE] = ACTIONS(4874),
    [anon_sym_Continue] = ACTIONS(4874),
    [anon_sym_break] = ACTIONS(4874),
    [anon_sym_BREAK] = ACTIONS(4874),
    [anon_sym_Break] = ACTIONS(4874),
    [anon_sym_with] = ACTIONS(4874),
    [anon_sym_WITH] = ACTIONS(4874),
    [anon_sym_With] = ACTIONS(4874),
    [sym_asserterror_keyword] = ACTIONS(4876),
    [sym_page_keyword] = ACTIONS(4874),
    [anon_sym_codeunit] = ACTIONS(4874),
    [anon_sym_CODEUNIT] = ACTIONS(4874),
    [anon_sym_Codeunit] = ACTIONS(4874),
    [anon_sym_CodeUnit] = ACTIONS(4874),
    [anon_sym_COdeunit] = ACTIONS(4874),
    [anon_sym_codeUnit] = ACTIONS(4874),
    [sym_report_keyword] = ACTIONS(4874),
    [sym_query_keyword] = ACTIONS(4874),
    [anon_sym_xmlport] = ACTIONS(4874),
    [anon_sym_XMLPORT] = ACTIONS(4874),
    [anon_sym_Xmlport] = ACTIONS(4874),
    [anon_sym_XMLport] = ACTIONS(4874),
    [anon_sym_XMLPort] = ACTIONS(4874),
    [anon_sym_XmlPort] = ACTIONS(4874),
    [anon_sym_enum] = ACTIONS(4874),
    [anon_sym_ENUM] = ACTIONS(4874),
    [anon_sym_Enum] = ACTIONS(4874),
    [anon_sym_eNUM] = ACTIONS(4874),
    [anon_sym_eNum] = ACTIONS(4874),
    [anon_sym_ENum] = ACTIONS(4874),
    [sym_quoted_identifier] = ACTIONS(4876),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4876),
    [sym_integer] = ACTIONS(4874),
    [sym_continue_as_identifier] = ACTIONS(4876),
    [sym_preproc_open] = ACTIONS(4876),
    [sym_end_keyword] = ACTIONS(4876),
  },
  [STATE(2445)] = {
    [sym_identifier] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(2593),
    [anon_sym_EQ] = ACTIONS(2595),
    [anon_sym_COMMA] = ACTIONS(4825),
    [anon_sym_COLON] = ACTIONS(4823),
    [anon_sym_DASH] = ACTIONS(4827),
    [aux_sym_boolean_token1] = ACTIONS(4823),
    [aux_sym_boolean_token2] = ACTIONS(4823),
    [sym_decimal] = ACTIONS(4823),
    [anon_sym_LPAREN] = ACTIONS(4825),
    [anon_sym_DOT_DOT] = ACTIONS(2595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4823),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_LBRACK] = ACTIONS(4830),
    [aux_sym_record_type_token1] = ACTIONS(4823),
    [aux_sym_basic_type_token21] = ACTIONS(4823),
    [aux_sym_basic_type_token22] = ACTIONS(4823),
    [aux_sym_basic_type_token48] = ACTIONS(4823),
    [anon_sym_POUNDif] = ACTIONS(4825),
    [anon_sym_POUNDIF] = ACTIONS(4825),
    [anon_sym_POUNDIf] = ACTIONS(4825),
    [anon_sym_not] = ACTIONS(4823),
    [anon_sym_NOT] = ACTIONS(4823),
    [anon_sym_Not] = ACTIONS(4823),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2595),
    [aux_sym__expression_token1] = ACTIONS(2595),
    [aux_sym__expression_token2] = ACTIONS(2595),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4823),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4823),
    [anon_sym_SLASH] = ACTIONS(2593),
    [anon_sym_div] = ACTIONS(2593),
    [anon_sym_DIV] = ACTIONS(2593),
    [anon_sym_Div] = ACTIONS(2593),
    [anon_sym_mod] = ACTIONS(2593),
    [anon_sym_MOD] = ACTIONS(2593),
    [anon_sym_Mod] = ACTIONS(2593),
    [anon_sym_PLUS] = ACTIONS(4827),
    [anon_sym_GT_EQ] = ACTIONS(2595),
    [anon_sym_LT_EQ] = ACTIONS(2595),
    [anon_sym_GT] = ACTIONS(2593),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_LT_GT] = ACTIONS(2595),
    [anon_sym_and] = ACTIONS(2593),
    [anon_sym_AND] = ACTIONS(2593),
    [anon_sym_And] = ACTIONS(2593),
    [anon_sym_or] = ACTIONS(2593),
    [anon_sym_OR] = ACTIONS(2593),
    [anon_sym_Or] = ACTIONS(2593),
    [anon_sym_xor] = ACTIONS(2593),
    [anon_sym_XOR] = ACTIONS(2593),
    [anon_sym_Xor] = ACTIONS(2593),
    [anon_sym_QMARK] = ACTIONS(2595),
    [sym_datetime_literal] = ACTIONS(4825),
    [sym_date_literal] = ACTIONS(4823),
    [sym_time_literal] = ACTIONS(4823),
    [sym_biginteger_literal] = ACTIONS(4825),
    [anon_sym_in] = ACTIONS(2593),
    [anon_sym_IN] = ACTIONS(2593),
    [anon_sym_In] = ACTIONS(2593),
    [sym_page_keyword] = ACTIONS(4823),
    [anon_sym_codeunit] = ACTIONS(4823),
    [anon_sym_CODEUNIT] = ACTIONS(4823),
    [anon_sym_Codeunit] = ACTIONS(4823),
    [anon_sym_CodeUnit] = ACTIONS(4823),
    [anon_sym_COdeunit] = ACTIONS(4823),
    [anon_sym_codeUnit] = ACTIONS(4823),
    [sym_report_keyword] = ACTIONS(4823),
    [sym_query_keyword] = ACTIONS(4823),
    [anon_sym_xmlport] = ACTIONS(4823),
    [anon_sym_XMLPORT] = ACTIONS(4823),
    [anon_sym_Xmlport] = ACTIONS(4823),
    [anon_sym_XMLport] = ACTIONS(4823),
    [anon_sym_XMLPort] = ACTIONS(4823),
    [anon_sym_XmlPort] = ACTIONS(4823),
    [anon_sym_enum] = ACTIONS(4823),
    [anon_sym_ENUM] = ACTIONS(4823),
    [anon_sym_Enum] = ACTIONS(4823),
    [anon_sym_eNUM] = ACTIONS(4823),
    [anon_sym_eNum] = ACTIONS(4823),
    [anon_sym_ENum] = ACTIONS(4823),
    [sym_quoted_identifier] = ACTIONS(4825),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4825),
    [sym_integer] = ACTIONS(4823),
    [sym_continue_as_identifier] = ACTIONS(4825),
    [sym_preproc_open] = ACTIONS(4825),
  },
  [STATE(2446)] = {
    [sym__body_element] = STATE(5591),
    [sym_empty_statement] = STATE(5591),
    [sym_property] = STATE(5591),
    [sym_fields_section] = STATE(5591),
    [sym_keys_section] = STATE(5591),
    [sym_fieldgroups_section] = STATE(5591),
    [sym_enum_value_declaration] = STATE(5591),
    [sym_labels_section] = STATE(5591),
    [sym_layout_section] = STATE(5591),
    [sym_modify_modification] = STATE(5591),
    [sym_actions_section] = STATE(5591),
    [sym_views_section] = STATE(5591),
    [sym_dataset_section] = STATE(5591),
    [sym_requestpage_section] = STATE(5591),
    [sym_rendering_section] = STATE(5591),
    [sym_elements_section] = STATE(5591),
    [sym_schema_section] = STATE(5591),
    [sym_xmlport_element] = STATE(2565),
    [sym__xmlport_body_element] = STATE(2565),
    [sym_preproc_conditional_xmlport] = STATE(2565),
    [sym_xmlport_attribute] = STATE(2565),
    [sym_assembly_declaration] = STATE(5591),
    [sym_event_declaration] = STATE(5591),
    [sym_procedure] = STATE(5591),
    [sym_preproc_split_procedure] = STATE(5591),
    [sym__procedure_header] = STATE(8121),
    [sym_procedure_modifier] = STATE(12340),
    [sym_trigger_declaration] = STATE(5591),
    [sym_var_section] = STATE(5591),
    [sym_attribute_item] = STATE(5844),
    [sym_preproc_conditional] = STATE(5591),
    [sym_preproc_if] = STATE(2446),
    [sym_preproc_elif] = STATE(2631),
    [sym_preproc_else] = STATE(2735),
    [sym_preproc_endif] = STATE(5727),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(2740),
    [aux_sym_xmlport_element_repeat1] = STATE(2565),
    [aux_sym_preproc_conditional_xmlport_repeat1] = STATE(7827),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_repeat1] = STATE(7983),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDelif] = ACTIONS(5825),
    [anon_sym_POUNDELIF] = ACTIONS(5825),
    [anon_sym_POUNDElif] = ACTIONS(5825),
    [anon_sym_POUNDelse] = ACTIONS(5827),
    [anon_sym_POUNDELSE] = ACTIONS(5827),
    [anon_sym_POUNDElse] = ACTIONS(5827),
    [anon_sym_POUNDendif] = ACTIONS(5829),
    [anon_sym_POUNDENDIF] = ACTIONS(5829),
    [anon_sym_POUNDEndif] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5831),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(5829),
  },
  [STATE(2447)] = {
    [sym_identifier] = ACTIONS(5447),
    [anon_sym_SEMI] = ACTIONS(5449),
    [anon_sym_DASH] = ACTIONS(5449),
    [aux_sym_boolean_token1] = ACTIONS(5447),
    [aux_sym_boolean_token2] = ACTIONS(5447),
    [sym_decimal] = ACTIONS(5447),
    [anon_sym_LPAREN] = ACTIONS(5449),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5447),
    [anon_sym_LBRACK] = ACTIONS(5449),
    [aux_sym_record_type_token1] = ACTIONS(5447),
    [aux_sym_basic_type_token21] = ACTIONS(5447),
    [aux_sym_basic_type_token22] = ACTIONS(5447),
    [aux_sym_basic_type_token48] = ACTIONS(5447),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5447),
    [anon_sym_POUNDif] = ACTIONS(5449),
    [anon_sym_POUNDIF] = ACTIONS(5449),
    [anon_sym_POUNDIf] = ACTIONS(5449),
    [anon_sym_not] = ACTIONS(5447),
    [anon_sym_NOT] = ACTIONS(5447),
    [anon_sym_Not] = ACTIONS(5447),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5447),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5447),
    [anon_sym_PLUS] = ACTIONS(5449),
    [sym_datetime_literal] = ACTIONS(5449),
    [sym_date_literal] = ACTIONS(5447),
    [sym_time_literal] = ACTIONS(5447),
    [sym_biginteger_literal] = ACTIONS(5449),
    [anon_sym_if] = ACTIONS(5447),
    [anon_sym_IF] = ACTIONS(5447),
    [anon_sym_If] = ACTIONS(5447),
    [anon_sym_case] = ACTIONS(5447),
    [anon_sym_CASE] = ACTIONS(5447),
    [anon_sym_Case] = ACTIONS(5447),
    [anon_sym_for] = ACTIONS(5447),
    [anon_sym_FOR] = ACTIONS(5447),
    [anon_sym_For] = ACTIONS(5447),
    [anon_sym_foreach] = ACTIONS(5447),
    [anon_sym_FOREACH] = ACTIONS(5447),
    [anon_sym_Foreach] = ACTIONS(5447),
    [anon_sym_while] = ACTIONS(5447),
    [anon_sym_WHILE] = ACTIONS(5447),
    [anon_sym_While] = ACTIONS(5447),
    [anon_sym_repeat] = ACTIONS(5447),
    [anon_sym_REPEAT] = ACTIONS(5447),
    [anon_sym_Repeat] = ACTIONS(5447),
    [anon_sym_exit] = ACTIONS(5447),
    [anon_sym_EXIT] = ACTIONS(5447),
    [anon_sym_Exit] = ACTIONS(5447),
    [anon_sym_continue] = ACTIONS(5447),
    [anon_sym_CONTINUE] = ACTIONS(5447),
    [anon_sym_Continue] = ACTIONS(5447),
    [anon_sym_break] = ACTIONS(5447),
    [anon_sym_BREAK] = ACTIONS(5447),
    [anon_sym_Break] = ACTIONS(5447),
    [anon_sym_with] = ACTIONS(5447),
    [anon_sym_WITH] = ACTIONS(5447),
    [anon_sym_With] = ACTIONS(5447),
    [sym_asserterror_keyword] = ACTIONS(5449),
    [sym_page_keyword] = ACTIONS(5447),
    [anon_sym_codeunit] = ACTIONS(5447),
    [anon_sym_CODEUNIT] = ACTIONS(5447),
    [anon_sym_Codeunit] = ACTIONS(5447),
    [anon_sym_CodeUnit] = ACTIONS(5447),
    [anon_sym_COdeunit] = ACTIONS(5447),
    [anon_sym_codeUnit] = ACTIONS(5447),
    [sym_report_keyword] = ACTIONS(5447),
    [sym_query_keyword] = ACTIONS(5447),
    [anon_sym_xmlport] = ACTIONS(5447),
    [anon_sym_XMLPORT] = ACTIONS(5447),
    [anon_sym_Xmlport] = ACTIONS(5447),
    [anon_sym_XMLport] = ACTIONS(5447),
    [anon_sym_XMLPort] = ACTIONS(5447),
    [anon_sym_XmlPort] = ACTIONS(5447),
    [anon_sym_enum] = ACTIONS(5447),
    [anon_sym_ENUM] = ACTIONS(5447),
    [anon_sym_Enum] = ACTIONS(5447),
    [anon_sym_eNUM] = ACTIONS(5447),
    [anon_sym_eNum] = ACTIONS(5447),
    [anon_sym_ENum] = ACTIONS(5447),
    [sym_quoted_identifier] = ACTIONS(5449),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5449),
    [sym_integer] = ACTIONS(5447),
    [sym_continue_as_identifier] = ACTIONS(5449),
    [sym_preproc_open] = ACTIONS(5449),
  },
  [STATE(2448)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_elif] = STATE(2572),
    [sym_preproc_else] = STATE(2710),
    [sym_preproc_endif] = STATE(5471),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(8034),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(5512),
    [anon_sym_POUNDELIF] = ACTIONS(5512),
    [anon_sym_POUNDElif] = ACTIONS(5512),
    [anon_sym_POUNDelse] = ACTIONS(5514),
    [anon_sym_POUNDELSE] = ACTIONS(5514),
    [anon_sym_POUNDElse] = ACTIONS(5514),
    [anon_sym_POUNDendif] = ACTIONS(5570),
    [anon_sym_POUNDENDIF] = ACTIONS(5570),
    [anon_sym_POUNDEndif] = ACTIONS(5570),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5570),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2449)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_elif] = STATE(2572),
    [sym_preproc_else] = STATE(2704),
    [sym_preproc_endif] = STATE(4981),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(8018),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(5512),
    [anon_sym_POUNDELIF] = ACTIONS(5512),
    [anon_sym_POUNDElif] = ACTIONS(5512),
    [anon_sym_POUNDelse] = ACTIONS(5514),
    [anon_sym_POUNDELSE] = ACTIONS(5514),
    [anon_sym_POUNDElse] = ACTIONS(5514),
    [anon_sym_POUNDendif] = ACTIONS(5574),
    [anon_sym_POUNDENDIF] = ACTIONS(5574),
    [anon_sym_POUNDEndif] = ACTIONS(5574),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5574),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2450)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_elif] = STATE(2572),
    [sym_preproc_else] = STATE(2697),
    [sym_preproc_endif] = STATE(7489),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(7869),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(5512),
    [anon_sym_POUNDELIF] = ACTIONS(5512),
    [anon_sym_POUNDElif] = ACTIONS(5512),
    [anon_sym_POUNDelse] = ACTIONS(5514),
    [anon_sym_POUNDELSE] = ACTIONS(5514),
    [anon_sym_POUNDElse] = ACTIONS(5514),
    [anon_sym_POUNDendif] = ACTIONS(5560),
    [anon_sym_POUNDENDIF] = ACTIONS(5560),
    [anon_sym_POUNDEndif] = ACTIONS(5560),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5560),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2451)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_elif] = STATE(2572),
    [sym_preproc_else] = STATE(2671),
    [sym_preproc_endif] = STATE(4768),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(8046),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(5512),
    [anon_sym_POUNDELIF] = ACTIONS(5512),
    [anon_sym_POUNDElif] = ACTIONS(5512),
    [anon_sym_POUNDelse] = ACTIONS(5514),
    [anon_sym_POUNDELSE] = ACTIONS(5514),
    [anon_sym_POUNDElse] = ACTIONS(5514),
    [anon_sym_POUNDendif] = ACTIONS(5572),
    [anon_sym_POUNDENDIF] = ACTIONS(5572),
    [anon_sym_POUNDEndif] = ACTIONS(5572),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5572),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2452)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_elif] = STATE(2572),
    [sym_preproc_else] = STATE(2712),
    [sym_preproc_endif] = STATE(3823),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(8132),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(5512),
    [anon_sym_POUNDELIF] = ACTIONS(5512),
    [anon_sym_POUNDElif] = ACTIONS(5512),
    [anon_sym_POUNDelse] = ACTIONS(5514),
    [anon_sym_POUNDELSE] = ACTIONS(5514),
    [anon_sym_POUNDElse] = ACTIONS(5514),
    [anon_sym_POUNDendif] = ACTIONS(5562),
    [anon_sym_POUNDENDIF] = ACTIONS(5562),
    [anon_sym_POUNDEndif] = ACTIONS(5562),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5562),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2453)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_elif] = STATE(2572),
    [sym_preproc_else] = STATE(2682),
    [sym_preproc_endif] = STATE(2958),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(7780),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(5512),
    [anon_sym_POUNDELIF] = ACTIONS(5512),
    [anon_sym_POUNDElif] = ACTIONS(5512),
    [anon_sym_POUNDelse] = ACTIONS(5514),
    [anon_sym_POUNDELSE] = ACTIONS(5514),
    [anon_sym_POUNDElse] = ACTIONS(5514),
    [anon_sym_POUNDendif] = ACTIONS(5568),
    [anon_sym_POUNDENDIF] = ACTIONS(5568),
    [anon_sym_POUNDEndif] = ACTIONS(5568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5568),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2454)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_elif] = STATE(2572),
    [sym_preproc_else] = STATE(2691),
    [sym_preproc_endif] = STATE(7585),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(7990),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(5512),
    [anon_sym_POUNDELIF] = ACTIONS(5512),
    [anon_sym_POUNDElif] = ACTIONS(5512),
    [anon_sym_POUNDelse] = ACTIONS(5514),
    [anon_sym_POUNDELSE] = ACTIONS(5514),
    [anon_sym_POUNDElse] = ACTIONS(5514),
    [anon_sym_POUNDendif] = ACTIONS(5516),
    [anon_sym_POUNDENDIF] = ACTIONS(5516),
    [anon_sym_POUNDEndif] = ACTIONS(5516),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5516),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2455)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_elif] = STATE(2572),
    [sym_preproc_else] = STATE(2683),
    [sym_preproc_endif] = STATE(7061),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(7935),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(5512),
    [anon_sym_POUNDELIF] = ACTIONS(5512),
    [anon_sym_POUNDElif] = ACTIONS(5512),
    [anon_sym_POUNDelse] = ACTIONS(5514),
    [anon_sym_POUNDELSE] = ACTIONS(5514),
    [anon_sym_POUNDElse] = ACTIONS(5514),
    [anon_sym_POUNDendif] = ACTIONS(5576),
    [anon_sym_POUNDENDIF] = ACTIONS(5576),
    [anon_sym_POUNDEndif] = ACTIONS(5576),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5576),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2456)] = {
    [sym__body_element] = STATE(5591),
    [sym_empty_statement] = STATE(5591),
    [sym_property] = STATE(5591),
    [sym_fields_section] = STATE(5591),
    [sym_keys_section] = STATE(5591),
    [sym_fieldgroups_section] = STATE(5591),
    [sym_enum_value_declaration] = STATE(5591),
    [sym_labels_section] = STATE(5591),
    [sym_layout_section] = STATE(5591),
    [sym_modify_modification] = STATE(5591),
    [sym_actions_section] = STATE(5591),
    [sym_views_section] = STATE(5591),
    [sym_dataset_section] = STATE(5591),
    [sym_requestpage_section] = STATE(5591),
    [sym_rendering_section] = STATE(5591),
    [sym_elements_section] = STATE(5591),
    [sym_schema_section] = STATE(5591),
    [sym_xmlport_element] = STATE(2571),
    [sym__xmlport_body_element] = STATE(2571),
    [sym_preproc_conditional_xmlport] = STATE(2571),
    [sym_xmlport_attribute] = STATE(2571),
    [sym_assembly_declaration] = STATE(5591),
    [sym_event_declaration] = STATE(5591),
    [sym_procedure] = STATE(5591),
    [sym_preproc_split_procedure] = STATE(5591),
    [sym__procedure_header] = STATE(8109),
    [sym_procedure_modifier] = STATE(12340),
    [sym_trigger_declaration] = STATE(5591),
    [sym_var_section] = STATE(5591),
    [sym_attribute_item] = STATE(5844),
    [sym_preproc_conditional] = STATE(5591),
    [sym_preproc_if] = STATE(2446),
    [sym_preproc_elif] = STATE(2631),
    [sym_preproc_else] = STATE(2737),
    [sym_preproc_endif] = STATE(6637),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(2758),
    [aux_sym_xmlport_element_repeat1] = STATE(2571),
    [aux_sym_preproc_conditional_xmlport_repeat1] = STATE(7956),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_repeat1] = STATE(7927),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDelif] = ACTIONS(5825),
    [anon_sym_POUNDELIF] = ACTIONS(5825),
    [anon_sym_POUNDElif] = ACTIONS(5825),
    [anon_sym_POUNDelse] = ACTIONS(5827),
    [anon_sym_POUNDELSE] = ACTIONS(5827),
    [anon_sym_POUNDElse] = ACTIONS(5827),
    [anon_sym_POUNDendif] = ACTIONS(5869),
    [anon_sym_POUNDENDIF] = ACTIONS(5869),
    [anon_sym_POUNDEndif] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5831),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(5869),
  },
  [STATE(2457)] = {
    [ts_builtin_sym_end] = ACTIONS(4945),
    [anon_sym_POUNDif] = ACTIONS(4945),
    [anon_sym_POUNDIF] = ACTIONS(4945),
    [anon_sym_POUNDIf] = ACTIONS(4945),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4947),
    [anon_sym_tableextension] = ACTIONS(4945),
    [anon_sym_TABLEEXTENSION] = ACTIONS(4945),
    [anon_sym_Tableextension] = ACTIONS(4945),
    [anon_sym_TableExtension] = ACTIONS(4945),
    [anon_sym_tableExtension] = ACTIONS(4945),
    [sym_page_keyword] = ACTIONS(4947),
    [anon_sym_pageextension] = ACTIONS(4945),
    [anon_sym_PAGEEXTENSION] = ACTIONS(4945),
    [anon_sym_Pageextension] = ACTIONS(4945),
    [anon_sym_PageExtension] = ACTIONS(4945),
    [anon_sym_pageExtension] = ACTIONS(4945),
    [anon_sym_codeunit] = ACTIONS(4945),
    [anon_sym_CODEUNIT] = ACTIONS(4945),
    [anon_sym_Codeunit] = ACTIONS(4945),
    [anon_sym_CodeUnit] = ACTIONS(4945),
    [anon_sym_COdeunit] = ACTIONS(4945),
    [anon_sym_codeUnit] = ACTIONS(4945),
    [sym_report_keyword] = ACTIONS(4947),
    [anon_sym_reportextension] = ACTIONS(4945),
    [anon_sym_REPORTEXTENSION] = ACTIONS(4945),
    [anon_sym_Reportextension] = ACTIONS(4945),
    [anon_sym_ReportExtension] = ACTIONS(4945),
    [anon_sym_reportExtension] = ACTIONS(4945),
    [sym_query_keyword] = ACTIONS(4945),
    [anon_sym_xmlport] = ACTIONS(4945),
    [anon_sym_XMLPORT] = ACTIONS(4945),
    [anon_sym_Xmlport] = ACTIONS(4945),
    [anon_sym_XMLport] = ACTIONS(4945),
    [anon_sym_XMLPort] = ACTIONS(4945),
    [anon_sym_XmlPort] = ACTIONS(4945),
    [anon_sym_enum] = ACTIONS(4947),
    [anon_sym_ENUM] = ACTIONS(4947),
    [anon_sym_Enum] = ACTIONS(4947),
    [anon_sym_eNUM] = ACTIONS(4945),
    [anon_sym_eNum] = ACTIONS(4945),
    [anon_sym_ENum] = ACTIONS(4945),
    [anon_sym_enumextension] = ACTIONS(4945),
    [anon_sym_ENUMEXTENSION] = ACTIONS(4945),
    [anon_sym_Enumextension] = ACTIONS(4945),
    [anon_sym_EnumExtension] = ACTIONS(4945),
    [anon_sym_enumExtension] = ACTIONS(4945),
    [sym_interface_keyword] = ACTIONS(4945),
    [anon_sym_controladdin] = ACTIONS(4945),
    [anon_sym_CONTROLADDIN] = ACTIONS(4945),
    [anon_sym_Controladdin] = ACTIONS(4945),
    [anon_sym_ControlAddIn] = ACTIONS(4945),
    [anon_sym_ControlAddin] = ACTIONS(4945),
    [anon_sym_controlAddIn] = ACTIONS(4945),
    [anon_sym_controlAddin] = ACTIONS(4945),
    [anon_sym_dotnet] = ACTIONS(4945),
    [anon_sym_DOTNET] = ACTIONS(4945),
    [anon_sym_Dotnet] = ACTIONS(4945),
    [anon_sym_DotNet] = ACTIONS(4945),
    [anon_sym_dotNet] = ACTIONS(4945),
    [sym_profile_keyword] = ACTIONS(4947),
    [anon_sym_profileextension] = ACTIONS(4945),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(4945),
    [anon_sym_Profileextension] = ACTIONS(4945),
    [anon_sym_ProfileExtension] = ACTIONS(4945),
    [anon_sym_profileExtension] = ACTIONS(4945),
    [anon_sym_permissionset] = ACTIONS(4947),
    [anon_sym_PERMISSIONSET] = ACTIONS(4947),
    [anon_sym_Permissionset] = ACTIONS(4947),
    [anon_sym_PermissionSet] = ACTIONS(4947),
    [anon_sym_permissionSet] = ACTIONS(4947),
    [anon_sym_permissionsetextension] = ACTIONS(4945),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(4945),
    [anon_sym_Permissionsetextension] = ACTIONS(4945),
    [anon_sym_PermissionSetExtension] = ACTIONS(4945),
    [anon_sym_permissionSetExtension] = ACTIONS(4945),
    [sym_entitlement_keyword] = ACTIONS(4945),
    [anon_sym_pagecustomization] = ACTIONS(4945),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(4945),
    [anon_sym_Pagecustomization] = ACTIONS(4945),
    [anon_sym_PageCustomization] = ACTIONS(4945),
    [anon_sym_pageCustomization] = ACTIONS(4945),
    [sym_using_keyword] = ACTIONS(4945),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(4945),
  },
  [STATE(2458)] = {
    [ts_builtin_sym_end] = ACTIONS(5317),
    [anon_sym_POUNDif] = ACTIONS(5317),
    [anon_sym_POUNDIF] = ACTIONS(5317),
    [anon_sym_POUNDIf] = ACTIONS(5317),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5319),
    [anon_sym_tableextension] = ACTIONS(5317),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5317),
    [anon_sym_Tableextension] = ACTIONS(5317),
    [anon_sym_TableExtension] = ACTIONS(5317),
    [anon_sym_tableExtension] = ACTIONS(5317),
    [sym_page_keyword] = ACTIONS(5319),
    [anon_sym_pageextension] = ACTIONS(5317),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5317),
    [anon_sym_Pageextension] = ACTIONS(5317),
    [anon_sym_PageExtension] = ACTIONS(5317),
    [anon_sym_pageExtension] = ACTIONS(5317),
    [anon_sym_codeunit] = ACTIONS(5317),
    [anon_sym_CODEUNIT] = ACTIONS(5317),
    [anon_sym_Codeunit] = ACTIONS(5317),
    [anon_sym_CodeUnit] = ACTIONS(5317),
    [anon_sym_COdeunit] = ACTIONS(5317),
    [anon_sym_codeUnit] = ACTIONS(5317),
    [sym_report_keyword] = ACTIONS(5319),
    [anon_sym_reportextension] = ACTIONS(5317),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5317),
    [anon_sym_Reportextension] = ACTIONS(5317),
    [anon_sym_ReportExtension] = ACTIONS(5317),
    [anon_sym_reportExtension] = ACTIONS(5317),
    [sym_query_keyword] = ACTIONS(5317),
    [anon_sym_xmlport] = ACTIONS(5317),
    [anon_sym_XMLPORT] = ACTIONS(5317),
    [anon_sym_Xmlport] = ACTIONS(5317),
    [anon_sym_XMLport] = ACTIONS(5317),
    [anon_sym_XMLPort] = ACTIONS(5317),
    [anon_sym_XmlPort] = ACTIONS(5317),
    [anon_sym_enum] = ACTIONS(5319),
    [anon_sym_ENUM] = ACTIONS(5319),
    [anon_sym_Enum] = ACTIONS(5319),
    [anon_sym_eNUM] = ACTIONS(5317),
    [anon_sym_eNum] = ACTIONS(5317),
    [anon_sym_ENum] = ACTIONS(5317),
    [anon_sym_enumextension] = ACTIONS(5317),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5317),
    [anon_sym_Enumextension] = ACTIONS(5317),
    [anon_sym_EnumExtension] = ACTIONS(5317),
    [anon_sym_enumExtension] = ACTIONS(5317),
    [sym_interface_keyword] = ACTIONS(5317),
    [anon_sym_controladdin] = ACTIONS(5317),
    [anon_sym_CONTROLADDIN] = ACTIONS(5317),
    [anon_sym_Controladdin] = ACTIONS(5317),
    [anon_sym_ControlAddIn] = ACTIONS(5317),
    [anon_sym_ControlAddin] = ACTIONS(5317),
    [anon_sym_controlAddIn] = ACTIONS(5317),
    [anon_sym_controlAddin] = ACTIONS(5317),
    [anon_sym_dotnet] = ACTIONS(5317),
    [anon_sym_DOTNET] = ACTIONS(5317),
    [anon_sym_Dotnet] = ACTIONS(5317),
    [anon_sym_DotNet] = ACTIONS(5317),
    [anon_sym_dotNet] = ACTIONS(5317),
    [sym_profile_keyword] = ACTIONS(5319),
    [anon_sym_profileextension] = ACTIONS(5317),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5317),
    [anon_sym_Profileextension] = ACTIONS(5317),
    [anon_sym_ProfileExtension] = ACTIONS(5317),
    [anon_sym_profileExtension] = ACTIONS(5317),
    [anon_sym_permissionset] = ACTIONS(5319),
    [anon_sym_PERMISSIONSET] = ACTIONS(5319),
    [anon_sym_Permissionset] = ACTIONS(5319),
    [anon_sym_PermissionSet] = ACTIONS(5319),
    [anon_sym_permissionSet] = ACTIONS(5319),
    [anon_sym_permissionsetextension] = ACTIONS(5317),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5317),
    [anon_sym_Permissionsetextension] = ACTIONS(5317),
    [anon_sym_PermissionSetExtension] = ACTIONS(5317),
    [anon_sym_permissionSetExtension] = ACTIONS(5317),
    [sym_entitlement_keyword] = ACTIONS(5317),
    [anon_sym_pagecustomization] = ACTIONS(5317),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5317),
    [anon_sym_Pagecustomization] = ACTIONS(5317),
    [anon_sym_PageCustomization] = ACTIONS(5317),
    [anon_sym_pageCustomization] = ACTIONS(5317),
    [sym_using_keyword] = ACTIONS(5317),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5317),
  },
  [STATE(2459)] = {
    [ts_builtin_sym_end] = ACTIONS(5148),
    [anon_sym_POUNDif] = ACTIONS(5148),
    [anon_sym_POUNDIF] = ACTIONS(5148),
    [anon_sym_POUNDIf] = ACTIONS(5148),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5150),
    [anon_sym_tableextension] = ACTIONS(5148),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5148),
    [anon_sym_Tableextension] = ACTIONS(5148),
    [anon_sym_TableExtension] = ACTIONS(5148),
    [anon_sym_tableExtension] = ACTIONS(5148),
    [sym_page_keyword] = ACTIONS(5150),
    [anon_sym_pageextension] = ACTIONS(5148),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5148),
    [anon_sym_Pageextension] = ACTIONS(5148),
    [anon_sym_PageExtension] = ACTIONS(5148),
    [anon_sym_pageExtension] = ACTIONS(5148),
    [anon_sym_codeunit] = ACTIONS(5148),
    [anon_sym_CODEUNIT] = ACTIONS(5148),
    [anon_sym_Codeunit] = ACTIONS(5148),
    [anon_sym_CodeUnit] = ACTIONS(5148),
    [anon_sym_COdeunit] = ACTIONS(5148),
    [anon_sym_codeUnit] = ACTIONS(5148),
    [sym_report_keyword] = ACTIONS(5150),
    [anon_sym_reportextension] = ACTIONS(5148),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5148),
    [anon_sym_Reportextension] = ACTIONS(5148),
    [anon_sym_ReportExtension] = ACTIONS(5148),
    [anon_sym_reportExtension] = ACTIONS(5148),
    [sym_query_keyword] = ACTIONS(5148),
    [anon_sym_xmlport] = ACTIONS(5148),
    [anon_sym_XMLPORT] = ACTIONS(5148),
    [anon_sym_Xmlport] = ACTIONS(5148),
    [anon_sym_XMLport] = ACTIONS(5148),
    [anon_sym_XMLPort] = ACTIONS(5148),
    [anon_sym_XmlPort] = ACTIONS(5148),
    [anon_sym_enum] = ACTIONS(5150),
    [anon_sym_ENUM] = ACTIONS(5150),
    [anon_sym_Enum] = ACTIONS(5150),
    [anon_sym_eNUM] = ACTIONS(5148),
    [anon_sym_eNum] = ACTIONS(5148),
    [anon_sym_ENum] = ACTIONS(5148),
    [anon_sym_enumextension] = ACTIONS(5148),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5148),
    [anon_sym_Enumextension] = ACTIONS(5148),
    [anon_sym_EnumExtension] = ACTIONS(5148),
    [anon_sym_enumExtension] = ACTIONS(5148),
    [sym_interface_keyword] = ACTIONS(5148),
    [anon_sym_controladdin] = ACTIONS(5148),
    [anon_sym_CONTROLADDIN] = ACTIONS(5148),
    [anon_sym_Controladdin] = ACTIONS(5148),
    [anon_sym_ControlAddIn] = ACTIONS(5148),
    [anon_sym_ControlAddin] = ACTIONS(5148),
    [anon_sym_controlAddIn] = ACTIONS(5148),
    [anon_sym_controlAddin] = ACTIONS(5148),
    [anon_sym_dotnet] = ACTIONS(5148),
    [anon_sym_DOTNET] = ACTIONS(5148),
    [anon_sym_Dotnet] = ACTIONS(5148),
    [anon_sym_DotNet] = ACTIONS(5148),
    [anon_sym_dotNet] = ACTIONS(5148),
    [sym_profile_keyword] = ACTIONS(5150),
    [anon_sym_profileextension] = ACTIONS(5148),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5148),
    [anon_sym_Profileextension] = ACTIONS(5148),
    [anon_sym_ProfileExtension] = ACTIONS(5148),
    [anon_sym_profileExtension] = ACTIONS(5148),
    [anon_sym_permissionset] = ACTIONS(5150),
    [anon_sym_PERMISSIONSET] = ACTIONS(5150),
    [anon_sym_Permissionset] = ACTIONS(5150),
    [anon_sym_PermissionSet] = ACTIONS(5150),
    [anon_sym_permissionSet] = ACTIONS(5150),
    [anon_sym_permissionsetextension] = ACTIONS(5148),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5148),
    [anon_sym_Permissionsetextension] = ACTIONS(5148),
    [anon_sym_PermissionSetExtension] = ACTIONS(5148),
    [anon_sym_permissionSetExtension] = ACTIONS(5148),
    [sym_entitlement_keyword] = ACTIONS(5148),
    [anon_sym_pagecustomization] = ACTIONS(5148),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5148),
    [anon_sym_Pagecustomization] = ACTIONS(5148),
    [anon_sym_PageCustomization] = ACTIONS(5148),
    [anon_sym_pageCustomization] = ACTIONS(5148),
    [sym_using_keyword] = ACTIONS(5148),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5148),
  },
  [STATE(2460)] = {
    [ts_builtin_sym_end] = ACTIONS(5152),
    [anon_sym_POUNDif] = ACTIONS(5152),
    [anon_sym_POUNDIF] = ACTIONS(5152),
    [anon_sym_POUNDIf] = ACTIONS(5152),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5154),
    [anon_sym_tableextension] = ACTIONS(5152),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5152),
    [anon_sym_Tableextension] = ACTIONS(5152),
    [anon_sym_TableExtension] = ACTIONS(5152),
    [anon_sym_tableExtension] = ACTIONS(5152),
    [sym_page_keyword] = ACTIONS(5154),
    [anon_sym_pageextension] = ACTIONS(5152),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5152),
    [anon_sym_Pageextension] = ACTIONS(5152),
    [anon_sym_PageExtension] = ACTIONS(5152),
    [anon_sym_pageExtension] = ACTIONS(5152),
    [anon_sym_codeunit] = ACTIONS(5152),
    [anon_sym_CODEUNIT] = ACTIONS(5152),
    [anon_sym_Codeunit] = ACTIONS(5152),
    [anon_sym_CodeUnit] = ACTIONS(5152),
    [anon_sym_COdeunit] = ACTIONS(5152),
    [anon_sym_codeUnit] = ACTIONS(5152),
    [sym_report_keyword] = ACTIONS(5154),
    [anon_sym_reportextension] = ACTIONS(5152),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5152),
    [anon_sym_Reportextension] = ACTIONS(5152),
    [anon_sym_ReportExtension] = ACTIONS(5152),
    [anon_sym_reportExtension] = ACTIONS(5152),
    [sym_query_keyword] = ACTIONS(5152),
    [anon_sym_xmlport] = ACTIONS(5152),
    [anon_sym_XMLPORT] = ACTIONS(5152),
    [anon_sym_Xmlport] = ACTIONS(5152),
    [anon_sym_XMLport] = ACTIONS(5152),
    [anon_sym_XMLPort] = ACTIONS(5152),
    [anon_sym_XmlPort] = ACTIONS(5152),
    [anon_sym_enum] = ACTIONS(5154),
    [anon_sym_ENUM] = ACTIONS(5154),
    [anon_sym_Enum] = ACTIONS(5154),
    [anon_sym_eNUM] = ACTIONS(5152),
    [anon_sym_eNum] = ACTIONS(5152),
    [anon_sym_ENum] = ACTIONS(5152),
    [anon_sym_enumextension] = ACTIONS(5152),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5152),
    [anon_sym_Enumextension] = ACTIONS(5152),
    [anon_sym_EnumExtension] = ACTIONS(5152),
    [anon_sym_enumExtension] = ACTIONS(5152),
    [sym_interface_keyword] = ACTIONS(5152),
    [anon_sym_controladdin] = ACTIONS(5152),
    [anon_sym_CONTROLADDIN] = ACTIONS(5152),
    [anon_sym_Controladdin] = ACTIONS(5152),
    [anon_sym_ControlAddIn] = ACTIONS(5152),
    [anon_sym_ControlAddin] = ACTIONS(5152),
    [anon_sym_controlAddIn] = ACTIONS(5152),
    [anon_sym_controlAddin] = ACTIONS(5152),
    [anon_sym_dotnet] = ACTIONS(5152),
    [anon_sym_DOTNET] = ACTIONS(5152),
    [anon_sym_Dotnet] = ACTIONS(5152),
    [anon_sym_DotNet] = ACTIONS(5152),
    [anon_sym_dotNet] = ACTIONS(5152),
    [sym_profile_keyword] = ACTIONS(5154),
    [anon_sym_profileextension] = ACTIONS(5152),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5152),
    [anon_sym_Profileextension] = ACTIONS(5152),
    [anon_sym_ProfileExtension] = ACTIONS(5152),
    [anon_sym_profileExtension] = ACTIONS(5152),
    [anon_sym_permissionset] = ACTIONS(5154),
    [anon_sym_PERMISSIONSET] = ACTIONS(5154),
    [anon_sym_Permissionset] = ACTIONS(5154),
    [anon_sym_PermissionSet] = ACTIONS(5154),
    [anon_sym_permissionSet] = ACTIONS(5154),
    [anon_sym_permissionsetextension] = ACTIONS(5152),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5152),
    [anon_sym_Permissionsetextension] = ACTIONS(5152),
    [anon_sym_PermissionSetExtension] = ACTIONS(5152),
    [anon_sym_permissionSetExtension] = ACTIONS(5152),
    [sym_entitlement_keyword] = ACTIONS(5152),
    [anon_sym_pagecustomization] = ACTIONS(5152),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5152),
    [anon_sym_Pagecustomization] = ACTIONS(5152),
    [anon_sym_PageCustomization] = ACTIONS(5152),
    [anon_sym_pageCustomization] = ACTIONS(5152),
    [sym_using_keyword] = ACTIONS(5152),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5152),
  },
  [STATE(2461)] = {
    [ts_builtin_sym_end] = ACTIONS(5156),
    [anon_sym_POUNDif] = ACTIONS(5156),
    [anon_sym_POUNDIF] = ACTIONS(5156),
    [anon_sym_POUNDIf] = ACTIONS(5156),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5158),
    [anon_sym_tableextension] = ACTIONS(5156),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5156),
    [anon_sym_Tableextension] = ACTIONS(5156),
    [anon_sym_TableExtension] = ACTIONS(5156),
    [anon_sym_tableExtension] = ACTIONS(5156),
    [sym_page_keyword] = ACTIONS(5158),
    [anon_sym_pageextension] = ACTIONS(5156),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5156),
    [anon_sym_Pageextension] = ACTIONS(5156),
    [anon_sym_PageExtension] = ACTIONS(5156),
    [anon_sym_pageExtension] = ACTIONS(5156),
    [anon_sym_codeunit] = ACTIONS(5156),
    [anon_sym_CODEUNIT] = ACTIONS(5156),
    [anon_sym_Codeunit] = ACTIONS(5156),
    [anon_sym_CodeUnit] = ACTIONS(5156),
    [anon_sym_COdeunit] = ACTIONS(5156),
    [anon_sym_codeUnit] = ACTIONS(5156),
    [sym_report_keyword] = ACTIONS(5158),
    [anon_sym_reportextension] = ACTIONS(5156),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5156),
    [anon_sym_Reportextension] = ACTIONS(5156),
    [anon_sym_ReportExtension] = ACTIONS(5156),
    [anon_sym_reportExtension] = ACTIONS(5156),
    [sym_query_keyword] = ACTIONS(5156),
    [anon_sym_xmlport] = ACTIONS(5156),
    [anon_sym_XMLPORT] = ACTIONS(5156),
    [anon_sym_Xmlport] = ACTIONS(5156),
    [anon_sym_XMLport] = ACTIONS(5156),
    [anon_sym_XMLPort] = ACTIONS(5156),
    [anon_sym_XmlPort] = ACTIONS(5156),
    [anon_sym_enum] = ACTIONS(5158),
    [anon_sym_ENUM] = ACTIONS(5158),
    [anon_sym_Enum] = ACTIONS(5158),
    [anon_sym_eNUM] = ACTIONS(5156),
    [anon_sym_eNum] = ACTIONS(5156),
    [anon_sym_ENum] = ACTIONS(5156),
    [anon_sym_enumextension] = ACTIONS(5156),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5156),
    [anon_sym_Enumextension] = ACTIONS(5156),
    [anon_sym_EnumExtension] = ACTIONS(5156),
    [anon_sym_enumExtension] = ACTIONS(5156),
    [sym_interface_keyword] = ACTIONS(5156),
    [anon_sym_controladdin] = ACTIONS(5156),
    [anon_sym_CONTROLADDIN] = ACTIONS(5156),
    [anon_sym_Controladdin] = ACTIONS(5156),
    [anon_sym_ControlAddIn] = ACTIONS(5156),
    [anon_sym_ControlAddin] = ACTIONS(5156),
    [anon_sym_controlAddIn] = ACTIONS(5156),
    [anon_sym_controlAddin] = ACTIONS(5156),
    [anon_sym_dotnet] = ACTIONS(5156),
    [anon_sym_DOTNET] = ACTIONS(5156),
    [anon_sym_Dotnet] = ACTIONS(5156),
    [anon_sym_DotNet] = ACTIONS(5156),
    [anon_sym_dotNet] = ACTIONS(5156),
    [sym_profile_keyword] = ACTIONS(5158),
    [anon_sym_profileextension] = ACTIONS(5156),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5156),
    [anon_sym_Profileextension] = ACTIONS(5156),
    [anon_sym_ProfileExtension] = ACTIONS(5156),
    [anon_sym_profileExtension] = ACTIONS(5156),
    [anon_sym_permissionset] = ACTIONS(5158),
    [anon_sym_PERMISSIONSET] = ACTIONS(5158),
    [anon_sym_Permissionset] = ACTIONS(5158),
    [anon_sym_PermissionSet] = ACTIONS(5158),
    [anon_sym_permissionSet] = ACTIONS(5158),
    [anon_sym_permissionsetextension] = ACTIONS(5156),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5156),
    [anon_sym_Permissionsetextension] = ACTIONS(5156),
    [anon_sym_PermissionSetExtension] = ACTIONS(5156),
    [anon_sym_permissionSetExtension] = ACTIONS(5156),
    [sym_entitlement_keyword] = ACTIONS(5156),
    [anon_sym_pagecustomization] = ACTIONS(5156),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5156),
    [anon_sym_Pagecustomization] = ACTIONS(5156),
    [anon_sym_PageCustomization] = ACTIONS(5156),
    [anon_sym_pageCustomization] = ACTIONS(5156),
    [sym_using_keyword] = ACTIONS(5156),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5156),
  },
  [STATE(2462)] = {
    [ts_builtin_sym_end] = ACTIONS(5009),
    [anon_sym_POUNDif] = ACTIONS(5009),
    [anon_sym_POUNDIF] = ACTIONS(5009),
    [anon_sym_POUNDIf] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5011),
    [anon_sym_tableextension] = ACTIONS(5009),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5009),
    [anon_sym_Tableextension] = ACTIONS(5009),
    [anon_sym_TableExtension] = ACTIONS(5009),
    [anon_sym_tableExtension] = ACTIONS(5009),
    [sym_page_keyword] = ACTIONS(5011),
    [anon_sym_pageextension] = ACTIONS(5009),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5009),
    [anon_sym_Pageextension] = ACTIONS(5009),
    [anon_sym_PageExtension] = ACTIONS(5009),
    [anon_sym_pageExtension] = ACTIONS(5009),
    [anon_sym_codeunit] = ACTIONS(5009),
    [anon_sym_CODEUNIT] = ACTIONS(5009),
    [anon_sym_Codeunit] = ACTIONS(5009),
    [anon_sym_CodeUnit] = ACTIONS(5009),
    [anon_sym_COdeunit] = ACTIONS(5009),
    [anon_sym_codeUnit] = ACTIONS(5009),
    [sym_report_keyword] = ACTIONS(5011),
    [anon_sym_reportextension] = ACTIONS(5009),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5009),
    [anon_sym_Reportextension] = ACTIONS(5009),
    [anon_sym_ReportExtension] = ACTIONS(5009),
    [anon_sym_reportExtension] = ACTIONS(5009),
    [sym_query_keyword] = ACTIONS(5009),
    [anon_sym_xmlport] = ACTIONS(5009),
    [anon_sym_XMLPORT] = ACTIONS(5009),
    [anon_sym_Xmlport] = ACTIONS(5009),
    [anon_sym_XMLport] = ACTIONS(5009),
    [anon_sym_XMLPort] = ACTIONS(5009),
    [anon_sym_XmlPort] = ACTIONS(5009),
    [anon_sym_enum] = ACTIONS(5011),
    [anon_sym_ENUM] = ACTIONS(5011),
    [anon_sym_Enum] = ACTIONS(5011),
    [anon_sym_eNUM] = ACTIONS(5009),
    [anon_sym_eNum] = ACTIONS(5009),
    [anon_sym_ENum] = ACTIONS(5009),
    [anon_sym_enumextension] = ACTIONS(5009),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5009),
    [anon_sym_Enumextension] = ACTIONS(5009),
    [anon_sym_EnumExtension] = ACTIONS(5009),
    [anon_sym_enumExtension] = ACTIONS(5009),
    [sym_interface_keyword] = ACTIONS(5009),
    [anon_sym_controladdin] = ACTIONS(5009),
    [anon_sym_CONTROLADDIN] = ACTIONS(5009),
    [anon_sym_Controladdin] = ACTIONS(5009),
    [anon_sym_ControlAddIn] = ACTIONS(5009),
    [anon_sym_ControlAddin] = ACTIONS(5009),
    [anon_sym_controlAddIn] = ACTIONS(5009),
    [anon_sym_controlAddin] = ACTIONS(5009),
    [anon_sym_dotnet] = ACTIONS(5009),
    [anon_sym_DOTNET] = ACTIONS(5009),
    [anon_sym_Dotnet] = ACTIONS(5009),
    [anon_sym_DotNet] = ACTIONS(5009),
    [anon_sym_dotNet] = ACTIONS(5009),
    [sym_profile_keyword] = ACTIONS(5011),
    [anon_sym_profileextension] = ACTIONS(5009),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5009),
    [anon_sym_Profileextension] = ACTIONS(5009),
    [anon_sym_ProfileExtension] = ACTIONS(5009),
    [anon_sym_profileExtension] = ACTIONS(5009),
    [anon_sym_permissionset] = ACTIONS(5011),
    [anon_sym_PERMISSIONSET] = ACTIONS(5011),
    [anon_sym_Permissionset] = ACTIONS(5011),
    [anon_sym_PermissionSet] = ACTIONS(5011),
    [anon_sym_permissionSet] = ACTIONS(5011),
    [anon_sym_permissionsetextension] = ACTIONS(5009),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5009),
    [anon_sym_Permissionsetextension] = ACTIONS(5009),
    [anon_sym_PermissionSetExtension] = ACTIONS(5009),
    [anon_sym_permissionSetExtension] = ACTIONS(5009),
    [sym_entitlement_keyword] = ACTIONS(5009),
    [anon_sym_pagecustomization] = ACTIONS(5009),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5009),
    [anon_sym_Pagecustomization] = ACTIONS(5009),
    [anon_sym_PageCustomization] = ACTIONS(5009),
    [anon_sym_pageCustomization] = ACTIONS(5009),
    [sym_using_keyword] = ACTIONS(5009),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5009),
  },
  [STATE(2463)] = {
    [ts_builtin_sym_end] = ACTIONS(5160),
    [anon_sym_POUNDif] = ACTIONS(5160),
    [anon_sym_POUNDIF] = ACTIONS(5160),
    [anon_sym_POUNDIf] = ACTIONS(5160),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5162),
    [anon_sym_tableextension] = ACTIONS(5160),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5160),
    [anon_sym_Tableextension] = ACTIONS(5160),
    [anon_sym_TableExtension] = ACTIONS(5160),
    [anon_sym_tableExtension] = ACTIONS(5160),
    [sym_page_keyword] = ACTIONS(5162),
    [anon_sym_pageextension] = ACTIONS(5160),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5160),
    [anon_sym_Pageextension] = ACTIONS(5160),
    [anon_sym_PageExtension] = ACTIONS(5160),
    [anon_sym_pageExtension] = ACTIONS(5160),
    [anon_sym_codeunit] = ACTIONS(5160),
    [anon_sym_CODEUNIT] = ACTIONS(5160),
    [anon_sym_Codeunit] = ACTIONS(5160),
    [anon_sym_CodeUnit] = ACTIONS(5160),
    [anon_sym_COdeunit] = ACTIONS(5160),
    [anon_sym_codeUnit] = ACTIONS(5160),
    [sym_report_keyword] = ACTIONS(5162),
    [anon_sym_reportextension] = ACTIONS(5160),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5160),
    [anon_sym_Reportextension] = ACTIONS(5160),
    [anon_sym_ReportExtension] = ACTIONS(5160),
    [anon_sym_reportExtension] = ACTIONS(5160),
    [sym_query_keyword] = ACTIONS(5160),
    [anon_sym_xmlport] = ACTIONS(5160),
    [anon_sym_XMLPORT] = ACTIONS(5160),
    [anon_sym_Xmlport] = ACTIONS(5160),
    [anon_sym_XMLport] = ACTIONS(5160),
    [anon_sym_XMLPort] = ACTIONS(5160),
    [anon_sym_XmlPort] = ACTIONS(5160),
    [anon_sym_enum] = ACTIONS(5162),
    [anon_sym_ENUM] = ACTIONS(5162),
    [anon_sym_Enum] = ACTIONS(5162),
    [anon_sym_eNUM] = ACTIONS(5160),
    [anon_sym_eNum] = ACTIONS(5160),
    [anon_sym_ENum] = ACTIONS(5160),
    [anon_sym_enumextension] = ACTIONS(5160),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5160),
    [anon_sym_Enumextension] = ACTIONS(5160),
    [anon_sym_EnumExtension] = ACTIONS(5160),
    [anon_sym_enumExtension] = ACTIONS(5160),
    [sym_interface_keyword] = ACTIONS(5160),
    [anon_sym_controladdin] = ACTIONS(5160),
    [anon_sym_CONTROLADDIN] = ACTIONS(5160),
    [anon_sym_Controladdin] = ACTIONS(5160),
    [anon_sym_ControlAddIn] = ACTIONS(5160),
    [anon_sym_ControlAddin] = ACTIONS(5160),
    [anon_sym_controlAddIn] = ACTIONS(5160),
    [anon_sym_controlAddin] = ACTIONS(5160),
    [anon_sym_dotnet] = ACTIONS(5160),
    [anon_sym_DOTNET] = ACTIONS(5160),
    [anon_sym_Dotnet] = ACTIONS(5160),
    [anon_sym_DotNet] = ACTIONS(5160),
    [anon_sym_dotNet] = ACTIONS(5160),
    [sym_profile_keyword] = ACTIONS(5162),
    [anon_sym_profileextension] = ACTIONS(5160),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5160),
    [anon_sym_Profileextension] = ACTIONS(5160),
    [anon_sym_ProfileExtension] = ACTIONS(5160),
    [anon_sym_profileExtension] = ACTIONS(5160),
    [anon_sym_permissionset] = ACTIONS(5162),
    [anon_sym_PERMISSIONSET] = ACTIONS(5162),
    [anon_sym_Permissionset] = ACTIONS(5162),
    [anon_sym_PermissionSet] = ACTIONS(5162),
    [anon_sym_permissionSet] = ACTIONS(5162),
    [anon_sym_permissionsetextension] = ACTIONS(5160),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5160),
    [anon_sym_Permissionsetextension] = ACTIONS(5160),
    [anon_sym_PermissionSetExtension] = ACTIONS(5160),
    [anon_sym_permissionSetExtension] = ACTIONS(5160),
    [sym_entitlement_keyword] = ACTIONS(5160),
    [anon_sym_pagecustomization] = ACTIONS(5160),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5160),
    [anon_sym_Pagecustomization] = ACTIONS(5160),
    [anon_sym_PageCustomization] = ACTIONS(5160),
    [anon_sym_pageCustomization] = ACTIONS(5160),
    [sym_using_keyword] = ACTIONS(5160),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5160),
  },
  [STATE(2464)] = {
    [ts_builtin_sym_end] = ACTIONS(5105),
    [anon_sym_POUNDif] = ACTIONS(5105),
    [anon_sym_POUNDIF] = ACTIONS(5105),
    [anon_sym_POUNDIf] = ACTIONS(5105),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5107),
    [anon_sym_tableextension] = ACTIONS(5105),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5105),
    [anon_sym_Tableextension] = ACTIONS(5105),
    [anon_sym_TableExtension] = ACTIONS(5105),
    [anon_sym_tableExtension] = ACTIONS(5105),
    [sym_page_keyword] = ACTIONS(5107),
    [anon_sym_pageextension] = ACTIONS(5105),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5105),
    [anon_sym_Pageextension] = ACTIONS(5105),
    [anon_sym_PageExtension] = ACTIONS(5105),
    [anon_sym_pageExtension] = ACTIONS(5105),
    [anon_sym_codeunit] = ACTIONS(5105),
    [anon_sym_CODEUNIT] = ACTIONS(5105),
    [anon_sym_Codeunit] = ACTIONS(5105),
    [anon_sym_CodeUnit] = ACTIONS(5105),
    [anon_sym_COdeunit] = ACTIONS(5105),
    [anon_sym_codeUnit] = ACTIONS(5105),
    [sym_report_keyword] = ACTIONS(5107),
    [anon_sym_reportextension] = ACTIONS(5105),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5105),
    [anon_sym_Reportextension] = ACTIONS(5105),
    [anon_sym_ReportExtension] = ACTIONS(5105),
    [anon_sym_reportExtension] = ACTIONS(5105),
    [sym_query_keyword] = ACTIONS(5105),
    [anon_sym_xmlport] = ACTIONS(5105),
    [anon_sym_XMLPORT] = ACTIONS(5105),
    [anon_sym_Xmlport] = ACTIONS(5105),
    [anon_sym_XMLport] = ACTIONS(5105),
    [anon_sym_XMLPort] = ACTIONS(5105),
    [anon_sym_XmlPort] = ACTIONS(5105),
    [anon_sym_enum] = ACTIONS(5107),
    [anon_sym_ENUM] = ACTIONS(5107),
    [anon_sym_Enum] = ACTIONS(5107),
    [anon_sym_eNUM] = ACTIONS(5105),
    [anon_sym_eNum] = ACTIONS(5105),
    [anon_sym_ENum] = ACTIONS(5105),
    [anon_sym_enumextension] = ACTIONS(5105),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5105),
    [anon_sym_Enumextension] = ACTIONS(5105),
    [anon_sym_EnumExtension] = ACTIONS(5105),
    [anon_sym_enumExtension] = ACTIONS(5105),
    [sym_interface_keyword] = ACTIONS(5105),
    [anon_sym_controladdin] = ACTIONS(5105),
    [anon_sym_CONTROLADDIN] = ACTIONS(5105),
    [anon_sym_Controladdin] = ACTIONS(5105),
    [anon_sym_ControlAddIn] = ACTIONS(5105),
    [anon_sym_ControlAddin] = ACTIONS(5105),
    [anon_sym_controlAddIn] = ACTIONS(5105),
    [anon_sym_controlAddin] = ACTIONS(5105),
    [anon_sym_dotnet] = ACTIONS(5105),
    [anon_sym_DOTNET] = ACTIONS(5105),
    [anon_sym_Dotnet] = ACTIONS(5105),
    [anon_sym_DotNet] = ACTIONS(5105),
    [anon_sym_dotNet] = ACTIONS(5105),
    [sym_profile_keyword] = ACTIONS(5107),
    [anon_sym_profileextension] = ACTIONS(5105),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5105),
    [anon_sym_Profileextension] = ACTIONS(5105),
    [anon_sym_ProfileExtension] = ACTIONS(5105),
    [anon_sym_profileExtension] = ACTIONS(5105),
    [anon_sym_permissionset] = ACTIONS(5107),
    [anon_sym_PERMISSIONSET] = ACTIONS(5107),
    [anon_sym_Permissionset] = ACTIONS(5107),
    [anon_sym_PermissionSet] = ACTIONS(5107),
    [anon_sym_permissionSet] = ACTIONS(5107),
    [anon_sym_permissionsetextension] = ACTIONS(5105),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5105),
    [anon_sym_Permissionsetextension] = ACTIONS(5105),
    [anon_sym_PermissionSetExtension] = ACTIONS(5105),
    [anon_sym_permissionSetExtension] = ACTIONS(5105),
    [sym_entitlement_keyword] = ACTIONS(5105),
    [anon_sym_pagecustomization] = ACTIONS(5105),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5105),
    [anon_sym_Pagecustomization] = ACTIONS(5105),
    [anon_sym_PageCustomization] = ACTIONS(5105),
    [anon_sym_pageCustomization] = ACTIONS(5105),
    [sym_using_keyword] = ACTIONS(5105),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5105),
  },
  [STATE(2465)] = {
    [ts_builtin_sym_end] = ACTIONS(5355),
    [anon_sym_POUNDif] = ACTIONS(5355),
    [anon_sym_POUNDIF] = ACTIONS(5355),
    [anon_sym_POUNDIf] = ACTIONS(5355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5357),
    [anon_sym_tableextension] = ACTIONS(5355),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5355),
    [anon_sym_Tableextension] = ACTIONS(5355),
    [anon_sym_TableExtension] = ACTIONS(5355),
    [anon_sym_tableExtension] = ACTIONS(5355),
    [sym_page_keyword] = ACTIONS(5357),
    [anon_sym_pageextension] = ACTIONS(5355),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5355),
    [anon_sym_Pageextension] = ACTIONS(5355),
    [anon_sym_PageExtension] = ACTIONS(5355),
    [anon_sym_pageExtension] = ACTIONS(5355),
    [anon_sym_codeunit] = ACTIONS(5355),
    [anon_sym_CODEUNIT] = ACTIONS(5355),
    [anon_sym_Codeunit] = ACTIONS(5355),
    [anon_sym_CodeUnit] = ACTIONS(5355),
    [anon_sym_COdeunit] = ACTIONS(5355),
    [anon_sym_codeUnit] = ACTIONS(5355),
    [sym_report_keyword] = ACTIONS(5357),
    [anon_sym_reportextension] = ACTIONS(5355),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5355),
    [anon_sym_Reportextension] = ACTIONS(5355),
    [anon_sym_ReportExtension] = ACTIONS(5355),
    [anon_sym_reportExtension] = ACTIONS(5355),
    [sym_query_keyword] = ACTIONS(5355),
    [anon_sym_xmlport] = ACTIONS(5355),
    [anon_sym_XMLPORT] = ACTIONS(5355),
    [anon_sym_Xmlport] = ACTIONS(5355),
    [anon_sym_XMLport] = ACTIONS(5355),
    [anon_sym_XMLPort] = ACTIONS(5355),
    [anon_sym_XmlPort] = ACTIONS(5355),
    [anon_sym_enum] = ACTIONS(5357),
    [anon_sym_ENUM] = ACTIONS(5357),
    [anon_sym_Enum] = ACTIONS(5357),
    [anon_sym_eNUM] = ACTIONS(5355),
    [anon_sym_eNum] = ACTIONS(5355),
    [anon_sym_ENum] = ACTIONS(5355),
    [anon_sym_enumextension] = ACTIONS(5355),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5355),
    [anon_sym_Enumextension] = ACTIONS(5355),
    [anon_sym_EnumExtension] = ACTIONS(5355),
    [anon_sym_enumExtension] = ACTIONS(5355),
    [sym_interface_keyword] = ACTIONS(5355),
    [anon_sym_controladdin] = ACTIONS(5355),
    [anon_sym_CONTROLADDIN] = ACTIONS(5355),
    [anon_sym_Controladdin] = ACTIONS(5355),
    [anon_sym_ControlAddIn] = ACTIONS(5355),
    [anon_sym_ControlAddin] = ACTIONS(5355),
    [anon_sym_controlAddIn] = ACTIONS(5355),
    [anon_sym_controlAddin] = ACTIONS(5355),
    [anon_sym_dotnet] = ACTIONS(5355),
    [anon_sym_DOTNET] = ACTIONS(5355),
    [anon_sym_Dotnet] = ACTIONS(5355),
    [anon_sym_DotNet] = ACTIONS(5355),
    [anon_sym_dotNet] = ACTIONS(5355),
    [sym_profile_keyword] = ACTIONS(5357),
    [anon_sym_profileextension] = ACTIONS(5355),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5355),
    [anon_sym_Profileextension] = ACTIONS(5355),
    [anon_sym_ProfileExtension] = ACTIONS(5355),
    [anon_sym_profileExtension] = ACTIONS(5355),
    [anon_sym_permissionset] = ACTIONS(5357),
    [anon_sym_PERMISSIONSET] = ACTIONS(5357),
    [anon_sym_Permissionset] = ACTIONS(5357),
    [anon_sym_PermissionSet] = ACTIONS(5357),
    [anon_sym_permissionSet] = ACTIONS(5357),
    [anon_sym_permissionsetextension] = ACTIONS(5355),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5355),
    [anon_sym_Permissionsetextension] = ACTIONS(5355),
    [anon_sym_PermissionSetExtension] = ACTIONS(5355),
    [anon_sym_permissionSetExtension] = ACTIONS(5355),
    [sym_entitlement_keyword] = ACTIONS(5355),
    [anon_sym_pagecustomization] = ACTIONS(5355),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5355),
    [anon_sym_Pagecustomization] = ACTIONS(5355),
    [anon_sym_PageCustomization] = ACTIONS(5355),
    [anon_sym_pageCustomization] = ACTIONS(5355),
    [sym_using_keyword] = ACTIONS(5355),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5355),
  },
  [STATE(2466)] = {
    [ts_builtin_sym_end] = ACTIONS(5359),
    [anon_sym_POUNDif] = ACTIONS(5359),
    [anon_sym_POUNDIF] = ACTIONS(5359),
    [anon_sym_POUNDIf] = ACTIONS(5359),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5361),
    [anon_sym_tableextension] = ACTIONS(5359),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5359),
    [anon_sym_Tableextension] = ACTIONS(5359),
    [anon_sym_TableExtension] = ACTIONS(5359),
    [anon_sym_tableExtension] = ACTIONS(5359),
    [sym_page_keyword] = ACTIONS(5361),
    [anon_sym_pageextension] = ACTIONS(5359),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5359),
    [anon_sym_Pageextension] = ACTIONS(5359),
    [anon_sym_PageExtension] = ACTIONS(5359),
    [anon_sym_pageExtension] = ACTIONS(5359),
    [anon_sym_codeunit] = ACTIONS(5359),
    [anon_sym_CODEUNIT] = ACTIONS(5359),
    [anon_sym_Codeunit] = ACTIONS(5359),
    [anon_sym_CodeUnit] = ACTIONS(5359),
    [anon_sym_COdeunit] = ACTIONS(5359),
    [anon_sym_codeUnit] = ACTIONS(5359),
    [sym_report_keyword] = ACTIONS(5361),
    [anon_sym_reportextension] = ACTIONS(5359),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5359),
    [anon_sym_Reportextension] = ACTIONS(5359),
    [anon_sym_ReportExtension] = ACTIONS(5359),
    [anon_sym_reportExtension] = ACTIONS(5359),
    [sym_query_keyword] = ACTIONS(5359),
    [anon_sym_xmlport] = ACTIONS(5359),
    [anon_sym_XMLPORT] = ACTIONS(5359),
    [anon_sym_Xmlport] = ACTIONS(5359),
    [anon_sym_XMLport] = ACTIONS(5359),
    [anon_sym_XMLPort] = ACTIONS(5359),
    [anon_sym_XmlPort] = ACTIONS(5359),
    [anon_sym_enum] = ACTIONS(5361),
    [anon_sym_ENUM] = ACTIONS(5361),
    [anon_sym_Enum] = ACTIONS(5361),
    [anon_sym_eNUM] = ACTIONS(5359),
    [anon_sym_eNum] = ACTIONS(5359),
    [anon_sym_ENum] = ACTIONS(5359),
    [anon_sym_enumextension] = ACTIONS(5359),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5359),
    [anon_sym_Enumextension] = ACTIONS(5359),
    [anon_sym_EnumExtension] = ACTIONS(5359),
    [anon_sym_enumExtension] = ACTIONS(5359),
    [sym_interface_keyword] = ACTIONS(5359),
    [anon_sym_controladdin] = ACTIONS(5359),
    [anon_sym_CONTROLADDIN] = ACTIONS(5359),
    [anon_sym_Controladdin] = ACTIONS(5359),
    [anon_sym_ControlAddIn] = ACTIONS(5359),
    [anon_sym_ControlAddin] = ACTIONS(5359),
    [anon_sym_controlAddIn] = ACTIONS(5359),
    [anon_sym_controlAddin] = ACTIONS(5359),
    [anon_sym_dotnet] = ACTIONS(5359),
    [anon_sym_DOTNET] = ACTIONS(5359),
    [anon_sym_Dotnet] = ACTIONS(5359),
    [anon_sym_DotNet] = ACTIONS(5359),
    [anon_sym_dotNet] = ACTIONS(5359),
    [sym_profile_keyword] = ACTIONS(5361),
    [anon_sym_profileextension] = ACTIONS(5359),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5359),
    [anon_sym_Profileextension] = ACTIONS(5359),
    [anon_sym_ProfileExtension] = ACTIONS(5359),
    [anon_sym_profileExtension] = ACTIONS(5359),
    [anon_sym_permissionset] = ACTIONS(5361),
    [anon_sym_PERMISSIONSET] = ACTIONS(5361),
    [anon_sym_Permissionset] = ACTIONS(5361),
    [anon_sym_PermissionSet] = ACTIONS(5361),
    [anon_sym_permissionSet] = ACTIONS(5361),
    [anon_sym_permissionsetextension] = ACTIONS(5359),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5359),
    [anon_sym_Permissionsetextension] = ACTIONS(5359),
    [anon_sym_PermissionSetExtension] = ACTIONS(5359),
    [anon_sym_permissionSetExtension] = ACTIONS(5359),
    [sym_entitlement_keyword] = ACTIONS(5359),
    [anon_sym_pagecustomization] = ACTIONS(5359),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5359),
    [anon_sym_Pagecustomization] = ACTIONS(5359),
    [anon_sym_PageCustomization] = ACTIONS(5359),
    [anon_sym_pageCustomization] = ACTIONS(5359),
    [sym_using_keyword] = ACTIONS(5359),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5359),
  },
  [STATE(2467)] = {
    [ts_builtin_sym_end] = ACTIONS(5363),
    [anon_sym_POUNDif] = ACTIONS(5363),
    [anon_sym_POUNDIF] = ACTIONS(5363),
    [anon_sym_POUNDIf] = ACTIONS(5363),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5365),
    [anon_sym_tableextension] = ACTIONS(5363),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5363),
    [anon_sym_Tableextension] = ACTIONS(5363),
    [anon_sym_TableExtension] = ACTIONS(5363),
    [anon_sym_tableExtension] = ACTIONS(5363),
    [sym_page_keyword] = ACTIONS(5365),
    [anon_sym_pageextension] = ACTIONS(5363),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5363),
    [anon_sym_Pageextension] = ACTIONS(5363),
    [anon_sym_PageExtension] = ACTIONS(5363),
    [anon_sym_pageExtension] = ACTIONS(5363),
    [anon_sym_codeunit] = ACTIONS(5363),
    [anon_sym_CODEUNIT] = ACTIONS(5363),
    [anon_sym_Codeunit] = ACTIONS(5363),
    [anon_sym_CodeUnit] = ACTIONS(5363),
    [anon_sym_COdeunit] = ACTIONS(5363),
    [anon_sym_codeUnit] = ACTIONS(5363),
    [sym_report_keyword] = ACTIONS(5365),
    [anon_sym_reportextension] = ACTIONS(5363),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5363),
    [anon_sym_Reportextension] = ACTIONS(5363),
    [anon_sym_ReportExtension] = ACTIONS(5363),
    [anon_sym_reportExtension] = ACTIONS(5363),
    [sym_query_keyword] = ACTIONS(5363),
    [anon_sym_xmlport] = ACTIONS(5363),
    [anon_sym_XMLPORT] = ACTIONS(5363),
    [anon_sym_Xmlport] = ACTIONS(5363),
    [anon_sym_XMLport] = ACTIONS(5363),
    [anon_sym_XMLPort] = ACTIONS(5363),
    [anon_sym_XmlPort] = ACTIONS(5363),
    [anon_sym_enum] = ACTIONS(5365),
    [anon_sym_ENUM] = ACTIONS(5365),
    [anon_sym_Enum] = ACTIONS(5365),
    [anon_sym_eNUM] = ACTIONS(5363),
    [anon_sym_eNum] = ACTIONS(5363),
    [anon_sym_ENum] = ACTIONS(5363),
    [anon_sym_enumextension] = ACTIONS(5363),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5363),
    [anon_sym_Enumextension] = ACTIONS(5363),
    [anon_sym_EnumExtension] = ACTIONS(5363),
    [anon_sym_enumExtension] = ACTIONS(5363),
    [sym_interface_keyword] = ACTIONS(5363),
    [anon_sym_controladdin] = ACTIONS(5363),
    [anon_sym_CONTROLADDIN] = ACTIONS(5363),
    [anon_sym_Controladdin] = ACTIONS(5363),
    [anon_sym_ControlAddIn] = ACTIONS(5363),
    [anon_sym_ControlAddin] = ACTIONS(5363),
    [anon_sym_controlAddIn] = ACTIONS(5363),
    [anon_sym_controlAddin] = ACTIONS(5363),
    [anon_sym_dotnet] = ACTIONS(5363),
    [anon_sym_DOTNET] = ACTIONS(5363),
    [anon_sym_Dotnet] = ACTIONS(5363),
    [anon_sym_DotNet] = ACTIONS(5363),
    [anon_sym_dotNet] = ACTIONS(5363),
    [sym_profile_keyword] = ACTIONS(5365),
    [anon_sym_profileextension] = ACTIONS(5363),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5363),
    [anon_sym_Profileextension] = ACTIONS(5363),
    [anon_sym_ProfileExtension] = ACTIONS(5363),
    [anon_sym_profileExtension] = ACTIONS(5363),
    [anon_sym_permissionset] = ACTIONS(5365),
    [anon_sym_PERMISSIONSET] = ACTIONS(5365),
    [anon_sym_Permissionset] = ACTIONS(5365),
    [anon_sym_PermissionSet] = ACTIONS(5365),
    [anon_sym_permissionSet] = ACTIONS(5365),
    [anon_sym_permissionsetextension] = ACTIONS(5363),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5363),
    [anon_sym_Permissionsetextension] = ACTIONS(5363),
    [anon_sym_PermissionSetExtension] = ACTIONS(5363),
    [anon_sym_permissionSetExtension] = ACTIONS(5363),
    [sym_entitlement_keyword] = ACTIONS(5363),
    [anon_sym_pagecustomization] = ACTIONS(5363),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5363),
    [anon_sym_Pagecustomization] = ACTIONS(5363),
    [anon_sym_PageCustomization] = ACTIONS(5363),
    [anon_sym_pageCustomization] = ACTIONS(5363),
    [sym_using_keyword] = ACTIONS(5363),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5363),
  },
  [STATE(2468)] = {
    [ts_builtin_sym_end] = ACTIONS(5367),
    [anon_sym_POUNDif] = ACTIONS(5367),
    [anon_sym_POUNDIF] = ACTIONS(5367),
    [anon_sym_POUNDIf] = ACTIONS(5367),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5369),
    [anon_sym_tableextension] = ACTIONS(5367),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5367),
    [anon_sym_Tableextension] = ACTIONS(5367),
    [anon_sym_TableExtension] = ACTIONS(5367),
    [anon_sym_tableExtension] = ACTIONS(5367),
    [sym_page_keyword] = ACTIONS(5369),
    [anon_sym_pageextension] = ACTIONS(5367),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5367),
    [anon_sym_Pageextension] = ACTIONS(5367),
    [anon_sym_PageExtension] = ACTIONS(5367),
    [anon_sym_pageExtension] = ACTIONS(5367),
    [anon_sym_codeunit] = ACTIONS(5367),
    [anon_sym_CODEUNIT] = ACTIONS(5367),
    [anon_sym_Codeunit] = ACTIONS(5367),
    [anon_sym_CodeUnit] = ACTIONS(5367),
    [anon_sym_COdeunit] = ACTIONS(5367),
    [anon_sym_codeUnit] = ACTIONS(5367),
    [sym_report_keyword] = ACTIONS(5369),
    [anon_sym_reportextension] = ACTIONS(5367),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5367),
    [anon_sym_Reportextension] = ACTIONS(5367),
    [anon_sym_ReportExtension] = ACTIONS(5367),
    [anon_sym_reportExtension] = ACTIONS(5367),
    [sym_query_keyword] = ACTIONS(5367),
    [anon_sym_xmlport] = ACTIONS(5367),
    [anon_sym_XMLPORT] = ACTIONS(5367),
    [anon_sym_Xmlport] = ACTIONS(5367),
    [anon_sym_XMLport] = ACTIONS(5367),
    [anon_sym_XMLPort] = ACTIONS(5367),
    [anon_sym_XmlPort] = ACTIONS(5367),
    [anon_sym_enum] = ACTIONS(5369),
    [anon_sym_ENUM] = ACTIONS(5369),
    [anon_sym_Enum] = ACTIONS(5369),
    [anon_sym_eNUM] = ACTIONS(5367),
    [anon_sym_eNum] = ACTIONS(5367),
    [anon_sym_ENum] = ACTIONS(5367),
    [anon_sym_enumextension] = ACTIONS(5367),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5367),
    [anon_sym_Enumextension] = ACTIONS(5367),
    [anon_sym_EnumExtension] = ACTIONS(5367),
    [anon_sym_enumExtension] = ACTIONS(5367),
    [sym_interface_keyword] = ACTIONS(5367),
    [anon_sym_controladdin] = ACTIONS(5367),
    [anon_sym_CONTROLADDIN] = ACTIONS(5367),
    [anon_sym_Controladdin] = ACTIONS(5367),
    [anon_sym_ControlAddIn] = ACTIONS(5367),
    [anon_sym_ControlAddin] = ACTIONS(5367),
    [anon_sym_controlAddIn] = ACTIONS(5367),
    [anon_sym_controlAddin] = ACTIONS(5367),
    [anon_sym_dotnet] = ACTIONS(5367),
    [anon_sym_DOTNET] = ACTIONS(5367),
    [anon_sym_Dotnet] = ACTIONS(5367),
    [anon_sym_DotNet] = ACTIONS(5367),
    [anon_sym_dotNet] = ACTIONS(5367),
    [sym_profile_keyword] = ACTIONS(5369),
    [anon_sym_profileextension] = ACTIONS(5367),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5367),
    [anon_sym_Profileextension] = ACTIONS(5367),
    [anon_sym_ProfileExtension] = ACTIONS(5367),
    [anon_sym_profileExtension] = ACTIONS(5367),
    [anon_sym_permissionset] = ACTIONS(5369),
    [anon_sym_PERMISSIONSET] = ACTIONS(5369),
    [anon_sym_Permissionset] = ACTIONS(5369),
    [anon_sym_PermissionSet] = ACTIONS(5369),
    [anon_sym_permissionSet] = ACTIONS(5369),
    [anon_sym_permissionsetextension] = ACTIONS(5367),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5367),
    [anon_sym_Permissionsetextension] = ACTIONS(5367),
    [anon_sym_PermissionSetExtension] = ACTIONS(5367),
    [anon_sym_permissionSetExtension] = ACTIONS(5367),
    [sym_entitlement_keyword] = ACTIONS(5367),
    [anon_sym_pagecustomization] = ACTIONS(5367),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5367),
    [anon_sym_Pagecustomization] = ACTIONS(5367),
    [anon_sym_PageCustomization] = ACTIONS(5367),
    [anon_sym_pageCustomization] = ACTIONS(5367),
    [sym_using_keyword] = ACTIONS(5367),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5367),
  },
  [STATE(2469)] = {
    [ts_builtin_sym_end] = ACTIONS(5109),
    [anon_sym_POUNDif] = ACTIONS(5109),
    [anon_sym_POUNDIF] = ACTIONS(5109),
    [anon_sym_POUNDIf] = ACTIONS(5109),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5111),
    [anon_sym_tableextension] = ACTIONS(5109),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5109),
    [anon_sym_Tableextension] = ACTIONS(5109),
    [anon_sym_TableExtension] = ACTIONS(5109),
    [anon_sym_tableExtension] = ACTIONS(5109),
    [sym_page_keyword] = ACTIONS(5111),
    [anon_sym_pageextension] = ACTIONS(5109),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5109),
    [anon_sym_Pageextension] = ACTIONS(5109),
    [anon_sym_PageExtension] = ACTIONS(5109),
    [anon_sym_pageExtension] = ACTIONS(5109),
    [anon_sym_codeunit] = ACTIONS(5109),
    [anon_sym_CODEUNIT] = ACTIONS(5109),
    [anon_sym_Codeunit] = ACTIONS(5109),
    [anon_sym_CodeUnit] = ACTIONS(5109),
    [anon_sym_COdeunit] = ACTIONS(5109),
    [anon_sym_codeUnit] = ACTIONS(5109),
    [sym_report_keyword] = ACTIONS(5111),
    [anon_sym_reportextension] = ACTIONS(5109),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5109),
    [anon_sym_Reportextension] = ACTIONS(5109),
    [anon_sym_ReportExtension] = ACTIONS(5109),
    [anon_sym_reportExtension] = ACTIONS(5109),
    [sym_query_keyword] = ACTIONS(5109),
    [anon_sym_xmlport] = ACTIONS(5109),
    [anon_sym_XMLPORT] = ACTIONS(5109),
    [anon_sym_Xmlport] = ACTIONS(5109),
    [anon_sym_XMLport] = ACTIONS(5109),
    [anon_sym_XMLPort] = ACTIONS(5109),
    [anon_sym_XmlPort] = ACTIONS(5109),
    [anon_sym_enum] = ACTIONS(5111),
    [anon_sym_ENUM] = ACTIONS(5111),
    [anon_sym_Enum] = ACTIONS(5111),
    [anon_sym_eNUM] = ACTIONS(5109),
    [anon_sym_eNum] = ACTIONS(5109),
    [anon_sym_ENum] = ACTIONS(5109),
    [anon_sym_enumextension] = ACTIONS(5109),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5109),
    [anon_sym_Enumextension] = ACTIONS(5109),
    [anon_sym_EnumExtension] = ACTIONS(5109),
    [anon_sym_enumExtension] = ACTIONS(5109),
    [sym_interface_keyword] = ACTIONS(5109),
    [anon_sym_controladdin] = ACTIONS(5109),
    [anon_sym_CONTROLADDIN] = ACTIONS(5109),
    [anon_sym_Controladdin] = ACTIONS(5109),
    [anon_sym_ControlAddIn] = ACTIONS(5109),
    [anon_sym_ControlAddin] = ACTIONS(5109),
    [anon_sym_controlAddIn] = ACTIONS(5109),
    [anon_sym_controlAddin] = ACTIONS(5109),
    [anon_sym_dotnet] = ACTIONS(5109),
    [anon_sym_DOTNET] = ACTIONS(5109),
    [anon_sym_Dotnet] = ACTIONS(5109),
    [anon_sym_DotNet] = ACTIONS(5109),
    [anon_sym_dotNet] = ACTIONS(5109),
    [sym_profile_keyword] = ACTIONS(5111),
    [anon_sym_profileextension] = ACTIONS(5109),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5109),
    [anon_sym_Profileextension] = ACTIONS(5109),
    [anon_sym_ProfileExtension] = ACTIONS(5109),
    [anon_sym_profileExtension] = ACTIONS(5109),
    [anon_sym_permissionset] = ACTIONS(5111),
    [anon_sym_PERMISSIONSET] = ACTIONS(5111),
    [anon_sym_Permissionset] = ACTIONS(5111),
    [anon_sym_PermissionSet] = ACTIONS(5111),
    [anon_sym_permissionSet] = ACTIONS(5111),
    [anon_sym_permissionsetextension] = ACTIONS(5109),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5109),
    [anon_sym_Permissionsetextension] = ACTIONS(5109),
    [anon_sym_PermissionSetExtension] = ACTIONS(5109),
    [anon_sym_permissionSetExtension] = ACTIONS(5109),
    [sym_entitlement_keyword] = ACTIONS(5109),
    [anon_sym_pagecustomization] = ACTIONS(5109),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5109),
    [anon_sym_Pagecustomization] = ACTIONS(5109),
    [anon_sym_PageCustomization] = ACTIONS(5109),
    [anon_sym_pageCustomization] = ACTIONS(5109),
    [sym_using_keyword] = ACTIONS(5109),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5109),
  },
  [STATE(2470)] = {
    [ts_builtin_sym_end] = ACTIONS(5113),
    [anon_sym_POUNDif] = ACTIONS(5113),
    [anon_sym_POUNDIF] = ACTIONS(5113),
    [anon_sym_POUNDIf] = ACTIONS(5113),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5115),
    [anon_sym_tableextension] = ACTIONS(5113),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5113),
    [anon_sym_Tableextension] = ACTIONS(5113),
    [anon_sym_TableExtension] = ACTIONS(5113),
    [anon_sym_tableExtension] = ACTIONS(5113),
    [sym_page_keyword] = ACTIONS(5115),
    [anon_sym_pageextension] = ACTIONS(5113),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5113),
    [anon_sym_Pageextension] = ACTIONS(5113),
    [anon_sym_PageExtension] = ACTIONS(5113),
    [anon_sym_pageExtension] = ACTIONS(5113),
    [anon_sym_codeunit] = ACTIONS(5113),
    [anon_sym_CODEUNIT] = ACTIONS(5113),
    [anon_sym_Codeunit] = ACTIONS(5113),
    [anon_sym_CodeUnit] = ACTIONS(5113),
    [anon_sym_COdeunit] = ACTIONS(5113),
    [anon_sym_codeUnit] = ACTIONS(5113),
    [sym_report_keyword] = ACTIONS(5115),
    [anon_sym_reportextension] = ACTIONS(5113),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5113),
    [anon_sym_Reportextension] = ACTIONS(5113),
    [anon_sym_ReportExtension] = ACTIONS(5113),
    [anon_sym_reportExtension] = ACTIONS(5113),
    [sym_query_keyword] = ACTIONS(5113),
    [anon_sym_xmlport] = ACTIONS(5113),
    [anon_sym_XMLPORT] = ACTIONS(5113),
    [anon_sym_Xmlport] = ACTIONS(5113),
    [anon_sym_XMLport] = ACTIONS(5113),
    [anon_sym_XMLPort] = ACTIONS(5113),
    [anon_sym_XmlPort] = ACTIONS(5113),
    [anon_sym_enum] = ACTIONS(5115),
    [anon_sym_ENUM] = ACTIONS(5115),
    [anon_sym_Enum] = ACTIONS(5115),
    [anon_sym_eNUM] = ACTIONS(5113),
    [anon_sym_eNum] = ACTIONS(5113),
    [anon_sym_ENum] = ACTIONS(5113),
    [anon_sym_enumextension] = ACTIONS(5113),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5113),
    [anon_sym_Enumextension] = ACTIONS(5113),
    [anon_sym_EnumExtension] = ACTIONS(5113),
    [anon_sym_enumExtension] = ACTIONS(5113),
    [sym_interface_keyword] = ACTIONS(5113),
    [anon_sym_controladdin] = ACTIONS(5113),
    [anon_sym_CONTROLADDIN] = ACTIONS(5113),
    [anon_sym_Controladdin] = ACTIONS(5113),
    [anon_sym_ControlAddIn] = ACTIONS(5113),
    [anon_sym_ControlAddin] = ACTIONS(5113),
    [anon_sym_controlAddIn] = ACTIONS(5113),
    [anon_sym_controlAddin] = ACTIONS(5113),
    [anon_sym_dotnet] = ACTIONS(5113),
    [anon_sym_DOTNET] = ACTIONS(5113),
    [anon_sym_Dotnet] = ACTIONS(5113),
    [anon_sym_DotNet] = ACTIONS(5113),
    [anon_sym_dotNet] = ACTIONS(5113),
    [sym_profile_keyword] = ACTIONS(5115),
    [anon_sym_profileextension] = ACTIONS(5113),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5113),
    [anon_sym_Profileextension] = ACTIONS(5113),
    [anon_sym_ProfileExtension] = ACTIONS(5113),
    [anon_sym_profileExtension] = ACTIONS(5113),
    [anon_sym_permissionset] = ACTIONS(5115),
    [anon_sym_PERMISSIONSET] = ACTIONS(5115),
    [anon_sym_Permissionset] = ACTIONS(5115),
    [anon_sym_PermissionSet] = ACTIONS(5115),
    [anon_sym_permissionSet] = ACTIONS(5115),
    [anon_sym_permissionsetextension] = ACTIONS(5113),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5113),
    [anon_sym_Permissionsetextension] = ACTIONS(5113),
    [anon_sym_PermissionSetExtension] = ACTIONS(5113),
    [anon_sym_permissionSetExtension] = ACTIONS(5113),
    [sym_entitlement_keyword] = ACTIONS(5113),
    [anon_sym_pagecustomization] = ACTIONS(5113),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5113),
    [anon_sym_Pagecustomization] = ACTIONS(5113),
    [anon_sym_PageCustomization] = ACTIONS(5113),
    [anon_sym_pageCustomization] = ACTIONS(5113),
    [sym_using_keyword] = ACTIONS(5113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5113),
  },
  [STATE(2471)] = {
    [ts_builtin_sym_end] = ACTIONS(5117),
    [anon_sym_POUNDif] = ACTIONS(5117),
    [anon_sym_POUNDIF] = ACTIONS(5117),
    [anon_sym_POUNDIf] = ACTIONS(5117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5119),
    [anon_sym_tableextension] = ACTIONS(5117),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5117),
    [anon_sym_Tableextension] = ACTIONS(5117),
    [anon_sym_TableExtension] = ACTIONS(5117),
    [anon_sym_tableExtension] = ACTIONS(5117),
    [sym_page_keyword] = ACTIONS(5119),
    [anon_sym_pageextension] = ACTIONS(5117),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5117),
    [anon_sym_Pageextension] = ACTIONS(5117),
    [anon_sym_PageExtension] = ACTIONS(5117),
    [anon_sym_pageExtension] = ACTIONS(5117),
    [anon_sym_codeunit] = ACTIONS(5117),
    [anon_sym_CODEUNIT] = ACTIONS(5117),
    [anon_sym_Codeunit] = ACTIONS(5117),
    [anon_sym_CodeUnit] = ACTIONS(5117),
    [anon_sym_COdeunit] = ACTIONS(5117),
    [anon_sym_codeUnit] = ACTIONS(5117),
    [sym_report_keyword] = ACTIONS(5119),
    [anon_sym_reportextension] = ACTIONS(5117),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5117),
    [anon_sym_Reportextension] = ACTIONS(5117),
    [anon_sym_ReportExtension] = ACTIONS(5117),
    [anon_sym_reportExtension] = ACTIONS(5117),
    [sym_query_keyword] = ACTIONS(5117),
    [anon_sym_xmlport] = ACTIONS(5117),
    [anon_sym_XMLPORT] = ACTIONS(5117),
    [anon_sym_Xmlport] = ACTIONS(5117),
    [anon_sym_XMLport] = ACTIONS(5117),
    [anon_sym_XMLPort] = ACTIONS(5117),
    [anon_sym_XmlPort] = ACTIONS(5117),
    [anon_sym_enum] = ACTIONS(5119),
    [anon_sym_ENUM] = ACTIONS(5119),
    [anon_sym_Enum] = ACTIONS(5119),
    [anon_sym_eNUM] = ACTIONS(5117),
    [anon_sym_eNum] = ACTIONS(5117),
    [anon_sym_ENum] = ACTIONS(5117),
    [anon_sym_enumextension] = ACTIONS(5117),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5117),
    [anon_sym_Enumextension] = ACTIONS(5117),
    [anon_sym_EnumExtension] = ACTIONS(5117),
    [anon_sym_enumExtension] = ACTIONS(5117),
    [sym_interface_keyword] = ACTIONS(5117),
    [anon_sym_controladdin] = ACTIONS(5117),
    [anon_sym_CONTROLADDIN] = ACTIONS(5117),
    [anon_sym_Controladdin] = ACTIONS(5117),
    [anon_sym_ControlAddIn] = ACTIONS(5117),
    [anon_sym_ControlAddin] = ACTIONS(5117),
    [anon_sym_controlAddIn] = ACTIONS(5117),
    [anon_sym_controlAddin] = ACTIONS(5117),
    [anon_sym_dotnet] = ACTIONS(5117),
    [anon_sym_DOTNET] = ACTIONS(5117),
    [anon_sym_Dotnet] = ACTIONS(5117),
    [anon_sym_DotNet] = ACTIONS(5117),
    [anon_sym_dotNet] = ACTIONS(5117),
    [sym_profile_keyword] = ACTIONS(5119),
    [anon_sym_profileextension] = ACTIONS(5117),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5117),
    [anon_sym_Profileextension] = ACTIONS(5117),
    [anon_sym_ProfileExtension] = ACTIONS(5117),
    [anon_sym_profileExtension] = ACTIONS(5117),
    [anon_sym_permissionset] = ACTIONS(5119),
    [anon_sym_PERMISSIONSET] = ACTIONS(5119),
    [anon_sym_Permissionset] = ACTIONS(5119),
    [anon_sym_PermissionSet] = ACTIONS(5119),
    [anon_sym_permissionSet] = ACTIONS(5119),
    [anon_sym_permissionsetextension] = ACTIONS(5117),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5117),
    [anon_sym_Permissionsetextension] = ACTIONS(5117),
    [anon_sym_PermissionSetExtension] = ACTIONS(5117),
    [anon_sym_permissionSetExtension] = ACTIONS(5117),
    [sym_entitlement_keyword] = ACTIONS(5117),
    [anon_sym_pagecustomization] = ACTIONS(5117),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5117),
    [anon_sym_Pagecustomization] = ACTIONS(5117),
    [anon_sym_PageCustomization] = ACTIONS(5117),
    [anon_sym_pageCustomization] = ACTIONS(5117),
    [sym_using_keyword] = ACTIONS(5117),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5117),
  },
  [STATE(2472)] = {
    [ts_builtin_sym_end] = ACTIONS(5121),
    [anon_sym_POUNDif] = ACTIONS(5121),
    [anon_sym_POUNDIF] = ACTIONS(5121),
    [anon_sym_POUNDIf] = ACTIONS(5121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5123),
    [anon_sym_tableextension] = ACTIONS(5121),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5121),
    [anon_sym_Tableextension] = ACTIONS(5121),
    [anon_sym_TableExtension] = ACTIONS(5121),
    [anon_sym_tableExtension] = ACTIONS(5121),
    [sym_page_keyword] = ACTIONS(5123),
    [anon_sym_pageextension] = ACTIONS(5121),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5121),
    [anon_sym_Pageextension] = ACTIONS(5121),
    [anon_sym_PageExtension] = ACTIONS(5121),
    [anon_sym_pageExtension] = ACTIONS(5121),
    [anon_sym_codeunit] = ACTIONS(5121),
    [anon_sym_CODEUNIT] = ACTIONS(5121),
    [anon_sym_Codeunit] = ACTIONS(5121),
    [anon_sym_CodeUnit] = ACTIONS(5121),
    [anon_sym_COdeunit] = ACTIONS(5121),
    [anon_sym_codeUnit] = ACTIONS(5121),
    [sym_report_keyword] = ACTIONS(5123),
    [anon_sym_reportextension] = ACTIONS(5121),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5121),
    [anon_sym_Reportextension] = ACTIONS(5121),
    [anon_sym_ReportExtension] = ACTIONS(5121),
    [anon_sym_reportExtension] = ACTIONS(5121),
    [sym_query_keyword] = ACTIONS(5121),
    [anon_sym_xmlport] = ACTIONS(5121),
    [anon_sym_XMLPORT] = ACTIONS(5121),
    [anon_sym_Xmlport] = ACTIONS(5121),
    [anon_sym_XMLport] = ACTIONS(5121),
    [anon_sym_XMLPort] = ACTIONS(5121),
    [anon_sym_XmlPort] = ACTIONS(5121),
    [anon_sym_enum] = ACTIONS(5123),
    [anon_sym_ENUM] = ACTIONS(5123),
    [anon_sym_Enum] = ACTIONS(5123),
    [anon_sym_eNUM] = ACTIONS(5121),
    [anon_sym_eNum] = ACTIONS(5121),
    [anon_sym_ENum] = ACTIONS(5121),
    [anon_sym_enumextension] = ACTIONS(5121),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5121),
    [anon_sym_Enumextension] = ACTIONS(5121),
    [anon_sym_EnumExtension] = ACTIONS(5121),
    [anon_sym_enumExtension] = ACTIONS(5121),
    [sym_interface_keyword] = ACTIONS(5121),
    [anon_sym_controladdin] = ACTIONS(5121),
    [anon_sym_CONTROLADDIN] = ACTIONS(5121),
    [anon_sym_Controladdin] = ACTIONS(5121),
    [anon_sym_ControlAddIn] = ACTIONS(5121),
    [anon_sym_ControlAddin] = ACTIONS(5121),
    [anon_sym_controlAddIn] = ACTIONS(5121),
    [anon_sym_controlAddin] = ACTIONS(5121),
    [anon_sym_dotnet] = ACTIONS(5121),
    [anon_sym_DOTNET] = ACTIONS(5121),
    [anon_sym_Dotnet] = ACTIONS(5121),
    [anon_sym_DotNet] = ACTIONS(5121),
    [anon_sym_dotNet] = ACTIONS(5121),
    [sym_profile_keyword] = ACTIONS(5123),
    [anon_sym_profileextension] = ACTIONS(5121),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5121),
    [anon_sym_Profileextension] = ACTIONS(5121),
    [anon_sym_ProfileExtension] = ACTIONS(5121),
    [anon_sym_profileExtension] = ACTIONS(5121),
    [anon_sym_permissionset] = ACTIONS(5123),
    [anon_sym_PERMISSIONSET] = ACTIONS(5123),
    [anon_sym_Permissionset] = ACTIONS(5123),
    [anon_sym_PermissionSet] = ACTIONS(5123),
    [anon_sym_permissionSet] = ACTIONS(5123),
    [anon_sym_permissionsetextension] = ACTIONS(5121),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5121),
    [anon_sym_Permissionsetextension] = ACTIONS(5121),
    [anon_sym_PermissionSetExtension] = ACTIONS(5121),
    [anon_sym_permissionSetExtension] = ACTIONS(5121),
    [sym_entitlement_keyword] = ACTIONS(5121),
    [anon_sym_pagecustomization] = ACTIONS(5121),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5121),
    [anon_sym_Pagecustomization] = ACTIONS(5121),
    [anon_sym_PageCustomization] = ACTIONS(5121),
    [anon_sym_pageCustomization] = ACTIONS(5121),
    [sym_using_keyword] = ACTIONS(5121),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5121),
  },
  [STATE(2473)] = {
    [ts_builtin_sym_end] = ACTIONS(5125),
    [anon_sym_POUNDif] = ACTIONS(5125),
    [anon_sym_POUNDIF] = ACTIONS(5125),
    [anon_sym_POUNDIf] = ACTIONS(5125),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5127),
    [anon_sym_tableextension] = ACTIONS(5125),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5125),
    [anon_sym_Tableextension] = ACTIONS(5125),
    [anon_sym_TableExtension] = ACTIONS(5125),
    [anon_sym_tableExtension] = ACTIONS(5125),
    [sym_page_keyword] = ACTIONS(5127),
    [anon_sym_pageextension] = ACTIONS(5125),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5125),
    [anon_sym_Pageextension] = ACTIONS(5125),
    [anon_sym_PageExtension] = ACTIONS(5125),
    [anon_sym_pageExtension] = ACTIONS(5125),
    [anon_sym_codeunit] = ACTIONS(5125),
    [anon_sym_CODEUNIT] = ACTIONS(5125),
    [anon_sym_Codeunit] = ACTIONS(5125),
    [anon_sym_CodeUnit] = ACTIONS(5125),
    [anon_sym_COdeunit] = ACTIONS(5125),
    [anon_sym_codeUnit] = ACTIONS(5125),
    [sym_report_keyword] = ACTIONS(5127),
    [anon_sym_reportextension] = ACTIONS(5125),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5125),
    [anon_sym_Reportextension] = ACTIONS(5125),
    [anon_sym_ReportExtension] = ACTIONS(5125),
    [anon_sym_reportExtension] = ACTIONS(5125),
    [sym_query_keyword] = ACTIONS(5125),
    [anon_sym_xmlport] = ACTIONS(5125),
    [anon_sym_XMLPORT] = ACTIONS(5125),
    [anon_sym_Xmlport] = ACTIONS(5125),
    [anon_sym_XMLport] = ACTIONS(5125),
    [anon_sym_XMLPort] = ACTIONS(5125),
    [anon_sym_XmlPort] = ACTIONS(5125),
    [anon_sym_enum] = ACTIONS(5127),
    [anon_sym_ENUM] = ACTIONS(5127),
    [anon_sym_Enum] = ACTIONS(5127),
    [anon_sym_eNUM] = ACTIONS(5125),
    [anon_sym_eNum] = ACTIONS(5125),
    [anon_sym_ENum] = ACTIONS(5125),
    [anon_sym_enumextension] = ACTIONS(5125),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5125),
    [anon_sym_Enumextension] = ACTIONS(5125),
    [anon_sym_EnumExtension] = ACTIONS(5125),
    [anon_sym_enumExtension] = ACTIONS(5125),
    [sym_interface_keyword] = ACTIONS(5125),
    [anon_sym_controladdin] = ACTIONS(5125),
    [anon_sym_CONTROLADDIN] = ACTIONS(5125),
    [anon_sym_Controladdin] = ACTIONS(5125),
    [anon_sym_ControlAddIn] = ACTIONS(5125),
    [anon_sym_ControlAddin] = ACTIONS(5125),
    [anon_sym_controlAddIn] = ACTIONS(5125),
    [anon_sym_controlAddin] = ACTIONS(5125),
    [anon_sym_dotnet] = ACTIONS(5125),
    [anon_sym_DOTNET] = ACTIONS(5125),
    [anon_sym_Dotnet] = ACTIONS(5125),
    [anon_sym_DotNet] = ACTIONS(5125),
    [anon_sym_dotNet] = ACTIONS(5125),
    [sym_profile_keyword] = ACTIONS(5127),
    [anon_sym_profileextension] = ACTIONS(5125),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5125),
    [anon_sym_Profileextension] = ACTIONS(5125),
    [anon_sym_ProfileExtension] = ACTIONS(5125),
    [anon_sym_profileExtension] = ACTIONS(5125),
    [anon_sym_permissionset] = ACTIONS(5127),
    [anon_sym_PERMISSIONSET] = ACTIONS(5127),
    [anon_sym_Permissionset] = ACTIONS(5127),
    [anon_sym_PermissionSet] = ACTIONS(5127),
    [anon_sym_permissionSet] = ACTIONS(5127),
    [anon_sym_permissionsetextension] = ACTIONS(5125),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5125),
    [anon_sym_Permissionsetextension] = ACTIONS(5125),
    [anon_sym_PermissionSetExtension] = ACTIONS(5125),
    [anon_sym_permissionSetExtension] = ACTIONS(5125),
    [sym_entitlement_keyword] = ACTIONS(5125),
    [anon_sym_pagecustomization] = ACTIONS(5125),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5125),
    [anon_sym_Pagecustomization] = ACTIONS(5125),
    [anon_sym_PageCustomization] = ACTIONS(5125),
    [anon_sym_pageCustomization] = ACTIONS(5125),
    [sym_using_keyword] = ACTIONS(5125),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5125),
  },
  [STATE(2474)] = {
    [ts_builtin_sym_end] = ACTIONS(5129),
    [anon_sym_POUNDif] = ACTIONS(5129),
    [anon_sym_POUNDIF] = ACTIONS(5129),
    [anon_sym_POUNDIf] = ACTIONS(5129),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5131),
    [anon_sym_tableextension] = ACTIONS(5129),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5129),
    [anon_sym_Tableextension] = ACTIONS(5129),
    [anon_sym_TableExtension] = ACTIONS(5129),
    [anon_sym_tableExtension] = ACTIONS(5129),
    [sym_page_keyword] = ACTIONS(5131),
    [anon_sym_pageextension] = ACTIONS(5129),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5129),
    [anon_sym_Pageextension] = ACTIONS(5129),
    [anon_sym_PageExtension] = ACTIONS(5129),
    [anon_sym_pageExtension] = ACTIONS(5129),
    [anon_sym_codeunit] = ACTIONS(5129),
    [anon_sym_CODEUNIT] = ACTIONS(5129),
    [anon_sym_Codeunit] = ACTIONS(5129),
    [anon_sym_CodeUnit] = ACTIONS(5129),
    [anon_sym_COdeunit] = ACTIONS(5129),
    [anon_sym_codeUnit] = ACTIONS(5129),
    [sym_report_keyword] = ACTIONS(5131),
    [anon_sym_reportextension] = ACTIONS(5129),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5129),
    [anon_sym_Reportextension] = ACTIONS(5129),
    [anon_sym_ReportExtension] = ACTIONS(5129),
    [anon_sym_reportExtension] = ACTIONS(5129),
    [sym_query_keyword] = ACTIONS(5129),
    [anon_sym_xmlport] = ACTIONS(5129),
    [anon_sym_XMLPORT] = ACTIONS(5129),
    [anon_sym_Xmlport] = ACTIONS(5129),
    [anon_sym_XMLport] = ACTIONS(5129),
    [anon_sym_XMLPort] = ACTIONS(5129),
    [anon_sym_XmlPort] = ACTIONS(5129),
    [anon_sym_enum] = ACTIONS(5131),
    [anon_sym_ENUM] = ACTIONS(5131),
    [anon_sym_Enum] = ACTIONS(5131),
    [anon_sym_eNUM] = ACTIONS(5129),
    [anon_sym_eNum] = ACTIONS(5129),
    [anon_sym_ENum] = ACTIONS(5129),
    [anon_sym_enumextension] = ACTIONS(5129),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5129),
    [anon_sym_Enumextension] = ACTIONS(5129),
    [anon_sym_EnumExtension] = ACTIONS(5129),
    [anon_sym_enumExtension] = ACTIONS(5129),
    [sym_interface_keyword] = ACTIONS(5129),
    [anon_sym_controladdin] = ACTIONS(5129),
    [anon_sym_CONTROLADDIN] = ACTIONS(5129),
    [anon_sym_Controladdin] = ACTIONS(5129),
    [anon_sym_ControlAddIn] = ACTIONS(5129),
    [anon_sym_ControlAddin] = ACTIONS(5129),
    [anon_sym_controlAddIn] = ACTIONS(5129),
    [anon_sym_controlAddin] = ACTIONS(5129),
    [anon_sym_dotnet] = ACTIONS(5129),
    [anon_sym_DOTNET] = ACTIONS(5129),
    [anon_sym_Dotnet] = ACTIONS(5129),
    [anon_sym_DotNet] = ACTIONS(5129),
    [anon_sym_dotNet] = ACTIONS(5129),
    [sym_profile_keyword] = ACTIONS(5131),
    [anon_sym_profileextension] = ACTIONS(5129),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5129),
    [anon_sym_Profileextension] = ACTIONS(5129),
    [anon_sym_ProfileExtension] = ACTIONS(5129),
    [anon_sym_profileExtension] = ACTIONS(5129),
    [anon_sym_permissionset] = ACTIONS(5131),
    [anon_sym_PERMISSIONSET] = ACTIONS(5131),
    [anon_sym_Permissionset] = ACTIONS(5131),
    [anon_sym_PermissionSet] = ACTIONS(5131),
    [anon_sym_permissionSet] = ACTIONS(5131),
    [anon_sym_permissionsetextension] = ACTIONS(5129),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5129),
    [anon_sym_Permissionsetextension] = ACTIONS(5129),
    [anon_sym_PermissionSetExtension] = ACTIONS(5129),
    [anon_sym_permissionSetExtension] = ACTIONS(5129),
    [sym_entitlement_keyword] = ACTIONS(5129),
    [anon_sym_pagecustomization] = ACTIONS(5129),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5129),
    [anon_sym_Pagecustomization] = ACTIONS(5129),
    [anon_sym_PageCustomization] = ACTIONS(5129),
    [anon_sym_pageCustomization] = ACTIONS(5129),
    [sym_using_keyword] = ACTIONS(5129),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5129),
  },
  [STATE(2475)] = {
    [sym__body_element] = STATE(5964),
    [sym_empty_statement] = STATE(5964),
    [sym_property] = STATE(5964),
    [sym_fields_section] = STATE(5964),
    [sym_keys_section] = STATE(5964),
    [sym_fieldgroups_section] = STATE(5964),
    [sym_enum_value_declaration] = STATE(5964),
    [sym_labels_section] = STATE(5964),
    [sym_layout_section] = STATE(5964),
    [sym_modify_modification] = STATE(5964),
    [sym_actions_section] = STATE(5964),
    [sym_views_section] = STATE(5964),
    [sym_dataset_section] = STATE(5964),
    [sym_requestpage_section] = STATE(5964),
    [sym_rendering_section] = STATE(5964),
    [sym_elements_section] = STATE(5964),
    [sym_query_dataitem] = STATE(2574),
    [sym__query_body_element] = STATE(2574),
    [sym_preproc_conditional_query] = STATE(2574),
    [sym_query_column] = STATE(2574),
    [sym_query_filter] = STATE(2574),
    [sym_schema_section] = STATE(5964),
    [sym_assembly_declaration] = STATE(5964),
    [sym_event_declaration] = STATE(5964),
    [sym_procedure] = STATE(5964),
    [sym_preproc_split_procedure] = STATE(5964),
    [sym__procedure_header] = STATE(8087),
    [sym_procedure_modifier] = STATE(12657),
    [sym_trigger_declaration] = STATE(5964),
    [sym_var_section] = STATE(5964),
    [sym_attribute_item] = STATE(3722),
    [sym_preproc_conditional] = STATE(5964),
    [sym_preproc_if] = STATE(2494),
    [sym_preproc_elif] = STATE(2656),
    [sym_preproc_else] = STATE(2756),
    [sym_preproc_endif] = STATE(6822),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(2739),
    [aux_sym_query_dataitem_repeat1] = STATE(2574),
    [aux_sym_preproc_conditional_query_repeat1] = STATE(8098),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_repeat1] = STATE(8094),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(2883),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(2476)] = {
    [ts_builtin_sym_end] = ACTIONS(5339),
    [anon_sym_POUNDif] = ACTIONS(5339),
    [anon_sym_POUNDIF] = ACTIONS(5339),
    [anon_sym_POUNDIf] = ACTIONS(5339),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5341),
    [anon_sym_tableextension] = ACTIONS(5339),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5339),
    [anon_sym_Tableextension] = ACTIONS(5339),
    [anon_sym_TableExtension] = ACTIONS(5339),
    [anon_sym_tableExtension] = ACTIONS(5339),
    [sym_page_keyword] = ACTIONS(5341),
    [anon_sym_pageextension] = ACTIONS(5339),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5339),
    [anon_sym_Pageextension] = ACTIONS(5339),
    [anon_sym_PageExtension] = ACTIONS(5339),
    [anon_sym_pageExtension] = ACTIONS(5339),
    [anon_sym_codeunit] = ACTIONS(5339),
    [anon_sym_CODEUNIT] = ACTIONS(5339),
    [anon_sym_Codeunit] = ACTIONS(5339),
    [anon_sym_CodeUnit] = ACTIONS(5339),
    [anon_sym_COdeunit] = ACTIONS(5339),
    [anon_sym_codeUnit] = ACTIONS(5339),
    [sym_report_keyword] = ACTIONS(5341),
    [anon_sym_reportextension] = ACTIONS(5339),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5339),
    [anon_sym_Reportextension] = ACTIONS(5339),
    [anon_sym_ReportExtension] = ACTIONS(5339),
    [anon_sym_reportExtension] = ACTIONS(5339),
    [sym_query_keyword] = ACTIONS(5339),
    [anon_sym_xmlport] = ACTIONS(5339),
    [anon_sym_XMLPORT] = ACTIONS(5339),
    [anon_sym_Xmlport] = ACTIONS(5339),
    [anon_sym_XMLport] = ACTIONS(5339),
    [anon_sym_XMLPort] = ACTIONS(5339),
    [anon_sym_XmlPort] = ACTIONS(5339),
    [anon_sym_enum] = ACTIONS(5341),
    [anon_sym_ENUM] = ACTIONS(5341),
    [anon_sym_Enum] = ACTIONS(5341),
    [anon_sym_eNUM] = ACTIONS(5339),
    [anon_sym_eNum] = ACTIONS(5339),
    [anon_sym_ENum] = ACTIONS(5339),
    [anon_sym_enumextension] = ACTIONS(5339),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5339),
    [anon_sym_Enumextension] = ACTIONS(5339),
    [anon_sym_EnumExtension] = ACTIONS(5339),
    [anon_sym_enumExtension] = ACTIONS(5339),
    [sym_interface_keyword] = ACTIONS(5339),
    [anon_sym_controladdin] = ACTIONS(5339),
    [anon_sym_CONTROLADDIN] = ACTIONS(5339),
    [anon_sym_Controladdin] = ACTIONS(5339),
    [anon_sym_ControlAddIn] = ACTIONS(5339),
    [anon_sym_ControlAddin] = ACTIONS(5339),
    [anon_sym_controlAddIn] = ACTIONS(5339),
    [anon_sym_controlAddin] = ACTIONS(5339),
    [anon_sym_dotnet] = ACTIONS(5339),
    [anon_sym_DOTNET] = ACTIONS(5339),
    [anon_sym_Dotnet] = ACTIONS(5339),
    [anon_sym_DotNet] = ACTIONS(5339),
    [anon_sym_dotNet] = ACTIONS(5339),
    [sym_profile_keyword] = ACTIONS(5341),
    [anon_sym_profileextension] = ACTIONS(5339),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5339),
    [anon_sym_Profileextension] = ACTIONS(5339),
    [anon_sym_ProfileExtension] = ACTIONS(5339),
    [anon_sym_profileExtension] = ACTIONS(5339),
    [anon_sym_permissionset] = ACTIONS(5341),
    [anon_sym_PERMISSIONSET] = ACTIONS(5341),
    [anon_sym_Permissionset] = ACTIONS(5341),
    [anon_sym_PermissionSet] = ACTIONS(5341),
    [anon_sym_permissionSet] = ACTIONS(5341),
    [anon_sym_permissionsetextension] = ACTIONS(5339),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5339),
    [anon_sym_Permissionsetextension] = ACTIONS(5339),
    [anon_sym_PermissionSetExtension] = ACTIONS(5339),
    [anon_sym_permissionSetExtension] = ACTIONS(5339),
    [sym_entitlement_keyword] = ACTIONS(5339),
    [anon_sym_pagecustomization] = ACTIONS(5339),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5339),
    [anon_sym_Pagecustomization] = ACTIONS(5339),
    [anon_sym_PageCustomization] = ACTIONS(5339),
    [anon_sym_pageCustomization] = ACTIONS(5339),
    [sym_using_keyword] = ACTIONS(5339),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5339),
  },
  [STATE(2477)] = {
    [ts_builtin_sym_end] = ACTIONS(5133),
    [anon_sym_POUNDif] = ACTIONS(5133),
    [anon_sym_POUNDIF] = ACTIONS(5133),
    [anon_sym_POUNDIf] = ACTIONS(5133),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5135),
    [anon_sym_tableextension] = ACTIONS(5133),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5133),
    [anon_sym_Tableextension] = ACTIONS(5133),
    [anon_sym_TableExtension] = ACTIONS(5133),
    [anon_sym_tableExtension] = ACTIONS(5133),
    [sym_page_keyword] = ACTIONS(5135),
    [anon_sym_pageextension] = ACTIONS(5133),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5133),
    [anon_sym_Pageextension] = ACTIONS(5133),
    [anon_sym_PageExtension] = ACTIONS(5133),
    [anon_sym_pageExtension] = ACTIONS(5133),
    [anon_sym_codeunit] = ACTIONS(5133),
    [anon_sym_CODEUNIT] = ACTIONS(5133),
    [anon_sym_Codeunit] = ACTIONS(5133),
    [anon_sym_CodeUnit] = ACTIONS(5133),
    [anon_sym_COdeunit] = ACTIONS(5133),
    [anon_sym_codeUnit] = ACTIONS(5133),
    [sym_report_keyword] = ACTIONS(5135),
    [anon_sym_reportextension] = ACTIONS(5133),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5133),
    [anon_sym_Reportextension] = ACTIONS(5133),
    [anon_sym_ReportExtension] = ACTIONS(5133),
    [anon_sym_reportExtension] = ACTIONS(5133),
    [sym_query_keyword] = ACTIONS(5133),
    [anon_sym_xmlport] = ACTIONS(5133),
    [anon_sym_XMLPORT] = ACTIONS(5133),
    [anon_sym_Xmlport] = ACTIONS(5133),
    [anon_sym_XMLport] = ACTIONS(5133),
    [anon_sym_XMLPort] = ACTIONS(5133),
    [anon_sym_XmlPort] = ACTIONS(5133),
    [anon_sym_enum] = ACTIONS(5135),
    [anon_sym_ENUM] = ACTIONS(5135),
    [anon_sym_Enum] = ACTIONS(5135),
    [anon_sym_eNUM] = ACTIONS(5133),
    [anon_sym_eNum] = ACTIONS(5133),
    [anon_sym_ENum] = ACTIONS(5133),
    [anon_sym_enumextension] = ACTIONS(5133),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5133),
    [anon_sym_Enumextension] = ACTIONS(5133),
    [anon_sym_EnumExtension] = ACTIONS(5133),
    [anon_sym_enumExtension] = ACTIONS(5133),
    [sym_interface_keyword] = ACTIONS(5133),
    [anon_sym_controladdin] = ACTIONS(5133),
    [anon_sym_CONTROLADDIN] = ACTIONS(5133),
    [anon_sym_Controladdin] = ACTIONS(5133),
    [anon_sym_ControlAddIn] = ACTIONS(5133),
    [anon_sym_ControlAddin] = ACTIONS(5133),
    [anon_sym_controlAddIn] = ACTIONS(5133),
    [anon_sym_controlAddin] = ACTIONS(5133),
    [anon_sym_dotnet] = ACTIONS(5133),
    [anon_sym_DOTNET] = ACTIONS(5133),
    [anon_sym_Dotnet] = ACTIONS(5133),
    [anon_sym_DotNet] = ACTIONS(5133),
    [anon_sym_dotNet] = ACTIONS(5133),
    [sym_profile_keyword] = ACTIONS(5135),
    [anon_sym_profileextension] = ACTIONS(5133),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5133),
    [anon_sym_Profileextension] = ACTIONS(5133),
    [anon_sym_ProfileExtension] = ACTIONS(5133),
    [anon_sym_profileExtension] = ACTIONS(5133),
    [anon_sym_permissionset] = ACTIONS(5135),
    [anon_sym_PERMISSIONSET] = ACTIONS(5135),
    [anon_sym_Permissionset] = ACTIONS(5135),
    [anon_sym_PermissionSet] = ACTIONS(5135),
    [anon_sym_permissionSet] = ACTIONS(5135),
    [anon_sym_permissionsetextension] = ACTIONS(5133),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5133),
    [anon_sym_Permissionsetextension] = ACTIONS(5133),
    [anon_sym_PermissionSetExtension] = ACTIONS(5133),
    [anon_sym_permissionSetExtension] = ACTIONS(5133),
    [sym_entitlement_keyword] = ACTIONS(5133),
    [anon_sym_pagecustomization] = ACTIONS(5133),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5133),
    [anon_sym_Pagecustomization] = ACTIONS(5133),
    [anon_sym_PageCustomization] = ACTIONS(5133),
    [anon_sym_pageCustomization] = ACTIONS(5133),
    [sym_using_keyword] = ACTIONS(5133),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5133),
  },
  [STATE(2478)] = {
    [ts_builtin_sym_end] = ACTIONS(5137),
    [anon_sym_POUNDif] = ACTIONS(5137),
    [anon_sym_POUNDIF] = ACTIONS(5137),
    [anon_sym_POUNDIf] = ACTIONS(5137),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5139),
    [anon_sym_tableextension] = ACTIONS(5137),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5137),
    [anon_sym_Tableextension] = ACTIONS(5137),
    [anon_sym_TableExtension] = ACTIONS(5137),
    [anon_sym_tableExtension] = ACTIONS(5137),
    [sym_page_keyword] = ACTIONS(5139),
    [anon_sym_pageextension] = ACTIONS(5137),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5137),
    [anon_sym_Pageextension] = ACTIONS(5137),
    [anon_sym_PageExtension] = ACTIONS(5137),
    [anon_sym_pageExtension] = ACTIONS(5137),
    [anon_sym_codeunit] = ACTIONS(5137),
    [anon_sym_CODEUNIT] = ACTIONS(5137),
    [anon_sym_Codeunit] = ACTIONS(5137),
    [anon_sym_CodeUnit] = ACTIONS(5137),
    [anon_sym_COdeunit] = ACTIONS(5137),
    [anon_sym_codeUnit] = ACTIONS(5137),
    [sym_report_keyword] = ACTIONS(5139),
    [anon_sym_reportextension] = ACTIONS(5137),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5137),
    [anon_sym_Reportextension] = ACTIONS(5137),
    [anon_sym_ReportExtension] = ACTIONS(5137),
    [anon_sym_reportExtension] = ACTIONS(5137),
    [sym_query_keyword] = ACTIONS(5137),
    [anon_sym_xmlport] = ACTIONS(5137),
    [anon_sym_XMLPORT] = ACTIONS(5137),
    [anon_sym_Xmlport] = ACTIONS(5137),
    [anon_sym_XMLport] = ACTIONS(5137),
    [anon_sym_XMLPort] = ACTIONS(5137),
    [anon_sym_XmlPort] = ACTIONS(5137),
    [anon_sym_enum] = ACTIONS(5139),
    [anon_sym_ENUM] = ACTIONS(5139),
    [anon_sym_Enum] = ACTIONS(5139),
    [anon_sym_eNUM] = ACTIONS(5137),
    [anon_sym_eNum] = ACTIONS(5137),
    [anon_sym_ENum] = ACTIONS(5137),
    [anon_sym_enumextension] = ACTIONS(5137),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5137),
    [anon_sym_Enumextension] = ACTIONS(5137),
    [anon_sym_EnumExtension] = ACTIONS(5137),
    [anon_sym_enumExtension] = ACTIONS(5137),
    [sym_interface_keyword] = ACTIONS(5137),
    [anon_sym_controladdin] = ACTIONS(5137),
    [anon_sym_CONTROLADDIN] = ACTIONS(5137),
    [anon_sym_Controladdin] = ACTIONS(5137),
    [anon_sym_ControlAddIn] = ACTIONS(5137),
    [anon_sym_ControlAddin] = ACTIONS(5137),
    [anon_sym_controlAddIn] = ACTIONS(5137),
    [anon_sym_controlAddin] = ACTIONS(5137),
    [anon_sym_dotnet] = ACTIONS(5137),
    [anon_sym_DOTNET] = ACTIONS(5137),
    [anon_sym_Dotnet] = ACTIONS(5137),
    [anon_sym_DotNet] = ACTIONS(5137),
    [anon_sym_dotNet] = ACTIONS(5137),
    [sym_profile_keyword] = ACTIONS(5139),
    [anon_sym_profileextension] = ACTIONS(5137),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5137),
    [anon_sym_Profileextension] = ACTIONS(5137),
    [anon_sym_ProfileExtension] = ACTIONS(5137),
    [anon_sym_profileExtension] = ACTIONS(5137),
    [anon_sym_permissionset] = ACTIONS(5139),
    [anon_sym_PERMISSIONSET] = ACTIONS(5139),
    [anon_sym_Permissionset] = ACTIONS(5139),
    [anon_sym_PermissionSet] = ACTIONS(5139),
    [anon_sym_permissionSet] = ACTIONS(5139),
    [anon_sym_permissionsetextension] = ACTIONS(5137),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5137),
    [anon_sym_Permissionsetextension] = ACTIONS(5137),
    [anon_sym_PermissionSetExtension] = ACTIONS(5137),
    [anon_sym_permissionSetExtension] = ACTIONS(5137),
    [sym_entitlement_keyword] = ACTIONS(5137),
    [anon_sym_pagecustomization] = ACTIONS(5137),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5137),
    [anon_sym_Pagecustomization] = ACTIONS(5137),
    [anon_sym_PageCustomization] = ACTIONS(5137),
    [anon_sym_pageCustomization] = ACTIONS(5137),
    [sym_using_keyword] = ACTIONS(5137),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5137),
  },
  [STATE(2479)] = {
    [ts_builtin_sym_end] = ACTIONS(5141),
    [anon_sym_POUNDif] = ACTIONS(5141),
    [anon_sym_POUNDIF] = ACTIONS(5141),
    [anon_sym_POUNDIf] = ACTIONS(5141),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5143),
    [anon_sym_tableextension] = ACTIONS(5141),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5141),
    [anon_sym_Tableextension] = ACTIONS(5141),
    [anon_sym_TableExtension] = ACTIONS(5141),
    [anon_sym_tableExtension] = ACTIONS(5141),
    [sym_page_keyword] = ACTIONS(5143),
    [anon_sym_pageextension] = ACTIONS(5141),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5141),
    [anon_sym_Pageextension] = ACTIONS(5141),
    [anon_sym_PageExtension] = ACTIONS(5141),
    [anon_sym_pageExtension] = ACTIONS(5141),
    [anon_sym_codeunit] = ACTIONS(5141),
    [anon_sym_CODEUNIT] = ACTIONS(5141),
    [anon_sym_Codeunit] = ACTIONS(5141),
    [anon_sym_CodeUnit] = ACTIONS(5141),
    [anon_sym_COdeunit] = ACTIONS(5141),
    [anon_sym_codeUnit] = ACTIONS(5141),
    [sym_report_keyword] = ACTIONS(5143),
    [anon_sym_reportextension] = ACTIONS(5141),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5141),
    [anon_sym_Reportextension] = ACTIONS(5141),
    [anon_sym_ReportExtension] = ACTIONS(5141),
    [anon_sym_reportExtension] = ACTIONS(5141),
    [sym_query_keyword] = ACTIONS(5141),
    [anon_sym_xmlport] = ACTIONS(5141),
    [anon_sym_XMLPORT] = ACTIONS(5141),
    [anon_sym_Xmlport] = ACTIONS(5141),
    [anon_sym_XMLport] = ACTIONS(5141),
    [anon_sym_XMLPort] = ACTIONS(5141),
    [anon_sym_XmlPort] = ACTIONS(5141),
    [anon_sym_enum] = ACTIONS(5143),
    [anon_sym_ENUM] = ACTIONS(5143),
    [anon_sym_Enum] = ACTIONS(5143),
    [anon_sym_eNUM] = ACTIONS(5141),
    [anon_sym_eNum] = ACTIONS(5141),
    [anon_sym_ENum] = ACTIONS(5141),
    [anon_sym_enumextension] = ACTIONS(5141),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5141),
    [anon_sym_Enumextension] = ACTIONS(5141),
    [anon_sym_EnumExtension] = ACTIONS(5141),
    [anon_sym_enumExtension] = ACTIONS(5141),
    [sym_interface_keyword] = ACTIONS(5141),
    [anon_sym_controladdin] = ACTIONS(5141),
    [anon_sym_CONTROLADDIN] = ACTIONS(5141),
    [anon_sym_Controladdin] = ACTIONS(5141),
    [anon_sym_ControlAddIn] = ACTIONS(5141),
    [anon_sym_ControlAddin] = ACTIONS(5141),
    [anon_sym_controlAddIn] = ACTIONS(5141),
    [anon_sym_controlAddin] = ACTIONS(5141),
    [anon_sym_dotnet] = ACTIONS(5141),
    [anon_sym_DOTNET] = ACTIONS(5141),
    [anon_sym_Dotnet] = ACTIONS(5141),
    [anon_sym_DotNet] = ACTIONS(5141),
    [anon_sym_dotNet] = ACTIONS(5141),
    [sym_profile_keyword] = ACTIONS(5143),
    [anon_sym_profileextension] = ACTIONS(5141),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5141),
    [anon_sym_Profileextension] = ACTIONS(5141),
    [anon_sym_ProfileExtension] = ACTIONS(5141),
    [anon_sym_profileExtension] = ACTIONS(5141),
    [anon_sym_permissionset] = ACTIONS(5143),
    [anon_sym_PERMISSIONSET] = ACTIONS(5143),
    [anon_sym_Permissionset] = ACTIONS(5143),
    [anon_sym_PermissionSet] = ACTIONS(5143),
    [anon_sym_permissionSet] = ACTIONS(5143),
    [anon_sym_permissionsetextension] = ACTIONS(5141),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5141),
    [anon_sym_Permissionsetextension] = ACTIONS(5141),
    [anon_sym_PermissionSetExtension] = ACTIONS(5141),
    [anon_sym_permissionSetExtension] = ACTIONS(5141),
    [sym_entitlement_keyword] = ACTIONS(5141),
    [anon_sym_pagecustomization] = ACTIONS(5141),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5141),
    [anon_sym_Pagecustomization] = ACTIONS(5141),
    [anon_sym_PageCustomization] = ACTIONS(5141),
    [anon_sym_pageCustomization] = ACTIONS(5141),
    [sym_using_keyword] = ACTIONS(5141),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5141),
  },
  [STATE(2480)] = {
    [ts_builtin_sym_end] = ACTIONS(5343),
    [anon_sym_POUNDif] = ACTIONS(5343),
    [anon_sym_POUNDIF] = ACTIONS(5343),
    [anon_sym_POUNDIf] = ACTIONS(5343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5345),
    [anon_sym_tableextension] = ACTIONS(5343),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5343),
    [anon_sym_Tableextension] = ACTIONS(5343),
    [anon_sym_TableExtension] = ACTIONS(5343),
    [anon_sym_tableExtension] = ACTIONS(5343),
    [sym_page_keyword] = ACTIONS(5345),
    [anon_sym_pageextension] = ACTIONS(5343),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5343),
    [anon_sym_Pageextension] = ACTIONS(5343),
    [anon_sym_PageExtension] = ACTIONS(5343),
    [anon_sym_pageExtension] = ACTIONS(5343),
    [anon_sym_codeunit] = ACTIONS(5343),
    [anon_sym_CODEUNIT] = ACTIONS(5343),
    [anon_sym_Codeunit] = ACTIONS(5343),
    [anon_sym_CodeUnit] = ACTIONS(5343),
    [anon_sym_COdeunit] = ACTIONS(5343),
    [anon_sym_codeUnit] = ACTIONS(5343),
    [sym_report_keyword] = ACTIONS(5345),
    [anon_sym_reportextension] = ACTIONS(5343),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5343),
    [anon_sym_Reportextension] = ACTIONS(5343),
    [anon_sym_ReportExtension] = ACTIONS(5343),
    [anon_sym_reportExtension] = ACTIONS(5343),
    [sym_query_keyword] = ACTIONS(5343),
    [anon_sym_xmlport] = ACTIONS(5343),
    [anon_sym_XMLPORT] = ACTIONS(5343),
    [anon_sym_Xmlport] = ACTIONS(5343),
    [anon_sym_XMLport] = ACTIONS(5343),
    [anon_sym_XMLPort] = ACTIONS(5343),
    [anon_sym_XmlPort] = ACTIONS(5343),
    [anon_sym_enum] = ACTIONS(5345),
    [anon_sym_ENUM] = ACTIONS(5345),
    [anon_sym_Enum] = ACTIONS(5345),
    [anon_sym_eNUM] = ACTIONS(5343),
    [anon_sym_eNum] = ACTIONS(5343),
    [anon_sym_ENum] = ACTIONS(5343),
    [anon_sym_enumextension] = ACTIONS(5343),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5343),
    [anon_sym_Enumextension] = ACTIONS(5343),
    [anon_sym_EnumExtension] = ACTIONS(5343),
    [anon_sym_enumExtension] = ACTIONS(5343),
    [sym_interface_keyword] = ACTIONS(5343),
    [anon_sym_controladdin] = ACTIONS(5343),
    [anon_sym_CONTROLADDIN] = ACTIONS(5343),
    [anon_sym_Controladdin] = ACTIONS(5343),
    [anon_sym_ControlAddIn] = ACTIONS(5343),
    [anon_sym_ControlAddin] = ACTIONS(5343),
    [anon_sym_controlAddIn] = ACTIONS(5343),
    [anon_sym_controlAddin] = ACTIONS(5343),
    [anon_sym_dotnet] = ACTIONS(5343),
    [anon_sym_DOTNET] = ACTIONS(5343),
    [anon_sym_Dotnet] = ACTIONS(5343),
    [anon_sym_DotNet] = ACTIONS(5343),
    [anon_sym_dotNet] = ACTIONS(5343),
    [sym_profile_keyword] = ACTIONS(5345),
    [anon_sym_profileextension] = ACTIONS(5343),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5343),
    [anon_sym_Profileextension] = ACTIONS(5343),
    [anon_sym_ProfileExtension] = ACTIONS(5343),
    [anon_sym_profileExtension] = ACTIONS(5343),
    [anon_sym_permissionset] = ACTIONS(5345),
    [anon_sym_PERMISSIONSET] = ACTIONS(5345),
    [anon_sym_Permissionset] = ACTIONS(5345),
    [anon_sym_PermissionSet] = ACTIONS(5345),
    [anon_sym_permissionSet] = ACTIONS(5345),
    [anon_sym_permissionsetextension] = ACTIONS(5343),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5343),
    [anon_sym_Permissionsetextension] = ACTIONS(5343),
    [anon_sym_PermissionSetExtension] = ACTIONS(5343),
    [anon_sym_permissionSetExtension] = ACTIONS(5343),
    [sym_entitlement_keyword] = ACTIONS(5343),
    [anon_sym_pagecustomization] = ACTIONS(5343),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5343),
    [anon_sym_Pagecustomization] = ACTIONS(5343),
    [anon_sym_PageCustomization] = ACTIONS(5343),
    [anon_sym_pageCustomization] = ACTIONS(5343),
    [sym_using_keyword] = ACTIONS(5343),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5343),
  },
  [STATE(2481)] = {
    [ts_builtin_sym_end] = ACTIONS(5347),
    [anon_sym_POUNDif] = ACTIONS(5347),
    [anon_sym_POUNDIF] = ACTIONS(5347),
    [anon_sym_POUNDIf] = ACTIONS(5347),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5349),
    [anon_sym_tableextension] = ACTIONS(5347),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5347),
    [anon_sym_Tableextension] = ACTIONS(5347),
    [anon_sym_TableExtension] = ACTIONS(5347),
    [anon_sym_tableExtension] = ACTIONS(5347),
    [sym_page_keyword] = ACTIONS(5349),
    [anon_sym_pageextension] = ACTIONS(5347),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5347),
    [anon_sym_Pageextension] = ACTIONS(5347),
    [anon_sym_PageExtension] = ACTIONS(5347),
    [anon_sym_pageExtension] = ACTIONS(5347),
    [anon_sym_codeunit] = ACTIONS(5347),
    [anon_sym_CODEUNIT] = ACTIONS(5347),
    [anon_sym_Codeunit] = ACTIONS(5347),
    [anon_sym_CodeUnit] = ACTIONS(5347),
    [anon_sym_COdeunit] = ACTIONS(5347),
    [anon_sym_codeUnit] = ACTIONS(5347),
    [sym_report_keyword] = ACTIONS(5349),
    [anon_sym_reportextension] = ACTIONS(5347),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5347),
    [anon_sym_Reportextension] = ACTIONS(5347),
    [anon_sym_ReportExtension] = ACTIONS(5347),
    [anon_sym_reportExtension] = ACTIONS(5347),
    [sym_query_keyword] = ACTIONS(5347),
    [anon_sym_xmlport] = ACTIONS(5347),
    [anon_sym_XMLPORT] = ACTIONS(5347),
    [anon_sym_Xmlport] = ACTIONS(5347),
    [anon_sym_XMLport] = ACTIONS(5347),
    [anon_sym_XMLPort] = ACTIONS(5347),
    [anon_sym_XmlPort] = ACTIONS(5347),
    [anon_sym_enum] = ACTIONS(5349),
    [anon_sym_ENUM] = ACTIONS(5349),
    [anon_sym_Enum] = ACTIONS(5349),
    [anon_sym_eNUM] = ACTIONS(5347),
    [anon_sym_eNum] = ACTIONS(5347),
    [anon_sym_ENum] = ACTIONS(5347),
    [anon_sym_enumextension] = ACTIONS(5347),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5347),
    [anon_sym_Enumextension] = ACTIONS(5347),
    [anon_sym_EnumExtension] = ACTIONS(5347),
    [anon_sym_enumExtension] = ACTIONS(5347),
    [sym_interface_keyword] = ACTIONS(5347),
    [anon_sym_controladdin] = ACTIONS(5347),
    [anon_sym_CONTROLADDIN] = ACTIONS(5347),
    [anon_sym_Controladdin] = ACTIONS(5347),
    [anon_sym_ControlAddIn] = ACTIONS(5347),
    [anon_sym_ControlAddin] = ACTIONS(5347),
    [anon_sym_controlAddIn] = ACTIONS(5347),
    [anon_sym_controlAddin] = ACTIONS(5347),
    [anon_sym_dotnet] = ACTIONS(5347),
    [anon_sym_DOTNET] = ACTIONS(5347),
    [anon_sym_Dotnet] = ACTIONS(5347),
    [anon_sym_DotNet] = ACTIONS(5347),
    [anon_sym_dotNet] = ACTIONS(5347),
    [sym_profile_keyword] = ACTIONS(5349),
    [anon_sym_profileextension] = ACTIONS(5347),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5347),
    [anon_sym_Profileextension] = ACTIONS(5347),
    [anon_sym_ProfileExtension] = ACTIONS(5347),
    [anon_sym_profileExtension] = ACTIONS(5347),
    [anon_sym_permissionset] = ACTIONS(5349),
    [anon_sym_PERMISSIONSET] = ACTIONS(5349),
    [anon_sym_Permissionset] = ACTIONS(5349),
    [anon_sym_PermissionSet] = ACTIONS(5349),
    [anon_sym_permissionSet] = ACTIONS(5349),
    [anon_sym_permissionsetextension] = ACTIONS(5347),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5347),
    [anon_sym_Permissionsetextension] = ACTIONS(5347),
    [anon_sym_PermissionSetExtension] = ACTIONS(5347),
    [anon_sym_permissionSetExtension] = ACTIONS(5347),
    [sym_entitlement_keyword] = ACTIONS(5347),
    [anon_sym_pagecustomization] = ACTIONS(5347),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5347),
    [anon_sym_Pagecustomization] = ACTIONS(5347),
    [anon_sym_PageCustomization] = ACTIONS(5347),
    [anon_sym_pageCustomization] = ACTIONS(5347),
    [sym_using_keyword] = ACTIONS(5347),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5347),
  },
  [STATE(2482)] = {
    [ts_builtin_sym_end] = ACTIONS(5164),
    [anon_sym_POUNDif] = ACTIONS(5164),
    [anon_sym_POUNDIF] = ACTIONS(5164),
    [anon_sym_POUNDIf] = ACTIONS(5164),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5166),
    [anon_sym_tableextension] = ACTIONS(5164),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5164),
    [anon_sym_Tableextension] = ACTIONS(5164),
    [anon_sym_TableExtension] = ACTIONS(5164),
    [anon_sym_tableExtension] = ACTIONS(5164),
    [sym_page_keyword] = ACTIONS(5166),
    [anon_sym_pageextension] = ACTIONS(5164),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5164),
    [anon_sym_Pageextension] = ACTIONS(5164),
    [anon_sym_PageExtension] = ACTIONS(5164),
    [anon_sym_pageExtension] = ACTIONS(5164),
    [anon_sym_codeunit] = ACTIONS(5164),
    [anon_sym_CODEUNIT] = ACTIONS(5164),
    [anon_sym_Codeunit] = ACTIONS(5164),
    [anon_sym_CodeUnit] = ACTIONS(5164),
    [anon_sym_COdeunit] = ACTIONS(5164),
    [anon_sym_codeUnit] = ACTIONS(5164),
    [sym_report_keyword] = ACTIONS(5166),
    [anon_sym_reportextension] = ACTIONS(5164),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5164),
    [anon_sym_Reportextension] = ACTIONS(5164),
    [anon_sym_ReportExtension] = ACTIONS(5164),
    [anon_sym_reportExtension] = ACTIONS(5164),
    [sym_query_keyword] = ACTIONS(5164),
    [anon_sym_xmlport] = ACTIONS(5164),
    [anon_sym_XMLPORT] = ACTIONS(5164),
    [anon_sym_Xmlport] = ACTIONS(5164),
    [anon_sym_XMLport] = ACTIONS(5164),
    [anon_sym_XMLPort] = ACTIONS(5164),
    [anon_sym_XmlPort] = ACTIONS(5164),
    [anon_sym_enum] = ACTIONS(5166),
    [anon_sym_ENUM] = ACTIONS(5166),
    [anon_sym_Enum] = ACTIONS(5166),
    [anon_sym_eNUM] = ACTIONS(5164),
    [anon_sym_eNum] = ACTIONS(5164),
    [anon_sym_ENum] = ACTIONS(5164),
    [anon_sym_enumextension] = ACTIONS(5164),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5164),
    [anon_sym_Enumextension] = ACTIONS(5164),
    [anon_sym_EnumExtension] = ACTIONS(5164),
    [anon_sym_enumExtension] = ACTIONS(5164),
    [sym_interface_keyword] = ACTIONS(5164),
    [anon_sym_controladdin] = ACTIONS(5164),
    [anon_sym_CONTROLADDIN] = ACTIONS(5164),
    [anon_sym_Controladdin] = ACTIONS(5164),
    [anon_sym_ControlAddIn] = ACTIONS(5164),
    [anon_sym_ControlAddin] = ACTIONS(5164),
    [anon_sym_controlAddIn] = ACTIONS(5164),
    [anon_sym_controlAddin] = ACTIONS(5164),
    [anon_sym_dotnet] = ACTIONS(5164),
    [anon_sym_DOTNET] = ACTIONS(5164),
    [anon_sym_Dotnet] = ACTIONS(5164),
    [anon_sym_DotNet] = ACTIONS(5164),
    [anon_sym_dotNet] = ACTIONS(5164),
    [sym_profile_keyword] = ACTIONS(5166),
    [anon_sym_profileextension] = ACTIONS(5164),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5164),
    [anon_sym_Profileextension] = ACTIONS(5164),
    [anon_sym_ProfileExtension] = ACTIONS(5164),
    [anon_sym_profileExtension] = ACTIONS(5164),
    [anon_sym_permissionset] = ACTIONS(5166),
    [anon_sym_PERMISSIONSET] = ACTIONS(5166),
    [anon_sym_Permissionset] = ACTIONS(5166),
    [anon_sym_PermissionSet] = ACTIONS(5166),
    [anon_sym_permissionSet] = ACTIONS(5166),
    [anon_sym_permissionsetextension] = ACTIONS(5164),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5164),
    [anon_sym_Permissionsetextension] = ACTIONS(5164),
    [anon_sym_PermissionSetExtension] = ACTIONS(5164),
    [anon_sym_permissionSetExtension] = ACTIONS(5164),
    [sym_entitlement_keyword] = ACTIONS(5164),
    [anon_sym_pagecustomization] = ACTIONS(5164),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5164),
    [anon_sym_Pagecustomization] = ACTIONS(5164),
    [anon_sym_PageCustomization] = ACTIONS(5164),
    [anon_sym_pageCustomization] = ACTIONS(5164),
    [sym_using_keyword] = ACTIONS(5164),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5164),
  },
  [STATE(2483)] = {
    [ts_builtin_sym_end] = ACTIONS(5351),
    [anon_sym_POUNDif] = ACTIONS(5351),
    [anon_sym_POUNDIF] = ACTIONS(5351),
    [anon_sym_POUNDIf] = ACTIONS(5351),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5353),
    [anon_sym_tableextension] = ACTIONS(5351),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5351),
    [anon_sym_Tableextension] = ACTIONS(5351),
    [anon_sym_TableExtension] = ACTIONS(5351),
    [anon_sym_tableExtension] = ACTIONS(5351),
    [sym_page_keyword] = ACTIONS(5353),
    [anon_sym_pageextension] = ACTIONS(5351),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5351),
    [anon_sym_Pageextension] = ACTIONS(5351),
    [anon_sym_PageExtension] = ACTIONS(5351),
    [anon_sym_pageExtension] = ACTIONS(5351),
    [anon_sym_codeunit] = ACTIONS(5351),
    [anon_sym_CODEUNIT] = ACTIONS(5351),
    [anon_sym_Codeunit] = ACTIONS(5351),
    [anon_sym_CodeUnit] = ACTIONS(5351),
    [anon_sym_COdeunit] = ACTIONS(5351),
    [anon_sym_codeUnit] = ACTIONS(5351),
    [sym_report_keyword] = ACTIONS(5353),
    [anon_sym_reportextension] = ACTIONS(5351),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5351),
    [anon_sym_Reportextension] = ACTIONS(5351),
    [anon_sym_ReportExtension] = ACTIONS(5351),
    [anon_sym_reportExtension] = ACTIONS(5351),
    [sym_query_keyword] = ACTIONS(5351),
    [anon_sym_xmlport] = ACTIONS(5351),
    [anon_sym_XMLPORT] = ACTIONS(5351),
    [anon_sym_Xmlport] = ACTIONS(5351),
    [anon_sym_XMLport] = ACTIONS(5351),
    [anon_sym_XMLPort] = ACTIONS(5351),
    [anon_sym_XmlPort] = ACTIONS(5351),
    [anon_sym_enum] = ACTIONS(5353),
    [anon_sym_ENUM] = ACTIONS(5353),
    [anon_sym_Enum] = ACTIONS(5353),
    [anon_sym_eNUM] = ACTIONS(5351),
    [anon_sym_eNum] = ACTIONS(5351),
    [anon_sym_ENum] = ACTIONS(5351),
    [anon_sym_enumextension] = ACTIONS(5351),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5351),
    [anon_sym_Enumextension] = ACTIONS(5351),
    [anon_sym_EnumExtension] = ACTIONS(5351),
    [anon_sym_enumExtension] = ACTIONS(5351),
    [sym_interface_keyword] = ACTIONS(5351),
    [anon_sym_controladdin] = ACTIONS(5351),
    [anon_sym_CONTROLADDIN] = ACTIONS(5351),
    [anon_sym_Controladdin] = ACTIONS(5351),
    [anon_sym_ControlAddIn] = ACTIONS(5351),
    [anon_sym_ControlAddin] = ACTIONS(5351),
    [anon_sym_controlAddIn] = ACTIONS(5351),
    [anon_sym_controlAddin] = ACTIONS(5351),
    [anon_sym_dotnet] = ACTIONS(5351),
    [anon_sym_DOTNET] = ACTIONS(5351),
    [anon_sym_Dotnet] = ACTIONS(5351),
    [anon_sym_DotNet] = ACTIONS(5351),
    [anon_sym_dotNet] = ACTIONS(5351),
    [sym_profile_keyword] = ACTIONS(5353),
    [anon_sym_profileextension] = ACTIONS(5351),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5351),
    [anon_sym_Profileextension] = ACTIONS(5351),
    [anon_sym_ProfileExtension] = ACTIONS(5351),
    [anon_sym_profileExtension] = ACTIONS(5351),
    [anon_sym_permissionset] = ACTIONS(5353),
    [anon_sym_PERMISSIONSET] = ACTIONS(5353),
    [anon_sym_Permissionset] = ACTIONS(5353),
    [anon_sym_PermissionSet] = ACTIONS(5353),
    [anon_sym_permissionSet] = ACTIONS(5353),
    [anon_sym_permissionsetextension] = ACTIONS(5351),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5351),
    [anon_sym_Permissionsetextension] = ACTIONS(5351),
    [anon_sym_PermissionSetExtension] = ACTIONS(5351),
    [anon_sym_permissionSetExtension] = ACTIONS(5351),
    [sym_entitlement_keyword] = ACTIONS(5351),
    [anon_sym_pagecustomization] = ACTIONS(5351),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5351),
    [anon_sym_Pagecustomization] = ACTIONS(5351),
    [anon_sym_PageCustomization] = ACTIONS(5351),
    [anon_sym_pageCustomization] = ACTIONS(5351),
    [sym_using_keyword] = ACTIONS(5351),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5351),
  },
  [STATE(2484)] = {
    [ts_builtin_sym_end] = ACTIONS(5168),
    [anon_sym_POUNDif] = ACTIONS(5168),
    [anon_sym_POUNDIF] = ACTIONS(5168),
    [anon_sym_POUNDIf] = ACTIONS(5168),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5170),
    [anon_sym_tableextension] = ACTIONS(5168),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5168),
    [anon_sym_Tableextension] = ACTIONS(5168),
    [anon_sym_TableExtension] = ACTIONS(5168),
    [anon_sym_tableExtension] = ACTIONS(5168),
    [sym_page_keyword] = ACTIONS(5170),
    [anon_sym_pageextension] = ACTIONS(5168),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5168),
    [anon_sym_Pageextension] = ACTIONS(5168),
    [anon_sym_PageExtension] = ACTIONS(5168),
    [anon_sym_pageExtension] = ACTIONS(5168),
    [anon_sym_codeunit] = ACTIONS(5168),
    [anon_sym_CODEUNIT] = ACTIONS(5168),
    [anon_sym_Codeunit] = ACTIONS(5168),
    [anon_sym_CodeUnit] = ACTIONS(5168),
    [anon_sym_COdeunit] = ACTIONS(5168),
    [anon_sym_codeUnit] = ACTIONS(5168),
    [sym_report_keyword] = ACTIONS(5170),
    [anon_sym_reportextension] = ACTIONS(5168),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5168),
    [anon_sym_Reportextension] = ACTIONS(5168),
    [anon_sym_ReportExtension] = ACTIONS(5168),
    [anon_sym_reportExtension] = ACTIONS(5168),
    [sym_query_keyword] = ACTIONS(5168),
    [anon_sym_xmlport] = ACTIONS(5168),
    [anon_sym_XMLPORT] = ACTIONS(5168),
    [anon_sym_Xmlport] = ACTIONS(5168),
    [anon_sym_XMLport] = ACTIONS(5168),
    [anon_sym_XMLPort] = ACTIONS(5168),
    [anon_sym_XmlPort] = ACTIONS(5168),
    [anon_sym_enum] = ACTIONS(5170),
    [anon_sym_ENUM] = ACTIONS(5170),
    [anon_sym_Enum] = ACTIONS(5170),
    [anon_sym_eNUM] = ACTIONS(5168),
    [anon_sym_eNum] = ACTIONS(5168),
    [anon_sym_ENum] = ACTIONS(5168),
    [anon_sym_enumextension] = ACTIONS(5168),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5168),
    [anon_sym_Enumextension] = ACTIONS(5168),
    [anon_sym_EnumExtension] = ACTIONS(5168),
    [anon_sym_enumExtension] = ACTIONS(5168),
    [sym_interface_keyword] = ACTIONS(5168),
    [anon_sym_controladdin] = ACTIONS(5168),
    [anon_sym_CONTROLADDIN] = ACTIONS(5168),
    [anon_sym_Controladdin] = ACTIONS(5168),
    [anon_sym_ControlAddIn] = ACTIONS(5168),
    [anon_sym_ControlAddin] = ACTIONS(5168),
    [anon_sym_controlAddIn] = ACTIONS(5168),
    [anon_sym_controlAddin] = ACTIONS(5168),
    [anon_sym_dotnet] = ACTIONS(5168),
    [anon_sym_DOTNET] = ACTIONS(5168),
    [anon_sym_Dotnet] = ACTIONS(5168),
    [anon_sym_DotNet] = ACTIONS(5168),
    [anon_sym_dotNet] = ACTIONS(5168),
    [sym_profile_keyword] = ACTIONS(5170),
    [anon_sym_profileextension] = ACTIONS(5168),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5168),
    [anon_sym_Profileextension] = ACTIONS(5168),
    [anon_sym_ProfileExtension] = ACTIONS(5168),
    [anon_sym_profileExtension] = ACTIONS(5168),
    [anon_sym_permissionset] = ACTIONS(5170),
    [anon_sym_PERMISSIONSET] = ACTIONS(5170),
    [anon_sym_Permissionset] = ACTIONS(5170),
    [anon_sym_PermissionSet] = ACTIONS(5170),
    [anon_sym_permissionSet] = ACTIONS(5170),
    [anon_sym_permissionsetextension] = ACTIONS(5168),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5168),
    [anon_sym_Permissionsetextension] = ACTIONS(5168),
    [anon_sym_PermissionSetExtension] = ACTIONS(5168),
    [anon_sym_permissionSetExtension] = ACTIONS(5168),
    [sym_entitlement_keyword] = ACTIONS(5168),
    [anon_sym_pagecustomization] = ACTIONS(5168),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5168),
    [anon_sym_Pagecustomization] = ACTIONS(5168),
    [anon_sym_PageCustomization] = ACTIONS(5168),
    [anon_sym_pageCustomization] = ACTIONS(5168),
    [sym_using_keyword] = ACTIONS(5168),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5168),
  },
  [STATE(2485)] = {
    [ts_builtin_sym_end] = ACTIONS(5172),
    [anon_sym_POUNDif] = ACTIONS(5172),
    [anon_sym_POUNDIF] = ACTIONS(5172),
    [anon_sym_POUNDIf] = ACTIONS(5172),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5174),
    [anon_sym_tableextension] = ACTIONS(5172),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5172),
    [anon_sym_Tableextension] = ACTIONS(5172),
    [anon_sym_TableExtension] = ACTIONS(5172),
    [anon_sym_tableExtension] = ACTIONS(5172),
    [sym_page_keyword] = ACTIONS(5174),
    [anon_sym_pageextension] = ACTIONS(5172),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5172),
    [anon_sym_Pageextension] = ACTIONS(5172),
    [anon_sym_PageExtension] = ACTIONS(5172),
    [anon_sym_pageExtension] = ACTIONS(5172),
    [anon_sym_codeunit] = ACTIONS(5172),
    [anon_sym_CODEUNIT] = ACTIONS(5172),
    [anon_sym_Codeunit] = ACTIONS(5172),
    [anon_sym_CodeUnit] = ACTIONS(5172),
    [anon_sym_COdeunit] = ACTIONS(5172),
    [anon_sym_codeUnit] = ACTIONS(5172),
    [sym_report_keyword] = ACTIONS(5174),
    [anon_sym_reportextension] = ACTIONS(5172),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5172),
    [anon_sym_Reportextension] = ACTIONS(5172),
    [anon_sym_ReportExtension] = ACTIONS(5172),
    [anon_sym_reportExtension] = ACTIONS(5172),
    [sym_query_keyword] = ACTIONS(5172),
    [anon_sym_xmlport] = ACTIONS(5172),
    [anon_sym_XMLPORT] = ACTIONS(5172),
    [anon_sym_Xmlport] = ACTIONS(5172),
    [anon_sym_XMLport] = ACTIONS(5172),
    [anon_sym_XMLPort] = ACTIONS(5172),
    [anon_sym_XmlPort] = ACTIONS(5172),
    [anon_sym_enum] = ACTIONS(5174),
    [anon_sym_ENUM] = ACTIONS(5174),
    [anon_sym_Enum] = ACTIONS(5174),
    [anon_sym_eNUM] = ACTIONS(5172),
    [anon_sym_eNum] = ACTIONS(5172),
    [anon_sym_ENum] = ACTIONS(5172),
    [anon_sym_enumextension] = ACTIONS(5172),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5172),
    [anon_sym_Enumextension] = ACTIONS(5172),
    [anon_sym_EnumExtension] = ACTIONS(5172),
    [anon_sym_enumExtension] = ACTIONS(5172),
    [sym_interface_keyword] = ACTIONS(5172),
    [anon_sym_controladdin] = ACTIONS(5172),
    [anon_sym_CONTROLADDIN] = ACTIONS(5172),
    [anon_sym_Controladdin] = ACTIONS(5172),
    [anon_sym_ControlAddIn] = ACTIONS(5172),
    [anon_sym_ControlAddin] = ACTIONS(5172),
    [anon_sym_controlAddIn] = ACTIONS(5172),
    [anon_sym_controlAddin] = ACTIONS(5172),
    [anon_sym_dotnet] = ACTIONS(5172),
    [anon_sym_DOTNET] = ACTIONS(5172),
    [anon_sym_Dotnet] = ACTIONS(5172),
    [anon_sym_DotNet] = ACTIONS(5172),
    [anon_sym_dotNet] = ACTIONS(5172),
    [sym_profile_keyword] = ACTIONS(5174),
    [anon_sym_profileextension] = ACTIONS(5172),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5172),
    [anon_sym_Profileextension] = ACTIONS(5172),
    [anon_sym_ProfileExtension] = ACTIONS(5172),
    [anon_sym_profileExtension] = ACTIONS(5172),
    [anon_sym_permissionset] = ACTIONS(5174),
    [anon_sym_PERMISSIONSET] = ACTIONS(5174),
    [anon_sym_Permissionset] = ACTIONS(5174),
    [anon_sym_PermissionSet] = ACTIONS(5174),
    [anon_sym_permissionSet] = ACTIONS(5174),
    [anon_sym_permissionsetextension] = ACTIONS(5172),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5172),
    [anon_sym_Permissionsetextension] = ACTIONS(5172),
    [anon_sym_PermissionSetExtension] = ACTIONS(5172),
    [anon_sym_permissionSetExtension] = ACTIONS(5172),
    [sym_entitlement_keyword] = ACTIONS(5172),
    [anon_sym_pagecustomization] = ACTIONS(5172),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5172),
    [anon_sym_Pagecustomization] = ACTIONS(5172),
    [anon_sym_PageCustomization] = ACTIONS(5172),
    [anon_sym_pageCustomization] = ACTIONS(5172),
    [sym_using_keyword] = ACTIONS(5172),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5172),
  },
  [STATE(2486)] = {
    [ts_builtin_sym_end] = ACTIONS(5176),
    [anon_sym_POUNDif] = ACTIONS(5176),
    [anon_sym_POUNDIF] = ACTIONS(5176),
    [anon_sym_POUNDIf] = ACTIONS(5176),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5178),
    [anon_sym_tableextension] = ACTIONS(5176),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5176),
    [anon_sym_Tableextension] = ACTIONS(5176),
    [anon_sym_TableExtension] = ACTIONS(5176),
    [anon_sym_tableExtension] = ACTIONS(5176),
    [sym_page_keyword] = ACTIONS(5178),
    [anon_sym_pageextension] = ACTIONS(5176),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5176),
    [anon_sym_Pageextension] = ACTIONS(5176),
    [anon_sym_PageExtension] = ACTIONS(5176),
    [anon_sym_pageExtension] = ACTIONS(5176),
    [anon_sym_codeunit] = ACTIONS(5176),
    [anon_sym_CODEUNIT] = ACTIONS(5176),
    [anon_sym_Codeunit] = ACTIONS(5176),
    [anon_sym_CodeUnit] = ACTIONS(5176),
    [anon_sym_COdeunit] = ACTIONS(5176),
    [anon_sym_codeUnit] = ACTIONS(5176),
    [sym_report_keyword] = ACTIONS(5178),
    [anon_sym_reportextension] = ACTIONS(5176),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5176),
    [anon_sym_Reportextension] = ACTIONS(5176),
    [anon_sym_ReportExtension] = ACTIONS(5176),
    [anon_sym_reportExtension] = ACTIONS(5176),
    [sym_query_keyword] = ACTIONS(5176),
    [anon_sym_xmlport] = ACTIONS(5176),
    [anon_sym_XMLPORT] = ACTIONS(5176),
    [anon_sym_Xmlport] = ACTIONS(5176),
    [anon_sym_XMLport] = ACTIONS(5176),
    [anon_sym_XMLPort] = ACTIONS(5176),
    [anon_sym_XmlPort] = ACTIONS(5176),
    [anon_sym_enum] = ACTIONS(5178),
    [anon_sym_ENUM] = ACTIONS(5178),
    [anon_sym_Enum] = ACTIONS(5178),
    [anon_sym_eNUM] = ACTIONS(5176),
    [anon_sym_eNum] = ACTIONS(5176),
    [anon_sym_ENum] = ACTIONS(5176),
    [anon_sym_enumextension] = ACTIONS(5176),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5176),
    [anon_sym_Enumextension] = ACTIONS(5176),
    [anon_sym_EnumExtension] = ACTIONS(5176),
    [anon_sym_enumExtension] = ACTIONS(5176),
    [sym_interface_keyword] = ACTIONS(5176),
    [anon_sym_controladdin] = ACTIONS(5176),
    [anon_sym_CONTROLADDIN] = ACTIONS(5176),
    [anon_sym_Controladdin] = ACTIONS(5176),
    [anon_sym_ControlAddIn] = ACTIONS(5176),
    [anon_sym_ControlAddin] = ACTIONS(5176),
    [anon_sym_controlAddIn] = ACTIONS(5176),
    [anon_sym_controlAddin] = ACTIONS(5176),
    [anon_sym_dotnet] = ACTIONS(5176),
    [anon_sym_DOTNET] = ACTIONS(5176),
    [anon_sym_Dotnet] = ACTIONS(5176),
    [anon_sym_DotNet] = ACTIONS(5176),
    [anon_sym_dotNet] = ACTIONS(5176),
    [sym_profile_keyword] = ACTIONS(5178),
    [anon_sym_profileextension] = ACTIONS(5176),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5176),
    [anon_sym_Profileextension] = ACTIONS(5176),
    [anon_sym_ProfileExtension] = ACTIONS(5176),
    [anon_sym_profileExtension] = ACTIONS(5176),
    [anon_sym_permissionset] = ACTIONS(5178),
    [anon_sym_PERMISSIONSET] = ACTIONS(5178),
    [anon_sym_Permissionset] = ACTIONS(5178),
    [anon_sym_PermissionSet] = ACTIONS(5178),
    [anon_sym_permissionSet] = ACTIONS(5178),
    [anon_sym_permissionsetextension] = ACTIONS(5176),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5176),
    [anon_sym_Permissionsetextension] = ACTIONS(5176),
    [anon_sym_PermissionSetExtension] = ACTIONS(5176),
    [anon_sym_permissionSetExtension] = ACTIONS(5176),
    [sym_entitlement_keyword] = ACTIONS(5176),
    [anon_sym_pagecustomization] = ACTIONS(5176),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5176),
    [anon_sym_Pagecustomization] = ACTIONS(5176),
    [anon_sym_PageCustomization] = ACTIONS(5176),
    [anon_sym_pageCustomization] = ACTIONS(5176),
    [sym_using_keyword] = ACTIONS(5176),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5176),
  },
  [STATE(2487)] = {
    [ts_builtin_sym_end] = ACTIONS(5180),
    [anon_sym_POUNDif] = ACTIONS(5180),
    [anon_sym_POUNDIF] = ACTIONS(5180),
    [anon_sym_POUNDIf] = ACTIONS(5180),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5182),
    [anon_sym_tableextension] = ACTIONS(5180),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5180),
    [anon_sym_Tableextension] = ACTIONS(5180),
    [anon_sym_TableExtension] = ACTIONS(5180),
    [anon_sym_tableExtension] = ACTIONS(5180),
    [sym_page_keyword] = ACTIONS(5182),
    [anon_sym_pageextension] = ACTIONS(5180),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5180),
    [anon_sym_Pageextension] = ACTIONS(5180),
    [anon_sym_PageExtension] = ACTIONS(5180),
    [anon_sym_pageExtension] = ACTIONS(5180),
    [anon_sym_codeunit] = ACTIONS(5180),
    [anon_sym_CODEUNIT] = ACTIONS(5180),
    [anon_sym_Codeunit] = ACTIONS(5180),
    [anon_sym_CodeUnit] = ACTIONS(5180),
    [anon_sym_COdeunit] = ACTIONS(5180),
    [anon_sym_codeUnit] = ACTIONS(5180),
    [sym_report_keyword] = ACTIONS(5182),
    [anon_sym_reportextension] = ACTIONS(5180),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5180),
    [anon_sym_Reportextension] = ACTIONS(5180),
    [anon_sym_ReportExtension] = ACTIONS(5180),
    [anon_sym_reportExtension] = ACTIONS(5180),
    [sym_query_keyword] = ACTIONS(5180),
    [anon_sym_xmlport] = ACTIONS(5180),
    [anon_sym_XMLPORT] = ACTIONS(5180),
    [anon_sym_Xmlport] = ACTIONS(5180),
    [anon_sym_XMLport] = ACTIONS(5180),
    [anon_sym_XMLPort] = ACTIONS(5180),
    [anon_sym_XmlPort] = ACTIONS(5180),
    [anon_sym_enum] = ACTIONS(5182),
    [anon_sym_ENUM] = ACTIONS(5182),
    [anon_sym_Enum] = ACTIONS(5182),
    [anon_sym_eNUM] = ACTIONS(5180),
    [anon_sym_eNum] = ACTIONS(5180),
    [anon_sym_ENum] = ACTIONS(5180),
    [anon_sym_enumextension] = ACTIONS(5180),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5180),
    [anon_sym_Enumextension] = ACTIONS(5180),
    [anon_sym_EnumExtension] = ACTIONS(5180),
    [anon_sym_enumExtension] = ACTIONS(5180),
    [sym_interface_keyword] = ACTIONS(5180),
    [anon_sym_controladdin] = ACTIONS(5180),
    [anon_sym_CONTROLADDIN] = ACTIONS(5180),
    [anon_sym_Controladdin] = ACTIONS(5180),
    [anon_sym_ControlAddIn] = ACTIONS(5180),
    [anon_sym_ControlAddin] = ACTIONS(5180),
    [anon_sym_controlAddIn] = ACTIONS(5180),
    [anon_sym_controlAddin] = ACTIONS(5180),
    [anon_sym_dotnet] = ACTIONS(5180),
    [anon_sym_DOTNET] = ACTIONS(5180),
    [anon_sym_Dotnet] = ACTIONS(5180),
    [anon_sym_DotNet] = ACTIONS(5180),
    [anon_sym_dotNet] = ACTIONS(5180),
    [sym_profile_keyword] = ACTIONS(5182),
    [anon_sym_profileextension] = ACTIONS(5180),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5180),
    [anon_sym_Profileextension] = ACTIONS(5180),
    [anon_sym_ProfileExtension] = ACTIONS(5180),
    [anon_sym_profileExtension] = ACTIONS(5180),
    [anon_sym_permissionset] = ACTIONS(5182),
    [anon_sym_PERMISSIONSET] = ACTIONS(5182),
    [anon_sym_Permissionset] = ACTIONS(5182),
    [anon_sym_PermissionSet] = ACTIONS(5182),
    [anon_sym_permissionSet] = ACTIONS(5182),
    [anon_sym_permissionsetextension] = ACTIONS(5180),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5180),
    [anon_sym_Permissionsetextension] = ACTIONS(5180),
    [anon_sym_PermissionSetExtension] = ACTIONS(5180),
    [anon_sym_permissionSetExtension] = ACTIONS(5180),
    [sym_entitlement_keyword] = ACTIONS(5180),
    [anon_sym_pagecustomization] = ACTIONS(5180),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5180),
    [anon_sym_Pagecustomization] = ACTIONS(5180),
    [anon_sym_PageCustomization] = ACTIONS(5180),
    [anon_sym_pageCustomization] = ACTIONS(5180),
    [sym_using_keyword] = ACTIONS(5180),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5180),
  },
  [STATE(2488)] = {
    [ts_builtin_sym_end] = ACTIONS(5184),
    [anon_sym_POUNDif] = ACTIONS(5184),
    [anon_sym_POUNDIF] = ACTIONS(5184),
    [anon_sym_POUNDIf] = ACTIONS(5184),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5186),
    [anon_sym_tableextension] = ACTIONS(5184),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5184),
    [anon_sym_Tableextension] = ACTIONS(5184),
    [anon_sym_TableExtension] = ACTIONS(5184),
    [anon_sym_tableExtension] = ACTIONS(5184),
    [sym_page_keyword] = ACTIONS(5186),
    [anon_sym_pageextension] = ACTIONS(5184),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5184),
    [anon_sym_Pageextension] = ACTIONS(5184),
    [anon_sym_PageExtension] = ACTIONS(5184),
    [anon_sym_pageExtension] = ACTIONS(5184),
    [anon_sym_codeunit] = ACTIONS(5184),
    [anon_sym_CODEUNIT] = ACTIONS(5184),
    [anon_sym_Codeunit] = ACTIONS(5184),
    [anon_sym_CodeUnit] = ACTIONS(5184),
    [anon_sym_COdeunit] = ACTIONS(5184),
    [anon_sym_codeUnit] = ACTIONS(5184),
    [sym_report_keyword] = ACTIONS(5186),
    [anon_sym_reportextension] = ACTIONS(5184),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5184),
    [anon_sym_Reportextension] = ACTIONS(5184),
    [anon_sym_ReportExtension] = ACTIONS(5184),
    [anon_sym_reportExtension] = ACTIONS(5184),
    [sym_query_keyword] = ACTIONS(5184),
    [anon_sym_xmlport] = ACTIONS(5184),
    [anon_sym_XMLPORT] = ACTIONS(5184),
    [anon_sym_Xmlport] = ACTIONS(5184),
    [anon_sym_XMLport] = ACTIONS(5184),
    [anon_sym_XMLPort] = ACTIONS(5184),
    [anon_sym_XmlPort] = ACTIONS(5184),
    [anon_sym_enum] = ACTIONS(5186),
    [anon_sym_ENUM] = ACTIONS(5186),
    [anon_sym_Enum] = ACTIONS(5186),
    [anon_sym_eNUM] = ACTIONS(5184),
    [anon_sym_eNum] = ACTIONS(5184),
    [anon_sym_ENum] = ACTIONS(5184),
    [anon_sym_enumextension] = ACTIONS(5184),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5184),
    [anon_sym_Enumextension] = ACTIONS(5184),
    [anon_sym_EnumExtension] = ACTIONS(5184),
    [anon_sym_enumExtension] = ACTIONS(5184),
    [sym_interface_keyword] = ACTIONS(5184),
    [anon_sym_controladdin] = ACTIONS(5184),
    [anon_sym_CONTROLADDIN] = ACTIONS(5184),
    [anon_sym_Controladdin] = ACTIONS(5184),
    [anon_sym_ControlAddIn] = ACTIONS(5184),
    [anon_sym_ControlAddin] = ACTIONS(5184),
    [anon_sym_controlAddIn] = ACTIONS(5184),
    [anon_sym_controlAddin] = ACTIONS(5184),
    [anon_sym_dotnet] = ACTIONS(5184),
    [anon_sym_DOTNET] = ACTIONS(5184),
    [anon_sym_Dotnet] = ACTIONS(5184),
    [anon_sym_DotNet] = ACTIONS(5184),
    [anon_sym_dotNet] = ACTIONS(5184),
    [sym_profile_keyword] = ACTIONS(5186),
    [anon_sym_profileextension] = ACTIONS(5184),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5184),
    [anon_sym_Profileextension] = ACTIONS(5184),
    [anon_sym_ProfileExtension] = ACTIONS(5184),
    [anon_sym_profileExtension] = ACTIONS(5184),
    [anon_sym_permissionset] = ACTIONS(5186),
    [anon_sym_PERMISSIONSET] = ACTIONS(5186),
    [anon_sym_Permissionset] = ACTIONS(5186),
    [anon_sym_PermissionSet] = ACTIONS(5186),
    [anon_sym_permissionSet] = ACTIONS(5186),
    [anon_sym_permissionsetextension] = ACTIONS(5184),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5184),
    [anon_sym_Permissionsetextension] = ACTIONS(5184),
    [anon_sym_PermissionSetExtension] = ACTIONS(5184),
    [anon_sym_permissionSetExtension] = ACTIONS(5184),
    [sym_entitlement_keyword] = ACTIONS(5184),
    [anon_sym_pagecustomization] = ACTIONS(5184),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5184),
    [anon_sym_Pagecustomization] = ACTIONS(5184),
    [anon_sym_PageCustomization] = ACTIONS(5184),
    [anon_sym_pageCustomization] = ACTIONS(5184),
    [sym_using_keyword] = ACTIONS(5184),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5184),
  },
  [STATE(2489)] = {
    [ts_builtin_sym_end] = ACTIONS(5188),
    [anon_sym_POUNDif] = ACTIONS(5188),
    [anon_sym_POUNDIF] = ACTIONS(5188),
    [anon_sym_POUNDIf] = ACTIONS(5188),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5190),
    [anon_sym_tableextension] = ACTIONS(5188),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5188),
    [anon_sym_Tableextension] = ACTIONS(5188),
    [anon_sym_TableExtension] = ACTIONS(5188),
    [anon_sym_tableExtension] = ACTIONS(5188),
    [sym_page_keyword] = ACTIONS(5190),
    [anon_sym_pageextension] = ACTIONS(5188),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5188),
    [anon_sym_Pageextension] = ACTIONS(5188),
    [anon_sym_PageExtension] = ACTIONS(5188),
    [anon_sym_pageExtension] = ACTIONS(5188),
    [anon_sym_codeunit] = ACTIONS(5188),
    [anon_sym_CODEUNIT] = ACTIONS(5188),
    [anon_sym_Codeunit] = ACTIONS(5188),
    [anon_sym_CodeUnit] = ACTIONS(5188),
    [anon_sym_COdeunit] = ACTIONS(5188),
    [anon_sym_codeUnit] = ACTIONS(5188),
    [sym_report_keyword] = ACTIONS(5190),
    [anon_sym_reportextension] = ACTIONS(5188),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5188),
    [anon_sym_Reportextension] = ACTIONS(5188),
    [anon_sym_ReportExtension] = ACTIONS(5188),
    [anon_sym_reportExtension] = ACTIONS(5188),
    [sym_query_keyword] = ACTIONS(5188),
    [anon_sym_xmlport] = ACTIONS(5188),
    [anon_sym_XMLPORT] = ACTIONS(5188),
    [anon_sym_Xmlport] = ACTIONS(5188),
    [anon_sym_XMLport] = ACTIONS(5188),
    [anon_sym_XMLPort] = ACTIONS(5188),
    [anon_sym_XmlPort] = ACTIONS(5188),
    [anon_sym_enum] = ACTIONS(5190),
    [anon_sym_ENUM] = ACTIONS(5190),
    [anon_sym_Enum] = ACTIONS(5190),
    [anon_sym_eNUM] = ACTIONS(5188),
    [anon_sym_eNum] = ACTIONS(5188),
    [anon_sym_ENum] = ACTIONS(5188),
    [anon_sym_enumextension] = ACTIONS(5188),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5188),
    [anon_sym_Enumextension] = ACTIONS(5188),
    [anon_sym_EnumExtension] = ACTIONS(5188),
    [anon_sym_enumExtension] = ACTIONS(5188),
    [sym_interface_keyword] = ACTIONS(5188),
    [anon_sym_controladdin] = ACTIONS(5188),
    [anon_sym_CONTROLADDIN] = ACTIONS(5188),
    [anon_sym_Controladdin] = ACTIONS(5188),
    [anon_sym_ControlAddIn] = ACTIONS(5188),
    [anon_sym_ControlAddin] = ACTIONS(5188),
    [anon_sym_controlAddIn] = ACTIONS(5188),
    [anon_sym_controlAddin] = ACTIONS(5188),
    [anon_sym_dotnet] = ACTIONS(5188),
    [anon_sym_DOTNET] = ACTIONS(5188),
    [anon_sym_Dotnet] = ACTIONS(5188),
    [anon_sym_DotNet] = ACTIONS(5188),
    [anon_sym_dotNet] = ACTIONS(5188),
    [sym_profile_keyword] = ACTIONS(5190),
    [anon_sym_profileextension] = ACTIONS(5188),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5188),
    [anon_sym_Profileextension] = ACTIONS(5188),
    [anon_sym_ProfileExtension] = ACTIONS(5188),
    [anon_sym_profileExtension] = ACTIONS(5188),
    [anon_sym_permissionset] = ACTIONS(5190),
    [anon_sym_PERMISSIONSET] = ACTIONS(5190),
    [anon_sym_Permissionset] = ACTIONS(5190),
    [anon_sym_PermissionSet] = ACTIONS(5190),
    [anon_sym_permissionSet] = ACTIONS(5190),
    [anon_sym_permissionsetextension] = ACTIONS(5188),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5188),
    [anon_sym_Permissionsetextension] = ACTIONS(5188),
    [anon_sym_PermissionSetExtension] = ACTIONS(5188),
    [anon_sym_permissionSetExtension] = ACTIONS(5188),
    [sym_entitlement_keyword] = ACTIONS(5188),
    [anon_sym_pagecustomization] = ACTIONS(5188),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5188),
    [anon_sym_Pagecustomization] = ACTIONS(5188),
    [anon_sym_PageCustomization] = ACTIONS(5188),
    [anon_sym_pageCustomization] = ACTIONS(5188),
    [sym_using_keyword] = ACTIONS(5188),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5188),
  },
  [STATE(2490)] = {
    [ts_builtin_sym_end] = ACTIONS(5192),
    [anon_sym_POUNDif] = ACTIONS(5192),
    [anon_sym_POUNDIF] = ACTIONS(5192),
    [anon_sym_POUNDIf] = ACTIONS(5192),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5194),
    [anon_sym_tableextension] = ACTIONS(5192),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5192),
    [anon_sym_Tableextension] = ACTIONS(5192),
    [anon_sym_TableExtension] = ACTIONS(5192),
    [anon_sym_tableExtension] = ACTIONS(5192),
    [sym_page_keyword] = ACTIONS(5194),
    [anon_sym_pageextension] = ACTIONS(5192),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5192),
    [anon_sym_Pageextension] = ACTIONS(5192),
    [anon_sym_PageExtension] = ACTIONS(5192),
    [anon_sym_pageExtension] = ACTIONS(5192),
    [anon_sym_codeunit] = ACTIONS(5192),
    [anon_sym_CODEUNIT] = ACTIONS(5192),
    [anon_sym_Codeunit] = ACTIONS(5192),
    [anon_sym_CodeUnit] = ACTIONS(5192),
    [anon_sym_COdeunit] = ACTIONS(5192),
    [anon_sym_codeUnit] = ACTIONS(5192),
    [sym_report_keyword] = ACTIONS(5194),
    [anon_sym_reportextension] = ACTIONS(5192),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5192),
    [anon_sym_Reportextension] = ACTIONS(5192),
    [anon_sym_ReportExtension] = ACTIONS(5192),
    [anon_sym_reportExtension] = ACTIONS(5192),
    [sym_query_keyword] = ACTIONS(5192),
    [anon_sym_xmlport] = ACTIONS(5192),
    [anon_sym_XMLPORT] = ACTIONS(5192),
    [anon_sym_Xmlport] = ACTIONS(5192),
    [anon_sym_XMLport] = ACTIONS(5192),
    [anon_sym_XMLPort] = ACTIONS(5192),
    [anon_sym_XmlPort] = ACTIONS(5192),
    [anon_sym_enum] = ACTIONS(5194),
    [anon_sym_ENUM] = ACTIONS(5194),
    [anon_sym_Enum] = ACTIONS(5194),
    [anon_sym_eNUM] = ACTIONS(5192),
    [anon_sym_eNum] = ACTIONS(5192),
    [anon_sym_ENum] = ACTIONS(5192),
    [anon_sym_enumextension] = ACTIONS(5192),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5192),
    [anon_sym_Enumextension] = ACTIONS(5192),
    [anon_sym_EnumExtension] = ACTIONS(5192),
    [anon_sym_enumExtension] = ACTIONS(5192),
    [sym_interface_keyword] = ACTIONS(5192),
    [anon_sym_controladdin] = ACTIONS(5192),
    [anon_sym_CONTROLADDIN] = ACTIONS(5192),
    [anon_sym_Controladdin] = ACTIONS(5192),
    [anon_sym_ControlAddIn] = ACTIONS(5192),
    [anon_sym_ControlAddin] = ACTIONS(5192),
    [anon_sym_controlAddIn] = ACTIONS(5192),
    [anon_sym_controlAddin] = ACTIONS(5192),
    [anon_sym_dotnet] = ACTIONS(5192),
    [anon_sym_DOTNET] = ACTIONS(5192),
    [anon_sym_Dotnet] = ACTIONS(5192),
    [anon_sym_DotNet] = ACTIONS(5192),
    [anon_sym_dotNet] = ACTIONS(5192),
    [sym_profile_keyword] = ACTIONS(5194),
    [anon_sym_profileextension] = ACTIONS(5192),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5192),
    [anon_sym_Profileextension] = ACTIONS(5192),
    [anon_sym_ProfileExtension] = ACTIONS(5192),
    [anon_sym_profileExtension] = ACTIONS(5192),
    [anon_sym_permissionset] = ACTIONS(5194),
    [anon_sym_PERMISSIONSET] = ACTIONS(5194),
    [anon_sym_Permissionset] = ACTIONS(5194),
    [anon_sym_PermissionSet] = ACTIONS(5194),
    [anon_sym_permissionSet] = ACTIONS(5194),
    [anon_sym_permissionsetextension] = ACTIONS(5192),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5192),
    [anon_sym_Permissionsetextension] = ACTIONS(5192),
    [anon_sym_PermissionSetExtension] = ACTIONS(5192),
    [anon_sym_permissionSetExtension] = ACTIONS(5192),
    [sym_entitlement_keyword] = ACTIONS(5192),
    [anon_sym_pagecustomization] = ACTIONS(5192),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5192),
    [anon_sym_Pagecustomization] = ACTIONS(5192),
    [anon_sym_PageCustomization] = ACTIONS(5192),
    [anon_sym_pageCustomization] = ACTIONS(5192),
    [sym_using_keyword] = ACTIONS(5192),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5192),
  },
  [STATE(2491)] = {
    [ts_builtin_sym_end] = ACTIONS(5196),
    [anon_sym_POUNDif] = ACTIONS(5196),
    [anon_sym_POUNDIF] = ACTIONS(5196),
    [anon_sym_POUNDIf] = ACTIONS(5196),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5198),
    [anon_sym_tableextension] = ACTIONS(5196),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5196),
    [anon_sym_Tableextension] = ACTIONS(5196),
    [anon_sym_TableExtension] = ACTIONS(5196),
    [anon_sym_tableExtension] = ACTIONS(5196),
    [sym_page_keyword] = ACTIONS(5198),
    [anon_sym_pageextension] = ACTIONS(5196),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5196),
    [anon_sym_Pageextension] = ACTIONS(5196),
    [anon_sym_PageExtension] = ACTIONS(5196),
    [anon_sym_pageExtension] = ACTIONS(5196),
    [anon_sym_codeunit] = ACTIONS(5196),
    [anon_sym_CODEUNIT] = ACTIONS(5196),
    [anon_sym_Codeunit] = ACTIONS(5196),
    [anon_sym_CodeUnit] = ACTIONS(5196),
    [anon_sym_COdeunit] = ACTIONS(5196),
    [anon_sym_codeUnit] = ACTIONS(5196),
    [sym_report_keyword] = ACTIONS(5198),
    [anon_sym_reportextension] = ACTIONS(5196),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5196),
    [anon_sym_Reportextension] = ACTIONS(5196),
    [anon_sym_ReportExtension] = ACTIONS(5196),
    [anon_sym_reportExtension] = ACTIONS(5196),
    [sym_query_keyword] = ACTIONS(5196),
    [anon_sym_xmlport] = ACTIONS(5196),
    [anon_sym_XMLPORT] = ACTIONS(5196),
    [anon_sym_Xmlport] = ACTIONS(5196),
    [anon_sym_XMLport] = ACTIONS(5196),
    [anon_sym_XMLPort] = ACTIONS(5196),
    [anon_sym_XmlPort] = ACTIONS(5196),
    [anon_sym_enum] = ACTIONS(5198),
    [anon_sym_ENUM] = ACTIONS(5198),
    [anon_sym_Enum] = ACTIONS(5198),
    [anon_sym_eNUM] = ACTIONS(5196),
    [anon_sym_eNum] = ACTIONS(5196),
    [anon_sym_ENum] = ACTIONS(5196),
    [anon_sym_enumextension] = ACTIONS(5196),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5196),
    [anon_sym_Enumextension] = ACTIONS(5196),
    [anon_sym_EnumExtension] = ACTIONS(5196),
    [anon_sym_enumExtension] = ACTIONS(5196),
    [sym_interface_keyword] = ACTIONS(5196),
    [anon_sym_controladdin] = ACTIONS(5196),
    [anon_sym_CONTROLADDIN] = ACTIONS(5196),
    [anon_sym_Controladdin] = ACTIONS(5196),
    [anon_sym_ControlAddIn] = ACTIONS(5196),
    [anon_sym_ControlAddin] = ACTIONS(5196),
    [anon_sym_controlAddIn] = ACTIONS(5196),
    [anon_sym_controlAddin] = ACTIONS(5196),
    [anon_sym_dotnet] = ACTIONS(5196),
    [anon_sym_DOTNET] = ACTIONS(5196),
    [anon_sym_Dotnet] = ACTIONS(5196),
    [anon_sym_DotNet] = ACTIONS(5196),
    [anon_sym_dotNet] = ACTIONS(5196),
    [sym_profile_keyword] = ACTIONS(5198),
    [anon_sym_profileextension] = ACTIONS(5196),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5196),
    [anon_sym_Profileextension] = ACTIONS(5196),
    [anon_sym_ProfileExtension] = ACTIONS(5196),
    [anon_sym_profileExtension] = ACTIONS(5196),
    [anon_sym_permissionset] = ACTIONS(5198),
    [anon_sym_PERMISSIONSET] = ACTIONS(5198),
    [anon_sym_Permissionset] = ACTIONS(5198),
    [anon_sym_PermissionSet] = ACTIONS(5198),
    [anon_sym_permissionSet] = ACTIONS(5198),
    [anon_sym_permissionsetextension] = ACTIONS(5196),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5196),
    [anon_sym_Permissionsetextension] = ACTIONS(5196),
    [anon_sym_PermissionSetExtension] = ACTIONS(5196),
    [anon_sym_permissionSetExtension] = ACTIONS(5196),
    [sym_entitlement_keyword] = ACTIONS(5196),
    [anon_sym_pagecustomization] = ACTIONS(5196),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5196),
    [anon_sym_Pagecustomization] = ACTIONS(5196),
    [anon_sym_PageCustomization] = ACTIONS(5196),
    [anon_sym_pageCustomization] = ACTIONS(5196),
    [sym_using_keyword] = ACTIONS(5196),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5196),
  },
  [STATE(2492)] = {
    [ts_builtin_sym_end] = ACTIONS(5200),
    [anon_sym_POUNDif] = ACTIONS(5200),
    [anon_sym_POUNDIF] = ACTIONS(5200),
    [anon_sym_POUNDIf] = ACTIONS(5200),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5202),
    [anon_sym_tableextension] = ACTIONS(5200),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5200),
    [anon_sym_Tableextension] = ACTIONS(5200),
    [anon_sym_TableExtension] = ACTIONS(5200),
    [anon_sym_tableExtension] = ACTIONS(5200),
    [sym_page_keyword] = ACTIONS(5202),
    [anon_sym_pageextension] = ACTIONS(5200),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5200),
    [anon_sym_Pageextension] = ACTIONS(5200),
    [anon_sym_PageExtension] = ACTIONS(5200),
    [anon_sym_pageExtension] = ACTIONS(5200),
    [anon_sym_codeunit] = ACTIONS(5200),
    [anon_sym_CODEUNIT] = ACTIONS(5200),
    [anon_sym_Codeunit] = ACTIONS(5200),
    [anon_sym_CodeUnit] = ACTIONS(5200),
    [anon_sym_COdeunit] = ACTIONS(5200),
    [anon_sym_codeUnit] = ACTIONS(5200),
    [sym_report_keyword] = ACTIONS(5202),
    [anon_sym_reportextension] = ACTIONS(5200),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5200),
    [anon_sym_Reportextension] = ACTIONS(5200),
    [anon_sym_ReportExtension] = ACTIONS(5200),
    [anon_sym_reportExtension] = ACTIONS(5200),
    [sym_query_keyword] = ACTIONS(5200),
    [anon_sym_xmlport] = ACTIONS(5200),
    [anon_sym_XMLPORT] = ACTIONS(5200),
    [anon_sym_Xmlport] = ACTIONS(5200),
    [anon_sym_XMLport] = ACTIONS(5200),
    [anon_sym_XMLPort] = ACTIONS(5200),
    [anon_sym_XmlPort] = ACTIONS(5200),
    [anon_sym_enum] = ACTIONS(5202),
    [anon_sym_ENUM] = ACTIONS(5202),
    [anon_sym_Enum] = ACTIONS(5202),
    [anon_sym_eNUM] = ACTIONS(5200),
    [anon_sym_eNum] = ACTIONS(5200),
    [anon_sym_ENum] = ACTIONS(5200),
    [anon_sym_enumextension] = ACTIONS(5200),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5200),
    [anon_sym_Enumextension] = ACTIONS(5200),
    [anon_sym_EnumExtension] = ACTIONS(5200),
    [anon_sym_enumExtension] = ACTIONS(5200),
    [sym_interface_keyword] = ACTIONS(5200),
    [anon_sym_controladdin] = ACTIONS(5200),
    [anon_sym_CONTROLADDIN] = ACTIONS(5200),
    [anon_sym_Controladdin] = ACTIONS(5200),
    [anon_sym_ControlAddIn] = ACTIONS(5200),
    [anon_sym_ControlAddin] = ACTIONS(5200),
    [anon_sym_controlAddIn] = ACTIONS(5200),
    [anon_sym_controlAddin] = ACTIONS(5200),
    [anon_sym_dotnet] = ACTIONS(5200),
    [anon_sym_DOTNET] = ACTIONS(5200),
    [anon_sym_Dotnet] = ACTIONS(5200),
    [anon_sym_DotNet] = ACTIONS(5200),
    [anon_sym_dotNet] = ACTIONS(5200),
    [sym_profile_keyword] = ACTIONS(5202),
    [anon_sym_profileextension] = ACTIONS(5200),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5200),
    [anon_sym_Profileextension] = ACTIONS(5200),
    [anon_sym_ProfileExtension] = ACTIONS(5200),
    [anon_sym_profileExtension] = ACTIONS(5200),
    [anon_sym_permissionset] = ACTIONS(5202),
    [anon_sym_PERMISSIONSET] = ACTIONS(5202),
    [anon_sym_Permissionset] = ACTIONS(5202),
    [anon_sym_PermissionSet] = ACTIONS(5202),
    [anon_sym_permissionSet] = ACTIONS(5202),
    [anon_sym_permissionsetextension] = ACTIONS(5200),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5200),
    [anon_sym_Permissionsetextension] = ACTIONS(5200),
    [anon_sym_PermissionSetExtension] = ACTIONS(5200),
    [anon_sym_permissionSetExtension] = ACTIONS(5200),
    [sym_entitlement_keyword] = ACTIONS(5200),
    [anon_sym_pagecustomization] = ACTIONS(5200),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5200),
    [anon_sym_Pagecustomization] = ACTIONS(5200),
    [anon_sym_PageCustomization] = ACTIONS(5200),
    [anon_sym_pageCustomization] = ACTIONS(5200),
    [sym_using_keyword] = ACTIONS(5200),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5200),
  },
  [STATE(2493)] = {
    [ts_builtin_sym_end] = ACTIONS(5013),
    [anon_sym_POUNDif] = ACTIONS(5013),
    [anon_sym_POUNDIF] = ACTIONS(5013),
    [anon_sym_POUNDIf] = ACTIONS(5013),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5015),
    [anon_sym_tableextension] = ACTIONS(5013),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5013),
    [anon_sym_Tableextension] = ACTIONS(5013),
    [anon_sym_TableExtension] = ACTIONS(5013),
    [anon_sym_tableExtension] = ACTIONS(5013),
    [sym_page_keyword] = ACTIONS(5015),
    [anon_sym_pageextension] = ACTIONS(5013),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5013),
    [anon_sym_Pageextension] = ACTIONS(5013),
    [anon_sym_PageExtension] = ACTIONS(5013),
    [anon_sym_pageExtension] = ACTIONS(5013),
    [anon_sym_codeunit] = ACTIONS(5013),
    [anon_sym_CODEUNIT] = ACTIONS(5013),
    [anon_sym_Codeunit] = ACTIONS(5013),
    [anon_sym_CodeUnit] = ACTIONS(5013),
    [anon_sym_COdeunit] = ACTIONS(5013),
    [anon_sym_codeUnit] = ACTIONS(5013),
    [sym_report_keyword] = ACTIONS(5015),
    [anon_sym_reportextension] = ACTIONS(5013),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5013),
    [anon_sym_Reportextension] = ACTIONS(5013),
    [anon_sym_ReportExtension] = ACTIONS(5013),
    [anon_sym_reportExtension] = ACTIONS(5013),
    [sym_query_keyword] = ACTIONS(5013),
    [anon_sym_xmlport] = ACTIONS(5013),
    [anon_sym_XMLPORT] = ACTIONS(5013),
    [anon_sym_Xmlport] = ACTIONS(5013),
    [anon_sym_XMLport] = ACTIONS(5013),
    [anon_sym_XMLPort] = ACTIONS(5013),
    [anon_sym_XmlPort] = ACTIONS(5013),
    [anon_sym_enum] = ACTIONS(5015),
    [anon_sym_ENUM] = ACTIONS(5015),
    [anon_sym_Enum] = ACTIONS(5015),
    [anon_sym_eNUM] = ACTIONS(5013),
    [anon_sym_eNum] = ACTIONS(5013),
    [anon_sym_ENum] = ACTIONS(5013),
    [anon_sym_enumextension] = ACTIONS(5013),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5013),
    [anon_sym_Enumextension] = ACTIONS(5013),
    [anon_sym_EnumExtension] = ACTIONS(5013),
    [anon_sym_enumExtension] = ACTIONS(5013),
    [sym_interface_keyword] = ACTIONS(5013),
    [anon_sym_controladdin] = ACTIONS(5013),
    [anon_sym_CONTROLADDIN] = ACTIONS(5013),
    [anon_sym_Controladdin] = ACTIONS(5013),
    [anon_sym_ControlAddIn] = ACTIONS(5013),
    [anon_sym_ControlAddin] = ACTIONS(5013),
    [anon_sym_controlAddIn] = ACTIONS(5013),
    [anon_sym_controlAddin] = ACTIONS(5013),
    [anon_sym_dotnet] = ACTIONS(5013),
    [anon_sym_DOTNET] = ACTIONS(5013),
    [anon_sym_Dotnet] = ACTIONS(5013),
    [anon_sym_DotNet] = ACTIONS(5013),
    [anon_sym_dotNet] = ACTIONS(5013),
    [sym_profile_keyword] = ACTIONS(5015),
    [anon_sym_profileextension] = ACTIONS(5013),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5013),
    [anon_sym_Profileextension] = ACTIONS(5013),
    [anon_sym_ProfileExtension] = ACTIONS(5013),
    [anon_sym_profileExtension] = ACTIONS(5013),
    [anon_sym_permissionset] = ACTIONS(5015),
    [anon_sym_PERMISSIONSET] = ACTIONS(5015),
    [anon_sym_Permissionset] = ACTIONS(5015),
    [anon_sym_PermissionSet] = ACTIONS(5015),
    [anon_sym_permissionSet] = ACTIONS(5015),
    [anon_sym_permissionsetextension] = ACTIONS(5013),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5013),
    [anon_sym_Permissionsetextension] = ACTIONS(5013),
    [anon_sym_PermissionSetExtension] = ACTIONS(5013),
    [anon_sym_permissionSetExtension] = ACTIONS(5013),
    [sym_entitlement_keyword] = ACTIONS(5013),
    [anon_sym_pagecustomization] = ACTIONS(5013),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5013),
    [anon_sym_Pagecustomization] = ACTIONS(5013),
    [anon_sym_PageCustomization] = ACTIONS(5013),
    [anon_sym_pageCustomization] = ACTIONS(5013),
    [sym_using_keyword] = ACTIONS(5013),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5013),
  },
  [STATE(2494)] = {
    [sym__body_element] = STATE(5964),
    [sym_empty_statement] = STATE(5964),
    [sym_property] = STATE(5964),
    [sym_fields_section] = STATE(5964),
    [sym_keys_section] = STATE(5964),
    [sym_fieldgroups_section] = STATE(5964),
    [sym_enum_value_declaration] = STATE(5964),
    [sym_labels_section] = STATE(5964),
    [sym_layout_section] = STATE(5964),
    [sym_modify_modification] = STATE(5964),
    [sym_actions_section] = STATE(5964),
    [sym_views_section] = STATE(5964),
    [sym_dataset_section] = STATE(5964),
    [sym_requestpage_section] = STATE(5964),
    [sym_rendering_section] = STATE(5964),
    [sym_elements_section] = STATE(5964),
    [sym_query_dataitem] = STATE(2575),
    [sym__query_body_element] = STATE(2575),
    [sym_preproc_conditional_query] = STATE(2575),
    [sym_query_column] = STATE(2575),
    [sym_query_filter] = STATE(2575),
    [sym_schema_section] = STATE(5964),
    [sym_assembly_declaration] = STATE(5964),
    [sym_event_declaration] = STATE(5964),
    [sym_procedure] = STATE(5964),
    [sym_preproc_split_procedure] = STATE(5964),
    [sym__procedure_header] = STATE(8089),
    [sym_procedure_modifier] = STATE(12657),
    [sym_trigger_declaration] = STATE(5964),
    [sym_var_section] = STATE(5964),
    [sym_attribute_item] = STATE(3722),
    [sym_preproc_conditional] = STATE(5964),
    [sym_preproc_if] = STATE(2494),
    [sym_preproc_elif] = STATE(2656),
    [sym_preproc_else] = STATE(2745),
    [sym_preproc_endif] = STATE(5963),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(2755),
    [aux_sym_query_dataitem_repeat1] = STATE(2575),
    [aux_sym_preproc_conditional_query_repeat1] = STATE(7833),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_repeat1] = STATE(8159),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(2883),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(2495)] = {
    [ts_builtin_sym_end] = ACTIONS(4989),
    [anon_sym_POUNDif] = ACTIONS(4989),
    [anon_sym_POUNDIF] = ACTIONS(4989),
    [anon_sym_POUNDIf] = ACTIONS(4989),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4991),
    [anon_sym_tableextension] = ACTIONS(4989),
    [anon_sym_TABLEEXTENSION] = ACTIONS(4989),
    [anon_sym_Tableextension] = ACTIONS(4989),
    [anon_sym_TableExtension] = ACTIONS(4989),
    [anon_sym_tableExtension] = ACTIONS(4989),
    [sym_page_keyword] = ACTIONS(4991),
    [anon_sym_pageextension] = ACTIONS(4989),
    [anon_sym_PAGEEXTENSION] = ACTIONS(4989),
    [anon_sym_Pageextension] = ACTIONS(4989),
    [anon_sym_PageExtension] = ACTIONS(4989),
    [anon_sym_pageExtension] = ACTIONS(4989),
    [anon_sym_codeunit] = ACTIONS(4989),
    [anon_sym_CODEUNIT] = ACTIONS(4989),
    [anon_sym_Codeunit] = ACTIONS(4989),
    [anon_sym_CodeUnit] = ACTIONS(4989),
    [anon_sym_COdeunit] = ACTIONS(4989),
    [anon_sym_codeUnit] = ACTIONS(4989),
    [sym_report_keyword] = ACTIONS(4991),
    [anon_sym_reportextension] = ACTIONS(4989),
    [anon_sym_REPORTEXTENSION] = ACTIONS(4989),
    [anon_sym_Reportextension] = ACTIONS(4989),
    [anon_sym_ReportExtension] = ACTIONS(4989),
    [anon_sym_reportExtension] = ACTIONS(4989),
    [sym_query_keyword] = ACTIONS(4989),
    [anon_sym_xmlport] = ACTIONS(4989),
    [anon_sym_XMLPORT] = ACTIONS(4989),
    [anon_sym_Xmlport] = ACTIONS(4989),
    [anon_sym_XMLport] = ACTIONS(4989),
    [anon_sym_XMLPort] = ACTIONS(4989),
    [anon_sym_XmlPort] = ACTIONS(4989),
    [anon_sym_enum] = ACTIONS(4991),
    [anon_sym_ENUM] = ACTIONS(4991),
    [anon_sym_Enum] = ACTIONS(4991),
    [anon_sym_eNUM] = ACTIONS(4989),
    [anon_sym_eNum] = ACTIONS(4989),
    [anon_sym_ENum] = ACTIONS(4989),
    [anon_sym_enumextension] = ACTIONS(4989),
    [anon_sym_ENUMEXTENSION] = ACTIONS(4989),
    [anon_sym_Enumextension] = ACTIONS(4989),
    [anon_sym_EnumExtension] = ACTIONS(4989),
    [anon_sym_enumExtension] = ACTIONS(4989),
    [sym_interface_keyword] = ACTIONS(4989),
    [anon_sym_controladdin] = ACTIONS(4989),
    [anon_sym_CONTROLADDIN] = ACTIONS(4989),
    [anon_sym_Controladdin] = ACTIONS(4989),
    [anon_sym_ControlAddIn] = ACTIONS(4989),
    [anon_sym_ControlAddin] = ACTIONS(4989),
    [anon_sym_controlAddIn] = ACTIONS(4989),
    [anon_sym_controlAddin] = ACTIONS(4989),
    [anon_sym_dotnet] = ACTIONS(4989),
    [anon_sym_DOTNET] = ACTIONS(4989),
    [anon_sym_Dotnet] = ACTIONS(4989),
    [anon_sym_DotNet] = ACTIONS(4989),
    [anon_sym_dotNet] = ACTIONS(4989),
    [sym_profile_keyword] = ACTIONS(4991),
    [anon_sym_profileextension] = ACTIONS(4989),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(4989),
    [anon_sym_Profileextension] = ACTIONS(4989),
    [anon_sym_ProfileExtension] = ACTIONS(4989),
    [anon_sym_profileExtension] = ACTIONS(4989),
    [anon_sym_permissionset] = ACTIONS(4991),
    [anon_sym_PERMISSIONSET] = ACTIONS(4991),
    [anon_sym_Permissionset] = ACTIONS(4991),
    [anon_sym_PermissionSet] = ACTIONS(4991),
    [anon_sym_permissionSet] = ACTIONS(4991),
    [anon_sym_permissionsetextension] = ACTIONS(4989),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(4989),
    [anon_sym_Permissionsetextension] = ACTIONS(4989),
    [anon_sym_PermissionSetExtension] = ACTIONS(4989),
    [anon_sym_permissionSetExtension] = ACTIONS(4989),
    [sym_entitlement_keyword] = ACTIONS(4989),
    [anon_sym_pagecustomization] = ACTIONS(4989),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(4989),
    [anon_sym_Pagecustomization] = ACTIONS(4989),
    [anon_sym_PageCustomization] = ACTIONS(4989),
    [anon_sym_pageCustomization] = ACTIONS(4989),
    [sym_using_keyword] = ACTIONS(4989),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(4989),
  },
  [STATE(2496)] = {
    [ts_builtin_sym_end] = ACTIONS(5017),
    [anon_sym_POUNDif] = ACTIONS(5017),
    [anon_sym_POUNDIF] = ACTIONS(5017),
    [anon_sym_POUNDIf] = ACTIONS(5017),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5019),
    [anon_sym_tableextension] = ACTIONS(5017),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5017),
    [anon_sym_Tableextension] = ACTIONS(5017),
    [anon_sym_TableExtension] = ACTIONS(5017),
    [anon_sym_tableExtension] = ACTIONS(5017),
    [sym_page_keyword] = ACTIONS(5019),
    [anon_sym_pageextension] = ACTIONS(5017),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5017),
    [anon_sym_Pageextension] = ACTIONS(5017),
    [anon_sym_PageExtension] = ACTIONS(5017),
    [anon_sym_pageExtension] = ACTIONS(5017),
    [anon_sym_codeunit] = ACTIONS(5017),
    [anon_sym_CODEUNIT] = ACTIONS(5017),
    [anon_sym_Codeunit] = ACTIONS(5017),
    [anon_sym_CodeUnit] = ACTIONS(5017),
    [anon_sym_COdeunit] = ACTIONS(5017),
    [anon_sym_codeUnit] = ACTIONS(5017),
    [sym_report_keyword] = ACTIONS(5019),
    [anon_sym_reportextension] = ACTIONS(5017),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5017),
    [anon_sym_Reportextension] = ACTIONS(5017),
    [anon_sym_ReportExtension] = ACTIONS(5017),
    [anon_sym_reportExtension] = ACTIONS(5017),
    [sym_query_keyword] = ACTIONS(5017),
    [anon_sym_xmlport] = ACTIONS(5017),
    [anon_sym_XMLPORT] = ACTIONS(5017),
    [anon_sym_Xmlport] = ACTIONS(5017),
    [anon_sym_XMLport] = ACTIONS(5017),
    [anon_sym_XMLPort] = ACTIONS(5017),
    [anon_sym_XmlPort] = ACTIONS(5017),
    [anon_sym_enum] = ACTIONS(5019),
    [anon_sym_ENUM] = ACTIONS(5019),
    [anon_sym_Enum] = ACTIONS(5019),
    [anon_sym_eNUM] = ACTIONS(5017),
    [anon_sym_eNum] = ACTIONS(5017),
    [anon_sym_ENum] = ACTIONS(5017),
    [anon_sym_enumextension] = ACTIONS(5017),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5017),
    [anon_sym_Enumextension] = ACTIONS(5017),
    [anon_sym_EnumExtension] = ACTIONS(5017),
    [anon_sym_enumExtension] = ACTIONS(5017),
    [sym_interface_keyword] = ACTIONS(5017),
    [anon_sym_controladdin] = ACTIONS(5017),
    [anon_sym_CONTROLADDIN] = ACTIONS(5017),
    [anon_sym_Controladdin] = ACTIONS(5017),
    [anon_sym_ControlAddIn] = ACTIONS(5017),
    [anon_sym_ControlAddin] = ACTIONS(5017),
    [anon_sym_controlAddIn] = ACTIONS(5017),
    [anon_sym_controlAddin] = ACTIONS(5017),
    [anon_sym_dotnet] = ACTIONS(5017),
    [anon_sym_DOTNET] = ACTIONS(5017),
    [anon_sym_Dotnet] = ACTIONS(5017),
    [anon_sym_DotNet] = ACTIONS(5017),
    [anon_sym_dotNet] = ACTIONS(5017),
    [sym_profile_keyword] = ACTIONS(5019),
    [anon_sym_profileextension] = ACTIONS(5017),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5017),
    [anon_sym_Profileextension] = ACTIONS(5017),
    [anon_sym_ProfileExtension] = ACTIONS(5017),
    [anon_sym_profileExtension] = ACTIONS(5017),
    [anon_sym_permissionset] = ACTIONS(5019),
    [anon_sym_PERMISSIONSET] = ACTIONS(5019),
    [anon_sym_Permissionset] = ACTIONS(5019),
    [anon_sym_PermissionSet] = ACTIONS(5019),
    [anon_sym_permissionSet] = ACTIONS(5019),
    [anon_sym_permissionsetextension] = ACTIONS(5017),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5017),
    [anon_sym_Permissionsetextension] = ACTIONS(5017),
    [anon_sym_PermissionSetExtension] = ACTIONS(5017),
    [anon_sym_permissionSetExtension] = ACTIONS(5017),
    [sym_entitlement_keyword] = ACTIONS(5017),
    [anon_sym_pagecustomization] = ACTIONS(5017),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5017),
    [anon_sym_Pagecustomization] = ACTIONS(5017),
    [anon_sym_PageCustomization] = ACTIONS(5017),
    [anon_sym_pageCustomization] = ACTIONS(5017),
    [sym_using_keyword] = ACTIONS(5017),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5017),
  },
  [STATE(2497)] = {
    [ts_builtin_sym_end] = ACTIONS(4993),
    [anon_sym_POUNDif] = ACTIONS(4993),
    [anon_sym_POUNDIF] = ACTIONS(4993),
    [anon_sym_POUNDIf] = ACTIONS(4993),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4995),
    [anon_sym_tableextension] = ACTIONS(4993),
    [anon_sym_TABLEEXTENSION] = ACTIONS(4993),
    [anon_sym_Tableextension] = ACTIONS(4993),
    [anon_sym_TableExtension] = ACTIONS(4993),
    [anon_sym_tableExtension] = ACTIONS(4993),
    [sym_page_keyword] = ACTIONS(4995),
    [anon_sym_pageextension] = ACTIONS(4993),
    [anon_sym_PAGEEXTENSION] = ACTIONS(4993),
    [anon_sym_Pageextension] = ACTIONS(4993),
    [anon_sym_PageExtension] = ACTIONS(4993),
    [anon_sym_pageExtension] = ACTIONS(4993),
    [anon_sym_codeunit] = ACTIONS(4993),
    [anon_sym_CODEUNIT] = ACTIONS(4993),
    [anon_sym_Codeunit] = ACTIONS(4993),
    [anon_sym_CodeUnit] = ACTIONS(4993),
    [anon_sym_COdeunit] = ACTIONS(4993),
    [anon_sym_codeUnit] = ACTIONS(4993),
    [sym_report_keyword] = ACTIONS(4995),
    [anon_sym_reportextension] = ACTIONS(4993),
    [anon_sym_REPORTEXTENSION] = ACTIONS(4993),
    [anon_sym_Reportextension] = ACTIONS(4993),
    [anon_sym_ReportExtension] = ACTIONS(4993),
    [anon_sym_reportExtension] = ACTIONS(4993),
    [sym_query_keyword] = ACTIONS(4993),
    [anon_sym_xmlport] = ACTIONS(4993),
    [anon_sym_XMLPORT] = ACTIONS(4993),
    [anon_sym_Xmlport] = ACTIONS(4993),
    [anon_sym_XMLport] = ACTIONS(4993),
    [anon_sym_XMLPort] = ACTIONS(4993),
    [anon_sym_XmlPort] = ACTIONS(4993),
    [anon_sym_enum] = ACTIONS(4995),
    [anon_sym_ENUM] = ACTIONS(4995),
    [anon_sym_Enum] = ACTIONS(4995),
    [anon_sym_eNUM] = ACTIONS(4993),
    [anon_sym_eNum] = ACTIONS(4993),
    [anon_sym_ENum] = ACTIONS(4993),
    [anon_sym_enumextension] = ACTIONS(4993),
    [anon_sym_ENUMEXTENSION] = ACTIONS(4993),
    [anon_sym_Enumextension] = ACTIONS(4993),
    [anon_sym_EnumExtension] = ACTIONS(4993),
    [anon_sym_enumExtension] = ACTIONS(4993),
    [sym_interface_keyword] = ACTIONS(4993),
    [anon_sym_controladdin] = ACTIONS(4993),
    [anon_sym_CONTROLADDIN] = ACTIONS(4993),
    [anon_sym_Controladdin] = ACTIONS(4993),
    [anon_sym_ControlAddIn] = ACTIONS(4993),
    [anon_sym_ControlAddin] = ACTIONS(4993),
    [anon_sym_controlAddIn] = ACTIONS(4993),
    [anon_sym_controlAddin] = ACTIONS(4993),
    [anon_sym_dotnet] = ACTIONS(4993),
    [anon_sym_DOTNET] = ACTIONS(4993),
    [anon_sym_Dotnet] = ACTIONS(4993),
    [anon_sym_DotNet] = ACTIONS(4993),
    [anon_sym_dotNet] = ACTIONS(4993),
    [sym_profile_keyword] = ACTIONS(4995),
    [anon_sym_profileextension] = ACTIONS(4993),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(4993),
    [anon_sym_Profileextension] = ACTIONS(4993),
    [anon_sym_ProfileExtension] = ACTIONS(4993),
    [anon_sym_profileExtension] = ACTIONS(4993),
    [anon_sym_permissionset] = ACTIONS(4995),
    [anon_sym_PERMISSIONSET] = ACTIONS(4995),
    [anon_sym_Permissionset] = ACTIONS(4995),
    [anon_sym_PermissionSet] = ACTIONS(4995),
    [anon_sym_permissionSet] = ACTIONS(4995),
    [anon_sym_permissionsetextension] = ACTIONS(4993),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(4993),
    [anon_sym_Permissionsetextension] = ACTIONS(4993),
    [anon_sym_PermissionSetExtension] = ACTIONS(4993),
    [anon_sym_permissionSetExtension] = ACTIONS(4993),
    [sym_entitlement_keyword] = ACTIONS(4993),
    [anon_sym_pagecustomization] = ACTIONS(4993),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(4993),
    [anon_sym_Pagecustomization] = ACTIONS(4993),
    [anon_sym_PageCustomization] = ACTIONS(4993),
    [anon_sym_pageCustomization] = ACTIONS(4993),
    [sym_using_keyword] = ACTIONS(4993),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(4993),
  },
  [STATE(2498)] = {
    [ts_builtin_sym_end] = ACTIONS(5371),
    [anon_sym_POUNDif] = ACTIONS(5371),
    [anon_sym_POUNDIF] = ACTIONS(5371),
    [anon_sym_POUNDIf] = ACTIONS(5371),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5373),
    [anon_sym_tableextension] = ACTIONS(5371),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5371),
    [anon_sym_Tableextension] = ACTIONS(5371),
    [anon_sym_TableExtension] = ACTIONS(5371),
    [anon_sym_tableExtension] = ACTIONS(5371),
    [sym_page_keyword] = ACTIONS(5373),
    [anon_sym_pageextension] = ACTIONS(5371),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5371),
    [anon_sym_Pageextension] = ACTIONS(5371),
    [anon_sym_PageExtension] = ACTIONS(5371),
    [anon_sym_pageExtension] = ACTIONS(5371),
    [anon_sym_codeunit] = ACTIONS(5371),
    [anon_sym_CODEUNIT] = ACTIONS(5371),
    [anon_sym_Codeunit] = ACTIONS(5371),
    [anon_sym_CodeUnit] = ACTIONS(5371),
    [anon_sym_COdeunit] = ACTIONS(5371),
    [anon_sym_codeUnit] = ACTIONS(5371),
    [sym_report_keyword] = ACTIONS(5373),
    [anon_sym_reportextension] = ACTIONS(5371),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5371),
    [anon_sym_Reportextension] = ACTIONS(5371),
    [anon_sym_ReportExtension] = ACTIONS(5371),
    [anon_sym_reportExtension] = ACTIONS(5371),
    [sym_query_keyword] = ACTIONS(5371),
    [anon_sym_xmlport] = ACTIONS(5371),
    [anon_sym_XMLPORT] = ACTIONS(5371),
    [anon_sym_Xmlport] = ACTIONS(5371),
    [anon_sym_XMLport] = ACTIONS(5371),
    [anon_sym_XMLPort] = ACTIONS(5371),
    [anon_sym_XmlPort] = ACTIONS(5371),
    [anon_sym_enum] = ACTIONS(5373),
    [anon_sym_ENUM] = ACTIONS(5373),
    [anon_sym_Enum] = ACTIONS(5373),
    [anon_sym_eNUM] = ACTIONS(5371),
    [anon_sym_eNum] = ACTIONS(5371),
    [anon_sym_ENum] = ACTIONS(5371),
    [anon_sym_enumextension] = ACTIONS(5371),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5371),
    [anon_sym_Enumextension] = ACTIONS(5371),
    [anon_sym_EnumExtension] = ACTIONS(5371),
    [anon_sym_enumExtension] = ACTIONS(5371),
    [sym_interface_keyword] = ACTIONS(5371),
    [anon_sym_controladdin] = ACTIONS(5371),
    [anon_sym_CONTROLADDIN] = ACTIONS(5371),
    [anon_sym_Controladdin] = ACTIONS(5371),
    [anon_sym_ControlAddIn] = ACTIONS(5371),
    [anon_sym_ControlAddin] = ACTIONS(5371),
    [anon_sym_controlAddIn] = ACTIONS(5371),
    [anon_sym_controlAddin] = ACTIONS(5371),
    [anon_sym_dotnet] = ACTIONS(5371),
    [anon_sym_DOTNET] = ACTIONS(5371),
    [anon_sym_Dotnet] = ACTIONS(5371),
    [anon_sym_DotNet] = ACTIONS(5371),
    [anon_sym_dotNet] = ACTIONS(5371),
    [sym_profile_keyword] = ACTIONS(5373),
    [anon_sym_profileextension] = ACTIONS(5371),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5371),
    [anon_sym_Profileextension] = ACTIONS(5371),
    [anon_sym_ProfileExtension] = ACTIONS(5371),
    [anon_sym_profileExtension] = ACTIONS(5371),
    [anon_sym_permissionset] = ACTIONS(5373),
    [anon_sym_PERMISSIONSET] = ACTIONS(5373),
    [anon_sym_Permissionset] = ACTIONS(5373),
    [anon_sym_PermissionSet] = ACTIONS(5373),
    [anon_sym_permissionSet] = ACTIONS(5373),
    [anon_sym_permissionsetextension] = ACTIONS(5371),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5371),
    [anon_sym_Permissionsetextension] = ACTIONS(5371),
    [anon_sym_PermissionSetExtension] = ACTIONS(5371),
    [anon_sym_permissionSetExtension] = ACTIONS(5371),
    [sym_entitlement_keyword] = ACTIONS(5371),
    [anon_sym_pagecustomization] = ACTIONS(5371),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5371),
    [anon_sym_Pagecustomization] = ACTIONS(5371),
    [anon_sym_PageCustomization] = ACTIONS(5371),
    [anon_sym_pageCustomization] = ACTIONS(5371),
    [sym_using_keyword] = ACTIONS(5371),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5371),
  },
  [STATE(2499)] = {
    [ts_builtin_sym_end] = ACTIONS(5325),
    [anon_sym_POUNDif] = ACTIONS(5325),
    [anon_sym_POUNDIF] = ACTIONS(5325),
    [anon_sym_POUNDIf] = ACTIONS(5325),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5327),
    [anon_sym_tableextension] = ACTIONS(5325),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5325),
    [anon_sym_Tableextension] = ACTIONS(5325),
    [anon_sym_TableExtension] = ACTIONS(5325),
    [anon_sym_tableExtension] = ACTIONS(5325),
    [sym_page_keyword] = ACTIONS(5327),
    [anon_sym_pageextension] = ACTIONS(5325),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5325),
    [anon_sym_Pageextension] = ACTIONS(5325),
    [anon_sym_PageExtension] = ACTIONS(5325),
    [anon_sym_pageExtension] = ACTIONS(5325),
    [anon_sym_codeunit] = ACTIONS(5325),
    [anon_sym_CODEUNIT] = ACTIONS(5325),
    [anon_sym_Codeunit] = ACTIONS(5325),
    [anon_sym_CodeUnit] = ACTIONS(5325),
    [anon_sym_COdeunit] = ACTIONS(5325),
    [anon_sym_codeUnit] = ACTIONS(5325),
    [sym_report_keyword] = ACTIONS(5327),
    [anon_sym_reportextension] = ACTIONS(5325),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5325),
    [anon_sym_Reportextension] = ACTIONS(5325),
    [anon_sym_ReportExtension] = ACTIONS(5325),
    [anon_sym_reportExtension] = ACTIONS(5325),
    [sym_query_keyword] = ACTIONS(5325),
    [anon_sym_xmlport] = ACTIONS(5325),
    [anon_sym_XMLPORT] = ACTIONS(5325),
    [anon_sym_Xmlport] = ACTIONS(5325),
    [anon_sym_XMLport] = ACTIONS(5325),
    [anon_sym_XMLPort] = ACTIONS(5325),
    [anon_sym_XmlPort] = ACTIONS(5325),
    [anon_sym_enum] = ACTIONS(5327),
    [anon_sym_ENUM] = ACTIONS(5327),
    [anon_sym_Enum] = ACTIONS(5327),
    [anon_sym_eNUM] = ACTIONS(5325),
    [anon_sym_eNum] = ACTIONS(5325),
    [anon_sym_ENum] = ACTIONS(5325),
    [anon_sym_enumextension] = ACTIONS(5325),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5325),
    [anon_sym_Enumextension] = ACTIONS(5325),
    [anon_sym_EnumExtension] = ACTIONS(5325),
    [anon_sym_enumExtension] = ACTIONS(5325),
    [sym_interface_keyword] = ACTIONS(5325),
    [anon_sym_controladdin] = ACTIONS(5325),
    [anon_sym_CONTROLADDIN] = ACTIONS(5325),
    [anon_sym_Controladdin] = ACTIONS(5325),
    [anon_sym_ControlAddIn] = ACTIONS(5325),
    [anon_sym_ControlAddin] = ACTIONS(5325),
    [anon_sym_controlAddIn] = ACTIONS(5325),
    [anon_sym_controlAddin] = ACTIONS(5325),
    [anon_sym_dotnet] = ACTIONS(5325),
    [anon_sym_DOTNET] = ACTIONS(5325),
    [anon_sym_Dotnet] = ACTIONS(5325),
    [anon_sym_DotNet] = ACTIONS(5325),
    [anon_sym_dotNet] = ACTIONS(5325),
    [sym_profile_keyword] = ACTIONS(5327),
    [anon_sym_profileextension] = ACTIONS(5325),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5325),
    [anon_sym_Profileextension] = ACTIONS(5325),
    [anon_sym_ProfileExtension] = ACTIONS(5325),
    [anon_sym_profileExtension] = ACTIONS(5325),
    [anon_sym_permissionset] = ACTIONS(5327),
    [anon_sym_PERMISSIONSET] = ACTIONS(5327),
    [anon_sym_Permissionset] = ACTIONS(5327),
    [anon_sym_PermissionSet] = ACTIONS(5327),
    [anon_sym_permissionSet] = ACTIONS(5327),
    [anon_sym_permissionsetextension] = ACTIONS(5325),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5325),
    [anon_sym_Permissionsetextension] = ACTIONS(5325),
    [anon_sym_PermissionSetExtension] = ACTIONS(5325),
    [anon_sym_permissionSetExtension] = ACTIONS(5325),
    [sym_entitlement_keyword] = ACTIONS(5325),
    [anon_sym_pagecustomization] = ACTIONS(5325),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5325),
    [anon_sym_Pagecustomization] = ACTIONS(5325),
    [anon_sym_PageCustomization] = ACTIONS(5325),
    [anon_sym_pageCustomization] = ACTIONS(5325),
    [sym_using_keyword] = ACTIONS(5325),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5325),
  },
  [STATE(2500)] = {
    [ts_builtin_sym_end] = ACTIONS(5375),
    [anon_sym_POUNDif] = ACTIONS(5375),
    [anon_sym_POUNDIF] = ACTIONS(5375),
    [anon_sym_POUNDIf] = ACTIONS(5375),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5377),
    [anon_sym_tableextension] = ACTIONS(5375),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5375),
    [anon_sym_Tableextension] = ACTIONS(5375),
    [anon_sym_TableExtension] = ACTIONS(5375),
    [anon_sym_tableExtension] = ACTIONS(5375),
    [sym_page_keyword] = ACTIONS(5377),
    [anon_sym_pageextension] = ACTIONS(5375),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5375),
    [anon_sym_Pageextension] = ACTIONS(5375),
    [anon_sym_PageExtension] = ACTIONS(5375),
    [anon_sym_pageExtension] = ACTIONS(5375),
    [anon_sym_codeunit] = ACTIONS(5375),
    [anon_sym_CODEUNIT] = ACTIONS(5375),
    [anon_sym_Codeunit] = ACTIONS(5375),
    [anon_sym_CodeUnit] = ACTIONS(5375),
    [anon_sym_COdeunit] = ACTIONS(5375),
    [anon_sym_codeUnit] = ACTIONS(5375),
    [sym_report_keyword] = ACTIONS(5377),
    [anon_sym_reportextension] = ACTIONS(5375),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5375),
    [anon_sym_Reportextension] = ACTIONS(5375),
    [anon_sym_ReportExtension] = ACTIONS(5375),
    [anon_sym_reportExtension] = ACTIONS(5375),
    [sym_query_keyword] = ACTIONS(5375),
    [anon_sym_xmlport] = ACTIONS(5375),
    [anon_sym_XMLPORT] = ACTIONS(5375),
    [anon_sym_Xmlport] = ACTIONS(5375),
    [anon_sym_XMLport] = ACTIONS(5375),
    [anon_sym_XMLPort] = ACTIONS(5375),
    [anon_sym_XmlPort] = ACTIONS(5375),
    [anon_sym_enum] = ACTIONS(5377),
    [anon_sym_ENUM] = ACTIONS(5377),
    [anon_sym_Enum] = ACTIONS(5377),
    [anon_sym_eNUM] = ACTIONS(5375),
    [anon_sym_eNum] = ACTIONS(5375),
    [anon_sym_ENum] = ACTIONS(5375),
    [anon_sym_enumextension] = ACTIONS(5375),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5375),
    [anon_sym_Enumextension] = ACTIONS(5375),
    [anon_sym_EnumExtension] = ACTIONS(5375),
    [anon_sym_enumExtension] = ACTIONS(5375),
    [sym_interface_keyword] = ACTIONS(5375),
    [anon_sym_controladdin] = ACTIONS(5375),
    [anon_sym_CONTROLADDIN] = ACTIONS(5375),
    [anon_sym_Controladdin] = ACTIONS(5375),
    [anon_sym_ControlAddIn] = ACTIONS(5375),
    [anon_sym_ControlAddin] = ACTIONS(5375),
    [anon_sym_controlAddIn] = ACTIONS(5375),
    [anon_sym_controlAddin] = ACTIONS(5375),
    [anon_sym_dotnet] = ACTIONS(5375),
    [anon_sym_DOTNET] = ACTIONS(5375),
    [anon_sym_Dotnet] = ACTIONS(5375),
    [anon_sym_DotNet] = ACTIONS(5375),
    [anon_sym_dotNet] = ACTIONS(5375),
    [sym_profile_keyword] = ACTIONS(5377),
    [anon_sym_profileextension] = ACTIONS(5375),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5375),
    [anon_sym_Profileextension] = ACTIONS(5375),
    [anon_sym_ProfileExtension] = ACTIONS(5375),
    [anon_sym_profileExtension] = ACTIONS(5375),
    [anon_sym_permissionset] = ACTIONS(5377),
    [anon_sym_PERMISSIONSET] = ACTIONS(5377),
    [anon_sym_Permissionset] = ACTIONS(5377),
    [anon_sym_PermissionSet] = ACTIONS(5377),
    [anon_sym_permissionSet] = ACTIONS(5377),
    [anon_sym_permissionsetextension] = ACTIONS(5375),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5375),
    [anon_sym_Permissionsetextension] = ACTIONS(5375),
    [anon_sym_PermissionSetExtension] = ACTIONS(5375),
    [anon_sym_permissionSetExtension] = ACTIONS(5375),
    [sym_entitlement_keyword] = ACTIONS(5375),
    [anon_sym_pagecustomization] = ACTIONS(5375),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5375),
    [anon_sym_Pagecustomization] = ACTIONS(5375),
    [anon_sym_PageCustomization] = ACTIONS(5375),
    [anon_sym_pageCustomization] = ACTIONS(5375),
    [sym_using_keyword] = ACTIONS(5375),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5375),
  },
  [STATE(2501)] = {
    [ts_builtin_sym_end] = ACTIONS(5329),
    [anon_sym_POUNDif] = ACTIONS(5329),
    [anon_sym_POUNDIF] = ACTIONS(5329),
    [anon_sym_POUNDIf] = ACTIONS(5329),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5331),
    [anon_sym_tableextension] = ACTIONS(5329),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5329),
    [anon_sym_Tableextension] = ACTIONS(5329),
    [anon_sym_TableExtension] = ACTIONS(5329),
    [anon_sym_tableExtension] = ACTIONS(5329),
    [sym_page_keyword] = ACTIONS(5331),
    [anon_sym_pageextension] = ACTIONS(5329),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5329),
    [anon_sym_Pageextension] = ACTIONS(5329),
    [anon_sym_PageExtension] = ACTIONS(5329),
    [anon_sym_pageExtension] = ACTIONS(5329),
    [anon_sym_codeunit] = ACTIONS(5329),
    [anon_sym_CODEUNIT] = ACTIONS(5329),
    [anon_sym_Codeunit] = ACTIONS(5329),
    [anon_sym_CodeUnit] = ACTIONS(5329),
    [anon_sym_COdeunit] = ACTIONS(5329),
    [anon_sym_codeUnit] = ACTIONS(5329),
    [sym_report_keyword] = ACTIONS(5331),
    [anon_sym_reportextension] = ACTIONS(5329),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5329),
    [anon_sym_Reportextension] = ACTIONS(5329),
    [anon_sym_ReportExtension] = ACTIONS(5329),
    [anon_sym_reportExtension] = ACTIONS(5329),
    [sym_query_keyword] = ACTIONS(5329),
    [anon_sym_xmlport] = ACTIONS(5329),
    [anon_sym_XMLPORT] = ACTIONS(5329),
    [anon_sym_Xmlport] = ACTIONS(5329),
    [anon_sym_XMLport] = ACTIONS(5329),
    [anon_sym_XMLPort] = ACTIONS(5329),
    [anon_sym_XmlPort] = ACTIONS(5329),
    [anon_sym_enum] = ACTIONS(5331),
    [anon_sym_ENUM] = ACTIONS(5331),
    [anon_sym_Enum] = ACTIONS(5331),
    [anon_sym_eNUM] = ACTIONS(5329),
    [anon_sym_eNum] = ACTIONS(5329),
    [anon_sym_ENum] = ACTIONS(5329),
    [anon_sym_enumextension] = ACTIONS(5329),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5329),
    [anon_sym_Enumextension] = ACTIONS(5329),
    [anon_sym_EnumExtension] = ACTIONS(5329),
    [anon_sym_enumExtension] = ACTIONS(5329),
    [sym_interface_keyword] = ACTIONS(5329),
    [anon_sym_controladdin] = ACTIONS(5329),
    [anon_sym_CONTROLADDIN] = ACTIONS(5329),
    [anon_sym_Controladdin] = ACTIONS(5329),
    [anon_sym_ControlAddIn] = ACTIONS(5329),
    [anon_sym_ControlAddin] = ACTIONS(5329),
    [anon_sym_controlAddIn] = ACTIONS(5329),
    [anon_sym_controlAddin] = ACTIONS(5329),
    [anon_sym_dotnet] = ACTIONS(5329),
    [anon_sym_DOTNET] = ACTIONS(5329),
    [anon_sym_Dotnet] = ACTIONS(5329),
    [anon_sym_DotNet] = ACTIONS(5329),
    [anon_sym_dotNet] = ACTIONS(5329),
    [sym_profile_keyword] = ACTIONS(5331),
    [anon_sym_profileextension] = ACTIONS(5329),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5329),
    [anon_sym_Profileextension] = ACTIONS(5329),
    [anon_sym_ProfileExtension] = ACTIONS(5329),
    [anon_sym_profileExtension] = ACTIONS(5329),
    [anon_sym_permissionset] = ACTIONS(5331),
    [anon_sym_PERMISSIONSET] = ACTIONS(5331),
    [anon_sym_Permissionset] = ACTIONS(5331),
    [anon_sym_PermissionSet] = ACTIONS(5331),
    [anon_sym_permissionSet] = ACTIONS(5331),
    [anon_sym_permissionsetextension] = ACTIONS(5329),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5329),
    [anon_sym_Permissionsetextension] = ACTIONS(5329),
    [anon_sym_PermissionSetExtension] = ACTIONS(5329),
    [anon_sym_permissionSetExtension] = ACTIONS(5329),
    [sym_entitlement_keyword] = ACTIONS(5329),
    [anon_sym_pagecustomization] = ACTIONS(5329),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5329),
    [anon_sym_Pagecustomization] = ACTIONS(5329),
    [anon_sym_PageCustomization] = ACTIONS(5329),
    [anon_sym_pageCustomization] = ACTIONS(5329),
    [sym_using_keyword] = ACTIONS(5329),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5329),
  },
  [STATE(2502)] = {
    [ts_builtin_sym_end] = ACTIONS(5379),
    [anon_sym_POUNDif] = ACTIONS(5379),
    [anon_sym_POUNDIF] = ACTIONS(5379),
    [anon_sym_POUNDIf] = ACTIONS(5379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5381),
    [anon_sym_tableextension] = ACTIONS(5379),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5379),
    [anon_sym_Tableextension] = ACTIONS(5379),
    [anon_sym_TableExtension] = ACTIONS(5379),
    [anon_sym_tableExtension] = ACTIONS(5379),
    [sym_page_keyword] = ACTIONS(5381),
    [anon_sym_pageextension] = ACTIONS(5379),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5379),
    [anon_sym_Pageextension] = ACTIONS(5379),
    [anon_sym_PageExtension] = ACTIONS(5379),
    [anon_sym_pageExtension] = ACTIONS(5379),
    [anon_sym_codeunit] = ACTIONS(5379),
    [anon_sym_CODEUNIT] = ACTIONS(5379),
    [anon_sym_Codeunit] = ACTIONS(5379),
    [anon_sym_CodeUnit] = ACTIONS(5379),
    [anon_sym_COdeunit] = ACTIONS(5379),
    [anon_sym_codeUnit] = ACTIONS(5379),
    [sym_report_keyword] = ACTIONS(5381),
    [anon_sym_reportextension] = ACTIONS(5379),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5379),
    [anon_sym_Reportextension] = ACTIONS(5379),
    [anon_sym_ReportExtension] = ACTIONS(5379),
    [anon_sym_reportExtension] = ACTIONS(5379),
    [sym_query_keyword] = ACTIONS(5379),
    [anon_sym_xmlport] = ACTIONS(5379),
    [anon_sym_XMLPORT] = ACTIONS(5379),
    [anon_sym_Xmlport] = ACTIONS(5379),
    [anon_sym_XMLport] = ACTIONS(5379),
    [anon_sym_XMLPort] = ACTIONS(5379),
    [anon_sym_XmlPort] = ACTIONS(5379),
    [anon_sym_enum] = ACTIONS(5381),
    [anon_sym_ENUM] = ACTIONS(5381),
    [anon_sym_Enum] = ACTIONS(5381),
    [anon_sym_eNUM] = ACTIONS(5379),
    [anon_sym_eNum] = ACTIONS(5379),
    [anon_sym_ENum] = ACTIONS(5379),
    [anon_sym_enumextension] = ACTIONS(5379),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5379),
    [anon_sym_Enumextension] = ACTIONS(5379),
    [anon_sym_EnumExtension] = ACTIONS(5379),
    [anon_sym_enumExtension] = ACTIONS(5379),
    [sym_interface_keyword] = ACTIONS(5379),
    [anon_sym_controladdin] = ACTIONS(5379),
    [anon_sym_CONTROLADDIN] = ACTIONS(5379),
    [anon_sym_Controladdin] = ACTIONS(5379),
    [anon_sym_ControlAddIn] = ACTIONS(5379),
    [anon_sym_ControlAddin] = ACTIONS(5379),
    [anon_sym_controlAddIn] = ACTIONS(5379),
    [anon_sym_controlAddin] = ACTIONS(5379),
    [anon_sym_dotnet] = ACTIONS(5379),
    [anon_sym_DOTNET] = ACTIONS(5379),
    [anon_sym_Dotnet] = ACTIONS(5379),
    [anon_sym_DotNet] = ACTIONS(5379),
    [anon_sym_dotNet] = ACTIONS(5379),
    [sym_profile_keyword] = ACTIONS(5381),
    [anon_sym_profileextension] = ACTIONS(5379),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5379),
    [anon_sym_Profileextension] = ACTIONS(5379),
    [anon_sym_ProfileExtension] = ACTIONS(5379),
    [anon_sym_profileExtension] = ACTIONS(5379),
    [anon_sym_permissionset] = ACTIONS(5381),
    [anon_sym_PERMISSIONSET] = ACTIONS(5381),
    [anon_sym_Permissionset] = ACTIONS(5381),
    [anon_sym_PermissionSet] = ACTIONS(5381),
    [anon_sym_permissionSet] = ACTIONS(5381),
    [anon_sym_permissionsetextension] = ACTIONS(5379),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5379),
    [anon_sym_Permissionsetextension] = ACTIONS(5379),
    [anon_sym_PermissionSetExtension] = ACTIONS(5379),
    [anon_sym_permissionSetExtension] = ACTIONS(5379),
    [sym_entitlement_keyword] = ACTIONS(5379),
    [anon_sym_pagecustomization] = ACTIONS(5379),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5379),
    [anon_sym_Pagecustomization] = ACTIONS(5379),
    [anon_sym_PageCustomization] = ACTIONS(5379),
    [anon_sym_pageCustomization] = ACTIONS(5379),
    [sym_using_keyword] = ACTIONS(5379),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5379),
  },
  [STATE(2503)] = {
    [ts_builtin_sym_end] = ACTIONS(5001),
    [anon_sym_POUNDif] = ACTIONS(5001),
    [anon_sym_POUNDIF] = ACTIONS(5001),
    [anon_sym_POUNDIf] = ACTIONS(5001),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5003),
    [anon_sym_tableextension] = ACTIONS(5001),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5001),
    [anon_sym_Tableextension] = ACTIONS(5001),
    [anon_sym_TableExtension] = ACTIONS(5001),
    [anon_sym_tableExtension] = ACTIONS(5001),
    [sym_page_keyword] = ACTIONS(5003),
    [anon_sym_pageextension] = ACTIONS(5001),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5001),
    [anon_sym_Pageextension] = ACTIONS(5001),
    [anon_sym_PageExtension] = ACTIONS(5001),
    [anon_sym_pageExtension] = ACTIONS(5001),
    [anon_sym_codeunit] = ACTIONS(5001),
    [anon_sym_CODEUNIT] = ACTIONS(5001),
    [anon_sym_Codeunit] = ACTIONS(5001),
    [anon_sym_CodeUnit] = ACTIONS(5001),
    [anon_sym_COdeunit] = ACTIONS(5001),
    [anon_sym_codeUnit] = ACTIONS(5001),
    [sym_report_keyword] = ACTIONS(5003),
    [anon_sym_reportextension] = ACTIONS(5001),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5001),
    [anon_sym_Reportextension] = ACTIONS(5001),
    [anon_sym_ReportExtension] = ACTIONS(5001),
    [anon_sym_reportExtension] = ACTIONS(5001),
    [sym_query_keyword] = ACTIONS(5001),
    [anon_sym_xmlport] = ACTIONS(5001),
    [anon_sym_XMLPORT] = ACTIONS(5001),
    [anon_sym_Xmlport] = ACTIONS(5001),
    [anon_sym_XMLport] = ACTIONS(5001),
    [anon_sym_XMLPort] = ACTIONS(5001),
    [anon_sym_XmlPort] = ACTIONS(5001),
    [anon_sym_enum] = ACTIONS(5003),
    [anon_sym_ENUM] = ACTIONS(5003),
    [anon_sym_Enum] = ACTIONS(5003),
    [anon_sym_eNUM] = ACTIONS(5001),
    [anon_sym_eNum] = ACTIONS(5001),
    [anon_sym_ENum] = ACTIONS(5001),
    [anon_sym_enumextension] = ACTIONS(5001),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5001),
    [anon_sym_Enumextension] = ACTIONS(5001),
    [anon_sym_EnumExtension] = ACTIONS(5001),
    [anon_sym_enumExtension] = ACTIONS(5001),
    [sym_interface_keyword] = ACTIONS(5001),
    [anon_sym_controladdin] = ACTIONS(5001),
    [anon_sym_CONTROLADDIN] = ACTIONS(5001),
    [anon_sym_Controladdin] = ACTIONS(5001),
    [anon_sym_ControlAddIn] = ACTIONS(5001),
    [anon_sym_ControlAddin] = ACTIONS(5001),
    [anon_sym_controlAddIn] = ACTIONS(5001),
    [anon_sym_controlAddin] = ACTIONS(5001),
    [anon_sym_dotnet] = ACTIONS(5001),
    [anon_sym_DOTNET] = ACTIONS(5001),
    [anon_sym_Dotnet] = ACTIONS(5001),
    [anon_sym_DotNet] = ACTIONS(5001),
    [anon_sym_dotNet] = ACTIONS(5001),
    [sym_profile_keyword] = ACTIONS(5003),
    [anon_sym_profileextension] = ACTIONS(5001),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5001),
    [anon_sym_Profileextension] = ACTIONS(5001),
    [anon_sym_ProfileExtension] = ACTIONS(5001),
    [anon_sym_profileExtension] = ACTIONS(5001),
    [anon_sym_permissionset] = ACTIONS(5003),
    [anon_sym_PERMISSIONSET] = ACTIONS(5003),
    [anon_sym_Permissionset] = ACTIONS(5003),
    [anon_sym_PermissionSet] = ACTIONS(5003),
    [anon_sym_permissionSet] = ACTIONS(5003),
    [anon_sym_permissionsetextension] = ACTIONS(5001),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5001),
    [anon_sym_Permissionsetextension] = ACTIONS(5001),
    [anon_sym_PermissionSetExtension] = ACTIONS(5001),
    [anon_sym_permissionSetExtension] = ACTIONS(5001),
    [sym_entitlement_keyword] = ACTIONS(5001),
    [anon_sym_pagecustomization] = ACTIONS(5001),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5001),
    [anon_sym_Pagecustomization] = ACTIONS(5001),
    [anon_sym_PageCustomization] = ACTIONS(5001),
    [anon_sym_pageCustomization] = ACTIONS(5001),
    [sym_using_keyword] = ACTIONS(5001),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5001),
  },
  [STATE(2504)] = {
    [ts_builtin_sym_end] = ACTIONS(5261),
    [anon_sym_POUNDif] = ACTIONS(5261),
    [anon_sym_POUNDIF] = ACTIONS(5261),
    [anon_sym_POUNDIf] = ACTIONS(5261),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5263),
    [anon_sym_tableextension] = ACTIONS(5261),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5261),
    [anon_sym_Tableextension] = ACTIONS(5261),
    [anon_sym_TableExtension] = ACTIONS(5261),
    [anon_sym_tableExtension] = ACTIONS(5261),
    [sym_page_keyword] = ACTIONS(5263),
    [anon_sym_pageextension] = ACTIONS(5261),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5261),
    [anon_sym_Pageextension] = ACTIONS(5261),
    [anon_sym_PageExtension] = ACTIONS(5261),
    [anon_sym_pageExtension] = ACTIONS(5261),
    [anon_sym_codeunit] = ACTIONS(5261),
    [anon_sym_CODEUNIT] = ACTIONS(5261),
    [anon_sym_Codeunit] = ACTIONS(5261),
    [anon_sym_CodeUnit] = ACTIONS(5261),
    [anon_sym_COdeunit] = ACTIONS(5261),
    [anon_sym_codeUnit] = ACTIONS(5261),
    [sym_report_keyword] = ACTIONS(5263),
    [anon_sym_reportextension] = ACTIONS(5261),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5261),
    [anon_sym_Reportextension] = ACTIONS(5261),
    [anon_sym_ReportExtension] = ACTIONS(5261),
    [anon_sym_reportExtension] = ACTIONS(5261),
    [sym_query_keyword] = ACTIONS(5261),
    [anon_sym_xmlport] = ACTIONS(5261),
    [anon_sym_XMLPORT] = ACTIONS(5261),
    [anon_sym_Xmlport] = ACTIONS(5261),
    [anon_sym_XMLport] = ACTIONS(5261),
    [anon_sym_XMLPort] = ACTIONS(5261),
    [anon_sym_XmlPort] = ACTIONS(5261),
    [anon_sym_enum] = ACTIONS(5263),
    [anon_sym_ENUM] = ACTIONS(5263),
    [anon_sym_Enum] = ACTIONS(5263),
    [anon_sym_eNUM] = ACTIONS(5261),
    [anon_sym_eNum] = ACTIONS(5261),
    [anon_sym_ENum] = ACTIONS(5261),
    [anon_sym_enumextension] = ACTIONS(5261),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5261),
    [anon_sym_Enumextension] = ACTIONS(5261),
    [anon_sym_EnumExtension] = ACTIONS(5261),
    [anon_sym_enumExtension] = ACTIONS(5261),
    [sym_interface_keyword] = ACTIONS(5261),
    [anon_sym_controladdin] = ACTIONS(5261),
    [anon_sym_CONTROLADDIN] = ACTIONS(5261),
    [anon_sym_Controladdin] = ACTIONS(5261),
    [anon_sym_ControlAddIn] = ACTIONS(5261),
    [anon_sym_ControlAddin] = ACTIONS(5261),
    [anon_sym_controlAddIn] = ACTIONS(5261),
    [anon_sym_controlAddin] = ACTIONS(5261),
    [anon_sym_dotnet] = ACTIONS(5261),
    [anon_sym_DOTNET] = ACTIONS(5261),
    [anon_sym_Dotnet] = ACTIONS(5261),
    [anon_sym_DotNet] = ACTIONS(5261),
    [anon_sym_dotNet] = ACTIONS(5261),
    [sym_profile_keyword] = ACTIONS(5263),
    [anon_sym_profileextension] = ACTIONS(5261),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5261),
    [anon_sym_Profileextension] = ACTIONS(5261),
    [anon_sym_ProfileExtension] = ACTIONS(5261),
    [anon_sym_profileExtension] = ACTIONS(5261),
    [anon_sym_permissionset] = ACTIONS(5263),
    [anon_sym_PERMISSIONSET] = ACTIONS(5263),
    [anon_sym_Permissionset] = ACTIONS(5263),
    [anon_sym_PermissionSet] = ACTIONS(5263),
    [anon_sym_permissionSet] = ACTIONS(5263),
    [anon_sym_permissionsetextension] = ACTIONS(5261),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5261),
    [anon_sym_Permissionsetextension] = ACTIONS(5261),
    [anon_sym_PermissionSetExtension] = ACTIONS(5261),
    [anon_sym_permissionSetExtension] = ACTIONS(5261),
    [sym_entitlement_keyword] = ACTIONS(5261),
    [anon_sym_pagecustomization] = ACTIONS(5261),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5261),
    [anon_sym_Pagecustomization] = ACTIONS(5261),
    [anon_sym_PageCustomization] = ACTIONS(5261),
    [anon_sym_pageCustomization] = ACTIONS(5261),
    [sym_using_keyword] = ACTIONS(5261),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5261),
  },
  [STATE(2505)] = {
    [ts_builtin_sym_end] = ACTIONS(5321),
    [anon_sym_POUNDif] = ACTIONS(5321),
    [anon_sym_POUNDIF] = ACTIONS(5321),
    [anon_sym_POUNDIf] = ACTIONS(5321),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5323),
    [anon_sym_tableextension] = ACTIONS(5321),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5321),
    [anon_sym_Tableextension] = ACTIONS(5321),
    [anon_sym_TableExtension] = ACTIONS(5321),
    [anon_sym_tableExtension] = ACTIONS(5321),
    [sym_page_keyword] = ACTIONS(5323),
    [anon_sym_pageextension] = ACTIONS(5321),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5321),
    [anon_sym_Pageextension] = ACTIONS(5321),
    [anon_sym_PageExtension] = ACTIONS(5321),
    [anon_sym_pageExtension] = ACTIONS(5321),
    [anon_sym_codeunit] = ACTIONS(5321),
    [anon_sym_CODEUNIT] = ACTIONS(5321),
    [anon_sym_Codeunit] = ACTIONS(5321),
    [anon_sym_CodeUnit] = ACTIONS(5321),
    [anon_sym_COdeunit] = ACTIONS(5321),
    [anon_sym_codeUnit] = ACTIONS(5321),
    [sym_report_keyword] = ACTIONS(5323),
    [anon_sym_reportextension] = ACTIONS(5321),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5321),
    [anon_sym_Reportextension] = ACTIONS(5321),
    [anon_sym_ReportExtension] = ACTIONS(5321),
    [anon_sym_reportExtension] = ACTIONS(5321),
    [sym_query_keyword] = ACTIONS(5321),
    [anon_sym_xmlport] = ACTIONS(5321),
    [anon_sym_XMLPORT] = ACTIONS(5321),
    [anon_sym_Xmlport] = ACTIONS(5321),
    [anon_sym_XMLport] = ACTIONS(5321),
    [anon_sym_XMLPort] = ACTIONS(5321),
    [anon_sym_XmlPort] = ACTIONS(5321),
    [anon_sym_enum] = ACTIONS(5323),
    [anon_sym_ENUM] = ACTIONS(5323),
    [anon_sym_Enum] = ACTIONS(5323),
    [anon_sym_eNUM] = ACTIONS(5321),
    [anon_sym_eNum] = ACTIONS(5321),
    [anon_sym_ENum] = ACTIONS(5321),
    [anon_sym_enumextension] = ACTIONS(5321),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5321),
    [anon_sym_Enumextension] = ACTIONS(5321),
    [anon_sym_EnumExtension] = ACTIONS(5321),
    [anon_sym_enumExtension] = ACTIONS(5321),
    [sym_interface_keyword] = ACTIONS(5321),
    [anon_sym_controladdin] = ACTIONS(5321),
    [anon_sym_CONTROLADDIN] = ACTIONS(5321),
    [anon_sym_Controladdin] = ACTIONS(5321),
    [anon_sym_ControlAddIn] = ACTIONS(5321),
    [anon_sym_ControlAddin] = ACTIONS(5321),
    [anon_sym_controlAddIn] = ACTIONS(5321),
    [anon_sym_controlAddin] = ACTIONS(5321),
    [anon_sym_dotnet] = ACTIONS(5321),
    [anon_sym_DOTNET] = ACTIONS(5321),
    [anon_sym_Dotnet] = ACTIONS(5321),
    [anon_sym_DotNet] = ACTIONS(5321),
    [anon_sym_dotNet] = ACTIONS(5321),
    [sym_profile_keyword] = ACTIONS(5323),
    [anon_sym_profileextension] = ACTIONS(5321),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5321),
    [anon_sym_Profileextension] = ACTIONS(5321),
    [anon_sym_ProfileExtension] = ACTIONS(5321),
    [anon_sym_profileExtension] = ACTIONS(5321),
    [anon_sym_permissionset] = ACTIONS(5323),
    [anon_sym_PERMISSIONSET] = ACTIONS(5323),
    [anon_sym_Permissionset] = ACTIONS(5323),
    [anon_sym_PermissionSet] = ACTIONS(5323),
    [anon_sym_permissionSet] = ACTIONS(5323),
    [anon_sym_permissionsetextension] = ACTIONS(5321),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5321),
    [anon_sym_Permissionsetextension] = ACTIONS(5321),
    [anon_sym_PermissionSetExtension] = ACTIONS(5321),
    [anon_sym_permissionSetExtension] = ACTIONS(5321),
    [sym_entitlement_keyword] = ACTIONS(5321),
    [anon_sym_pagecustomization] = ACTIONS(5321),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5321),
    [anon_sym_Pagecustomization] = ACTIONS(5321),
    [anon_sym_PageCustomization] = ACTIONS(5321),
    [anon_sym_pageCustomization] = ACTIONS(5321),
    [sym_using_keyword] = ACTIONS(5321),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5321),
  },
  [STATE(2506)] = {
    [ts_builtin_sym_end] = ACTIONS(5269),
    [anon_sym_POUNDif] = ACTIONS(5269),
    [anon_sym_POUNDIF] = ACTIONS(5269),
    [anon_sym_POUNDIf] = ACTIONS(5269),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5271),
    [anon_sym_tableextension] = ACTIONS(5269),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5269),
    [anon_sym_Tableextension] = ACTIONS(5269),
    [anon_sym_TableExtension] = ACTIONS(5269),
    [anon_sym_tableExtension] = ACTIONS(5269),
    [sym_page_keyword] = ACTIONS(5271),
    [anon_sym_pageextension] = ACTIONS(5269),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5269),
    [anon_sym_Pageextension] = ACTIONS(5269),
    [anon_sym_PageExtension] = ACTIONS(5269),
    [anon_sym_pageExtension] = ACTIONS(5269),
    [anon_sym_codeunit] = ACTIONS(5269),
    [anon_sym_CODEUNIT] = ACTIONS(5269),
    [anon_sym_Codeunit] = ACTIONS(5269),
    [anon_sym_CodeUnit] = ACTIONS(5269),
    [anon_sym_COdeunit] = ACTIONS(5269),
    [anon_sym_codeUnit] = ACTIONS(5269),
    [sym_report_keyword] = ACTIONS(5271),
    [anon_sym_reportextension] = ACTIONS(5269),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5269),
    [anon_sym_Reportextension] = ACTIONS(5269),
    [anon_sym_ReportExtension] = ACTIONS(5269),
    [anon_sym_reportExtension] = ACTIONS(5269),
    [sym_query_keyword] = ACTIONS(5269),
    [anon_sym_xmlport] = ACTIONS(5269),
    [anon_sym_XMLPORT] = ACTIONS(5269),
    [anon_sym_Xmlport] = ACTIONS(5269),
    [anon_sym_XMLport] = ACTIONS(5269),
    [anon_sym_XMLPort] = ACTIONS(5269),
    [anon_sym_XmlPort] = ACTIONS(5269),
    [anon_sym_enum] = ACTIONS(5271),
    [anon_sym_ENUM] = ACTIONS(5271),
    [anon_sym_Enum] = ACTIONS(5271),
    [anon_sym_eNUM] = ACTIONS(5269),
    [anon_sym_eNum] = ACTIONS(5269),
    [anon_sym_ENum] = ACTIONS(5269),
    [anon_sym_enumextension] = ACTIONS(5269),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5269),
    [anon_sym_Enumextension] = ACTIONS(5269),
    [anon_sym_EnumExtension] = ACTIONS(5269),
    [anon_sym_enumExtension] = ACTIONS(5269),
    [sym_interface_keyword] = ACTIONS(5269),
    [anon_sym_controladdin] = ACTIONS(5269),
    [anon_sym_CONTROLADDIN] = ACTIONS(5269),
    [anon_sym_Controladdin] = ACTIONS(5269),
    [anon_sym_ControlAddIn] = ACTIONS(5269),
    [anon_sym_ControlAddin] = ACTIONS(5269),
    [anon_sym_controlAddIn] = ACTIONS(5269),
    [anon_sym_controlAddin] = ACTIONS(5269),
    [anon_sym_dotnet] = ACTIONS(5269),
    [anon_sym_DOTNET] = ACTIONS(5269),
    [anon_sym_Dotnet] = ACTIONS(5269),
    [anon_sym_DotNet] = ACTIONS(5269),
    [anon_sym_dotNet] = ACTIONS(5269),
    [sym_profile_keyword] = ACTIONS(5271),
    [anon_sym_profileextension] = ACTIONS(5269),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5269),
    [anon_sym_Profileextension] = ACTIONS(5269),
    [anon_sym_ProfileExtension] = ACTIONS(5269),
    [anon_sym_profileExtension] = ACTIONS(5269),
    [anon_sym_permissionset] = ACTIONS(5271),
    [anon_sym_PERMISSIONSET] = ACTIONS(5271),
    [anon_sym_Permissionset] = ACTIONS(5271),
    [anon_sym_PermissionSet] = ACTIONS(5271),
    [anon_sym_permissionSet] = ACTIONS(5271),
    [anon_sym_permissionsetextension] = ACTIONS(5269),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5269),
    [anon_sym_Permissionsetextension] = ACTIONS(5269),
    [anon_sym_PermissionSetExtension] = ACTIONS(5269),
    [anon_sym_permissionSetExtension] = ACTIONS(5269),
    [sym_entitlement_keyword] = ACTIONS(5269),
    [anon_sym_pagecustomization] = ACTIONS(5269),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5269),
    [anon_sym_Pagecustomization] = ACTIONS(5269),
    [anon_sym_PageCustomization] = ACTIONS(5269),
    [anon_sym_pageCustomization] = ACTIONS(5269),
    [sym_using_keyword] = ACTIONS(5269),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5269),
  },
  [STATE(2507)] = {
    [ts_builtin_sym_end] = ACTIONS(5005),
    [anon_sym_POUNDif] = ACTIONS(5005),
    [anon_sym_POUNDIF] = ACTIONS(5005),
    [anon_sym_POUNDIf] = ACTIONS(5005),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5007),
    [anon_sym_tableextension] = ACTIONS(5005),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5005),
    [anon_sym_Tableextension] = ACTIONS(5005),
    [anon_sym_TableExtension] = ACTIONS(5005),
    [anon_sym_tableExtension] = ACTIONS(5005),
    [sym_page_keyword] = ACTIONS(5007),
    [anon_sym_pageextension] = ACTIONS(5005),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5005),
    [anon_sym_Pageextension] = ACTIONS(5005),
    [anon_sym_PageExtension] = ACTIONS(5005),
    [anon_sym_pageExtension] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(5005),
    [anon_sym_CODEUNIT] = ACTIONS(5005),
    [anon_sym_Codeunit] = ACTIONS(5005),
    [anon_sym_CodeUnit] = ACTIONS(5005),
    [anon_sym_COdeunit] = ACTIONS(5005),
    [anon_sym_codeUnit] = ACTIONS(5005),
    [sym_report_keyword] = ACTIONS(5007),
    [anon_sym_reportextension] = ACTIONS(5005),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5005),
    [anon_sym_Reportextension] = ACTIONS(5005),
    [anon_sym_ReportExtension] = ACTIONS(5005),
    [anon_sym_reportExtension] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(5005),
    [anon_sym_XMLPORT] = ACTIONS(5005),
    [anon_sym_Xmlport] = ACTIONS(5005),
    [anon_sym_XMLport] = ACTIONS(5005),
    [anon_sym_XMLPort] = ACTIONS(5005),
    [anon_sym_XmlPort] = ACTIONS(5005),
    [anon_sym_enum] = ACTIONS(5007),
    [anon_sym_ENUM] = ACTIONS(5007),
    [anon_sym_Enum] = ACTIONS(5007),
    [anon_sym_eNUM] = ACTIONS(5005),
    [anon_sym_eNum] = ACTIONS(5005),
    [anon_sym_ENum] = ACTIONS(5005),
    [anon_sym_enumextension] = ACTIONS(5005),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5005),
    [anon_sym_Enumextension] = ACTIONS(5005),
    [anon_sym_EnumExtension] = ACTIONS(5005),
    [anon_sym_enumExtension] = ACTIONS(5005),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(5005),
    [anon_sym_CONTROLADDIN] = ACTIONS(5005),
    [anon_sym_Controladdin] = ACTIONS(5005),
    [anon_sym_ControlAddIn] = ACTIONS(5005),
    [anon_sym_ControlAddin] = ACTIONS(5005),
    [anon_sym_controlAddIn] = ACTIONS(5005),
    [anon_sym_controlAddin] = ACTIONS(5005),
    [anon_sym_dotnet] = ACTIONS(5005),
    [anon_sym_DOTNET] = ACTIONS(5005),
    [anon_sym_Dotnet] = ACTIONS(5005),
    [anon_sym_DotNet] = ACTIONS(5005),
    [anon_sym_dotNet] = ACTIONS(5005),
    [sym_profile_keyword] = ACTIONS(5007),
    [anon_sym_profileextension] = ACTIONS(5005),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5005),
    [anon_sym_Profileextension] = ACTIONS(5005),
    [anon_sym_ProfileExtension] = ACTIONS(5005),
    [anon_sym_profileExtension] = ACTIONS(5005),
    [anon_sym_permissionset] = ACTIONS(5007),
    [anon_sym_PERMISSIONSET] = ACTIONS(5007),
    [anon_sym_Permissionset] = ACTIONS(5007),
    [anon_sym_PermissionSet] = ACTIONS(5007),
    [anon_sym_permissionSet] = ACTIONS(5007),
    [anon_sym_permissionsetextension] = ACTIONS(5005),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5005),
    [anon_sym_Permissionsetextension] = ACTIONS(5005),
    [anon_sym_PermissionSetExtension] = ACTIONS(5005),
    [anon_sym_permissionSetExtension] = ACTIONS(5005),
    [sym_entitlement_keyword] = ACTIONS(5005),
    [anon_sym_pagecustomization] = ACTIONS(5005),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5005),
    [anon_sym_Pagecustomization] = ACTIONS(5005),
    [anon_sym_PageCustomization] = ACTIONS(5005),
    [anon_sym_pageCustomization] = ACTIONS(5005),
    [sym_using_keyword] = ACTIONS(5005),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5005),
  },
  [STATE(2508)] = {
    [ts_builtin_sym_end] = ACTIONS(5387),
    [anon_sym_POUNDif] = ACTIONS(5387),
    [anon_sym_POUNDIF] = ACTIONS(5387),
    [anon_sym_POUNDIf] = ACTIONS(5387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5389),
    [anon_sym_tableextension] = ACTIONS(5387),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5387),
    [anon_sym_Tableextension] = ACTIONS(5387),
    [anon_sym_TableExtension] = ACTIONS(5387),
    [anon_sym_tableExtension] = ACTIONS(5387),
    [sym_page_keyword] = ACTIONS(5389),
    [anon_sym_pageextension] = ACTIONS(5387),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5387),
    [anon_sym_Pageextension] = ACTIONS(5387),
    [anon_sym_PageExtension] = ACTIONS(5387),
    [anon_sym_pageExtension] = ACTIONS(5387),
    [anon_sym_codeunit] = ACTIONS(5387),
    [anon_sym_CODEUNIT] = ACTIONS(5387),
    [anon_sym_Codeunit] = ACTIONS(5387),
    [anon_sym_CodeUnit] = ACTIONS(5387),
    [anon_sym_COdeunit] = ACTIONS(5387),
    [anon_sym_codeUnit] = ACTIONS(5387),
    [sym_report_keyword] = ACTIONS(5389),
    [anon_sym_reportextension] = ACTIONS(5387),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5387),
    [anon_sym_Reportextension] = ACTIONS(5387),
    [anon_sym_ReportExtension] = ACTIONS(5387),
    [anon_sym_reportExtension] = ACTIONS(5387),
    [sym_query_keyword] = ACTIONS(5387),
    [anon_sym_xmlport] = ACTIONS(5387),
    [anon_sym_XMLPORT] = ACTIONS(5387),
    [anon_sym_Xmlport] = ACTIONS(5387),
    [anon_sym_XMLport] = ACTIONS(5387),
    [anon_sym_XMLPort] = ACTIONS(5387),
    [anon_sym_XmlPort] = ACTIONS(5387),
    [anon_sym_enum] = ACTIONS(5389),
    [anon_sym_ENUM] = ACTIONS(5389),
    [anon_sym_Enum] = ACTIONS(5389),
    [anon_sym_eNUM] = ACTIONS(5387),
    [anon_sym_eNum] = ACTIONS(5387),
    [anon_sym_ENum] = ACTIONS(5387),
    [anon_sym_enumextension] = ACTIONS(5387),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5387),
    [anon_sym_Enumextension] = ACTIONS(5387),
    [anon_sym_EnumExtension] = ACTIONS(5387),
    [anon_sym_enumExtension] = ACTIONS(5387),
    [sym_interface_keyword] = ACTIONS(5387),
    [anon_sym_controladdin] = ACTIONS(5387),
    [anon_sym_CONTROLADDIN] = ACTIONS(5387),
    [anon_sym_Controladdin] = ACTIONS(5387),
    [anon_sym_ControlAddIn] = ACTIONS(5387),
    [anon_sym_ControlAddin] = ACTIONS(5387),
    [anon_sym_controlAddIn] = ACTIONS(5387),
    [anon_sym_controlAddin] = ACTIONS(5387),
    [anon_sym_dotnet] = ACTIONS(5387),
    [anon_sym_DOTNET] = ACTIONS(5387),
    [anon_sym_Dotnet] = ACTIONS(5387),
    [anon_sym_DotNet] = ACTIONS(5387),
    [anon_sym_dotNet] = ACTIONS(5387),
    [sym_profile_keyword] = ACTIONS(5389),
    [anon_sym_profileextension] = ACTIONS(5387),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5387),
    [anon_sym_Profileextension] = ACTIONS(5387),
    [anon_sym_ProfileExtension] = ACTIONS(5387),
    [anon_sym_profileExtension] = ACTIONS(5387),
    [anon_sym_permissionset] = ACTIONS(5389),
    [anon_sym_PERMISSIONSET] = ACTIONS(5389),
    [anon_sym_Permissionset] = ACTIONS(5389),
    [anon_sym_PermissionSet] = ACTIONS(5389),
    [anon_sym_permissionSet] = ACTIONS(5389),
    [anon_sym_permissionsetextension] = ACTIONS(5387),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5387),
    [anon_sym_Permissionsetextension] = ACTIONS(5387),
    [anon_sym_PermissionSetExtension] = ACTIONS(5387),
    [anon_sym_permissionSetExtension] = ACTIONS(5387),
    [sym_entitlement_keyword] = ACTIONS(5387),
    [anon_sym_pagecustomization] = ACTIONS(5387),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5387),
    [anon_sym_Pagecustomization] = ACTIONS(5387),
    [anon_sym_PageCustomization] = ACTIONS(5387),
    [anon_sym_pageCustomization] = ACTIONS(5387),
    [sym_using_keyword] = ACTIONS(5387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5387),
  },
  [STATE(2509)] = {
    [ts_builtin_sym_end] = ACTIONS(5275),
    [anon_sym_POUNDif] = ACTIONS(5275),
    [anon_sym_POUNDIF] = ACTIONS(5275),
    [anon_sym_POUNDIf] = ACTIONS(5275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5277),
    [anon_sym_tableextension] = ACTIONS(5275),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5275),
    [anon_sym_Tableextension] = ACTIONS(5275),
    [anon_sym_TableExtension] = ACTIONS(5275),
    [anon_sym_tableExtension] = ACTIONS(5275),
    [sym_page_keyword] = ACTIONS(5277),
    [anon_sym_pageextension] = ACTIONS(5275),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5275),
    [anon_sym_Pageextension] = ACTIONS(5275),
    [anon_sym_PageExtension] = ACTIONS(5275),
    [anon_sym_pageExtension] = ACTIONS(5275),
    [anon_sym_codeunit] = ACTIONS(5275),
    [anon_sym_CODEUNIT] = ACTIONS(5275),
    [anon_sym_Codeunit] = ACTIONS(5275),
    [anon_sym_CodeUnit] = ACTIONS(5275),
    [anon_sym_COdeunit] = ACTIONS(5275),
    [anon_sym_codeUnit] = ACTIONS(5275),
    [sym_report_keyword] = ACTIONS(5277),
    [anon_sym_reportextension] = ACTIONS(5275),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5275),
    [anon_sym_Reportextension] = ACTIONS(5275),
    [anon_sym_ReportExtension] = ACTIONS(5275),
    [anon_sym_reportExtension] = ACTIONS(5275),
    [sym_query_keyword] = ACTIONS(5275),
    [anon_sym_xmlport] = ACTIONS(5275),
    [anon_sym_XMLPORT] = ACTIONS(5275),
    [anon_sym_Xmlport] = ACTIONS(5275),
    [anon_sym_XMLport] = ACTIONS(5275),
    [anon_sym_XMLPort] = ACTIONS(5275),
    [anon_sym_XmlPort] = ACTIONS(5275),
    [anon_sym_enum] = ACTIONS(5277),
    [anon_sym_ENUM] = ACTIONS(5277),
    [anon_sym_Enum] = ACTIONS(5277),
    [anon_sym_eNUM] = ACTIONS(5275),
    [anon_sym_eNum] = ACTIONS(5275),
    [anon_sym_ENum] = ACTIONS(5275),
    [anon_sym_enumextension] = ACTIONS(5275),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5275),
    [anon_sym_Enumextension] = ACTIONS(5275),
    [anon_sym_EnumExtension] = ACTIONS(5275),
    [anon_sym_enumExtension] = ACTIONS(5275),
    [sym_interface_keyword] = ACTIONS(5275),
    [anon_sym_controladdin] = ACTIONS(5275),
    [anon_sym_CONTROLADDIN] = ACTIONS(5275),
    [anon_sym_Controladdin] = ACTIONS(5275),
    [anon_sym_ControlAddIn] = ACTIONS(5275),
    [anon_sym_ControlAddin] = ACTIONS(5275),
    [anon_sym_controlAddIn] = ACTIONS(5275),
    [anon_sym_controlAddin] = ACTIONS(5275),
    [anon_sym_dotnet] = ACTIONS(5275),
    [anon_sym_DOTNET] = ACTIONS(5275),
    [anon_sym_Dotnet] = ACTIONS(5275),
    [anon_sym_DotNet] = ACTIONS(5275),
    [anon_sym_dotNet] = ACTIONS(5275),
    [sym_profile_keyword] = ACTIONS(5277),
    [anon_sym_profileextension] = ACTIONS(5275),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5275),
    [anon_sym_Profileextension] = ACTIONS(5275),
    [anon_sym_ProfileExtension] = ACTIONS(5275),
    [anon_sym_profileExtension] = ACTIONS(5275),
    [anon_sym_permissionset] = ACTIONS(5277),
    [anon_sym_PERMISSIONSET] = ACTIONS(5277),
    [anon_sym_Permissionset] = ACTIONS(5277),
    [anon_sym_PermissionSet] = ACTIONS(5277),
    [anon_sym_permissionSet] = ACTIONS(5277),
    [anon_sym_permissionsetextension] = ACTIONS(5275),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5275),
    [anon_sym_Permissionsetextension] = ACTIONS(5275),
    [anon_sym_PermissionSetExtension] = ACTIONS(5275),
    [anon_sym_permissionSetExtension] = ACTIONS(5275),
    [sym_entitlement_keyword] = ACTIONS(5275),
    [anon_sym_pagecustomization] = ACTIONS(5275),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5275),
    [anon_sym_Pagecustomization] = ACTIONS(5275),
    [anon_sym_PageCustomization] = ACTIONS(5275),
    [anon_sym_pageCustomization] = ACTIONS(5275),
    [sym_using_keyword] = ACTIONS(5275),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5275),
  },
  [STATE(2510)] = {
    [ts_builtin_sym_end] = ACTIONS(5279),
    [anon_sym_POUNDif] = ACTIONS(5279),
    [anon_sym_POUNDIF] = ACTIONS(5279),
    [anon_sym_POUNDIf] = ACTIONS(5279),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5281),
    [anon_sym_tableextension] = ACTIONS(5279),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5279),
    [anon_sym_Tableextension] = ACTIONS(5279),
    [anon_sym_TableExtension] = ACTIONS(5279),
    [anon_sym_tableExtension] = ACTIONS(5279),
    [sym_page_keyword] = ACTIONS(5281),
    [anon_sym_pageextension] = ACTIONS(5279),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5279),
    [anon_sym_Pageextension] = ACTIONS(5279),
    [anon_sym_PageExtension] = ACTIONS(5279),
    [anon_sym_pageExtension] = ACTIONS(5279),
    [anon_sym_codeunit] = ACTIONS(5279),
    [anon_sym_CODEUNIT] = ACTIONS(5279),
    [anon_sym_Codeunit] = ACTIONS(5279),
    [anon_sym_CodeUnit] = ACTIONS(5279),
    [anon_sym_COdeunit] = ACTIONS(5279),
    [anon_sym_codeUnit] = ACTIONS(5279),
    [sym_report_keyword] = ACTIONS(5281),
    [anon_sym_reportextension] = ACTIONS(5279),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5279),
    [anon_sym_Reportextension] = ACTIONS(5279),
    [anon_sym_ReportExtension] = ACTIONS(5279),
    [anon_sym_reportExtension] = ACTIONS(5279),
    [sym_query_keyword] = ACTIONS(5279),
    [anon_sym_xmlport] = ACTIONS(5279),
    [anon_sym_XMLPORT] = ACTIONS(5279),
    [anon_sym_Xmlport] = ACTIONS(5279),
    [anon_sym_XMLport] = ACTIONS(5279),
    [anon_sym_XMLPort] = ACTIONS(5279),
    [anon_sym_XmlPort] = ACTIONS(5279),
    [anon_sym_enum] = ACTIONS(5281),
    [anon_sym_ENUM] = ACTIONS(5281),
    [anon_sym_Enum] = ACTIONS(5281),
    [anon_sym_eNUM] = ACTIONS(5279),
    [anon_sym_eNum] = ACTIONS(5279),
    [anon_sym_ENum] = ACTIONS(5279),
    [anon_sym_enumextension] = ACTIONS(5279),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5279),
    [anon_sym_Enumextension] = ACTIONS(5279),
    [anon_sym_EnumExtension] = ACTIONS(5279),
    [anon_sym_enumExtension] = ACTIONS(5279),
    [sym_interface_keyword] = ACTIONS(5279),
    [anon_sym_controladdin] = ACTIONS(5279),
    [anon_sym_CONTROLADDIN] = ACTIONS(5279),
    [anon_sym_Controladdin] = ACTIONS(5279),
    [anon_sym_ControlAddIn] = ACTIONS(5279),
    [anon_sym_ControlAddin] = ACTIONS(5279),
    [anon_sym_controlAddIn] = ACTIONS(5279),
    [anon_sym_controlAddin] = ACTIONS(5279),
    [anon_sym_dotnet] = ACTIONS(5279),
    [anon_sym_DOTNET] = ACTIONS(5279),
    [anon_sym_Dotnet] = ACTIONS(5279),
    [anon_sym_DotNet] = ACTIONS(5279),
    [anon_sym_dotNet] = ACTIONS(5279),
    [sym_profile_keyword] = ACTIONS(5281),
    [anon_sym_profileextension] = ACTIONS(5279),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5279),
    [anon_sym_Profileextension] = ACTIONS(5279),
    [anon_sym_ProfileExtension] = ACTIONS(5279),
    [anon_sym_profileExtension] = ACTIONS(5279),
    [anon_sym_permissionset] = ACTIONS(5281),
    [anon_sym_PERMISSIONSET] = ACTIONS(5281),
    [anon_sym_Permissionset] = ACTIONS(5281),
    [anon_sym_PermissionSet] = ACTIONS(5281),
    [anon_sym_permissionSet] = ACTIONS(5281),
    [anon_sym_permissionsetextension] = ACTIONS(5279),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5279),
    [anon_sym_Permissionsetextension] = ACTIONS(5279),
    [anon_sym_PermissionSetExtension] = ACTIONS(5279),
    [anon_sym_permissionSetExtension] = ACTIONS(5279),
    [sym_entitlement_keyword] = ACTIONS(5279),
    [anon_sym_pagecustomization] = ACTIONS(5279),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5279),
    [anon_sym_Pagecustomization] = ACTIONS(5279),
    [anon_sym_PageCustomization] = ACTIONS(5279),
    [anon_sym_pageCustomization] = ACTIONS(5279),
    [sym_using_keyword] = ACTIONS(5279),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5279),
  },
  [STATE(2511)] = {
    [ts_builtin_sym_end] = ACTIONS(5283),
    [anon_sym_POUNDif] = ACTIONS(5283),
    [anon_sym_POUNDIF] = ACTIONS(5283),
    [anon_sym_POUNDIf] = ACTIONS(5283),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5285),
    [anon_sym_tableextension] = ACTIONS(5283),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5283),
    [anon_sym_Tableextension] = ACTIONS(5283),
    [anon_sym_TableExtension] = ACTIONS(5283),
    [anon_sym_tableExtension] = ACTIONS(5283),
    [sym_page_keyword] = ACTIONS(5285),
    [anon_sym_pageextension] = ACTIONS(5283),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5283),
    [anon_sym_Pageextension] = ACTIONS(5283),
    [anon_sym_PageExtension] = ACTIONS(5283),
    [anon_sym_pageExtension] = ACTIONS(5283),
    [anon_sym_codeunit] = ACTIONS(5283),
    [anon_sym_CODEUNIT] = ACTIONS(5283),
    [anon_sym_Codeunit] = ACTIONS(5283),
    [anon_sym_CodeUnit] = ACTIONS(5283),
    [anon_sym_COdeunit] = ACTIONS(5283),
    [anon_sym_codeUnit] = ACTIONS(5283),
    [sym_report_keyword] = ACTIONS(5285),
    [anon_sym_reportextension] = ACTIONS(5283),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5283),
    [anon_sym_Reportextension] = ACTIONS(5283),
    [anon_sym_ReportExtension] = ACTIONS(5283),
    [anon_sym_reportExtension] = ACTIONS(5283),
    [sym_query_keyword] = ACTIONS(5283),
    [anon_sym_xmlport] = ACTIONS(5283),
    [anon_sym_XMLPORT] = ACTIONS(5283),
    [anon_sym_Xmlport] = ACTIONS(5283),
    [anon_sym_XMLport] = ACTIONS(5283),
    [anon_sym_XMLPort] = ACTIONS(5283),
    [anon_sym_XmlPort] = ACTIONS(5283),
    [anon_sym_enum] = ACTIONS(5285),
    [anon_sym_ENUM] = ACTIONS(5285),
    [anon_sym_Enum] = ACTIONS(5285),
    [anon_sym_eNUM] = ACTIONS(5283),
    [anon_sym_eNum] = ACTIONS(5283),
    [anon_sym_ENum] = ACTIONS(5283),
    [anon_sym_enumextension] = ACTIONS(5283),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5283),
    [anon_sym_Enumextension] = ACTIONS(5283),
    [anon_sym_EnumExtension] = ACTIONS(5283),
    [anon_sym_enumExtension] = ACTIONS(5283),
    [sym_interface_keyword] = ACTIONS(5283),
    [anon_sym_controladdin] = ACTIONS(5283),
    [anon_sym_CONTROLADDIN] = ACTIONS(5283),
    [anon_sym_Controladdin] = ACTIONS(5283),
    [anon_sym_ControlAddIn] = ACTIONS(5283),
    [anon_sym_ControlAddin] = ACTIONS(5283),
    [anon_sym_controlAddIn] = ACTIONS(5283),
    [anon_sym_controlAddin] = ACTIONS(5283),
    [anon_sym_dotnet] = ACTIONS(5283),
    [anon_sym_DOTNET] = ACTIONS(5283),
    [anon_sym_Dotnet] = ACTIONS(5283),
    [anon_sym_DotNet] = ACTIONS(5283),
    [anon_sym_dotNet] = ACTIONS(5283),
    [sym_profile_keyword] = ACTIONS(5285),
    [anon_sym_profileextension] = ACTIONS(5283),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5283),
    [anon_sym_Profileextension] = ACTIONS(5283),
    [anon_sym_ProfileExtension] = ACTIONS(5283),
    [anon_sym_profileExtension] = ACTIONS(5283),
    [anon_sym_permissionset] = ACTIONS(5285),
    [anon_sym_PERMISSIONSET] = ACTIONS(5285),
    [anon_sym_Permissionset] = ACTIONS(5285),
    [anon_sym_PermissionSet] = ACTIONS(5285),
    [anon_sym_permissionSet] = ACTIONS(5285),
    [anon_sym_permissionsetextension] = ACTIONS(5283),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5283),
    [anon_sym_Permissionsetextension] = ACTIONS(5283),
    [anon_sym_PermissionSetExtension] = ACTIONS(5283),
    [anon_sym_permissionSetExtension] = ACTIONS(5283),
    [sym_entitlement_keyword] = ACTIONS(5283),
    [anon_sym_pagecustomization] = ACTIONS(5283),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5283),
    [anon_sym_Pagecustomization] = ACTIONS(5283),
    [anon_sym_PageCustomization] = ACTIONS(5283),
    [anon_sym_pageCustomization] = ACTIONS(5283),
    [sym_using_keyword] = ACTIONS(5283),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5283),
  },
  [STATE(2512)] = {
    [ts_builtin_sym_end] = ACTIONS(5287),
    [anon_sym_POUNDif] = ACTIONS(5287),
    [anon_sym_POUNDIF] = ACTIONS(5287),
    [anon_sym_POUNDIf] = ACTIONS(5287),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5289),
    [anon_sym_tableextension] = ACTIONS(5287),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5287),
    [anon_sym_Tableextension] = ACTIONS(5287),
    [anon_sym_TableExtension] = ACTIONS(5287),
    [anon_sym_tableExtension] = ACTIONS(5287),
    [sym_page_keyword] = ACTIONS(5289),
    [anon_sym_pageextension] = ACTIONS(5287),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5287),
    [anon_sym_Pageextension] = ACTIONS(5287),
    [anon_sym_PageExtension] = ACTIONS(5287),
    [anon_sym_pageExtension] = ACTIONS(5287),
    [anon_sym_codeunit] = ACTIONS(5287),
    [anon_sym_CODEUNIT] = ACTIONS(5287),
    [anon_sym_Codeunit] = ACTIONS(5287),
    [anon_sym_CodeUnit] = ACTIONS(5287),
    [anon_sym_COdeunit] = ACTIONS(5287),
    [anon_sym_codeUnit] = ACTIONS(5287),
    [sym_report_keyword] = ACTIONS(5289),
    [anon_sym_reportextension] = ACTIONS(5287),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5287),
    [anon_sym_Reportextension] = ACTIONS(5287),
    [anon_sym_ReportExtension] = ACTIONS(5287),
    [anon_sym_reportExtension] = ACTIONS(5287),
    [sym_query_keyword] = ACTIONS(5287),
    [anon_sym_xmlport] = ACTIONS(5287),
    [anon_sym_XMLPORT] = ACTIONS(5287),
    [anon_sym_Xmlport] = ACTIONS(5287),
    [anon_sym_XMLport] = ACTIONS(5287),
    [anon_sym_XMLPort] = ACTIONS(5287),
    [anon_sym_XmlPort] = ACTIONS(5287),
    [anon_sym_enum] = ACTIONS(5289),
    [anon_sym_ENUM] = ACTIONS(5289),
    [anon_sym_Enum] = ACTIONS(5289),
    [anon_sym_eNUM] = ACTIONS(5287),
    [anon_sym_eNum] = ACTIONS(5287),
    [anon_sym_ENum] = ACTIONS(5287),
    [anon_sym_enumextension] = ACTIONS(5287),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5287),
    [anon_sym_Enumextension] = ACTIONS(5287),
    [anon_sym_EnumExtension] = ACTIONS(5287),
    [anon_sym_enumExtension] = ACTIONS(5287),
    [sym_interface_keyword] = ACTIONS(5287),
    [anon_sym_controladdin] = ACTIONS(5287),
    [anon_sym_CONTROLADDIN] = ACTIONS(5287),
    [anon_sym_Controladdin] = ACTIONS(5287),
    [anon_sym_ControlAddIn] = ACTIONS(5287),
    [anon_sym_ControlAddin] = ACTIONS(5287),
    [anon_sym_controlAddIn] = ACTIONS(5287),
    [anon_sym_controlAddin] = ACTIONS(5287),
    [anon_sym_dotnet] = ACTIONS(5287),
    [anon_sym_DOTNET] = ACTIONS(5287),
    [anon_sym_Dotnet] = ACTIONS(5287),
    [anon_sym_DotNet] = ACTIONS(5287),
    [anon_sym_dotNet] = ACTIONS(5287),
    [sym_profile_keyword] = ACTIONS(5289),
    [anon_sym_profileextension] = ACTIONS(5287),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5287),
    [anon_sym_Profileextension] = ACTIONS(5287),
    [anon_sym_ProfileExtension] = ACTIONS(5287),
    [anon_sym_profileExtension] = ACTIONS(5287),
    [anon_sym_permissionset] = ACTIONS(5289),
    [anon_sym_PERMISSIONSET] = ACTIONS(5289),
    [anon_sym_Permissionset] = ACTIONS(5289),
    [anon_sym_PermissionSet] = ACTIONS(5289),
    [anon_sym_permissionSet] = ACTIONS(5289),
    [anon_sym_permissionsetextension] = ACTIONS(5287),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5287),
    [anon_sym_Permissionsetextension] = ACTIONS(5287),
    [anon_sym_PermissionSetExtension] = ACTIONS(5287),
    [anon_sym_permissionSetExtension] = ACTIONS(5287),
    [sym_entitlement_keyword] = ACTIONS(5287),
    [anon_sym_pagecustomization] = ACTIONS(5287),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5287),
    [anon_sym_Pagecustomization] = ACTIONS(5287),
    [anon_sym_PageCustomization] = ACTIONS(5287),
    [anon_sym_pageCustomization] = ACTIONS(5287),
    [sym_using_keyword] = ACTIONS(5287),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5287),
  },
  [STATE(2513)] = {
    [ts_builtin_sym_end] = ACTIONS(5021),
    [anon_sym_POUNDif] = ACTIONS(5021),
    [anon_sym_POUNDIF] = ACTIONS(5021),
    [anon_sym_POUNDIf] = ACTIONS(5021),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5023),
    [anon_sym_tableextension] = ACTIONS(5021),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5021),
    [anon_sym_Tableextension] = ACTIONS(5021),
    [anon_sym_TableExtension] = ACTIONS(5021),
    [anon_sym_tableExtension] = ACTIONS(5021),
    [sym_page_keyword] = ACTIONS(5023),
    [anon_sym_pageextension] = ACTIONS(5021),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5021),
    [anon_sym_Pageextension] = ACTIONS(5021),
    [anon_sym_PageExtension] = ACTIONS(5021),
    [anon_sym_pageExtension] = ACTIONS(5021),
    [anon_sym_codeunit] = ACTIONS(5021),
    [anon_sym_CODEUNIT] = ACTIONS(5021),
    [anon_sym_Codeunit] = ACTIONS(5021),
    [anon_sym_CodeUnit] = ACTIONS(5021),
    [anon_sym_COdeunit] = ACTIONS(5021),
    [anon_sym_codeUnit] = ACTIONS(5021),
    [sym_report_keyword] = ACTIONS(5023),
    [anon_sym_reportextension] = ACTIONS(5021),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5021),
    [anon_sym_Reportextension] = ACTIONS(5021),
    [anon_sym_ReportExtension] = ACTIONS(5021),
    [anon_sym_reportExtension] = ACTIONS(5021),
    [sym_query_keyword] = ACTIONS(5021),
    [anon_sym_xmlport] = ACTIONS(5021),
    [anon_sym_XMLPORT] = ACTIONS(5021),
    [anon_sym_Xmlport] = ACTIONS(5021),
    [anon_sym_XMLport] = ACTIONS(5021),
    [anon_sym_XMLPort] = ACTIONS(5021),
    [anon_sym_XmlPort] = ACTIONS(5021),
    [anon_sym_enum] = ACTIONS(5023),
    [anon_sym_ENUM] = ACTIONS(5023),
    [anon_sym_Enum] = ACTIONS(5023),
    [anon_sym_eNUM] = ACTIONS(5021),
    [anon_sym_eNum] = ACTIONS(5021),
    [anon_sym_ENum] = ACTIONS(5021),
    [anon_sym_enumextension] = ACTIONS(5021),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5021),
    [anon_sym_Enumextension] = ACTIONS(5021),
    [anon_sym_EnumExtension] = ACTIONS(5021),
    [anon_sym_enumExtension] = ACTIONS(5021),
    [sym_interface_keyword] = ACTIONS(5021),
    [anon_sym_controladdin] = ACTIONS(5021),
    [anon_sym_CONTROLADDIN] = ACTIONS(5021),
    [anon_sym_Controladdin] = ACTIONS(5021),
    [anon_sym_ControlAddIn] = ACTIONS(5021),
    [anon_sym_ControlAddin] = ACTIONS(5021),
    [anon_sym_controlAddIn] = ACTIONS(5021),
    [anon_sym_controlAddin] = ACTIONS(5021),
    [anon_sym_dotnet] = ACTIONS(5021),
    [anon_sym_DOTNET] = ACTIONS(5021),
    [anon_sym_Dotnet] = ACTIONS(5021),
    [anon_sym_DotNet] = ACTIONS(5021),
    [anon_sym_dotNet] = ACTIONS(5021),
    [sym_profile_keyword] = ACTIONS(5023),
    [anon_sym_profileextension] = ACTIONS(5021),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5021),
    [anon_sym_Profileextension] = ACTIONS(5021),
    [anon_sym_ProfileExtension] = ACTIONS(5021),
    [anon_sym_profileExtension] = ACTIONS(5021),
    [anon_sym_permissionset] = ACTIONS(5023),
    [anon_sym_PERMISSIONSET] = ACTIONS(5023),
    [anon_sym_Permissionset] = ACTIONS(5023),
    [anon_sym_PermissionSet] = ACTIONS(5023),
    [anon_sym_permissionSet] = ACTIONS(5023),
    [anon_sym_permissionsetextension] = ACTIONS(5021),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5021),
    [anon_sym_Permissionsetextension] = ACTIONS(5021),
    [anon_sym_PermissionSetExtension] = ACTIONS(5021),
    [anon_sym_permissionSetExtension] = ACTIONS(5021),
    [sym_entitlement_keyword] = ACTIONS(5021),
    [anon_sym_pagecustomization] = ACTIONS(5021),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5021),
    [anon_sym_Pagecustomization] = ACTIONS(5021),
    [anon_sym_PageCustomization] = ACTIONS(5021),
    [anon_sym_pageCustomization] = ACTIONS(5021),
    [sym_using_keyword] = ACTIONS(5021),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5021),
  },
  [STATE(2514)] = {
    [ts_builtin_sym_end] = ACTIONS(5025),
    [anon_sym_POUNDif] = ACTIONS(5025),
    [anon_sym_POUNDIF] = ACTIONS(5025),
    [anon_sym_POUNDIf] = ACTIONS(5025),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5027),
    [anon_sym_tableextension] = ACTIONS(5025),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5025),
    [anon_sym_Tableextension] = ACTIONS(5025),
    [anon_sym_TableExtension] = ACTIONS(5025),
    [anon_sym_tableExtension] = ACTIONS(5025),
    [sym_page_keyword] = ACTIONS(5027),
    [anon_sym_pageextension] = ACTIONS(5025),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5025),
    [anon_sym_Pageextension] = ACTIONS(5025),
    [anon_sym_PageExtension] = ACTIONS(5025),
    [anon_sym_pageExtension] = ACTIONS(5025),
    [anon_sym_codeunit] = ACTIONS(5025),
    [anon_sym_CODEUNIT] = ACTIONS(5025),
    [anon_sym_Codeunit] = ACTIONS(5025),
    [anon_sym_CodeUnit] = ACTIONS(5025),
    [anon_sym_COdeunit] = ACTIONS(5025),
    [anon_sym_codeUnit] = ACTIONS(5025),
    [sym_report_keyword] = ACTIONS(5027),
    [anon_sym_reportextension] = ACTIONS(5025),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5025),
    [anon_sym_Reportextension] = ACTIONS(5025),
    [anon_sym_ReportExtension] = ACTIONS(5025),
    [anon_sym_reportExtension] = ACTIONS(5025),
    [sym_query_keyword] = ACTIONS(5025),
    [anon_sym_xmlport] = ACTIONS(5025),
    [anon_sym_XMLPORT] = ACTIONS(5025),
    [anon_sym_Xmlport] = ACTIONS(5025),
    [anon_sym_XMLport] = ACTIONS(5025),
    [anon_sym_XMLPort] = ACTIONS(5025),
    [anon_sym_XmlPort] = ACTIONS(5025),
    [anon_sym_enum] = ACTIONS(5027),
    [anon_sym_ENUM] = ACTIONS(5027),
    [anon_sym_Enum] = ACTIONS(5027),
    [anon_sym_eNUM] = ACTIONS(5025),
    [anon_sym_eNum] = ACTIONS(5025),
    [anon_sym_ENum] = ACTIONS(5025),
    [anon_sym_enumextension] = ACTIONS(5025),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5025),
    [anon_sym_Enumextension] = ACTIONS(5025),
    [anon_sym_EnumExtension] = ACTIONS(5025),
    [anon_sym_enumExtension] = ACTIONS(5025),
    [sym_interface_keyword] = ACTIONS(5025),
    [anon_sym_controladdin] = ACTIONS(5025),
    [anon_sym_CONTROLADDIN] = ACTIONS(5025),
    [anon_sym_Controladdin] = ACTIONS(5025),
    [anon_sym_ControlAddIn] = ACTIONS(5025),
    [anon_sym_ControlAddin] = ACTIONS(5025),
    [anon_sym_controlAddIn] = ACTIONS(5025),
    [anon_sym_controlAddin] = ACTIONS(5025),
    [anon_sym_dotnet] = ACTIONS(5025),
    [anon_sym_DOTNET] = ACTIONS(5025),
    [anon_sym_Dotnet] = ACTIONS(5025),
    [anon_sym_DotNet] = ACTIONS(5025),
    [anon_sym_dotNet] = ACTIONS(5025),
    [sym_profile_keyword] = ACTIONS(5027),
    [anon_sym_profileextension] = ACTIONS(5025),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5025),
    [anon_sym_Profileextension] = ACTIONS(5025),
    [anon_sym_ProfileExtension] = ACTIONS(5025),
    [anon_sym_profileExtension] = ACTIONS(5025),
    [anon_sym_permissionset] = ACTIONS(5027),
    [anon_sym_PERMISSIONSET] = ACTIONS(5027),
    [anon_sym_Permissionset] = ACTIONS(5027),
    [anon_sym_PermissionSet] = ACTIONS(5027),
    [anon_sym_permissionSet] = ACTIONS(5027),
    [anon_sym_permissionsetextension] = ACTIONS(5025),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5025),
    [anon_sym_Permissionsetextension] = ACTIONS(5025),
    [anon_sym_PermissionSetExtension] = ACTIONS(5025),
    [anon_sym_permissionSetExtension] = ACTIONS(5025),
    [sym_entitlement_keyword] = ACTIONS(5025),
    [anon_sym_pagecustomization] = ACTIONS(5025),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5025),
    [anon_sym_Pagecustomization] = ACTIONS(5025),
    [anon_sym_PageCustomization] = ACTIONS(5025),
    [anon_sym_pageCustomization] = ACTIONS(5025),
    [sym_using_keyword] = ACTIONS(5025),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5025),
  },
  [STATE(2515)] = {
    [ts_builtin_sym_end] = ACTIONS(5029),
    [anon_sym_POUNDif] = ACTIONS(5029),
    [anon_sym_POUNDIF] = ACTIONS(5029),
    [anon_sym_POUNDIf] = ACTIONS(5029),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5031),
    [anon_sym_tableextension] = ACTIONS(5029),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5029),
    [anon_sym_Tableextension] = ACTIONS(5029),
    [anon_sym_TableExtension] = ACTIONS(5029),
    [anon_sym_tableExtension] = ACTIONS(5029),
    [sym_page_keyword] = ACTIONS(5031),
    [anon_sym_pageextension] = ACTIONS(5029),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5029),
    [anon_sym_Pageextension] = ACTIONS(5029),
    [anon_sym_PageExtension] = ACTIONS(5029),
    [anon_sym_pageExtension] = ACTIONS(5029),
    [anon_sym_codeunit] = ACTIONS(5029),
    [anon_sym_CODEUNIT] = ACTIONS(5029),
    [anon_sym_Codeunit] = ACTIONS(5029),
    [anon_sym_CodeUnit] = ACTIONS(5029),
    [anon_sym_COdeunit] = ACTIONS(5029),
    [anon_sym_codeUnit] = ACTIONS(5029),
    [sym_report_keyword] = ACTIONS(5031),
    [anon_sym_reportextension] = ACTIONS(5029),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5029),
    [anon_sym_Reportextension] = ACTIONS(5029),
    [anon_sym_ReportExtension] = ACTIONS(5029),
    [anon_sym_reportExtension] = ACTIONS(5029),
    [sym_query_keyword] = ACTIONS(5029),
    [anon_sym_xmlport] = ACTIONS(5029),
    [anon_sym_XMLPORT] = ACTIONS(5029),
    [anon_sym_Xmlport] = ACTIONS(5029),
    [anon_sym_XMLport] = ACTIONS(5029),
    [anon_sym_XMLPort] = ACTIONS(5029),
    [anon_sym_XmlPort] = ACTIONS(5029),
    [anon_sym_enum] = ACTIONS(5031),
    [anon_sym_ENUM] = ACTIONS(5031),
    [anon_sym_Enum] = ACTIONS(5031),
    [anon_sym_eNUM] = ACTIONS(5029),
    [anon_sym_eNum] = ACTIONS(5029),
    [anon_sym_ENum] = ACTIONS(5029),
    [anon_sym_enumextension] = ACTIONS(5029),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5029),
    [anon_sym_Enumextension] = ACTIONS(5029),
    [anon_sym_EnumExtension] = ACTIONS(5029),
    [anon_sym_enumExtension] = ACTIONS(5029),
    [sym_interface_keyword] = ACTIONS(5029),
    [anon_sym_controladdin] = ACTIONS(5029),
    [anon_sym_CONTROLADDIN] = ACTIONS(5029),
    [anon_sym_Controladdin] = ACTIONS(5029),
    [anon_sym_ControlAddIn] = ACTIONS(5029),
    [anon_sym_ControlAddin] = ACTIONS(5029),
    [anon_sym_controlAddIn] = ACTIONS(5029),
    [anon_sym_controlAddin] = ACTIONS(5029),
    [anon_sym_dotnet] = ACTIONS(5029),
    [anon_sym_DOTNET] = ACTIONS(5029),
    [anon_sym_Dotnet] = ACTIONS(5029),
    [anon_sym_DotNet] = ACTIONS(5029),
    [anon_sym_dotNet] = ACTIONS(5029),
    [sym_profile_keyword] = ACTIONS(5031),
    [anon_sym_profileextension] = ACTIONS(5029),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5029),
    [anon_sym_Profileextension] = ACTIONS(5029),
    [anon_sym_ProfileExtension] = ACTIONS(5029),
    [anon_sym_profileExtension] = ACTIONS(5029),
    [anon_sym_permissionset] = ACTIONS(5031),
    [anon_sym_PERMISSIONSET] = ACTIONS(5031),
    [anon_sym_Permissionset] = ACTIONS(5031),
    [anon_sym_PermissionSet] = ACTIONS(5031),
    [anon_sym_permissionSet] = ACTIONS(5031),
    [anon_sym_permissionsetextension] = ACTIONS(5029),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5029),
    [anon_sym_Permissionsetextension] = ACTIONS(5029),
    [anon_sym_PermissionSetExtension] = ACTIONS(5029),
    [anon_sym_permissionSetExtension] = ACTIONS(5029),
    [sym_entitlement_keyword] = ACTIONS(5029),
    [anon_sym_pagecustomization] = ACTIONS(5029),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5029),
    [anon_sym_Pagecustomization] = ACTIONS(5029),
    [anon_sym_PageCustomization] = ACTIONS(5029),
    [anon_sym_pageCustomization] = ACTIONS(5029),
    [sym_using_keyword] = ACTIONS(5029),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5029),
  },
  [STATE(2516)] = {
    [ts_builtin_sym_end] = ACTIONS(5065),
    [anon_sym_POUNDif] = ACTIONS(5065),
    [anon_sym_POUNDIF] = ACTIONS(5065),
    [anon_sym_POUNDIf] = ACTIONS(5065),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5067),
    [anon_sym_tableextension] = ACTIONS(5065),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5065),
    [anon_sym_Tableextension] = ACTIONS(5065),
    [anon_sym_TableExtension] = ACTIONS(5065),
    [anon_sym_tableExtension] = ACTIONS(5065),
    [sym_page_keyword] = ACTIONS(5067),
    [anon_sym_pageextension] = ACTIONS(5065),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5065),
    [anon_sym_Pageextension] = ACTIONS(5065),
    [anon_sym_PageExtension] = ACTIONS(5065),
    [anon_sym_pageExtension] = ACTIONS(5065),
    [anon_sym_codeunit] = ACTIONS(5065),
    [anon_sym_CODEUNIT] = ACTIONS(5065),
    [anon_sym_Codeunit] = ACTIONS(5065),
    [anon_sym_CodeUnit] = ACTIONS(5065),
    [anon_sym_COdeunit] = ACTIONS(5065),
    [anon_sym_codeUnit] = ACTIONS(5065),
    [sym_report_keyword] = ACTIONS(5067),
    [anon_sym_reportextension] = ACTIONS(5065),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5065),
    [anon_sym_Reportextension] = ACTIONS(5065),
    [anon_sym_ReportExtension] = ACTIONS(5065),
    [anon_sym_reportExtension] = ACTIONS(5065),
    [sym_query_keyword] = ACTIONS(5065),
    [anon_sym_xmlport] = ACTIONS(5065),
    [anon_sym_XMLPORT] = ACTIONS(5065),
    [anon_sym_Xmlport] = ACTIONS(5065),
    [anon_sym_XMLport] = ACTIONS(5065),
    [anon_sym_XMLPort] = ACTIONS(5065),
    [anon_sym_XmlPort] = ACTIONS(5065),
    [anon_sym_enum] = ACTIONS(5067),
    [anon_sym_ENUM] = ACTIONS(5067),
    [anon_sym_Enum] = ACTIONS(5067),
    [anon_sym_eNUM] = ACTIONS(5065),
    [anon_sym_eNum] = ACTIONS(5065),
    [anon_sym_ENum] = ACTIONS(5065),
    [anon_sym_enumextension] = ACTIONS(5065),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5065),
    [anon_sym_Enumextension] = ACTIONS(5065),
    [anon_sym_EnumExtension] = ACTIONS(5065),
    [anon_sym_enumExtension] = ACTIONS(5065),
    [sym_interface_keyword] = ACTIONS(5065),
    [anon_sym_controladdin] = ACTIONS(5065),
    [anon_sym_CONTROLADDIN] = ACTIONS(5065),
    [anon_sym_Controladdin] = ACTIONS(5065),
    [anon_sym_ControlAddIn] = ACTIONS(5065),
    [anon_sym_ControlAddin] = ACTIONS(5065),
    [anon_sym_controlAddIn] = ACTIONS(5065),
    [anon_sym_controlAddin] = ACTIONS(5065),
    [anon_sym_dotnet] = ACTIONS(5065),
    [anon_sym_DOTNET] = ACTIONS(5065),
    [anon_sym_Dotnet] = ACTIONS(5065),
    [anon_sym_DotNet] = ACTIONS(5065),
    [anon_sym_dotNet] = ACTIONS(5065),
    [sym_profile_keyword] = ACTIONS(5067),
    [anon_sym_profileextension] = ACTIONS(5065),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5065),
    [anon_sym_Profileextension] = ACTIONS(5065),
    [anon_sym_ProfileExtension] = ACTIONS(5065),
    [anon_sym_profileExtension] = ACTIONS(5065),
    [anon_sym_permissionset] = ACTIONS(5067),
    [anon_sym_PERMISSIONSET] = ACTIONS(5067),
    [anon_sym_Permissionset] = ACTIONS(5067),
    [anon_sym_PermissionSet] = ACTIONS(5067),
    [anon_sym_permissionSet] = ACTIONS(5067),
    [anon_sym_permissionsetextension] = ACTIONS(5065),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5065),
    [anon_sym_Permissionsetextension] = ACTIONS(5065),
    [anon_sym_PermissionSetExtension] = ACTIONS(5065),
    [anon_sym_permissionSetExtension] = ACTIONS(5065),
    [sym_entitlement_keyword] = ACTIONS(5065),
    [anon_sym_pagecustomization] = ACTIONS(5065),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5065),
    [anon_sym_Pagecustomization] = ACTIONS(5065),
    [anon_sym_PageCustomization] = ACTIONS(5065),
    [anon_sym_pageCustomization] = ACTIONS(5065),
    [sym_using_keyword] = ACTIONS(5065),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5065),
  },
  [STATE(2517)] = {
    [ts_builtin_sym_end] = ACTIONS(5069),
    [anon_sym_POUNDif] = ACTIONS(5069),
    [anon_sym_POUNDIF] = ACTIONS(5069),
    [anon_sym_POUNDIf] = ACTIONS(5069),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5071),
    [anon_sym_tableextension] = ACTIONS(5069),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5069),
    [anon_sym_Tableextension] = ACTIONS(5069),
    [anon_sym_TableExtension] = ACTIONS(5069),
    [anon_sym_tableExtension] = ACTIONS(5069),
    [sym_page_keyword] = ACTIONS(5071),
    [anon_sym_pageextension] = ACTIONS(5069),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5069),
    [anon_sym_Pageextension] = ACTIONS(5069),
    [anon_sym_PageExtension] = ACTIONS(5069),
    [anon_sym_pageExtension] = ACTIONS(5069),
    [anon_sym_codeunit] = ACTIONS(5069),
    [anon_sym_CODEUNIT] = ACTIONS(5069),
    [anon_sym_Codeunit] = ACTIONS(5069),
    [anon_sym_CodeUnit] = ACTIONS(5069),
    [anon_sym_COdeunit] = ACTIONS(5069),
    [anon_sym_codeUnit] = ACTIONS(5069),
    [sym_report_keyword] = ACTIONS(5071),
    [anon_sym_reportextension] = ACTIONS(5069),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5069),
    [anon_sym_Reportextension] = ACTIONS(5069),
    [anon_sym_ReportExtension] = ACTIONS(5069),
    [anon_sym_reportExtension] = ACTIONS(5069),
    [sym_query_keyword] = ACTIONS(5069),
    [anon_sym_xmlport] = ACTIONS(5069),
    [anon_sym_XMLPORT] = ACTIONS(5069),
    [anon_sym_Xmlport] = ACTIONS(5069),
    [anon_sym_XMLport] = ACTIONS(5069),
    [anon_sym_XMLPort] = ACTIONS(5069),
    [anon_sym_XmlPort] = ACTIONS(5069),
    [anon_sym_enum] = ACTIONS(5071),
    [anon_sym_ENUM] = ACTIONS(5071),
    [anon_sym_Enum] = ACTIONS(5071),
    [anon_sym_eNUM] = ACTIONS(5069),
    [anon_sym_eNum] = ACTIONS(5069),
    [anon_sym_ENum] = ACTIONS(5069),
    [anon_sym_enumextension] = ACTIONS(5069),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5069),
    [anon_sym_Enumextension] = ACTIONS(5069),
    [anon_sym_EnumExtension] = ACTIONS(5069),
    [anon_sym_enumExtension] = ACTIONS(5069),
    [sym_interface_keyword] = ACTIONS(5069),
    [anon_sym_controladdin] = ACTIONS(5069),
    [anon_sym_CONTROLADDIN] = ACTIONS(5069),
    [anon_sym_Controladdin] = ACTIONS(5069),
    [anon_sym_ControlAddIn] = ACTIONS(5069),
    [anon_sym_ControlAddin] = ACTIONS(5069),
    [anon_sym_controlAddIn] = ACTIONS(5069),
    [anon_sym_controlAddin] = ACTIONS(5069),
    [anon_sym_dotnet] = ACTIONS(5069),
    [anon_sym_DOTNET] = ACTIONS(5069),
    [anon_sym_Dotnet] = ACTIONS(5069),
    [anon_sym_DotNet] = ACTIONS(5069),
    [anon_sym_dotNet] = ACTIONS(5069),
    [sym_profile_keyword] = ACTIONS(5071),
    [anon_sym_profileextension] = ACTIONS(5069),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5069),
    [anon_sym_Profileextension] = ACTIONS(5069),
    [anon_sym_ProfileExtension] = ACTIONS(5069),
    [anon_sym_profileExtension] = ACTIONS(5069),
    [anon_sym_permissionset] = ACTIONS(5071),
    [anon_sym_PERMISSIONSET] = ACTIONS(5071),
    [anon_sym_Permissionset] = ACTIONS(5071),
    [anon_sym_PermissionSet] = ACTIONS(5071),
    [anon_sym_permissionSet] = ACTIONS(5071),
    [anon_sym_permissionsetextension] = ACTIONS(5069),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5069),
    [anon_sym_Permissionsetextension] = ACTIONS(5069),
    [anon_sym_PermissionSetExtension] = ACTIONS(5069),
    [anon_sym_permissionSetExtension] = ACTIONS(5069),
    [sym_entitlement_keyword] = ACTIONS(5069),
    [anon_sym_pagecustomization] = ACTIONS(5069),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5069),
    [anon_sym_Pagecustomization] = ACTIONS(5069),
    [anon_sym_PageCustomization] = ACTIONS(5069),
    [anon_sym_pageCustomization] = ACTIONS(5069),
    [sym_using_keyword] = ACTIONS(5069),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5069),
  },
  [STATE(2518)] = {
    [ts_builtin_sym_end] = ACTIONS(5073),
    [anon_sym_POUNDif] = ACTIONS(5073),
    [anon_sym_POUNDIF] = ACTIONS(5073),
    [anon_sym_POUNDIf] = ACTIONS(5073),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5075),
    [anon_sym_tableextension] = ACTIONS(5073),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5073),
    [anon_sym_Tableextension] = ACTIONS(5073),
    [anon_sym_TableExtension] = ACTIONS(5073),
    [anon_sym_tableExtension] = ACTIONS(5073),
    [sym_page_keyword] = ACTIONS(5075),
    [anon_sym_pageextension] = ACTIONS(5073),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5073),
    [anon_sym_Pageextension] = ACTIONS(5073),
    [anon_sym_PageExtension] = ACTIONS(5073),
    [anon_sym_pageExtension] = ACTIONS(5073),
    [anon_sym_codeunit] = ACTIONS(5073),
    [anon_sym_CODEUNIT] = ACTIONS(5073),
    [anon_sym_Codeunit] = ACTIONS(5073),
    [anon_sym_CodeUnit] = ACTIONS(5073),
    [anon_sym_COdeunit] = ACTIONS(5073),
    [anon_sym_codeUnit] = ACTIONS(5073),
    [sym_report_keyword] = ACTIONS(5075),
    [anon_sym_reportextension] = ACTIONS(5073),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5073),
    [anon_sym_Reportextension] = ACTIONS(5073),
    [anon_sym_ReportExtension] = ACTIONS(5073),
    [anon_sym_reportExtension] = ACTIONS(5073),
    [sym_query_keyword] = ACTIONS(5073),
    [anon_sym_xmlport] = ACTIONS(5073),
    [anon_sym_XMLPORT] = ACTIONS(5073),
    [anon_sym_Xmlport] = ACTIONS(5073),
    [anon_sym_XMLport] = ACTIONS(5073),
    [anon_sym_XMLPort] = ACTIONS(5073),
    [anon_sym_XmlPort] = ACTIONS(5073),
    [anon_sym_enum] = ACTIONS(5075),
    [anon_sym_ENUM] = ACTIONS(5075),
    [anon_sym_Enum] = ACTIONS(5075),
    [anon_sym_eNUM] = ACTIONS(5073),
    [anon_sym_eNum] = ACTIONS(5073),
    [anon_sym_ENum] = ACTIONS(5073),
    [anon_sym_enumextension] = ACTIONS(5073),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5073),
    [anon_sym_Enumextension] = ACTIONS(5073),
    [anon_sym_EnumExtension] = ACTIONS(5073),
    [anon_sym_enumExtension] = ACTIONS(5073),
    [sym_interface_keyword] = ACTIONS(5073),
    [anon_sym_controladdin] = ACTIONS(5073),
    [anon_sym_CONTROLADDIN] = ACTIONS(5073),
    [anon_sym_Controladdin] = ACTIONS(5073),
    [anon_sym_ControlAddIn] = ACTIONS(5073),
    [anon_sym_ControlAddin] = ACTIONS(5073),
    [anon_sym_controlAddIn] = ACTIONS(5073),
    [anon_sym_controlAddin] = ACTIONS(5073),
    [anon_sym_dotnet] = ACTIONS(5073),
    [anon_sym_DOTNET] = ACTIONS(5073),
    [anon_sym_Dotnet] = ACTIONS(5073),
    [anon_sym_DotNet] = ACTIONS(5073),
    [anon_sym_dotNet] = ACTIONS(5073),
    [sym_profile_keyword] = ACTIONS(5075),
    [anon_sym_profileextension] = ACTIONS(5073),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5073),
    [anon_sym_Profileextension] = ACTIONS(5073),
    [anon_sym_ProfileExtension] = ACTIONS(5073),
    [anon_sym_profileExtension] = ACTIONS(5073),
    [anon_sym_permissionset] = ACTIONS(5075),
    [anon_sym_PERMISSIONSET] = ACTIONS(5075),
    [anon_sym_Permissionset] = ACTIONS(5075),
    [anon_sym_PermissionSet] = ACTIONS(5075),
    [anon_sym_permissionSet] = ACTIONS(5075),
    [anon_sym_permissionsetextension] = ACTIONS(5073),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5073),
    [anon_sym_Permissionsetextension] = ACTIONS(5073),
    [anon_sym_PermissionSetExtension] = ACTIONS(5073),
    [anon_sym_permissionSetExtension] = ACTIONS(5073),
    [sym_entitlement_keyword] = ACTIONS(5073),
    [anon_sym_pagecustomization] = ACTIONS(5073),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5073),
    [anon_sym_Pagecustomization] = ACTIONS(5073),
    [anon_sym_PageCustomization] = ACTIONS(5073),
    [anon_sym_pageCustomization] = ACTIONS(5073),
    [sym_using_keyword] = ACTIONS(5073),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5073),
  },
  [STATE(2519)] = {
    [ts_builtin_sym_end] = ACTIONS(5033),
    [anon_sym_POUNDif] = ACTIONS(5033),
    [anon_sym_POUNDIF] = ACTIONS(5033),
    [anon_sym_POUNDIf] = ACTIONS(5033),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5035),
    [anon_sym_tableextension] = ACTIONS(5033),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5033),
    [anon_sym_Tableextension] = ACTIONS(5033),
    [anon_sym_TableExtension] = ACTIONS(5033),
    [anon_sym_tableExtension] = ACTIONS(5033),
    [sym_page_keyword] = ACTIONS(5035),
    [anon_sym_pageextension] = ACTIONS(5033),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5033),
    [anon_sym_Pageextension] = ACTIONS(5033),
    [anon_sym_PageExtension] = ACTIONS(5033),
    [anon_sym_pageExtension] = ACTIONS(5033),
    [anon_sym_codeunit] = ACTIONS(5033),
    [anon_sym_CODEUNIT] = ACTIONS(5033),
    [anon_sym_Codeunit] = ACTIONS(5033),
    [anon_sym_CodeUnit] = ACTIONS(5033),
    [anon_sym_COdeunit] = ACTIONS(5033),
    [anon_sym_codeUnit] = ACTIONS(5033),
    [sym_report_keyword] = ACTIONS(5035),
    [anon_sym_reportextension] = ACTIONS(5033),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5033),
    [anon_sym_Reportextension] = ACTIONS(5033),
    [anon_sym_ReportExtension] = ACTIONS(5033),
    [anon_sym_reportExtension] = ACTIONS(5033),
    [sym_query_keyword] = ACTIONS(5033),
    [anon_sym_xmlport] = ACTIONS(5033),
    [anon_sym_XMLPORT] = ACTIONS(5033),
    [anon_sym_Xmlport] = ACTIONS(5033),
    [anon_sym_XMLport] = ACTIONS(5033),
    [anon_sym_XMLPort] = ACTIONS(5033),
    [anon_sym_XmlPort] = ACTIONS(5033),
    [anon_sym_enum] = ACTIONS(5035),
    [anon_sym_ENUM] = ACTIONS(5035),
    [anon_sym_Enum] = ACTIONS(5035),
    [anon_sym_eNUM] = ACTIONS(5033),
    [anon_sym_eNum] = ACTIONS(5033),
    [anon_sym_ENum] = ACTIONS(5033),
    [anon_sym_enumextension] = ACTIONS(5033),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5033),
    [anon_sym_Enumextension] = ACTIONS(5033),
    [anon_sym_EnumExtension] = ACTIONS(5033),
    [anon_sym_enumExtension] = ACTIONS(5033),
    [sym_interface_keyword] = ACTIONS(5033),
    [anon_sym_controladdin] = ACTIONS(5033),
    [anon_sym_CONTROLADDIN] = ACTIONS(5033),
    [anon_sym_Controladdin] = ACTIONS(5033),
    [anon_sym_ControlAddIn] = ACTIONS(5033),
    [anon_sym_ControlAddin] = ACTIONS(5033),
    [anon_sym_controlAddIn] = ACTIONS(5033),
    [anon_sym_controlAddin] = ACTIONS(5033),
    [anon_sym_dotnet] = ACTIONS(5033),
    [anon_sym_DOTNET] = ACTIONS(5033),
    [anon_sym_Dotnet] = ACTIONS(5033),
    [anon_sym_DotNet] = ACTIONS(5033),
    [anon_sym_dotNet] = ACTIONS(5033),
    [sym_profile_keyword] = ACTIONS(5035),
    [anon_sym_profileextension] = ACTIONS(5033),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5033),
    [anon_sym_Profileextension] = ACTIONS(5033),
    [anon_sym_ProfileExtension] = ACTIONS(5033),
    [anon_sym_profileExtension] = ACTIONS(5033),
    [anon_sym_permissionset] = ACTIONS(5035),
    [anon_sym_PERMISSIONSET] = ACTIONS(5035),
    [anon_sym_Permissionset] = ACTIONS(5035),
    [anon_sym_PermissionSet] = ACTIONS(5035),
    [anon_sym_permissionSet] = ACTIONS(5035),
    [anon_sym_permissionsetextension] = ACTIONS(5033),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5033),
    [anon_sym_Permissionsetextension] = ACTIONS(5033),
    [anon_sym_PermissionSetExtension] = ACTIONS(5033),
    [anon_sym_permissionSetExtension] = ACTIONS(5033),
    [sym_entitlement_keyword] = ACTIONS(5033),
    [anon_sym_pagecustomization] = ACTIONS(5033),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5033),
    [anon_sym_Pagecustomization] = ACTIONS(5033),
    [anon_sym_PageCustomization] = ACTIONS(5033),
    [anon_sym_pageCustomization] = ACTIONS(5033),
    [sym_using_keyword] = ACTIONS(5033),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5033),
  },
  [STATE(2520)] = {
    [ts_builtin_sym_end] = ACTIONS(5037),
    [anon_sym_POUNDif] = ACTIONS(5037),
    [anon_sym_POUNDIF] = ACTIONS(5037),
    [anon_sym_POUNDIf] = ACTIONS(5037),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5039),
    [anon_sym_tableextension] = ACTIONS(5037),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5037),
    [anon_sym_Tableextension] = ACTIONS(5037),
    [anon_sym_TableExtension] = ACTIONS(5037),
    [anon_sym_tableExtension] = ACTIONS(5037),
    [sym_page_keyword] = ACTIONS(5039),
    [anon_sym_pageextension] = ACTIONS(5037),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5037),
    [anon_sym_Pageextension] = ACTIONS(5037),
    [anon_sym_PageExtension] = ACTIONS(5037),
    [anon_sym_pageExtension] = ACTIONS(5037),
    [anon_sym_codeunit] = ACTIONS(5037),
    [anon_sym_CODEUNIT] = ACTIONS(5037),
    [anon_sym_Codeunit] = ACTIONS(5037),
    [anon_sym_CodeUnit] = ACTIONS(5037),
    [anon_sym_COdeunit] = ACTIONS(5037),
    [anon_sym_codeUnit] = ACTIONS(5037),
    [sym_report_keyword] = ACTIONS(5039),
    [anon_sym_reportextension] = ACTIONS(5037),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5037),
    [anon_sym_Reportextension] = ACTIONS(5037),
    [anon_sym_ReportExtension] = ACTIONS(5037),
    [anon_sym_reportExtension] = ACTIONS(5037),
    [sym_query_keyword] = ACTIONS(5037),
    [anon_sym_xmlport] = ACTIONS(5037),
    [anon_sym_XMLPORT] = ACTIONS(5037),
    [anon_sym_Xmlport] = ACTIONS(5037),
    [anon_sym_XMLport] = ACTIONS(5037),
    [anon_sym_XMLPort] = ACTIONS(5037),
    [anon_sym_XmlPort] = ACTIONS(5037),
    [anon_sym_enum] = ACTIONS(5039),
    [anon_sym_ENUM] = ACTIONS(5039),
    [anon_sym_Enum] = ACTIONS(5039),
    [anon_sym_eNUM] = ACTIONS(5037),
    [anon_sym_eNum] = ACTIONS(5037),
    [anon_sym_ENum] = ACTIONS(5037),
    [anon_sym_enumextension] = ACTIONS(5037),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5037),
    [anon_sym_Enumextension] = ACTIONS(5037),
    [anon_sym_EnumExtension] = ACTIONS(5037),
    [anon_sym_enumExtension] = ACTIONS(5037),
    [sym_interface_keyword] = ACTIONS(5037),
    [anon_sym_controladdin] = ACTIONS(5037),
    [anon_sym_CONTROLADDIN] = ACTIONS(5037),
    [anon_sym_Controladdin] = ACTIONS(5037),
    [anon_sym_ControlAddIn] = ACTIONS(5037),
    [anon_sym_ControlAddin] = ACTIONS(5037),
    [anon_sym_controlAddIn] = ACTIONS(5037),
    [anon_sym_controlAddin] = ACTIONS(5037),
    [anon_sym_dotnet] = ACTIONS(5037),
    [anon_sym_DOTNET] = ACTIONS(5037),
    [anon_sym_Dotnet] = ACTIONS(5037),
    [anon_sym_DotNet] = ACTIONS(5037),
    [anon_sym_dotNet] = ACTIONS(5037),
    [sym_profile_keyword] = ACTIONS(5039),
    [anon_sym_profileextension] = ACTIONS(5037),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5037),
    [anon_sym_Profileextension] = ACTIONS(5037),
    [anon_sym_ProfileExtension] = ACTIONS(5037),
    [anon_sym_profileExtension] = ACTIONS(5037),
    [anon_sym_permissionset] = ACTIONS(5039),
    [anon_sym_PERMISSIONSET] = ACTIONS(5039),
    [anon_sym_Permissionset] = ACTIONS(5039),
    [anon_sym_PermissionSet] = ACTIONS(5039),
    [anon_sym_permissionSet] = ACTIONS(5039),
    [anon_sym_permissionsetextension] = ACTIONS(5037),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5037),
    [anon_sym_Permissionsetextension] = ACTIONS(5037),
    [anon_sym_PermissionSetExtension] = ACTIONS(5037),
    [anon_sym_permissionSetExtension] = ACTIONS(5037),
    [sym_entitlement_keyword] = ACTIONS(5037),
    [anon_sym_pagecustomization] = ACTIONS(5037),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5037),
    [anon_sym_Pagecustomization] = ACTIONS(5037),
    [anon_sym_PageCustomization] = ACTIONS(5037),
    [anon_sym_pageCustomization] = ACTIONS(5037),
    [sym_using_keyword] = ACTIONS(5037),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5037),
  },
  [STATE(2521)] = {
    [ts_builtin_sym_end] = ACTIONS(5041),
    [anon_sym_POUNDif] = ACTIONS(5041),
    [anon_sym_POUNDIF] = ACTIONS(5041),
    [anon_sym_POUNDIf] = ACTIONS(5041),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5043),
    [anon_sym_tableextension] = ACTIONS(5041),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5041),
    [anon_sym_Tableextension] = ACTIONS(5041),
    [anon_sym_TableExtension] = ACTIONS(5041),
    [anon_sym_tableExtension] = ACTIONS(5041),
    [sym_page_keyword] = ACTIONS(5043),
    [anon_sym_pageextension] = ACTIONS(5041),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5041),
    [anon_sym_Pageextension] = ACTIONS(5041),
    [anon_sym_PageExtension] = ACTIONS(5041),
    [anon_sym_pageExtension] = ACTIONS(5041),
    [anon_sym_codeunit] = ACTIONS(5041),
    [anon_sym_CODEUNIT] = ACTIONS(5041),
    [anon_sym_Codeunit] = ACTIONS(5041),
    [anon_sym_CodeUnit] = ACTIONS(5041),
    [anon_sym_COdeunit] = ACTIONS(5041),
    [anon_sym_codeUnit] = ACTIONS(5041),
    [sym_report_keyword] = ACTIONS(5043),
    [anon_sym_reportextension] = ACTIONS(5041),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5041),
    [anon_sym_Reportextension] = ACTIONS(5041),
    [anon_sym_ReportExtension] = ACTIONS(5041),
    [anon_sym_reportExtension] = ACTIONS(5041),
    [sym_query_keyword] = ACTIONS(5041),
    [anon_sym_xmlport] = ACTIONS(5041),
    [anon_sym_XMLPORT] = ACTIONS(5041),
    [anon_sym_Xmlport] = ACTIONS(5041),
    [anon_sym_XMLport] = ACTIONS(5041),
    [anon_sym_XMLPort] = ACTIONS(5041),
    [anon_sym_XmlPort] = ACTIONS(5041),
    [anon_sym_enum] = ACTIONS(5043),
    [anon_sym_ENUM] = ACTIONS(5043),
    [anon_sym_Enum] = ACTIONS(5043),
    [anon_sym_eNUM] = ACTIONS(5041),
    [anon_sym_eNum] = ACTIONS(5041),
    [anon_sym_ENum] = ACTIONS(5041),
    [anon_sym_enumextension] = ACTIONS(5041),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5041),
    [anon_sym_Enumextension] = ACTIONS(5041),
    [anon_sym_EnumExtension] = ACTIONS(5041),
    [anon_sym_enumExtension] = ACTIONS(5041),
    [sym_interface_keyword] = ACTIONS(5041),
    [anon_sym_controladdin] = ACTIONS(5041),
    [anon_sym_CONTROLADDIN] = ACTIONS(5041),
    [anon_sym_Controladdin] = ACTIONS(5041),
    [anon_sym_ControlAddIn] = ACTIONS(5041),
    [anon_sym_ControlAddin] = ACTIONS(5041),
    [anon_sym_controlAddIn] = ACTIONS(5041),
    [anon_sym_controlAddin] = ACTIONS(5041),
    [anon_sym_dotnet] = ACTIONS(5041),
    [anon_sym_DOTNET] = ACTIONS(5041),
    [anon_sym_Dotnet] = ACTIONS(5041),
    [anon_sym_DotNet] = ACTIONS(5041),
    [anon_sym_dotNet] = ACTIONS(5041),
    [sym_profile_keyword] = ACTIONS(5043),
    [anon_sym_profileextension] = ACTIONS(5041),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5041),
    [anon_sym_Profileextension] = ACTIONS(5041),
    [anon_sym_ProfileExtension] = ACTIONS(5041),
    [anon_sym_profileExtension] = ACTIONS(5041),
    [anon_sym_permissionset] = ACTIONS(5043),
    [anon_sym_PERMISSIONSET] = ACTIONS(5043),
    [anon_sym_Permissionset] = ACTIONS(5043),
    [anon_sym_PermissionSet] = ACTIONS(5043),
    [anon_sym_permissionSet] = ACTIONS(5043),
    [anon_sym_permissionsetextension] = ACTIONS(5041),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5041),
    [anon_sym_Permissionsetextension] = ACTIONS(5041),
    [anon_sym_PermissionSetExtension] = ACTIONS(5041),
    [anon_sym_permissionSetExtension] = ACTIONS(5041),
    [sym_entitlement_keyword] = ACTIONS(5041),
    [anon_sym_pagecustomization] = ACTIONS(5041),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5041),
    [anon_sym_Pagecustomization] = ACTIONS(5041),
    [anon_sym_PageCustomization] = ACTIONS(5041),
    [anon_sym_pageCustomization] = ACTIONS(5041),
    [sym_using_keyword] = ACTIONS(5041),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5041),
  },
  [STATE(2522)] = {
    [ts_builtin_sym_end] = ACTIONS(4997),
    [anon_sym_POUNDif] = ACTIONS(4997),
    [anon_sym_POUNDIF] = ACTIONS(4997),
    [anon_sym_POUNDIf] = ACTIONS(4997),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4999),
    [anon_sym_tableextension] = ACTIONS(4997),
    [anon_sym_TABLEEXTENSION] = ACTIONS(4997),
    [anon_sym_Tableextension] = ACTIONS(4997),
    [anon_sym_TableExtension] = ACTIONS(4997),
    [anon_sym_tableExtension] = ACTIONS(4997),
    [sym_page_keyword] = ACTIONS(4999),
    [anon_sym_pageextension] = ACTIONS(4997),
    [anon_sym_PAGEEXTENSION] = ACTIONS(4997),
    [anon_sym_Pageextension] = ACTIONS(4997),
    [anon_sym_PageExtension] = ACTIONS(4997),
    [anon_sym_pageExtension] = ACTIONS(4997),
    [anon_sym_codeunit] = ACTIONS(4997),
    [anon_sym_CODEUNIT] = ACTIONS(4997),
    [anon_sym_Codeunit] = ACTIONS(4997),
    [anon_sym_CodeUnit] = ACTIONS(4997),
    [anon_sym_COdeunit] = ACTIONS(4997),
    [anon_sym_codeUnit] = ACTIONS(4997),
    [sym_report_keyword] = ACTIONS(4999),
    [anon_sym_reportextension] = ACTIONS(4997),
    [anon_sym_REPORTEXTENSION] = ACTIONS(4997),
    [anon_sym_Reportextension] = ACTIONS(4997),
    [anon_sym_ReportExtension] = ACTIONS(4997),
    [anon_sym_reportExtension] = ACTIONS(4997),
    [sym_query_keyword] = ACTIONS(4997),
    [anon_sym_xmlport] = ACTIONS(4997),
    [anon_sym_XMLPORT] = ACTIONS(4997),
    [anon_sym_Xmlport] = ACTIONS(4997),
    [anon_sym_XMLport] = ACTIONS(4997),
    [anon_sym_XMLPort] = ACTIONS(4997),
    [anon_sym_XmlPort] = ACTIONS(4997),
    [anon_sym_enum] = ACTIONS(4999),
    [anon_sym_ENUM] = ACTIONS(4999),
    [anon_sym_Enum] = ACTIONS(4999),
    [anon_sym_eNUM] = ACTIONS(4997),
    [anon_sym_eNum] = ACTIONS(4997),
    [anon_sym_ENum] = ACTIONS(4997),
    [anon_sym_enumextension] = ACTIONS(4997),
    [anon_sym_ENUMEXTENSION] = ACTIONS(4997),
    [anon_sym_Enumextension] = ACTIONS(4997),
    [anon_sym_EnumExtension] = ACTIONS(4997),
    [anon_sym_enumExtension] = ACTIONS(4997),
    [sym_interface_keyword] = ACTIONS(4997),
    [anon_sym_controladdin] = ACTIONS(4997),
    [anon_sym_CONTROLADDIN] = ACTIONS(4997),
    [anon_sym_Controladdin] = ACTIONS(4997),
    [anon_sym_ControlAddIn] = ACTIONS(4997),
    [anon_sym_ControlAddin] = ACTIONS(4997),
    [anon_sym_controlAddIn] = ACTIONS(4997),
    [anon_sym_controlAddin] = ACTIONS(4997),
    [anon_sym_dotnet] = ACTIONS(4997),
    [anon_sym_DOTNET] = ACTIONS(4997),
    [anon_sym_Dotnet] = ACTIONS(4997),
    [anon_sym_DotNet] = ACTIONS(4997),
    [anon_sym_dotNet] = ACTIONS(4997),
    [sym_profile_keyword] = ACTIONS(4999),
    [anon_sym_profileextension] = ACTIONS(4997),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(4997),
    [anon_sym_Profileextension] = ACTIONS(4997),
    [anon_sym_ProfileExtension] = ACTIONS(4997),
    [anon_sym_profileExtension] = ACTIONS(4997),
    [anon_sym_permissionset] = ACTIONS(4999),
    [anon_sym_PERMISSIONSET] = ACTIONS(4999),
    [anon_sym_Permissionset] = ACTIONS(4999),
    [anon_sym_PermissionSet] = ACTIONS(4999),
    [anon_sym_permissionSet] = ACTIONS(4999),
    [anon_sym_permissionsetextension] = ACTIONS(4997),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(4997),
    [anon_sym_Permissionsetextension] = ACTIONS(4997),
    [anon_sym_PermissionSetExtension] = ACTIONS(4997),
    [anon_sym_permissionSetExtension] = ACTIONS(4997),
    [sym_entitlement_keyword] = ACTIONS(4997),
    [anon_sym_pagecustomization] = ACTIONS(4997),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(4997),
    [anon_sym_Pagecustomization] = ACTIONS(4997),
    [anon_sym_PageCustomization] = ACTIONS(4997),
    [anon_sym_pageCustomization] = ACTIONS(4997),
    [sym_using_keyword] = ACTIONS(4997),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(4997),
  },
  [STATE(2523)] = {
    [ts_builtin_sym_end] = ACTIONS(5305),
    [anon_sym_POUNDif] = ACTIONS(5305),
    [anon_sym_POUNDIF] = ACTIONS(5305),
    [anon_sym_POUNDIf] = ACTIONS(5305),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5307),
    [anon_sym_tableextension] = ACTIONS(5305),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5305),
    [anon_sym_Tableextension] = ACTIONS(5305),
    [anon_sym_TableExtension] = ACTIONS(5305),
    [anon_sym_tableExtension] = ACTIONS(5305),
    [sym_page_keyword] = ACTIONS(5307),
    [anon_sym_pageextension] = ACTIONS(5305),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5305),
    [anon_sym_Pageextension] = ACTIONS(5305),
    [anon_sym_PageExtension] = ACTIONS(5305),
    [anon_sym_pageExtension] = ACTIONS(5305),
    [anon_sym_codeunit] = ACTIONS(5305),
    [anon_sym_CODEUNIT] = ACTIONS(5305),
    [anon_sym_Codeunit] = ACTIONS(5305),
    [anon_sym_CodeUnit] = ACTIONS(5305),
    [anon_sym_COdeunit] = ACTIONS(5305),
    [anon_sym_codeUnit] = ACTIONS(5305),
    [sym_report_keyword] = ACTIONS(5307),
    [anon_sym_reportextension] = ACTIONS(5305),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5305),
    [anon_sym_Reportextension] = ACTIONS(5305),
    [anon_sym_ReportExtension] = ACTIONS(5305),
    [anon_sym_reportExtension] = ACTIONS(5305),
    [sym_query_keyword] = ACTIONS(5305),
    [anon_sym_xmlport] = ACTIONS(5305),
    [anon_sym_XMLPORT] = ACTIONS(5305),
    [anon_sym_Xmlport] = ACTIONS(5305),
    [anon_sym_XMLport] = ACTIONS(5305),
    [anon_sym_XMLPort] = ACTIONS(5305),
    [anon_sym_XmlPort] = ACTIONS(5305),
    [anon_sym_enum] = ACTIONS(5307),
    [anon_sym_ENUM] = ACTIONS(5307),
    [anon_sym_Enum] = ACTIONS(5307),
    [anon_sym_eNUM] = ACTIONS(5305),
    [anon_sym_eNum] = ACTIONS(5305),
    [anon_sym_ENum] = ACTIONS(5305),
    [anon_sym_enumextension] = ACTIONS(5305),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5305),
    [anon_sym_Enumextension] = ACTIONS(5305),
    [anon_sym_EnumExtension] = ACTIONS(5305),
    [anon_sym_enumExtension] = ACTIONS(5305),
    [sym_interface_keyword] = ACTIONS(5305),
    [anon_sym_controladdin] = ACTIONS(5305),
    [anon_sym_CONTROLADDIN] = ACTIONS(5305),
    [anon_sym_Controladdin] = ACTIONS(5305),
    [anon_sym_ControlAddIn] = ACTIONS(5305),
    [anon_sym_ControlAddin] = ACTIONS(5305),
    [anon_sym_controlAddIn] = ACTIONS(5305),
    [anon_sym_controlAddin] = ACTIONS(5305),
    [anon_sym_dotnet] = ACTIONS(5305),
    [anon_sym_DOTNET] = ACTIONS(5305),
    [anon_sym_Dotnet] = ACTIONS(5305),
    [anon_sym_DotNet] = ACTIONS(5305),
    [anon_sym_dotNet] = ACTIONS(5305),
    [sym_profile_keyword] = ACTIONS(5307),
    [anon_sym_profileextension] = ACTIONS(5305),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5305),
    [anon_sym_Profileextension] = ACTIONS(5305),
    [anon_sym_ProfileExtension] = ACTIONS(5305),
    [anon_sym_profileExtension] = ACTIONS(5305),
    [anon_sym_permissionset] = ACTIONS(5307),
    [anon_sym_PERMISSIONSET] = ACTIONS(5307),
    [anon_sym_Permissionset] = ACTIONS(5307),
    [anon_sym_PermissionSet] = ACTIONS(5307),
    [anon_sym_permissionSet] = ACTIONS(5307),
    [anon_sym_permissionsetextension] = ACTIONS(5305),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5305),
    [anon_sym_Permissionsetextension] = ACTIONS(5305),
    [anon_sym_PermissionSetExtension] = ACTIONS(5305),
    [anon_sym_permissionSetExtension] = ACTIONS(5305),
    [sym_entitlement_keyword] = ACTIONS(5305),
    [anon_sym_pagecustomization] = ACTIONS(5305),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5305),
    [anon_sym_Pagecustomization] = ACTIONS(5305),
    [anon_sym_PageCustomization] = ACTIONS(5305),
    [anon_sym_pageCustomization] = ACTIONS(5305),
    [sym_using_keyword] = ACTIONS(5305),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5305),
  },
  [STATE(2524)] = {
    [ts_builtin_sym_end] = ACTIONS(5309),
    [anon_sym_POUNDif] = ACTIONS(5309),
    [anon_sym_POUNDIF] = ACTIONS(5309),
    [anon_sym_POUNDIf] = ACTIONS(5309),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5311),
    [anon_sym_tableextension] = ACTIONS(5309),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5309),
    [anon_sym_Tableextension] = ACTIONS(5309),
    [anon_sym_TableExtension] = ACTIONS(5309),
    [anon_sym_tableExtension] = ACTIONS(5309),
    [sym_page_keyword] = ACTIONS(5311),
    [anon_sym_pageextension] = ACTIONS(5309),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5309),
    [anon_sym_Pageextension] = ACTIONS(5309),
    [anon_sym_PageExtension] = ACTIONS(5309),
    [anon_sym_pageExtension] = ACTIONS(5309),
    [anon_sym_codeunit] = ACTIONS(5309),
    [anon_sym_CODEUNIT] = ACTIONS(5309),
    [anon_sym_Codeunit] = ACTIONS(5309),
    [anon_sym_CodeUnit] = ACTIONS(5309),
    [anon_sym_COdeunit] = ACTIONS(5309),
    [anon_sym_codeUnit] = ACTIONS(5309),
    [sym_report_keyword] = ACTIONS(5311),
    [anon_sym_reportextension] = ACTIONS(5309),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5309),
    [anon_sym_Reportextension] = ACTIONS(5309),
    [anon_sym_ReportExtension] = ACTIONS(5309),
    [anon_sym_reportExtension] = ACTIONS(5309),
    [sym_query_keyword] = ACTIONS(5309),
    [anon_sym_xmlport] = ACTIONS(5309),
    [anon_sym_XMLPORT] = ACTIONS(5309),
    [anon_sym_Xmlport] = ACTIONS(5309),
    [anon_sym_XMLport] = ACTIONS(5309),
    [anon_sym_XMLPort] = ACTIONS(5309),
    [anon_sym_XmlPort] = ACTIONS(5309),
    [anon_sym_enum] = ACTIONS(5311),
    [anon_sym_ENUM] = ACTIONS(5311),
    [anon_sym_Enum] = ACTIONS(5311),
    [anon_sym_eNUM] = ACTIONS(5309),
    [anon_sym_eNum] = ACTIONS(5309),
    [anon_sym_ENum] = ACTIONS(5309),
    [anon_sym_enumextension] = ACTIONS(5309),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5309),
    [anon_sym_Enumextension] = ACTIONS(5309),
    [anon_sym_EnumExtension] = ACTIONS(5309),
    [anon_sym_enumExtension] = ACTIONS(5309),
    [sym_interface_keyword] = ACTIONS(5309),
    [anon_sym_controladdin] = ACTIONS(5309),
    [anon_sym_CONTROLADDIN] = ACTIONS(5309),
    [anon_sym_Controladdin] = ACTIONS(5309),
    [anon_sym_ControlAddIn] = ACTIONS(5309),
    [anon_sym_ControlAddin] = ACTIONS(5309),
    [anon_sym_controlAddIn] = ACTIONS(5309),
    [anon_sym_controlAddin] = ACTIONS(5309),
    [anon_sym_dotnet] = ACTIONS(5309),
    [anon_sym_DOTNET] = ACTIONS(5309),
    [anon_sym_Dotnet] = ACTIONS(5309),
    [anon_sym_DotNet] = ACTIONS(5309),
    [anon_sym_dotNet] = ACTIONS(5309),
    [sym_profile_keyword] = ACTIONS(5311),
    [anon_sym_profileextension] = ACTIONS(5309),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5309),
    [anon_sym_Profileextension] = ACTIONS(5309),
    [anon_sym_ProfileExtension] = ACTIONS(5309),
    [anon_sym_profileExtension] = ACTIONS(5309),
    [anon_sym_permissionset] = ACTIONS(5311),
    [anon_sym_PERMISSIONSET] = ACTIONS(5311),
    [anon_sym_Permissionset] = ACTIONS(5311),
    [anon_sym_PermissionSet] = ACTIONS(5311),
    [anon_sym_permissionSet] = ACTIONS(5311),
    [anon_sym_permissionsetextension] = ACTIONS(5309),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5309),
    [anon_sym_Permissionsetextension] = ACTIONS(5309),
    [anon_sym_PermissionSetExtension] = ACTIONS(5309),
    [anon_sym_permissionSetExtension] = ACTIONS(5309),
    [sym_entitlement_keyword] = ACTIONS(5309),
    [anon_sym_pagecustomization] = ACTIONS(5309),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5309),
    [anon_sym_Pagecustomization] = ACTIONS(5309),
    [anon_sym_PageCustomization] = ACTIONS(5309),
    [anon_sym_pageCustomization] = ACTIONS(5309),
    [sym_using_keyword] = ACTIONS(5309),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5309),
  },
  [STATE(2525)] = {
    [ts_builtin_sym_end] = ACTIONS(5313),
    [anon_sym_POUNDif] = ACTIONS(5313),
    [anon_sym_POUNDIF] = ACTIONS(5313),
    [anon_sym_POUNDIf] = ACTIONS(5313),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5315),
    [anon_sym_tableextension] = ACTIONS(5313),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5313),
    [anon_sym_Tableextension] = ACTIONS(5313),
    [anon_sym_TableExtension] = ACTIONS(5313),
    [anon_sym_tableExtension] = ACTIONS(5313),
    [sym_page_keyword] = ACTIONS(5315),
    [anon_sym_pageextension] = ACTIONS(5313),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5313),
    [anon_sym_Pageextension] = ACTIONS(5313),
    [anon_sym_PageExtension] = ACTIONS(5313),
    [anon_sym_pageExtension] = ACTIONS(5313),
    [anon_sym_codeunit] = ACTIONS(5313),
    [anon_sym_CODEUNIT] = ACTIONS(5313),
    [anon_sym_Codeunit] = ACTIONS(5313),
    [anon_sym_CodeUnit] = ACTIONS(5313),
    [anon_sym_COdeunit] = ACTIONS(5313),
    [anon_sym_codeUnit] = ACTIONS(5313),
    [sym_report_keyword] = ACTIONS(5315),
    [anon_sym_reportextension] = ACTIONS(5313),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5313),
    [anon_sym_Reportextension] = ACTIONS(5313),
    [anon_sym_ReportExtension] = ACTIONS(5313),
    [anon_sym_reportExtension] = ACTIONS(5313),
    [sym_query_keyword] = ACTIONS(5313),
    [anon_sym_xmlport] = ACTIONS(5313),
    [anon_sym_XMLPORT] = ACTIONS(5313),
    [anon_sym_Xmlport] = ACTIONS(5313),
    [anon_sym_XMLport] = ACTIONS(5313),
    [anon_sym_XMLPort] = ACTIONS(5313),
    [anon_sym_XmlPort] = ACTIONS(5313),
    [anon_sym_enum] = ACTIONS(5315),
    [anon_sym_ENUM] = ACTIONS(5315),
    [anon_sym_Enum] = ACTIONS(5315),
    [anon_sym_eNUM] = ACTIONS(5313),
    [anon_sym_eNum] = ACTIONS(5313),
    [anon_sym_ENum] = ACTIONS(5313),
    [anon_sym_enumextension] = ACTIONS(5313),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5313),
    [anon_sym_Enumextension] = ACTIONS(5313),
    [anon_sym_EnumExtension] = ACTIONS(5313),
    [anon_sym_enumExtension] = ACTIONS(5313),
    [sym_interface_keyword] = ACTIONS(5313),
    [anon_sym_controladdin] = ACTIONS(5313),
    [anon_sym_CONTROLADDIN] = ACTIONS(5313),
    [anon_sym_Controladdin] = ACTIONS(5313),
    [anon_sym_ControlAddIn] = ACTIONS(5313),
    [anon_sym_ControlAddin] = ACTIONS(5313),
    [anon_sym_controlAddIn] = ACTIONS(5313),
    [anon_sym_controlAddin] = ACTIONS(5313),
    [anon_sym_dotnet] = ACTIONS(5313),
    [anon_sym_DOTNET] = ACTIONS(5313),
    [anon_sym_Dotnet] = ACTIONS(5313),
    [anon_sym_DotNet] = ACTIONS(5313),
    [anon_sym_dotNet] = ACTIONS(5313),
    [sym_profile_keyword] = ACTIONS(5315),
    [anon_sym_profileextension] = ACTIONS(5313),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5313),
    [anon_sym_Profileextension] = ACTIONS(5313),
    [anon_sym_ProfileExtension] = ACTIONS(5313),
    [anon_sym_profileExtension] = ACTIONS(5313),
    [anon_sym_permissionset] = ACTIONS(5315),
    [anon_sym_PERMISSIONSET] = ACTIONS(5315),
    [anon_sym_Permissionset] = ACTIONS(5315),
    [anon_sym_PermissionSet] = ACTIONS(5315),
    [anon_sym_permissionSet] = ACTIONS(5315),
    [anon_sym_permissionsetextension] = ACTIONS(5313),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5313),
    [anon_sym_Permissionsetextension] = ACTIONS(5313),
    [anon_sym_PermissionSetExtension] = ACTIONS(5313),
    [anon_sym_permissionSetExtension] = ACTIONS(5313),
    [sym_entitlement_keyword] = ACTIONS(5313),
    [anon_sym_pagecustomization] = ACTIONS(5313),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5313),
    [anon_sym_Pagecustomization] = ACTIONS(5313),
    [anon_sym_PageCustomization] = ACTIONS(5313),
    [anon_sym_pageCustomization] = ACTIONS(5313),
    [sym_using_keyword] = ACTIONS(5313),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5313),
  },
  [STATE(2526)] = {
    [sym_argument_list] = STATE(4763),
    [sym_identifier] = ACTIONS(5877),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_DASH] = ACTIONS(5879),
    [aux_sym_boolean_token1] = ACTIONS(5877),
    [aux_sym_boolean_token2] = ACTIONS(5877),
    [sym_decimal] = ACTIONS(5877),
    [anon_sym_LPAREN] = ACTIONS(5882),
    [anon_sym_RPAREN] = ACTIONS(5884),
    [anon_sym_DOT_DOT] = ACTIONS(5886),
    [aux_sym_filter_value_token1] = ACTIONS(5877),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5877),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(5886),
    [aux_sym_record_type_token1] = ACTIONS(5877),
    [aux_sym_basic_type_token21] = ACTIONS(5877),
    [aux_sym_basic_type_token22] = ACTIONS(5877),
    [aux_sym_basic_type_token48] = ACTIONS(5877),
    [anon_sym_COLON_COLON] = ACTIONS(5889),
    [anon_sym_not] = ACTIONS(5877),
    [anon_sym_NOT] = ACTIONS(5877),
    [anon_sym_Not] = ACTIONS(5877),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5877),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5877),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(5879),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(5884),
    [sym_date_literal] = ACTIONS(5877),
    [sym_time_literal] = ACTIONS(5877),
    [sym_biginteger_literal] = ACTIONS(5884),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(5877),
    [anon_sym_codeunit] = ACTIONS(5877),
    [anon_sym_CODEUNIT] = ACTIONS(5877),
    [anon_sym_Codeunit] = ACTIONS(5877),
    [anon_sym_CodeUnit] = ACTIONS(5877),
    [anon_sym_COdeunit] = ACTIONS(5877),
    [anon_sym_codeUnit] = ACTIONS(5877),
    [sym_report_keyword] = ACTIONS(5877),
    [sym_query_keyword] = ACTIONS(5877),
    [anon_sym_xmlport] = ACTIONS(5877),
    [anon_sym_XMLPORT] = ACTIONS(5877),
    [anon_sym_Xmlport] = ACTIONS(5877),
    [anon_sym_XMLport] = ACTIONS(5877),
    [anon_sym_XMLPort] = ACTIONS(5877),
    [anon_sym_XmlPort] = ACTIONS(5877),
    [anon_sym_enum] = ACTIONS(5877),
    [anon_sym_ENUM] = ACTIONS(5877),
    [anon_sym_Enum] = ACTIONS(5877),
    [anon_sym_eNUM] = ACTIONS(5877),
    [anon_sym_eNum] = ACTIONS(5877),
    [anon_sym_ENum] = ACTIONS(5877),
    [sym_quoted_identifier] = ACTIONS(5884),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5884),
    [sym_integer] = ACTIONS(5877),
    [sym_continue_as_identifier] = ACTIONS(5884),
  },
  [STATE(2527)] = {
    [aux_sym_option_member_list_repeat2] = STATE(2527),
    [sym_identifier] = ACTIONS(565),
    [anon_sym_SEMI] = ACTIONS(567),
    [anon_sym_COMMA] = ACTIONS(5891),
    [anon_sym_DASH] = ACTIONS(567),
    [aux_sym_boolean_token1] = ACTIONS(565),
    [aux_sym_boolean_token2] = ACTIONS(565),
    [aux_sym_where_condition_token1] = ACTIONS(565),
    [aux_sym_tabledata_permission_token2] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [aux_sym_record_type_token1] = ACTIONS(565),
    [aux_sym_basic_type_token21] = ACTIONS(565),
    [aux_sym_basic_type_token22] = ACTIONS(565),
    [aux_sym_basic_type_token48] = ACTIONS(565),
    [aux_sym_basic_type_token53] = ACTIONS(565),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(565),
    [aux_sym_modify_modification_token1] = ACTIONS(565),
    [aux_sym_separator_action_token1] = ACTIONS(565),
    [aux_sym_assembly_declaration_token1] = ACTIONS(565),
    [aux_sym_type_declaration_token1] = ACTIONS(565),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(565),
    [anon_sym_POUNDif] = ACTIONS(567),
    [anon_sym_POUNDIF] = ACTIONS(567),
    [anon_sym_POUNDIf] = ACTIONS(567),
    [anon_sym_POUNDelif] = ACTIONS(567),
    [anon_sym_POUNDELIF] = ACTIONS(567),
    [anon_sym_POUNDElif] = ACTIONS(567),
    [anon_sym_POUNDelse] = ACTIONS(567),
    [anon_sym_POUNDELSE] = ACTIONS(567),
    [anon_sym_POUNDElse] = ACTIONS(567),
    [anon_sym_POUNDendif] = ACTIONS(567),
    [anon_sym_POUNDENDIF] = ACTIONS(567),
    [anon_sym_POUNDEndif] = ACTIONS(567),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(565),
    [sym_page_keyword] = ACTIONS(565),
    [anon_sym_codeunit] = ACTIONS(565),
    [anon_sym_CODEUNIT] = ACTIONS(565),
    [anon_sym_Codeunit] = ACTIONS(565),
    [anon_sym_CodeUnit] = ACTIONS(565),
    [anon_sym_COdeunit] = ACTIONS(565),
    [anon_sym_codeUnit] = ACTIONS(565),
    [sym_report_keyword] = ACTIONS(565),
    [sym_query_keyword] = ACTIONS(565),
    [anon_sym_xmlport] = ACTIONS(565),
    [anon_sym_XMLPORT] = ACTIONS(565),
    [anon_sym_Xmlport] = ACTIONS(565),
    [anon_sym_XMLport] = ACTIONS(565),
    [anon_sym_XMLPort] = ACTIONS(565),
    [anon_sym_XmlPort] = ACTIONS(565),
    [anon_sym_enum] = ACTIONS(565),
    [anon_sym_ENUM] = ACTIONS(565),
    [anon_sym_Enum] = ACTIONS(565),
    [anon_sym_eNUM] = ACTIONS(565),
    [anon_sym_eNum] = ACTIONS(565),
    [anon_sym_ENum] = ACTIONS(565),
    [sym_procedure_keyword] = ACTIONS(565),
    [sym_trigger_keyword] = ACTIONS(565),
    [sym_var_keyword] = ACTIONS(565),
    [sym_local_keyword] = ACTIONS(565),
    [sym_internal_keyword] = ACTIONS(565),
    [sym_protected_keyword] = ACTIONS(565),
    [sym_event_keyword] = ACTIONS(565),
    [sym_fields_keyword] = ACTIONS(565),
    [sym_keys_keyword] = ACTIONS(565),
    [sym_key_keyword] = ACTIONS(565),
    [sym_fieldgroups_keyword] = ACTIONS(565),
    [sym_actions_keyword] = ACTIONS(565),
    [sym_layout_keyword] = ACTIONS(565),
    [sym_dataset_keyword] = ACTIONS(565),
    [sym_elements_keyword] = ACTIONS(565),
    [sym_labels_keyword] = ACTIONS(565),
    [sym_rendering_keyword] = ACTIONS(565),
    [sym_requestpage_keyword] = ACTIONS(565),
    [sym_schema_keyword] = ACTIONS(565),
    [sym_views_keyword] = ACTIONS(565),
    [sym_quoted_identifier] = ACTIONS(567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(567),
    [sym_integer] = ACTIONS(567),
    [sym_property_name] = ACTIONS(567),
    [sym_preproc_open] = ACTIONS(567),
    [sym_preproc_close] = ACTIONS(567),
    [sym_begin_keyword] = ACTIONS(567),
  },
  [STATE(2528)] = {
    [ts_builtin_sym_end] = ACTIONS(5045),
    [anon_sym_POUNDif] = ACTIONS(5045),
    [anon_sym_POUNDIF] = ACTIONS(5045),
    [anon_sym_POUNDIf] = ACTIONS(5045),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5047),
    [anon_sym_tableextension] = ACTIONS(5045),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5045),
    [anon_sym_Tableextension] = ACTIONS(5045),
    [anon_sym_TableExtension] = ACTIONS(5045),
    [anon_sym_tableExtension] = ACTIONS(5045),
    [sym_page_keyword] = ACTIONS(5047),
    [anon_sym_pageextension] = ACTIONS(5045),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5045),
    [anon_sym_Pageextension] = ACTIONS(5045),
    [anon_sym_PageExtension] = ACTIONS(5045),
    [anon_sym_pageExtension] = ACTIONS(5045),
    [anon_sym_codeunit] = ACTIONS(5045),
    [anon_sym_CODEUNIT] = ACTIONS(5045),
    [anon_sym_Codeunit] = ACTIONS(5045),
    [anon_sym_CodeUnit] = ACTIONS(5045),
    [anon_sym_COdeunit] = ACTIONS(5045),
    [anon_sym_codeUnit] = ACTIONS(5045),
    [sym_report_keyword] = ACTIONS(5047),
    [anon_sym_reportextension] = ACTIONS(5045),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5045),
    [anon_sym_Reportextension] = ACTIONS(5045),
    [anon_sym_ReportExtension] = ACTIONS(5045),
    [anon_sym_reportExtension] = ACTIONS(5045),
    [sym_query_keyword] = ACTIONS(5045),
    [anon_sym_xmlport] = ACTIONS(5045),
    [anon_sym_XMLPORT] = ACTIONS(5045),
    [anon_sym_Xmlport] = ACTIONS(5045),
    [anon_sym_XMLport] = ACTIONS(5045),
    [anon_sym_XMLPort] = ACTIONS(5045),
    [anon_sym_XmlPort] = ACTIONS(5045),
    [anon_sym_enum] = ACTIONS(5047),
    [anon_sym_ENUM] = ACTIONS(5047),
    [anon_sym_Enum] = ACTIONS(5047),
    [anon_sym_eNUM] = ACTIONS(5045),
    [anon_sym_eNum] = ACTIONS(5045),
    [anon_sym_ENum] = ACTIONS(5045),
    [anon_sym_enumextension] = ACTIONS(5045),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5045),
    [anon_sym_Enumextension] = ACTIONS(5045),
    [anon_sym_EnumExtension] = ACTIONS(5045),
    [anon_sym_enumExtension] = ACTIONS(5045),
    [sym_interface_keyword] = ACTIONS(5045),
    [anon_sym_controladdin] = ACTIONS(5045),
    [anon_sym_CONTROLADDIN] = ACTIONS(5045),
    [anon_sym_Controladdin] = ACTIONS(5045),
    [anon_sym_ControlAddIn] = ACTIONS(5045),
    [anon_sym_ControlAddin] = ACTIONS(5045),
    [anon_sym_controlAddIn] = ACTIONS(5045),
    [anon_sym_controlAddin] = ACTIONS(5045),
    [anon_sym_dotnet] = ACTIONS(5045),
    [anon_sym_DOTNET] = ACTIONS(5045),
    [anon_sym_Dotnet] = ACTIONS(5045),
    [anon_sym_DotNet] = ACTIONS(5045),
    [anon_sym_dotNet] = ACTIONS(5045),
    [sym_profile_keyword] = ACTIONS(5047),
    [anon_sym_profileextension] = ACTIONS(5045),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5045),
    [anon_sym_Profileextension] = ACTIONS(5045),
    [anon_sym_ProfileExtension] = ACTIONS(5045),
    [anon_sym_profileExtension] = ACTIONS(5045),
    [anon_sym_permissionset] = ACTIONS(5047),
    [anon_sym_PERMISSIONSET] = ACTIONS(5047),
    [anon_sym_Permissionset] = ACTIONS(5047),
    [anon_sym_PermissionSet] = ACTIONS(5047),
    [anon_sym_permissionSet] = ACTIONS(5047),
    [anon_sym_permissionsetextension] = ACTIONS(5045),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5045),
    [anon_sym_Permissionsetextension] = ACTIONS(5045),
    [anon_sym_PermissionSetExtension] = ACTIONS(5045),
    [anon_sym_permissionSetExtension] = ACTIONS(5045),
    [sym_entitlement_keyword] = ACTIONS(5045),
    [anon_sym_pagecustomization] = ACTIONS(5045),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5045),
    [anon_sym_Pagecustomization] = ACTIONS(5045),
    [anon_sym_PageCustomization] = ACTIONS(5045),
    [anon_sym_pageCustomization] = ACTIONS(5045),
    [sym_using_keyword] = ACTIONS(5045),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5045),
  },
  [STATE(2529)] = {
    [ts_builtin_sym_end] = ACTIONS(5077),
    [anon_sym_POUNDif] = ACTIONS(5077),
    [anon_sym_POUNDIF] = ACTIONS(5077),
    [anon_sym_POUNDIf] = ACTIONS(5077),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5079),
    [anon_sym_tableextension] = ACTIONS(5077),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5077),
    [anon_sym_Tableextension] = ACTIONS(5077),
    [anon_sym_TableExtension] = ACTIONS(5077),
    [anon_sym_tableExtension] = ACTIONS(5077),
    [sym_page_keyword] = ACTIONS(5079),
    [anon_sym_pageextension] = ACTIONS(5077),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5077),
    [anon_sym_Pageextension] = ACTIONS(5077),
    [anon_sym_PageExtension] = ACTIONS(5077),
    [anon_sym_pageExtension] = ACTIONS(5077),
    [anon_sym_codeunit] = ACTIONS(5077),
    [anon_sym_CODEUNIT] = ACTIONS(5077),
    [anon_sym_Codeunit] = ACTIONS(5077),
    [anon_sym_CodeUnit] = ACTIONS(5077),
    [anon_sym_COdeunit] = ACTIONS(5077),
    [anon_sym_codeUnit] = ACTIONS(5077),
    [sym_report_keyword] = ACTIONS(5079),
    [anon_sym_reportextension] = ACTIONS(5077),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5077),
    [anon_sym_Reportextension] = ACTIONS(5077),
    [anon_sym_ReportExtension] = ACTIONS(5077),
    [anon_sym_reportExtension] = ACTIONS(5077),
    [sym_query_keyword] = ACTIONS(5077),
    [anon_sym_xmlport] = ACTIONS(5077),
    [anon_sym_XMLPORT] = ACTIONS(5077),
    [anon_sym_Xmlport] = ACTIONS(5077),
    [anon_sym_XMLport] = ACTIONS(5077),
    [anon_sym_XMLPort] = ACTIONS(5077),
    [anon_sym_XmlPort] = ACTIONS(5077),
    [anon_sym_enum] = ACTIONS(5079),
    [anon_sym_ENUM] = ACTIONS(5079),
    [anon_sym_Enum] = ACTIONS(5079),
    [anon_sym_eNUM] = ACTIONS(5077),
    [anon_sym_eNum] = ACTIONS(5077),
    [anon_sym_ENum] = ACTIONS(5077),
    [anon_sym_enumextension] = ACTIONS(5077),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5077),
    [anon_sym_Enumextension] = ACTIONS(5077),
    [anon_sym_EnumExtension] = ACTIONS(5077),
    [anon_sym_enumExtension] = ACTIONS(5077),
    [sym_interface_keyword] = ACTIONS(5077),
    [anon_sym_controladdin] = ACTIONS(5077),
    [anon_sym_CONTROLADDIN] = ACTIONS(5077),
    [anon_sym_Controladdin] = ACTIONS(5077),
    [anon_sym_ControlAddIn] = ACTIONS(5077),
    [anon_sym_ControlAddin] = ACTIONS(5077),
    [anon_sym_controlAddIn] = ACTIONS(5077),
    [anon_sym_controlAddin] = ACTIONS(5077),
    [anon_sym_dotnet] = ACTIONS(5077),
    [anon_sym_DOTNET] = ACTIONS(5077),
    [anon_sym_Dotnet] = ACTIONS(5077),
    [anon_sym_DotNet] = ACTIONS(5077),
    [anon_sym_dotNet] = ACTIONS(5077),
    [sym_profile_keyword] = ACTIONS(5079),
    [anon_sym_profileextension] = ACTIONS(5077),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5077),
    [anon_sym_Profileextension] = ACTIONS(5077),
    [anon_sym_ProfileExtension] = ACTIONS(5077),
    [anon_sym_profileExtension] = ACTIONS(5077),
    [anon_sym_permissionset] = ACTIONS(5079),
    [anon_sym_PERMISSIONSET] = ACTIONS(5079),
    [anon_sym_Permissionset] = ACTIONS(5079),
    [anon_sym_PermissionSet] = ACTIONS(5079),
    [anon_sym_permissionSet] = ACTIONS(5079),
    [anon_sym_permissionsetextension] = ACTIONS(5077),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5077),
    [anon_sym_Permissionsetextension] = ACTIONS(5077),
    [anon_sym_PermissionSetExtension] = ACTIONS(5077),
    [anon_sym_permissionSetExtension] = ACTIONS(5077),
    [sym_entitlement_keyword] = ACTIONS(5077),
    [anon_sym_pagecustomization] = ACTIONS(5077),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5077),
    [anon_sym_Pagecustomization] = ACTIONS(5077),
    [anon_sym_PageCustomization] = ACTIONS(5077),
    [anon_sym_pageCustomization] = ACTIONS(5077),
    [sym_using_keyword] = ACTIONS(5077),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5077),
  },
  [STATE(2530)] = {
    [ts_builtin_sym_end] = ACTIONS(5049),
    [anon_sym_POUNDif] = ACTIONS(5049),
    [anon_sym_POUNDIF] = ACTIONS(5049),
    [anon_sym_POUNDIf] = ACTIONS(5049),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5051),
    [anon_sym_tableextension] = ACTIONS(5049),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5049),
    [anon_sym_Tableextension] = ACTIONS(5049),
    [anon_sym_TableExtension] = ACTIONS(5049),
    [anon_sym_tableExtension] = ACTIONS(5049),
    [sym_page_keyword] = ACTIONS(5051),
    [anon_sym_pageextension] = ACTIONS(5049),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5049),
    [anon_sym_Pageextension] = ACTIONS(5049),
    [anon_sym_PageExtension] = ACTIONS(5049),
    [anon_sym_pageExtension] = ACTIONS(5049),
    [anon_sym_codeunit] = ACTIONS(5049),
    [anon_sym_CODEUNIT] = ACTIONS(5049),
    [anon_sym_Codeunit] = ACTIONS(5049),
    [anon_sym_CodeUnit] = ACTIONS(5049),
    [anon_sym_COdeunit] = ACTIONS(5049),
    [anon_sym_codeUnit] = ACTIONS(5049),
    [sym_report_keyword] = ACTIONS(5051),
    [anon_sym_reportextension] = ACTIONS(5049),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5049),
    [anon_sym_Reportextension] = ACTIONS(5049),
    [anon_sym_ReportExtension] = ACTIONS(5049),
    [anon_sym_reportExtension] = ACTIONS(5049),
    [sym_query_keyword] = ACTIONS(5049),
    [anon_sym_xmlport] = ACTIONS(5049),
    [anon_sym_XMLPORT] = ACTIONS(5049),
    [anon_sym_Xmlport] = ACTIONS(5049),
    [anon_sym_XMLport] = ACTIONS(5049),
    [anon_sym_XMLPort] = ACTIONS(5049),
    [anon_sym_XmlPort] = ACTIONS(5049),
    [anon_sym_enum] = ACTIONS(5051),
    [anon_sym_ENUM] = ACTIONS(5051),
    [anon_sym_Enum] = ACTIONS(5051),
    [anon_sym_eNUM] = ACTIONS(5049),
    [anon_sym_eNum] = ACTIONS(5049),
    [anon_sym_ENum] = ACTIONS(5049),
    [anon_sym_enumextension] = ACTIONS(5049),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5049),
    [anon_sym_Enumextension] = ACTIONS(5049),
    [anon_sym_EnumExtension] = ACTIONS(5049),
    [anon_sym_enumExtension] = ACTIONS(5049),
    [sym_interface_keyword] = ACTIONS(5049),
    [anon_sym_controladdin] = ACTIONS(5049),
    [anon_sym_CONTROLADDIN] = ACTIONS(5049),
    [anon_sym_Controladdin] = ACTIONS(5049),
    [anon_sym_ControlAddIn] = ACTIONS(5049),
    [anon_sym_ControlAddin] = ACTIONS(5049),
    [anon_sym_controlAddIn] = ACTIONS(5049),
    [anon_sym_controlAddin] = ACTIONS(5049),
    [anon_sym_dotnet] = ACTIONS(5049),
    [anon_sym_DOTNET] = ACTIONS(5049),
    [anon_sym_Dotnet] = ACTIONS(5049),
    [anon_sym_DotNet] = ACTIONS(5049),
    [anon_sym_dotNet] = ACTIONS(5049),
    [sym_profile_keyword] = ACTIONS(5051),
    [anon_sym_profileextension] = ACTIONS(5049),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5049),
    [anon_sym_Profileextension] = ACTIONS(5049),
    [anon_sym_ProfileExtension] = ACTIONS(5049),
    [anon_sym_profileExtension] = ACTIONS(5049),
    [anon_sym_permissionset] = ACTIONS(5051),
    [anon_sym_PERMISSIONSET] = ACTIONS(5051),
    [anon_sym_Permissionset] = ACTIONS(5051),
    [anon_sym_PermissionSet] = ACTIONS(5051),
    [anon_sym_permissionSet] = ACTIONS(5051),
    [anon_sym_permissionsetextension] = ACTIONS(5049),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5049),
    [anon_sym_Permissionsetextension] = ACTIONS(5049),
    [anon_sym_PermissionSetExtension] = ACTIONS(5049),
    [anon_sym_permissionSetExtension] = ACTIONS(5049),
    [sym_entitlement_keyword] = ACTIONS(5049),
    [anon_sym_pagecustomization] = ACTIONS(5049),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5049),
    [anon_sym_Pagecustomization] = ACTIONS(5049),
    [anon_sym_PageCustomization] = ACTIONS(5049),
    [anon_sym_pageCustomization] = ACTIONS(5049),
    [sym_using_keyword] = ACTIONS(5049),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5049),
  },
  [STATE(2531)] = {
    [ts_builtin_sym_end] = ACTIONS(5081),
    [anon_sym_POUNDif] = ACTIONS(5081),
    [anon_sym_POUNDIF] = ACTIONS(5081),
    [anon_sym_POUNDIf] = ACTIONS(5081),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5083),
    [anon_sym_tableextension] = ACTIONS(5081),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5081),
    [anon_sym_Tableextension] = ACTIONS(5081),
    [anon_sym_TableExtension] = ACTIONS(5081),
    [anon_sym_tableExtension] = ACTIONS(5081),
    [sym_page_keyword] = ACTIONS(5083),
    [anon_sym_pageextension] = ACTIONS(5081),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5081),
    [anon_sym_Pageextension] = ACTIONS(5081),
    [anon_sym_PageExtension] = ACTIONS(5081),
    [anon_sym_pageExtension] = ACTIONS(5081),
    [anon_sym_codeunit] = ACTIONS(5081),
    [anon_sym_CODEUNIT] = ACTIONS(5081),
    [anon_sym_Codeunit] = ACTIONS(5081),
    [anon_sym_CodeUnit] = ACTIONS(5081),
    [anon_sym_COdeunit] = ACTIONS(5081),
    [anon_sym_codeUnit] = ACTIONS(5081),
    [sym_report_keyword] = ACTIONS(5083),
    [anon_sym_reportextension] = ACTIONS(5081),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5081),
    [anon_sym_Reportextension] = ACTIONS(5081),
    [anon_sym_ReportExtension] = ACTIONS(5081),
    [anon_sym_reportExtension] = ACTIONS(5081),
    [sym_query_keyword] = ACTIONS(5081),
    [anon_sym_xmlport] = ACTIONS(5081),
    [anon_sym_XMLPORT] = ACTIONS(5081),
    [anon_sym_Xmlport] = ACTIONS(5081),
    [anon_sym_XMLport] = ACTIONS(5081),
    [anon_sym_XMLPort] = ACTIONS(5081),
    [anon_sym_XmlPort] = ACTIONS(5081),
    [anon_sym_enum] = ACTIONS(5083),
    [anon_sym_ENUM] = ACTIONS(5083),
    [anon_sym_Enum] = ACTIONS(5083),
    [anon_sym_eNUM] = ACTIONS(5081),
    [anon_sym_eNum] = ACTIONS(5081),
    [anon_sym_ENum] = ACTIONS(5081),
    [anon_sym_enumextension] = ACTIONS(5081),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5081),
    [anon_sym_Enumextension] = ACTIONS(5081),
    [anon_sym_EnumExtension] = ACTIONS(5081),
    [anon_sym_enumExtension] = ACTIONS(5081),
    [sym_interface_keyword] = ACTIONS(5081),
    [anon_sym_controladdin] = ACTIONS(5081),
    [anon_sym_CONTROLADDIN] = ACTIONS(5081),
    [anon_sym_Controladdin] = ACTIONS(5081),
    [anon_sym_ControlAddIn] = ACTIONS(5081),
    [anon_sym_ControlAddin] = ACTIONS(5081),
    [anon_sym_controlAddIn] = ACTIONS(5081),
    [anon_sym_controlAddin] = ACTIONS(5081),
    [anon_sym_dotnet] = ACTIONS(5081),
    [anon_sym_DOTNET] = ACTIONS(5081),
    [anon_sym_Dotnet] = ACTIONS(5081),
    [anon_sym_DotNet] = ACTIONS(5081),
    [anon_sym_dotNet] = ACTIONS(5081),
    [sym_profile_keyword] = ACTIONS(5083),
    [anon_sym_profileextension] = ACTIONS(5081),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5081),
    [anon_sym_Profileextension] = ACTIONS(5081),
    [anon_sym_ProfileExtension] = ACTIONS(5081),
    [anon_sym_profileExtension] = ACTIONS(5081),
    [anon_sym_permissionset] = ACTIONS(5083),
    [anon_sym_PERMISSIONSET] = ACTIONS(5083),
    [anon_sym_Permissionset] = ACTIONS(5083),
    [anon_sym_PermissionSet] = ACTIONS(5083),
    [anon_sym_permissionSet] = ACTIONS(5083),
    [anon_sym_permissionsetextension] = ACTIONS(5081),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5081),
    [anon_sym_Permissionsetextension] = ACTIONS(5081),
    [anon_sym_PermissionSetExtension] = ACTIONS(5081),
    [anon_sym_permissionSetExtension] = ACTIONS(5081),
    [sym_entitlement_keyword] = ACTIONS(5081),
    [anon_sym_pagecustomization] = ACTIONS(5081),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5081),
    [anon_sym_Pagecustomization] = ACTIONS(5081),
    [anon_sym_PageCustomization] = ACTIONS(5081),
    [anon_sym_pageCustomization] = ACTIONS(5081),
    [sym_using_keyword] = ACTIONS(5081),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5081),
  },
  [STATE(2532)] = {
    [ts_builtin_sym_end] = ACTIONS(5053),
    [anon_sym_POUNDif] = ACTIONS(5053),
    [anon_sym_POUNDIF] = ACTIONS(5053),
    [anon_sym_POUNDIf] = ACTIONS(5053),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5055),
    [anon_sym_tableextension] = ACTIONS(5053),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5053),
    [anon_sym_Tableextension] = ACTIONS(5053),
    [anon_sym_TableExtension] = ACTIONS(5053),
    [anon_sym_tableExtension] = ACTIONS(5053),
    [sym_page_keyword] = ACTIONS(5055),
    [anon_sym_pageextension] = ACTIONS(5053),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5053),
    [anon_sym_Pageextension] = ACTIONS(5053),
    [anon_sym_PageExtension] = ACTIONS(5053),
    [anon_sym_pageExtension] = ACTIONS(5053),
    [anon_sym_codeunit] = ACTIONS(5053),
    [anon_sym_CODEUNIT] = ACTIONS(5053),
    [anon_sym_Codeunit] = ACTIONS(5053),
    [anon_sym_CodeUnit] = ACTIONS(5053),
    [anon_sym_COdeunit] = ACTIONS(5053),
    [anon_sym_codeUnit] = ACTIONS(5053),
    [sym_report_keyword] = ACTIONS(5055),
    [anon_sym_reportextension] = ACTIONS(5053),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5053),
    [anon_sym_Reportextension] = ACTIONS(5053),
    [anon_sym_ReportExtension] = ACTIONS(5053),
    [anon_sym_reportExtension] = ACTIONS(5053),
    [sym_query_keyword] = ACTIONS(5053),
    [anon_sym_xmlport] = ACTIONS(5053),
    [anon_sym_XMLPORT] = ACTIONS(5053),
    [anon_sym_Xmlport] = ACTIONS(5053),
    [anon_sym_XMLport] = ACTIONS(5053),
    [anon_sym_XMLPort] = ACTIONS(5053),
    [anon_sym_XmlPort] = ACTIONS(5053),
    [anon_sym_enum] = ACTIONS(5055),
    [anon_sym_ENUM] = ACTIONS(5055),
    [anon_sym_Enum] = ACTIONS(5055),
    [anon_sym_eNUM] = ACTIONS(5053),
    [anon_sym_eNum] = ACTIONS(5053),
    [anon_sym_ENum] = ACTIONS(5053),
    [anon_sym_enumextension] = ACTIONS(5053),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5053),
    [anon_sym_Enumextension] = ACTIONS(5053),
    [anon_sym_EnumExtension] = ACTIONS(5053),
    [anon_sym_enumExtension] = ACTIONS(5053),
    [sym_interface_keyword] = ACTIONS(5053),
    [anon_sym_controladdin] = ACTIONS(5053),
    [anon_sym_CONTROLADDIN] = ACTIONS(5053),
    [anon_sym_Controladdin] = ACTIONS(5053),
    [anon_sym_ControlAddIn] = ACTIONS(5053),
    [anon_sym_ControlAddin] = ACTIONS(5053),
    [anon_sym_controlAddIn] = ACTIONS(5053),
    [anon_sym_controlAddin] = ACTIONS(5053),
    [anon_sym_dotnet] = ACTIONS(5053),
    [anon_sym_DOTNET] = ACTIONS(5053),
    [anon_sym_Dotnet] = ACTIONS(5053),
    [anon_sym_DotNet] = ACTIONS(5053),
    [anon_sym_dotNet] = ACTIONS(5053),
    [sym_profile_keyword] = ACTIONS(5055),
    [anon_sym_profileextension] = ACTIONS(5053),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5053),
    [anon_sym_Profileextension] = ACTIONS(5053),
    [anon_sym_ProfileExtension] = ACTIONS(5053),
    [anon_sym_profileExtension] = ACTIONS(5053),
    [anon_sym_permissionset] = ACTIONS(5055),
    [anon_sym_PERMISSIONSET] = ACTIONS(5055),
    [anon_sym_Permissionset] = ACTIONS(5055),
    [anon_sym_PermissionSet] = ACTIONS(5055),
    [anon_sym_permissionSet] = ACTIONS(5055),
    [anon_sym_permissionsetextension] = ACTIONS(5053),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5053),
    [anon_sym_Permissionsetextension] = ACTIONS(5053),
    [anon_sym_PermissionSetExtension] = ACTIONS(5053),
    [anon_sym_permissionSetExtension] = ACTIONS(5053),
    [sym_entitlement_keyword] = ACTIONS(5053),
    [anon_sym_pagecustomization] = ACTIONS(5053),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5053),
    [anon_sym_Pagecustomization] = ACTIONS(5053),
    [anon_sym_PageCustomization] = ACTIONS(5053),
    [anon_sym_pageCustomization] = ACTIONS(5053),
    [sym_using_keyword] = ACTIONS(5053),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5053),
  },
  [STATE(2533)] = {
    [ts_builtin_sym_end] = ACTIONS(5085),
    [anon_sym_POUNDif] = ACTIONS(5085),
    [anon_sym_POUNDIF] = ACTIONS(5085),
    [anon_sym_POUNDIf] = ACTIONS(5085),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5087),
    [anon_sym_tableextension] = ACTIONS(5085),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5085),
    [anon_sym_Tableextension] = ACTIONS(5085),
    [anon_sym_TableExtension] = ACTIONS(5085),
    [anon_sym_tableExtension] = ACTIONS(5085),
    [sym_page_keyword] = ACTIONS(5087),
    [anon_sym_pageextension] = ACTIONS(5085),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5085),
    [anon_sym_Pageextension] = ACTIONS(5085),
    [anon_sym_PageExtension] = ACTIONS(5085),
    [anon_sym_pageExtension] = ACTIONS(5085),
    [anon_sym_codeunit] = ACTIONS(5085),
    [anon_sym_CODEUNIT] = ACTIONS(5085),
    [anon_sym_Codeunit] = ACTIONS(5085),
    [anon_sym_CodeUnit] = ACTIONS(5085),
    [anon_sym_COdeunit] = ACTIONS(5085),
    [anon_sym_codeUnit] = ACTIONS(5085),
    [sym_report_keyword] = ACTIONS(5087),
    [anon_sym_reportextension] = ACTIONS(5085),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5085),
    [anon_sym_Reportextension] = ACTIONS(5085),
    [anon_sym_ReportExtension] = ACTIONS(5085),
    [anon_sym_reportExtension] = ACTIONS(5085),
    [sym_query_keyword] = ACTIONS(5085),
    [anon_sym_xmlport] = ACTIONS(5085),
    [anon_sym_XMLPORT] = ACTIONS(5085),
    [anon_sym_Xmlport] = ACTIONS(5085),
    [anon_sym_XMLport] = ACTIONS(5085),
    [anon_sym_XMLPort] = ACTIONS(5085),
    [anon_sym_XmlPort] = ACTIONS(5085),
    [anon_sym_enum] = ACTIONS(5087),
    [anon_sym_ENUM] = ACTIONS(5087),
    [anon_sym_Enum] = ACTIONS(5087),
    [anon_sym_eNUM] = ACTIONS(5085),
    [anon_sym_eNum] = ACTIONS(5085),
    [anon_sym_ENum] = ACTIONS(5085),
    [anon_sym_enumextension] = ACTIONS(5085),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5085),
    [anon_sym_Enumextension] = ACTIONS(5085),
    [anon_sym_EnumExtension] = ACTIONS(5085),
    [anon_sym_enumExtension] = ACTIONS(5085),
    [sym_interface_keyword] = ACTIONS(5085),
    [anon_sym_controladdin] = ACTIONS(5085),
    [anon_sym_CONTROLADDIN] = ACTIONS(5085),
    [anon_sym_Controladdin] = ACTIONS(5085),
    [anon_sym_ControlAddIn] = ACTIONS(5085),
    [anon_sym_ControlAddin] = ACTIONS(5085),
    [anon_sym_controlAddIn] = ACTIONS(5085),
    [anon_sym_controlAddin] = ACTIONS(5085),
    [anon_sym_dotnet] = ACTIONS(5085),
    [anon_sym_DOTNET] = ACTIONS(5085),
    [anon_sym_Dotnet] = ACTIONS(5085),
    [anon_sym_DotNet] = ACTIONS(5085),
    [anon_sym_dotNet] = ACTIONS(5085),
    [sym_profile_keyword] = ACTIONS(5087),
    [anon_sym_profileextension] = ACTIONS(5085),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5085),
    [anon_sym_Profileextension] = ACTIONS(5085),
    [anon_sym_ProfileExtension] = ACTIONS(5085),
    [anon_sym_profileExtension] = ACTIONS(5085),
    [anon_sym_permissionset] = ACTIONS(5087),
    [anon_sym_PERMISSIONSET] = ACTIONS(5087),
    [anon_sym_Permissionset] = ACTIONS(5087),
    [anon_sym_PermissionSet] = ACTIONS(5087),
    [anon_sym_permissionSet] = ACTIONS(5087),
    [anon_sym_permissionsetextension] = ACTIONS(5085),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5085),
    [anon_sym_Permissionsetextension] = ACTIONS(5085),
    [anon_sym_PermissionSetExtension] = ACTIONS(5085),
    [anon_sym_permissionSetExtension] = ACTIONS(5085),
    [sym_entitlement_keyword] = ACTIONS(5085),
    [anon_sym_pagecustomization] = ACTIONS(5085),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5085),
    [anon_sym_Pagecustomization] = ACTIONS(5085),
    [anon_sym_PageCustomization] = ACTIONS(5085),
    [anon_sym_pageCustomization] = ACTIONS(5085),
    [sym_using_keyword] = ACTIONS(5085),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5085),
  },
  [STATE(2534)] = {
    [ts_builtin_sym_end] = ACTIONS(5057),
    [anon_sym_POUNDif] = ACTIONS(5057),
    [anon_sym_POUNDIF] = ACTIONS(5057),
    [anon_sym_POUNDIf] = ACTIONS(5057),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5059),
    [anon_sym_tableextension] = ACTIONS(5057),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5057),
    [anon_sym_Tableextension] = ACTIONS(5057),
    [anon_sym_TableExtension] = ACTIONS(5057),
    [anon_sym_tableExtension] = ACTIONS(5057),
    [sym_page_keyword] = ACTIONS(5059),
    [anon_sym_pageextension] = ACTIONS(5057),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5057),
    [anon_sym_Pageextension] = ACTIONS(5057),
    [anon_sym_PageExtension] = ACTIONS(5057),
    [anon_sym_pageExtension] = ACTIONS(5057),
    [anon_sym_codeunit] = ACTIONS(5057),
    [anon_sym_CODEUNIT] = ACTIONS(5057),
    [anon_sym_Codeunit] = ACTIONS(5057),
    [anon_sym_CodeUnit] = ACTIONS(5057),
    [anon_sym_COdeunit] = ACTIONS(5057),
    [anon_sym_codeUnit] = ACTIONS(5057),
    [sym_report_keyword] = ACTIONS(5059),
    [anon_sym_reportextension] = ACTIONS(5057),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5057),
    [anon_sym_Reportextension] = ACTIONS(5057),
    [anon_sym_ReportExtension] = ACTIONS(5057),
    [anon_sym_reportExtension] = ACTIONS(5057),
    [sym_query_keyword] = ACTIONS(5057),
    [anon_sym_xmlport] = ACTIONS(5057),
    [anon_sym_XMLPORT] = ACTIONS(5057),
    [anon_sym_Xmlport] = ACTIONS(5057),
    [anon_sym_XMLport] = ACTIONS(5057),
    [anon_sym_XMLPort] = ACTIONS(5057),
    [anon_sym_XmlPort] = ACTIONS(5057),
    [anon_sym_enum] = ACTIONS(5059),
    [anon_sym_ENUM] = ACTIONS(5059),
    [anon_sym_Enum] = ACTIONS(5059),
    [anon_sym_eNUM] = ACTIONS(5057),
    [anon_sym_eNum] = ACTIONS(5057),
    [anon_sym_ENum] = ACTIONS(5057),
    [anon_sym_enumextension] = ACTIONS(5057),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5057),
    [anon_sym_Enumextension] = ACTIONS(5057),
    [anon_sym_EnumExtension] = ACTIONS(5057),
    [anon_sym_enumExtension] = ACTIONS(5057),
    [sym_interface_keyword] = ACTIONS(5057),
    [anon_sym_controladdin] = ACTIONS(5057),
    [anon_sym_CONTROLADDIN] = ACTIONS(5057),
    [anon_sym_Controladdin] = ACTIONS(5057),
    [anon_sym_ControlAddIn] = ACTIONS(5057),
    [anon_sym_ControlAddin] = ACTIONS(5057),
    [anon_sym_controlAddIn] = ACTIONS(5057),
    [anon_sym_controlAddin] = ACTIONS(5057),
    [anon_sym_dotnet] = ACTIONS(5057),
    [anon_sym_DOTNET] = ACTIONS(5057),
    [anon_sym_Dotnet] = ACTIONS(5057),
    [anon_sym_DotNet] = ACTIONS(5057),
    [anon_sym_dotNet] = ACTIONS(5057),
    [sym_profile_keyword] = ACTIONS(5059),
    [anon_sym_profileextension] = ACTIONS(5057),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5057),
    [anon_sym_Profileextension] = ACTIONS(5057),
    [anon_sym_ProfileExtension] = ACTIONS(5057),
    [anon_sym_profileExtension] = ACTIONS(5057),
    [anon_sym_permissionset] = ACTIONS(5059),
    [anon_sym_PERMISSIONSET] = ACTIONS(5059),
    [anon_sym_Permissionset] = ACTIONS(5059),
    [anon_sym_PermissionSet] = ACTIONS(5059),
    [anon_sym_permissionSet] = ACTIONS(5059),
    [anon_sym_permissionsetextension] = ACTIONS(5057),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5057),
    [anon_sym_Permissionsetextension] = ACTIONS(5057),
    [anon_sym_PermissionSetExtension] = ACTIONS(5057),
    [anon_sym_permissionSetExtension] = ACTIONS(5057),
    [sym_entitlement_keyword] = ACTIONS(5057),
    [anon_sym_pagecustomization] = ACTIONS(5057),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5057),
    [anon_sym_Pagecustomization] = ACTIONS(5057),
    [anon_sym_PageCustomization] = ACTIONS(5057),
    [anon_sym_pageCustomization] = ACTIONS(5057),
    [sym_using_keyword] = ACTIONS(5057),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5057),
  },
  [STATE(2535)] = {
    [ts_builtin_sym_end] = ACTIONS(5089),
    [anon_sym_POUNDif] = ACTIONS(5089),
    [anon_sym_POUNDIF] = ACTIONS(5089),
    [anon_sym_POUNDIf] = ACTIONS(5089),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5091),
    [anon_sym_tableextension] = ACTIONS(5089),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5089),
    [anon_sym_Tableextension] = ACTIONS(5089),
    [anon_sym_TableExtension] = ACTIONS(5089),
    [anon_sym_tableExtension] = ACTIONS(5089),
    [sym_page_keyword] = ACTIONS(5091),
    [anon_sym_pageextension] = ACTIONS(5089),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5089),
    [anon_sym_Pageextension] = ACTIONS(5089),
    [anon_sym_PageExtension] = ACTIONS(5089),
    [anon_sym_pageExtension] = ACTIONS(5089),
    [anon_sym_codeunit] = ACTIONS(5089),
    [anon_sym_CODEUNIT] = ACTIONS(5089),
    [anon_sym_Codeunit] = ACTIONS(5089),
    [anon_sym_CodeUnit] = ACTIONS(5089),
    [anon_sym_COdeunit] = ACTIONS(5089),
    [anon_sym_codeUnit] = ACTIONS(5089),
    [sym_report_keyword] = ACTIONS(5091),
    [anon_sym_reportextension] = ACTIONS(5089),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5089),
    [anon_sym_Reportextension] = ACTIONS(5089),
    [anon_sym_ReportExtension] = ACTIONS(5089),
    [anon_sym_reportExtension] = ACTIONS(5089),
    [sym_query_keyword] = ACTIONS(5089),
    [anon_sym_xmlport] = ACTIONS(5089),
    [anon_sym_XMLPORT] = ACTIONS(5089),
    [anon_sym_Xmlport] = ACTIONS(5089),
    [anon_sym_XMLport] = ACTIONS(5089),
    [anon_sym_XMLPort] = ACTIONS(5089),
    [anon_sym_XmlPort] = ACTIONS(5089),
    [anon_sym_enum] = ACTIONS(5091),
    [anon_sym_ENUM] = ACTIONS(5091),
    [anon_sym_Enum] = ACTIONS(5091),
    [anon_sym_eNUM] = ACTIONS(5089),
    [anon_sym_eNum] = ACTIONS(5089),
    [anon_sym_ENum] = ACTIONS(5089),
    [anon_sym_enumextension] = ACTIONS(5089),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5089),
    [anon_sym_Enumextension] = ACTIONS(5089),
    [anon_sym_EnumExtension] = ACTIONS(5089),
    [anon_sym_enumExtension] = ACTIONS(5089),
    [sym_interface_keyword] = ACTIONS(5089),
    [anon_sym_controladdin] = ACTIONS(5089),
    [anon_sym_CONTROLADDIN] = ACTIONS(5089),
    [anon_sym_Controladdin] = ACTIONS(5089),
    [anon_sym_ControlAddIn] = ACTIONS(5089),
    [anon_sym_ControlAddin] = ACTIONS(5089),
    [anon_sym_controlAddIn] = ACTIONS(5089),
    [anon_sym_controlAddin] = ACTIONS(5089),
    [anon_sym_dotnet] = ACTIONS(5089),
    [anon_sym_DOTNET] = ACTIONS(5089),
    [anon_sym_Dotnet] = ACTIONS(5089),
    [anon_sym_DotNet] = ACTIONS(5089),
    [anon_sym_dotNet] = ACTIONS(5089),
    [sym_profile_keyword] = ACTIONS(5091),
    [anon_sym_profileextension] = ACTIONS(5089),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5089),
    [anon_sym_Profileextension] = ACTIONS(5089),
    [anon_sym_ProfileExtension] = ACTIONS(5089),
    [anon_sym_profileExtension] = ACTIONS(5089),
    [anon_sym_permissionset] = ACTIONS(5091),
    [anon_sym_PERMISSIONSET] = ACTIONS(5091),
    [anon_sym_Permissionset] = ACTIONS(5091),
    [anon_sym_PermissionSet] = ACTIONS(5091),
    [anon_sym_permissionSet] = ACTIONS(5091),
    [anon_sym_permissionsetextension] = ACTIONS(5089),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5089),
    [anon_sym_Permissionsetextension] = ACTIONS(5089),
    [anon_sym_PermissionSetExtension] = ACTIONS(5089),
    [anon_sym_permissionSetExtension] = ACTIONS(5089),
    [sym_entitlement_keyword] = ACTIONS(5089),
    [anon_sym_pagecustomization] = ACTIONS(5089),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5089),
    [anon_sym_Pagecustomization] = ACTIONS(5089),
    [anon_sym_PageCustomization] = ACTIONS(5089),
    [anon_sym_pageCustomization] = ACTIONS(5089),
    [sym_using_keyword] = ACTIONS(5089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5089),
  },
  [STATE(2536)] = {
    [ts_builtin_sym_end] = ACTIONS(5097),
    [anon_sym_POUNDif] = ACTIONS(5097),
    [anon_sym_POUNDIF] = ACTIONS(5097),
    [anon_sym_POUNDIf] = ACTIONS(5097),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5099),
    [anon_sym_tableextension] = ACTIONS(5097),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5097),
    [anon_sym_Tableextension] = ACTIONS(5097),
    [anon_sym_TableExtension] = ACTIONS(5097),
    [anon_sym_tableExtension] = ACTIONS(5097),
    [sym_page_keyword] = ACTIONS(5099),
    [anon_sym_pageextension] = ACTIONS(5097),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5097),
    [anon_sym_Pageextension] = ACTIONS(5097),
    [anon_sym_PageExtension] = ACTIONS(5097),
    [anon_sym_pageExtension] = ACTIONS(5097),
    [anon_sym_codeunit] = ACTIONS(5097),
    [anon_sym_CODEUNIT] = ACTIONS(5097),
    [anon_sym_Codeunit] = ACTIONS(5097),
    [anon_sym_CodeUnit] = ACTIONS(5097),
    [anon_sym_COdeunit] = ACTIONS(5097),
    [anon_sym_codeUnit] = ACTIONS(5097),
    [sym_report_keyword] = ACTIONS(5099),
    [anon_sym_reportextension] = ACTIONS(5097),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5097),
    [anon_sym_Reportextension] = ACTIONS(5097),
    [anon_sym_ReportExtension] = ACTIONS(5097),
    [anon_sym_reportExtension] = ACTIONS(5097),
    [sym_query_keyword] = ACTIONS(5097),
    [anon_sym_xmlport] = ACTIONS(5097),
    [anon_sym_XMLPORT] = ACTIONS(5097),
    [anon_sym_Xmlport] = ACTIONS(5097),
    [anon_sym_XMLport] = ACTIONS(5097),
    [anon_sym_XMLPort] = ACTIONS(5097),
    [anon_sym_XmlPort] = ACTIONS(5097),
    [anon_sym_enum] = ACTIONS(5099),
    [anon_sym_ENUM] = ACTIONS(5099),
    [anon_sym_Enum] = ACTIONS(5099),
    [anon_sym_eNUM] = ACTIONS(5097),
    [anon_sym_eNum] = ACTIONS(5097),
    [anon_sym_ENum] = ACTIONS(5097),
    [anon_sym_enumextension] = ACTIONS(5097),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5097),
    [anon_sym_Enumextension] = ACTIONS(5097),
    [anon_sym_EnumExtension] = ACTIONS(5097),
    [anon_sym_enumExtension] = ACTIONS(5097),
    [sym_interface_keyword] = ACTIONS(5097),
    [anon_sym_controladdin] = ACTIONS(5097),
    [anon_sym_CONTROLADDIN] = ACTIONS(5097),
    [anon_sym_Controladdin] = ACTIONS(5097),
    [anon_sym_ControlAddIn] = ACTIONS(5097),
    [anon_sym_ControlAddin] = ACTIONS(5097),
    [anon_sym_controlAddIn] = ACTIONS(5097),
    [anon_sym_controlAddin] = ACTIONS(5097),
    [anon_sym_dotnet] = ACTIONS(5097),
    [anon_sym_DOTNET] = ACTIONS(5097),
    [anon_sym_Dotnet] = ACTIONS(5097),
    [anon_sym_DotNet] = ACTIONS(5097),
    [anon_sym_dotNet] = ACTIONS(5097),
    [sym_profile_keyword] = ACTIONS(5099),
    [anon_sym_profileextension] = ACTIONS(5097),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5097),
    [anon_sym_Profileextension] = ACTIONS(5097),
    [anon_sym_ProfileExtension] = ACTIONS(5097),
    [anon_sym_profileExtension] = ACTIONS(5097),
    [anon_sym_permissionset] = ACTIONS(5099),
    [anon_sym_PERMISSIONSET] = ACTIONS(5099),
    [anon_sym_Permissionset] = ACTIONS(5099),
    [anon_sym_PermissionSet] = ACTIONS(5099),
    [anon_sym_permissionSet] = ACTIONS(5099),
    [anon_sym_permissionsetextension] = ACTIONS(5097),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5097),
    [anon_sym_Permissionsetextension] = ACTIONS(5097),
    [anon_sym_PermissionSetExtension] = ACTIONS(5097),
    [anon_sym_permissionSetExtension] = ACTIONS(5097),
    [sym_entitlement_keyword] = ACTIONS(5097),
    [anon_sym_pagecustomization] = ACTIONS(5097),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5097),
    [anon_sym_Pagecustomization] = ACTIONS(5097),
    [anon_sym_PageCustomization] = ACTIONS(5097),
    [anon_sym_pageCustomization] = ACTIONS(5097),
    [sym_using_keyword] = ACTIONS(5097),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5097),
  },
  [STATE(2537)] = {
    [ts_builtin_sym_end] = ACTIONS(5101),
    [anon_sym_POUNDif] = ACTIONS(5101),
    [anon_sym_POUNDIF] = ACTIONS(5101),
    [anon_sym_POUNDIf] = ACTIONS(5101),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5103),
    [anon_sym_tableextension] = ACTIONS(5101),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5101),
    [anon_sym_Tableextension] = ACTIONS(5101),
    [anon_sym_TableExtension] = ACTIONS(5101),
    [anon_sym_tableExtension] = ACTIONS(5101),
    [sym_page_keyword] = ACTIONS(5103),
    [anon_sym_pageextension] = ACTIONS(5101),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5101),
    [anon_sym_Pageextension] = ACTIONS(5101),
    [anon_sym_PageExtension] = ACTIONS(5101),
    [anon_sym_pageExtension] = ACTIONS(5101),
    [anon_sym_codeunit] = ACTIONS(5101),
    [anon_sym_CODEUNIT] = ACTIONS(5101),
    [anon_sym_Codeunit] = ACTIONS(5101),
    [anon_sym_CodeUnit] = ACTIONS(5101),
    [anon_sym_COdeunit] = ACTIONS(5101),
    [anon_sym_codeUnit] = ACTIONS(5101),
    [sym_report_keyword] = ACTIONS(5103),
    [anon_sym_reportextension] = ACTIONS(5101),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5101),
    [anon_sym_Reportextension] = ACTIONS(5101),
    [anon_sym_ReportExtension] = ACTIONS(5101),
    [anon_sym_reportExtension] = ACTIONS(5101),
    [sym_query_keyword] = ACTIONS(5101),
    [anon_sym_xmlport] = ACTIONS(5101),
    [anon_sym_XMLPORT] = ACTIONS(5101),
    [anon_sym_Xmlport] = ACTIONS(5101),
    [anon_sym_XMLport] = ACTIONS(5101),
    [anon_sym_XMLPort] = ACTIONS(5101),
    [anon_sym_XmlPort] = ACTIONS(5101),
    [anon_sym_enum] = ACTIONS(5103),
    [anon_sym_ENUM] = ACTIONS(5103),
    [anon_sym_Enum] = ACTIONS(5103),
    [anon_sym_eNUM] = ACTIONS(5101),
    [anon_sym_eNum] = ACTIONS(5101),
    [anon_sym_ENum] = ACTIONS(5101),
    [anon_sym_enumextension] = ACTIONS(5101),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5101),
    [anon_sym_Enumextension] = ACTIONS(5101),
    [anon_sym_EnumExtension] = ACTIONS(5101),
    [anon_sym_enumExtension] = ACTIONS(5101),
    [sym_interface_keyword] = ACTIONS(5101),
    [anon_sym_controladdin] = ACTIONS(5101),
    [anon_sym_CONTROLADDIN] = ACTIONS(5101),
    [anon_sym_Controladdin] = ACTIONS(5101),
    [anon_sym_ControlAddIn] = ACTIONS(5101),
    [anon_sym_ControlAddin] = ACTIONS(5101),
    [anon_sym_controlAddIn] = ACTIONS(5101),
    [anon_sym_controlAddin] = ACTIONS(5101),
    [anon_sym_dotnet] = ACTIONS(5101),
    [anon_sym_DOTNET] = ACTIONS(5101),
    [anon_sym_Dotnet] = ACTIONS(5101),
    [anon_sym_DotNet] = ACTIONS(5101),
    [anon_sym_dotNet] = ACTIONS(5101),
    [sym_profile_keyword] = ACTIONS(5103),
    [anon_sym_profileextension] = ACTIONS(5101),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5101),
    [anon_sym_Profileextension] = ACTIONS(5101),
    [anon_sym_ProfileExtension] = ACTIONS(5101),
    [anon_sym_profileExtension] = ACTIONS(5101),
    [anon_sym_permissionset] = ACTIONS(5103),
    [anon_sym_PERMISSIONSET] = ACTIONS(5103),
    [anon_sym_Permissionset] = ACTIONS(5103),
    [anon_sym_PermissionSet] = ACTIONS(5103),
    [anon_sym_permissionSet] = ACTIONS(5103),
    [anon_sym_permissionsetextension] = ACTIONS(5101),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5101),
    [anon_sym_Permissionsetextension] = ACTIONS(5101),
    [anon_sym_PermissionSetExtension] = ACTIONS(5101),
    [anon_sym_permissionSetExtension] = ACTIONS(5101),
    [sym_entitlement_keyword] = ACTIONS(5101),
    [anon_sym_pagecustomization] = ACTIONS(5101),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5101),
    [anon_sym_Pagecustomization] = ACTIONS(5101),
    [anon_sym_PageCustomization] = ACTIONS(5101),
    [anon_sym_pageCustomization] = ACTIONS(5101),
    [sym_using_keyword] = ACTIONS(5101),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5101),
  },
  [STATE(2538)] = {
    [ts_builtin_sym_end] = ACTIONS(5383),
    [anon_sym_POUNDif] = ACTIONS(5383),
    [anon_sym_POUNDIF] = ACTIONS(5383),
    [anon_sym_POUNDIf] = ACTIONS(5383),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5385),
    [anon_sym_tableextension] = ACTIONS(5383),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5383),
    [anon_sym_Tableextension] = ACTIONS(5383),
    [anon_sym_TableExtension] = ACTIONS(5383),
    [anon_sym_tableExtension] = ACTIONS(5383),
    [sym_page_keyword] = ACTIONS(5385),
    [anon_sym_pageextension] = ACTIONS(5383),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5383),
    [anon_sym_Pageextension] = ACTIONS(5383),
    [anon_sym_PageExtension] = ACTIONS(5383),
    [anon_sym_pageExtension] = ACTIONS(5383),
    [anon_sym_codeunit] = ACTIONS(5383),
    [anon_sym_CODEUNIT] = ACTIONS(5383),
    [anon_sym_Codeunit] = ACTIONS(5383),
    [anon_sym_CodeUnit] = ACTIONS(5383),
    [anon_sym_COdeunit] = ACTIONS(5383),
    [anon_sym_codeUnit] = ACTIONS(5383),
    [sym_report_keyword] = ACTIONS(5385),
    [anon_sym_reportextension] = ACTIONS(5383),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5383),
    [anon_sym_Reportextension] = ACTIONS(5383),
    [anon_sym_ReportExtension] = ACTIONS(5383),
    [anon_sym_reportExtension] = ACTIONS(5383),
    [sym_query_keyword] = ACTIONS(5383),
    [anon_sym_xmlport] = ACTIONS(5383),
    [anon_sym_XMLPORT] = ACTIONS(5383),
    [anon_sym_Xmlport] = ACTIONS(5383),
    [anon_sym_XMLport] = ACTIONS(5383),
    [anon_sym_XMLPort] = ACTIONS(5383),
    [anon_sym_XmlPort] = ACTIONS(5383),
    [anon_sym_enum] = ACTIONS(5385),
    [anon_sym_ENUM] = ACTIONS(5385),
    [anon_sym_Enum] = ACTIONS(5385),
    [anon_sym_eNUM] = ACTIONS(5383),
    [anon_sym_eNum] = ACTIONS(5383),
    [anon_sym_ENum] = ACTIONS(5383),
    [anon_sym_enumextension] = ACTIONS(5383),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5383),
    [anon_sym_Enumextension] = ACTIONS(5383),
    [anon_sym_EnumExtension] = ACTIONS(5383),
    [anon_sym_enumExtension] = ACTIONS(5383),
    [sym_interface_keyword] = ACTIONS(5383),
    [anon_sym_controladdin] = ACTIONS(5383),
    [anon_sym_CONTROLADDIN] = ACTIONS(5383),
    [anon_sym_Controladdin] = ACTIONS(5383),
    [anon_sym_ControlAddIn] = ACTIONS(5383),
    [anon_sym_ControlAddin] = ACTIONS(5383),
    [anon_sym_controlAddIn] = ACTIONS(5383),
    [anon_sym_controlAddin] = ACTIONS(5383),
    [anon_sym_dotnet] = ACTIONS(5383),
    [anon_sym_DOTNET] = ACTIONS(5383),
    [anon_sym_Dotnet] = ACTIONS(5383),
    [anon_sym_DotNet] = ACTIONS(5383),
    [anon_sym_dotNet] = ACTIONS(5383),
    [sym_profile_keyword] = ACTIONS(5385),
    [anon_sym_profileextension] = ACTIONS(5383),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5383),
    [anon_sym_Profileextension] = ACTIONS(5383),
    [anon_sym_ProfileExtension] = ACTIONS(5383),
    [anon_sym_profileExtension] = ACTIONS(5383),
    [anon_sym_permissionset] = ACTIONS(5385),
    [anon_sym_PERMISSIONSET] = ACTIONS(5385),
    [anon_sym_Permissionset] = ACTIONS(5385),
    [anon_sym_PermissionSet] = ACTIONS(5385),
    [anon_sym_permissionSet] = ACTIONS(5385),
    [anon_sym_permissionsetextension] = ACTIONS(5383),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5383),
    [anon_sym_Permissionsetextension] = ACTIONS(5383),
    [anon_sym_PermissionSetExtension] = ACTIONS(5383),
    [anon_sym_permissionSetExtension] = ACTIONS(5383),
    [sym_entitlement_keyword] = ACTIONS(5383),
    [anon_sym_pagecustomization] = ACTIONS(5383),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5383),
    [anon_sym_Pagecustomization] = ACTIONS(5383),
    [anon_sym_PageCustomization] = ACTIONS(5383),
    [anon_sym_pageCustomization] = ACTIONS(5383),
    [sym_using_keyword] = ACTIONS(5383),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5383),
  },
  [STATE(2539)] = {
    [ts_builtin_sym_end] = ACTIONS(4985),
    [anon_sym_POUNDif] = ACTIONS(4985),
    [anon_sym_POUNDIF] = ACTIONS(4985),
    [anon_sym_POUNDIf] = ACTIONS(4985),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4987),
    [anon_sym_tableextension] = ACTIONS(4985),
    [anon_sym_TABLEEXTENSION] = ACTIONS(4985),
    [anon_sym_Tableextension] = ACTIONS(4985),
    [anon_sym_TableExtension] = ACTIONS(4985),
    [anon_sym_tableExtension] = ACTIONS(4985),
    [sym_page_keyword] = ACTIONS(4987),
    [anon_sym_pageextension] = ACTIONS(4985),
    [anon_sym_PAGEEXTENSION] = ACTIONS(4985),
    [anon_sym_Pageextension] = ACTIONS(4985),
    [anon_sym_PageExtension] = ACTIONS(4985),
    [anon_sym_pageExtension] = ACTIONS(4985),
    [anon_sym_codeunit] = ACTIONS(4985),
    [anon_sym_CODEUNIT] = ACTIONS(4985),
    [anon_sym_Codeunit] = ACTIONS(4985),
    [anon_sym_CodeUnit] = ACTIONS(4985),
    [anon_sym_COdeunit] = ACTIONS(4985),
    [anon_sym_codeUnit] = ACTIONS(4985),
    [sym_report_keyword] = ACTIONS(4987),
    [anon_sym_reportextension] = ACTIONS(4985),
    [anon_sym_REPORTEXTENSION] = ACTIONS(4985),
    [anon_sym_Reportextension] = ACTIONS(4985),
    [anon_sym_ReportExtension] = ACTIONS(4985),
    [anon_sym_reportExtension] = ACTIONS(4985),
    [sym_query_keyword] = ACTIONS(4985),
    [anon_sym_xmlport] = ACTIONS(4985),
    [anon_sym_XMLPORT] = ACTIONS(4985),
    [anon_sym_Xmlport] = ACTIONS(4985),
    [anon_sym_XMLport] = ACTIONS(4985),
    [anon_sym_XMLPort] = ACTIONS(4985),
    [anon_sym_XmlPort] = ACTIONS(4985),
    [anon_sym_enum] = ACTIONS(4987),
    [anon_sym_ENUM] = ACTIONS(4987),
    [anon_sym_Enum] = ACTIONS(4987),
    [anon_sym_eNUM] = ACTIONS(4985),
    [anon_sym_eNum] = ACTIONS(4985),
    [anon_sym_ENum] = ACTIONS(4985),
    [anon_sym_enumextension] = ACTIONS(4985),
    [anon_sym_ENUMEXTENSION] = ACTIONS(4985),
    [anon_sym_Enumextension] = ACTIONS(4985),
    [anon_sym_EnumExtension] = ACTIONS(4985),
    [anon_sym_enumExtension] = ACTIONS(4985),
    [sym_interface_keyword] = ACTIONS(4985),
    [anon_sym_controladdin] = ACTIONS(4985),
    [anon_sym_CONTROLADDIN] = ACTIONS(4985),
    [anon_sym_Controladdin] = ACTIONS(4985),
    [anon_sym_ControlAddIn] = ACTIONS(4985),
    [anon_sym_ControlAddin] = ACTIONS(4985),
    [anon_sym_controlAddIn] = ACTIONS(4985),
    [anon_sym_controlAddin] = ACTIONS(4985),
    [anon_sym_dotnet] = ACTIONS(4985),
    [anon_sym_DOTNET] = ACTIONS(4985),
    [anon_sym_Dotnet] = ACTIONS(4985),
    [anon_sym_DotNet] = ACTIONS(4985),
    [anon_sym_dotNet] = ACTIONS(4985),
    [sym_profile_keyword] = ACTIONS(4987),
    [anon_sym_profileextension] = ACTIONS(4985),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(4985),
    [anon_sym_Profileextension] = ACTIONS(4985),
    [anon_sym_ProfileExtension] = ACTIONS(4985),
    [anon_sym_profileExtension] = ACTIONS(4985),
    [anon_sym_permissionset] = ACTIONS(4987),
    [anon_sym_PERMISSIONSET] = ACTIONS(4987),
    [anon_sym_Permissionset] = ACTIONS(4987),
    [anon_sym_PermissionSet] = ACTIONS(4987),
    [anon_sym_permissionSet] = ACTIONS(4987),
    [anon_sym_permissionsetextension] = ACTIONS(4985),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(4985),
    [anon_sym_Permissionsetextension] = ACTIONS(4985),
    [anon_sym_PermissionSetExtension] = ACTIONS(4985),
    [anon_sym_permissionSetExtension] = ACTIONS(4985),
    [sym_entitlement_keyword] = ACTIONS(4985),
    [anon_sym_pagecustomization] = ACTIONS(4985),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(4985),
    [anon_sym_Pagecustomization] = ACTIONS(4985),
    [anon_sym_PageCustomization] = ACTIONS(4985),
    [anon_sym_pageCustomization] = ACTIONS(4985),
    [sym_using_keyword] = ACTIONS(4985),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(4985),
  },
  [STATE(2540)] = {
    [ts_builtin_sym_end] = ACTIONS(5061),
    [anon_sym_POUNDif] = ACTIONS(5061),
    [anon_sym_POUNDIF] = ACTIONS(5061),
    [anon_sym_POUNDIf] = ACTIONS(5061),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5063),
    [anon_sym_tableextension] = ACTIONS(5061),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5061),
    [anon_sym_Tableextension] = ACTIONS(5061),
    [anon_sym_TableExtension] = ACTIONS(5061),
    [anon_sym_tableExtension] = ACTIONS(5061),
    [sym_page_keyword] = ACTIONS(5063),
    [anon_sym_pageextension] = ACTIONS(5061),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5061),
    [anon_sym_Pageextension] = ACTIONS(5061),
    [anon_sym_PageExtension] = ACTIONS(5061),
    [anon_sym_pageExtension] = ACTIONS(5061),
    [anon_sym_codeunit] = ACTIONS(5061),
    [anon_sym_CODEUNIT] = ACTIONS(5061),
    [anon_sym_Codeunit] = ACTIONS(5061),
    [anon_sym_CodeUnit] = ACTIONS(5061),
    [anon_sym_COdeunit] = ACTIONS(5061),
    [anon_sym_codeUnit] = ACTIONS(5061),
    [sym_report_keyword] = ACTIONS(5063),
    [anon_sym_reportextension] = ACTIONS(5061),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5061),
    [anon_sym_Reportextension] = ACTIONS(5061),
    [anon_sym_ReportExtension] = ACTIONS(5061),
    [anon_sym_reportExtension] = ACTIONS(5061),
    [sym_query_keyword] = ACTIONS(5061),
    [anon_sym_xmlport] = ACTIONS(5061),
    [anon_sym_XMLPORT] = ACTIONS(5061),
    [anon_sym_Xmlport] = ACTIONS(5061),
    [anon_sym_XMLport] = ACTIONS(5061),
    [anon_sym_XMLPort] = ACTIONS(5061),
    [anon_sym_XmlPort] = ACTIONS(5061),
    [anon_sym_enum] = ACTIONS(5063),
    [anon_sym_ENUM] = ACTIONS(5063),
    [anon_sym_Enum] = ACTIONS(5063),
    [anon_sym_eNUM] = ACTIONS(5061),
    [anon_sym_eNum] = ACTIONS(5061),
    [anon_sym_ENum] = ACTIONS(5061),
    [anon_sym_enumextension] = ACTIONS(5061),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5061),
    [anon_sym_Enumextension] = ACTIONS(5061),
    [anon_sym_EnumExtension] = ACTIONS(5061),
    [anon_sym_enumExtension] = ACTIONS(5061),
    [sym_interface_keyword] = ACTIONS(5061),
    [anon_sym_controladdin] = ACTIONS(5061),
    [anon_sym_CONTROLADDIN] = ACTIONS(5061),
    [anon_sym_Controladdin] = ACTIONS(5061),
    [anon_sym_ControlAddIn] = ACTIONS(5061),
    [anon_sym_ControlAddin] = ACTIONS(5061),
    [anon_sym_controlAddIn] = ACTIONS(5061),
    [anon_sym_controlAddin] = ACTIONS(5061),
    [anon_sym_dotnet] = ACTIONS(5061),
    [anon_sym_DOTNET] = ACTIONS(5061),
    [anon_sym_Dotnet] = ACTIONS(5061),
    [anon_sym_DotNet] = ACTIONS(5061),
    [anon_sym_dotNet] = ACTIONS(5061),
    [sym_profile_keyword] = ACTIONS(5063),
    [anon_sym_profileextension] = ACTIONS(5061),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5061),
    [anon_sym_Profileextension] = ACTIONS(5061),
    [anon_sym_ProfileExtension] = ACTIONS(5061),
    [anon_sym_profileExtension] = ACTIONS(5061),
    [anon_sym_permissionset] = ACTIONS(5063),
    [anon_sym_PERMISSIONSET] = ACTIONS(5063),
    [anon_sym_Permissionset] = ACTIONS(5063),
    [anon_sym_PermissionSet] = ACTIONS(5063),
    [anon_sym_permissionSet] = ACTIONS(5063),
    [anon_sym_permissionsetextension] = ACTIONS(5061),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5061),
    [anon_sym_Permissionsetextension] = ACTIONS(5061),
    [anon_sym_PermissionSetExtension] = ACTIONS(5061),
    [anon_sym_permissionSetExtension] = ACTIONS(5061),
    [sym_entitlement_keyword] = ACTIONS(5061),
    [anon_sym_pagecustomization] = ACTIONS(5061),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5061),
    [anon_sym_Pagecustomization] = ACTIONS(5061),
    [anon_sym_PageCustomization] = ACTIONS(5061),
    [anon_sym_pageCustomization] = ACTIONS(5061),
    [sym_using_keyword] = ACTIONS(5061),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5061),
  },
  [STATE(2541)] = {
    [ts_builtin_sym_end] = ACTIONS(5265),
    [anon_sym_POUNDif] = ACTIONS(5265),
    [anon_sym_POUNDIF] = ACTIONS(5265),
    [anon_sym_POUNDIf] = ACTIONS(5265),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5267),
    [anon_sym_tableextension] = ACTIONS(5265),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5265),
    [anon_sym_Tableextension] = ACTIONS(5265),
    [anon_sym_TableExtension] = ACTIONS(5265),
    [anon_sym_tableExtension] = ACTIONS(5265),
    [sym_page_keyword] = ACTIONS(5267),
    [anon_sym_pageextension] = ACTIONS(5265),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5265),
    [anon_sym_Pageextension] = ACTIONS(5265),
    [anon_sym_PageExtension] = ACTIONS(5265),
    [anon_sym_pageExtension] = ACTIONS(5265),
    [anon_sym_codeunit] = ACTIONS(5265),
    [anon_sym_CODEUNIT] = ACTIONS(5265),
    [anon_sym_Codeunit] = ACTIONS(5265),
    [anon_sym_CodeUnit] = ACTIONS(5265),
    [anon_sym_COdeunit] = ACTIONS(5265),
    [anon_sym_codeUnit] = ACTIONS(5265),
    [sym_report_keyword] = ACTIONS(5267),
    [anon_sym_reportextension] = ACTIONS(5265),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5265),
    [anon_sym_Reportextension] = ACTIONS(5265),
    [anon_sym_ReportExtension] = ACTIONS(5265),
    [anon_sym_reportExtension] = ACTIONS(5265),
    [sym_query_keyword] = ACTIONS(5265),
    [anon_sym_xmlport] = ACTIONS(5265),
    [anon_sym_XMLPORT] = ACTIONS(5265),
    [anon_sym_Xmlport] = ACTIONS(5265),
    [anon_sym_XMLport] = ACTIONS(5265),
    [anon_sym_XMLPort] = ACTIONS(5265),
    [anon_sym_XmlPort] = ACTIONS(5265),
    [anon_sym_enum] = ACTIONS(5267),
    [anon_sym_ENUM] = ACTIONS(5267),
    [anon_sym_Enum] = ACTIONS(5267),
    [anon_sym_eNUM] = ACTIONS(5265),
    [anon_sym_eNum] = ACTIONS(5265),
    [anon_sym_ENum] = ACTIONS(5265),
    [anon_sym_enumextension] = ACTIONS(5265),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5265),
    [anon_sym_Enumextension] = ACTIONS(5265),
    [anon_sym_EnumExtension] = ACTIONS(5265),
    [anon_sym_enumExtension] = ACTIONS(5265),
    [sym_interface_keyword] = ACTIONS(5265),
    [anon_sym_controladdin] = ACTIONS(5265),
    [anon_sym_CONTROLADDIN] = ACTIONS(5265),
    [anon_sym_Controladdin] = ACTIONS(5265),
    [anon_sym_ControlAddIn] = ACTIONS(5265),
    [anon_sym_ControlAddin] = ACTIONS(5265),
    [anon_sym_controlAddIn] = ACTIONS(5265),
    [anon_sym_controlAddin] = ACTIONS(5265),
    [anon_sym_dotnet] = ACTIONS(5265),
    [anon_sym_DOTNET] = ACTIONS(5265),
    [anon_sym_Dotnet] = ACTIONS(5265),
    [anon_sym_DotNet] = ACTIONS(5265),
    [anon_sym_dotNet] = ACTIONS(5265),
    [sym_profile_keyword] = ACTIONS(5267),
    [anon_sym_profileextension] = ACTIONS(5265),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5265),
    [anon_sym_Profileextension] = ACTIONS(5265),
    [anon_sym_ProfileExtension] = ACTIONS(5265),
    [anon_sym_profileExtension] = ACTIONS(5265),
    [anon_sym_permissionset] = ACTIONS(5267),
    [anon_sym_PERMISSIONSET] = ACTIONS(5267),
    [anon_sym_Permissionset] = ACTIONS(5267),
    [anon_sym_PermissionSet] = ACTIONS(5267),
    [anon_sym_permissionSet] = ACTIONS(5267),
    [anon_sym_permissionsetextension] = ACTIONS(5265),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5265),
    [anon_sym_Permissionsetextension] = ACTIONS(5265),
    [anon_sym_PermissionSetExtension] = ACTIONS(5265),
    [anon_sym_permissionSetExtension] = ACTIONS(5265),
    [sym_entitlement_keyword] = ACTIONS(5265),
    [anon_sym_pagecustomization] = ACTIONS(5265),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5265),
    [anon_sym_Pagecustomization] = ACTIONS(5265),
    [anon_sym_PageCustomization] = ACTIONS(5265),
    [anon_sym_pageCustomization] = ACTIONS(5265),
    [sym_using_keyword] = ACTIONS(5265),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5265),
  },
  [STATE(2542)] = {
    [sym_identifier] = ACTIONS(2521),
    [anon_sym_DOT] = ACTIONS(2521),
    [anon_sym_EQ] = ACTIONS(2523),
    [anon_sym_DASH] = ACTIONS(2521),
    [aux_sym_boolean_token1] = ACTIONS(2521),
    [aux_sym_boolean_token2] = ACTIONS(2521),
    [sym_decimal] = ACTIONS(2521),
    [anon_sym_LPAREN] = ACTIONS(2523),
    [anon_sym_RPAREN] = ACTIONS(2523),
    [anon_sym_DOT_DOT] = ACTIONS(2523),
    [aux_sym_filter_value_token1] = ACTIONS(2521),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2521),
    [anon_sym_STAR] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2523),
    [aux_sym_record_type_token1] = ACTIONS(2521),
    [aux_sym_basic_type_token21] = ACTIONS(2521),
    [aux_sym_basic_type_token22] = ACTIONS(2521),
    [aux_sym_basic_type_token48] = ACTIONS(2521),
    [anon_sym_COLON_COLON] = ACTIONS(2523),
    [anon_sym_not] = ACTIONS(2521),
    [anon_sym_NOT] = ACTIONS(2521),
    [anon_sym_Not] = ACTIONS(2521),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2523),
    [aux_sym__expression_token1] = ACTIONS(2523),
    [aux_sym__expression_token2] = ACTIONS(2523),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2521),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2521),
    [anon_sym_SLASH] = ACTIONS(2521),
    [anon_sym_div] = ACTIONS(2521),
    [anon_sym_DIV] = ACTIONS(2521),
    [anon_sym_Div] = ACTIONS(2521),
    [anon_sym_mod] = ACTIONS(2521),
    [anon_sym_MOD] = ACTIONS(2521),
    [anon_sym_Mod] = ACTIONS(2521),
    [anon_sym_PLUS] = ACTIONS(2521),
    [anon_sym_GT_EQ] = ACTIONS(2523),
    [anon_sym_LT_EQ] = ACTIONS(2523),
    [anon_sym_GT] = ACTIONS(2521),
    [anon_sym_LT] = ACTIONS(2521),
    [anon_sym_LT_GT] = ACTIONS(2523),
    [anon_sym_and] = ACTIONS(2521),
    [anon_sym_AND] = ACTIONS(2521),
    [anon_sym_And] = ACTIONS(2521),
    [anon_sym_or] = ACTIONS(2521),
    [anon_sym_OR] = ACTIONS(2521),
    [anon_sym_Or] = ACTIONS(2521),
    [anon_sym_xor] = ACTIONS(2521),
    [anon_sym_XOR] = ACTIONS(2521),
    [anon_sym_Xor] = ACTIONS(2521),
    [anon_sym_QMARK] = ACTIONS(2523),
    [sym_datetime_literal] = ACTIONS(2523),
    [sym_date_literal] = ACTIONS(2521),
    [sym_time_literal] = ACTIONS(2521),
    [sym_biginteger_literal] = ACTIONS(2523),
    [anon_sym_in] = ACTIONS(2521),
    [anon_sym_IN] = ACTIONS(2521),
    [anon_sym_In] = ACTIONS(2521),
    [sym_page_keyword] = ACTIONS(2521),
    [anon_sym_codeunit] = ACTIONS(2521),
    [anon_sym_CODEUNIT] = ACTIONS(2521),
    [anon_sym_Codeunit] = ACTIONS(2521),
    [anon_sym_CodeUnit] = ACTIONS(2521),
    [anon_sym_COdeunit] = ACTIONS(2521),
    [anon_sym_codeUnit] = ACTIONS(2521),
    [sym_report_keyword] = ACTIONS(2521),
    [sym_query_keyword] = ACTIONS(2521),
    [anon_sym_xmlport] = ACTIONS(2521),
    [anon_sym_XMLPORT] = ACTIONS(2521),
    [anon_sym_Xmlport] = ACTIONS(2521),
    [anon_sym_XMLport] = ACTIONS(2521),
    [anon_sym_XMLPort] = ACTIONS(2521),
    [anon_sym_XmlPort] = ACTIONS(2521),
    [anon_sym_enum] = ACTIONS(2521),
    [anon_sym_ENUM] = ACTIONS(2521),
    [anon_sym_Enum] = ACTIONS(2521),
    [anon_sym_eNUM] = ACTIONS(2521),
    [anon_sym_eNum] = ACTIONS(2521),
    [anon_sym_ENum] = ACTIONS(2521),
    [sym_quoted_identifier] = ACTIONS(2523),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2523),
    [sym_integer] = ACTIONS(2521),
    [sym_continue_as_identifier] = ACTIONS(2523),
  },
  [STATE(2543)] = {
    [sym_identifier] = ACTIONS(2414),
    [anon_sym_DOT] = ACTIONS(2414),
    [anon_sym_EQ] = ACTIONS(2416),
    [anon_sym_DASH] = ACTIONS(2414),
    [aux_sym_boolean_token1] = ACTIONS(2414),
    [aux_sym_boolean_token2] = ACTIONS(2414),
    [sym_decimal] = ACTIONS(2414),
    [anon_sym_LPAREN] = ACTIONS(2416),
    [anon_sym_RPAREN] = ACTIONS(2416),
    [anon_sym_DOT_DOT] = ACTIONS(2416),
    [aux_sym_filter_value_token1] = ACTIONS(2414),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2414),
    [anon_sym_STAR] = ACTIONS(2414),
    [anon_sym_LBRACK] = ACTIONS(2416),
    [aux_sym_record_type_token1] = ACTIONS(2414),
    [aux_sym_basic_type_token21] = ACTIONS(2414),
    [aux_sym_basic_type_token22] = ACTIONS(2414),
    [aux_sym_basic_type_token48] = ACTIONS(2414),
    [anon_sym_COLON_COLON] = ACTIONS(2416),
    [anon_sym_not] = ACTIONS(2414),
    [anon_sym_NOT] = ACTIONS(2414),
    [anon_sym_Not] = ACTIONS(2414),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2416),
    [aux_sym__expression_token1] = ACTIONS(2416),
    [aux_sym__expression_token2] = ACTIONS(2416),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2414),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2414),
    [anon_sym_SLASH] = ACTIONS(2414),
    [anon_sym_div] = ACTIONS(2414),
    [anon_sym_DIV] = ACTIONS(2414),
    [anon_sym_Div] = ACTIONS(2414),
    [anon_sym_mod] = ACTIONS(2414),
    [anon_sym_MOD] = ACTIONS(2414),
    [anon_sym_Mod] = ACTIONS(2414),
    [anon_sym_PLUS] = ACTIONS(2414),
    [anon_sym_GT_EQ] = ACTIONS(2416),
    [anon_sym_LT_EQ] = ACTIONS(2416),
    [anon_sym_GT] = ACTIONS(2414),
    [anon_sym_LT] = ACTIONS(2414),
    [anon_sym_LT_GT] = ACTIONS(2416),
    [anon_sym_and] = ACTIONS(2414),
    [anon_sym_AND] = ACTIONS(2414),
    [anon_sym_And] = ACTIONS(2414),
    [anon_sym_or] = ACTIONS(2414),
    [anon_sym_OR] = ACTIONS(2414),
    [anon_sym_Or] = ACTIONS(2414),
    [anon_sym_xor] = ACTIONS(2414),
    [anon_sym_XOR] = ACTIONS(2414),
    [anon_sym_Xor] = ACTIONS(2414),
    [anon_sym_QMARK] = ACTIONS(2416),
    [sym_datetime_literal] = ACTIONS(2416),
    [sym_date_literal] = ACTIONS(2414),
    [sym_time_literal] = ACTIONS(2414),
    [sym_biginteger_literal] = ACTIONS(2416),
    [anon_sym_in] = ACTIONS(2414),
    [anon_sym_IN] = ACTIONS(2414),
    [anon_sym_In] = ACTIONS(2414),
    [sym_page_keyword] = ACTIONS(2414),
    [anon_sym_codeunit] = ACTIONS(2414),
    [anon_sym_CODEUNIT] = ACTIONS(2414),
    [anon_sym_Codeunit] = ACTIONS(2414),
    [anon_sym_CodeUnit] = ACTIONS(2414),
    [anon_sym_COdeunit] = ACTIONS(2414),
    [anon_sym_codeUnit] = ACTIONS(2414),
    [sym_report_keyword] = ACTIONS(2414),
    [sym_query_keyword] = ACTIONS(2414),
    [anon_sym_xmlport] = ACTIONS(2414),
    [anon_sym_XMLPORT] = ACTIONS(2414),
    [anon_sym_Xmlport] = ACTIONS(2414),
    [anon_sym_XMLport] = ACTIONS(2414),
    [anon_sym_XMLPort] = ACTIONS(2414),
    [anon_sym_XmlPort] = ACTIONS(2414),
    [anon_sym_enum] = ACTIONS(2414),
    [anon_sym_ENUM] = ACTIONS(2414),
    [anon_sym_Enum] = ACTIONS(2414),
    [anon_sym_eNUM] = ACTIONS(2414),
    [anon_sym_eNum] = ACTIONS(2414),
    [anon_sym_ENum] = ACTIONS(2414),
    [sym_quoted_identifier] = ACTIONS(2416),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2416),
    [sym_integer] = ACTIONS(2414),
    [sym_continue_as_identifier] = ACTIONS(2416),
  },
  [STATE(2544)] = {
    [sym_identifier] = ACTIONS(2418),
    [anon_sym_DOT] = ACTIONS(2418),
    [anon_sym_EQ] = ACTIONS(2420),
    [anon_sym_DASH] = ACTIONS(2418),
    [aux_sym_boolean_token1] = ACTIONS(2418),
    [aux_sym_boolean_token2] = ACTIONS(2418),
    [sym_decimal] = ACTIONS(2418),
    [anon_sym_LPAREN] = ACTIONS(2420),
    [anon_sym_RPAREN] = ACTIONS(2420),
    [anon_sym_DOT_DOT] = ACTIONS(2420),
    [aux_sym_filter_value_token1] = ACTIONS(2418),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2418),
    [anon_sym_STAR] = ACTIONS(2418),
    [anon_sym_LBRACK] = ACTIONS(2420),
    [aux_sym_record_type_token1] = ACTIONS(2418),
    [aux_sym_basic_type_token21] = ACTIONS(2418),
    [aux_sym_basic_type_token22] = ACTIONS(2418),
    [aux_sym_basic_type_token48] = ACTIONS(2418),
    [anon_sym_COLON_COLON] = ACTIONS(2420),
    [anon_sym_not] = ACTIONS(2418),
    [anon_sym_NOT] = ACTIONS(2418),
    [anon_sym_Not] = ACTIONS(2418),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2420),
    [aux_sym__expression_token1] = ACTIONS(2420),
    [aux_sym__expression_token2] = ACTIONS(2420),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2418),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2418),
    [anon_sym_SLASH] = ACTIONS(2418),
    [anon_sym_div] = ACTIONS(2418),
    [anon_sym_DIV] = ACTIONS(2418),
    [anon_sym_Div] = ACTIONS(2418),
    [anon_sym_mod] = ACTIONS(2418),
    [anon_sym_MOD] = ACTIONS(2418),
    [anon_sym_Mod] = ACTIONS(2418),
    [anon_sym_PLUS] = ACTIONS(2418),
    [anon_sym_GT_EQ] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(2420),
    [anon_sym_GT] = ACTIONS(2418),
    [anon_sym_LT] = ACTIONS(2418),
    [anon_sym_LT_GT] = ACTIONS(2420),
    [anon_sym_and] = ACTIONS(2418),
    [anon_sym_AND] = ACTIONS(2418),
    [anon_sym_And] = ACTIONS(2418),
    [anon_sym_or] = ACTIONS(2418),
    [anon_sym_OR] = ACTIONS(2418),
    [anon_sym_Or] = ACTIONS(2418),
    [anon_sym_xor] = ACTIONS(2418),
    [anon_sym_XOR] = ACTIONS(2418),
    [anon_sym_Xor] = ACTIONS(2418),
    [anon_sym_QMARK] = ACTIONS(2420),
    [sym_datetime_literal] = ACTIONS(2420),
    [sym_date_literal] = ACTIONS(2418),
    [sym_time_literal] = ACTIONS(2418),
    [sym_biginteger_literal] = ACTIONS(2420),
    [anon_sym_in] = ACTIONS(2418),
    [anon_sym_IN] = ACTIONS(2418),
    [anon_sym_In] = ACTIONS(2418),
    [sym_page_keyword] = ACTIONS(2418),
    [anon_sym_codeunit] = ACTIONS(2418),
    [anon_sym_CODEUNIT] = ACTIONS(2418),
    [anon_sym_Codeunit] = ACTIONS(2418),
    [anon_sym_CodeUnit] = ACTIONS(2418),
    [anon_sym_COdeunit] = ACTIONS(2418),
    [anon_sym_codeUnit] = ACTIONS(2418),
    [sym_report_keyword] = ACTIONS(2418),
    [sym_query_keyword] = ACTIONS(2418),
    [anon_sym_xmlport] = ACTIONS(2418),
    [anon_sym_XMLPORT] = ACTIONS(2418),
    [anon_sym_Xmlport] = ACTIONS(2418),
    [anon_sym_XMLport] = ACTIONS(2418),
    [anon_sym_XMLPort] = ACTIONS(2418),
    [anon_sym_XmlPort] = ACTIONS(2418),
    [anon_sym_enum] = ACTIONS(2418),
    [anon_sym_ENUM] = ACTIONS(2418),
    [anon_sym_Enum] = ACTIONS(2418),
    [anon_sym_eNUM] = ACTIONS(2418),
    [anon_sym_eNum] = ACTIONS(2418),
    [anon_sym_ENum] = ACTIONS(2418),
    [sym_quoted_identifier] = ACTIONS(2420),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2420),
    [sym_integer] = ACTIONS(2418),
    [sym_continue_as_identifier] = ACTIONS(2420),
  },
  [STATE(2545)] = {
    [sym_identifier] = ACTIONS(2422),
    [anon_sym_DOT] = ACTIONS(2422),
    [anon_sym_EQ] = ACTIONS(2424),
    [anon_sym_DASH] = ACTIONS(2422),
    [aux_sym_boolean_token1] = ACTIONS(2422),
    [aux_sym_boolean_token2] = ACTIONS(2422),
    [sym_decimal] = ACTIONS(2422),
    [anon_sym_LPAREN] = ACTIONS(2424),
    [anon_sym_RPAREN] = ACTIONS(2424),
    [anon_sym_DOT_DOT] = ACTIONS(2424),
    [aux_sym_filter_value_token1] = ACTIONS(2422),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2422),
    [anon_sym_STAR] = ACTIONS(2422),
    [anon_sym_LBRACK] = ACTIONS(2424),
    [aux_sym_record_type_token1] = ACTIONS(2422),
    [aux_sym_basic_type_token21] = ACTIONS(2422),
    [aux_sym_basic_type_token22] = ACTIONS(2422),
    [aux_sym_basic_type_token48] = ACTIONS(2422),
    [anon_sym_COLON_COLON] = ACTIONS(2424),
    [anon_sym_not] = ACTIONS(2422),
    [anon_sym_NOT] = ACTIONS(2422),
    [anon_sym_Not] = ACTIONS(2422),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2424),
    [aux_sym__expression_token1] = ACTIONS(2424),
    [aux_sym__expression_token2] = ACTIONS(2424),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2422),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2422),
    [anon_sym_SLASH] = ACTIONS(2422),
    [anon_sym_div] = ACTIONS(2422),
    [anon_sym_DIV] = ACTIONS(2422),
    [anon_sym_Div] = ACTIONS(2422),
    [anon_sym_mod] = ACTIONS(2422),
    [anon_sym_MOD] = ACTIONS(2422),
    [anon_sym_Mod] = ACTIONS(2422),
    [anon_sym_PLUS] = ACTIONS(2422),
    [anon_sym_GT_EQ] = ACTIONS(2424),
    [anon_sym_LT_EQ] = ACTIONS(2424),
    [anon_sym_GT] = ACTIONS(2422),
    [anon_sym_LT] = ACTIONS(2422),
    [anon_sym_LT_GT] = ACTIONS(2424),
    [anon_sym_and] = ACTIONS(2422),
    [anon_sym_AND] = ACTIONS(2422),
    [anon_sym_And] = ACTIONS(2422),
    [anon_sym_or] = ACTIONS(2422),
    [anon_sym_OR] = ACTIONS(2422),
    [anon_sym_Or] = ACTIONS(2422),
    [anon_sym_xor] = ACTIONS(2422),
    [anon_sym_XOR] = ACTIONS(2422),
    [anon_sym_Xor] = ACTIONS(2422),
    [anon_sym_QMARK] = ACTIONS(2424),
    [sym_datetime_literal] = ACTIONS(2424),
    [sym_date_literal] = ACTIONS(2422),
    [sym_time_literal] = ACTIONS(2422),
    [sym_biginteger_literal] = ACTIONS(2424),
    [anon_sym_in] = ACTIONS(2422),
    [anon_sym_IN] = ACTIONS(2422),
    [anon_sym_In] = ACTIONS(2422),
    [sym_page_keyword] = ACTIONS(2422),
    [anon_sym_codeunit] = ACTIONS(2422),
    [anon_sym_CODEUNIT] = ACTIONS(2422),
    [anon_sym_Codeunit] = ACTIONS(2422),
    [anon_sym_CodeUnit] = ACTIONS(2422),
    [anon_sym_COdeunit] = ACTIONS(2422),
    [anon_sym_codeUnit] = ACTIONS(2422),
    [sym_report_keyword] = ACTIONS(2422),
    [sym_query_keyword] = ACTIONS(2422),
    [anon_sym_xmlport] = ACTIONS(2422),
    [anon_sym_XMLPORT] = ACTIONS(2422),
    [anon_sym_Xmlport] = ACTIONS(2422),
    [anon_sym_XMLport] = ACTIONS(2422),
    [anon_sym_XMLPort] = ACTIONS(2422),
    [anon_sym_XmlPort] = ACTIONS(2422),
    [anon_sym_enum] = ACTIONS(2422),
    [anon_sym_ENUM] = ACTIONS(2422),
    [anon_sym_Enum] = ACTIONS(2422),
    [anon_sym_eNUM] = ACTIONS(2422),
    [anon_sym_eNum] = ACTIONS(2422),
    [anon_sym_ENum] = ACTIONS(2422),
    [sym_quoted_identifier] = ACTIONS(2424),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2424),
    [sym_integer] = ACTIONS(2422),
    [sym_continue_as_identifier] = ACTIONS(2424),
  },
  [STATE(2546)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_RPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_filter_value_token1] = ACTIONS(2426),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [anon_sym_COLON_COLON] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2428),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
  },
  [STATE(2547)] = {
    [sym_identifier] = ACTIONS(2426),
    [anon_sym_DOT] = ACTIONS(2426),
    [anon_sym_EQ] = ACTIONS(2428),
    [anon_sym_DASH] = ACTIONS(2426),
    [aux_sym_boolean_token1] = ACTIONS(2426),
    [aux_sym_boolean_token2] = ACTIONS(2426),
    [sym_decimal] = ACTIONS(2426),
    [anon_sym_LPAREN] = ACTIONS(2428),
    [anon_sym_RPAREN] = ACTIONS(2428),
    [anon_sym_DOT_DOT] = ACTIONS(2428),
    [aux_sym_filter_value_token1] = ACTIONS(2426),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2426),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [aux_sym_record_type_token1] = ACTIONS(2426),
    [aux_sym_basic_type_token21] = ACTIONS(2426),
    [aux_sym_basic_type_token22] = ACTIONS(2426),
    [aux_sym_basic_type_token48] = ACTIONS(2426),
    [anon_sym_COLON_COLON] = ACTIONS(5894),
    [anon_sym_not] = ACTIONS(2426),
    [anon_sym_NOT] = ACTIONS(2426),
    [anon_sym_Not] = ACTIONS(2426),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2428),
    [aux_sym__expression_token1] = ACTIONS(2428),
    [aux_sym__expression_token2] = ACTIONS(2428),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2426),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2426),
    [anon_sym_SLASH] = ACTIONS(2426),
    [anon_sym_div] = ACTIONS(2426),
    [anon_sym_DIV] = ACTIONS(2426),
    [anon_sym_Div] = ACTIONS(2426),
    [anon_sym_mod] = ACTIONS(2426),
    [anon_sym_MOD] = ACTIONS(2426),
    [anon_sym_Mod] = ACTIONS(2426),
    [anon_sym_PLUS] = ACTIONS(2426),
    [anon_sym_GT_EQ] = ACTIONS(2428),
    [anon_sym_LT_EQ] = ACTIONS(2428),
    [anon_sym_GT] = ACTIONS(2426),
    [anon_sym_LT] = ACTIONS(2426),
    [anon_sym_LT_GT] = ACTIONS(2428),
    [anon_sym_and] = ACTIONS(2426),
    [anon_sym_AND] = ACTIONS(2426),
    [anon_sym_And] = ACTIONS(2426),
    [anon_sym_or] = ACTIONS(2426),
    [anon_sym_OR] = ACTIONS(2426),
    [anon_sym_Or] = ACTIONS(2426),
    [anon_sym_xor] = ACTIONS(2426),
    [anon_sym_XOR] = ACTIONS(2426),
    [anon_sym_Xor] = ACTIONS(2426),
    [anon_sym_QMARK] = ACTIONS(2428),
    [sym_datetime_literal] = ACTIONS(2428),
    [sym_date_literal] = ACTIONS(2426),
    [sym_time_literal] = ACTIONS(2426),
    [sym_biginteger_literal] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2426),
    [anon_sym_IN] = ACTIONS(2426),
    [anon_sym_In] = ACTIONS(2426),
    [sym_page_keyword] = ACTIONS(2426),
    [anon_sym_codeunit] = ACTIONS(2426),
    [anon_sym_CODEUNIT] = ACTIONS(2426),
    [anon_sym_Codeunit] = ACTIONS(2426),
    [anon_sym_CodeUnit] = ACTIONS(2426),
    [anon_sym_COdeunit] = ACTIONS(2426),
    [anon_sym_codeUnit] = ACTIONS(2426),
    [sym_report_keyword] = ACTIONS(2426),
    [sym_query_keyword] = ACTIONS(2426),
    [anon_sym_xmlport] = ACTIONS(2426),
    [anon_sym_XMLPORT] = ACTIONS(2426),
    [anon_sym_Xmlport] = ACTIONS(2426),
    [anon_sym_XMLport] = ACTIONS(2426),
    [anon_sym_XMLPort] = ACTIONS(2426),
    [anon_sym_XmlPort] = ACTIONS(2426),
    [anon_sym_enum] = ACTIONS(2426),
    [anon_sym_ENUM] = ACTIONS(2426),
    [anon_sym_Enum] = ACTIONS(2426),
    [anon_sym_eNUM] = ACTIONS(2426),
    [anon_sym_eNum] = ACTIONS(2426),
    [anon_sym_ENum] = ACTIONS(2426),
    [sym_quoted_identifier] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2428),
    [sym_integer] = ACTIONS(2426),
    [sym_continue_as_identifier] = ACTIONS(2428),
  },
  [STATE(2548)] = {
    [sym_identifier] = ACTIONS(2266),
    [anon_sym_DOT] = ACTIONS(2266),
    [anon_sym_EQ] = ACTIONS(2268),
    [anon_sym_DASH] = ACTIONS(2266),
    [aux_sym_boolean_token1] = ACTIONS(2266),
    [aux_sym_boolean_token2] = ACTIONS(2266),
    [sym_decimal] = ACTIONS(2266),
    [anon_sym_LPAREN] = ACTIONS(2268),
    [anon_sym_RPAREN] = ACTIONS(2268),
    [anon_sym_DOT_DOT] = ACTIONS(2268),
    [aux_sym_filter_value_token1] = ACTIONS(2266),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2266),
    [anon_sym_STAR] = ACTIONS(2266),
    [anon_sym_LBRACK] = ACTIONS(2268),
    [aux_sym_record_type_token1] = ACTIONS(2266),
    [aux_sym_basic_type_token21] = ACTIONS(2266),
    [aux_sym_basic_type_token22] = ACTIONS(2266),
    [aux_sym_basic_type_token48] = ACTIONS(2266),
    [anon_sym_COLON_COLON] = ACTIONS(2268),
    [anon_sym_not] = ACTIONS(2266),
    [anon_sym_NOT] = ACTIONS(2266),
    [anon_sym_Not] = ACTIONS(2266),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2268),
    [aux_sym__expression_token1] = ACTIONS(2268),
    [aux_sym__expression_token2] = ACTIONS(2268),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2266),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2266),
    [anon_sym_SLASH] = ACTIONS(2266),
    [anon_sym_div] = ACTIONS(2266),
    [anon_sym_DIV] = ACTIONS(2266),
    [anon_sym_Div] = ACTIONS(2266),
    [anon_sym_mod] = ACTIONS(2266),
    [anon_sym_MOD] = ACTIONS(2266),
    [anon_sym_Mod] = ACTIONS(2266),
    [anon_sym_PLUS] = ACTIONS(2266),
    [anon_sym_GT_EQ] = ACTIONS(2268),
    [anon_sym_LT_EQ] = ACTIONS(2268),
    [anon_sym_GT] = ACTIONS(2266),
    [anon_sym_LT] = ACTIONS(2266),
    [anon_sym_LT_GT] = ACTIONS(2268),
    [anon_sym_and] = ACTIONS(2266),
    [anon_sym_AND] = ACTIONS(2266),
    [anon_sym_And] = ACTIONS(2266),
    [anon_sym_or] = ACTIONS(2266),
    [anon_sym_OR] = ACTIONS(2266),
    [anon_sym_Or] = ACTIONS(2266),
    [anon_sym_xor] = ACTIONS(2266),
    [anon_sym_XOR] = ACTIONS(2266),
    [anon_sym_Xor] = ACTIONS(2266),
    [anon_sym_QMARK] = ACTIONS(2268),
    [sym_datetime_literal] = ACTIONS(2268),
    [sym_date_literal] = ACTIONS(2266),
    [sym_time_literal] = ACTIONS(2266),
    [sym_biginteger_literal] = ACTIONS(2268),
    [anon_sym_in] = ACTIONS(2266),
    [anon_sym_IN] = ACTIONS(2266),
    [anon_sym_In] = ACTIONS(2266),
    [sym_page_keyword] = ACTIONS(2266),
    [anon_sym_codeunit] = ACTIONS(2266),
    [anon_sym_CODEUNIT] = ACTIONS(2266),
    [anon_sym_Codeunit] = ACTIONS(2266),
    [anon_sym_CodeUnit] = ACTIONS(2266),
    [anon_sym_COdeunit] = ACTIONS(2266),
    [anon_sym_codeUnit] = ACTIONS(2266),
    [sym_report_keyword] = ACTIONS(2266),
    [sym_query_keyword] = ACTIONS(2266),
    [anon_sym_xmlport] = ACTIONS(2266),
    [anon_sym_XMLPORT] = ACTIONS(2266),
    [anon_sym_Xmlport] = ACTIONS(2266),
    [anon_sym_XMLport] = ACTIONS(2266),
    [anon_sym_XMLPort] = ACTIONS(2266),
    [anon_sym_XmlPort] = ACTIONS(2266),
    [anon_sym_enum] = ACTIONS(2266),
    [anon_sym_ENUM] = ACTIONS(2266),
    [anon_sym_Enum] = ACTIONS(2266),
    [anon_sym_eNUM] = ACTIONS(2266),
    [anon_sym_eNum] = ACTIONS(2266),
    [anon_sym_ENum] = ACTIONS(2266),
    [sym_quoted_identifier] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2268),
    [sym_integer] = ACTIONS(2266),
    [sym_continue_as_identifier] = ACTIONS(2268),
  },
  [STATE(2549)] = {
    [sym_identifier] = ACTIONS(5877),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_DASH] = ACTIONS(5879),
    [aux_sym_boolean_token1] = ACTIONS(5877),
    [aux_sym_boolean_token2] = ACTIONS(5877),
    [sym_decimal] = ACTIONS(5877),
    [anon_sym_LPAREN] = ACTIONS(5884),
    [anon_sym_RPAREN] = ACTIONS(5884),
    [anon_sym_DOT_DOT] = ACTIONS(5886),
    [aux_sym_filter_value_token1] = ACTIONS(5877),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5877),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(5886),
    [aux_sym_record_type_token1] = ACTIONS(5877),
    [aux_sym_basic_type_token21] = ACTIONS(5877),
    [aux_sym_basic_type_token22] = ACTIONS(5877),
    [aux_sym_basic_type_token48] = ACTIONS(5877),
    [anon_sym_COLON_COLON] = ACTIONS(5889),
    [anon_sym_not] = ACTIONS(5877),
    [anon_sym_NOT] = ACTIONS(5877),
    [anon_sym_Not] = ACTIONS(5877),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5877),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5877),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(5879),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(5884),
    [sym_date_literal] = ACTIONS(5877),
    [sym_time_literal] = ACTIONS(5877),
    [sym_biginteger_literal] = ACTIONS(5884),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(5877),
    [anon_sym_codeunit] = ACTIONS(5877),
    [anon_sym_CODEUNIT] = ACTIONS(5877),
    [anon_sym_Codeunit] = ACTIONS(5877),
    [anon_sym_CodeUnit] = ACTIONS(5877),
    [anon_sym_COdeunit] = ACTIONS(5877),
    [anon_sym_codeUnit] = ACTIONS(5877),
    [sym_report_keyword] = ACTIONS(5877),
    [sym_query_keyword] = ACTIONS(5877),
    [anon_sym_xmlport] = ACTIONS(5877),
    [anon_sym_XMLPORT] = ACTIONS(5877),
    [anon_sym_Xmlport] = ACTIONS(5877),
    [anon_sym_XMLport] = ACTIONS(5877),
    [anon_sym_XMLPort] = ACTIONS(5877),
    [anon_sym_XmlPort] = ACTIONS(5877),
    [anon_sym_enum] = ACTIONS(5877),
    [anon_sym_ENUM] = ACTIONS(5877),
    [anon_sym_Enum] = ACTIONS(5877),
    [anon_sym_eNUM] = ACTIONS(5877),
    [anon_sym_eNum] = ACTIONS(5877),
    [anon_sym_ENum] = ACTIONS(5877),
    [sym_quoted_identifier] = ACTIONS(5884),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5884),
    [sym_integer] = ACTIONS(5877),
    [sym_continue_as_identifier] = ACTIONS(5884),
  },
  [STATE(2550)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2623),
    [sym_preproc_conditional_case_patterns] = STATE(2623),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(5896),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5898),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(5898),
    [anon_sym_ELSE] = ACTIONS(5898),
    [anon_sym_Else] = ACTIONS(5898),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2551)] = {
    [sym_boolean] = STATE(6824),
    [sym_option_member_list] = STATE(6847),
    [sym_option_member] = STATE(6790),
    [sym_keyword_identifier] = STATE(6824),
    [sym_codeunit_keyword] = STATE(6828),
    [sym_xmlport_keyword] = STATE(6828),
    [sym_enum_keyword] = STATE(6828),
    [sym_keyword_as_identifier] = STATE(6824),
    [aux_sym_option_member_list_repeat2] = STATE(2553),
    [sym_identifier] = ACTIONS(5900),
    [anon_sym_SEMI] = ACTIONS(275),
    [anon_sym_RBRACE] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(5902),
    [anon_sym_DASH] = ACTIONS(5904),
    [aux_sym_boolean_token1] = ACTIONS(5906),
    [aux_sym_boolean_token2] = ACTIONS(5906),
    [aux_sym_where_condition_token1] = ACTIONS(5908),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5910),
    [anon_sym_LBRACK] = ACTIONS(275),
    [aux_sym_record_type_token1] = ACTIONS(5910),
    [aux_sym_basic_type_token21] = ACTIONS(5910),
    [aux_sym_basic_type_token22] = ACTIONS(5912),
    [aux_sym_basic_type_token48] = ACTIONS(5910),
    [aux_sym_basic_type_token53] = ACTIONS(5908),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5908),
    [aux_sym_modify_modification_token1] = ACTIONS(277),
    [aux_sym_separator_action_token1] = ACTIONS(5908),
    [aux_sym_assembly_declaration_token1] = ACTIONS(277),
    [aux_sym_type_declaration_token1] = ACTIONS(5908),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(277),
    [anon_sym_POUNDif] = ACTIONS(275),
    [anon_sym_POUNDIF] = ACTIONS(275),
    [anon_sym_POUNDIf] = ACTIONS(275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5910),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5910),
    [sym_page_keyword] = ACTIONS(5910),
    [anon_sym_codeunit] = ACTIONS(5914),
    [anon_sym_CODEUNIT] = ACTIONS(5914),
    [anon_sym_Codeunit] = ACTIONS(5914),
    [anon_sym_CodeUnit] = ACTIONS(5914),
    [anon_sym_COdeunit] = ACTIONS(5914),
    [anon_sym_codeUnit] = ACTIONS(5914),
    [sym_report_keyword] = ACTIONS(5910),
    [sym_query_keyword] = ACTIONS(5910),
    [anon_sym_xmlport] = ACTIONS(5916),
    [anon_sym_XMLPORT] = ACTIONS(5916),
    [anon_sym_Xmlport] = ACTIONS(5916),
    [anon_sym_XMLport] = ACTIONS(5916),
    [anon_sym_XMLPort] = ACTIONS(5916),
    [anon_sym_XmlPort] = ACTIONS(5916),
    [anon_sym_enum] = ACTIONS(5918),
    [anon_sym_ENUM] = ACTIONS(5918),
    [anon_sym_Enum] = ACTIONS(5918),
    [anon_sym_eNUM] = ACTIONS(5918),
    [anon_sym_eNum] = ACTIONS(5918),
    [anon_sym_ENum] = ACTIONS(5918),
    [sym_procedure_keyword] = ACTIONS(277),
    [sym_trigger_keyword] = ACTIONS(277),
    [sym_var_keyword] = ACTIONS(277),
    [sym_local_keyword] = ACTIONS(5900),
    [sym_internal_keyword] = ACTIONS(5900),
    [sym_protected_keyword] = ACTIONS(5900),
    [sym_event_keyword] = ACTIONS(277),
    [sym_fields_keyword] = ACTIONS(277),
    [sym_keys_keyword] = ACTIONS(277),
    [sym_key_keyword] = ACTIONS(5908),
    [sym_fieldgroups_keyword] = ACTIONS(277),
    [sym_actions_keyword] = ACTIONS(277),
    [sym_layout_keyword] = ACTIONS(277),
    [sym_dataset_keyword] = ACTIONS(5908),
    [sym_elements_keyword] = ACTIONS(277),
    [sym_labels_keyword] = ACTIONS(277),
    [sym_rendering_keyword] = ACTIONS(277),
    [sym_requestpage_keyword] = ACTIONS(277),
    [sym_schema_keyword] = ACTIONS(277),
    [sym_views_keyword] = ACTIONS(277),
    [sym_quoted_identifier] = ACTIONS(5920),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5920),
    [sym_integer] = ACTIONS(5920),
    [sym_property_name] = ACTIONS(275),
    [sym_preproc_open] = ACTIONS(275),
    [sym_begin_keyword] = ACTIONS(275),
  },
  [STATE(2552)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2596),
    [sym_preproc_conditional_case_patterns] = STATE(2596),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(5922),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5924),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [anon_sym_else] = ACTIONS(5924),
    [anon_sym_ELSE] = ACTIONS(5924),
    [anon_sym_Else] = ACTIONS(5924),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2553)] = {
    [sym_boolean] = STATE(6824),
    [sym_option_member] = STATE(6799),
    [sym_keyword_identifier] = STATE(6824),
    [sym_codeunit_keyword] = STATE(6828),
    [sym_xmlport_keyword] = STATE(6828),
    [sym_enum_keyword] = STATE(6828),
    [sym_keyword_as_identifier] = STATE(6824),
    [aux_sym_option_member_list_repeat2] = STATE(2716),
    [sym_identifier] = ACTIONS(5900),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_RBRACE] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(5926),
    [anon_sym_DASH] = ACTIONS(5904),
    [aux_sym_boolean_token1] = ACTIONS(5906),
    [aux_sym_boolean_token2] = ACTIONS(5906),
    [aux_sym_where_condition_token1] = ACTIONS(5908),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5910),
    [anon_sym_LBRACK] = ACTIONS(374),
    [aux_sym_record_type_token1] = ACTIONS(5910),
    [aux_sym_basic_type_token21] = ACTIONS(5910),
    [aux_sym_basic_type_token22] = ACTIONS(5912),
    [aux_sym_basic_type_token48] = ACTIONS(5910),
    [aux_sym_basic_type_token53] = ACTIONS(5908),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5908),
    [aux_sym_modify_modification_token1] = ACTIONS(376),
    [aux_sym_separator_action_token1] = ACTIONS(5908),
    [aux_sym_assembly_declaration_token1] = ACTIONS(376),
    [aux_sym_type_declaration_token1] = ACTIONS(5908),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(376),
    [anon_sym_POUNDif] = ACTIONS(374),
    [anon_sym_POUNDIF] = ACTIONS(374),
    [anon_sym_POUNDIf] = ACTIONS(374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5910),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5910),
    [sym_page_keyword] = ACTIONS(5910),
    [anon_sym_codeunit] = ACTIONS(5914),
    [anon_sym_CODEUNIT] = ACTIONS(5914),
    [anon_sym_Codeunit] = ACTIONS(5914),
    [anon_sym_CodeUnit] = ACTIONS(5914),
    [anon_sym_COdeunit] = ACTIONS(5914),
    [anon_sym_codeUnit] = ACTIONS(5914),
    [sym_report_keyword] = ACTIONS(5910),
    [sym_query_keyword] = ACTIONS(5910),
    [anon_sym_xmlport] = ACTIONS(5916),
    [anon_sym_XMLPORT] = ACTIONS(5916),
    [anon_sym_Xmlport] = ACTIONS(5916),
    [anon_sym_XMLport] = ACTIONS(5916),
    [anon_sym_XMLPort] = ACTIONS(5916),
    [anon_sym_XmlPort] = ACTIONS(5916),
    [anon_sym_enum] = ACTIONS(5918),
    [anon_sym_ENUM] = ACTIONS(5918),
    [anon_sym_Enum] = ACTIONS(5918),
    [anon_sym_eNUM] = ACTIONS(5918),
    [anon_sym_eNum] = ACTIONS(5918),
    [anon_sym_ENum] = ACTIONS(5918),
    [sym_procedure_keyword] = ACTIONS(376),
    [sym_trigger_keyword] = ACTIONS(376),
    [sym_var_keyword] = ACTIONS(376),
    [sym_local_keyword] = ACTIONS(5900),
    [sym_internal_keyword] = ACTIONS(5900),
    [sym_protected_keyword] = ACTIONS(5900),
    [sym_event_keyword] = ACTIONS(376),
    [sym_fields_keyword] = ACTIONS(376),
    [sym_keys_keyword] = ACTIONS(376),
    [sym_key_keyword] = ACTIONS(5908),
    [sym_fieldgroups_keyword] = ACTIONS(376),
    [sym_actions_keyword] = ACTIONS(376),
    [sym_layout_keyword] = ACTIONS(376),
    [sym_dataset_keyword] = ACTIONS(5908),
    [sym_elements_keyword] = ACTIONS(376),
    [sym_labels_keyword] = ACTIONS(376),
    [sym_rendering_keyword] = ACTIONS(376),
    [sym_requestpage_keyword] = ACTIONS(376),
    [sym_schema_keyword] = ACTIONS(376),
    [sym_views_keyword] = ACTIONS(376),
    [sym_quoted_identifier] = ACTIONS(5920),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5920),
    [sym_integer] = ACTIONS(5920),
    [sym_property_name] = ACTIONS(374),
    [sym_preproc_open] = ACTIONS(374),
    [sym_begin_keyword] = ACTIONS(374),
  },
  [STATE(2554)] = {
    [sym_boolean] = STATE(2158),
    [sym_code_block] = STATE(1910),
    [sym_assignment_expression] = STATE(2158),
    [sym__expression] = STATE(2158),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2158),
    [sym_multiplicative_expression] = STATE(2158),
    [sym_additive_expression] = STATE(2158),
    [sym_comparison_expression] = STATE(2158),
    [sym_logical_expression] = STATE(2158),
    [sym_ternary_expression] = STATE(2158),
    [sym_unary_expression] = STATE(2158),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2158),
    [sym_list_literal] = STATE(2158),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2158),
    [sym__literal_value] = STATE(2158),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(2735),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(5928),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(553),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2739),
    [anon_sym_POUNDif] = ACTIONS(2735),
    [anon_sym_POUNDIF] = ACTIONS(2735),
    [anon_sym_POUNDIf] = ACTIONS(2735),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(5930),
    [sym_date_literal] = ACTIONS(5928),
    [sym_time_literal] = ACTIONS(5928),
    [sym_biginteger_literal] = ACTIONS(5930),
    [anon_sym_else] = ACTIONS(2739),
    [anon_sym_ELSE] = ACTIONS(2739),
    [anon_sym_Else] = ACTIONS(2739),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5930),
    [sym_integer] = ACTIONS(5928),
    [sym_continue_as_identifier] = ACTIONS(5930),
    [sym_preproc_open] = ACTIONS(2735),
    [sym_begin_keyword] = ACTIONS(555),
  },
  [STATE(2555)] = {
    [sym_identifier] = ACTIONS(5877),
    [anon_sym_DOT] = ACTIONS(5932),
    [anon_sym_EQ] = ACTIONS(5934),
    [anon_sym_DASH] = ACTIONS(5936),
    [aux_sym_boolean_token1] = ACTIONS(5877),
    [aux_sym_boolean_token2] = ACTIONS(5877),
    [sym_decimal] = ACTIONS(5877),
    [anon_sym_LPAREN] = ACTIONS(5884),
    [anon_sym_RPAREN] = ACTIONS(5884),
    [anon_sym_DOT_DOT] = ACTIONS(5939),
    [aux_sym_filter_value_token1] = ACTIONS(5877),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5877),
    [anon_sym_STAR] = ACTIONS(5932),
    [anon_sym_LBRACK] = ACTIONS(5939),
    [aux_sym_record_type_token1] = ACTIONS(5877),
    [aux_sym_basic_type_token21] = ACTIONS(5877),
    [aux_sym_basic_type_token22] = ACTIONS(5877),
    [aux_sym_basic_type_token48] = ACTIONS(5877),
    [anon_sym_not] = ACTIONS(5877),
    [anon_sym_NOT] = ACTIONS(5877),
    [anon_sym_Not] = ACTIONS(5877),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(5934),
    [aux_sym__expression_token1] = ACTIONS(5934),
    [aux_sym__expression_token2] = ACTIONS(5934),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5877),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5877),
    [anon_sym_SLASH] = ACTIONS(5932),
    [anon_sym_div] = ACTIONS(5932),
    [anon_sym_DIV] = ACTIONS(5932),
    [anon_sym_Div] = ACTIONS(5932),
    [anon_sym_mod] = ACTIONS(5932),
    [anon_sym_MOD] = ACTIONS(5932),
    [anon_sym_Mod] = ACTIONS(5932),
    [anon_sym_PLUS] = ACTIONS(5936),
    [anon_sym_GT_EQ] = ACTIONS(5934),
    [anon_sym_LT_EQ] = ACTIONS(5934),
    [anon_sym_GT] = ACTIONS(5932),
    [anon_sym_LT] = ACTIONS(5932),
    [anon_sym_LT_GT] = ACTIONS(5934),
    [anon_sym_and] = ACTIONS(5932),
    [anon_sym_AND] = ACTIONS(5932),
    [anon_sym_And] = ACTIONS(5932),
    [anon_sym_or] = ACTIONS(5932),
    [anon_sym_OR] = ACTIONS(5932),
    [anon_sym_Or] = ACTIONS(5932),
    [anon_sym_xor] = ACTIONS(5932),
    [anon_sym_XOR] = ACTIONS(5932),
    [anon_sym_Xor] = ACTIONS(5932),
    [anon_sym_QMARK] = ACTIONS(5934),
    [sym_datetime_literal] = ACTIONS(5884),
    [sym_date_literal] = ACTIONS(5877),
    [sym_time_literal] = ACTIONS(5877),
    [sym_biginteger_literal] = ACTIONS(5884),
    [anon_sym_in] = ACTIONS(5932),
    [anon_sym_IN] = ACTIONS(5932),
    [anon_sym_In] = ACTIONS(5932),
    [sym_page_keyword] = ACTIONS(5877),
    [anon_sym_codeunit] = ACTIONS(5877),
    [anon_sym_CODEUNIT] = ACTIONS(5877),
    [anon_sym_Codeunit] = ACTIONS(5877),
    [anon_sym_CodeUnit] = ACTIONS(5877),
    [anon_sym_COdeunit] = ACTIONS(5877),
    [anon_sym_codeUnit] = ACTIONS(5877),
    [sym_report_keyword] = ACTIONS(5877),
    [sym_query_keyword] = ACTIONS(5877),
    [anon_sym_xmlport] = ACTIONS(5877),
    [anon_sym_XMLPORT] = ACTIONS(5877),
    [anon_sym_Xmlport] = ACTIONS(5877),
    [anon_sym_XMLport] = ACTIONS(5877),
    [anon_sym_XMLPort] = ACTIONS(5877),
    [anon_sym_XmlPort] = ACTIONS(5877),
    [anon_sym_enum] = ACTIONS(5877),
    [anon_sym_ENUM] = ACTIONS(5877),
    [anon_sym_Enum] = ACTIONS(5877),
    [anon_sym_eNUM] = ACTIONS(5877),
    [anon_sym_eNum] = ACTIONS(5877),
    [anon_sym_ENum] = ACTIONS(5877),
    [sym_quoted_identifier] = ACTIONS(5884),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5884),
    [sym_integer] = ACTIONS(5877),
    [sym_continue_as_identifier] = ACTIONS(5884),
  },
  [STATE(2556)] = {
    [sym_identifier] = ACTIONS(2551),
    [anon_sym_DOT] = ACTIONS(2551),
    [anon_sym_EQ] = ACTIONS(2553),
    [anon_sym_DASH] = ACTIONS(2551),
    [aux_sym_boolean_token1] = ACTIONS(2551),
    [aux_sym_boolean_token2] = ACTIONS(2551),
    [sym_decimal] = ACTIONS(2551),
    [anon_sym_LPAREN] = ACTIONS(2553),
    [anon_sym_RPAREN] = ACTIONS(2553),
    [anon_sym_DOT_DOT] = ACTIONS(2553),
    [aux_sym_filter_value_token1] = ACTIONS(2551),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2551),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_LBRACK] = ACTIONS(2553),
    [aux_sym_record_type_token1] = ACTIONS(2551),
    [aux_sym_basic_type_token21] = ACTIONS(2551),
    [aux_sym_basic_type_token22] = ACTIONS(2551),
    [aux_sym_basic_type_token48] = ACTIONS(2551),
    [anon_sym_not] = ACTIONS(2551),
    [anon_sym_NOT] = ACTIONS(2551),
    [anon_sym_Not] = ACTIONS(2551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2553),
    [aux_sym__expression_token1] = ACTIONS(2553),
    [aux_sym__expression_token2] = ACTIONS(2553),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2551),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2551),
    [anon_sym_SLASH] = ACTIONS(2551),
    [anon_sym_div] = ACTIONS(2551),
    [anon_sym_DIV] = ACTIONS(2551),
    [anon_sym_Div] = ACTIONS(2551),
    [anon_sym_mod] = ACTIONS(2551),
    [anon_sym_MOD] = ACTIONS(2551),
    [anon_sym_Mod] = ACTIONS(2551),
    [anon_sym_PLUS] = ACTIONS(2551),
    [anon_sym_GT_EQ] = ACTIONS(2553),
    [anon_sym_LT_EQ] = ACTIONS(2553),
    [anon_sym_GT] = ACTIONS(2551),
    [anon_sym_LT] = ACTIONS(2551),
    [anon_sym_LT_GT] = ACTIONS(2553),
    [anon_sym_and] = ACTIONS(2551),
    [anon_sym_AND] = ACTIONS(2551),
    [anon_sym_And] = ACTIONS(2551),
    [anon_sym_or] = ACTIONS(2551),
    [anon_sym_OR] = ACTIONS(2551),
    [anon_sym_Or] = ACTIONS(2551),
    [anon_sym_xor] = ACTIONS(2551),
    [anon_sym_XOR] = ACTIONS(2551),
    [anon_sym_Xor] = ACTIONS(2551),
    [anon_sym_QMARK] = ACTIONS(2553),
    [sym_datetime_literal] = ACTIONS(2553),
    [sym_date_literal] = ACTIONS(2551),
    [sym_time_literal] = ACTIONS(2551),
    [sym_biginteger_literal] = ACTIONS(2553),
    [anon_sym_in] = ACTIONS(2551),
    [anon_sym_IN] = ACTIONS(2551),
    [anon_sym_In] = ACTIONS(2551),
    [sym_page_keyword] = ACTIONS(2551),
    [anon_sym_codeunit] = ACTIONS(2551),
    [anon_sym_CODEUNIT] = ACTIONS(2551),
    [anon_sym_Codeunit] = ACTIONS(2551),
    [anon_sym_CodeUnit] = ACTIONS(2551),
    [anon_sym_COdeunit] = ACTIONS(2551),
    [anon_sym_codeUnit] = ACTIONS(2551),
    [sym_report_keyword] = ACTIONS(2551),
    [sym_query_keyword] = ACTIONS(2551),
    [anon_sym_xmlport] = ACTIONS(2551),
    [anon_sym_XMLPORT] = ACTIONS(2551),
    [anon_sym_Xmlport] = ACTIONS(2551),
    [anon_sym_XMLport] = ACTIONS(2551),
    [anon_sym_XMLPort] = ACTIONS(2551),
    [anon_sym_XmlPort] = ACTIONS(2551),
    [anon_sym_enum] = ACTIONS(2551),
    [anon_sym_ENUM] = ACTIONS(2551),
    [anon_sym_Enum] = ACTIONS(2551),
    [anon_sym_eNUM] = ACTIONS(2551),
    [anon_sym_eNum] = ACTIONS(2551),
    [anon_sym_ENum] = ACTIONS(2551),
    [sym_quoted_identifier] = ACTIONS(2553),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2553),
    [sym_integer] = ACTIONS(2551),
    [sym_continue_as_identifier] = ACTIONS(2553),
  },
  [STATE(2557)] = {
    [sym__body_element] = STATE(6090),
    [sym_empty_statement] = STATE(6090),
    [sym_property] = STATE(6090),
    [sym_fields_section] = STATE(6090),
    [sym_keys_section] = STATE(6090),
    [sym_fieldgroups_section] = STATE(6090),
    [sym_enum_value_declaration] = STATE(6090),
    [sym_labels_section] = STATE(6090),
    [sym_layout_section] = STATE(6090),
    [sym_modify_modification] = STATE(6090),
    [sym_actions_section] = STATE(6090),
    [sym_views_section] = STATE(6090),
    [sym_dataset_section] = STATE(6090),
    [sym_report_dataitem] = STATE(2629),
    [sym__report_body_element] = STATE(2629),
    [sym_preproc_conditional_report] = STATE(2629),
    [sym_report_column] = STATE(2629),
    [sym_requestpage_section] = STATE(6090),
    [sym_rendering_section] = STATE(6090),
    [sym_elements_section] = STATE(6090),
    [sym_schema_section] = STATE(6090),
    [sym_assembly_declaration] = STATE(6090),
    [sym_event_declaration] = STATE(6090),
    [sym_procedure] = STATE(6090),
    [sym_preproc_split_procedure] = STATE(6090),
    [sym__procedure_header] = STATE(8089),
    [sym_procedure_modifier] = STATE(12657),
    [sym_trigger_declaration] = STATE(6090),
    [sym_var_section] = STATE(6090),
    [sym_attribute_item] = STATE(3722),
    [sym_preproc_conditional] = STATE(6090),
    [sym_preproc_if] = STATE(2557),
    [sym_preproc_elif] = STATE(2717),
    [sym_preproc_else] = STATE(3013),
    [sym_preproc_endif] = STATE(6091),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(2755),
    [aux_sym_report_dataitem_repeat1] = STATE(2629),
    [aux_sym_preproc_conditional_report_repeat1] = STATE(7832),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_repeat1] = STATE(8159),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(2883),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(2558)] = {
    [sym__body_element] = STATE(6090),
    [sym_empty_statement] = STATE(6090),
    [sym_property] = STATE(6090),
    [sym_fields_section] = STATE(6090),
    [sym_keys_section] = STATE(6090),
    [sym_fieldgroups_section] = STATE(6090),
    [sym_enum_value_declaration] = STATE(6090),
    [sym_labels_section] = STATE(6090),
    [sym_layout_section] = STATE(6090),
    [sym_modify_modification] = STATE(6090),
    [sym_actions_section] = STATE(6090),
    [sym_views_section] = STATE(6090),
    [sym_dataset_section] = STATE(6090),
    [sym_report_dataitem] = STATE(2634),
    [sym__report_body_element] = STATE(2634),
    [sym_preproc_conditional_report] = STATE(2634),
    [sym_report_column] = STATE(2634),
    [sym_requestpage_section] = STATE(6090),
    [sym_rendering_section] = STATE(6090),
    [sym_elements_section] = STATE(6090),
    [sym_schema_section] = STATE(6090),
    [sym_assembly_declaration] = STATE(6090),
    [sym_event_declaration] = STATE(6090),
    [sym_procedure] = STATE(6090),
    [sym_preproc_split_procedure] = STATE(6090),
    [sym__procedure_header] = STATE(8087),
    [sym_procedure_modifier] = STATE(12657),
    [sym_trigger_declaration] = STATE(6090),
    [sym_var_section] = STATE(6090),
    [sym_attribute_item] = STATE(3722),
    [sym_preproc_conditional] = STATE(6090),
    [sym_preproc_if] = STATE(2557),
    [sym_preproc_elif] = STATE(2717),
    [sym_preproc_else] = STATE(3205),
    [sym_preproc_endif] = STATE(6863),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(2739),
    [aux_sym_report_dataitem_repeat1] = STATE(2634),
    [aux_sym_preproc_conditional_report_repeat1] = STATE(8095),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_repeat1] = STATE(8094),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(2883),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(2559)] = {
    [sym_identifier] = ACTIONS(5877),
    [anon_sym_DOT] = ACTIONS(2434),
    [anon_sym_EQ] = ACTIONS(2436),
    [anon_sym_DASH] = ACTIONS(5879),
    [aux_sym_boolean_token1] = ACTIONS(5877),
    [aux_sym_boolean_token2] = ACTIONS(5877),
    [sym_decimal] = ACTIONS(5877),
    [anon_sym_LPAREN] = ACTIONS(5884),
    [anon_sym_RPAREN] = ACTIONS(5884),
    [anon_sym_DOT_DOT] = ACTIONS(5886),
    [aux_sym_filter_value_token1] = ACTIONS(5877),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5877),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_LBRACK] = ACTIONS(5886),
    [aux_sym_record_type_token1] = ACTIONS(5877),
    [aux_sym_basic_type_token21] = ACTIONS(5877),
    [aux_sym_basic_type_token22] = ACTIONS(5877),
    [aux_sym_basic_type_token48] = ACTIONS(5877),
    [anon_sym_not] = ACTIONS(5877),
    [anon_sym_NOT] = ACTIONS(5877),
    [anon_sym_Not] = ACTIONS(5877),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2436),
    [aux_sym__expression_token1] = ACTIONS(2436),
    [aux_sym__expression_token2] = ACTIONS(2436),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5877),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5877),
    [anon_sym_SLASH] = ACTIONS(2434),
    [anon_sym_div] = ACTIONS(2434),
    [anon_sym_DIV] = ACTIONS(2434),
    [anon_sym_Div] = ACTIONS(2434),
    [anon_sym_mod] = ACTIONS(2434),
    [anon_sym_MOD] = ACTIONS(2434),
    [anon_sym_Mod] = ACTIONS(2434),
    [anon_sym_PLUS] = ACTIONS(5879),
    [anon_sym_GT_EQ] = ACTIONS(2436),
    [anon_sym_LT_EQ] = ACTIONS(2436),
    [anon_sym_GT] = ACTIONS(2434),
    [anon_sym_LT] = ACTIONS(2434),
    [anon_sym_LT_GT] = ACTIONS(2436),
    [anon_sym_and] = ACTIONS(2434),
    [anon_sym_AND] = ACTIONS(2434),
    [anon_sym_And] = ACTIONS(2434),
    [anon_sym_or] = ACTIONS(2434),
    [anon_sym_OR] = ACTIONS(2434),
    [anon_sym_Or] = ACTIONS(2434),
    [anon_sym_xor] = ACTIONS(2434),
    [anon_sym_XOR] = ACTIONS(2434),
    [anon_sym_Xor] = ACTIONS(2434),
    [anon_sym_QMARK] = ACTIONS(2436),
    [sym_datetime_literal] = ACTIONS(5884),
    [sym_date_literal] = ACTIONS(5877),
    [sym_time_literal] = ACTIONS(5877),
    [sym_biginteger_literal] = ACTIONS(5884),
    [anon_sym_in] = ACTIONS(2434),
    [anon_sym_IN] = ACTIONS(2434),
    [anon_sym_In] = ACTIONS(2434),
    [sym_page_keyword] = ACTIONS(5877),
    [anon_sym_codeunit] = ACTIONS(5877),
    [anon_sym_CODEUNIT] = ACTIONS(5877),
    [anon_sym_Codeunit] = ACTIONS(5877),
    [anon_sym_CodeUnit] = ACTIONS(5877),
    [anon_sym_COdeunit] = ACTIONS(5877),
    [anon_sym_codeUnit] = ACTIONS(5877),
    [sym_report_keyword] = ACTIONS(5877),
    [sym_query_keyword] = ACTIONS(5877),
    [anon_sym_xmlport] = ACTIONS(5877),
    [anon_sym_XMLPORT] = ACTIONS(5877),
    [anon_sym_Xmlport] = ACTIONS(5877),
    [anon_sym_XMLport] = ACTIONS(5877),
    [anon_sym_XMLPort] = ACTIONS(5877),
    [anon_sym_XmlPort] = ACTIONS(5877),
    [anon_sym_enum] = ACTIONS(5877),
    [anon_sym_ENUM] = ACTIONS(5877),
    [anon_sym_Enum] = ACTIONS(5877),
    [anon_sym_eNUM] = ACTIONS(5877),
    [anon_sym_eNum] = ACTIONS(5877),
    [anon_sym_ENum] = ACTIONS(5877),
    [sym_quoted_identifier] = ACTIONS(5884),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5884),
    [sym_integer] = ACTIONS(5877),
    [sym_continue_as_identifier] = ACTIONS(5884),
  },
  [STATE(2560)] = {
    [sym_boolean] = STATE(2170),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2561),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDelif] = ACTIONS(5946),
    [anon_sym_POUNDELIF] = ACTIONS(5946),
    [anon_sym_POUNDElif] = ACTIONS(5946),
    [anon_sym_POUNDelse] = ACTIONS(5946),
    [anon_sym_POUNDELSE] = ACTIONS(5946),
    [anon_sym_POUNDElse] = ACTIONS(5946),
    [anon_sym_POUNDendif] = ACTIONS(5946),
    [anon_sym_POUNDENDIF] = ACTIONS(5946),
    [anon_sym_POUNDEndif] = ACTIONS(5946),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(5946),
  },
  [STATE(2561)] = {
    [sym_boolean] = STATE(2170),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDelif] = ACTIONS(5948),
    [anon_sym_POUNDELIF] = ACTIONS(5948),
    [anon_sym_POUNDElif] = ACTIONS(5948),
    [anon_sym_POUNDelse] = ACTIONS(5948),
    [anon_sym_POUNDELSE] = ACTIONS(5948),
    [anon_sym_POUNDElse] = ACTIONS(5948),
    [anon_sym_POUNDendif] = ACTIONS(5948),
    [anon_sym_POUNDENDIF] = ACTIONS(5948),
    [anon_sym_POUNDEndif] = ACTIONS(5948),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(5948),
  },
  [STATE(2562)] = {
    [sym_boolean] = STATE(2170),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [sym_identifier] = ACTIONS(5950),
    [anon_sym_DASH] = ACTIONS(5953),
    [aux_sym_boolean_token1] = ACTIONS(5956),
    [aux_sym_boolean_token2] = ACTIONS(5956),
    [sym_decimal] = ACTIONS(5959),
    [anon_sym_LPAREN] = ACTIONS(5962),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5965),
    [anon_sym_LBRACK] = ACTIONS(5968),
    [aux_sym_record_type_token1] = ACTIONS(5965),
    [aux_sym_basic_type_token21] = ACTIONS(5965),
    [aux_sym_basic_type_token22] = ACTIONS(5965),
    [aux_sym_basic_type_token48] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5971),
    [anon_sym_NOT] = ACTIONS(5971),
    [anon_sym_Not] = ACTIONS(5971),
    [anon_sym_POUNDelif] = ACTIONS(5974),
    [anon_sym_POUNDELIF] = ACTIONS(5974),
    [anon_sym_POUNDElif] = ACTIONS(5974),
    [anon_sym_POUNDelse] = ACTIONS(5974),
    [anon_sym_POUNDELSE] = ACTIONS(5974),
    [anon_sym_POUNDElse] = ACTIONS(5974),
    [anon_sym_POUNDendif] = ACTIONS(5974),
    [anon_sym_POUNDENDIF] = ACTIONS(5974),
    [anon_sym_POUNDEndif] = ACTIONS(5974),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5965),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5976),
    [anon_sym_PLUS] = ACTIONS(5953),
    [sym_datetime_literal] = ACTIONS(5979),
    [sym_date_literal] = ACTIONS(5959),
    [sym_time_literal] = ACTIONS(5959),
    [sym_biginteger_literal] = ACTIONS(5979),
    [sym_page_keyword] = ACTIONS(5976),
    [anon_sym_codeunit] = ACTIONS(5982),
    [anon_sym_CODEUNIT] = ACTIONS(5982),
    [anon_sym_Codeunit] = ACTIONS(5982),
    [anon_sym_CodeUnit] = ACTIONS(5982),
    [anon_sym_COdeunit] = ACTIONS(5982),
    [anon_sym_codeUnit] = ACTIONS(5982),
    [sym_report_keyword] = ACTIONS(5976),
    [sym_query_keyword] = ACTIONS(5976),
    [anon_sym_xmlport] = ACTIONS(5985),
    [anon_sym_XMLPORT] = ACTIONS(5985),
    [anon_sym_Xmlport] = ACTIONS(5985),
    [anon_sym_XMLport] = ACTIONS(5985),
    [anon_sym_XMLPort] = ACTIONS(5985),
    [anon_sym_XmlPort] = ACTIONS(5985),
    [anon_sym_enum] = ACTIONS(5988),
    [anon_sym_ENUM] = ACTIONS(5988),
    [anon_sym_Enum] = ACTIONS(5988),
    [anon_sym_eNUM] = ACTIONS(5988),
    [anon_sym_eNum] = ACTIONS(5988),
    [anon_sym_ENum] = ACTIONS(5988),
    [sym_quoted_identifier] = ACTIONS(5991),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5979),
    [sym_integer] = ACTIONS(5959),
    [sym_continue_as_identifier] = ACTIONS(5994),
    [sym_preproc_close] = ACTIONS(5974),
  },
  [STATE(2563)] = {
    [sym_identifier] = ACTIONS(2609),
    [anon_sym_DOT] = ACTIONS(2609),
    [anon_sym_EQ] = ACTIONS(2611),
    [anon_sym_DASH] = ACTIONS(2609),
    [aux_sym_boolean_token1] = ACTIONS(2609),
    [aux_sym_boolean_token2] = ACTIONS(2609),
    [sym_decimal] = ACTIONS(2609),
    [anon_sym_LPAREN] = ACTIONS(2611),
    [anon_sym_RPAREN] = ACTIONS(2611),
    [anon_sym_DOT_DOT] = ACTIONS(2611),
    [aux_sym_filter_value_token1] = ACTIONS(2609),
    [aux_sym_tabledata_permission_token2] = ACTIONS(2609),
    [anon_sym_STAR] = ACTIONS(2609),
    [anon_sym_LBRACK] = ACTIONS(2611),
    [aux_sym_record_type_token1] = ACTIONS(2609),
    [aux_sym_basic_type_token21] = ACTIONS(2609),
    [aux_sym_basic_type_token22] = ACTIONS(2609),
    [aux_sym_basic_type_token48] = ACTIONS(2609),
    [anon_sym_not] = ACTIONS(2609),
    [anon_sym_NOT] = ACTIONS(2609),
    [anon_sym_Not] = ACTIONS(2609),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2611),
    [aux_sym__expression_token1] = ACTIONS(2611),
    [aux_sym__expression_token2] = ACTIONS(2611),
    [aux_sym_keyword_identifier_token1] = ACTIONS(2609),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2609),
    [anon_sym_SLASH] = ACTIONS(2609),
    [anon_sym_div] = ACTIONS(2609),
    [anon_sym_DIV] = ACTIONS(2609),
    [anon_sym_Div] = ACTIONS(2609),
    [anon_sym_mod] = ACTIONS(2609),
    [anon_sym_MOD] = ACTIONS(2609),
    [anon_sym_Mod] = ACTIONS(2609),
    [anon_sym_PLUS] = ACTIONS(2609),
    [anon_sym_GT_EQ] = ACTIONS(2611),
    [anon_sym_LT_EQ] = ACTIONS(2611),
    [anon_sym_GT] = ACTIONS(2609),
    [anon_sym_LT] = ACTIONS(2609),
    [anon_sym_LT_GT] = ACTIONS(2611),
    [anon_sym_and] = ACTIONS(2609),
    [anon_sym_AND] = ACTIONS(2609),
    [anon_sym_And] = ACTIONS(2609),
    [anon_sym_or] = ACTIONS(2609),
    [anon_sym_OR] = ACTIONS(2609),
    [anon_sym_Or] = ACTIONS(2609),
    [anon_sym_xor] = ACTIONS(2609),
    [anon_sym_XOR] = ACTIONS(2609),
    [anon_sym_Xor] = ACTIONS(2609),
    [anon_sym_QMARK] = ACTIONS(2611),
    [sym_datetime_literal] = ACTIONS(2611),
    [sym_date_literal] = ACTIONS(2609),
    [sym_time_literal] = ACTIONS(2609),
    [sym_biginteger_literal] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(2609),
    [anon_sym_IN] = ACTIONS(2609),
    [anon_sym_In] = ACTIONS(2609),
    [sym_page_keyword] = ACTIONS(2609),
    [anon_sym_codeunit] = ACTIONS(2609),
    [anon_sym_CODEUNIT] = ACTIONS(2609),
    [anon_sym_Codeunit] = ACTIONS(2609),
    [anon_sym_CodeUnit] = ACTIONS(2609),
    [anon_sym_COdeunit] = ACTIONS(2609),
    [anon_sym_codeUnit] = ACTIONS(2609),
    [sym_report_keyword] = ACTIONS(2609),
    [sym_query_keyword] = ACTIONS(2609),
    [anon_sym_xmlport] = ACTIONS(2609),
    [anon_sym_XMLPORT] = ACTIONS(2609),
    [anon_sym_Xmlport] = ACTIONS(2609),
    [anon_sym_XMLport] = ACTIONS(2609),
    [anon_sym_XMLPort] = ACTIONS(2609),
    [anon_sym_XmlPort] = ACTIONS(2609),
    [anon_sym_enum] = ACTIONS(2609),
    [anon_sym_ENUM] = ACTIONS(2609),
    [anon_sym_Enum] = ACTIONS(2609),
    [anon_sym_eNUM] = ACTIONS(2609),
    [anon_sym_eNum] = ACTIONS(2609),
    [anon_sym_ENum] = ACTIONS(2609),
    [sym_quoted_identifier] = ACTIONS(2611),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(2611),
    [sym_integer] = ACTIONS(2609),
    [sym_continue_as_identifier] = ACTIONS(2611),
  },
  [STATE(2564)] = {
    [sym_identifier] = ACTIONS(5997),
    [anon_sym_DOT] = ACTIONS(5932),
    [anon_sym_EQ] = ACTIONS(5934),
    [anon_sym_DASH] = ACTIONS(5999),
    [aux_sym_boolean_token1] = ACTIONS(5997),
    [aux_sym_boolean_token2] = ACTIONS(5997),
    [sym_decimal] = ACTIONS(5997),
    [anon_sym_LPAREN] = ACTIONS(6002),
    [anon_sym_RPAREN] = ACTIONS(6002),
    [anon_sym_DOT_DOT] = ACTIONS(6004),
    [aux_sym_filter_value_token1] = ACTIONS(5997),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5997),
    [anon_sym_STAR] = ACTIONS(5932),
    [anon_sym_LBRACK] = ACTIONS(6004),
    [aux_sym_record_type_token1] = ACTIONS(5997),
    [aux_sym_basic_type_token21] = ACTIONS(5997),
    [aux_sym_basic_type_token22] = ACTIONS(5997),
    [aux_sym_basic_type_token48] = ACTIONS(5997),
    [anon_sym_not] = ACTIONS(5997),
    [anon_sym_NOT] = ACTIONS(5997),
    [anon_sym_Not] = ACTIONS(5997),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(5934),
    [aux_sym__expression_token1] = ACTIONS(5934),
    [aux_sym__expression_token2] = ACTIONS(5934),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5997),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5997),
    [anon_sym_SLASH] = ACTIONS(5932),
    [anon_sym_div] = ACTIONS(5932),
    [anon_sym_DIV] = ACTIONS(5932),
    [anon_sym_Div] = ACTIONS(5932),
    [anon_sym_mod] = ACTIONS(5932),
    [anon_sym_MOD] = ACTIONS(5932),
    [anon_sym_Mod] = ACTIONS(5932),
    [anon_sym_PLUS] = ACTIONS(5999),
    [anon_sym_GT_EQ] = ACTIONS(5934),
    [anon_sym_LT_EQ] = ACTIONS(5934),
    [anon_sym_GT] = ACTIONS(5932),
    [anon_sym_LT] = ACTIONS(5932),
    [anon_sym_LT_GT] = ACTIONS(5934),
    [anon_sym_and] = ACTIONS(5932),
    [anon_sym_AND] = ACTIONS(5932),
    [anon_sym_And] = ACTIONS(5932),
    [anon_sym_or] = ACTIONS(5932),
    [anon_sym_OR] = ACTIONS(5932),
    [anon_sym_Or] = ACTIONS(5932),
    [anon_sym_xor] = ACTIONS(5932),
    [anon_sym_XOR] = ACTIONS(5932),
    [anon_sym_Xor] = ACTIONS(5932),
    [anon_sym_QMARK] = ACTIONS(5934),
    [sym_datetime_literal] = ACTIONS(6002),
    [sym_date_literal] = ACTIONS(5997),
    [sym_time_literal] = ACTIONS(5997),
    [sym_biginteger_literal] = ACTIONS(6002),
    [anon_sym_in] = ACTIONS(5932),
    [anon_sym_IN] = ACTIONS(5932),
    [anon_sym_In] = ACTIONS(5932),
    [sym_page_keyword] = ACTIONS(5997),
    [anon_sym_codeunit] = ACTIONS(5997),
    [anon_sym_CODEUNIT] = ACTIONS(5997),
    [anon_sym_Codeunit] = ACTIONS(5997),
    [anon_sym_CodeUnit] = ACTIONS(5997),
    [anon_sym_COdeunit] = ACTIONS(5997),
    [anon_sym_codeUnit] = ACTIONS(5997),
    [sym_report_keyword] = ACTIONS(5997),
    [sym_query_keyword] = ACTIONS(5997),
    [anon_sym_xmlport] = ACTIONS(5997),
    [anon_sym_XMLPORT] = ACTIONS(5997),
    [anon_sym_Xmlport] = ACTIONS(5997),
    [anon_sym_XMLport] = ACTIONS(5997),
    [anon_sym_XMLPort] = ACTIONS(5997),
    [anon_sym_XmlPort] = ACTIONS(5997),
    [anon_sym_enum] = ACTIONS(5997),
    [anon_sym_ENUM] = ACTIONS(5997),
    [anon_sym_Enum] = ACTIONS(5997),
    [anon_sym_eNUM] = ACTIONS(5997),
    [anon_sym_eNum] = ACTIONS(5997),
    [anon_sym_ENum] = ACTIONS(5997),
    [sym_quoted_identifier] = ACTIONS(6002),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6002),
    [sym_integer] = ACTIONS(5997),
    [sym_continue_as_identifier] = ACTIONS(6002),
  },
  [STATE(2565)] = {
    [sym__body_element] = STATE(2652),
    [sym_empty_statement] = STATE(2652),
    [sym_property] = STATE(2652),
    [sym_fields_section] = STATE(2652),
    [sym_keys_section] = STATE(2652),
    [sym_fieldgroups_section] = STATE(2652),
    [sym_enum_value_declaration] = STATE(2652),
    [sym_labels_section] = STATE(2652),
    [sym_layout_section] = STATE(2652),
    [sym_modify_modification] = STATE(2652),
    [sym_actions_section] = STATE(2652),
    [sym_views_section] = STATE(2652),
    [sym_dataset_section] = STATE(2652),
    [sym_requestpage_section] = STATE(2652),
    [sym_rendering_section] = STATE(2652),
    [sym_elements_section] = STATE(2652),
    [sym_schema_section] = STATE(2652),
    [sym_xmlport_element] = STATE(2652),
    [sym__xmlport_body_element] = STATE(2652),
    [sym_preproc_conditional_xmlport] = STATE(2652),
    [sym_xmlport_attribute] = STATE(2652),
    [sym_assembly_declaration] = STATE(2652),
    [sym_event_declaration] = STATE(2652),
    [sym_procedure] = STATE(2652),
    [sym_preproc_split_procedure] = STATE(2652),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(2652),
    [sym_var_section] = STATE(2652),
    [sym_attribute_item] = STATE(2652),
    [sym_preproc_conditional] = STATE(2652),
    [sym_preproc_if] = STATE(2446),
    [sym_preproc_elif] = STATE(2657),
    [sym_preproc_else] = STATE(2753),
    [sym_preproc_endif] = STATE(5851),
    [aux_sym_xmlport_element_repeat1] = STATE(2652),
    [aux_sym_preproc_conditional_xmlport_repeat1] = STATE(7830),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDelif] = ACTIONS(5825),
    [anon_sym_POUNDELIF] = ACTIONS(5825),
    [anon_sym_POUNDElif] = ACTIONS(5825),
    [anon_sym_POUNDelse] = ACTIONS(5827),
    [anon_sym_POUNDELSE] = ACTIONS(5827),
    [anon_sym_POUNDElse] = ACTIONS(5827),
    [anon_sym_POUNDendif] = ACTIONS(5829),
    [anon_sym_POUNDENDIF] = ACTIONS(5829),
    [anon_sym_POUNDEndif] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(5829),
  },
  [STATE(2566)] = {
    [sym_boolean] = STATE(6824),
    [sym_option_member] = STATE(6803),
    [sym_keyword_identifier] = STATE(6824),
    [sym_codeunit_keyword] = STATE(6828),
    [sym_xmlport_keyword] = STATE(6828),
    [sym_enum_keyword] = STATE(6828),
    [sym_keyword_as_identifier] = STATE(6824),
    [sym_identifier] = ACTIONS(5900),
    [anon_sym_SEMI] = ACTIONS(389),
    [anon_sym_RBRACE] = ACTIONS(389),
    [anon_sym_COMMA] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(5904),
    [aux_sym_boolean_token1] = ACTIONS(5906),
    [aux_sym_boolean_token2] = ACTIONS(5906),
    [aux_sym_where_condition_token1] = ACTIONS(5908),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5910),
    [anon_sym_LBRACK] = ACTIONS(389),
    [aux_sym_record_type_token1] = ACTIONS(5910),
    [aux_sym_basic_type_token21] = ACTIONS(5910),
    [aux_sym_basic_type_token22] = ACTIONS(5912),
    [aux_sym_basic_type_token48] = ACTIONS(5910),
    [aux_sym_basic_type_token53] = ACTIONS(5908),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6009),
    [aux_sym_modify_modification_token1] = ACTIONS(391),
    [aux_sym_separator_action_token1] = ACTIONS(5908),
    [aux_sym_assembly_declaration_token1] = ACTIONS(391),
    [aux_sym_type_declaration_token1] = ACTIONS(5908),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(391),
    [anon_sym_POUNDif] = ACTIONS(389),
    [anon_sym_POUNDIF] = ACTIONS(389),
    [anon_sym_POUNDIf] = ACTIONS(389),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5910),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5910),
    [sym_page_keyword] = ACTIONS(5910),
    [anon_sym_codeunit] = ACTIONS(5914),
    [anon_sym_CODEUNIT] = ACTIONS(5914),
    [anon_sym_Codeunit] = ACTIONS(5914),
    [anon_sym_CodeUnit] = ACTIONS(5914),
    [anon_sym_COdeunit] = ACTIONS(5914),
    [anon_sym_codeUnit] = ACTIONS(5914),
    [sym_report_keyword] = ACTIONS(5910),
    [sym_query_keyword] = ACTIONS(5910),
    [anon_sym_xmlport] = ACTIONS(5916),
    [anon_sym_XMLPORT] = ACTIONS(5916),
    [anon_sym_Xmlport] = ACTIONS(5916),
    [anon_sym_XMLport] = ACTIONS(5916),
    [anon_sym_XMLPort] = ACTIONS(5916),
    [anon_sym_XmlPort] = ACTIONS(5916),
    [anon_sym_enum] = ACTIONS(5918),
    [anon_sym_ENUM] = ACTIONS(5918),
    [anon_sym_Enum] = ACTIONS(5918),
    [anon_sym_eNUM] = ACTIONS(5918),
    [anon_sym_eNum] = ACTIONS(5918),
    [anon_sym_ENum] = ACTIONS(5918),
    [sym_procedure_keyword] = ACTIONS(391),
    [sym_trigger_keyword] = ACTIONS(391),
    [sym_var_keyword] = ACTIONS(391),
    [sym_local_keyword] = ACTIONS(6012),
    [sym_internal_keyword] = ACTIONS(6012),
    [sym_protected_keyword] = ACTIONS(6012),
    [sym_event_keyword] = ACTIONS(391),
    [sym_fields_keyword] = ACTIONS(391),
    [sym_keys_keyword] = ACTIONS(391),
    [sym_key_keyword] = ACTIONS(5908),
    [sym_fieldgroups_keyword] = ACTIONS(391),
    [sym_actions_keyword] = ACTIONS(391),
    [sym_layout_keyword] = ACTIONS(391),
    [sym_dataset_keyword] = ACTIONS(6009),
    [sym_elements_keyword] = ACTIONS(391),
    [sym_labels_keyword] = ACTIONS(391),
    [sym_rendering_keyword] = ACTIONS(391),
    [sym_requestpage_keyword] = ACTIONS(391),
    [sym_schema_keyword] = ACTIONS(391),
    [sym_views_keyword] = ACTIONS(391),
    [sym_quoted_identifier] = ACTIONS(5920),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5920),
    [sym_integer] = ACTIONS(5920),
    [sym_property_name] = ACTIONS(389),
    [sym_preproc_open] = ACTIONS(389),
    [sym_begin_keyword] = ACTIONS(389),
  },
  [STATE(2567)] = {
    [sym_boolean] = STATE(6228),
    [sym_calc_field_reference] = STATE(10757),
    [sym_assignment_expression] = STATE(6228),
    [sym__expression] = STATE(6228),
    [sym_keyword_identifier] = STATE(5932),
    [sym_range_expression] = STATE(6228),
    [sym_multiplicative_expression] = STATE(6228),
    [sym_additive_expression] = STATE(6228),
    [sym_comparison_expression] = STATE(6228),
    [sym_logical_expression] = STATE(6228),
    [sym_ternary_expression] = STATE(6228),
    [sym_unary_expression] = STATE(6228),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6228),
    [sym_list_literal] = STATE(6228),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6228),
    [sym__literal_value] = STATE(6228),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(10239),
    [sym_keyword_as_identifier] = STATE(10239),
    [sym_identifier] = ACTIONS(5451),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6015),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6017),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(4848),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6019),
    [sym_date_literal] = ACTIONS(6015),
    [sym_time_literal] = ACTIONS(6015),
    [sym_biginteger_literal] = ACTIONS(6019),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_quoted_identifier] = ACTIONS(5459),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6019),
    [sym_integer] = ACTIONS(6015),
    [sym_continue_as_identifier] = ACTIONS(6019),
  },
  [STATE(2568)] = {
    [sym_boolean] = STATE(6345),
    [sym_simple_table_relation] = STATE(11235),
    [sym__namespaced_or_simple_ref] = STATE(10231),
    [sym_assignment_expression] = STATE(6345),
    [sym__expression] = STATE(6345),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6345),
    [sym_multiplicative_expression] = STATE(6345),
    [sym_additive_expression] = STATE(6345),
    [sym_comparison_expression] = STATE(6345),
    [sym_logical_expression] = STATE(6345),
    [sym_ternary_expression] = STATE(6345),
    [sym_unary_expression] = STATE(6345),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(5952),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6345),
    [sym_list_literal] = STATE(6345),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6345),
    [sym__literal_value] = STATE(6345),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(4762),
    [sym_keyword_as_identifier] = STATE(4762),
    [sym_identifier] = ACTIONS(5451),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(5455),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(5457),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5457),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_quoted_identifier] = ACTIONS(5459),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5457),
    [sym_integer] = ACTIONS(5461),
    [sym_continue_as_identifier] = ACTIONS(5457),
  },
  [STATE(2569)] = {
    [sym_boolean] = STATE(6347),
    [sym_simple_table_relation] = STATE(8353),
    [sym__namespaced_or_simple_ref] = STATE(7858),
    [sym_assignment_expression] = STATE(6347),
    [sym__expression] = STATE(6347),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6347),
    [sym_multiplicative_expression] = STATE(6347),
    [sym_additive_expression] = STATE(6347),
    [sym_comparison_expression] = STATE(6347),
    [sym_logical_expression] = STATE(6347),
    [sym_ternary_expression] = STATE(6347),
    [sym_unary_expression] = STATE(6347),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4845),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6347),
    [sym_list_literal] = STATE(6347),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6347),
    [sym__literal_value] = STATE(6347),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym__identifier_or_quoted] = STATE(7661),
    [sym_keyword_as_identifier] = STATE(7661),
    [sym_identifier] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6021),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_where_condition_token1] = ACTIONS(6023),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(3068),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_basic_type_token53] = ACTIONS(6023),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6023),
    [aux_sym_separator_action_token1] = ACTIONS(6023),
    [aux_sym_type_declaration_token1] = ACTIONS(6023),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6025),
    [sym_date_literal] = ACTIONS(6021),
    [sym_time_literal] = ACTIONS(6021),
    [sym_biginteger_literal] = ACTIONS(6025),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(6023),
    [sym_dataset_keyword] = ACTIONS(6023),
    [sym_quoted_identifier] = ACTIONS(3441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6025),
    [sym_integer] = ACTIONS(3084),
    [sym_continue_as_identifier] = ACTIONS(6025),
  },
  [STATE(2570)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(6027),
    [anon_sym_POUNDELIF] = ACTIONS(6027),
    [anon_sym_POUNDElif] = ACTIONS(6027),
    [anon_sym_POUNDelse] = ACTIONS(6027),
    [anon_sym_POUNDELSE] = ACTIONS(6027),
    [anon_sym_POUNDElse] = ACTIONS(6027),
    [anon_sym_POUNDendif] = ACTIONS(6027),
    [anon_sym_POUNDENDIF] = ACTIONS(6027),
    [anon_sym_POUNDEndif] = ACTIONS(6027),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(6027),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2571)] = {
    [sym__body_element] = STATE(2652),
    [sym_empty_statement] = STATE(2652),
    [sym_property] = STATE(2652),
    [sym_fields_section] = STATE(2652),
    [sym_keys_section] = STATE(2652),
    [sym_fieldgroups_section] = STATE(2652),
    [sym_enum_value_declaration] = STATE(2652),
    [sym_labels_section] = STATE(2652),
    [sym_layout_section] = STATE(2652),
    [sym_modify_modification] = STATE(2652),
    [sym_actions_section] = STATE(2652),
    [sym_views_section] = STATE(2652),
    [sym_dataset_section] = STATE(2652),
    [sym_requestpage_section] = STATE(2652),
    [sym_rendering_section] = STATE(2652),
    [sym_elements_section] = STATE(2652),
    [sym_schema_section] = STATE(2652),
    [sym_xmlport_element] = STATE(2652),
    [sym__xmlport_body_element] = STATE(2652),
    [sym_preproc_conditional_xmlport] = STATE(2652),
    [sym_xmlport_attribute] = STATE(2652),
    [sym_assembly_declaration] = STATE(2652),
    [sym_event_declaration] = STATE(2652),
    [sym_procedure] = STATE(2652),
    [sym_preproc_split_procedure] = STATE(2652),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(2652),
    [sym_var_section] = STATE(2652),
    [sym_attribute_item] = STATE(2652),
    [sym_preproc_conditional] = STATE(2652),
    [sym_preproc_if] = STATE(2446),
    [sym_preproc_elif] = STATE(2657),
    [sym_preproc_else] = STATE(2759),
    [sym_preproc_endif] = STATE(6393),
    [aux_sym_xmlport_element_repeat1] = STATE(2652),
    [aux_sym_preproc_conditional_xmlport_repeat1] = STATE(8042),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDelif] = ACTIONS(5825),
    [anon_sym_POUNDELIF] = ACTIONS(5825),
    [anon_sym_POUNDElif] = ACTIONS(5825),
    [anon_sym_POUNDelse] = ACTIONS(5827),
    [anon_sym_POUNDELSE] = ACTIONS(5827),
    [anon_sym_POUNDElse] = ACTIONS(5827),
    [anon_sym_POUNDendif] = ACTIONS(5869),
    [anon_sym_POUNDENDIF] = ACTIONS(5869),
    [anon_sym_POUNDEndif] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(5869),
  },
  [STATE(2572)] = {
    [sym__body_element] = STATE(2570),
    [sym_empty_statement] = STATE(2570),
    [sym_property] = STATE(2570),
    [sym_fields_section] = STATE(2570),
    [sym_keys_section] = STATE(2570),
    [sym_fieldgroups_section] = STATE(2570),
    [sym_enum_value_declaration] = STATE(2570),
    [sym_labels_section] = STATE(2570),
    [sym_layout_section] = STATE(2570),
    [sym_modify_modification] = STATE(2570),
    [sym_actions_section] = STATE(2570),
    [sym_views_section] = STATE(2570),
    [sym_dataset_section] = STATE(2570),
    [sym_requestpage_section] = STATE(2570),
    [sym_rendering_section] = STATE(2570),
    [sym_elements_section] = STATE(2570),
    [sym_schema_section] = STATE(2570),
    [sym_assembly_declaration] = STATE(2570),
    [sym_event_declaration] = STATE(2570),
    [sym_procedure] = STATE(2570),
    [sym_preproc_split_procedure] = STATE(2570),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2570),
    [sym_var_section] = STATE(2570),
    [sym_var_attribute_item] = STATE(2570),
    [sym_variable_declaration] = STATE(2570),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2570),
    [sym_preproc_if] = STATE(2722),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2570),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(6029),
    [anon_sym_POUNDELIF] = ACTIONS(6029),
    [anon_sym_POUNDElif] = ACTIONS(6029),
    [anon_sym_POUNDelse] = ACTIONS(6029),
    [anon_sym_POUNDELSE] = ACTIONS(6029),
    [anon_sym_POUNDElse] = ACTIONS(6029),
    [anon_sym_POUNDendif] = ACTIONS(6029),
    [anon_sym_POUNDENDIF] = ACTIONS(6029),
    [anon_sym_POUNDEndif] = ACTIONS(6029),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(6029),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2573)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(6031),
    [anon_sym_SEMI] = ACTIONS(6034),
    [aux_sym_where_condition_token1] = ACTIONS(6037),
    [anon_sym_LBRACK] = ACTIONS(6040),
    [aux_sym_basic_type_token22] = ACTIONS(6037),
    [aux_sym_basic_type_token53] = ACTIONS(6037),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6043),
    [aux_sym_modify_modification_token1] = ACTIONS(6046),
    [aux_sym_separator_action_token1] = ACTIONS(6037),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6049),
    [aux_sym_type_declaration_token1] = ACTIONS(6037),
    [anon_sym_POUNDif] = ACTIONS(6052),
    [anon_sym_POUNDIF] = ACTIONS(6052),
    [anon_sym_POUNDIf] = ACTIONS(6052),
    [anon_sym_POUNDelif] = ACTIONS(6055),
    [anon_sym_POUNDELIF] = ACTIONS(6055),
    [anon_sym_POUNDElif] = ACTIONS(6055),
    [anon_sym_POUNDelse] = ACTIONS(6055),
    [anon_sym_POUNDELSE] = ACTIONS(6055),
    [anon_sym_POUNDElse] = ACTIONS(6055),
    [anon_sym_POUNDendif] = ACTIONS(6055),
    [anon_sym_POUNDENDIF] = ACTIONS(6055),
    [anon_sym_POUNDEndif] = ACTIONS(6055),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6057),
    [sym_trigger_keyword] = ACTIONS(6060),
    [sym_var_keyword] = ACTIONS(6063),
    [sym_local_keyword] = ACTIONS(6066),
    [sym_internal_keyword] = ACTIONS(6069),
    [sym_protected_keyword] = ACTIONS(6066),
    [sym_event_keyword] = ACTIONS(6072),
    [sym_fields_keyword] = ACTIONS(6075),
    [sym_keys_keyword] = ACTIONS(6078),
    [sym_key_keyword] = ACTIONS(6037),
    [sym_fieldgroups_keyword] = ACTIONS(6081),
    [sym_actions_keyword] = ACTIONS(6084),
    [sym_layout_keyword] = ACTIONS(6087),
    [sym_dataset_keyword] = ACTIONS(6090),
    [sym_elements_keyword] = ACTIONS(6093),
    [sym_labels_keyword] = ACTIONS(6096),
    [sym_rendering_keyword] = ACTIONS(6099),
    [sym_requestpage_keyword] = ACTIONS(6102),
    [sym_schema_keyword] = ACTIONS(6105),
    [sym_views_keyword] = ACTIONS(6108),
    [sym_quoted_identifier] = ACTIONS(6111),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6114),
    [sym_preproc_open] = ACTIONS(6052),
    [sym_preproc_close] = ACTIONS(6055),
    [sym_var_attribute_open] = ACTIONS(6117),
  },
  [STATE(2574)] = {
    [sym__body_element] = STATE(2713),
    [sym_empty_statement] = STATE(2713),
    [sym_property] = STATE(2713),
    [sym_fields_section] = STATE(2713),
    [sym_keys_section] = STATE(2713),
    [sym_fieldgroups_section] = STATE(2713),
    [sym_enum_value_declaration] = STATE(2713),
    [sym_labels_section] = STATE(2713),
    [sym_layout_section] = STATE(2713),
    [sym_modify_modification] = STATE(2713),
    [sym_actions_section] = STATE(2713),
    [sym_views_section] = STATE(2713),
    [sym_dataset_section] = STATE(2713),
    [sym_requestpage_section] = STATE(2713),
    [sym_rendering_section] = STATE(2713),
    [sym_elements_section] = STATE(2713),
    [sym_query_dataitem] = STATE(2713),
    [sym__query_body_element] = STATE(2713),
    [sym_preproc_conditional_query] = STATE(2713),
    [sym_query_column] = STATE(2713),
    [sym_query_filter] = STATE(2713),
    [sym_schema_section] = STATE(2713),
    [sym_assembly_declaration] = STATE(2713),
    [sym_event_declaration] = STATE(2713),
    [sym_procedure] = STATE(2713),
    [sym_preproc_split_procedure] = STATE(2713),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2713),
    [sym_var_section] = STATE(2713),
    [sym_attribute_item] = STATE(2713),
    [sym_preproc_conditional] = STATE(2713),
    [sym_preproc_if] = STATE(2494),
    [sym_preproc_elif] = STATE(2680),
    [sym_preproc_else] = STATE(2776),
    [sym_preproc_endif] = STATE(6814),
    [aux_sym_query_dataitem_repeat1] = STATE(2713),
    [aux_sym_preproc_conditional_query_repeat1] = STATE(8133),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(2575)] = {
    [sym__body_element] = STATE(2713),
    [sym_empty_statement] = STATE(2713),
    [sym_property] = STATE(2713),
    [sym_fields_section] = STATE(2713),
    [sym_keys_section] = STATE(2713),
    [sym_fieldgroups_section] = STATE(2713),
    [sym_enum_value_declaration] = STATE(2713),
    [sym_labels_section] = STATE(2713),
    [sym_layout_section] = STATE(2713),
    [sym_modify_modification] = STATE(2713),
    [sym_actions_section] = STATE(2713),
    [sym_views_section] = STATE(2713),
    [sym_dataset_section] = STATE(2713),
    [sym_requestpage_section] = STATE(2713),
    [sym_rendering_section] = STATE(2713),
    [sym_elements_section] = STATE(2713),
    [sym_query_dataitem] = STATE(2713),
    [sym__query_body_element] = STATE(2713),
    [sym_preproc_conditional_query] = STATE(2713),
    [sym_query_column] = STATE(2713),
    [sym_query_filter] = STATE(2713),
    [sym_schema_section] = STATE(2713),
    [sym_assembly_declaration] = STATE(2713),
    [sym_event_declaration] = STATE(2713),
    [sym_procedure] = STATE(2713),
    [sym_preproc_split_procedure] = STATE(2713),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2713),
    [sym_var_section] = STATE(2713),
    [sym_attribute_item] = STATE(2713),
    [sym_preproc_conditional] = STATE(2713),
    [sym_preproc_if] = STATE(2494),
    [sym_preproc_elif] = STATE(2680),
    [sym_preproc_else] = STATE(2790),
    [sym_preproc_endif] = STATE(5918),
    [aux_sym_query_dataitem_repeat1] = STATE(2713),
    [aux_sym_preproc_conditional_query_repeat1] = STATE(7837),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(2576)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6120),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2577)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2622),
    [sym_preproc_conditional_case_patterns] = STATE(2622),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6122),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2578)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6124),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2579)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6126),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2580)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6128),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2581)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6130),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2582)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6132),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2583)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6134),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2584)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6136),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2585)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6138),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2586)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2600),
    [sym_preproc_conditional_case_patterns] = STATE(2600),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6140),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2587)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6142),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2588)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6144),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2589)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6146),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2590)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6148),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2591)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6150),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2592)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6152),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2593)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6154),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2594)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2603),
    [sym_preproc_conditional_case_patterns] = STATE(2603),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6140),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2595)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2582),
    [sym_preproc_conditional_case_patterns] = STATE(2582),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(5922),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2596)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6156),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2597)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2580),
    [sym_preproc_conditional_case_patterns] = STATE(2580),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(5896),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2598)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2585),
    [sym_preproc_conditional_case_patterns] = STATE(2585),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6158),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2599)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2604),
    [sym_preproc_conditional_case_patterns] = STATE(2604),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6160),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2600)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6162),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2601)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2578),
    [sym_preproc_conditional_case_patterns] = STATE(2578),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6164),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2602)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2617),
    [sym_preproc_conditional_case_patterns] = STATE(2617),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6166),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2603)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6168),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2604)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6170),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2605)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2583),
    [sym_preproc_conditional_case_patterns] = STATE(2583),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6140),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2606)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2584),
    [sym_preproc_conditional_case_patterns] = STATE(2584),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6140),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2607)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2576),
    [sym_preproc_conditional_case_patterns] = STATE(2576),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6158),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2608)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2587),
    [sym_preproc_conditional_case_patterns] = STATE(2587),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6166),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2609)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2588),
    [sym_preproc_conditional_case_patterns] = STATE(2588),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6164),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2610)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2589),
    [sym_preproc_conditional_case_patterns] = STATE(2589),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6166),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2611)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2621),
    [sym_preproc_conditional_case_patterns] = STATE(2621),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6172),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2612)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2590),
    [sym_preproc_conditional_case_patterns] = STATE(2590),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6172),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2613)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2591),
    [sym_preproc_conditional_case_patterns] = STATE(2591),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6122),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2614)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2592),
    [sym_preproc_conditional_case_patterns] = STATE(2592),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6172),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2615)] = {
    [anon_sym_RBRACE] = ACTIONS(5449),
    [aux_sym_where_condition_token1] = ACTIONS(5449),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5449),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5449),
    [aux_sym_basic_type_token6] = ACTIONS(5449),
    [aux_sym_addafter_modification_token1] = ACTIONS(5449),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5449),
    [aux_sym_modify_modification_token1] = ACTIONS(5449),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5449),
    [aux_sym_movelast_modification_token1] = ACTIONS(5449),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5449),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5449),
    [anon_sym_POUNDif] = ACTIONS(5449),
    [anon_sym_POUNDIF] = ACTIONS(5449),
    [anon_sym_POUNDIf] = ACTIONS(5449),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5447),
    [anon_sym_tableextension] = ACTIONS(5449),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5449),
    [anon_sym_Tableextension] = ACTIONS(5449),
    [anon_sym_TableExtension] = ACTIONS(5449),
    [anon_sym_tableExtension] = ACTIONS(5449),
    [sym_page_keyword] = ACTIONS(5447),
    [anon_sym_pageextension] = ACTIONS(5449),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5449),
    [anon_sym_Pageextension] = ACTIONS(5449),
    [anon_sym_PageExtension] = ACTIONS(5449),
    [anon_sym_pageExtension] = ACTIONS(5449),
    [anon_sym_codeunit] = ACTIONS(5449),
    [anon_sym_CODEUNIT] = ACTIONS(5449),
    [anon_sym_Codeunit] = ACTIONS(5449),
    [anon_sym_CodeUnit] = ACTIONS(5449),
    [anon_sym_COdeunit] = ACTIONS(5449),
    [anon_sym_codeUnit] = ACTIONS(5449),
    [sym_report_keyword] = ACTIONS(5447),
    [anon_sym_reportextension] = ACTIONS(5449),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5449),
    [anon_sym_Reportextension] = ACTIONS(5449),
    [anon_sym_ReportExtension] = ACTIONS(5449),
    [anon_sym_reportExtension] = ACTIONS(5449),
    [sym_query_keyword] = ACTIONS(5449),
    [anon_sym_xmlport] = ACTIONS(5449),
    [anon_sym_XMLPORT] = ACTIONS(5449),
    [anon_sym_Xmlport] = ACTIONS(5449),
    [anon_sym_XMLport] = ACTIONS(5449),
    [anon_sym_XMLPort] = ACTIONS(5449),
    [anon_sym_XmlPort] = ACTIONS(5449),
    [anon_sym_enum] = ACTIONS(5447),
    [anon_sym_ENUM] = ACTIONS(5447),
    [anon_sym_Enum] = ACTIONS(5447),
    [anon_sym_eNUM] = ACTIONS(5449),
    [anon_sym_eNum] = ACTIONS(5449),
    [anon_sym_ENum] = ACTIONS(5449),
    [anon_sym_enumextension] = ACTIONS(5449),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5449),
    [anon_sym_Enumextension] = ACTIONS(5449),
    [anon_sym_EnumExtension] = ACTIONS(5449),
    [anon_sym_enumExtension] = ACTIONS(5449),
    [sym_interface_keyword] = ACTIONS(5449),
    [anon_sym_permissionset] = ACTIONS(5447),
    [anon_sym_PERMISSIONSET] = ACTIONS(5447),
    [anon_sym_Permissionset] = ACTIONS(5447),
    [anon_sym_PermissionSet] = ACTIONS(5447),
    [anon_sym_permissionSet] = ACTIONS(5447),
    [anon_sym_permissionsetextension] = ACTIONS(5449),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5449),
    [anon_sym_Permissionsetextension] = ACTIONS(5449),
    [anon_sym_PermissionSetExtension] = ACTIONS(5449),
    [anon_sym_permissionSetExtension] = ACTIONS(5449),
    [sym_area_keyword] = ACTIONS(5449),
    [sym_group_keyword] = ACTIONS(5449),
    [sym_repeater_keyword] = ACTIONS(5449),
    [sym_cuegroup_keyword] = ACTIONS(5449),
    [sym_fixed_keyword] = ACTIONS(5449),
    [sym_grid_keyword] = ACTIONS(5449),
    [sym_part_keyword] = ACTIONS(5449),
    [sym_systempart_keyword] = ACTIONS(5449),
    [sym_usercontrol_keyword] = ACTIONS(5449),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5449),
  },
  [STATE(2616)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2593),
    [sym_preproc_conditional_case_patterns] = STATE(2593),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6160),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2617)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6174),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2618)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2581),
    [sym_preproc_conditional_case_patterns] = STATE(2581),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6172),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2619)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(6176),
    [anon_sym_COLON] = ACTIONS(6179),
    [anon_sym_DASH] = ACTIONS(6181),
    [aux_sym_boolean_token1] = ACTIONS(6184),
    [aux_sym_boolean_token2] = ACTIONS(6184),
    [sym_decimal] = ACTIONS(6187),
    [anon_sym_LPAREN] = ACTIONS(6190),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6193),
    [anon_sym_LBRACK] = ACTIONS(6196),
    [aux_sym_record_type_token1] = ACTIONS(6193),
    [aux_sym_basic_type_token21] = ACTIONS(6193),
    [aux_sym_basic_type_token22] = ACTIONS(6193),
    [aux_sym_basic_type_token48] = ACTIONS(6193),
    [anon_sym_POUNDif] = ACTIONS(6199),
    [anon_sym_POUNDIF] = ACTIONS(6199),
    [anon_sym_POUNDIf] = ACTIONS(6199),
    [anon_sym_not] = ACTIONS(6202),
    [anon_sym_NOT] = ACTIONS(6202),
    [anon_sym_Not] = ACTIONS(6202),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6193),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6205),
    [anon_sym_PLUS] = ACTIONS(6181),
    [sym_datetime_literal] = ACTIONS(6208),
    [sym_date_literal] = ACTIONS(6187),
    [sym_time_literal] = ACTIONS(6187),
    [sym_biginteger_literal] = ACTIONS(6208),
    [sym_page_keyword] = ACTIONS(6205),
    [anon_sym_codeunit] = ACTIONS(6211),
    [anon_sym_CODEUNIT] = ACTIONS(6211),
    [anon_sym_Codeunit] = ACTIONS(6211),
    [anon_sym_CodeUnit] = ACTIONS(6211),
    [anon_sym_COdeunit] = ACTIONS(6211),
    [anon_sym_codeUnit] = ACTIONS(6211),
    [sym_report_keyword] = ACTIONS(6205),
    [sym_query_keyword] = ACTIONS(6205),
    [anon_sym_xmlport] = ACTIONS(6214),
    [anon_sym_XMLPORT] = ACTIONS(6214),
    [anon_sym_Xmlport] = ACTIONS(6214),
    [anon_sym_XMLport] = ACTIONS(6214),
    [anon_sym_XMLPort] = ACTIONS(6214),
    [anon_sym_XmlPort] = ACTIONS(6214),
    [anon_sym_enum] = ACTIONS(6217),
    [anon_sym_ENUM] = ACTIONS(6217),
    [anon_sym_Enum] = ACTIONS(6217),
    [anon_sym_eNUM] = ACTIONS(6217),
    [anon_sym_eNum] = ACTIONS(6217),
    [anon_sym_ENum] = ACTIONS(6217),
    [sym_quoted_identifier] = ACTIONS(6220),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6208),
    [sym_integer] = ACTIONS(6187),
    [sym_continue_as_identifier] = ACTIONS(6223),
    [sym_preproc_open] = ACTIONS(6199),
  },
  [STATE(2620)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6226),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2621)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6228),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2622)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6230),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2623)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6232),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2624)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2619),
    [sym_preproc_conditional_case_patterns] = STATE(2619),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6234),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2625)] = {
    [sym_boolean] = STATE(2430),
    [sym_preproc_if] = STATE(2433),
    [sym_assignment_expression] = STATE(6338),
    [aux_sym__case_pattern] = STATE(2624),
    [sym_preproc_conditional_case_patterns] = STATE(2624),
    [sym__single_pattern] = STATE(4761),
    [sym__expression] = STATE(6338),
    [sym_keyword_identifier] = STATE(2406),
    [sym_range_expression] = STATE(2430),
    [sym_multiplicative_expression] = STATE(2430),
    [sym_additive_expression] = STATE(2430),
    [sym_comparison_expression] = STATE(2430),
    [sym_logical_expression] = STATE(2430),
    [sym_ternary_expression] = STATE(6338),
    [sym_unary_expression] = STATE(2430),
    [sym_call_expression] = STATE(2416),
    [sym_member_expression] = STATE(2406),
    [sym_subscript_expression] = STATE(2406),
    [sym_parenthesized_expression] = STATE(2430),
    [sym_list_literal] = STATE(6338),
    [sym_qualified_enum_value] = STATE(2406),
    [sym_database_reference] = STATE(2430),
    [sym__literal_value] = STATE(2430),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(4107),
    [anon_sym_COLON] = ACTIONS(6166),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(4109),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_POUNDif] = ACTIONS(3750),
    [anon_sym_POUNDIF] = ACTIONS(3750),
    [anon_sym_POUNDIf] = ACTIONS(3750),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(4111),
    [sym_date_literal] = ACTIONS(4109),
    [sym_time_literal] = ACTIONS(4109),
    [sym_biginteger_literal] = ACTIONS(4111),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(4113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4111),
    [sym_integer] = ACTIONS(4109),
    [sym_continue_as_identifier] = ACTIONS(4115),
    [sym_preproc_open] = ACTIONS(3750),
  },
  [STATE(2626)] = {
    [sym_preproc_split_procedure] = STATE(2626),
    [sym_var_attribute_item] = STATE(2626),
    [sym_preproc_conditional_var] = STATE(2626),
    [sym_variable_declaration] = STATE(2626),
    [sym_preproc_if] = STATE(2422),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_var_section_repeat1] = STATE(2626),
    [sym_identifier] = ACTIONS(6236),
    [anon_sym_SEMI] = ACTIONS(6239),
    [aux_sym_where_condition_token1] = ACTIONS(6241),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6244),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6244),
    [anon_sym_LBRACK] = ACTIONS(6239),
    [aux_sym_basic_type_token6] = ACTIONS(6244),
    [aux_sym_basic_type_token22] = ACTIONS(6241),
    [aux_sym_basic_type_token53] = ACTIONS(6241),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6241),
    [aux_sym_addafter_modification_token1] = ACTIONS(6244),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6244),
    [aux_sym_modify_modification_token1] = ACTIONS(6244),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6244),
    [aux_sym_movelast_modification_token1] = ACTIONS(6244),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6244),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6244),
    [aux_sym_separator_action_token1] = ACTIONS(6241),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6244),
    [aux_sym_type_declaration_token1] = ACTIONS(6241),
    [anon_sym_POUNDif] = ACTIONS(6246),
    [anon_sym_POUNDIF] = ACTIONS(6246),
    [anon_sym_POUNDIf] = ACTIONS(6246),
    [anon_sym_POUNDelif] = ACTIONS(6239),
    [anon_sym_POUNDELIF] = ACTIONS(6239),
    [anon_sym_POUNDElif] = ACTIONS(6239),
    [anon_sym_POUNDelse] = ACTIONS(6239),
    [anon_sym_POUNDELSE] = ACTIONS(6239),
    [anon_sym_POUNDElse] = ACTIONS(6239),
    [anon_sym_POUNDendif] = ACTIONS(6239),
    [anon_sym_POUNDENDIF] = ACTIONS(6239),
    [anon_sym_POUNDEndif] = ACTIONS(6239),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6244),
    [sym_trigger_keyword] = ACTIONS(6244),
    [sym_var_keyword] = ACTIONS(6244),
    [sym_local_keyword] = ACTIONS(6244),
    [sym_internal_keyword] = ACTIONS(6244),
    [sym_protected_keyword] = ACTIONS(6244),
    [sym_event_keyword] = ACTIONS(6244),
    [sym_fields_keyword] = ACTIONS(6244),
    [sym_keys_keyword] = ACTIONS(6244),
    [sym_key_keyword] = ACTIONS(6241),
    [sym_fieldgroups_keyword] = ACTIONS(6244),
    [sym_actions_keyword] = ACTIONS(6244),
    [sym_layout_keyword] = ACTIONS(6244),
    [sym_area_keyword] = ACTIONS(6244),
    [sym_group_keyword] = ACTIONS(6244),
    [sym_repeater_keyword] = ACTIONS(6244),
    [sym_cuegroup_keyword] = ACTIONS(6244),
    [sym_fixed_keyword] = ACTIONS(6244),
    [sym_grid_keyword] = ACTIONS(6244),
    [sym_part_keyword] = ACTIONS(6244),
    [sym_systempart_keyword] = ACTIONS(6244),
    [sym_usercontrol_keyword] = ACTIONS(6244),
    [sym_dataset_keyword] = ACTIONS(6241),
    [sym_elements_keyword] = ACTIONS(6244),
    [sym_dataitem_keyword] = ACTIONS(6244),
    [sym_column_keyword] = ACTIONS(6244),
    [sym_filter_keyword] = ACTIONS(6244),
    [sym_labels_keyword] = ACTIONS(6244),
    [sym_rendering_keyword] = ACTIONS(6244),
    [sym_requestpage_keyword] = ACTIONS(6244),
    [sym_schema_keyword] = ACTIONS(6244),
    [sym_views_keyword] = ACTIONS(6244),
    [sym_quoted_identifier] = ACTIONS(6249),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6239),
    [sym_preproc_open] = ACTIONS(6246),
    [sym_preproc_close] = ACTIONS(6239),
    [sym_var_attribute_open] = ACTIONS(6252),
  },
  [STATE(2627)] = {
    [sym_preproc_split_procedure] = STATE(2632),
    [sym_var_attribute_item] = STATE(2632),
    [sym_preproc_conditional_var] = STATE(2632),
    [sym_variable_declaration] = STATE(2632),
    [sym_preproc_if] = STATE(2422),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_var_section_repeat1] = STATE(2632),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(6255),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6257),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6257),
    [anon_sym_LBRACK] = ACTIONS(6255),
    [aux_sym_basic_type_token6] = ACTIONS(6257),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_addafter_modification_token1] = ACTIONS(6257),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6257),
    [aux_sym_modify_modification_token1] = ACTIONS(6257),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6257),
    [aux_sym_movelast_modification_token1] = ACTIONS(6257),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6257),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6257),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6257),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(6259),
    [anon_sym_POUNDIF] = ACTIONS(6259),
    [anon_sym_POUNDIf] = ACTIONS(6259),
    [anon_sym_POUNDelif] = ACTIONS(6255),
    [anon_sym_POUNDELIF] = ACTIONS(6255),
    [anon_sym_POUNDElif] = ACTIONS(6255),
    [anon_sym_POUNDelse] = ACTIONS(6255),
    [anon_sym_POUNDELSE] = ACTIONS(6255),
    [anon_sym_POUNDElse] = ACTIONS(6255),
    [anon_sym_POUNDendif] = ACTIONS(6255),
    [anon_sym_POUNDENDIF] = ACTIONS(6255),
    [anon_sym_POUNDEndif] = ACTIONS(6255),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6257),
    [sym_trigger_keyword] = ACTIONS(6257),
    [sym_var_keyword] = ACTIONS(6257),
    [sym_local_keyword] = ACTIONS(6257),
    [sym_internal_keyword] = ACTIONS(6257),
    [sym_protected_keyword] = ACTIONS(6257),
    [sym_event_keyword] = ACTIONS(6257),
    [sym_fields_keyword] = ACTIONS(6257),
    [sym_keys_keyword] = ACTIONS(6257),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(6257),
    [sym_actions_keyword] = ACTIONS(6257),
    [sym_layout_keyword] = ACTIONS(6257),
    [sym_area_keyword] = ACTIONS(6257),
    [sym_group_keyword] = ACTIONS(6257),
    [sym_repeater_keyword] = ACTIONS(6257),
    [sym_cuegroup_keyword] = ACTIONS(6257),
    [sym_fixed_keyword] = ACTIONS(6257),
    [sym_grid_keyword] = ACTIONS(6257),
    [sym_part_keyword] = ACTIONS(6257),
    [sym_systempart_keyword] = ACTIONS(6257),
    [sym_usercontrol_keyword] = ACTIONS(6257),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_elements_keyword] = ACTIONS(6257),
    [sym_dataitem_keyword] = ACTIONS(6257),
    [sym_column_keyword] = ACTIONS(6257),
    [sym_filter_keyword] = ACTIONS(6257),
    [sym_labels_keyword] = ACTIONS(6257),
    [sym_rendering_keyword] = ACTIONS(6257),
    [sym_requestpage_keyword] = ACTIONS(6257),
    [sym_schema_keyword] = ACTIONS(6257),
    [sym_views_keyword] = ACTIONS(6257),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6255),
    [sym_preproc_open] = ACTIONS(6259),
    [sym_preproc_close] = ACTIONS(6255),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2628)] = {
    [sym_preproc_split_procedure] = STATE(2626),
    [sym_var_attribute_item] = STATE(2626),
    [sym_preproc_conditional_var] = STATE(2626),
    [sym_variable_declaration] = STATE(2626),
    [sym_preproc_if] = STATE(2422),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_var_section_repeat1] = STATE(2626),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(6261),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6263),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6263),
    [anon_sym_LBRACK] = ACTIONS(6261),
    [aux_sym_basic_type_token6] = ACTIONS(6263),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_addafter_modification_token1] = ACTIONS(6263),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6263),
    [aux_sym_modify_modification_token1] = ACTIONS(6263),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6263),
    [aux_sym_movelast_modification_token1] = ACTIONS(6263),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6263),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6263),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6263),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(6259),
    [anon_sym_POUNDIF] = ACTIONS(6259),
    [anon_sym_POUNDIf] = ACTIONS(6259),
    [anon_sym_POUNDelif] = ACTIONS(6261),
    [anon_sym_POUNDELIF] = ACTIONS(6261),
    [anon_sym_POUNDElif] = ACTIONS(6261),
    [anon_sym_POUNDelse] = ACTIONS(6261),
    [anon_sym_POUNDELSE] = ACTIONS(6261),
    [anon_sym_POUNDElse] = ACTIONS(6261),
    [anon_sym_POUNDendif] = ACTIONS(6261),
    [anon_sym_POUNDENDIF] = ACTIONS(6261),
    [anon_sym_POUNDEndif] = ACTIONS(6261),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6263),
    [sym_trigger_keyword] = ACTIONS(6263),
    [sym_var_keyword] = ACTIONS(6263),
    [sym_local_keyword] = ACTIONS(6263),
    [sym_internal_keyword] = ACTIONS(6263),
    [sym_protected_keyword] = ACTIONS(6263),
    [sym_event_keyword] = ACTIONS(6263),
    [sym_fields_keyword] = ACTIONS(6263),
    [sym_keys_keyword] = ACTIONS(6263),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(6263),
    [sym_actions_keyword] = ACTIONS(6263),
    [sym_layout_keyword] = ACTIONS(6263),
    [sym_area_keyword] = ACTIONS(6263),
    [sym_group_keyword] = ACTIONS(6263),
    [sym_repeater_keyword] = ACTIONS(6263),
    [sym_cuegroup_keyword] = ACTIONS(6263),
    [sym_fixed_keyword] = ACTIONS(6263),
    [sym_grid_keyword] = ACTIONS(6263),
    [sym_part_keyword] = ACTIONS(6263),
    [sym_systempart_keyword] = ACTIONS(6263),
    [sym_usercontrol_keyword] = ACTIONS(6263),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_elements_keyword] = ACTIONS(6263),
    [sym_dataitem_keyword] = ACTIONS(6263),
    [sym_column_keyword] = ACTIONS(6263),
    [sym_filter_keyword] = ACTIONS(6263),
    [sym_labels_keyword] = ACTIONS(6263),
    [sym_rendering_keyword] = ACTIONS(6263),
    [sym_requestpage_keyword] = ACTIONS(6263),
    [sym_schema_keyword] = ACTIONS(6263),
    [sym_views_keyword] = ACTIONS(6263),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6261),
    [sym_preproc_open] = ACTIONS(6259),
    [sym_preproc_close] = ACTIONS(6261),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2629)] = {
    [sym__body_element] = STATE(2729),
    [sym_empty_statement] = STATE(2729),
    [sym_property] = STATE(2729),
    [sym_fields_section] = STATE(2729),
    [sym_keys_section] = STATE(2729),
    [sym_fieldgroups_section] = STATE(2729),
    [sym_enum_value_declaration] = STATE(2729),
    [sym_labels_section] = STATE(2729),
    [sym_layout_section] = STATE(2729),
    [sym_modify_modification] = STATE(2729),
    [sym_actions_section] = STATE(2729),
    [sym_views_section] = STATE(2729),
    [sym_dataset_section] = STATE(2729),
    [sym_report_dataitem] = STATE(2729),
    [sym__report_body_element] = STATE(2729),
    [sym_preproc_conditional_report] = STATE(2729),
    [sym_report_column] = STATE(2729),
    [sym_requestpage_section] = STATE(2729),
    [sym_rendering_section] = STATE(2729),
    [sym_elements_section] = STATE(2729),
    [sym_schema_section] = STATE(2729),
    [sym_assembly_declaration] = STATE(2729),
    [sym_event_declaration] = STATE(2729),
    [sym_procedure] = STATE(2729),
    [sym_preproc_split_procedure] = STATE(2729),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2729),
    [sym_var_section] = STATE(2729),
    [sym_attribute_item] = STATE(2729),
    [sym_preproc_conditional] = STATE(2729),
    [sym_preproc_if] = STATE(2557),
    [sym_preproc_elif] = STATE(2732),
    [sym_preproc_else] = STATE(3261),
    [sym_preproc_endif] = STATE(6043),
    [aux_sym_report_dataitem_repeat1] = STATE(2729),
    [aux_sym_preproc_conditional_report_repeat1] = STATE(7836),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(2630)] = {
    [sym_preproc_split_procedure] = STATE(2628),
    [sym_var_attribute_item] = STATE(2628),
    [sym_preproc_conditional_var] = STATE(2628),
    [sym_variable_declaration] = STATE(2628),
    [sym_preproc_if] = STATE(2422),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_var_section_repeat1] = STATE(2628),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(6265),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6267),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6267),
    [anon_sym_LBRACK] = ACTIONS(6265),
    [aux_sym_basic_type_token6] = ACTIONS(6267),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_addafter_modification_token1] = ACTIONS(6267),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6267),
    [aux_sym_modify_modification_token1] = ACTIONS(6267),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6267),
    [aux_sym_movelast_modification_token1] = ACTIONS(6267),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6267),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6267),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6267),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(6259),
    [anon_sym_POUNDIF] = ACTIONS(6259),
    [anon_sym_POUNDIf] = ACTIONS(6259),
    [anon_sym_POUNDelif] = ACTIONS(6265),
    [anon_sym_POUNDELIF] = ACTIONS(6265),
    [anon_sym_POUNDElif] = ACTIONS(6265),
    [anon_sym_POUNDelse] = ACTIONS(6265),
    [anon_sym_POUNDELSE] = ACTIONS(6265),
    [anon_sym_POUNDElse] = ACTIONS(6265),
    [anon_sym_POUNDendif] = ACTIONS(6265),
    [anon_sym_POUNDENDIF] = ACTIONS(6265),
    [anon_sym_POUNDEndif] = ACTIONS(6265),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6267),
    [sym_trigger_keyword] = ACTIONS(6267),
    [sym_var_keyword] = ACTIONS(6267),
    [sym_local_keyword] = ACTIONS(6267),
    [sym_internal_keyword] = ACTIONS(6267),
    [sym_protected_keyword] = ACTIONS(6267),
    [sym_event_keyword] = ACTIONS(6267),
    [sym_fields_keyword] = ACTIONS(6267),
    [sym_keys_keyword] = ACTIONS(6267),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(6267),
    [sym_actions_keyword] = ACTIONS(6267),
    [sym_layout_keyword] = ACTIONS(6267),
    [sym_area_keyword] = ACTIONS(6267),
    [sym_group_keyword] = ACTIONS(6267),
    [sym_repeater_keyword] = ACTIONS(6267),
    [sym_cuegroup_keyword] = ACTIONS(6267),
    [sym_fixed_keyword] = ACTIONS(6267),
    [sym_grid_keyword] = ACTIONS(6267),
    [sym_part_keyword] = ACTIONS(6267),
    [sym_systempart_keyword] = ACTIONS(6267),
    [sym_usercontrol_keyword] = ACTIONS(6267),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_elements_keyword] = ACTIONS(6267),
    [sym_dataitem_keyword] = ACTIONS(6267),
    [sym_column_keyword] = ACTIONS(6267),
    [sym_filter_keyword] = ACTIONS(6267),
    [sym_labels_keyword] = ACTIONS(6267),
    [sym_rendering_keyword] = ACTIONS(6267),
    [sym_requestpage_keyword] = ACTIONS(6267),
    [sym_schema_keyword] = ACTIONS(6267),
    [sym_views_keyword] = ACTIONS(6267),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6265),
    [sym_preproc_open] = ACTIONS(6259),
    [sym_preproc_close] = ACTIONS(6265),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2631)] = {
    [sym__body_element] = STATE(5591),
    [sym_empty_statement] = STATE(5591),
    [sym_property] = STATE(5591),
    [sym_fields_section] = STATE(5591),
    [sym_keys_section] = STATE(5591),
    [sym_fieldgroups_section] = STATE(5591),
    [sym_enum_value_declaration] = STATE(5591),
    [sym_labels_section] = STATE(5591),
    [sym_layout_section] = STATE(5591),
    [sym_modify_modification] = STATE(5591),
    [sym_actions_section] = STATE(5591),
    [sym_views_section] = STATE(5591),
    [sym_dataset_section] = STATE(5591),
    [sym_requestpage_section] = STATE(5591),
    [sym_rendering_section] = STATE(5591),
    [sym_elements_section] = STATE(5591),
    [sym_schema_section] = STATE(5591),
    [sym_xmlport_element] = STATE(2641),
    [sym__xmlport_body_element] = STATE(2641),
    [sym_preproc_conditional_xmlport] = STATE(2641),
    [sym_xmlport_attribute] = STATE(2641),
    [sym_assembly_declaration] = STATE(5591),
    [sym_event_declaration] = STATE(5591),
    [sym_procedure] = STATE(5591),
    [sym_preproc_split_procedure] = STATE(5591),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(5591),
    [sym_var_section] = STATE(5591),
    [sym_attribute_item] = STATE(5591),
    [sym_preproc_conditional] = STATE(5591),
    [sym_preproc_if] = STATE(2446),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3335),
    [aux_sym_xmlport_element_repeat1] = STATE(2641),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDelif] = ACTIONS(6269),
    [anon_sym_POUNDELIF] = ACTIONS(6269),
    [anon_sym_POUNDElif] = ACTIONS(6269),
    [anon_sym_POUNDelse] = ACTIONS(6269),
    [anon_sym_POUNDELSE] = ACTIONS(6269),
    [anon_sym_POUNDElse] = ACTIONS(6269),
    [anon_sym_POUNDendif] = ACTIONS(6269),
    [anon_sym_POUNDENDIF] = ACTIONS(6269),
    [anon_sym_POUNDEndif] = ACTIONS(6269),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(6269),
  },
  [STATE(2632)] = {
    [sym_preproc_split_procedure] = STATE(2626),
    [sym_var_attribute_item] = STATE(2626),
    [sym_preproc_conditional_var] = STATE(2626),
    [sym_variable_declaration] = STATE(2626),
    [sym_preproc_if] = STATE(2422),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_var_section_repeat1] = STATE(2626),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(6265),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6267),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6267),
    [anon_sym_LBRACK] = ACTIONS(6265),
    [aux_sym_basic_type_token6] = ACTIONS(6267),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_addafter_modification_token1] = ACTIONS(6267),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6267),
    [aux_sym_modify_modification_token1] = ACTIONS(6267),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6267),
    [aux_sym_movelast_modification_token1] = ACTIONS(6267),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6267),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6267),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6267),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(6259),
    [anon_sym_POUNDIF] = ACTIONS(6259),
    [anon_sym_POUNDIf] = ACTIONS(6259),
    [anon_sym_POUNDelif] = ACTIONS(6265),
    [anon_sym_POUNDELIF] = ACTIONS(6265),
    [anon_sym_POUNDElif] = ACTIONS(6265),
    [anon_sym_POUNDelse] = ACTIONS(6265),
    [anon_sym_POUNDELSE] = ACTIONS(6265),
    [anon_sym_POUNDElse] = ACTIONS(6265),
    [anon_sym_POUNDendif] = ACTIONS(6265),
    [anon_sym_POUNDENDIF] = ACTIONS(6265),
    [anon_sym_POUNDEndif] = ACTIONS(6265),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6267),
    [sym_trigger_keyword] = ACTIONS(6267),
    [sym_var_keyword] = ACTIONS(6267),
    [sym_local_keyword] = ACTIONS(6267),
    [sym_internal_keyword] = ACTIONS(6267),
    [sym_protected_keyword] = ACTIONS(6267),
    [sym_event_keyword] = ACTIONS(6267),
    [sym_fields_keyword] = ACTIONS(6267),
    [sym_keys_keyword] = ACTIONS(6267),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(6267),
    [sym_actions_keyword] = ACTIONS(6267),
    [sym_layout_keyword] = ACTIONS(6267),
    [sym_area_keyword] = ACTIONS(6267),
    [sym_group_keyword] = ACTIONS(6267),
    [sym_repeater_keyword] = ACTIONS(6267),
    [sym_cuegroup_keyword] = ACTIONS(6267),
    [sym_fixed_keyword] = ACTIONS(6267),
    [sym_grid_keyword] = ACTIONS(6267),
    [sym_part_keyword] = ACTIONS(6267),
    [sym_systempart_keyword] = ACTIONS(6267),
    [sym_usercontrol_keyword] = ACTIONS(6267),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_elements_keyword] = ACTIONS(6267),
    [sym_dataitem_keyword] = ACTIONS(6267),
    [sym_column_keyword] = ACTIONS(6267),
    [sym_filter_keyword] = ACTIONS(6267),
    [sym_labels_keyword] = ACTIONS(6267),
    [sym_rendering_keyword] = ACTIONS(6267),
    [sym_requestpage_keyword] = ACTIONS(6267),
    [sym_schema_keyword] = ACTIONS(6267),
    [sym_views_keyword] = ACTIONS(6267),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6265),
    [sym_preproc_open] = ACTIONS(6259),
    [sym_preproc_close] = ACTIONS(6265),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2633)] = {
    [sym_preproc_conditional_controladdin] = STATE(2721),
    [sym__body_element] = STATE(6269),
    [sym_empty_statement] = STATE(6269),
    [sym_property] = STATE(6269),
    [sym_fields_section] = STATE(6269),
    [sym_keys_section] = STATE(6269),
    [sym_fieldgroups_section] = STATE(6269),
    [sym_enum_value_declaration] = STATE(6269),
    [sym_labels_section] = STATE(6269),
    [sym_layout_section] = STATE(6269),
    [sym_modify_modification] = STATE(6269),
    [sym_actions_section] = STATE(6269),
    [sym_views_section] = STATE(6269),
    [sym_dataset_section] = STATE(6269),
    [sym_requestpage_section] = STATE(6269),
    [sym_rendering_section] = STATE(6269),
    [sym_elements_section] = STATE(6269),
    [sym_schema_section] = STATE(6269),
    [sym_assembly_declaration] = STATE(6269),
    [sym_event_declaration] = STATE(6269),
    [sym_procedure] = STATE(6269),
    [sym_preproc_split_procedure] = STATE(6269),
    [sym__procedure_header] = STATE(8087),
    [sym_interface_procedure] = STATE(2721),
    [sym_procedure_modifier] = STATE(12657),
    [sym_trigger_declaration] = STATE(6269),
    [sym_var_section] = STATE(6269),
    [sym_attribute_item] = STATE(3722),
    [sym_preproc_conditional] = STATE(6269),
    [sym_preproc_if] = STATE(2635),
    [sym_preproc_elif] = STATE(2806),
    [sym_preproc_else] = STATE(3373),
    [sym_preproc_endif] = STATE(6926),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(2739),
    [aux_sym_controladdin_declaration_repeat1] = STATE(2721),
    [aux_sym_preproc_conditional_controladdin_repeat1] = STATE(8151),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_repeat1] = STATE(8094),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6272),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(2634)] = {
    [sym__body_element] = STATE(2729),
    [sym_empty_statement] = STATE(2729),
    [sym_property] = STATE(2729),
    [sym_fields_section] = STATE(2729),
    [sym_keys_section] = STATE(2729),
    [sym_fieldgroups_section] = STATE(2729),
    [sym_enum_value_declaration] = STATE(2729),
    [sym_labels_section] = STATE(2729),
    [sym_layout_section] = STATE(2729),
    [sym_modify_modification] = STATE(2729),
    [sym_actions_section] = STATE(2729),
    [sym_views_section] = STATE(2729),
    [sym_dataset_section] = STATE(2729),
    [sym_report_dataitem] = STATE(2729),
    [sym__report_body_element] = STATE(2729),
    [sym_preproc_conditional_report] = STATE(2729),
    [sym_report_column] = STATE(2729),
    [sym_requestpage_section] = STATE(2729),
    [sym_rendering_section] = STATE(2729),
    [sym_elements_section] = STATE(2729),
    [sym_schema_section] = STATE(2729),
    [sym_assembly_declaration] = STATE(2729),
    [sym_event_declaration] = STATE(2729),
    [sym_procedure] = STATE(2729),
    [sym_preproc_split_procedure] = STATE(2729),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2729),
    [sym_var_section] = STATE(2729),
    [sym_attribute_item] = STATE(2729),
    [sym_preproc_conditional] = STATE(2729),
    [sym_preproc_if] = STATE(2557),
    [sym_preproc_elif] = STATE(2732),
    [sym_preproc_else] = STATE(3262),
    [sym_preproc_endif] = STATE(6880),
    [aux_sym_report_dataitem_repeat1] = STATE(2729),
    [aux_sym_preproc_conditional_report_repeat1] = STATE(8131),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(2635)] = {
    [sym_preproc_conditional_controladdin] = STATE(2726),
    [sym__body_element] = STATE(6269),
    [sym_empty_statement] = STATE(6269),
    [sym_property] = STATE(6269),
    [sym_fields_section] = STATE(6269),
    [sym_keys_section] = STATE(6269),
    [sym_fieldgroups_section] = STATE(6269),
    [sym_enum_value_declaration] = STATE(6269),
    [sym_labels_section] = STATE(6269),
    [sym_layout_section] = STATE(6269),
    [sym_modify_modification] = STATE(6269),
    [sym_actions_section] = STATE(6269),
    [sym_views_section] = STATE(6269),
    [sym_dataset_section] = STATE(6269),
    [sym_requestpage_section] = STATE(6269),
    [sym_rendering_section] = STATE(6269),
    [sym_elements_section] = STATE(6269),
    [sym_schema_section] = STATE(6269),
    [sym_assembly_declaration] = STATE(6269),
    [sym_event_declaration] = STATE(6269),
    [sym_procedure] = STATE(6269),
    [sym_preproc_split_procedure] = STATE(6269),
    [sym__procedure_header] = STATE(8089),
    [sym_interface_procedure] = STATE(2726),
    [sym_procedure_modifier] = STATE(12657),
    [sym_trigger_declaration] = STATE(6269),
    [sym_var_section] = STATE(6269),
    [sym_attribute_item] = STATE(3722),
    [sym_preproc_conditional] = STATE(6269),
    [sym_preproc_if] = STATE(2635),
    [sym_preproc_elif] = STATE(2806),
    [sym_preproc_else] = STATE(3375),
    [sym_preproc_endif] = STATE(6268),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(2755),
    [aux_sym_controladdin_declaration_repeat1] = STATE(2726),
    [aux_sym_preproc_conditional_controladdin_repeat1] = STATE(8163),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_repeat1] = STATE(8159),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6272),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(2636)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(2607),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2637)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(2616),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2638)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(2625),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2648),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2639)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(2599),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2640)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(4820),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2641)] = {
    [sym__body_element] = STATE(2652),
    [sym_empty_statement] = STATE(2652),
    [sym_property] = STATE(2652),
    [sym_fields_section] = STATE(2652),
    [sym_keys_section] = STATE(2652),
    [sym_fieldgroups_section] = STATE(2652),
    [sym_enum_value_declaration] = STATE(2652),
    [sym_labels_section] = STATE(2652),
    [sym_layout_section] = STATE(2652),
    [sym_modify_modification] = STATE(2652),
    [sym_actions_section] = STATE(2652),
    [sym_views_section] = STATE(2652),
    [sym_dataset_section] = STATE(2652),
    [sym_requestpage_section] = STATE(2652),
    [sym_rendering_section] = STATE(2652),
    [sym_elements_section] = STATE(2652),
    [sym_schema_section] = STATE(2652),
    [sym_xmlport_element] = STATE(2652),
    [sym__xmlport_body_element] = STATE(2652),
    [sym_preproc_conditional_xmlport] = STATE(2652),
    [sym_xmlport_attribute] = STATE(2652),
    [sym_assembly_declaration] = STATE(2652),
    [sym_event_declaration] = STATE(2652),
    [sym_procedure] = STATE(2652),
    [sym_preproc_split_procedure] = STATE(2652),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(2652),
    [sym_var_section] = STATE(2652),
    [sym_attribute_item] = STATE(2652),
    [sym_preproc_conditional] = STATE(2652),
    [sym_preproc_if] = STATE(2446),
    [aux_sym_xmlport_element_repeat1] = STATE(2652),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDelif] = ACTIONS(6274),
    [anon_sym_POUNDELIF] = ACTIONS(6274),
    [anon_sym_POUNDElif] = ACTIONS(6274),
    [anon_sym_POUNDelse] = ACTIONS(6274),
    [anon_sym_POUNDELSE] = ACTIONS(6274),
    [anon_sym_POUNDElse] = ACTIONS(6274),
    [anon_sym_POUNDendif] = ACTIONS(6274),
    [anon_sym_POUNDENDIF] = ACTIONS(6274),
    [anon_sym_POUNDEndif] = ACTIONS(6274),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(6274),
  },
  [STATE(2642)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(2595),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2636),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2643)] = {
    [sym_boolean] = STATE(6087),
    [sym_code_block] = STATE(10296),
    [sym_assignment_expression] = STATE(6087),
    [sym__expression] = STATE(6087),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6087),
    [sym_multiplicative_expression] = STATE(6087),
    [sym_additive_expression] = STATE(6087),
    [sym_comparison_expression] = STATE(6087),
    [sym_logical_expression] = STATE(6087),
    [sym_ternary_expression] = STATE(6087),
    [sym_unary_expression] = STATE(6087),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6087),
    [sym_list_literal] = STATE(6087),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6087),
    [sym__literal_value] = STATE(6087),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(2735),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6276),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(559),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6278),
    [sym_date_literal] = ACTIONS(6276),
    [sym_time_literal] = ACTIONS(6276),
    [sym_biginteger_literal] = ACTIONS(6278),
    [anon_sym_else] = ACTIONS(2739),
    [anon_sym_ELSE] = ACTIONS(2739),
    [anon_sym_Else] = ACTIONS(2739),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6278),
    [sym_integer] = ACTIONS(6276),
    [sym_continue_as_identifier] = ACTIONS(6278),
    [sym_begin_keyword] = ACTIONS(563),
  },
  [STATE(2644)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(4832),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2645)] = {
    [sym_boolean] = STATE(6283),
    [sym__preproc_if_header] = STATE(10168),
    [sym__expression_statement] = STATE(11961),
    [sym_assignment_expression] = STATE(6283),
    [sym__expression] = STATE(6283),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6283),
    [sym_multiplicative_expression] = STATE(6283),
    [sym_additive_expression] = STATE(6283),
    [sym_comparison_expression] = STATE(6283),
    [sym_logical_expression] = STATE(6283),
    [sym_ternary_expression] = STATE(6283),
    [sym_unary_expression] = STATE(6283),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6283),
    [sym_list_literal] = STATE(6283),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6283),
    [sym__literal_value] = STATE(6283),
    [sym_if_keyword] = STATE(3150),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2718),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6282),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(6284),
    [sym_date_literal] = ACTIONS(6282),
    [sym_time_literal] = ACTIONS(6282),
    [sym_biginteger_literal] = ACTIONS(6284),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6284),
    [sym_integer] = ACTIONS(6282),
    [sym_continue_as_identifier] = ACTIONS(6284),
  },
  [STATE(2646)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(4796),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2655),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2647)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(4821),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2644),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2648)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(2611),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2649)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(4822),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2650)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(2577),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2639),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2651)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(2598),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2652)] = {
    [sym__body_element] = STATE(2652),
    [sym_empty_statement] = STATE(2652),
    [sym_property] = STATE(2652),
    [sym_fields_section] = STATE(2652),
    [sym_keys_section] = STATE(2652),
    [sym_fieldgroups_section] = STATE(2652),
    [sym_enum_value_declaration] = STATE(2652),
    [sym_labels_section] = STATE(2652),
    [sym_layout_section] = STATE(2652),
    [sym_modify_modification] = STATE(2652),
    [sym_actions_section] = STATE(2652),
    [sym_views_section] = STATE(2652),
    [sym_dataset_section] = STATE(2652),
    [sym_requestpage_section] = STATE(2652),
    [sym_rendering_section] = STATE(2652),
    [sym_elements_section] = STATE(2652),
    [sym_schema_section] = STATE(2652),
    [sym_xmlport_element] = STATE(2652),
    [sym__xmlport_body_element] = STATE(2652),
    [sym_preproc_conditional_xmlport] = STATE(2652),
    [sym_xmlport_attribute] = STATE(2652),
    [sym_assembly_declaration] = STATE(2652),
    [sym_event_declaration] = STATE(2652),
    [sym_procedure] = STATE(2652),
    [sym_preproc_split_procedure] = STATE(2652),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(2652),
    [sym_var_section] = STATE(2652),
    [sym_attribute_item] = STATE(2652),
    [sym_preproc_conditional] = STATE(2652),
    [sym_preproc_if] = STATE(2446),
    [aux_sym_xmlport_element_repeat1] = STATE(2652),
    [anon_sym_SEMI] = ACTIONS(6288),
    [anon_sym_LBRACK] = ACTIONS(6291),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6294),
    [aux_sym_modify_modification_token1] = ACTIONS(6297),
    [aux_sym_xmlport_element_token1] = ACTIONS(6300),
    [aux_sym_xmlport_element_token2] = ACTIONS(6300),
    [aux_sym_xmlport_element_token3] = ACTIONS(6300),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6303),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6303),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6306),
    [anon_sym_POUNDif] = ACTIONS(6309),
    [anon_sym_POUNDIF] = ACTIONS(6309),
    [anon_sym_POUNDIf] = ACTIONS(6309),
    [anon_sym_POUNDelif] = ACTIONS(6312),
    [anon_sym_POUNDELIF] = ACTIONS(6312),
    [anon_sym_POUNDElif] = ACTIONS(6312),
    [anon_sym_POUNDelse] = ACTIONS(6312),
    [anon_sym_POUNDELSE] = ACTIONS(6312),
    [anon_sym_POUNDElse] = ACTIONS(6312),
    [anon_sym_POUNDendif] = ACTIONS(6312),
    [anon_sym_POUNDENDIF] = ACTIONS(6312),
    [anon_sym_POUNDEndif] = ACTIONS(6312),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6314),
    [sym_trigger_keyword] = ACTIONS(6317),
    [sym_var_keyword] = ACTIONS(6320),
    [sym_local_keyword] = ACTIONS(6323),
    [sym_internal_keyword] = ACTIONS(6326),
    [sym_protected_keyword] = ACTIONS(6323),
    [sym_event_keyword] = ACTIONS(6329),
    [sym_fields_keyword] = ACTIONS(6332),
    [sym_keys_keyword] = ACTIONS(6335),
    [sym_fieldgroups_keyword] = ACTIONS(6338),
    [sym_actions_keyword] = ACTIONS(6341),
    [sym_layout_keyword] = ACTIONS(6344),
    [sym_dataset_keyword] = ACTIONS(6347),
    [sym_elements_keyword] = ACTIONS(6350),
    [sym_labels_keyword] = ACTIONS(6353),
    [sym_rendering_keyword] = ACTIONS(6356),
    [sym_requestpage_keyword] = ACTIONS(6359),
    [sym_schema_keyword] = ACTIONS(6362),
    [sym_views_keyword] = ACTIONS(6365),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6368),
    [sym_preproc_open] = ACTIONS(6309),
    [sym_preproc_close] = ACTIONS(6312),
  },
  [STATE(2653)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(2618),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2654)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(2602),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2653),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2655)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(4806),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2656)] = {
    [sym__body_element] = STATE(5964),
    [sym_empty_statement] = STATE(5964),
    [sym_property] = STATE(5964),
    [sym_fields_section] = STATE(5964),
    [sym_keys_section] = STATE(5964),
    [sym_fieldgroups_section] = STATE(5964),
    [sym_enum_value_declaration] = STATE(5964),
    [sym_labels_section] = STATE(5964),
    [sym_layout_section] = STATE(5964),
    [sym_modify_modification] = STATE(5964),
    [sym_actions_section] = STATE(5964),
    [sym_views_section] = STATE(5964),
    [sym_dataset_section] = STATE(5964),
    [sym_requestpage_section] = STATE(5964),
    [sym_rendering_section] = STATE(5964),
    [sym_elements_section] = STATE(5964),
    [sym_query_dataitem] = STATE(2714),
    [sym__query_body_element] = STATE(2714),
    [sym_preproc_conditional_query] = STATE(2714),
    [sym_query_column] = STATE(2714),
    [sym_query_filter] = STATE(2714),
    [sym_schema_section] = STATE(5964),
    [sym_assembly_declaration] = STATE(5964),
    [sym_event_declaration] = STATE(5964),
    [sym_procedure] = STATE(5964),
    [sym_preproc_split_procedure] = STATE(5964),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(5964),
    [sym_var_section] = STATE(5964),
    [sym_attribute_item] = STATE(5964),
    [sym_preproc_conditional] = STATE(5964),
    [sym_preproc_if] = STATE(2494),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3335),
    [aux_sym_query_dataitem_repeat1] = STATE(2714),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(6371),
    [anon_sym_POUNDELIF] = ACTIONS(6371),
    [anon_sym_POUNDElif] = ACTIONS(6371),
    [anon_sym_POUNDelse] = ACTIONS(6371),
    [anon_sym_POUNDELSE] = ACTIONS(6371),
    [anon_sym_POUNDElse] = ACTIONS(6371),
    [anon_sym_POUNDendif] = ACTIONS(6371),
    [anon_sym_POUNDENDIF] = ACTIONS(6371),
    [anon_sym_POUNDEndif] = ACTIONS(6371),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(6371),
  },
  [STATE(2657)] = {
    [sym__body_element] = STATE(2641),
    [sym_empty_statement] = STATE(2641),
    [sym_property] = STATE(2641),
    [sym_fields_section] = STATE(2641),
    [sym_keys_section] = STATE(2641),
    [sym_fieldgroups_section] = STATE(2641),
    [sym_enum_value_declaration] = STATE(2641),
    [sym_labels_section] = STATE(2641),
    [sym_layout_section] = STATE(2641),
    [sym_modify_modification] = STATE(2641),
    [sym_actions_section] = STATE(2641),
    [sym_views_section] = STATE(2641),
    [sym_dataset_section] = STATE(2641),
    [sym_requestpage_section] = STATE(2641),
    [sym_rendering_section] = STATE(2641),
    [sym_elements_section] = STATE(2641),
    [sym_schema_section] = STATE(2641),
    [sym_xmlport_element] = STATE(2641),
    [sym__xmlport_body_element] = STATE(2641),
    [sym_preproc_conditional_xmlport] = STATE(2641),
    [sym_xmlport_attribute] = STATE(2641),
    [sym_assembly_declaration] = STATE(2641),
    [sym_event_declaration] = STATE(2641),
    [sym_procedure] = STATE(2641),
    [sym_preproc_split_procedure] = STATE(2641),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(2641),
    [sym_var_section] = STATE(2641),
    [sym_attribute_item] = STATE(2641),
    [sym_preproc_conditional] = STATE(2641),
    [sym_preproc_if] = STATE(2446),
    [aux_sym_xmlport_element_repeat1] = STATE(2641),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDelif] = ACTIONS(6374),
    [anon_sym_POUNDELIF] = ACTIONS(6374),
    [anon_sym_POUNDElif] = ACTIONS(6374),
    [anon_sym_POUNDelse] = ACTIONS(6374),
    [anon_sym_POUNDELSE] = ACTIONS(6374),
    [anon_sym_POUNDElse] = ACTIONS(6374),
    [anon_sym_POUNDendif] = ACTIONS(6374),
    [anon_sym_POUNDENDIF] = ACTIONS(6374),
    [anon_sym_POUNDEndif] = ACTIONS(6374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(6374),
  },
  [STATE(2658)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(4807),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2640),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2659)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(4809),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2649),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2660)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(2608),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2662),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2661)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(2610),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2664),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2662)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(2612),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2663)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(2613),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2637),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2664)] = {
    [sym_boolean] = STATE(2170),
    [sym_preproc_endif] = STATE(2614),
    [sym_assignment_expression] = STATE(6339),
    [sym__single_pattern] = STATE(4131),
    [sym__expression] = STATE(6339),
    [sym_keyword_identifier] = STATE(2032),
    [sym_range_expression] = STATE(2170),
    [sym_multiplicative_expression] = STATE(2170),
    [sym_additive_expression] = STATE(2170),
    [sym_comparison_expression] = STATE(2170),
    [sym_logical_expression] = STATE(2170),
    [sym_ternary_expression] = STATE(6339),
    [sym_unary_expression] = STATE(2170),
    [sym_call_expression] = STATE(2112),
    [sym_member_expression] = STATE(2032),
    [sym_subscript_expression] = STATE(2032),
    [sym_parenthesized_expression] = STATE(2170),
    [sym_list_literal] = STATE(6339),
    [sym_qualified_enum_value] = STATE(2032),
    [sym_database_reference] = STATE(2170),
    [sym__literal_value] = STATE(2170),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(2562),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(5614),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(5626),
    [sym_date_literal] = ACTIONS(5614),
    [sym_time_literal] = ACTIONS(5614),
    [sym_biginteger_literal] = ACTIONS(5626),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5626),
    [sym_integer] = ACTIONS(5614),
    [sym_continue_as_identifier] = ACTIONS(5630),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2665)] = {
    [sym__body_element] = STATE(2687),
    [sym_empty_statement] = STATE(2687),
    [sym_property] = STATE(2687),
    [sym_fields_section] = STATE(2687),
    [sym_keys_section] = STATE(2687),
    [sym_fieldgroups_section] = STATE(2687),
    [sym_enum_value_declaration] = STATE(2687),
    [sym_labels_section] = STATE(2687),
    [sym_layout_section] = STATE(2687),
    [sym_modify_modification] = STATE(2687),
    [sym_actions_section] = STATE(2687),
    [sym_views_section] = STATE(2687),
    [sym_dataset_section] = STATE(2687),
    [sym_requestpage_section] = STATE(2687),
    [sym_rendering_section] = STATE(2687),
    [sym_elements_section] = STATE(2687),
    [sym_schema_section] = STATE(2687),
    [sym_assembly_declaration] = STATE(2687),
    [sym_event_declaration] = STATE(2687),
    [sym_procedure] = STATE(2687),
    [sym_preproc_split_procedure] = STATE(2687),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2687),
    [sym_var_section] = STATE(2687),
    [sym_var_attribute_item] = STATE(2687),
    [sym_variable_declaration] = STATE(2687),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2687),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7084),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2687),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5576),
    [anon_sym_POUNDENDIF] = ACTIONS(5576),
    [anon_sym_POUNDEndif] = ACTIONS(5576),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5576),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2666)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(5500),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5570),
    [anon_sym_POUNDENDIF] = ACTIONS(5570),
    [anon_sym_POUNDEndif] = ACTIONS(5570),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5570),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2667)] = {
    [sym__body_element] = STATE(2668),
    [sym_empty_statement] = STATE(2668),
    [sym_property] = STATE(2668),
    [sym_fields_section] = STATE(2668),
    [sym_keys_section] = STATE(2668),
    [sym_fieldgroups_section] = STATE(2668),
    [sym_enum_value_declaration] = STATE(2668),
    [sym_labels_section] = STATE(2668),
    [sym_layout_section] = STATE(2668),
    [sym_modify_modification] = STATE(2668),
    [sym_actions_section] = STATE(2668),
    [sym_views_section] = STATE(2668),
    [sym_dataset_section] = STATE(2668),
    [sym_requestpage_section] = STATE(2668),
    [sym_rendering_section] = STATE(2668),
    [sym_elements_section] = STATE(2668),
    [sym_schema_section] = STATE(2668),
    [sym_assembly_declaration] = STATE(2668),
    [sym_event_declaration] = STATE(2668),
    [sym_procedure] = STATE(2668),
    [sym_preproc_split_procedure] = STATE(2668),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2668),
    [sym_var_section] = STATE(2668),
    [sym_var_attribute_item] = STATE(2668),
    [sym_variable_declaration] = STATE(2668),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2668),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(5500),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2668),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5570),
    [anon_sym_POUNDENDIF] = ACTIONS(5570),
    [anon_sym_POUNDEndif] = ACTIONS(5570),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5570),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2668)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(5524),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5570),
    [anon_sym_POUNDENDIF] = ACTIONS(5570),
    [anon_sym_POUNDEndif] = ACTIONS(5570),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5570),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2669)] = {
    [sym__body_element] = STATE(2670),
    [sym_empty_statement] = STATE(2670),
    [sym_property] = STATE(2670),
    [sym_fields_section] = STATE(2670),
    [sym_keys_section] = STATE(2670),
    [sym_fieldgroups_section] = STATE(2670),
    [sym_enum_value_declaration] = STATE(2670),
    [sym_labels_section] = STATE(2670),
    [sym_layout_section] = STATE(2670),
    [sym_modify_modification] = STATE(2670),
    [sym_actions_section] = STATE(2670),
    [sym_views_section] = STATE(2670),
    [sym_dataset_section] = STATE(2670),
    [sym_requestpage_section] = STATE(2670),
    [sym_rendering_section] = STATE(2670),
    [sym_elements_section] = STATE(2670),
    [sym_schema_section] = STATE(2670),
    [sym_assembly_declaration] = STATE(2670),
    [sym_event_declaration] = STATE(2670),
    [sym_procedure] = STATE(2670),
    [sym_preproc_split_procedure] = STATE(2670),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2670),
    [sym_var_section] = STATE(2670),
    [sym_var_attribute_item] = STATE(2670),
    [sym_variable_declaration] = STATE(2670),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2670),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(4768),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2670),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5572),
    [anon_sym_POUNDENDIF] = ACTIONS(5572),
    [anon_sym_POUNDEndif] = ACTIONS(5572),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5572),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2670)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(4770),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5572),
    [anon_sym_POUNDENDIF] = ACTIONS(5572),
    [anon_sym_POUNDEndif] = ACTIONS(5572),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5572),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2671)] = {
    [sym__body_element] = STATE(2672),
    [sym_empty_statement] = STATE(2672),
    [sym_property] = STATE(2672),
    [sym_fields_section] = STATE(2672),
    [sym_keys_section] = STATE(2672),
    [sym_fieldgroups_section] = STATE(2672),
    [sym_enum_value_declaration] = STATE(2672),
    [sym_labels_section] = STATE(2672),
    [sym_layout_section] = STATE(2672),
    [sym_modify_modification] = STATE(2672),
    [sym_actions_section] = STATE(2672),
    [sym_views_section] = STATE(2672),
    [sym_dataset_section] = STATE(2672),
    [sym_requestpage_section] = STATE(2672),
    [sym_rendering_section] = STATE(2672),
    [sym_elements_section] = STATE(2672),
    [sym_schema_section] = STATE(2672),
    [sym_assembly_declaration] = STATE(2672),
    [sym_event_declaration] = STATE(2672),
    [sym_procedure] = STATE(2672),
    [sym_preproc_split_procedure] = STATE(2672),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2672),
    [sym_var_section] = STATE(2672),
    [sym_var_attribute_item] = STATE(2672),
    [sym_variable_declaration] = STATE(2672),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2672),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(4770),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2672),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5572),
    [anon_sym_POUNDENDIF] = ACTIONS(5572),
    [anon_sym_POUNDEndif] = ACTIONS(5572),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5572),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2672)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(4772),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5572),
    [anon_sym_POUNDENDIF] = ACTIONS(5572),
    [anon_sym_POUNDEndif] = ACTIONS(5572),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5572),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2673)] = {
    [sym__body_element] = STATE(2674),
    [sym_empty_statement] = STATE(2674),
    [sym_property] = STATE(2674),
    [sym_fields_section] = STATE(2674),
    [sym_keys_section] = STATE(2674),
    [sym_fieldgroups_section] = STATE(2674),
    [sym_enum_value_declaration] = STATE(2674),
    [sym_labels_section] = STATE(2674),
    [sym_layout_section] = STATE(2674),
    [sym_modify_modification] = STATE(2674),
    [sym_actions_section] = STATE(2674),
    [sym_views_section] = STATE(2674),
    [sym_dataset_section] = STATE(2674),
    [sym_requestpage_section] = STATE(2674),
    [sym_rendering_section] = STATE(2674),
    [sym_elements_section] = STATE(2674),
    [sym_schema_section] = STATE(2674),
    [sym_assembly_declaration] = STATE(2674),
    [sym_event_declaration] = STATE(2674),
    [sym_procedure] = STATE(2674),
    [sym_preproc_split_procedure] = STATE(2674),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2674),
    [sym_var_section] = STATE(2674),
    [sym_var_attribute_item] = STATE(2674),
    [sym_variable_declaration] = STATE(2674),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2674),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(4772),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2674),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5572),
    [anon_sym_POUNDENDIF] = ACTIONS(5572),
    [anon_sym_POUNDEndif] = ACTIONS(5572),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5572),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2674)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(4775),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5572),
    [anon_sym_POUNDENDIF] = ACTIONS(5572),
    [anon_sym_POUNDEndif] = ACTIONS(5572),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5572),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2675)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7069),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5576),
    [anon_sym_POUNDENDIF] = ACTIONS(5576),
    [anon_sym_POUNDEndif] = ACTIONS(5576),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5576),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2676)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(3822),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5562),
    [anon_sym_POUNDENDIF] = ACTIONS(5562),
    [anon_sym_POUNDEndif] = ACTIONS(5562),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5562),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2677)] = {
    [sym__body_element] = STATE(2678),
    [sym_empty_statement] = STATE(2678),
    [sym_property] = STATE(2678),
    [sym_fields_section] = STATE(2678),
    [sym_keys_section] = STATE(2678),
    [sym_fieldgroups_section] = STATE(2678),
    [sym_enum_value_declaration] = STATE(2678),
    [sym_labels_section] = STATE(2678),
    [sym_layout_section] = STATE(2678),
    [sym_modify_modification] = STATE(2678),
    [sym_actions_section] = STATE(2678),
    [sym_views_section] = STATE(2678),
    [sym_dataset_section] = STATE(2678),
    [sym_requestpage_section] = STATE(2678),
    [sym_rendering_section] = STATE(2678),
    [sym_elements_section] = STATE(2678),
    [sym_schema_section] = STATE(2678),
    [sym_assembly_declaration] = STATE(2678),
    [sym_event_declaration] = STATE(2678),
    [sym_procedure] = STATE(2678),
    [sym_preproc_split_procedure] = STATE(2678),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2678),
    [sym_var_section] = STATE(2678),
    [sym_var_attribute_item] = STATE(2678),
    [sym_variable_declaration] = STATE(2678),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2678),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(3822),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2678),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5562),
    [anon_sym_POUNDENDIF] = ACTIONS(5562),
    [anon_sym_POUNDEndif] = ACTIONS(5562),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5562),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2678)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(3803),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5562),
    [anon_sym_POUNDENDIF] = ACTIONS(5562),
    [anon_sym_POUNDEndif] = ACTIONS(5562),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5562),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2679)] = {
    [sym__body_element] = STATE(2681),
    [sym_empty_statement] = STATE(2681),
    [sym_property] = STATE(2681),
    [sym_fields_section] = STATE(2681),
    [sym_keys_section] = STATE(2681),
    [sym_fieldgroups_section] = STATE(2681),
    [sym_enum_value_declaration] = STATE(2681),
    [sym_labels_section] = STATE(2681),
    [sym_layout_section] = STATE(2681),
    [sym_modify_modification] = STATE(2681),
    [sym_actions_section] = STATE(2681),
    [sym_views_section] = STATE(2681),
    [sym_dataset_section] = STATE(2681),
    [sym_requestpage_section] = STATE(2681),
    [sym_rendering_section] = STATE(2681),
    [sym_elements_section] = STATE(2681),
    [sym_schema_section] = STATE(2681),
    [sym_assembly_declaration] = STATE(2681),
    [sym_event_declaration] = STATE(2681),
    [sym_procedure] = STATE(2681),
    [sym_preproc_split_procedure] = STATE(2681),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2681),
    [sym_var_section] = STATE(2681),
    [sym_var_attribute_item] = STATE(2681),
    [sym_variable_declaration] = STATE(2681),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2681),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(2958),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2681),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5568),
    [anon_sym_POUNDENDIF] = ACTIONS(5568),
    [anon_sym_POUNDEndif] = ACTIONS(5568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5568),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2680)] = {
    [sym__body_element] = STATE(2714),
    [sym_empty_statement] = STATE(2714),
    [sym_property] = STATE(2714),
    [sym_fields_section] = STATE(2714),
    [sym_keys_section] = STATE(2714),
    [sym_fieldgroups_section] = STATE(2714),
    [sym_enum_value_declaration] = STATE(2714),
    [sym_labels_section] = STATE(2714),
    [sym_layout_section] = STATE(2714),
    [sym_modify_modification] = STATE(2714),
    [sym_actions_section] = STATE(2714),
    [sym_views_section] = STATE(2714),
    [sym_dataset_section] = STATE(2714),
    [sym_requestpage_section] = STATE(2714),
    [sym_rendering_section] = STATE(2714),
    [sym_elements_section] = STATE(2714),
    [sym_query_dataitem] = STATE(2714),
    [sym__query_body_element] = STATE(2714),
    [sym_preproc_conditional_query] = STATE(2714),
    [sym_query_column] = STATE(2714),
    [sym_query_filter] = STATE(2714),
    [sym_schema_section] = STATE(2714),
    [sym_assembly_declaration] = STATE(2714),
    [sym_event_declaration] = STATE(2714),
    [sym_procedure] = STATE(2714),
    [sym_preproc_split_procedure] = STATE(2714),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2714),
    [sym_var_section] = STATE(2714),
    [sym_attribute_item] = STATE(2714),
    [sym_preproc_conditional] = STATE(2714),
    [sym_preproc_if] = STATE(2494),
    [aux_sym_query_dataitem_repeat1] = STATE(2714),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(6376),
    [anon_sym_POUNDELIF] = ACTIONS(6376),
    [anon_sym_POUNDElif] = ACTIONS(6376),
    [anon_sym_POUNDelse] = ACTIONS(6376),
    [anon_sym_POUNDELSE] = ACTIONS(6376),
    [anon_sym_POUNDElse] = ACTIONS(6376),
    [anon_sym_POUNDendif] = ACTIONS(6376),
    [anon_sym_POUNDENDIF] = ACTIONS(6376),
    [anon_sym_POUNDEndif] = ACTIONS(6376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(6376),
  },
  [STATE(2681)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(3038),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5568),
    [anon_sym_POUNDENDIF] = ACTIONS(5568),
    [anon_sym_POUNDEndif] = ACTIONS(5568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5568),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2682)] = {
    [sym__body_element] = STATE(2684),
    [sym_empty_statement] = STATE(2684),
    [sym_property] = STATE(2684),
    [sym_fields_section] = STATE(2684),
    [sym_keys_section] = STATE(2684),
    [sym_fieldgroups_section] = STATE(2684),
    [sym_enum_value_declaration] = STATE(2684),
    [sym_labels_section] = STATE(2684),
    [sym_layout_section] = STATE(2684),
    [sym_modify_modification] = STATE(2684),
    [sym_actions_section] = STATE(2684),
    [sym_views_section] = STATE(2684),
    [sym_dataset_section] = STATE(2684),
    [sym_requestpage_section] = STATE(2684),
    [sym_rendering_section] = STATE(2684),
    [sym_elements_section] = STATE(2684),
    [sym_schema_section] = STATE(2684),
    [sym_assembly_declaration] = STATE(2684),
    [sym_event_declaration] = STATE(2684),
    [sym_procedure] = STATE(2684),
    [sym_preproc_split_procedure] = STATE(2684),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2684),
    [sym_var_section] = STATE(2684),
    [sym_var_attribute_item] = STATE(2684),
    [sym_variable_declaration] = STATE(2684),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2684),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(3038),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2684),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5568),
    [anon_sym_POUNDENDIF] = ACTIONS(5568),
    [anon_sym_POUNDEndif] = ACTIONS(5568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5568),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2683)] = {
    [sym__body_element] = STATE(2686),
    [sym_empty_statement] = STATE(2686),
    [sym_property] = STATE(2686),
    [sym_fields_section] = STATE(2686),
    [sym_keys_section] = STATE(2686),
    [sym_fieldgroups_section] = STATE(2686),
    [sym_enum_value_declaration] = STATE(2686),
    [sym_labels_section] = STATE(2686),
    [sym_layout_section] = STATE(2686),
    [sym_modify_modification] = STATE(2686),
    [sym_actions_section] = STATE(2686),
    [sym_views_section] = STATE(2686),
    [sym_dataset_section] = STATE(2686),
    [sym_requestpage_section] = STATE(2686),
    [sym_rendering_section] = STATE(2686),
    [sym_elements_section] = STATE(2686),
    [sym_schema_section] = STATE(2686),
    [sym_assembly_declaration] = STATE(2686),
    [sym_event_declaration] = STATE(2686),
    [sym_procedure] = STATE(2686),
    [sym_preproc_split_procedure] = STATE(2686),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2686),
    [sym_var_section] = STATE(2686),
    [sym_var_attribute_item] = STATE(2686),
    [sym_variable_declaration] = STATE(2686),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2686),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7069),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2686),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5576),
    [anon_sym_POUNDENDIF] = ACTIONS(5576),
    [anon_sym_POUNDEndif] = ACTIONS(5576),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5576),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2684)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(3074),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5568),
    [anon_sym_POUNDENDIF] = ACTIONS(5568),
    [anon_sym_POUNDEndif] = ACTIONS(5568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5568),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2685)] = {
    [sym__body_element] = STATE(2701),
    [sym_empty_statement] = STATE(2701),
    [sym_property] = STATE(2701),
    [sym_fields_section] = STATE(2701),
    [sym_keys_section] = STATE(2701),
    [sym_fieldgroups_section] = STATE(2701),
    [sym_enum_value_declaration] = STATE(2701),
    [sym_labels_section] = STATE(2701),
    [sym_layout_section] = STATE(2701),
    [sym_modify_modification] = STATE(2701),
    [sym_actions_section] = STATE(2701),
    [sym_views_section] = STATE(2701),
    [sym_dataset_section] = STATE(2701),
    [sym_requestpage_section] = STATE(2701),
    [sym_rendering_section] = STATE(2701),
    [sym_elements_section] = STATE(2701),
    [sym_schema_section] = STATE(2701),
    [sym_assembly_declaration] = STATE(2701),
    [sym_event_declaration] = STATE(2701),
    [sym_procedure] = STATE(2701),
    [sym_preproc_split_procedure] = STATE(2701),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2701),
    [sym_var_section] = STATE(2701),
    [sym_var_attribute_item] = STATE(2701),
    [sym_variable_declaration] = STATE(2701),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2701),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(3074),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2701),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5568),
    [anon_sym_POUNDENDIF] = ACTIONS(5568),
    [anon_sym_POUNDEndif] = ACTIONS(5568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5568),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2686)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7084),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5576),
    [anon_sym_POUNDENDIF] = ACTIONS(5576),
    [anon_sym_POUNDEndif] = ACTIONS(5576),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5576),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2687)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7096),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5576),
    [anon_sym_POUNDENDIF] = ACTIONS(5576),
    [anon_sym_POUNDEndif] = ACTIONS(5576),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5576),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2688)] = {
    [sym__body_element] = STATE(2690),
    [sym_empty_statement] = STATE(2690),
    [sym_property] = STATE(2690),
    [sym_fields_section] = STATE(2690),
    [sym_keys_section] = STATE(2690),
    [sym_fieldgroups_section] = STATE(2690),
    [sym_enum_value_declaration] = STATE(2690),
    [sym_labels_section] = STATE(2690),
    [sym_layout_section] = STATE(2690),
    [sym_modify_modification] = STATE(2690),
    [sym_actions_section] = STATE(2690),
    [sym_views_section] = STATE(2690),
    [sym_dataset_section] = STATE(2690),
    [sym_requestpage_section] = STATE(2690),
    [sym_rendering_section] = STATE(2690),
    [sym_elements_section] = STATE(2690),
    [sym_schema_section] = STATE(2690),
    [sym_assembly_declaration] = STATE(2690),
    [sym_event_declaration] = STATE(2690),
    [sym_procedure] = STATE(2690),
    [sym_preproc_split_procedure] = STATE(2690),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2690),
    [sym_var_section] = STATE(2690),
    [sym_var_attribute_item] = STATE(2690),
    [sym_variable_declaration] = STATE(2690),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2690),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7585),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2690),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5516),
    [anon_sym_POUNDENDIF] = ACTIONS(5516),
    [anon_sym_POUNDEndif] = ACTIONS(5516),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5516),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2689)] = {
    [sym__body_element] = STATE(2711),
    [sym_empty_statement] = STATE(2711),
    [sym_property] = STATE(2711),
    [sym_fields_section] = STATE(2711),
    [sym_keys_section] = STATE(2711),
    [sym_fieldgroups_section] = STATE(2711),
    [sym_enum_value_declaration] = STATE(2711),
    [sym_labels_section] = STATE(2711),
    [sym_layout_section] = STATE(2711),
    [sym_modify_modification] = STATE(2711),
    [sym_actions_section] = STATE(2711),
    [sym_views_section] = STATE(2711),
    [sym_dataset_section] = STATE(2711),
    [sym_requestpage_section] = STATE(2711),
    [sym_rendering_section] = STATE(2711),
    [sym_elements_section] = STATE(2711),
    [sym_schema_section] = STATE(2711),
    [sym_assembly_declaration] = STATE(2711),
    [sym_event_declaration] = STATE(2711),
    [sym_procedure] = STATE(2711),
    [sym_preproc_split_procedure] = STATE(2711),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2711),
    [sym_var_section] = STATE(2711),
    [sym_var_attribute_item] = STATE(2711),
    [sym_variable_declaration] = STATE(2711),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2711),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(3823),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2711),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5562),
    [anon_sym_POUNDENDIF] = ACTIONS(5562),
    [anon_sym_POUNDEndif] = ACTIONS(5562),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5562),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2690)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7627),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5516),
    [anon_sym_POUNDENDIF] = ACTIONS(5516),
    [anon_sym_POUNDEndif] = ACTIONS(5516),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5516),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2691)] = {
    [sym__body_element] = STATE(2692),
    [sym_empty_statement] = STATE(2692),
    [sym_property] = STATE(2692),
    [sym_fields_section] = STATE(2692),
    [sym_keys_section] = STATE(2692),
    [sym_fieldgroups_section] = STATE(2692),
    [sym_enum_value_declaration] = STATE(2692),
    [sym_labels_section] = STATE(2692),
    [sym_layout_section] = STATE(2692),
    [sym_modify_modification] = STATE(2692),
    [sym_actions_section] = STATE(2692),
    [sym_views_section] = STATE(2692),
    [sym_dataset_section] = STATE(2692),
    [sym_requestpage_section] = STATE(2692),
    [sym_rendering_section] = STATE(2692),
    [sym_elements_section] = STATE(2692),
    [sym_schema_section] = STATE(2692),
    [sym_assembly_declaration] = STATE(2692),
    [sym_event_declaration] = STATE(2692),
    [sym_procedure] = STATE(2692),
    [sym_preproc_split_procedure] = STATE(2692),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2692),
    [sym_var_section] = STATE(2692),
    [sym_var_attribute_item] = STATE(2692),
    [sym_variable_declaration] = STATE(2692),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2692),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7627),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2692),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5516),
    [anon_sym_POUNDENDIF] = ACTIONS(5516),
    [anon_sym_POUNDEndif] = ACTIONS(5516),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5516),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2692)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7591),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5516),
    [anon_sym_POUNDENDIF] = ACTIONS(5516),
    [anon_sym_POUNDEndif] = ACTIONS(5516),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5516),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2693)] = {
    [sym__body_element] = STATE(2695),
    [sym_empty_statement] = STATE(2695),
    [sym_property] = STATE(2695),
    [sym_fields_section] = STATE(2695),
    [sym_keys_section] = STATE(2695),
    [sym_fieldgroups_section] = STATE(2695),
    [sym_enum_value_declaration] = STATE(2695),
    [sym_labels_section] = STATE(2695),
    [sym_layout_section] = STATE(2695),
    [sym_modify_modification] = STATE(2695),
    [sym_actions_section] = STATE(2695),
    [sym_views_section] = STATE(2695),
    [sym_dataset_section] = STATE(2695),
    [sym_requestpage_section] = STATE(2695),
    [sym_rendering_section] = STATE(2695),
    [sym_elements_section] = STATE(2695),
    [sym_schema_section] = STATE(2695),
    [sym_assembly_declaration] = STATE(2695),
    [sym_event_declaration] = STATE(2695),
    [sym_procedure] = STATE(2695),
    [sym_preproc_split_procedure] = STATE(2695),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2695),
    [sym_var_section] = STATE(2695),
    [sym_var_attribute_item] = STATE(2695),
    [sym_variable_declaration] = STATE(2695),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2695),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7591),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2695),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5516),
    [anon_sym_POUNDENDIF] = ACTIONS(5516),
    [anon_sym_POUNDEndif] = ACTIONS(5516),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5516),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2694)] = {
    [sym__body_element] = STATE(2696),
    [sym_empty_statement] = STATE(2696),
    [sym_property] = STATE(2696),
    [sym_fields_section] = STATE(2696),
    [sym_keys_section] = STATE(2696),
    [sym_fieldgroups_section] = STATE(2696),
    [sym_enum_value_declaration] = STATE(2696),
    [sym_labels_section] = STATE(2696),
    [sym_layout_section] = STATE(2696),
    [sym_modify_modification] = STATE(2696),
    [sym_actions_section] = STATE(2696),
    [sym_views_section] = STATE(2696),
    [sym_dataset_section] = STATE(2696),
    [sym_requestpage_section] = STATE(2696),
    [sym_rendering_section] = STATE(2696),
    [sym_elements_section] = STATE(2696),
    [sym_schema_section] = STATE(2696),
    [sym_assembly_declaration] = STATE(2696),
    [sym_event_declaration] = STATE(2696),
    [sym_procedure] = STATE(2696),
    [sym_preproc_split_procedure] = STATE(2696),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2696),
    [sym_var_section] = STATE(2696),
    [sym_var_attribute_item] = STATE(2696),
    [sym_variable_declaration] = STATE(2696),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2696),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7489),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2696),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5560),
    [anon_sym_POUNDENDIF] = ACTIONS(5560),
    [anon_sym_POUNDEndif] = ACTIONS(5560),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5560),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2695)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7571),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5516),
    [anon_sym_POUNDENDIF] = ACTIONS(5516),
    [anon_sym_POUNDEndif] = ACTIONS(5516),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5516),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2696)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7513),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5560),
    [anon_sym_POUNDENDIF] = ACTIONS(5560),
    [anon_sym_POUNDEndif] = ACTIONS(5560),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5560),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2697)] = {
    [sym__body_element] = STATE(2698),
    [sym_empty_statement] = STATE(2698),
    [sym_property] = STATE(2698),
    [sym_fields_section] = STATE(2698),
    [sym_keys_section] = STATE(2698),
    [sym_fieldgroups_section] = STATE(2698),
    [sym_enum_value_declaration] = STATE(2698),
    [sym_labels_section] = STATE(2698),
    [sym_layout_section] = STATE(2698),
    [sym_modify_modification] = STATE(2698),
    [sym_actions_section] = STATE(2698),
    [sym_views_section] = STATE(2698),
    [sym_dataset_section] = STATE(2698),
    [sym_requestpage_section] = STATE(2698),
    [sym_rendering_section] = STATE(2698),
    [sym_elements_section] = STATE(2698),
    [sym_schema_section] = STATE(2698),
    [sym_assembly_declaration] = STATE(2698),
    [sym_event_declaration] = STATE(2698),
    [sym_procedure] = STATE(2698),
    [sym_preproc_split_procedure] = STATE(2698),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2698),
    [sym_var_section] = STATE(2698),
    [sym_var_attribute_item] = STATE(2698),
    [sym_variable_declaration] = STATE(2698),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2698),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7513),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2698),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5560),
    [anon_sym_POUNDENDIF] = ACTIONS(5560),
    [anon_sym_POUNDEndif] = ACTIONS(5560),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5560),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2698)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7521),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5560),
    [anon_sym_POUNDENDIF] = ACTIONS(5560),
    [anon_sym_POUNDEndif] = ACTIONS(5560),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5560),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2699)] = {
    [sym__body_element] = STATE(2700),
    [sym_empty_statement] = STATE(2700),
    [sym_property] = STATE(2700),
    [sym_fields_section] = STATE(2700),
    [sym_keys_section] = STATE(2700),
    [sym_fieldgroups_section] = STATE(2700),
    [sym_enum_value_declaration] = STATE(2700),
    [sym_labels_section] = STATE(2700),
    [sym_layout_section] = STATE(2700),
    [sym_modify_modification] = STATE(2700),
    [sym_actions_section] = STATE(2700),
    [sym_views_section] = STATE(2700),
    [sym_dataset_section] = STATE(2700),
    [sym_requestpage_section] = STATE(2700),
    [sym_rendering_section] = STATE(2700),
    [sym_elements_section] = STATE(2700),
    [sym_schema_section] = STATE(2700),
    [sym_assembly_declaration] = STATE(2700),
    [sym_event_declaration] = STATE(2700),
    [sym_procedure] = STATE(2700),
    [sym_preproc_split_procedure] = STATE(2700),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2700),
    [sym_var_section] = STATE(2700),
    [sym_var_attribute_item] = STATE(2700),
    [sym_variable_declaration] = STATE(2700),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2700),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7521),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2700),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5560),
    [anon_sym_POUNDENDIF] = ACTIONS(5560),
    [anon_sym_POUNDEndif] = ACTIONS(5560),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5560),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2700)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7491),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5560),
    [anon_sym_POUNDENDIF] = ACTIONS(5560),
    [anon_sym_POUNDEndif] = ACTIONS(5560),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5560),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2701)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(3095),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5568),
    [anon_sym_POUNDENDIF] = ACTIONS(5568),
    [anon_sym_POUNDEndif] = ACTIONS(5568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5568),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2702)] = {
    [sym__body_element] = STATE(2703),
    [sym_empty_statement] = STATE(2703),
    [sym_property] = STATE(2703),
    [sym_fields_section] = STATE(2703),
    [sym_keys_section] = STATE(2703),
    [sym_fieldgroups_section] = STATE(2703),
    [sym_enum_value_declaration] = STATE(2703),
    [sym_labels_section] = STATE(2703),
    [sym_layout_section] = STATE(2703),
    [sym_modify_modification] = STATE(2703),
    [sym_actions_section] = STATE(2703),
    [sym_views_section] = STATE(2703),
    [sym_dataset_section] = STATE(2703),
    [sym_requestpage_section] = STATE(2703),
    [sym_rendering_section] = STATE(2703),
    [sym_elements_section] = STATE(2703),
    [sym_schema_section] = STATE(2703),
    [sym_assembly_declaration] = STATE(2703),
    [sym_event_declaration] = STATE(2703),
    [sym_procedure] = STATE(2703),
    [sym_preproc_split_procedure] = STATE(2703),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2703),
    [sym_var_section] = STATE(2703),
    [sym_var_attribute_item] = STATE(2703),
    [sym_variable_declaration] = STATE(2703),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2703),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(4981),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2703),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5574),
    [anon_sym_POUNDENDIF] = ACTIONS(5574),
    [anon_sym_POUNDEndif] = ACTIONS(5574),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5574),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2703)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(4998),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5574),
    [anon_sym_POUNDENDIF] = ACTIONS(5574),
    [anon_sym_POUNDEndif] = ACTIONS(5574),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5574),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2704)] = {
    [sym__body_element] = STATE(2705),
    [sym_empty_statement] = STATE(2705),
    [sym_property] = STATE(2705),
    [sym_fields_section] = STATE(2705),
    [sym_keys_section] = STATE(2705),
    [sym_fieldgroups_section] = STATE(2705),
    [sym_enum_value_declaration] = STATE(2705),
    [sym_labels_section] = STATE(2705),
    [sym_layout_section] = STATE(2705),
    [sym_modify_modification] = STATE(2705),
    [sym_actions_section] = STATE(2705),
    [sym_views_section] = STATE(2705),
    [sym_dataset_section] = STATE(2705),
    [sym_requestpage_section] = STATE(2705),
    [sym_rendering_section] = STATE(2705),
    [sym_elements_section] = STATE(2705),
    [sym_schema_section] = STATE(2705),
    [sym_assembly_declaration] = STATE(2705),
    [sym_event_declaration] = STATE(2705),
    [sym_procedure] = STATE(2705),
    [sym_preproc_split_procedure] = STATE(2705),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2705),
    [sym_var_section] = STATE(2705),
    [sym_var_attribute_item] = STATE(2705),
    [sym_variable_declaration] = STATE(2705),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2705),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(4998),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2705),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5574),
    [anon_sym_POUNDENDIF] = ACTIONS(5574),
    [anon_sym_POUNDEndif] = ACTIONS(5574),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5574),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2705)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(5000),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5574),
    [anon_sym_POUNDENDIF] = ACTIONS(5574),
    [anon_sym_POUNDEndif] = ACTIONS(5574),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5574),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2706)] = {
    [sym__body_element] = STATE(2707),
    [sym_empty_statement] = STATE(2707),
    [sym_property] = STATE(2707),
    [sym_fields_section] = STATE(2707),
    [sym_keys_section] = STATE(2707),
    [sym_fieldgroups_section] = STATE(2707),
    [sym_enum_value_declaration] = STATE(2707),
    [sym_labels_section] = STATE(2707),
    [sym_layout_section] = STATE(2707),
    [sym_modify_modification] = STATE(2707),
    [sym_actions_section] = STATE(2707),
    [sym_views_section] = STATE(2707),
    [sym_dataset_section] = STATE(2707),
    [sym_requestpage_section] = STATE(2707),
    [sym_rendering_section] = STATE(2707),
    [sym_elements_section] = STATE(2707),
    [sym_schema_section] = STATE(2707),
    [sym_assembly_declaration] = STATE(2707),
    [sym_event_declaration] = STATE(2707),
    [sym_procedure] = STATE(2707),
    [sym_preproc_split_procedure] = STATE(2707),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2707),
    [sym_var_section] = STATE(2707),
    [sym_var_attribute_item] = STATE(2707),
    [sym_variable_declaration] = STATE(2707),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2707),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(5000),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2707),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5574),
    [anon_sym_POUNDENDIF] = ACTIONS(5574),
    [anon_sym_POUNDEndif] = ACTIONS(5574),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5574),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2707)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(5004),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5574),
    [anon_sym_POUNDENDIF] = ACTIONS(5574),
    [anon_sym_POUNDEndif] = ACTIONS(5574),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5574),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2708)] = {
    [sym__body_element] = STATE(2709),
    [sym_empty_statement] = STATE(2709),
    [sym_property] = STATE(2709),
    [sym_fields_section] = STATE(2709),
    [sym_keys_section] = STATE(2709),
    [sym_fieldgroups_section] = STATE(2709),
    [sym_enum_value_declaration] = STATE(2709),
    [sym_labels_section] = STATE(2709),
    [sym_layout_section] = STATE(2709),
    [sym_modify_modification] = STATE(2709),
    [sym_actions_section] = STATE(2709),
    [sym_views_section] = STATE(2709),
    [sym_dataset_section] = STATE(2709),
    [sym_requestpage_section] = STATE(2709),
    [sym_rendering_section] = STATE(2709),
    [sym_elements_section] = STATE(2709),
    [sym_schema_section] = STATE(2709),
    [sym_assembly_declaration] = STATE(2709),
    [sym_event_declaration] = STATE(2709),
    [sym_procedure] = STATE(2709),
    [sym_preproc_split_procedure] = STATE(2709),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2709),
    [sym_var_section] = STATE(2709),
    [sym_var_attribute_item] = STATE(2709),
    [sym_variable_declaration] = STATE(2709),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2709),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(5471),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2709),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5570),
    [anon_sym_POUNDENDIF] = ACTIONS(5570),
    [anon_sym_POUNDEndif] = ACTIONS(5570),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5570),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2709)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(5491),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5570),
    [anon_sym_POUNDENDIF] = ACTIONS(5570),
    [anon_sym_POUNDEndif] = ACTIONS(5570),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5570),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2710)] = {
    [sym__body_element] = STATE(2666),
    [sym_empty_statement] = STATE(2666),
    [sym_property] = STATE(2666),
    [sym_fields_section] = STATE(2666),
    [sym_keys_section] = STATE(2666),
    [sym_fieldgroups_section] = STATE(2666),
    [sym_enum_value_declaration] = STATE(2666),
    [sym_labels_section] = STATE(2666),
    [sym_layout_section] = STATE(2666),
    [sym_modify_modification] = STATE(2666),
    [sym_actions_section] = STATE(2666),
    [sym_views_section] = STATE(2666),
    [sym_dataset_section] = STATE(2666),
    [sym_requestpage_section] = STATE(2666),
    [sym_rendering_section] = STATE(2666),
    [sym_elements_section] = STATE(2666),
    [sym_schema_section] = STATE(2666),
    [sym_assembly_declaration] = STATE(2666),
    [sym_event_declaration] = STATE(2666),
    [sym_procedure] = STATE(2666),
    [sym_preproc_split_procedure] = STATE(2666),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2666),
    [sym_var_section] = STATE(2666),
    [sym_var_attribute_item] = STATE(2666),
    [sym_variable_declaration] = STATE(2666),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2666),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(5491),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2666),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5570),
    [anon_sym_POUNDENDIF] = ACTIONS(5570),
    [anon_sym_POUNDEndif] = ACTIONS(5570),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5570),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2711)] = {
    [sym__body_element] = STATE(2573),
    [sym_empty_statement] = STATE(2573),
    [sym_property] = STATE(2573),
    [sym_fields_section] = STATE(2573),
    [sym_keys_section] = STATE(2573),
    [sym_fieldgroups_section] = STATE(2573),
    [sym_enum_value_declaration] = STATE(2573),
    [sym_labels_section] = STATE(2573),
    [sym_layout_section] = STATE(2573),
    [sym_modify_modification] = STATE(2573),
    [sym_actions_section] = STATE(2573),
    [sym_views_section] = STATE(2573),
    [sym_dataset_section] = STATE(2573),
    [sym_requestpage_section] = STATE(2573),
    [sym_rendering_section] = STATE(2573),
    [sym_elements_section] = STATE(2573),
    [sym_schema_section] = STATE(2573),
    [sym_assembly_declaration] = STATE(2573),
    [sym_event_declaration] = STATE(2573),
    [sym_procedure] = STATE(2573),
    [sym_preproc_split_procedure] = STATE(2573),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2573),
    [sym_var_section] = STATE(2573),
    [sym_var_attribute_item] = STATE(2573),
    [sym_variable_declaration] = STATE(2573),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2573),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(3798),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2573),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5562),
    [anon_sym_POUNDENDIF] = ACTIONS(5562),
    [anon_sym_POUNDEndif] = ACTIONS(5562),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5562),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2712)] = {
    [sym__body_element] = STATE(2676),
    [sym_empty_statement] = STATE(2676),
    [sym_property] = STATE(2676),
    [sym_fields_section] = STATE(2676),
    [sym_keys_section] = STATE(2676),
    [sym_fieldgroups_section] = STATE(2676),
    [sym_enum_value_declaration] = STATE(2676),
    [sym_labels_section] = STATE(2676),
    [sym_layout_section] = STATE(2676),
    [sym_modify_modification] = STATE(2676),
    [sym_actions_section] = STATE(2676),
    [sym_views_section] = STATE(2676),
    [sym_dataset_section] = STATE(2676),
    [sym_requestpage_section] = STATE(2676),
    [sym_rendering_section] = STATE(2676),
    [sym_elements_section] = STATE(2676),
    [sym_schema_section] = STATE(2676),
    [sym_assembly_declaration] = STATE(2676),
    [sym_event_declaration] = STATE(2676),
    [sym_procedure] = STATE(2676),
    [sym_preproc_split_procedure] = STATE(2676),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2676),
    [sym_var_section] = STATE(2676),
    [sym_var_attribute_item] = STATE(2676),
    [sym_variable_declaration] = STATE(2676),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2676),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(3798),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2676),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5562),
    [anon_sym_POUNDENDIF] = ACTIONS(5562),
    [anon_sym_POUNDEndif] = ACTIONS(5562),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5562),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2713)] = {
    [sym__body_element] = STATE(2713),
    [sym_empty_statement] = STATE(2713),
    [sym_property] = STATE(2713),
    [sym_fields_section] = STATE(2713),
    [sym_keys_section] = STATE(2713),
    [sym_fieldgroups_section] = STATE(2713),
    [sym_enum_value_declaration] = STATE(2713),
    [sym_labels_section] = STATE(2713),
    [sym_layout_section] = STATE(2713),
    [sym_modify_modification] = STATE(2713),
    [sym_actions_section] = STATE(2713),
    [sym_views_section] = STATE(2713),
    [sym_dataset_section] = STATE(2713),
    [sym_requestpage_section] = STATE(2713),
    [sym_rendering_section] = STATE(2713),
    [sym_elements_section] = STATE(2713),
    [sym_query_dataitem] = STATE(2713),
    [sym__query_body_element] = STATE(2713),
    [sym_preproc_conditional_query] = STATE(2713),
    [sym_query_column] = STATE(2713),
    [sym_query_filter] = STATE(2713),
    [sym_schema_section] = STATE(2713),
    [sym_assembly_declaration] = STATE(2713),
    [sym_event_declaration] = STATE(2713),
    [sym_procedure] = STATE(2713),
    [sym_preproc_split_procedure] = STATE(2713),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2713),
    [sym_var_section] = STATE(2713),
    [sym_attribute_item] = STATE(2713),
    [sym_preproc_conditional] = STATE(2713),
    [sym_preproc_if] = STATE(2494),
    [aux_sym_query_dataitem_repeat1] = STATE(2713),
    [anon_sym_SEMI] = ACTIONS(6378),
    [anon_sym_LBRACK] = ACTIONS(6381),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6384),
    [aux_sym_modify_modification_token1] = ACTIONS(6387),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6390),
    [anon_sym_POUNDif] = ACTIONS(6393),
    [anon_sym_POUNDIF] = ACTIONS(6393),
    [anon_sym_POUNDIf] = ACTIONS(6393),
    [anon_sym_POUNDelif] = ACTIONS(6396),
    [anon_sym_POUNDELIF] = ACTIONS(6396),
    [anon_sym_POUNDElif] = ACTIONS(6396),
    [anon_sym_POUNDelse] = ACTIONS(6396),
    [anon_sym_POUNDELSE] = ACTIONS(6396),
    [anon_sym_POUNDElse] = ACTIONS(6396),
    [anon_sym_POUNDendif] = ACTIONS(6396),
    [anon_sym_POUNDENDIF] = ACTIONS(6396),
    [anon_sym_POUNDEndif] = ACTIONS(6396),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6398),
    [sym_trigger_keyword] = ACTIONS(6401),
    [sym_var_keyword] = ACTIONS(6404),
    [sym_local_keyword] = ACTIONS(6407),
    [sym_internal_keyword] = ACTIONS(6410),
    [sym_protected_keyword] = ACTIONS(6407),
    [sym_event_keyword] = ACTIONS(6413),
    [sym_fields_keyword] = ACTIONS(6416),
    [sym_keys_keyword] = ACTIONS(6419),
    [sym_fieldgroups_keyword] = ACTIONS(6422),
    [sym_actions_keyword] = ACTIONS(6425),
    [sym_layout_keyword] = ACTIONS(6428),
    [sym_dataset_keyword] = ACTIONS(6431),
    [sym_elements_keyword] = ACTIONS(6434),
    [sym_dataitem_keyword] = ACTIONS(6437),
    [sym_column_keyword] = ACTIONS(6440),
    [sym_filter_keyword] = ACTIONS(6443),
    [sym_labels_keyword] = ACTIONS(6446),
    [sym_rendering_keyword] = ACTIONS(6449),
    [sym_requestpage_keyword] = ACTIONS(6452),
    [sym_schema_keyword] = ACTIONS(6455),
    [sym_views_keyword] = ACTIONS(6458),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6461),
    [sym_preproc_open] = ACTIONS(6393),
    [sym_preproc_close] = ACTIONS(6396),
  },
  [STATE(2714)] = {
    [sym__body_element] = STATE(2713),
    [sym_empty_statement] = STATE(2713),
    [sym_property] = STATE(2713),
    [sym_fields_section] = STATE(2713),
    [sym_keys_section] = STATE(2713),
    [sym_fieldgroups_section] = STATE(2713),
    [sym_enum_value_declaration] = STATE(2713),
    [sym_labels_section] = STATE(2713),
    [sym_layout_section] = STATE(2713),
    [sym_modify_modification] = STATE(2713),
    [sym_actions_section] = STATE(2713),
    [sym_views_section] = STATE(2713),
    [sym_dataset_section] = STATE(2713),
    [sym_requestpage_section] = STATE(2713),
    [sym_rendering_section] = STATE(2713),
    [sym_elements_section] = STATE(2713),
    [sym_query_dataitem] = STATE(2713),
    [sym__query_body_element] = STATE(2713),
    [sym_preproc_conditional_query] = STATE(2713),
    [sym_query_column] = STATE(2713),
    [sym_query_filter] = STATE(2713),
    [sym_schema_section] = STATE(2713),
    [sym_assembly_declaration] = STATE(2713),
    [sym_event_declaration] = STATE(2713),
    [sym_procedure] = STATE(2713),
    [sym_preproc_split_procedure] = STATE(2713),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2713),
    [sym_var_section] = STATE(2713),
    [sym_attribute_item] = STATE(2713),
    [sym_preproc_conditional] = STATE(2713),
    [sym_preproc_if] = STATE(2494),
    [aux_sym_query_dataitem_repeat1] = STATE(2713),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(6464),
    [anon_sym_POUNDELIF] = ACTIONS(6464),
    [anon_sym_POUNDElif] = ACTIONS(6464),
    [anon_sym_POUNDelse] = ACTIONS(6464),
    [anon_sym_POUNDELSE] = ACTIONS(6464),
    [anon_sym_POUNDElse] = ACTIONS(6464),
    [anon_sym_POUNDendif] = ACTIONS(6464),
    [anon_sym_POUNDENDIF] = ACTIONS(6464),
    [anon_sym_POUNDEndif] = ACTIONS(6464),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(6464),
  },
  [STATE(2715)] = {
    [sym__body_element] = STATE(2675),
    [sym_empty_statement] = STATE(2675),
    [sym_property] = STATE(2675),
    [sym_fields_section] = STATE(2675),
    [sym_keys_section] = STATE(2675),
    [sym_fieldgroups_section] = STATE(2675),
    [sym_enum_value_declaration] = STATE(2675),
    [sym_labels_section] = STATE(2675),
    [sym_layout_section] = STATE(2675),
    [sym_modify_modification] = STATE(2675),
    [sym_actions_section] = STATE(2675),
    [sym_views_section] = STATE(2675),
    [sym_dataset_section] = STATE(2675),
    [sym_requestpage_section] = STATE(2675),
    [sym_rendering_section] = STATE(2675),
    [sym_elements_section] = STATE(2675),
    [sym_schema_section] = STATE(2675),
    [sym_assembly_declaration] = STATE(2675),
    [sym_event_declaration] = STATE(2675),
    [sym_procedure] = STATE(2675),
    [sym_preproc_split_procedure] = STATE(2675),
    [sym_procedure_modifier] = STATE(12339),
    [sym_trigger_declaration] = STATE(2675),
    [sym_var_section] = STATE(2675),
    [sym_var_attribute_item] = STATE(2675),
    [sym_variable_declaration] = STATE(2675),
    [sym_attribute_item] = STATE(5378),
    [sym_preproc_conditional] = STATE(2675),
    [sym_preproc_if] = STATE(2722),
    [sym_preproc_endif] = STATE(7061),
    [sym__identifier_or_quoted] = STATE(10763),
    [sym_keyword_as_identifier] = STATE(10763),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(2675),
    [sym_identifier] = ACTIONS(5500),
    [anon_sym_SEMI] = ACTIONS(5502),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5506),
    [aux_sym_modify_modification_token1] = ACTIONS(5508),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5510),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5576),
    [anon_sym_POUNDENDIF] = ACTIONS(5576),
    [anon_sym_POUNDEndif] = ACTIONS(5576),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5867),
    [sym_trigger_keyword] = ACTIONS(5520),
    [sym_var_keyword] = ACTIONS(5522),
    [sym_local_keyword] = ACTIONS(5524),
    [sym_internal_keyword] = ACTIONS(5526),
    [sym_protected_keyword] = ACTIONS(5524),
    [sym_event_keyword] = ACTIONS(5528),
    [sym_fields_keyword] = ACTIONS(5530),
    [sym_keys_keyword] = ACTIONS(5532),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(5534),
    [sym_actions_keyword] = ACTIONS(5536),
    [sym_layout_keyword] = ACTIONS(5538),
    [sym_dataset_keyword] = ACTIONS(5540),
    [sym_elements_keyword] = ACTIONS(5542),
    [sym_labels_keyword] = ACTIONS(5544),
    [sym_rendering_keyword] = ACTIONS(5546),
    [sym_requestpage_keyword] = ACTIONS(5548),
    [sym_schema_keyword] = ACTIONS(5550),
    [sym_views_keyword] = ACTIONS(5552),
    [sym_quoted_identifier] = ACTIONS(5554),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5556),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5576),
    [sym_var_attribute_open] = ACTIONS(5558),
  },
  [STATE(2716)] = {
    [aux_sym_option_member_list_repeat2] = STATE(2716),
    [sym_identifier] = ACTIONS(565),
    [anon_sym_SEMI] = ACTIONS(567),
    [anon_sym_RBRACE] = ACTIONS(567),
    [anon_sym_COMMA] = ACTIONS(6466),
    [anon_sym_DASH] = ACTIONS(567),
    [aux_sym_boolean_token1] = ACTIONS(565),
    [aux_sym_boolean_token2] = ACTIONS(565),
    [aux_sym_where_condition_token1] = ACTIONS(565),
    [aux_sym_tabledata_permission_token2] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [aux_sym_record_type_token1] = ACTIONS(565),
    [aux_sym_basic_type_token21] = ACTIONS(565),
    [aux_sym_basic_type_token22] = ACTIONS(565),
    [aux_sym_basic_type_token48] = ACTIONS(565),
    [aux_sym_basic_type_token53] = ACTIONS(565),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(565),
    [aux_sym_modify_modification_token1] = ACTIONS(565),
    [aux_sym_separator_action_token1] = ACTIONS(565),
    [aux_sym_assembly_declaration_token1] = ACTIONS(565),
    [aux_sym_type_declaration_token1] = ACTIONS(565),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(565),
    [anon_sym_POUNDif] = ACTIONS(567),
    [anon_sym_POUNDIF] = ACTIONS(567),
    [anon_sym_POUNDIf] = ACTIONS(567),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(565),
    [sym_page_keyword] = ACTIONS(565),
    [anon_sym_codeunit] = ACTIONS(565),
    [anon_sym_CODEUNIT] = ACTIONS(565),
    [anon_sym_Codeunit] = ACTIONS(565),
    [anon_sym_CodeUnit] = ACTIONS(565),
    [anon_sym_COdeunit] = ACTIONS(565),
    [anon_sym_codeUnit] = ACTIONS(565),
    [sym_report_keyword] = ACTIONS(565),
    [sym_query_keyword] = ACTIONS(565),
    [anon_sym_xmlport] = ACTIONS(565),
    [anon_sym_XMLPORT] = ACTIONS(565),
    [anon_sym_Xmlport] = ACTIONS(565),
    [anon_sym_XMLport] = ACTIONS(565),
    [anon_sym_XMLPort] = ACTIONS(565),
    [anon_sym_XmlPort] = ACTIONS(565),
    [anon_sym_enum] = ACTIONS(565),
    [anon_sym_ENUM] = ACTIONS(565),
    [anon_sym_Enum] = ACTIONS(565),
    [anon_sym_eNUM] = ACTIONS(565),
    [anon_sym_eNum] = ACTIONS(565),
    [anon_sym_ENum] = ACTIONS(565),
    [sym_procedure_keyword] = ACTIONS(565),
    [sym_trigger_keyword] = ACTIONS(565),
    [sym_var_keyword] = ACTIONS(565),
    [sym_local_keyword] = ACTIONS(565),
    [sym_internal_keyword] = ACTIONS(565),
    [sym_protected_keyword] = ACTIONS(565),
    [sym_event_keyword] = ACTIONS(565),
    [sym_fields_keyword] = ACTIONS(565),
    [sym_keys_keyword] = ACTIONS(565),
    [sym_key_keyword] = ACTIONS(565),
    [sym_fieldgroups_keyword] = ACTIONS(565),
    [sym_actions_keyword] = ACTIONS(565),
    [sym_layout_keyword] = ACTIONS(565),
    [sym_dataset_keyword] = ACTIONS(565),
    [sym_elements_keyword] = ACTIONS(565),
    [sym_labels_keyword] = ACTIONS(565),
    [sym_rendering_keyword] = ACTIONS(565),
    [sym_requestpage_keyword] = ACTIONS(565),
    [sym_schema_keyword] = ACTIONS(565),
    [sym_views_keyword] = ACTIONS(565),
    [sym_quoted_identifier] = ACTIONS(567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(567),
    [sym_integer] = ACTIONS(567),
    [sym_property_name] = ACTIONS(567),
    [sym_preproc_open] = ACTIONS(567),
    [sym_begin_keyword] = ACTIONS(567),
  },
  [STATE(2717)] = {
    [sym__body_element] = STATE(6090),
    [sym_empty_statement] = STATE(6090),
    [sym_property] = STATE(6090),
    [sym_fields_section] = STATE(6090),
    [sym_keys_section] = STATE(6090),
    [sym_fieldgroups_section] = STATE(6090),
    [sym_enum_value_declaration] = STATE(6090),
    [sym_labels_section] = STATE(6090),
    [sym_layout_section] = STATE(6090),
    [sym_modify_modification] = STATE(6090),
    [sym_actions_section] = STATE(6090),
    [sym_views_section] = STATE(6090),
    [sym_dataset_section] = STATE(6090),
    [sym_report_dataitem] = STATE(2731),
    [sym__report_body_element] = STATE(2731),
    [sym_preproc_conditional_report] = STATE(2731),
    [sym_report_column] = STATE(2731),
    [sym_requestpage_section] = STATE(6090),
    [sym_rendering_section] = STATE(6090),
    [sym_elements_section] = STATE(6090),
    [sym_schema_section] = STATE(6090),
    [sym_assembly_declaration] = STATE(6090),
    [sym_event_declaration] = STATE(6090),
    [sym_procedure] = STATE(6090),
    [sym_preproc_split_procedure] = STATE(6090),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(6090),
    [sym_var_section] = STATE(6090),
    [sym_attribute_item] = STATE(6090),
    [sym_preproc_conditional] = STATE(6090),
    [sym_preproc_if] = STATE(2557),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3335),
    [aux_sym_report_dataitem_repeat1] = STATE(2731),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(6469),
    [anon_sym_POUNDELIF] = ACTIONS(6469),
    [anon_sym_POUNDElif] = ACTIONS(6469),
    [anon_sym_POUNDelse] = ACTIONS(6469),
    [anon_sym_POUNDELSE] = ACTIONS(6469),
    [anon_sym_POUNDElse] = ACTIONS(6469),
    [anon_sym_POUNDendif] = ACTIONS(6469),
    [anon_sym_POUNDENDIF] = ACTIONS(6469),
    [anon_sym_POUNDEndif] = ACTIONS(6469),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(6469),
  },
  [STATE(2718)] = {
    [sym_boolean] = STATE(6283),
    [sym__expression_statement] = STATE(11961),
    [sym_assignment_expression] = STATE(6283),
    [sym__expression] = STATE(6283),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6283),
    [sym_multiplicative_expression] = STATE(6283),
    [sym_additive_expression] = STATE(6283),
    [sym_comparison_expression] = STATE(6283),
    [sym_logical_expression] = STATE(6283),
    [sym_ternary_expression] = STATE(6283),
    [sym_unary_expression] = STATE(6283),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6283),
    [sym_list_literal] = STATE(6283),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6283),
    [sym__literal_value] = STATE(6283),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [aux_sym__preproc_guard_block_repeat1] = STATE(2718),
    [sym_identifier] = ACTIONS(6472),
    [anon_sym_DASH] = ACTIONS(6475),
    [aux_sym_boolean_token1] = ACTIONS(6478),
    [aux_sym_boolean_token2] = ACTIONS(6478),
    [sym_decimal] = ACTIONS(6481),
    [anon_sym_LPAREN] = ACTIONS(6484),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6487),
    [anon_sym_LBRACK] = ACTIONS(6490),
    [aux_sym_record_type_token1] = ACTIONS(6487),
    [aux_sym_basic_type_token21] = ACTIONS(6487),
    [aux_sym_basic_type_token22] = ACTIONS(6487),
    [aux_sym_basic_type_token48] = ACTIONS(6487),
    [anon_sym_not] = ACTIONS(6493),
    [anon_sym_NOT] = ACTIONS(6493),
    [anon_sym_Not] = ACTIONS(6493),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6487),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6496),
    [anon_sym_PLUS] = ACTIONS(6475),
    [sym_datetime_literal] = ACTIONS(6499),
    [sym_date_literal] = ACTIONS(6481),
    [sym_time_literal] = ACTIONS(6481),
    [sym_biginteger_literal] = ACTIONS(6499),
    [anon_sym_if] = ACTIONS(6502),
    [anon_sym_IF] = ACTIONS(6502),
    [anon_sym_If] = ACTIONS(6502),
    [sym_page_keyword] = ACTIONS(6496),
    [anon_sym_codeunit] = ACTIONS(6504),
    [anon_sym_CODEUNIT] = ACTIONS(6504),
    [anon_sym_Codeunit] = ACTIONS(6504),
    [anon_sym_CodeUnit] = ACTIONS(6504),
    [anon_sym_COdeunit] = ACTIONS(6504),
    [anon_sym_codeUnit] = ACTIONS(6504),
    [sym_report_keyword] = ACTIONS(6496),
    [sym_query_keyword] = ACTIONS(6496),
    [anon_sym_xmlport] = ACTIONS(6507),
    [anon_sym_XMLPORT] = ACTIONS(6507),
    [anon_sym_Xmlport] = ACTIONS(6507),
    [anon_sym_XMLport] = ACTIONS(6507),
    [anon_sym_XMLPort] = ACTIONS(6507),
    [anon_sym_XmlPort] = ACTIONS(6507),
    [anon_sym_enum] = ACTIONS(6510),
    [anon_sym_ENUM] = ACTIONS(6510),
    [anon_sym_Enum] = ACTIONS(6510),
    [anon_sym_eNUM] = ACTIONS(6510),
    [anon_sym_eNum] = ACTIONS(6510),
    [anon_sym_ENum] = ACTIONS(6510),
    [sym_quoted_identifier] = ACTIONS(6513),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6499),
    [sym_integer] = ACTIONS(6481),
    [sym_continue_as_identifier] = ACTIONS(6499),
  },
  [STATE(2719)] = {
    [sym_boolean] = STATE(2555),
    [sym_filter_value] = STATE(12202),
    [sym_assignment_expression] = STATE(6345),
    [sym__expression] = STATE(6345),
    [sym_keyword_identifier] = STATE(2526),
    [sym_range_expression] = STATE(6345),
    [sym_multiplicative_expression] = STATE(6345),
    [sym_additive_expression] = STATE(6345),
    [sym_comparison_expression] = STATE(6345),
    [sym_logical_expression] = STATE(6345),
    [sym_ternary_expression] = STATE(6345),
    [sym_unary_expression] = STATE(6345),
    [sym_call_expression] = STATE(6372),
    [sym_member_expression] = STATE(6325),
    [sym_subscript_expression] = STATE(6325),
    [sym_parenthesized_expression] = STATE(6345),
    [sym_list_literal] = STATE(6345),
    [sym_qualified_enum_value] = STATE(2526),
    [sym_database_reference] = STATE(2559),
    [sym__literal_value] = STATE(6345),
    [sym_codeunit_keyword] = STATE(2547),
    [sym_xmlport_keyword] = STATE(2547),
    [sym_enum_keyword] = STATE(2546),
    [aux_sym_filter_value_repeat1] = STATE(2727),
    [sym_identifier] = ACTIONS(6516),
    [anon_sym_DASH] = ACTIONS(6518),
    [aux_sym_boolean_token1] = ACTIONS(6520),
    [aux_sym_boolean_token2] = ACTIONS(6520),
    [sym_decimal] = ACTIONS(6522),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_DOT_DOT] = ACTIONS(6524),
    [aux_sym_filter_value_token1] = ACTIONS(6524),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6526),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(6526),
    [aux_sym_basic_type_token21] = ACTIONS(6526),
    [aux_sym_basic_type_token22] = ACTIONS(6526),
    [aux_sym_basic_type_token48] = ACTIONS(6526),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6526),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6528),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6530),
    [sym_date_literal] = ACTIONS(6522),
    [sym_time_literal] = ACTIONS(6522),
    [sym_biginteger_literal] = ACTIONS(6530),
    [sym_page_keyword] = ACTIONS(6528),
    [anon_sym_codeunit] = ACTIONS(6532),
    [anon_sym_CODEUNIT] = ACTIONS(6532),
    [anon_sym_Codeunit] = ACTIONS(6532),
    [anon_sym_CodeUnit] = ACTIONS(6532),
    [anon_sym_COdeunit] = ACTIONS(6532),
    [anon_sym_codeUnit] = ACTIONS(6532),
    [sym_report_keyword] = ACTIONS(6528),
    [sym_query_keyword] = ACTIONS(6528),
    [anon_sym_xmlport] = ACTIONS(6534),
    [anon_sym_XMLPORT] = ACTIONS(6534),
    [anon_sym_Xmlport] = ACTIONS(6534),
    [anon_sym_XMLport] = ACTIONS(6534),
    [anon_sym_XMLPort] = ACTIONS(6534),
    [anon_sym_XmlPort] = ACTIONS(6534),
    [anon_sym_enum] = ACTIONS(6536),
    [anon_sym_ENUM] = ACTIONS(6536),
    [anon_sym_Enum] = ACTIONS(6536),
    [anon_sym_eNUM] = ACTIONS(6536),
    [anon_sym_eNum] = ACTIONS(6536),
    [anon_sym_ENum] = ACTIONS(6536),
    [sym_quoted_identifier] = ACTIONS(6538),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6530),
    [sym_integer] = ACTIONS(6522),
    [sym_continue_as_identifier] = ACTIONS(5457),
  },
  [STATE(2720)] = {
    [sym_boolean] = STATE(2555),
    [sym_filter_value] = STATE(11923),
    [sym_assignment_expression] = STATE(6345),
    [sym__expression] = STATE(6345),
    [sym_keyword_identifier] = STATE(2526),
    [sym_range_expression] = STATE(6345),
    [sym_multiplicative_expression] = STATE(6345),
    [sym_additive_expression] = STATE(6345),
    [sym_comparison_expression] = STATE(6345),
    [sym_logical_expression] = STATE(6345),
    [sym_ternary_expression] = STATE(6345),
    [sym_unary_expression] = STATE(6345),
    [sym_call_expression] = STATE(6372),
    [sym_member_expression] = STATE(6325),
    [sym_subscript_expression] = STATE(6325),
    [sym_parenthesized_expression] = STATE(6345),
    [sym_list_literal] = STATE(6345),
    [sym_qualified_enum_value] = STATE(2526),
    [sym_database_reference] = STATE(2559),
    [sym__literal_value] = STATE(6345),
    [sym_codeunit_keyword] = STATE(2547),
    [sym_xmlport_keyword] = STATE(2547),
    [sym_enum_keyword] = STATE(2546),
    [aux_sym_filter_value_repeat1] = STATE(2727),
    [sym_identifier] = ACTIONS(6516),
    [anon_sym_DASH] = ACTIONS(6518),
    [aux_sym_boolean_token1] = ACTIONS(6520),
    [aux_sym_boolean_token2] = ACTIONS(6520),
    [sym_decimal] = ACTIONS(6522),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_DOT_DOT] = ACTIONS(6524),
    [aux_sym_filter_value_token1] = ACTIONS(6524),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6526),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(6526),
    [aux_sym_basic_type_token21] = ACTIONS(6526),
    [aux_sym_basic_type_token22] = ACTIONS(6526),
    [aux_sym_basic_type_token48] = ACTIONS(6526),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6526),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6528),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6530),
    [sym_date_literal] = ACTIONS(6522),
    [sym_time_literal] = ACTIONS(6522),
    [sym_biginteger_literal] = ACTIONS(6530),
    [sym_page_keyword] = ACTIONS(6528),
    [anon_sym_codeunit] = ACTIONS(6532),
    [anon_sym_CODEUNIT] = ACTIONS(6532),
    [anon_sym_Codeunit] = ACTIONS(6532),
    [anon_sym_CodeUnit] = ACTIONS(6532),
    [anon_sym_COdeunit] = ACTIONS(6532),
    [anon_sym_codeUnit] = ACTIONS(6532),
    [sym_report_keyword] = ACTIONS(6528),
    [sym_query_keyword] = ACTIONS(6528),
    [anon_sym_xmlport] = ACTIONS(6534),
    [anon_sym_XMLPORT] = ACTIONS(6534),
    [anon_sym_Xmlport] = ACTIONS(6534),
    [anon_sym_XMLport] = ACTIONS(6534),
    [anon_sym_XMLPort] = ACTIONS(6534),
    [anon_sym_XmlPort] = ACTIONS(6534),
    [anon_sym_enum] = ACTIONS(6536),
    [anon_sym_ENUM] = ACTIONS(6536),
    [anon_sym_Enum] = ACTIONS(6536),
    [anon_sym_eNUM] = ACTIONS(6536),
    [anon_sym_eNum] = ACTIONS(6536),
    [anon_sym_ENum] = ACTIONS(6536),
    [sym_quoted_identifier] = ACTIONS(6538),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6530),
    [sym_integer] = ACTIONS(6522),
    [sym_continue_as_identifier] = ACTIONS(5457),
  },
  [STATE(2721)] = {
    [sym_preproc_conditional_controladdin] = STATE(2885),
    [sym__body_element] = STATE(2885),
    [sym_empty_statement] = STATE(2885),
    [sym_property] = STATE(2885),
    [sym_fields_section] = STATE(2885),
    [sym_keys_section] = STATE(2885),
    [sym_fieldgroups_section] = STATE(2885),
    [sym_enum_value_declaration] = STATE(2885),
    [sym_labels_section] = STATE(2885),
    [sym_layout_section] = STATE(2885),
    [sym_modify_modification] = STATE(2885),
    [sym_actions_section] = STATE(2885),
    [sym_views_section] = STATE(2885),
    [sym_dataset_section] = STATE(2885),
    [sym_requestpage_section] = STATE(2885),
    [sym_rendering_section] = STATE(2885),
    [sym_elements_section] = STATE(2885),
    [sym_schema_section] = STATE(2885),
    [sym_assembly_declaration] = STATE(2885),
    [sym_event_declaration] = STATE(2885),
    [sym_procedure] = STATE(2885),
    [sym_preproc_split_procedure] = STATE(2885),
    [sym_interface_procedure] = STATE(2885),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2885),
    [sym_var_section] = STATE(2885),
    [sym_attribute_item] = STATE(2885),
    [sym_preproc_conditional] = STATE(2885),
    [sym_preproc_if] = STATE(2635),
    [sym_preproc_elif] = STATE(2874),
    [sym_preproc_else] = STATE(3418),
    [sym_preproc_endif] = STATE(6949),
    [aux_sym_controladdin_declaration_repeat1] = STATE(2885),
    [aux_sym_preproc_conditional_controladdin_repeat1] = STATE(7976),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(2722)] = {
    [sym__body_element] = STATE(2746),
    [sym_empty_statement] = STATE(2746),
    [sym_property] = STATE(2746),
    [sym_fields_section] = STATE(2746),
    [sym_keys_section] = STATE(2746),
    [sym_fieldgroups_section] = STATE(2746),
    [sym_enum_value_declaration] = STATE(2746),
    [sym_labels_section] = STATE(2746),
    [sym_layout_section] = STATE(2746),
    [sym_modify_modification] = STATE(2746),
    [sym_actions_section] = STATE(2746),
    [sym_views_section] = STATE(2746),
    [sym_dataset_section] = STATE(2746),
    [sym_requestpage_section] = STATE(2746),
    [sym_rendering_section] = STATE(2746),
    [sym_elements_section] = STATE(2746),
    [sym_schema_section] = STATE(2746),
    [sym_assembly_declaration] = STATE(2746),
    [sym_event_declaration] = STATE(2746),
    [sym_procedure] = STATE(2746),
    [sym_preproc_split_procedure] = STATE(2746),
    [sym__procedure_header] = STATE(8096),
    [sym_procedure_modifier] = STATE(12657),
    [sym_trigger_declaration] = STATE(2746),
    [sym_var_section] = STATE(2746),
    [sym_attribute_item] = STATE(3722),
    [sym_preproc_conditional] = STATE(2746),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_elif] = STATE(3272),
    [sym_preproc_else] = STATE(3484),
    [sym_preproc_endif] = STATE(5147),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(2746),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_repeat1] = STATE(7863),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(5568),
    [anon_sym_POUNDENDIF] = ACTIONS(5568),
    [anon_sym_POUNDEndif] = ACTIONS(5568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(2883),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5568),
  },
  [STATE(2723)] = {
    [sym_boolean] = STATE(2555),
    [sym_assignment_expression] = STATE(6345),
    [sym__expression] = STATE(6345),
    [sym_keyword_identifier] = STATE(2526),
    [sym_range_expression] = STATE(6345),
    [sym_multiplicative_expression] = STATE(6345),
    [sym_additive_expression] = STATE(6345),
    [sym_comparison_expression] = STATE(6345),
    [sym_logical_expression] = STATE(6345),
    [sym_ternary_expression] = STATE(6345),
    [sym_unary_expression] = STATE(6345),
    [sym_call_expression] = STATE(6372),
    [sym_member_expression] = STATE(6325),
    [sym_subscript_expression] = STATE(6325),
    [sym_parenthesized_expression] = STATE(6345),
    [sym_list_literal] = STATE(6345),
    [sym_qualified_enum_value] = STATE(2526),
    [sym_database_reference] = STATE(2559),
    [sym__literal_value] = STATE(6345),
    [sym_codeunit_keyword] = STATE(2547),
    [sym_xmlport_keyword] = STATE(2547),
    [sym_enum_keyword] = STATE(2546),
    [aux_sym_filter_value_repeat1] = STATE(2723),
    [sym_identifier] = ACTIONS(6542),
    [anon_sym_DASH] = ACTIONS(6545),
    [aux_sym_boolean_token1] = ACTIONS(6548),
    [aux_sym_boolean_token2] = ACTIONS(6548),
    [sym_decimal] = ACTIONS(6551),
    [anon_sym_LPAREN] = ACTIONS(6554),
    [anon_sym_RPAREN] = ACTIONS(6002),
    [anon_sym_DOT_DOT] = ACTIONS(6557),
    [aux_sym_filter_value_token1] = ACTIONS(6557),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6560),
    [anon_sym_LBRACK] = ACTIONS(6563),
    [aux_sym_record_type_token1] = ACTIONS(6560),
    [aux_sym_basic_type_token21] = ACTIONS(6560),
    [aux_sym_basic_type_token22] = ACTIONS(6560),
    [aux_sym_basic_type_token48] = ACTIONS(6560),
    [anon_sym_not] = ACTIONS(6566),
    [anon_sym_NOT] = ACTIONS(6566),
    [anon_sym_Not] = ACTIONS(6566),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6560),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6569),
    [anon_sym_PLUS] = ACTIONS(6572),
    [sym_datetime_literal] = ACTIONS(6575),
    [sym_date_literal] = ACTIONS(6551),
    [sym_time_literal] = ACTIONS(6551),
    [sym_biginteger_literal] = ACTIONS(6575),
    [sym_page_keyword] = ACTIONS(6569),
    [anon_sym_codeunit] = ACTIONS(6578),
    [anon_sym_CODEUNIT] = ACTIONS(6578),
    [anon_sym_Codeunit] = ACTIONS(6578),
    [anon_sym_CodeUnit] = ACTIONS(6578),
    [anon_sym_COdeunit] = ACTIONS(6578),
    [anon_sym_codeUnit] = ACTIONS(6578),
    [sym_report_keyword] = ACTIONS(6569),
    [sym_query_keyword] = ACTIONS(6569),
    [anon_sym_xmlport] = ACTIONS(6581),
    [anon_sym_XMLPORT] = ACTIONS(6581),
    [anon_sym_Xmlport] = ACTIONS(6581),
    [anon_sym_XMLport] = ACTIONS(6581),
    [anon_sym_XMLPort] = ACTIONS(6581),
    [anon_sym_XmlPort] = ACTIONS(6581),
    [anon_sym_enum] = ACTIONS(6584),
    [anon_sym_ENUM] = ACTIONS(6584),
    [anon_sym_Enum] = ACTIONS(6584),
    [anon_sym_eNUM] = ACTIONS(6584),
    [anon_sym_eNum] = ACTIONS(6584),
    [anon_sym_ENum] = ACTIONS(6584),
    [sym_quoted_identifier] = ACTIONS(6587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6575),
    [sym_integer] = ACTIONS(6551),
    [sym_continue_as_identifier] = ACTIONS(6590),
  },
  [STATE(2724)] = {
    [sym__body_element] = STATE(2739),
    [sym_empty_statement] = STATE(2739),
    [sym_property] = STATE(2739),
    [sym_fields_section] = STATE(2739),
    [sym_keys_section] = STATE(2739),
    [sym_fieldgroups_section] = STATE(2739),
    [sym_enum_value_declaration] = STATE(2739),
    [sym_labels_section] = STATE(2739),
    [sym_layout_section] = STATE(2739),
    [sym_modify_modification] = STATE(2739),
    [sym_actions_section] = STATE(2739),
    [sym_views_section] = STATE(2739),
    [sym_dataset_section] = STATE(2739),
    [sym_requestpage_section] = STATE(2739),
    [sym_rendering_section] = STATE(2739),
    [sym_elements_section] = STATE(2739),
    [sym_schema_section] = STATE(2739),
    [sym_assembly_declaration] = STATE(2739),
    [sym_event_declaration] = STATE(2739),
    [sym_procedure] = STATE(2739),
    [sym_preproc_split_procedure] = STATE(2739),
    [sym__procedure_header] = STATE(8087),
    [sym_procedure_modifier] = STATE(12657),
    [sym_trigger_declaration] = STATE(2739),
    [sym_var_section] = STATE(2739),
    [sym_attribute_item] = STATE(3722),
    [sym_preproc_conditional] = STATE(2739),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_elif] = STATE(3272),
    [sym_preproc_else] = STATE(3466),
    [sym_preproc_endif] = STATE(6871),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(2739),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_repeat1] = STATE(8094),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(2883),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(2725)] = {
    [sym_boolean] = STATE(7263),
    [sym_option_member_list] = STATE(7391),
    [sym_option_member] = STATE(7258),
    [sym_keyword_identifier] = STATE(7263),
    [sym_codeunit_keyword] = STATE(7278),
    [sym_xmlport_keyword] = STATE(7278),
    [sym_enum_keyword] = STATE(7278),
    [sym_keyword_as_identifier] = STATE(7263),
    [aux_sym_option_member_list_repeat2] = STATE(2738),
    [sym_identifier] = ACTIONS(6593),
    [anon_sym_SEMI] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(6595),
    [anon_sym_DASH] = ACTIONS(6597),
    [aux_sym_boolean_token1] = ACTIONS(6599),
    [aux_sym_boolean_token2] = ACTIONS(6599),
    [aux_sym_where_condition_token1] = ACTIONS(6601),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6603),
    [aux_sym_record_type_token1] = ACTIONS(6603),
    [aux_sym_basic_type_token21] = ACTIONS(6603),
    [aux_sym_basic_type_token22] = ACTIONS(6605),
    [aux_sym_basic_type_token48] = ACTIONS(6603),
    [aux_sym_basic_type_token53] = ACTIONS(6601),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6601),
    [aux_sym_separator_action_token1] = ACTIONS(6601),
    [aux_sym_type_declaration_token1] = ACTIONS(6601),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(277),
    [anon_sym_POUNDif] = ACTIONS(275),
    [anon_sym_POUNDIF] = ACTIONS(275),
    [anon_sym_POUNDIf] = ACTIONS(275),
    [anon_sym_POUNDelif] = ACTIONS(275),
    [anon_sym_POUNDELIF] = ACTIONS(275),
    [anon_sym_POUNDElif] = ACTIONS(275),
    [anon_sym_POUNDelse] = ACTIONS(275),
    [anon_sym_POUNDELSE] = ACTIONS(275),
    [anon_sym_POUNDElse] = ACTIONS(275),
    [anon_sym_POUNDendif] = ACTIONS(275),
    [anon_sym_POUNDENDIF] = ACTIONS(275),
    [anon_sym_POUNDEndif] = ACTIONS(275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6603),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6603),
    [sym_page_keyword] = ACTIONS(6603),
    [anon_sym_codeunit] = ACTIONS(6607),
    [anon_sym_CODEUNIT] = ACTIONS(6607),
    [anon_sym_Codeunit] = ACTIONS(6607),
    [anon_sym_CodeUnit] = ACTIONS(6607),
    [anon_sym_COdeunit] = ACTIONS(6607),
    [anon_sym_codeUnit] = ACTIONS(6607),
    [sym_report_keyword] = ACTIONS(6603),
    [sym_query_keyword] = ACTIONS(6603),
    [anon_sym_xmlport] = ACTIONS(6609),
    [anon_sym_XMLPORT] = ACTIONS(6609),
    [anon_sym_Xmlport] = ACTIONS(6609),
    [anon_sym_XMLport] = ACTIONS(6609),
    [anon_sym_XMLPort] = ACTIONS(6609),
    [anon_sym_XmlPort] = ACTIONS(6609),
    [anon_sym_enum] = ACTIONS(6611),
    [anon_sym_ENUM] = ACTIONS(6611),
    [anon_sym_Enum] = ACTIONS(6611),
    [anon_sym_eNUM] = ACTIONS(6611),
    [anon_sym_eNum] = ACTIONS(6611),
    [anon_sym_ENum] = ACTIONS(6611),
    [sym_var_keyword] = ACTIONS(277),
    [sym_local_keyword] = ACTIONS(6593),
    [sym_internal_keyword] = ACTIONS(6593),
    [sym_protected_keyword] = ACTIONS(6593),
    [sym_key_keyword] = ACTIONS(6601),
    [sym_dataset_keyword] = ACTIONS(6601),
    [sym_quoted_identifier] = ACTIONS(6613),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6613),
    [sym_integer] = ACTIONS(6613),
    [sym_preproc_open] = ACTIONS(275),
    [sym_preproc_close] = ACTIONS(275),
    [sym_begin_keyword] = ACTIONS(275),
  },
  [STATE(2726)] = {
    [sym_preproc_conditional_controladdin] = STATE(2885),
    [sym__body_element] = STATE(2885),
    [sym_empty_statement] = STATE(2885),
    [sym_property] = STATE(2885),
    [sym_fields_section] = STATE(2885),
    [sym_keys_section] = STATE(2885),
    [sym_fieldgroups_section] = STATE(2885),
    [sym_enum_value_declaration] = STATE(2885),
    [sym_labels_section] = STATE(2885),
    [sym_layout_section] = STATE(2885),
    [sym_modify_modification] = STATE(2885),
    [sym_actions_section] = STATE(2885),
    [sym_views_section] = STATE(2885),
    [sym_dataset_section] = STATE(2885),
    [sym_requestpage_section] = STATE(2885),
    [sym_rendering_section] = STATE(2885),
    [sym_elements_section] = STATE(2885),
    [sym_schema_section] = STATE(2885),
    [sym_assembly_declaration] = STATE(2885),
    [sym_event_declaration] = STATE(2885),
    [sym_procedure] = STATE(2885),
    [sym_preproc_split_procedure] = STATE(2885),
    [sym_interface_procedure] = STATE(2885),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2885),
    [sym_var_section] = STATE(2885),
    [sym_attribute_item] = STATE(2885),
    [sym_preproc_conditional] = STATE(2885),
    [sym_preproc_if] = STATE(2635),
    [sym_preproc_elif] = STATE(2874),
    [sym_preproc_else] = STATE(3428),
    [sym_preproc_endif] = STATE(6264),
    [aux_sym_controladdin_declaration_repeat1] = STATE(2885),
    [aux_sym_preproc_conditional_controladdin_repeat1] = STATE(8170),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(2727)] = {
    [sym_boolean] = STATE(2555),
    [sym_assignment_expression] = STATE(6345),
    [sym__expression] = STATE(6345),
    [sym_keyword_identifier] = STATE(2526),
    [sym_range_expression] = STATE(6345),
    [sym_multiplicative_expression] = STATE(6345),
    [sym_additive_expression] = STATE(6345),
    [sym_comparison_expression] = STATE(6345),
    [sym_logical_expression] = STATE(6345),
    [sym_ternary_expression] = STATE(6345),
    [sym_unary_expression] = STATE(6345),
    [sym_call_expression] = STATE(6372),
    [sym_member_expression] = STATE(6325),
    [sym_subscript_expression] = STATE(6325),
    [sym_parenthesized_expression] = STATE(6345),
    [sym_list_literal] = STATE(6345),
    [sym_qualified_enum_value] = STATE(2526),
    [sym_database_reference] = STATE(2559),
    [sym__literal_value] = STATE(6345),
    [sym_codeunit_keyword] = STATE(2547),
    [sym_xmlport_keyword] = STATE(2547),
    [sym_enum_keyword] = STATE(2546),
    [aux_sym_filter_value_repeat1] = STATE(2723),
    [sym_identifier] = ACTIONS(6516),
    [anon_sym_DASH] = ACTIONS(6518),
    [aux_sym_boolean_token1] = ACTIONS(6520),
    [aux_sym_boolean_token2] = ACTIONS(6520),
    [sym_decimal] = ACTIONS(6522),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6615),
    [anon_sym_DOT_DOT] = ACTIONS(6617),
    [aux_sym_filter_value_token1] = ACTIONS(6617),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6526),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(6526),
    [aux_sym_basic_type_token21] = ACTIONS(6526),
    [aux_sym_basic_type_token22] = ACTIONS(6526),
    [aux_sym_basic_type_token48] = ACTIONS(6526),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6526),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6528),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6530),
    [sym_date_literal] = ACTIONS(6522),
    [sym_time_literal] = ACTIONS(6522),
    [sym_biginteger_literal] = ACTIONS(6530),
    [sym_page_keyword] = ACTIONS(6528),
    [anon_sym_codeunit] = ACTIONS(6532),
    [anon_sym_CODEUNIT] = ACTIONS(6532),
    [anon_sym_Codeunit] = ACTIONS(6532),
    [anon_sym_CodeUnit] = ACTIONS(6532),
    [anon_sym_COdeunit] = ACTIONS(6532),
    [anon_sym_codeUnit] = ACTIONS(6532),
    [sym_report_keyword] = ACTIONS(6528),
    [sym_query_keyword] = ACTIONS(6528),
    [anon_sym_xmlport] = ACTIONS(6534),
    [anon_sym_XMLPORT] = ACTIONS(6534),
    [anon_sym_Xmlport] = ACTIONS(6534),
    [anon_sym_XMLport] = ACTIONS(6534),
    [anon_sym_XMLPort] = ACTIONS(6534),
    [anon_sym_XmlPort] = ACTIONS(6534),
    [anon_sym_enum] = ACTIONS(6536),
    [anon_sym_ENUM] = ACTIONS(6536),
    [anon_sym_Enum] = ACTIONS(6536),
    [anon_sym_eNUM] = ACTIONS(6536),
    [anon_sym_eNum] = ACTIONS(6536),
    [anon_sym_ENum] = ACTIONS(6536),
    [sym_quoted_identifier] = ACTIONS(6538),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6530),
    [sym_integer] = ACTIONS(6522),
    [sym_continue_as_identifier] = ACTIONS(5457),
  },
  [STATE(2728)] = {
    [sym_boolean] = STATE(2555),
    [sym_filter_value] = STATE(12384),
    [sym_assignment_expression] = STATE(6345),
    [sym__expression] = STATE(6345),
    [sym_keyword_identifier] = STATE(2526),
    [sym_range_expression] = STATE(6345),
    [sym_multiplicative_expression] = STATE(6345),
    [sym_additive_expression] = STATE(6345),
    [sym_comparison_expression] = STATE(6345),
    [sym_logical_expression] = STATE(6345),
    [sym_ternary_expression] = STATE(6345),
    [sym_unary_expression] = STATE(6345),
    [sym_call_expression] = STATE(6372),
    [sym_member_expression] = STATE(6325),
    [sym_subscript_expression] = STATE(6325),
    [sym_parenthesized_expression] = STATE(6345),
    [sym_list_literal] = STATE(6345),
    [sym_qualified_enum_value] = STATE(2526),
    [sym_database_reference] = STATE(2559),
    [sym__literal_value] = STATE(6345),
    [sym_codeunit_keyword] = STATE(2547),
    [sym_xmlport_keyword] = STATE(2547),
    [sym_enum_keyword] = STATE(2546),
    [aux_sym_filter_value_repeat1] = STATE(2727),
    [sym_identifier] = ACTIONS(6516),
    [anon_sym_DASH] = ACTIONS(6518),
    [aux_sym_boolean_token1] = ACTIONS(6520),
    [aux_sym_boolean_token2] = ACTIONS(6520),
    [sym_decimal] = ACTIONS(6522),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_DOT_DOT] = ACTIONS(6524),
    [aux_sym_filter_value_token1] = ACTIONS(6524),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6526),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(6526),
    [aux_sym_basic_type_token21] = ACTIONS(6526),
    [aux_sym_basic_type_token22] = ACTIONS(6526),
    [aux_sym_basic_type_token48] = ACTIONS(6526),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6526),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6528),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6530),
    [sym_date_literal] = ACTIONS(6522),
    [sym_time_literal] = ACTIONS(6522),
    [sym_biginteger_literal] = ACTIONS(6530),
    [sym_page_keyword] = ACTIONS(6528),
    [anon_sym_codeunit] = ACTIONS(6532),
    [anon_sym_CODEUNIT] = ACTIONS(6532),
    [anon_sym_Codeunit] = ACTIONS(6532),
    [anon_sym_CodeUnit] = ACTIONS(6532),
    [anon_sym_COdeunit] = ACTIONS(6532),
    [anon_sym_codeUnit] = ACTIONS(6532),
    [sym_report_keyword] = ACTIONS(6528),
    [sym_query_keyword] = ACTIONS(6528),
    [anon_sym_xmlport] = ACTIONS(6534),
    [anon_sym_XMLPORT] = ACTIONS(6534),
    [anon_sym_Xmlport] = ACTIONS(6534),
    [anon_sym_XMLport] = ACTIONS(6534),
    [anon_sym_XMLPort] = ACTIONS(6534),
    [anon_sym_XmlPort] = ACTIONS(6534),
    [anon_sym_enum] = ACTIONS(6536),
    [anon_sym_ENUM] = ACTIONS(6536),
    [anon_sym_Enum] = ACTIONS(6536),
    [anon_sym_eNUM] = ACTIONS(6536),
    [anon_sym_eNum] = ACTIONS(6536),
    [anon_sym_ENum] = ACTIONS(6536),
    [sym_quoted_identifier] = ACTIONS(6538),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6530),
    [sym_integer] = ACTIONS(6522),
    [sym_continue_as_identifier] = ACTIONS(5457),
  },
  [STATE(2729)] = {
    [sym__body_element] = STATE(2729),
    [sym_empty_statement] = STATE(2729),
    [sym_property] = STATE(2729),
    [sym_fields_section] = STATE(2729),
    [sym_keys_section] = STATE(2729),
    [sym_fieldgroups_section] = STATE(2729),
    [sym_enum_value_declaration] = STATE(2729),
    [sym_labels_section] = STATE(2729),
    [sym_layout_section] = STATE(2729),
    [sym_modify_modification] = STATE(2729),
    [sym_actions_section] = STATE(2729),
    [sym_views_section] = STATE(2729),
    [sym_dataset_section] = STATE(2729),
    [sym_report_dataitem] = STATE(2729),
    [sym__report_body_element] = STATE(2729),
    [sym_preproc_conditional_report] = STATE(2729),
    [sym_report_column] = STATE(2729),
    [sym_requestpage_section] = STATE(2729),
    [sym_rendering_section] = STATE(2729),
    [sym_elements_section] = STATE(2729),
    [sym_schema_section] = STATE(2729),
    [sym_assembly_declaration] = STATE(2729),
    [sym_event_declaration] = STATE(2729),
    [sym_procedure] = STATE(2729),
    [sym_preproc_split_procedure] = STATE(2729),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2729),
    [sym_var_section] = STATE(2729),
    [sym_attribute_item] = STATE(2729),
    [sym_preproc_conditional] = STATE(2729),
    [sym_preproc_if] = STATE(2557),
    [aux_sym_report_dataitem_repeat1] = STATE(2729),
    [anon_sym_SEMI] = ACTIONS(6619),
    [anon_sym_LBRACK] = ACTIONS(6622),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6625),
    [aux_sym_modify_modification_token1] = ACTIONS(6628),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6631),
    [anon_sym_POUNDif] = ACTIONS(6634),
    [anon_sym_POUNDIF] = ACTIONS(6634),
    [anon_sym_POUNDIf] = ACTIONS(6634),
    [anon_sym_POUNDelif] = ACTIONS(6637),
    [anon_sym_POUNDELIF] = ACTIONS(6637),
    [anon_sym_POUNDElif] = ACTIONS(6637),
    [anon_sym_POUNDelse] = ACTIONS(6637),
    [anon_sym_POUNDELSE] = ACTIONS(6637),
    [anon_sym_POUNDElse] = ACTIONS(6637),
    [anon_sym_POUNDendif] = ACTIONS(6637),
    [anon_sym_POUNDENDIF] = ACTIONS(6637),
    [anon_sym_POUNDEndif] = ACTIONS(6637),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6639),
    [sym_trigger_keyword] = ACTIONS(6642),
    [sym_var_keyword] = ACTIONS(6645),
    [sym_local_keyword] = ACTIONS(6648),
    [sym_internal_keyword] = ACTIONS(6651),
    [sym_protected_keyword] = ACTIONS(6648),
    [sym_event_keyword] = ACTIONS(6654),
    [sym_fields_keyword] = ACTIONS(6657),
    [sym_keys_keyword] = ACTIONS(6660),
    [sym_fieldgroups_keyword] = ACTIONS(6663),
    [sym_actions_keyword] = ACTIONS(6666),
    [sym_layout_keyword] = ACTIONS(6669),
    [sym_dataset_keyword] = ACTIONS(6672),
    [sym_elements_keyword] = ACTIONS(6675),
    [sym_dataitem_keyword] = ACTIONS(6678),
    [sym_column_keyword] = ACTIONS(6681),
    [sym_labels_keyword] = ACTIONS(6684),
    [sym_rendering_keyword] = ACTIONS(6687),
    [sym_requestpage_keyword] = ACTIONS(6690),
    [sym_schema_keyword] = ACTIONS(6693),
    [sym_views_keyword] = ACTIONS(6696),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6699),
    [sym_preproc_open] = ACTIONS(6634),
    [sym_preproc_close] = ACTIONS(6637),
  },
  [STATE(2730)] = {
    [sym_boolean] = STATE(2555),
    [sym_filter_value] = STATE(12218),
    [sym_assignment_expression] = STATE(6345),
    [sym__expression] = STATE(6345),
    [sym_keyword_identifier] = STATE(2526),
    [sym_range_expression] = STATE(6345),
    [sym_multiplicative_expression] = STATE(6345),
    [sym_additive_expression] = STATE(6345),
    [sym_comparison_expression] = STATE(6345),
    [sym_logical_expression] = STATE(6345),
    [sym_ternary_expression] = STATE(6345),
    [sym_unary_expression] = STATE(6345),
    [sym_call_expression] = STATE(6372),
    [sym_member_expression] = STATE(6325),
    [sym_subscript_expression] = STATE(6325),
    [sym_parenthesized_expression] = STATE(6345),
    [sym_list_literal] = STATE(6345),
    [sym_qualified_enum_value] = STATE(2526),
    [sym_database_reference] = STATE(2559),
    [sym__literal_value] = STATE(6345),
    [sym_codeunit_keyword] = STATE(2547),
    [sym_xmlport_keyword] = STATE(2547),
    [sym_enum_keyword] = STATE(2546),
    [aux_sym_filter_value_repeat1] = STATE(2727),
    [sym_identifier] = ACTIONS(6516),
    [anon_sym_DASH] = ACTIONS(6518),
    [aux_sym_boolean_token1] = ACTIONS(6520),
    [aux_sym_boolean_token2] = ACTIONS(6520),
    [sym_decimal] = ACTIONS(6522),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_DOT_DOT] = ACTIONS(6524),
    [aux_sym_filter_value_token1] = ACTIONS(6524),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6526),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(6526),
    [aux_sym_basic_type_token21] = ACTIONS(6526),
    [aux_sym_basic_type_token22] = ACTIONS(6526),
    [aux_sym_basic_type_token48] = ACTIONS(6526),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6526),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6528),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6530),
    [sym_date_literal] = ACTIONS(6522),
    [sym_time_literal] = ACTIONS(6522),
    [sym_biginteger_literal] = ACTIONS(6530),
    [sym_page_keyword] = ACTIONS(6528),
    [anon_sym_codeunit] = ACTIONS(6532),
    [anon_sym_CODEUNIT] = ACTIONS(6532),
    [anon_sym_Codeunit] = ACTIONS(6532),
    [anon_sym_CodeUnit] = ACTIONS(6532),
    [anon_sym_COdeunit] = ACTIONS(6532),
    [anon_sym_codeUnit] = ACTIONS(6532),
    [sym_report_keyword] = ACTIONS(6528),
    [sym_query_keyword] = ACTIONS(6528),
    [anon_sym_xmlport] = ACTIONS(6534),
    [anon_sym_XMLPORT] = ACTIONS(6534),
    [anon_sym_Xmlport] = ACTIONS(6534),
    [anon_sym_XMLport] = ACTIONS(6534),
    [anon_sym_XMLPort] = ACTIONS(6534),
    [anon_sym_XmlPort] = ACTIONS(6534),
    [anon_sym_enum] = ACTIONS(6536),
    [anon_sym_ENUM] = ACTIONS(6536),
    [anon_sym_Enum] = ACTIONS(6536),
    [anon_sym_eNUM] = ACTIONS(6536),
    [anon_sym_eNum] = ACTIONS(6536),
    [anon_sym_ENum] = ACTIONS(6536),
    [sym_quoted_identifier] = ACTIONS(6538),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6530),
    [sym_integer] = ACTIONS(6522),
    [sym_continue_as_identifier] = ACTIONS(5457),
  },
  [STATE(2731)] = {
    [sym__body_element] = STATE(2729),
    [sym_empty_statement] = STATE(2729),
    [sym_property] = STATE(2729),
    [sym_fields_section] = STATE(2729),
    [sym_keys_section] = STATE(2729),
    [sym_fieldgroups_section] = STATE(2729),
    [sym_enum_value_declaration] = STATE(2729),
    [sym_labels_section] = STATE(2729),
    [sym_layout_section] = STATE(2729),
    [sym_modify_modification] = STATE(2729),
    [sym_actions_section] = STATE(2729),
    [sym_views_section] = STATE(2729),
    [sym_dataset_section] = STATE(2729),
    [sym_report_dataitem] = STATE(2729),
    [sym__report_body_element] = STATE(2729),
    [sym_preproc_conditional_report] = STATE(2729),
    [sym_report_column] = STATE(2729),
    [sym_requestpage_section] = STATE(2729),
    [sym_rendering_section] = STATE(2729),
    [sym_elements_section] = STATE(2729),
    [sym_schema_section] = STATE(2729),
    [sym_assembly_declaration] = STATE(2729),
    [sym_event_declaration] = STATE(2729),
    [sym_procedure] = STATE(2729),
    [sym_preproc_split_procedure] = STATE(2729),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2729),
    [sym_var_section] = STATE(2729),
    [sym_attribute_item] = STATE(2729),
    [sym_preproc_conditional] = STATE(2729),
    [sym_preproc_if] = STATE(2557),
    [aux_sym_report_dataitem_repeat1] = STATE(2729),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(6702),
    [anon_sym_POUNDELIF] = ACTIONS(6702),
    [anon_sym_POUNDElif] = ACTIONS(6702),
    [anon_sym_POUNDelse] = ACTIONS(6702),
    [anon_sym_POUNDELSE] = ACTIONS(6702),
    [anon_sym_POUNDElse] = ACTIONS(6702),
    [anon_sym_POUNDendif] = ACTIONS(6702),
    [anon_sym_POUNDENDIF] = ACTIONS(6702),
    [anon_sym_POUNDEndif] = ACTIONS(6702),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(6702),
  },
  [STATE(2732)] = {
    [sym__body_element] = STATE(2731),
    [sym_empty_statement] = STATE(2731),
    [sym_property] = STATE(2731),
    [sym_fields_section] = STATE(2731),
    [sym_keys_section] = STATE(2731),
    [sym_fieldgroups_section] = STATE(2731),
    [sym_enum_value_declaration] = STATE(2731),
    [sym_labels_section] = STATE(2731),
    [sym_layout_section] = STATE(2731),
    [sym_modify_modification] = STATE(2731),
    [sym_actions_section] = STATE(2731),
    [sym_views_section] = STATE(2731),
    [sym_dataset_section] = STATE(2731),
    [sym_report_dataitem] = STATE(2731),
    [sym__report_body_element] = STATE(2731),
    [sym_preproc_conditional_report] = STATE(2731),
    [sym_report_column] = STATE(2731),
    [sym_requestpage_section] = STATE(2731),
    [sym_rendering_section] = STATE(2731),
    [sym_elements_section] = STATE(2731),
    [sym_schema_section] = STATE(2731),
    [sym_assembly_declaration] = STATE(2731),
    [sym_event_declaration] = STATE(2731),
    [sym_procedure] = STATE(2731),
    [sym_preproc_split_procedure] = STATE(2731),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2731),
    [sym_var_section] = STATE(2731),
    [sym_attribute_item] = STATE(2731),
    [sym_preproc_conditional] = STATE(2731),
    [sym_preproc_if] = STATE(2557),
    [aux_sym_report_dataitem_repeat1] = STATE(2731),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(6704),
    [anon_sym_POUNDELIF] = ACTIONS(6704),
    [anon_sym_POUNDElif] = ACTIONS(6704),
    [anon_sym_POUNDelse] = ACTIONS(6704),
    [anon_sym_POUNDELSE] = ACTIONS(6704),
    [anon_sym_POUNDElse] = ACTIONS(6704),
    [anon_sym_POUNDendif] = ACTIONS(6704),
    [anon_sym_POUNDENDIF] = ACTIONS(6704),
    [anon_sym_POUNDEndif] = ACTIONS(6704),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(6704),
  },
  [STATE(2733)] = {
    [sym__body_element] = STATE(2755),
    [sym_empty_statement] = STATE(2755),
    [sym_property] = STATE(2755),
    [sym_fields_section] = STATE(2755),
    [sym_keys_section] = STATE(2755),
    [sym_fieldgroups_section] = STATE(2755),
    [sym_enum_value_declaration] = STATE(2755),
    [sym_labels_section] = STATE(2755),
    [sym_layout_section] = STATE(2755),
    [sym_modify_modification] = STATE(2755),
    [sym_actions_section] = STATE(2755),
    [sym_views_section] = STATE(2755),
    [sym_dataset_section] = STATE(2755),
    [sym_requestpage_section] = STATE(2755),
    [sym_rendering_section] = STATE(2755),
    [sym_elements_section] = STATE(2755),
    [sym_schema_section] = STATE(2755),
    [sym_assembly_declaration] = STATE(2755),
    [sym_event_declaration] = STATE(2755),
    [sym_procedure] = STATE(2755),
    [sym_preproc_split_procedure] = STATE(2755),
    [sym__procedure_header] = STATE(8089),
    [sym_procedure_modifier] = STATE(12657),
    [sym_trigger_declaration] = STATE(2755),
    [sym_var_section] = STATE(2755),
    [sym_attribute_item] = STATE(3722),
    [sym_preproc_conditional] = STATE(2755),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_elif] = STATE(3272),
    [sym_preproc_else] = STATE(3485),
    [sym_preproc_endif] = STATE(6266),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(2755),
    [aux_sym__procedure_header_repeat1] = STATE(9005),
    [aux_sym_preproc_conditional_repeat1] = STATE(8159),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(2883),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(2734)] = {
    [sym_boolean] = STATE(4924),
    [sym_assignment_expression] = STATE(4924),
    [sym__expression] = STATE(4924),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4924),
    [sym_multiplicative_expression] = STATE(4924),
    [sym_additive_expression] = STATE(4924),
    [sym_comparison_expression] = STATE(4924),
    [sym_logical_expression] = STATE(4924),
    [sym_ternary_expression] = STATE(4924),
    [sym_unary_expression] = STATE(4924),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4924),
    [sym_list_literal] = STATE(4924),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4924),
    [sym__literal_value] = STATE(4924),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6706),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(5884),
    [anon_sym_DOT_DOT] = ACTIONS(5884),
    [aux_sym_filter_value_token1] = ACTIONS(5884),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6708),
    [sym_date_literal] = ACTIONS(6706),
    [sym_time_literal] = ACTIONS(6706),
    [sym_biginteger_literal] = ACTIONS(6708),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6708),
    [sym_integer] = ACTIONS(6710),
    [sym_continue_as_identifier] = ACTIONS(6708),
  },
  [STATE(2735)] = {
    [sym__body_element] = STATE(5591),
    [sym_empty_statement] = STATE(5591),
    [sym_property] = STATE(5591),
    [sym_fields_section] = STATE(5591),
    [sym_keys_section] = STATE(5591),
    [sym_fieldgroups_section] = STATE(5591),
    [sym_enum_value_declaration] = STATE(5591),
    [sym_labels_section] = STATE(5591),
    [sym_layout_section] = STATE(5591),
    [sym_modify_modification] = STATE(5591),
    [sym_actions_section] = STATE(5591),
    [sym_views_section] = STATE(5591),
    [sym_dataset_section] = STATE(5591),
    [sym_requestpage_section] = STATE(5591),
    [sym_rendering_section] = STATE(5591),
    [sym_elements_section] = STATE(5591),
    [sym_schema_section] = STATE(5591),
    [sym_xmlport_element] = STATE(2752),
    [sym__xmlport_body_element] = STATE(2752),
    [sym_preproc_conditional_xmlport] = STATE(2752),
    [sym_xmlport_attribute] = STATE(2752),
    [sym_assembly_declaration] = STATE(5591),
    [sym_event_declaration] = STATE(5591),
    [sym_procedure] = STATE(5591),
    [sym_preproc_split_procedure] = STATE(5591),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(5591),
    [sym_var_section] = STATE(5591),
    [sym_attribute_item] = STATE(5591),
    [sym_preproc_conditional] = STATE(5591),
    [sym_preproc_if] = STATE(2446),
    [sym_preproc_endif] = STATE(5850),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3486),
    [aux_sym_xmlport_element_repeat1] = STATE(2752),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDendif] = ACTIONS(5829),
    [anon_sym_POUNDENDIF] = ACTIONS(5829),
    [anon_sym_POUNDEndif] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(5829),
  },
  [STATE(2736)] = {
    [sym_boolean] = STATE(6331),
    [sym_attribute_argument_list] = STATE(11320),
    [sym__attribute_argument] = STATE(10709),
    [sym_assignment_expression] = STATE(6345),
    [sym__expression] = STATE(6345),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6345),
    [sym_multiplicative_expression] = STATE(6345),
    [sym_additive_expression] = STATE(6345),
    [sym_comparison_expression] = STATE(6345),
    [sym_logical_expression] = STATE(6345),
    [sym_ternary_expression] = STATE(6345),
    [sym_unary_expression] = STATE(6345),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(6219),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6345),
    [sym_list_literal] = STATE(6345),
    [sym_qualified_enum_value] = STATE(6219),
    [sym_database_reference] = STATE(6358),
    [sym__literal_value] = STATE(6345),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6712),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6714),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(5457),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5457),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6716),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6718),
    [sym_integer] = ACTIONS(6720),
    [sym_continue_as_identifier] = ACTIONS(5457),
  },
  [STATE(2737)] = {
    [sym__body_element] = STATE(5591),
    [sym_empty_statement] = STATE(5591),
    [sym_property] = STATE(5591),
    [sym_fields_section] = STATE(5591),
    [sym_keys_section] = STATE(5591),
    [sym_fieldgroups_section] = STATE(5591),
    [sym_enum_value_declaration] = STATE(5591),
    [sym_labels_section] = STATE(5591),
    [sym_layout_section] = STATE(5591),
    [sym_modify_modification] = STATE(5591),
    [sym_actions_section] = STATE(5591),
    [sym_views_section] = STATE(5591),
    [sym_dataset_section] = STATE(5591),
    [sym_requestpage_section] = STATE(5591),
    [sym_rendering_section] = STATE(5591),
    [sym_elements_section] = STATE(5591),
    [sym_schema_section] = STATE(5591),
    [sym_xmlport_element] = STATE(2748),
    [sym__xmlport_body_element] = STATE(2748),
    [sym_preproc_conditional_xmlport] = STATE(2748),
    [sym_xmlport_attribute] = STATE(2748),
    [sym_assembly_declaration] = STATE(5591),
    [sym_event_declaration] = STATE(5591),
    [sym_procedure] = STATE(5591),
    [sym_preproc_split_procedure] = STATE(5591),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(5591),
    [sym_var_section] = STATE(5591),
    [sym_attribute_item] = STATE(5591),
    [sym_preproc_conditional] = STATE(5591),
    [sym_preproc_if] = STATE(2446),
    [sym_preproc_endif] = STATE(6390),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3505),
    [aux_sym_xmlport_element_repeat1] = STATE(2748),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDendif] = ACTIONS(5869),
    [anon_sym_POUNDENDIF] = ACTIONS(5869),
    [anon_sym_POUNDEndif] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(5869),
  },
  [STATE(2738)] = {
    [sym_boolean] = STATE(7263),
    [sym_option_member] = STATE(7256),
    [sym_keyword_identifier] = STATE(7263),
    [sym_codeunit_keyword] = STATE(7278),
    [sym_xmlport_keyword] = STATE(7278),
    [sym_enum_keyword] = STATE(7278),
    [sym_keyword_as_identifier] = STATE(7263),
    [aux_sym_option_member_list_repeat2] = STATE(3368),
    [sym_identifier] = ACTIONS(6593),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(6722),
    [anon_sym_DASH] = ACTIONS(6597),
    [aux_sym_boolean_token1] = ACTIONS(6599),
    [aux_sym_boolean_token2] = ACTIONS(6599),
    [aux_sym_where_condition_token1] = ACTIONS(6601),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6603),
    [aux_sym_record_type_token1] = ACTIONS(6603),
    [aux_sym_basic_type_token21] = ACTIONS(6603),
    [aux_sym_basic_type_token22] = ACTIONS(6605),
    [aux_sym_basic_type_token48] = ACTIONS(6603),
    [aux_sym_basic_type_token53] = ACTIONS(6601),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6601),
    [aux_sym_separator_action_token1] = ACTIONS(6601),
    [aux_sym_type_declaration_token1] = ACTIONS(6601),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(376),
    [anon_sym_POUNDif] = ACTIONS(374),
    [anon_sym_POUNDIF] = ACTIONS(374),
    [anon_sym_POUNDIf] = ACTIONS(374),
    [anon_sym_POUNDelif] = ACTIONS(374),
    [anon_sym_POUNDELIF] = ACTIONS(374),
    [anon_sym_POUNDElif] = ACTIONS(374),
    [anon_sym_POUNDelse] = ACTIONS(374),
    [anon_sym_POUNDELSE] = ACTIONS(374),
    [anon_sym_POUNDElse] = ACTIONS(374),
    [anon_sym_POUNDendif] = ACTIONS(374),
    [anon_sym_POUNDENDIF] = ACTIONS(374),
    [anon_sym_POUNDEndif] = ACTIONS(374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6603),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6603),
    [sym_page_keyword] = ACTIONS(6603),
    [anon_sym_codeunit] = ACTIONS(6607),
    [anon_sym_CODEUNIT] = ACTIONS(6607),
    [anon_sym_Codeunit] = ACTIONS(6607),
    [anon_sym_CodeUnit] = ACTIONS(6607),
    [anon_sym_COdeunit] = ACTIONS(6607),
    [anon_sym_codeUnit] = ACTIONS(6607),
    [sym_report_keyword] = ACTIONS(6603),
    [sym_query_keyword] = ACTIONS(6603),
    [anon_sym_xmlport] = ACTIONS(6609),
    [anon_sym_XMLPORT] = ACTIONS(6609),
    [anon_sym_Xmlport] = ACTIONS(6609),
    [anon_sym_XMLport] = ACTIONS(6609),
    [anon_sym_XMLPort] = ACTIONS(6609),
    [anon_sym_XmlPort] = ACTIONS(6609),
    [anon_sym_enum] = ACTIONS(6611),
    [anon_sym_ENUM] = ACTIONS(6611),
    [anon_sym_Enum] = ACTIONS(6611),
    [anon_sym_eNUM] = ACTIONS(6611),
    [anon_sym_eNum] = ACTIONS(6611),
    [anon_sym_ENum] = ACTIONS(6611),
    [sym_var_keyword] = ACTIONS(376),
    [sym_local_keyword] = ACTIONS(6593),
    [sym_internal_keyword] = ACTIONS(6593),
    [sym_protected_keyword] = ACTIONS(6593),
    [sym_key_keyword] = ACTIONS(6601),
    [sym_dataset_keyword] = ACTIONS(6601),
    [sym_quoted_identifier] = ACTIONS(6613),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6613),
    [sym_integer] = ACTIONS(6613),
    [sym_preproc_open] = ACTIONS(374),
    [sym_preproc_close] = ACTIONS(374),
    [sym_begin_keyword] = ACTIONS(374),
  },
  [STATE(2739)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_elif] = STATE(3272),
    [sym_preproc_else] = STATE(3506),
    [sym_preproc_endif] = STATE(4130),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [aux_sym_preproc_conditional_repeat1] = STATE(7914),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(2740)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_elif] = STATE(3272),
    [sym_preproc_else] = STATE(3487),
    [sym_preproc_endif] = STATE(5732),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [aux_sym_preproc_conditional_repeat1] = STATE(7989),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(5829),
    [anon_sym_POUNDENDIF] = ACTIONS(5829),
    [anon_sym_POUNDEndif] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5829),
  },
  [STATE(2741)] = {
    [sym_identifier] = ACTIONS(4808),
    [anon_sym_DASH] = ACTIONS(4810),
    [aux_sym_boolean_token1] = ACTIONS(4808),
    [aux_sym_boolean_token2] = ACTIONS(4808),
    [sym_decimal] = ACTIONS(4808),
    [anon_sym_LPAREN] = ACTIONS(4810),
    [aux_sym_where_condition_token1] = ACTIONS(4808),
    [aux_sym_if_table_relation_token1] = ACTIONS(4808),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4808),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4808),
    [anon_sym_LBRACK] = ACTIONS(4810),
    [aux_sym_record_type_token1] = ACTIONS(4808),
    [aux_sym_basic_type_token21] = ACTIONS(4808),
    [aux_sym_basic_type_token22] = ACTIONS(4808),
    [aux_sym_basic_type_token48] = ACTIONS(4808),
    [aux_sym_basic_type_token53] = ACTIONS(4808),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4808),
    [aux_sym_separator_action_token1] = ACTIONS(4808),
    [aux_sym_type_declaration_token1] = ACTIONS(4808),
    [anon_sym_POUNDif] = ACTIONS(4810),
    [anon_sym_POUNDIF] = ACTIONS(4810),
    [anon_sym_POUNDIf] = ACTIONS(4810),
    [anon_sym_not] = ACTIONS(4808),
    [anon_sym_NOT] = ACTIONS(4808),
    [anon_sym_Not] = ACTIONS(4808),
    [anon_sym_POUNDelif] = ACTIONS(4810),
    [anon_sym_POUNDELIF] = ACTIONS(4810),
    [anon_sym_POUNDElif] = ACTIONS(4810),
    [anon_sym_POUNDelse] = ACTIONS(4810),
    [anon_sym_POUNDELSE] = ACTIONS(4810),
    [anon_sym_POUNDElse] = ACTIONS(4810),
    [anon_sym_POUNDendif] = ACTIONS(4810),
    [anon_sym_POUNDENDIF] = ACTIONS(4810),
    [anon_sym_POUNDEndif] = ACTIONS(4810),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4808),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4808),
    [anon_sym_PLUS] = ACTIONS(4810),
    [sym_datetime_literal] = ACTIONS(4810),
    [sym_date_literal] = ACTIONS(4808),
    [sym_time_literal] = ACTIONS(4808),
    [sym_biginteger_literal] = ACTIONS(4810),
    [sym_table_keyword] = ACTIONS(4808),
    [sym_page_keyword] = ACTIONS(4808),
    [anon_sym_codeunit] = ACTIONS(4808),
    [anon_sym_CODEUNIT] = ACTIONS(4808),
    [anon_sym_Codeunit] = ACTIONS(4808),
    [anon_sym_CodeUnit] = ACTIONS(4808),
    [anon_sym_COdeunit] = ACTIONS(4808),
    [anon_sym_codeUnit] = ACTIONS(4808),
    [sym_report_keyword] = ACTIONS(4808),
    [sym_query_keyword] = ACTIONS(4808),
    [anon_sym_xmlport] = ACTIONS(4808),
    [anon_sym_XMLPORT] = ACTIONS(4808),
    [anon_sym_Xmlport] = ACTIONS(4808),
    [anon_sym_XMLport] = ACTIONS(4808),
    [anon_sym_XMLPort] = ACTIONS(4808),
    [anon_sym_XmlPort] = ACTIONS(4808),
    [anon_sym_enum] = ACTIONS(4808),
    [anon_sym_ENUM] = ACTIONS(4808),
    [anon_sym_Enum] = ACTIONS(4808),
    [anon_sym_eNUM] = ACTIONS(4808),
    [anon_sym_eNum] = ACTIONS(4808),
    [anon_sym_ENum] = ACTIONS(4808),
    [sym_key_keyword] = ACTIONS(4808),
    [sym_dataset_keyword] = ACTIONS(4808),
    [sym_quoted_identifier] = ACTIONS(4810),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4810),
    [sym_integer] = ACTIONS(4808),
    [sym_continue_as_identifier] = ACTIONS(4810),
    [sym_preproc_open] = ACTIONS(4810),
    [sym_preproc_close] = ACTIONS(4810),
  },
  [STATE(2742)] = {
    [sym__body_element] = STATE(2749),
    [sym_empty_statement] = STATE(2749),
    [sym_property] = STATE(2749),
    [sym_fields_section] = STATE(2749),
    [sym_keys_section] = STATE(2749),
    [sym_fieldgroups_section] = STATE(2749),
    [sym_enum_value_declaration] = STATE(2749),
    [sym_labels_section] = STATE(2749),
    [sym_layout_section] = STATE(2749),
    [sym_modify_modification] = STATE(2749),
    [sym_actions_section] = STATE(2749),
    [sym_views_section] = STATE(2749),
    [sym_dataset_section] = STATE(2749),
    [sym_requestpage_section] = STATE(2749),
    [sym_rendering_section] = STATE(2749),
    [sym_elements_section] = STATE(2749),
    [sym_schema_section] = STATE(2749),
    [sym_xmlport_element] = STATE(2749),
    [sym__xmlport_body_element] = STATE(2749),
    [sym_preproc_conditional_xmlport] = STATE(2749),
    [sym_xmlport_attribute] = STATE(2749),
    [sym_assembly_declaration] = STATE(2749),
    [sym_event_declaration] = STATE(2749),
    [sym_procedure] = STATE(2749),
    [sym_preproc_split_procedure] = STATE(2749),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(2749),
    [sym_var_section] = STATE(2749),
    [sym_attribute_item] = STATE(2749),
    [sym_preproc_conditional] = STATE(2749),
    [sym_preproc_if] = STATE(2446),
    [sym_preproc_endif] = STATE(6767),
    [aux_sym_xmlport_element_repeat1] = STATE(2749),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDendif] = ACTIONS(5869),
    [anon_sym_POUNDENDIF] = ACTIONS(5869),
    [anon_sym_POUNDEndif] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(5869),
  },
  [STATE(2743)] = {
    [sym__body_element] = STATE(2652),
    [sym_empty_statement] = STATE(2652),
    [sym_property] = STATE(2652),
    [sym_fields_section] = STATE(2652),
    [sym_keys_section] = STATE(2652),
    [sym_fieldgroups_section] = STATE(2652),
    [sym_enum_value_declaration] = STATE(2652),
    [sym_labels_section] = STATE(2652),
    [sym_layout_section] = STATE(2652),
    [sym_modify_modification] = STATE(2652),
    [sym_actions_section] = STATE(2652),
    [sym_views_section] = STATE(2652),
    [sym_dataset_section] = STATE(2652),
    [sym_requestpage_section] = STATE(2652),
    [sym_rendering_section] = STATE(2652),
    [sym_elements_section] = STATE(2652),
    [sym_schema_section] = STATE(2652),
    [sym_xmlport_element] = STATE(2652),
    [sym__xmlport_body_element] = STATE(2652),
    [sym_preproc_conditional_xmlport] = STATE(2652),
    [sym_xmlport_attribute] = STATE(2652),
    [sym_assembly_declaration] = STATE(2652),
    [sym_event_declaration] = STATE(2652),
    [sym_procedure] = STATE(2652),
    [sym_preproc_split_procedure] = STATE(2652),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(2652),
    [sym_var_section] = STATE(2652),
    [sym_attribute_item] = STATE(2652),
    [sym_preproc_conditional] = STATE(2652),
    [sym_preproc_if] = STATE(2446),
    [sym_preproc_endif] = STATE(6767),
    [aux_sym_xmlport_element_repeat1] = STATE(2652),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDendif] = ACTIONS(5869),
    [anon_sym_POUNDENDIF] = ACTIONS(5869),
    [anon_sym_POUNDEndif] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(5869),
  },
  [STATE(2744)] = {
    [sym_identifier] = ACTIONS(4467),
    [anon_sym_DASH] = ACTIONS(4469),
    [aux_sym_boolean_token1] = ACTIONS(4467),
    [aux_sym_boolean_token2] = ACTIONS(4467),
    [sym_decimal] = ACTIONS(4467),
    [anon_sym_LPAREN] = ACTIONS(4469),
    [aux_sym_where_condition_token1] = ACTIONS(4467),
    [aux_sym_if_table_relation_token1] = ACTIONS(4467),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4467),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4467),
    [anon_sym_LBRACK] = ACTIONS(4469),
    [aux_sym_record_type_token1] = ACTIONS(4467),
    [aux_sym_basic_type_token21] = ACTIONS(4467),
    [aux_sym_basic_type_token22] = ACTIONS(4467),
    [aux_sym_basic_type_token48] = ACTIONS(4467),
    [aux_sym_basic_type_token53] = ACTIONS(4467),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4467),
    [aux_sym_separator_action_token1] = ACTIONS(4467),
    [aux_sym_type_declaration_token1] = ACTIONS(4467),
    [anon_sym_POUNDif] = ACTIONS(4469),
    [anon_sym_POUNDIF] = ACTIONS(4469),
    [anon_sym_POUNDIf] = ACTIONS(4469),
    [anon_sym_not] = ACTIONS(4467),
    [anon_sym_NOT] = ACTIONS(4467),
    [anon_sym_Not] = ACTIONS(4467),
    [anon_sym_POUNDelif] = ACTIONS(4469),
    [anon_sym_POUNDELIF] = ACTIONS(4469),
    [anon_sym_POUNDElif] = ACTIONS(4469),
    [anon_sym_POUNDelse] = ACTIONS(4469),
    [anon_sym_POUNDELSE] = ACTIONS(4469),
    [anon_sym_POUNDElse] = ACTIONS(4469),
    [anon_sym_POUNDendif] = ACTIONS(4469),
    [anon_sym_POUNDENDIF] = ACTIONS(4469),
    [anon_sym_POUNDEndif] = ACTIONS(4469),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4467),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4467),
    [anon_sym_PLUS] = ACTIONS(4469),
    [sym_datetime_literal] = ACTIONS(4469),
    [sym_date_literal] = ACTIONS(4467),
    [sym_time_literal] = ACTIONS(4467),
    [sym_biginteger_literal] = ACTIONS(4469),
    [sym_table_keyword] = ACTIONS(4467),
    [sym_page_keyword] = ACTIONS(4467),
    [anon_sym_codeunit] = ACTIONS(4467),
    [anon_sym_CODEUNIT] = ACTIONS(4467),
    [anon_sym_Codeunit] = ACTIONS(4467),
    [anon_sym_CodeUnit] = ACTIONS(4467),
    [anon_sym_COdeunit] = ACTIONS(4467),
    [anon_sym_codeUnit] = ACTIONS(4467),
    [sym_report_keyword] = ACTIONS(4467),
    [sym_query_keyword] = ACTIONS(4467),
    [anon_sym_xmlport] = ACTIONS(4467),
    [anon_sym_XMLPORT] = ACTIONS(4467),
    [anon_sym_Xmlport] = ACTIONS(4467),
    [anon_sym_XMLport] = ACTIONS(4467),
    [anon_sym_XMLPort] = ACTIONS(4467),
    [anon_sym_XmlPort] = ACTIONS(4467),
    [anon_sym_enum] = ACTIONS(4467),
    [anon_sym_ENUM] = ACTIONS(4467),
    [anon_sym_Enum] = ACTIONS(4467),
    [anon_sym_eNUM] = ACTIONS(4467),
    [anon_sym_eNum] = ACTIONS(4467),
    [anon_sym_ENum] = ACTIONS(4467),
    [sym_key_keyword] = ACTIONS(4467),
    [sym_dataset_keyword] = ACTIONS(4467),
    [sym_quoted_identifier] = ACTIONS(4469),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4469),
    [sym_integer] = ACTIONS(4467),
    [sym_continue_as_identifier] = ACTIONS(4469),
    [sym_preproc_open] = ACTIONS(4469),
    [sym_preproc_close] = ACTIONS(4469),
  },
  [STATE(2745)] = {
    [sym__body_element] = STATE(5964),
    [sym_empty_statement] = STATE(5964),
    [sym_property] = STATE(5964),
    [sym_fields_section] = STATE(5964),
    [sym_keys_section] = STATE(5964),
    [sym_fieldgroups_section] = STATE(5964),
    [sym_enum_value_declaration] = STATE(5964),
    [sym_labels_section] = STATE(5964),
    [sym_layout_section] = STATE(5964),
    [sym_modify_modification] = STATE(5964),
    [sym_actions_section] = STATE(5964),
    [sym_views_section] = STATE(5964),
    [sym_dataset_section] = STATE(5964),
    [sym_requestpage_section] = STATE(5964),
    [sym_rendering_section] = STATE(5964),
    [sym_elements_section] = STATE(5964),
    [sym_query_dataitem] = STATE(2789),
    [sym__query_body_element] = STATE(2789),
    [sym_preproc_conditional_query] = STATE(2789),
    [sym_query_column] = STATE(2789),
    [sym_query_filter] = STATE(2789),
    [sym_schema_section] = STATE(5964),
    [sym_assembly_declaration] = STATE(5964),
    [sym_event_declaration] = STATE(5964),
    [sym_procedure] = STATE(5964),
    [sym_preproc_split_procedure] = STATE(5964),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(5964),
    [sym_var_section] = STATE(5964),
    [sym_attribute_item] = STATE(5964),
    [sym_preproc_conditional] = STATE(5964),
    [sym_preproc_if] = STATE(2494),
    [sym_preproc_endif] = STATE(5913),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3482),
    [aux_sym_query_dataitem_repeat1] = STATE(2789),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(2746)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_elif] = STATE(3272),
    [sym_preproc_else] = STATE(3477),
    [sym_preproc_endif] = STATE(5117),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [aux_sym_preproc_conditional_repeat1] = STATE(7868),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(5568),
    [anon_sym_POUNDENDIF] = ACTIONS(5568),
    [anon_sym_POUNDEndif] = ACTIONS(5568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5568),
  },
  [STATE(2747)] = {
    [sym__body_element] = STATE(2652),
    [sym_empty_statement] = STATE(2652),
    [sym_property] = STATE(2652),
    [sym_fields_section] = STATE(2652),
    [sym_keys_section] = STATE(2652),
    [sym_fieldgroups_section] = STATE(2652),
    [sym_enum_value_declaration] = STATE(2652),
    [sym_labels_section] = STATE(2652),
    [sym_layout_section] = STATE(2652),
    [sym_modify_modification] = STATE(2652),
    [sym_actions_section] = STATE(2652),
    [sym_views_section] = STATE(2652),
    [sym_dataset_section] = STATE(2652),
    [sym_requestpage_section] = STATE(2652),
    [sym_rendering_section] = STATE(2652),
    [sym_elements_section] = STATE(2652),
    [sym_schema_section] = STATE(2652),
    [sym_xmlport_element] = STATE(2652),
    [sym__xmlport_body_element] = STATE(2652),
    [sym_preproc_conditional_xmlport] = STATE(2652),
    [sym_xmlport_attribute] = STATE(2652),
    [sym_assembly_declaration] = STATE(2652),
    [sym_event_declaration] = STATE(2652),
    [sym_procedure] = STATE(2652),
    [sym_preproc_split_procedure] = STATE(2652),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(2652),
    [sym_var_section] = STATE(2652),
    [sym_attribute_item] = STATE(2652),
    [sym_preproc_conditional] = STATE(2652),
    [sym_preproc_if] = STATE(2446),
    [sym_preproc_endif] = STATE(5729),
    [aux_sym_xmlport_element_repeat1] = STATE(2652),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDendif] = ACTIONS(5829),
    [anon_sym_POUNDENDIF] = ACTIONS(5829),
    [anon_sym_POUNDEndif] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(5829),
  },
  [STATE(2748)] = {
    [sym__body_element] = STATE(2652),
    [sym_empty_statement] = STATE(2652),
    [sym_property] = STATE(2652),
    [sym_fields_section] = STATE(2652),
    [sym_keys_section] = STATE(2652),
    [sym_fieldgroups_section] = STATE(2652),
    [sym_enum_value_declaration] = STATE(2652),
    [sym_labels_section] = STATE(2652),
    [sym_layout_section] = STATE(2652),
    [sym_modify_modification] = STATE(2652),
    [sym_actions_section] = STATE(2652),
    [sym_views_section] = STATE(2652),
    [sym_dataset_section] = STATE(2652),
    [sym_requestpage_section] = STATE(2652),
    [sym_rendering_section] = STATE(2652),
    [sym_elements_section] = STATE(2652),
    [sym_schema_section] = STATE(2652),
    [sym_xmlport_element] = STATE(2652),
    [sym__xmlport_body_element] = STATE(2652),
    [sym_preproc_conditional_xmlport] = STATE(2652),
    [sym_xmlport_attribute] = STATE(2652),
    [sym_assembly_declaration] = STATE(2652),
    [sym_event_declaration] = STATE(2652),
    [sym_procedure] = STATE(2652),
    [sym_preproc_split_procedure] = STATE(2652),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(2652),
    [sym_var_section] = STATE(2652),
    [sym_attribute_item] = STATE(2652),
    [sym_preproc_conditional] = STATE(2652),
    [sym_preproc_if] = STATE(2446),
    [sym_preproc_endif] = STATE(6592),
    [aux_sym_xmlport_element_repeat1] = STATE(2652),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDendif] = ACTIONS(5869),
    [anon_sym_POUNDENDIF] = ACTIONS(5869),
    [anon_sym_POUNDEndif] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(5869),
  },
  [STATE(2749)] = {
    [sym__body_element] = STATE(2652),
    [sym_empty_statement] = STATE(2652),
    [sym_property] = STATE(2652),
    [sym_fields_section] = STATE(2652),
    [sym_keys_section] = STATE(2652),
    [sym_fieldgroups_section] = STATE(2652),
    [sym_enum_value_declaration] = STATE(2652),
    [sym_labels_section] = STATE(2652),
    [sym_layout_section] = STATE(2652),
    [sym_modify_modification] = STATE(2652),
    [sym_actions_section] = STATE(2652),
    [sym_views_section] = STATE(2652),
    [sym_dataset_section] = STATE(2652),
    [sym_requestpage_section] = STATE(2652),
    [sym_rendering_section] = STATE(2652),
    [sym_elements_section] = STATE(2652),
    [sym_schema_section] = STATE(2652),
    [sym_xmlport_element] = STATE(2652),
    [sym__xmlport_body_element] = STATE(2652),
    [sym_preproc_conditional_xmlport] = STATE(2652),
    [sym_xmlport_attribute] = STATE(2652),
    [sym_assembly_declaration] = STATE(2652),
    [sym_event_declaration] = STATE(2652),
    [sym_procedure] = STATE(2652),
    [sym_preproc_split_procedure] = STATE(2652),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(2652),
    [sym_var_section] = STATE(2652),
    [sym_attribute_item] = STATE(2652),
    [sym_preproc_conditional] = STATE(2652),
    [sym_preproc_if] = STATE(2446),
    [sym_preproc_endif] = STATE(6384),
    [aux_sym_xmlport_element_repeat1] = STATE(2652),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDendif] = ACTIONS(5869),
    [anon_sym_POUNDENDIF] = ACTIONS(5869),
    [anon_sym_POUNDEndif] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(5869),
  },
  [STATE(2750)] = {
    [sym_identifier] = ACTIONS(4463),
    [anon_sym_DASH] = ACTIONS(4465),
    [aux_sym_boolean_token1] = ACTIONS(4463),
    [aux_sym_boolean_token2] = ACTIONS(4463),
    [sym_decimal] = ACTIONS(4463),
    [anon_sym_LPAREN] = ACTIONS(4465),
    [aux_sym_where_condition_token1] = ACTIONS(4463),
    [aux_sym_if_table_relation_token1] = ACTIONS(4463),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4463),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4463),
    [anon_sym_LBRACK] = ACTIONS(4465),
    [aux_sym_record_type_token1] = ACTIONS(4463),
    [aux_sym_basic_type_token21] = ACTIONS(4463),
    [aux_sym_basic_type_token22] = ACTIONS(4463),
    [aux_sym_basic_type_token48] = ACTIONS(4463),
    [aux_sym_basic_type_token53] = ACTIONS(4463),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4463),
    [aux_sym_separator_action_token1] = ACTIONS(4463),
    [aux_sym_type_declaration_token1] = ACTIONS(4463),
    [anon_sym_POUNDif] = ACTIONS(4465),
    [anon_sym_POUNDIF] = ACTIONS(4465),
    [anon_sym_POUNDIf] = ACTIONS(4465),
    [anon_sym_not] = ACTIONS(4463),
    [anon_sym_NOT] = ACTIONS(4463),
    [anon_sym_Not] = ACTIONS(4463),
    [anon_sym_POUNDelif] = ACTIONS(4465),
    [anon_sym_POUNDELIF] = ACTIONS(4465),
    [anon_sym_POUNDElif] = ACTIONS(4465),
    [anon_sym_POUNDelse] = ACTIONS(4465),
    [anon_sym_POUNDELSE] = ACTIONS(4465),
    [anon_sym_POUNDElse] = ACTIONS(4465),
    [anon_sym_POUNDendif] = ACTIONS(4465),
    [anon_sym_POUNDENDIF] = ACTIONS(4465),
    [anon_sym_POUNDEndif] = ACTIONS(4465),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4463),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4463),
    [anon_sym_PLUS] = ACTIONS(4465),
    [sym_datetime_literal] = ACTIONS(4465),
    [sym_date_literal] = ACTIONS(4463),
    [sym_time_literal] = ACTIONS(4463),
    [sym_biginteger_literal] = ACTIONS(4465),
    [sym_table_keyword] = ACTIONS(4463),
    [sym_page_keyword] = ACTIONS(4463),
    [anon_sym_codeunit] = ACTIONS(4463),
    [anon_sym_CODEUNIT] = ACTIONS(4463),
    [anon_sym_Codeunit] = ACTIONS(4463),
    [anon_sym_CodeUnit] = ACTIONS(4463),
    [anon_sym_COdeunit] = ACTIONS(4463),
    [anon_sym_codeUnit] = ACTIONS(4463),
    [sym_report_keyword] = ACTIONS(4463),
    [sym_query_keyword] = ACTIONS(4463),
    [anon_sym_xmlport] = ACTIONS(4463),
    [anon_sym_XMLPORT] = ACTIONS(4463),
    [anon_sym_Xmlport] = ACTIONS(4463),
    [anon_sym_XMLport] = ACTIONS(4463),
    [anon_sym_XMLPort] = ACTIONS(4463),
    [anon_sym_XmlPort] = ACTIONS(4463),
    [anon_sym_enum] = ACTIONS(4463),
    [anon_sym_ENUM] = ACTIONS(4463),
    [anon_sym_Enum] = ACTIONS(4463),
    [anon_sym_eNUM] = ACTIONS(4463),
    [anon_sym_eNum] = ACTIONS(4463),
    [anon_sym_ENum] = ACTIONS(4463),
    [sym_key_keyword] = ACTIONS(4463),
    [sym_dataset_keyword] = ACTIONS(4463),
    [sym_quoted_identifier] = ACTIONS(4465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4465),
    [sym_integer] = ACTIONS(4463),
    [sym_continue_as_identifier] = ACTIONS(4465),
    [sym_preproc_open] = ACTIONS(4465),
    [sym_preproc_close] = ACTIONS(4465),
  },
  [STATE(2751)] = {
    [sym__body_element] = STATE(2754),
    [sym_empty_statement] = STATE(2754),
    [sym_property] = STATE(2754),
    [sym_fields_section] = STATE(2754),
    [sym_keys_section] = STATE(2754),
    [sym_fieldgroups_section] = STATE(2754),
    [sym_enum_value_declaration] = STATE(2754),
    [sym_labels_section] = STATE(2754),
    [sym_layout_section] = STATE(2754),
    [sym_modify_modification] = STATE(2754),
    [sym_actions_section] = STATE(2754),
    [sym_views_section] = STATE(2754),
    [sym_dataset_section] = STATE(2754),
    [sym_requestpage_section] = STATE(2754),
    [sym_rendering_section] = STATE(2754),
    [sym_elements_section] = STATE(2754),
    [sym_schema_section] = STATE(2754),
    [sym_xmlport_element] = STATE(2754),
    [sym__xmlport_body_element] = STATE(2754),
    [sym_preproc_conditional_xmlport] = STATE(2754),
    [sym_xmlport_attribute] = STATE(2754),
    [sym_assembly_declaration] = STATE(2754),
    [sym_event_declaration] = STATE(2754),
    [sym_procedure] = STATE(2754),
    [sym_preproc_split_procedure] = STATE(2754),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(2754),
    [sym_var_section] = STATE(2754),
    [sym_attribute_item] = STATE(2754),
    [sym_preproc_conditional] = STATE(2754),
    [sym_preproc_if] = STATE(2446),
    [sym_preproc_endif] = STATE(5729),
    [aux_sym_xmlport_element_repeat1] = STATE(2754),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDendif] = ACTIONS(5829),
    [anon_sym_POUNDENDIF] = ACTIONS(5829),
    [anon_sym_POUNDEndif] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(5829),
  },
  [STATE(2752)] = {
    [sym__body_element] = STATE(2652),
    [sym_empty_statement] = STATE(2652),
    [sym_property] = STATE(2652),
    [sym_fields_section] = STATE(2652),
    [sym_keys_section] = STATE(2652),
    [sym_fieldgroups_section] = STATE(2652),
    [sym_enum_value_declaration] = STATE(2652),
    [sym_labels_section] = STATE(2652),
    [sym_layout_section] = STATE(2652),
    [sym_modify_modification] = STATE(2652),
    [sym_actions_section] = STATE(2652),
    [sym_views_section] = STATE(2652),
    [sym_dataset_section] = STATE(2652),
    [sym_requestpage_section] = STATE(2652),
    [sym_rendering_section] = STATE(2652),
    [sym_elements_section] = STATE(2652),
    [sym_schema_section] = STATE(2652),
    [sym_xmlport_element] = STATE(2652),
    [sym__xmlport_body_element] = STATE(2652),
    [sym_preproc_conditional_xmlport] = STATE(2652),
    [sym_xmlport_attribute] = STATE(2652),
    [sym_assembly_declaration] = STATE(2652),
    [sym_event_declaration] = STATE(2652),
    [sym_procedure] = STATE(2652),
    [sym_preproc_split_procedure] = STATE(2652),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(2652),
    [sym_var_section] = STATE(2652),
    [sym_attribute_item] = STATE(2652),
    [sym_preproc_conditional] = STATE(2652),
    [sym_preproc_if] = STATE(2446),
    [sym_preproc_endif] = STATE(5823),
    [aux_sym_xmlport_element_repeat1] = STATE(2652),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDendif] = ACTIONS(5829),
    [anon_sym_POUNDENDIF] = ACTIONS(5829),
    [anon_sym_POUNDEndif] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(5829),
  },
  [STATE(2753)] = {
    [sym__body_element] = STATE(2747),
    [sym_empty_statement] = STATE(2747),
    [sym_property] = STATE(2747),
    [sym_fields_section] = STATE(2747),
    [sym_keys_section] = STATE(2747),
    [sym_fieldgroups_section] = STATE(2747),
    [sym_enum_value_declaration] = STATE(2747),
    [sym_labels_section] = STATE(2747),
    [sym_layout_section] = STATE(2747),
    [sym_modify_modification] = STATE(2747),
    [sym_actions_section] = STATE(2747),
    [sym_views_section] = STATE(2747),
    [sym_dataset_section] = STATE(2747),
    [sym_requestpage_section] = STATE(2747),
    [sym_rendering_section] = STATE(2747),
    [sym_elements_section] = STATE(2747),
    [sym_schema_section] = STATE(2747),
    [sym_xmlport_element] = STATE(2747),
    [sym__xmlport_body_element] = STATE(2747),
    [sym_preproc_conditional_xmlport] = STATE(2747),
    [sym_xmlport_attribute] = STATE(2747),
    [sym_assembly_declaration] = STATE(2747),
    [sym_event_declaration] = STATE(2747),
    [sym_procedure] = STATE(2747),
    [sym_preproc_split_procedure] = STATE(2747),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(2747),
    [sym_var_section] = STATE(2747),
    [sym_attribute_item] = STATE(2747),
    [sym_preproc_conditional] = STATE(2747),
    [sym_preproc_if] = STATE(2446),
    [sym_preproc_endif] = STATE(5823),
    [aux_sym_xmlport_element_repeat1] = STATE(2747),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDendif] = ACTIONS(5829),
    [anon_sym_POUNDENDIF] = ACTIONS(5829),
    [anon_sym_POUNDEndif] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(5829),
  },
  [STATE(2754)] = {
    [sym__body_element] = STATE(2652),
    [sym_empty_statement] = STATE(2652),
    [sym_property] = STATE(2652),
    [sym_fields_section] = STATE(2652),
    [sym_keys_section] = STATE(2652),
    [sym_fieldgroups_section] = STATE(2652),
    [sym_enum_value_declaration] = STATE(2652),
    [sym_labels_section] = STATE(2652),
    [sym_layout_section] = STATE(2652),
    [sym_modify_modification] = STATE(2652),
    [sym_actions_section] = STATE(2652),
    [sym_views_section] = STATE(2652),
    [sym_dataset_section] = STATE(2652),
    [sym_requestpage_section] = STATE(2652),
    [sym_rendering_section] = STATE(2652),
    [sym_elements_section] = STATE(2652),
    [sym_schema_section] = STATE(2652),
    [sym_xmlport_element] = STATE(2652),
    [sym__xmlport_body_element] = STATE(2652),
    [sym_preproc_conditional_xmlport] = STATE(2652),
    [sym_xmlport_attribute] = STATE(2652),
    [sym_assembly_declaration] = STATE(2652),
    [sym_event_declaration] = STATE(2652),
    [sym_procedure] = STATE(2652),
    [sym_preproc_split_procedure] = STATE(2652),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(2652),
    [sym_var_section] = STATE(2652),
    [sym_attribute_item] = STATE(2652),
    [sym_preproc_conditional] = STATE(2652),
    [sym_preproc_if] = STATE(2446),
    [sym_preproc_endif] = STATE(5630),
    [aux_sym_xmlport_element_repeat1] = STATE(2652),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDendif] = ACTIONS(5829),
    [anon_sym_POUNDENDIF] = ACTIONS(5829),
    [anon_sym_POUNDEndif] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(5829),
  },
  [STATE(2755)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_elif] = STATE(3272),
    [sym_preproc_else] = STATE(3508),
    [sym_preproc_endif] = STATE(3571),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [aux_sym_preproc_conditional_repeat1] = STATE(8169),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(2756)] = {
    [sym__body_element] = STATE(5964),
    [sym_empty_statement] = STATE(5964),
    [sym_property] = STATE(5964),
    [sym_fields_section] = STATE(5964),
    [sym_keys_section] = STATE(5964),
    [sym_fieldgroups_section] = STATE(5964),
    [sym_enum_value_declaration] = STATE(5964),
    [sym_labels_section] = STATE(5964),
    [sym_layout_section] = STATE(5964),
    [sym_modify_modification] = STATE(5964),
    [sym_actions_section] = STATE(5964),
    [sym_views_section] = STATE(5964),
    [sym_dataset_section] = STATE(5964),
    [sym_requestpage_section] = STATE(5964),
    [sym_rendering_section] = STATE(5964),
    [sym_elements_section] = STATE(5964),
    [sym_query_dataitem] = STATE(2781),
    [sym__query_body_element] = STATE(2781),
    [sym_preproc_conditional_query] = STATE(2781),
    [sym_query_column] = STATE(2781),
    [sym_query_filter] = STATE(2781),
    [sym_schema_section] = STATE(5964),
    [sym_assembly_declaration] = STATE(5964),
    [sym_event_declaration] = STATE(5964),
    [sym_procedure] = STATE(5964),
    [sym_preproc_split_procedure] = STATE(5964),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(5964),
    [sym_var_section] = STATE(5964),
    [sym_attribute_item] = STATE(5964),
    [sym_preproc_conditional] = STATE(5964),
    [sym_preproc_if] = STATE(2494),
    [sym_preproc_endif] = STATE(6810),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3490),
    [aux_sym_query_dataitem_repeat1] = STATE(2781),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(2757)] = {
    [sym_boolean] = STATE(7263),
    [sym_option_member] = STATE(7338),
    [sym_keyword_identifier] = STATE(7263),
    [sym_codeunit_keyword] = STATE(7278),
    [sym_xmlport_keyword] = STATE(7278),
    [sym_enum_keyword] = STATE(7278),
    [sym_keyword_as_identifier] = STATE(7263),
    [sym_identifier] = ACTIONS(6593),
    [anon_sym_SEMI] = ACTIONS(389),
    [anon_sym_COMMA] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(6597),
    [aux_sym_boolean_token1] = ACTIONS(6599),
    [aux_sym_boolean_token2] = ACTIONS(6599),
    [aux_sym_where_condition_token1] = ACTIONS(6601),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6603),
    [aux_sym_record_type_token1] = ACTIONS(6603),
    [aux_sym_basic_type_token21] = ACTIONS(6603),
    [aux_sym_basic_type_token22] = ACTIONS(6605),
    [aux_sym_basic_type_token48] = ACTIONS(6603),
    [aux_sym_basic_type_token53] = ACTIONS(6601),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6601),
    [aux_sym_separator_action_token1] = ACTIONS(6601),
    [aux_sym_type_declaration_token1] = ACTIONS(6601),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(391),
    [anon_sym_POUNDif] = ACTIONS(389),
    [anon_sym_POUNDIF] = ACTIONS(389),
    [anon_sym_POUNDIf] = ACTIONS(389),
    [anon_sym_POUNDelif] = ACTIONS(389),
    [anon_sym_POUNDELIF] = ACTIONS(389),
    [anon_sym_POUNDElif] = ACTIONS(389),
    [anon_sym_POUNDelse] = ACTIONS(389),
    [anon_sym_POUNDELSE] = ACTIONS(389),
    [anon_sym_POUNDElse] = ACTIONS(389),
    [anon_sym_POUNDendif] = ACTIONS(389),
    [anon_sym_POUNDENDIF] = ACTIONS(389),
    [anon_sym_POUNDEndif] = ACTIONS(389),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6603),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6603),
    [sym_page_keyword] = ACTIONS(6603),
    [anon_sym_codeunit] = ACTIONS(6607),
    [anon_sym_CODEUNIT] = ACTIONS(6607),
    [anon_sym_Codeunit] = ACTIONS(6607),
    [anon_sym_CodeUnit] = ACTIONS(6607),
    [anon_sym_COdeunit] = ACTIONS(6607),
    [anon_sym_codeUnit] = ACTIONS(6607),
    [sym_report_keyword] = ACTIONS(6603),
    [sym_query_keyword] = ACTIONS(6603),
    [anon_sym_xmlport] = ACTIONS(6609),
    [anon_sym_XMLPORT] = ACTIONS(6609),
    [anon_sym_Xmlport] = ACTIONS(6609),
    [anon_sym_XMLport] = ACTIONS(6609),
    [anon_sym_XMLPort] = ACTIONS(6609),
    [anon_sym_XmlPort] = ACTIONS(6609),
    [anon_sym_enum] = ACTIONS(6611),
    [anon_sym_ENUM] = ACTIONS(6611),
    [anon_sym_Enum] = ACTIONS(6611),
    [anon_sym_eNUM] = ACTIONS(6611),
    [anon_sym_eNum] = ACTIONS(6611),
    [anon_sym_ENum] = ACTIONS(6611),
    [sym_var_keyword] = ACTIONS(391),
    [sym_local_keyword] = ACTIONS(6724),
    [sym_internal_keyword] = ACTIONS(6593),
    [sym_protected_keyword] = ACTIONS(6724),
    [sym_key_keyword] = ACTIONS(6601),
    [sym_dataset_keyword] = ACTIONS(6601),
    [sym_quoted_identifier] = ACTIONS(6613),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6613),
    [sym_integer] = ACTIONS(6613),
    [sym_preproc_open] = ACTIONS(389),
    [sym_preproc_close] = ACTIONS(389),
    [sym_begin_keyword] = ACTIONS(389),
  },
  [STATE(2758)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_elif] = STATE(3272),
    [sym_preproc_else] = STATE(3468),
    [sym_preproc_endif] = STATE(6711),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [aux_sym_preproc_conditional_repeat1] = STATE(7934),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(2877),
    [anon_sym_POUNDELIF] = ACTIONS(2877),
    [anon_sym_POUNDElif] = ACTIONS(2877),
    [anon_sym_POUNDelse] = ACTIONS(2879),
    [anon_sym_POUNDELSE] = ACTIONS(2879),
    [anon_sym_POUNDElse] = ACTIONS(2879),
    [anon_sym_POUNDendif] = ACTIONS(5869),
    [anon_sym_POUNDENDIF] = ACTIONS(5869),
    [anon_sym_POUNDEndif] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5869),
  },
  [STATE(2759)] = {
    [sym__body_element] = STATE(2743),
    [sym_empty_statement] = STATE(2743),
    [sym_property] = STATE(2743),
    [sym_fields_section] = STATE(2743),
    [sym_keys_section] = STATE(2743),
    [sym_fieldgroups_section] = STATE(2743),
    [sym_enum_value_declaration] = STATE(2743),
    [sym_labels_section] = STATE(2743),
    [sym_layout_section] = STATE(2743),
    [sym_modify_modification] = STATE(2743),
    [sym_actions_section] = STATE(2743),
    [sym_views_section] = STATE(2743),
    [sym_dataset_section] = STATE(2743),
    [sym_requestpage_section] = STATE(2743),
    [sym_rendering_section] = STATE(2743),
    [sym_elements_section] = STATE(2743),
    [sym_schema_section] = STATE(2743),
    [sym_xmlport_element] = STATE(2743),
    [sym__xmlport_body_element] = STATE(2743),
    [sym_preproc_conditional_xmlport] = STATE(2743),
    [sym_xmlport_attribute] = STATE(2743),
    [sym_assembly_declaration] = STATE(2743),
    [sym_event_declaration] = STATE(2743),
    [sym_procedure] = STATE(2743),
    [sym_preproc_split_procedure] = STATE(2743),
    [sym_procedure_modifier] = STATE(12431),
    [sym_trigger_declaration] = STATE(2743),
    [sym_var_section] = STATE(2743),
    [sym_attribute_item] = STATE(2743),
    [sym_preproc_conditional] = STATE(2743),
    [sym_preproc_if] = STATE(2446),
    [sym_preproc_endif] = STATE(6592),
    [aux_sym_xmlport_element_repeat1] = STATE(2743),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5813),
    [aux_sym_modify_modification_token1] = ACTIONS(5815),
    [aux_sym_xmlport_element_token1] = ACTIONS(5817),
    [aux_sym_xmlport_element_token2] = ACTIONS(5817),
    [aux_sym_xmlport_element_token3] = ACTIONS(5817),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5819),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5821),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [anon_sym_POUNDendif] = ACTIONS(5869),
    [anon_sym_POUNDENDIF] = ACTIONS(5869),
    [anon_sym_POUNDEndif] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6007),
    [sym_trigger_keyword] = ACTIONS(5833),
    [sym_var_keyword] = ACTIONS(5835),
    [sym_local_keyword] = ACTIONS(5837),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(5837),
    [sym_event_keyword] = ACTIONS(5839),
    [sym_fields_keyword] = ACTIONS(5841),
    [sym_keys_keyword] = ACTIONS(5843),
    [sym_fieldgroups_keyword] = ACTIONS(5845),
    [sym_actions_keyword] = ACTIONS(5847),
    [sym_layout_keyword] = ACTIONS(5849),
    [sym_dataset_keyword] = ACTIONS(5851),
    [sym_elements_keyword] = ACTIONS(5853),
    [sym_labels_keyword] = ACTIONS(5855),
    [sym_rendering_keyword] = ACTIONS(5857),
    [sym_requestpage_keyword] = ACTIONS(5859),
    [sym_schema_keyword] = ACTIONS(5861),
    [sym_views_keyword] = ACTIONS(5863),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5823),
    [sym_preproc_close] = ACTIONS(5869),
  },
  [STATE(2760)] = {
    [sym_boolean] = STATE(6221),
    [sym_assignment_expression] = STATE(6221),
    [sym__expression] = STATE(6221),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6221),
    [sym_multiplicative_expression] = STATE(6221),
    [sym_additive_expression] = STATE(6221),
    [sym_comparison_expression] = STATE(6221),
    [sym_logical_expression] = STATE(6221),
    [sym_ternary_expression] = STATE(6221),
    [sym_unary_expression] = STATE(6221),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6221),
    [sym_list_literal] = STATE(6221),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6221),
    [sym__literal_value] = STATE(6221),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6727),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6729),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6731),
    [sym_date_literal] = ACTIONS(6727),
    [sym_time_literal] = ACTIONS(6727),
    [sym_biginteger_literal] = ACTIONS(6731),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6731),
    [sym_integer] = ACTIONS(6727),
    [sym_continue_as_identifier] = ACTIONS(6731),
  },
  [STATE(2761)] = {
    [sym_boolean] = STATE(6331),
    [sym__attribute_argument] = STATE(11229),
    [sym_assignment_expression] = STATE(6345),
    [sym__expression] = STATE(6345),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6345),
    [sym_multiplicative_expression] = STATE(6345),
    [sym_additive_expression] = STATE(6345),
    [sym_comparison_expression] = STATE(6345),
    [sym_logical_expression] = STATE(6345),
    [sym_ternary_expression] = STATE(6345),
    [sym_unary_expression] = STATE(6345),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(6219),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6345),
    [sym_list_literal] = STATE(6345),
    [sym_qualified_enum_value] = STATE(6219),
    [sym_database_reference] = STATE(6358),
    [sym__literal_value] = STATE(6345),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6712),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(5457),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5457),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6716),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6718),
    [sym_integer] = ACTIONS(6720),
    [sym_continue_as_identifier] = ACTIONS(5457),
  },
  [STATE(2762)] = {
    [sym_boolean] = STATE(6236),
    [sym_assignment_expression] = STATE(6236),
    [sym__expression] = STATE(6236),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6236),
    [sym_multiplicative_expression] = STATE(6236),
    [sym_additive_expression] = STATE(6236),
    [sym_comparison_expression] = STATE(6236),
    [sym_logical_expression] = STATE(6236),
    [sym_ternary_expression] = STATE(6236),
    [sym_unary_expression] = STATE(6236),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6236),
    [sym_list_literal] = STATE(6236),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6236),
    [sym__literal_value] = STATE(6236),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6733),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_RBRACK] = ACTIONS(6735),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6737),
    [sym_date_literal] = ACTIONS(6733),
    [sym_time_literal] = ACTIONS(6733),
    [sym_biginteger_literal] = ACTIONS(6737),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6737),
    [sym_integer] = ACTIONS(6733),
    [sym_continue_as_identifier] = ACTIONS(6737),
  },
  [STATE(2763)] = {
    [sym__body_element] = STATE(2769),
    [sym_empty_statement] = STATE(2769),
    [sym_property] = STATE(2769),
    [sym_fields_section] = STATE(2769),
    [sym_keys_section] = STATE(2769),
    [sym_fieldgroups_section] = STATE(2769),
    [sym_enum_value_declaration] = STATE(2769),
    [sym_labels_section] = STATE(2769),
    [sym_layout_section] = STATE(2769),
    [sym_modify_modification] = STATE(2769),
    [sym_actions_section] = STATE(2769),
    [sym_views_section] = STATE(2769),
    [sym_dataset_section] = STATE(2769),
    [sym_requestpage_section] = STATE(2769),
    [sym_rendering_section] = STATE(2769),
    [sym_elements_section] = STATE(2769),
    [sym_query_dataitem] = STATE(2769),
    [sym__query_body_element] = STATE(2769),
    [sym_preproc_conditional_query] = STATE(2769),
    [sym_query_column] = STATE(2769),
    [sym_query_filter] = STATE(2769),
    [sym_schema_section] = STATE(2769),
    [sym_assembly_declaration] = STATE(2769),
    [sym_event_declaration] = STATE(2769),
    [sym_procedure] = STATE(2769),
    [sym_preproc_split_procedure] = STATE(2769),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2769),
    [sym_var_section] = STATE(2769),
    [sym_attribute_item] = STATE(2769),
    [sym_preproc_conditional] = STATE(2769),
    [sym_preproc_if] = STATE(2494),
    [sym_preproc_endif] = STATE(6842),
    [aux_sym_query_dataitem_repeat1] = STATE(2769),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(2764)] = {
    [sym_boolean] = STATE(6328),
    [sym__field_source] = STATE(12187),
    [sym_assignment_expression] = STATE(6328),
    [sym__expression] = STATE(6328),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6328),
    [sym_multiplicative_expression] = STATE(6328),
    [sym_additive_expression] = STATE(6328),
    [sym_comparison_expression] = STATE(6328),
    [sym_logical_expression] = STATE(6328),
    [sym_ternary_expression] = STATE(6328),
    [sym_unary_expression] = STATE(6328),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6328),
    [sym_list_literal] = STATE(6328),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6328),
    [sym__literal_value] = STATE(6328),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6739),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6741),
    [sym_date_literal] = ACTIONS(6739),
    [sym_time_literal] = ACTIONS(6739),
    [sym_biginteger_literal] = ACTIONS(6741),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6741),
    [sym_integer] = ACTIONS(6739),
    [sym_continue_as_identifier] = ACTIONS(6741),
  },
  [STATE(2765)] = {
    [sym_boolean] = STATE(6237),
    [sym_assignment_expression] = STATE(6237),
    [sym__expression] = STATE(6237),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6237),
    [sym_multiplicative_expression] = STATE(6237),
    [sym_additive_expression] = STATE(6237),
    [sym_comparison_expression] = STATE(6237),
    [sym_logical_expression] = STATE(6237),
    [sym_ternary_expression] = STATE(6237),
    [sym_unary_expression] = STATE(6237),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6237),
    [sym_list_literal] = STATE(6237),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6237),
    [sym__literal_value] = STATE(6237),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6743),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_RBRACK] = ACTIONS(6745),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6747),
    [sym_date_literal] = ACTIONS(6743),
    [sym_time_literal] = ACTIONS(6743),
    [sym_biginteger_literal] = ACTIONS(6747),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6747),
    [sym_integer] = ACTIONS(6743),
    [sym_continue_as_identifier] = ACTIONS(6747),
  },
  [STATE(2766)] = {
    [sym_boolean] = STATE(6234),
    [sym_assignment_expression] = STATE(6234),
    [sym__expression] = STATE(6234),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6234),
    [sym_multiplicative_expression] = STATE(6234),
    [sym_additive_expression] = STATE(6234),
    [sym_comparison_expression] = STATE(6234),
    [sym_logical_expression] = STATE(6234),
    [sym_ternary_expression] = STATE(6234),
    [sym_unary_expression] = STATE(6234),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6234),
    [sym_list_literal] = STATE(6234),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6234),
    [sym__literal_value] = STATE(6234),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6749),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_RBRACK] = ACTIONS(6751),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6753),
    [sym_date_literal] = ACTIONS(6749),
    [sym_time_literal] = ACTIONS(6749),
    [sym_biginteger_literal] = ACTIONS(6753),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6753),
    [sym_integer] = ACTIONS(6749),
    [sym_continue_as_identifier] = ACTIONS(6753),
  },
  [STATE(2767)] = {
    [sym_boolean] = STATE(6291),
    [sym_assignment_expression] = STATE(6291),
    [sym__expression] = STATE(6291),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6291),
    [sym_multiplicative_expression] = STATE(6291),
    [sym_additive_expression] = STATE(6291),
    [sym_comparison_expression] = STATE(6291),
    [sym_logical_expression] = STATE(6291),
    [sym_ternary_expression] = STATE(6291),
    [sym_unary_expression] = STATE(6291),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6291),
    [sym_list_literal] = STATE(6291),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6291),
    [sym__literal_value] = STATE(6291),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6755),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6757),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6759),
    [sym_date_literal] = ACTIONS(6755),
    [sym_time_literal] = ACTIONS(6755),
    [sym_biginteger_literal] = ACTIONS(6759),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6759),
    [sym_integer] = ACTIONS(6755),
    [sym_continue_as_identifier] = ACTIONS(6759),
  },
  [STATE(2768)] = {
    [sym_boolean] = STATE(6377),
    [sym_assignment_expression] = STATE(6345),
    [sym__expression] = STATE(6345),
    [sym_keyword_identifier] = STATE(6259),
    [sym_range_expression] = STATE(6345),
    [sym_multiplicative_expression] = STATE(6345),
    [sym_additive_expression] = STATE(6345),
    [sym_comparison_expression] = STATE(6345),
    [sym_logical_expression] = STATE(6345),
    [sym_ternary_expression] = STATE(6345),
    [sym_unary_expression] = STATE(6345),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6345),
    [sym_list_literal] = STATE(6345),
    [sym_qualified_enum_value] = STATE(6259),
    [sym_database_reference] = STATE(6378),
    [sym__literal_value] = STATE(6345),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6761),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6763),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(5457),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5457),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6765),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6767),
    [sym_integer] = ACTIONS(6769),
    [sym_continue_as_identifier] = ACTIONS(5457),
  },
  [STATE(2769)] = {
    [sym__body_element] = STATE(2713),
    [sym_empty_statement] = STATE(2713),
    [sym_property] = STATE(2713),
    [sym_fields_section] = STATE(2713),
    [sym_keys_section] = STATE(2713),
    [sym_fieldgroups_section] = STATE(2713),
    [sym_enum_value_declaration] = STATE(2713),
    [sym_labels_section] = STATE(2713),
    [sym_layout_section] = STATE(2713),
    [sym_modify_modification] = STATE(2713),
    [sym_actions_section] = STATE(2713),
    [sym_views_section] = STATE(2713),
    [sym_dataset_section] = STATE(2713),
    [sym_requestpage_section] = STATE(2713),
    [sym_rendering_section] = STATE(2713),
    [sym_elements_section] = STATE(2713),
    [sym_query_dataitem] = STATE(2713),
    [sym__query_body_element] = STATE(2713),
    [sym_preproc_conditional_query] = STATE(2713),
    [sym_query_column] = STATE(2713),
    [sym_query_filter] = STATE(2713),
    [sym_schema_section] = STATE(2713),
    [sym_assembly_declaration] = STATE(2713),
    [sym_event_declaration] = STATE(2713),
    [sym_procedure] = STATE(2713),
    [sym_preproc_split_procedure] = STATE(2713),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2713),
    [sym_var_section] = STATE(2713),
    [sym_attribute_item] = STATE(2713),
    [sym_preproc_conditional] = STATE(2713),
    [sym_preproc_if] = STATE(2494),
    [sym_preproc_endif] = STATE(6818),
    [aux_sym_query_dataitem_repeat1] = STATE(2713),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(2770)] = {
    [sym_boolean] = STATE(6227),
    [sym_assignment_expression] = STATE(6227),
    [sym__expression] = STATE(6227),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6227),
    [sym_multiplicative_expression] = STATE(6227),
    [sym_additive_expression] = STATE(6227),
    [sym_comparison_expression] = STATE(6227),
    [sym_logical_expression] = STATE(6227),
    [sym_ternary_expression] = STATE(6227),
    [sym_unary_expression] = STATE(6227),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6227),
    [sym_list_literal] = STATE(6227),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6227),
    [sym__literal_value] = STATE(6227),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6771),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6773),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6775),
    [sym_date_literal] = ACTIONS(6771),
    [sym_time_literal] = ACTIONS(6771),
    [sym_biginteger_literal] = ACTIONS(6775),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6775),
    [sym_integer] = ACTIONS(6771),
    [sym_continue_as_identifier] = ACTIONS(6775),
  },
  [STATE(2771)] = {
    [sym_boolean] = STATE(6206),
    [sym_assignment_expression] = STATE(6206),
    [sym__expression] = STATE(6206),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6206),
    [sym_multiplicative_expression] = STATE(6206),
    [sym_additive_expression] = STATE(6206),
    [sym_comparison_expression] = STATE(6206),
    [sym_logical_expression] = STATE(6206),
    [sym_ternary_expression] = STATE(6206),
    [sym_unary_expression] = STATE(6206),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6206),
    [sym_list_literal] = STATE(6206),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6206),
    [sym__literal_value] = STATE(6206),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6777),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6779),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6781),
    [sym_date_literal] = ACTIONS(6777),
    [sym_time_literal] = ACTIONS(6777),
    [sym_biginteger_literal] = ACTIONS(6781),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6781),
    [sym_integer] = ACTIONS(6777),
    [sym_continue_as_identifier] = ACTIONS(6781),
  },
  [STATE(2772)] = {
    [sym_boolean] = STATE(6328),
    [sym__field_source] = STATE(11506),
    [sym_assignment_expression] = STATE(6328),
    [sym__expression] = STATE(6328),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6328),
    [sym_multiplicative_expression] = STATE(6328),
    [sym_additive_expression] = STATE(6328),
    [sym_comparison_expression] = STATE(6328),
    [sym_logical_expression] = STATE(6328),
    [sym_ternary_expression] = STATE(6328),
    [sym_unary_expression] = STATE(6328),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6328),
    [sym_list_literal] = STATE(6328),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6328),
    [sym__literal_value] = STATE(6328),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6739),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6741),
    [sym_date_literal] = ACTIONS(6739),
    [sym_time_literal] = ACTIONS(6739),
    [sym_biginteger_literal] = ACTIONS(6741),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6741),
    [sym_integer] = ACTIONS(6739),
    [sym_continue_as_identifier] = ACTIONS(6741),
  },
  [STATE(2773)] = {
    [sym_boolean] = STATE(6328),
    [sym__field_source] = STATE(11993),
    [sym_assignment_expression] = STATE(6328),
    [sym__expression] = STATE(6328),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6328),
    [sym_multiplicative_expression] = STATE(6328),
    [sym_additive_expression] = STATE(6328),
    [sym_comparison_expression] = STATE(6328),
    [sym_logical_expression] = STATE(6328),
    [sym_ternary_expression] = STATE(6328),
    [sym_unary_expression] = STATE(6328),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6328),
    [sym_list_literal] = STATE(6328),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6328),
    [sym__literal_value] = STATE(6328),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6739),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6741),
    [sym_date_literal] = ACTIONS(6739),
    [sym_time_literal] = ACTIONS(6739),
    [sym_biginteger_literal] = ACTIONS(6741),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6741),
    [sym_integer] = ACTIONS(6739),
    [sym_continue_as_identifier] = ACTIONS(6741),
  },
  [STATE(2774)] = {
    [sym_boolean] = STATE(6380),
    [sym_assignment_expression] = STATE(6345),
    [sym__expression] = STATE(6345),
    [sym_keyword_identifier] = STATE(6267),
    [sym_range_expression] = STATE(6345),
    [sym_multiplicative_expression] = STATE(6345),
    [sym_additive_expression] = STATE(6345),
    [sym_comparison_expression] = STATE(6345),
    [sym_logical_expression] = STATE(6345),
    [sym_ternary_expression] = STATE(6345),
    [sym_unary_expression] = STATE(6345),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6345),
    [sym_list_literal] = STATE(6345),
    [sym_qualified_enum_value] = STATE(6267),
    [sym_database_reference] = STATE(6364),
    [sym__literal_value] = STATE(6345),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6783),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6785),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(5457),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5457),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6787),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6789),
    [sym_integer] = ACTIONS(6791),
    [sym_continue_as_identifier] = ACTIONS(5457),
  },
  [STATE(2775)] = {
    [sym_boolean] = STATE(6317),
    [sym__field_source] = STATE(11993),
    [sym_assignment_expression] = STATE(6317),
    [sym__expression] = STATE(6317),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6317),
    [sym_multiplicative_expression] = STATE(6317),
    [sym_additive_expression] = STATE(6317),
    [sym_comparison_expression] = STATE(6317),
    [sym_logical_expression] = STATE(6317),
    [sym_ternary_expression] = STATE(6317),
    [sym_unary_expression] = STATE(6317),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6317),
    [sym_list_literal] = STATE(6317),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6317),
    [sym__literal_value] = STATE(6317),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6793),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6795),
    [sym_date_literal] = ACTIONS(6793),
    [sym_time_literal] = ACTIONS(6793),
    [sym_biginteger_literal] = ACTIONS(6795),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6795),
    [sym_integer] = ACTIONS(6793),
    [sym_continue_as_identifier] = ACTIONS(6795),
  },
  [STATE(2776)] = {
    [sym__body_element] = STATE(2797),
    [sym_empty_statement] = STATE(2797),
    [sym_property] = STATE(2797),
    [sym_fields_section] = STATE(2797),
    [sym_keys_section] = STATE(2797),
    [sym_fieldgroups_section] = STATE(2797),
    [sym_enum_value_declaration] = STATE(2797),
    [sym_labels_section] = STATE(2797),
    [sym_layout_section] = STATE(2797),
    [sym_modify_modification] = STATE(2797),
    [sym_actions_section] = STATE(2797),
    [sym_views_section] = STATE(2797),
    [sym_dataset_section] = STATE(2797),
    [sym_requestpage_section] = STATE(2797),
    [sym_rendering_section] = STATE(2797),
    [sym_elements_section] = STATE(2797),
    [sym_query_dataitem] = STATE(2797),
    [sym__query_body_element] = STATE(2797),
    [sym_preproc_conditional_query] = STATE(2797),
    [sym_query_column] = STATE(2797),
    [sym_query_filter] = STATE(2797),
    [sym_schema_section] = STATE(2797),
    [sym_assembly_declaration] = STATE(2797),
    [sym_event_declaration] = STATE(2797),
    [sym_procedure] = STATE(2797),
    [sym_preproc_split_procedure] = STATE(2797),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2797),
    [sym_var_section] = STATE(2797),
    [sym_attribute_item] = STATE(2797),
    [sym_preproc_conditional] = STATE(2797),
    [sym_preproc_if] = STATE(2494),
    [sym_preproc_endif] = STATE(6805),
    [aux_sym_query_dataitem_repeat1] = STATE(2797),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(2777)] = {
    [sym_boolean] = STATE(6205),
    [sym_assignment_expression] = STATE(6205),
    [sym__expression] = STATE(6205),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6205),
    [sym_multiplicative_expression] = STATE(6205),
    [sym_additive_expression] = STATE(6205),
    [sym_comparison_expression] = STATE(6205),
    [sym_logical_expression] = STATE(6205),
    [sym_ternary_expression] = STATE(6205),
    [sym_unary_expression] = STATE(6205),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6205),
    [sym_list_literal] = STATE(6205),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6205),
    [sym__literal_value] = STATE(6205),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6797),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_RBRACK] = ACTIONS(6799),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6801),
    [sym_date_literal] = ACTIONS(6797),
    [sym_time_literal] = ACTIONS(6797),
    [sym_biginteger_literal] = ACTIONS(6801),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6801),
    [sym_integer] = ACTIONS(6797),
    [sym_continue_as_identifier] = ACTIONS(6801),
  },
  [STATE(2778)] = {
    [sym_boolean] = STATE(6297),
    [sym_assignment_expression] = STATE(6297),
    [sym__expression] = STATE(6297),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6297),
    [sym_multiplicative_expression] = STATE(6297),
    [sym_additive_expression] = STATE(6297),
    [sym_comparison_expression] = STATE(6297),
    [sym_logical_expression] = STATE(6297),
    [sym_ternary_expression] = STATE(6297),
    [sym_unary_expression] = STATE(6297),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6297),
    [sym_list_literal] = STATE(6297),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6297),
    [sym__literal_value] = STATE(6297),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6803),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6805),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6807),
    [sym_date_literal] = ACTIONS(6803),
    [sym_time_literal] = ACTIONS(6803),
    [sym_biginteger_literal] = ACTIONS(6807),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6807),
    [sym_integer] = ACTIONS(6803),
    [sym_continue_as_identifier] = ACTIONS(6807),
  },
  [STATE(2779)] = {
    [sym_boolean] = STATE(6328),
    [sym__field_source] = STATE(12536),
    [sym_assignment_expression] = STATE(6328),
    [sym__expression] = STATE(6328),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6328),
    [sym_multiplicative_expression] = STATE(6328),
    [sym_additive_expression] = STATE(6328),
    [sym_comparison_expression] = STATE(6328),
    [sym_logical_expression] = STATE(6328),
    [sym_ternary_expression] = STATE(6328),
    [sym_unary_expression] = STATE(6328),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6328),
    [sym_list_literal] = STATE(6328),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6328),
    [sym__literal_value] = STATE(6328),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6739),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6741),
    [sym_date_literal] = ACTIONS(6739),
    [sym_time_literal] = ACTIONS(6739),
    [sym_biginteger_literal] = ACTIONS(6741),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6741),
    [sym_integer] = ACTIONS(6739),
    [sym_continue_as_identifier] = ACTIONS(6741),
  },
  [STATE(2780)] = {
    [sym_boolean] = STATE(6328),
    [sym__field_source] = STATE(11429),
    [sym_assignment_expression] = STATE(6328),
    [sym__expression] = STATE(6328),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6328),
    [sym_multiplicative_expression] = STATE(6328),
    [sym_additive_expression] = STATE(6328),
    [sym_comparison_expression] = STATE(6328),
    [sym_logical_expression] = STATE(6328),
    [sym_ternary_expression] = STATE(6328),
    [sym_unary_expression] = STATE(6328),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6328),
    [sym_list_literal] = STATE(6328),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6328),
    [sym__literal_value] = STATE(6328),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6739),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6741),
    [sym_date_literal] = ACTIONS(6739),
    [sym_time_literal] = ACTIONS(6739),
    [sym_biginteger_literal] = ACTIONS(6741),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6741),
    [sym_integer] = ACTIONS(6739),
    [sym_continue_as_identifier] = ACTIONS(6741),
  },
  [STATE(2781)] = {
    [sym__body_element] = STATE(2713),
    [sym_empty_statement] = STATE(2713),
    [sym_property] = STATE(2713),
    [sym_fields_section] = STATE(2713),
    [sym_keys_section] = STATE(2713),
    [sym_fieldgroups_section] = STATE(2713),
    [sym_enum_value_declaration] = STATE(2713),
    [sym_labels_section] = STATE(2713),
    [sym_layout_section] = STATE(2713),
    [sym_modify_modification] = STATE(2713),
    [sym_actions_section] = STATE(2713),
    [sym_views_section] = STATE(2713),
    [sym_dataset_section] = STATE(2713),
    [sym_requestpage_section] = STATE(2713),
    [sym_rendering_section] = STATE(2713),
    [sym_elements_section] = STATE(2713),
    [sym_query_dataitem] = STATE(2713),
    [sym__query_body_element] = STATE(2713),
    [sym_preproc_conditional_query] = STATE(2713),
    [sym_query_column] = STATE(2713),
    [sym_query_filter] = STATE(2713),
    [sym_schema_section] = STATE(2713),
    [sym_assembly_declaration] = STATE(2713),
    [sym_event_declaration] = STATE(2713),
    [sym_procedure] = STATE(2713),
    [sym_preproc_split_procedure] = STATE(2713),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2713),
    [sym_var_section] = STATE(2713),
    [sym_attribute_item] = STATE(2713),
    [sym_preproc_conditional] = STATE(2713),
    [sym_preproc_if] = STATE(2494),
    [sym_preproc_endif] = STATE(6805),
    [aux_sym_query_dataitem_repeat1] = STATE(2713),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(2782)] = {
    [sym_boolean] = STATE(6328),
    [sym__field_source] = STATE(11490),
    [sym_assignment_expression] = STATE(6328),
    [sym__expression] = STATE(6328),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6328),
    [sym_multiplicative_expression] = STATE(6328),
    [sym_additive_expression] = STATE(6328),
    [sym_comparison_expression] = STATE(6328),
    [sym_logical_expression] = STATE(6328),
    [sym_ternary_expression] = STATE(6328),
    [sym_unary_expression] = STATE(6328),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6328),
    [sym_list_literal] = STATE(6328),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6328),
    [sym__literal_value] = STATE(6328),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6739),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6741),
    [sym_date_literal] = ACTIONS(6739),
    [sym_time_literal] = ACTIONS(6739),
    [sym_biginteger_literal] = ACTIONS(6741),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6741),
    [sym_integer] = ACTIONS(6739),
    [sym_continue_as_identifier] = ACTIONS(6741),
  },
  [STATE(2783)] = {
    [sym_boolean] = STATE(6320),
    [sym_assignment_expression] = STATE(6320),
    [sym__expression] = STATE(6320),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6320),
    [sym_multiplicative_expression] = STATE(6320),
    [sym_additive_expression] = STATE(6320),
    [sym_comparison_expression] = STATE(6320),
    [sym_logical_expression] = STATE(6320),
    [sym_ternary_expression] = STATE(6320),
    [sym_unary_expression] = STATE(6320),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6320),
    [sym_list_literal] = STATE(6320),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6320),
    [sym__literal_value] = STATE(6320),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6809),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6811),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6813),
    [sym_date_literal] = ACTIONS(6809),
    [sym_time_literal] = ACTIONS(6809),
    [sym_biginteger_literal] = ACTIONS(6813),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6813),
    [sym_integer] = ACTIONS(6809),
    [sym_continue_as_identifier] = ACTIONS(6813),
  },
  [STATE(2784)] = {
    [sym_boolean] = STATE(6208),
    [sym_assignment_expression] = STATE(6208),
    [sym__expression] = STATE(6208),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6208),
    [sym_multiplicative_expression] = STATE(6208),
    [sym_additive_expression] = STATE(6208),
    [sym_comparison_expression] = STATE(6208),
    [sym_logical_expression] = STATE(6208),
    [sym_ternary_expression] = STATE(6208),
    [sym_unary_expression] = STATE(6208),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6208),
    [sym_list_literal] = STATE(6208),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6208),
    [sym__literal_value] = STATE(6208),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6815),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6817),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6819),
    [sym_date_literal] = ACTIONS(6815),
    [sym_time_literal] = ACTIONS(6815),
    [sym_biginteger_literal] = ACTIONS(6819),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6819),
    [sym_integer] = ACTIONS(6815),
    [sym_continue_as_identifier] = ACTIONS(6819),
  },
  [STATE(2785)] = {
    [sym_boolean] = STATE(6223),
    [sym_assignment_expression] = STATE(6223),
    [sym__expression] = STATE(6223),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6223),
    [sym_multiplicative_expression] = STATE(6223),
    [sym_additive_expression] = STATE(6223),
    [sym_comparison_expression] = STATE(6223),
    [sym_logical_expression] = STATE(6223),
    [sym_ternary_expression] = STATE(6223),
    [sym_unary_expression] = STATE(6223),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6223),
    [sym_list_literal] = STATE(6223),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6223),
    [sym__literal_value] = STATE(6223),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6821),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_RBRACK] = ACTIONS(6823),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6825),
    [sym_date_literal] = ACTIONS(6821),
    [sym_time_literal] = ACTIONS(6821),
    [sym_biginteger_literal] = ACTIONS(6825),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6825),
    [sym_integer] = ACTIONS(6821),
    [sym_continue_as_identifier] = ACTIONS(6825),
  },
  [STATE(2786)] = {
    [sym_boolean] = STATE(6244),
    [sym_assignment_expression] = STATE(6244),
    [sym__expression] = STATE(6244),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6244),
    [sym_multiplicative_expression] = STATE(6244),
    [sym_additive_expression] = STATE(6244),
    [sym_comparison_expression] = STATE(6244),
    [sym_logical_expression] = STATE(6244),
    [sym_ternary_expression] = STATE(6244),
    [sym_unary_expression] = STATE(6244),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6244),
    [sym_list_literal] = STATE(6244),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6244),
    [sym__literal_value] = STATE(6244),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6827),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6829),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6831),
    [sym_date_literal] = ACTIONS(6827),
    [sym_time_literal] = ACTIONS(6827),
    [sym_biginteger_literal] = ACTIONS(6831),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6831),
    [sym_integer] = ACTIONS(6827),
    [sym_continue_as_identifier] = ACTIONS(6831),
  },
  [STATE(2787)] = {
    [sym_boolean] = STATE(6295),
    [sym_assignment_expression] = STATE(6295),
    [sym__expression] = STATE(6295),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6295),
    [sym_multiplicative_expression] = STATE(6295),
    [sym_additive_expression] = STATE(6295),
    [sym_comparison_expression] = STATE(6295),
    [sym_logical_expression] = STATE(6295),
    [sym_ternary_expression] = STATE(6295),
    [sym_unary_expression] = STATE(6295),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6295),
    [sym_list_literal] = STATE(6295),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6295),
    [sym__literal_value] = STATE(6295),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6833),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6835),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6837),
    [sym_date_literal] = ACTIONS(6833),
    [sym_time_literal] = ACTIONS(6833),
    [sym_biginteger_literal] = ACTIONS(6837),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6837),
    [sym_integer] = ACTIONS(6833),
    [sym_continue_as_identifier] = ACTIONS(6837),
  },
  [STATE(2788)] = {
    [sym_boolean] = STATE(6328),
    [sym__field_source] = STATE(11534),
    [sym_assignment_expression] = STATE(6328),
    [sym__expression] = STATE(6328),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6328),
    [sym_multiplicative_expression] = STATE(6328),
    [sym_additive_expression] = STATE(6328),
    [sym_comparison_expression] = STATE(6328),
    [sym_logical_expression] = STATE(6328),
    [sym_ternary_expression] = STATE(6328),
    [sym_unary_expression] = STATE(6328),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6328),
    [sym_list_literal] = STATE(6328),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6328),
    [sym__literal_value] = STATE(6328),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6739),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6741),
    [sym_date_literal] = ACTIONS(6739),
    [sym_time_literal] = ACTIONS(6739),
    [sym_biginteger_literal] = ACTIONS(6741),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6741),
    [sym_integer] = ACTIONS(6739),
    [sym_continue_as_identifier] = ACTIONS(6741),
  },
  [STATE(2789)] = {
    [sym__body_element] = STATE(2713),
    [sym_empty_statement] = STATE(2713),
    [sym_property] = STATE(2713),
    [sym_fields_section] = STATE(2713),
    [sym_keys_section] = STATE(2713),
    [sym_fieldgroups_section] = STATE(2713),
    [sym_enum_value_declaration] = STATE(2713),
    [sym_labels_section] = STATE(2713),
    [sym_layout_section] = STATE(2713),
    [sym_modify_modification] = STATE(2713),
    [sym_actions_section] = STATE(2713),
    [sym_views_section] = STATE(2713),
    [sym_dataset_section] = STATE(2713),
    [sym_requestpage_section] = STATE(2713),
    [sym_rendering_section] = STATE(2713),
    [sym_elements_section] = STATE(2713),
    [sym_query_dataitem] = STATE(2713),
    [sym__query_body_element] = STATE(2713),
    [sym_preproc_conditional_query] = STATE(2713),
    [sym_query_column] = STATE(2713),
    [sym_query_filter] = STATE(2713),
    [sym_schema_section] = STATE(2713),
    [sym_assembly_declaration] = STATE(2713),
    [sym_event_declaration] = STATE(2713),
    [sym_procedure] = STATE(2713),
    [sym_preproc_split_procedure] = STATE(2713),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2713),
    [sym_var_section] = STATE(2713),
    [sym_attribute_item] = STATE(2713),
    [sym_preproc_conditional] = STATE(2713),
    [sym_preproc_if] = STATE(2494),
    [sym_preproc_endif] = STATE(5971),
    [aux_sym_query_dataitem_repeat1] = STATE(2713),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(2790)] = {
    [sym__body_element] = STATE(2798),
    [sym_empty_statement] = STATE(2798),
    [sym_property] = STATE(2798),
    [sym_fields_section] = STATE(2798),
    [sym_keys_section] = STATE(2798),
    [sym_fieldgroups_section] = STATE(2798),
    [sym_enum_value_declaration] = STATE(2798),
    [sym_labels_section] = STATE(2798),
    [sym_layout_section] = STATE(2798),
    [sym_modify_modification] = STATE(2798),
    [sym_actions_section] = STATE(2798),
    [sym_views_section] = STATE(2798),
    [sym_dataset_section] = STATE(2798),
    [sym_requestpage_section] = STATE(2798),
    [sym_rendering_section] = STATE(2798),
    [sym_elements_section] = STATE(2798),
    [sym_query_dataitem] = STATE(2798),
    [sym__query_body_element] = STATE(2798),
    [sym_preproc_conditional_query] = STATE(2798),
    [sym_query_column] = STATE(2798),
    [sym_query_filter] = STATE(2798),
    [sym_schema_section] = STATE(2798),
    [sym_assembly_declaration] = STATE(2798),
    [sym_event_declaration] = STATE(2798),
    [sym_procedure] = STATE(2798),
    [sym_preproc_split_procedure] = STATE(2798),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2798),
    [sym_var_section] = STATE(2798),
    [sym_attribute_item] = STATE(2798),
    [sym_preproc_conditional] = STATE(2798),
    [sym_preproc_if] = STATE(2494),
    [sym_preproc_endif] = STATE(5971),
    [aux_sym_query_dataitem_repeat1] = STATE(2798),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(2791)] = {
    [sym_boolean] = STATE(6245),
    [sym_assignment_expression] = STATE(6245),
    [sym__expression] = STATE(6245),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6245),
    [sym_multiplicative_expression] = STATE(6245),
    [sym_additive_expression] = STATE(6245),
    [sym_comparison_expression] = STATE(6245),
    [sym_logical_expression] = STATE(6245),
    [sym_ternary_expression] = STATE(6245),
    [sym_unary_expression] = STATE(6245),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6245),
    [sym_list_literal] = STATE(6245),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6245),
    [sym__literal_value] = STATE(6245),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6839),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6841),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6843),
    [sym_date_literal] = ACTIONS(6839),
    [sym_time_literal] = ACTIONS(6839),
    [sym_biginteger_literal] = ACTIONS(6843),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6843),
    [sym_integer] = ACTIONS(6839),
    [sym_continue_as_identifier] = ACTIONS(6843),
  },
  [STATE(2792)] = {
    [sym_boolean] = STATE(6317),
    [sym__field_source] = STATE(11506),
    [sym_assignment_expression] = STATE(6317),
    [sym__expression] = STATE(6317),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6317),
    [sym_multiplicative_expression] = STATE(6317),
    [sym_additive_expression] = STATE(6317),
    [sym_comparison_expression] = STATE(6317),
    [sym_logical_expression] = STATE(6317),
    [sym_ternary_expression] = STATE(6317),
    [sym_unary_expression] = STATE(6317),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6317),
    [sym_list_literal] = STATE(6317),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6317),
    [sym__literal_value] = STATE(6317),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6793),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6795),
    [sym_date_literal] = ACTIONS(6793),
    [sym_time_literal] = ACTIONS(6793),
    [sym_biginteger_literal] = ACTIONS(6795),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6795),
    [sym_integer] = ACTIONS(6793),
    [sym_continue_as_identifier] = ACTIONS(6795),
  },
  [STATE(2793)] = {
    [sym_boolean] = STATE(6328),
    [sym__field_source] = STATE(11611),
    [sym_assignment_expression] = STATE(6328),
    [sym__expression] = STATE(6328),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6328),
    [sym_multiplicative_expression] = STATE(6328),
    [sym_additive_expression] = STATE(6328),
    [sym_comparison_expression] = STATE(6328),
    [sym_logical_expression] = STATE(6328),
    [sym_ternary_expression] = STATE(6328),
    [sym_unary_expression] = STATE(6328),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6328),
    [sym_list_literal] = STATE(6328),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6328),
    [sym__literal_value] = STATE(6328),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6739),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6741),
    [sym_date_literal] = ACTIONS(6739),
    [sym_time_literal] = ACTIONS(6739),
    [sym_biginteger_literal] = ACTIONS(6741),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6741),
    [sym_integer] = ACTIONS(6739),
    [sym_continue_as_identifier] = ACTIONS(6741),
  },
  [STATE(2794)] = {
    [sym_boolean] = STATE(6228),
    [sym_assignment_expression] = STATE(6228),
    [sym__expression] = STATE(6228),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6228),
    [sym_multiplicative_expression] = STATE(6228),
    [sym_additive_expression] = STATE(6228),
    [sym_comparison_expression] = STATE(6228),
    [sym_logical_expression] = STATE(6228),
    [sym_ternary_expression] = STATE(6228),
    [sym_unary_expression] = STATE(6228),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6228),
    [sym_list_literal] = STATE(6228),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6228),
    [sym__literal_value] = STATE(6228),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6015),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6017),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6019),
    [sym_date_literal] = ACTIONS(6015),
    [sym_time_literal] = ACTIONS(6015),
    [sym_biginteger_literal] = ACTIONS(6019),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6019),
    [sym_integer] = ACTIONS(6015),
    [sym_continue_as_identifier] = ACTIONS(6019),
  },
  [STATE(2795)] = {
    [sym_boolean] = STATE(6328),
    [sym__field_source] = STATE(12128),
    [sym_assignment_expression] = STATE(6328),
    [sym__expression] = STATE(6328),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6328),
    [sym_multiplicative_expression] = STATE(6328),
    [sym_additive_expression] = STATE(6328),
    [sym_comparison_expression] = STATE(6328),
    [sym_logical_expression] = STATE(6328),
    [sym_ternary_expression] = STATE(6328),
    [sym_unary_expression] = STATE(6328),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6328),
    [sym_list_literal] = STATE(6328),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6328),
    [sym__literal_value] = STATE(6328),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6739),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6741),
    [sym_date_literal] = ACTIONS(6739),
    [sym_time_literal] = ACTIONS(6739),
    [sym_biginteger_literal] = ACTIONS(6741),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6741),
    [sym_integer] = ACTIONS(6739),
    [sym_continue_as_identifier] = ACTIONS(6741),
  },
  [STATE(2796)] = {
    [sym_boolean] = STATE(6328),
    [sym__field_source] = STATE(11530),
    [sym_assignment_expression] = STATE(6328),
    [sym__expression] = STATE(6328),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6328),
    [sym_multiplicative_expression] = STATE(6328),
    [sym_additive_expression] = STATE(6328),
    [sym_comparison_expression] = STATE(6328),
    [sym_logical_expression] = STATE(6328),
    [sym_ternary_expression] = STATE(6328),
    [sym_unary_expression] = STATE(6328),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6328),
    [sym_list_literal] = STATE(6328),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6328),
    [sym__literal_value] = STATE(6328),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6739),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6741),
    [sym_date_literal] = ACTIONS(6739),
    [sym_time_literal] = ACTIONS(6739),
    [sym_biginteger_literal] = ACTIONS(6741),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6741),
    [sym_integer] = ACTIONS(6739),
    [sym_continue_as_identifier] = ACTIONS(6741),
  },
  [STATE(2797)] = {
    [sym__body_element] = STATE(2713),
    [sym_empty_statement] = STATE(2713),
    [sym_property] = STATE(2713),
    [sym_fields_section] = STATE(2713),
    [sym_keys_section] = STATE(2713),
    [sym_fieldgroups_section] = STATE(2713),
    [sym_enum_value_declaration] = STATE(2713),
    [sym_labels_section] = STATE(2713),
    [sym_layout_section] = STATE(2713),
    [sym_modify_modification] = STATE(2713),
    [sym_actions_section] = STATE(2713),
    [sym_views_section] = STATE(2713),
    [sym_dataset_section] = STATE(2713),
    [sym_requestpage_section] = STATE(2713),
    [sym_rendering_section] = STATE(2713),
    [sym_elements_section] = STATE(2713),
    [sym_query_dataitem] = STATE(2713),
    [sym__query_body_element] = STATE(2713),
    [sym_preproc_conditional_query] = STATE(2713),
    [sym_query_column] = STATE(2713),
    [sym_query_filter] = STATE(2713),
    [sym_schema_section] = STATE(2713),
    [sym_assembly_declaration] = STATE(2713),
    [sym_event_declaration] = STATE(2713),
    [sym_procedure] = STATE(2713),
    [sym_preproc_split_procedure] = STATE(2713),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2713),
    [sym_var_section] = STATE(2713),
    [sym_attribute_item] = STATE(2713),
    [sym_preproc_conditional] = STATE(2713),
    [sym_preproc_if] = STATE(2494),
    [sym_preproc_endif] = STATE(6842),
    [aux_sym_query_dataitem_repeat1] = STATE(2713),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(2798)] = {
    [sym__body_element] = STATE(2713),
    [sym_empty_statement] = STATE(2713),
    [sym_property] = STATE(2713),
    [sym_fields_section] = STATE(2713),
    [sym_keys_section] = STATE(2713),
    [sym_fieldgroups_section] = STATE(2713),
    [sym_enum_value_declaration] = STATE(2713),
    [sym_labels_section] = STATE(2713),
    [sym_layout_section] = STATE(2713),
    [sym_modify_modification] = STATE(2713),
    [sym_actions_section] = STATE(2713),
    [sym_views_section] = STATE(2713),
    [sym_dataset_section] = STATE(2713),
    [sym_requestpage_section] = STATE(2713),
    [sym_rendering_section] = STATE(2713),
    [sym_elements_section] = STATE(2713),
    [sym_query_dataitem] = STATE(2713),
    [sym__query_body_element] = STATE(2713),
    [sym_preproc_conditional_query] = STATE(2713),
    [sym_query_column] = STATE(2713),
    [sym_query_filter] = STATE(2713),
    [sym_schema_section] = STATE(2713),
    [sym_assembly_declaration] = STATE(2713),
    [sym_event_declaration] = STATE(2713),
    [sym_procedure] = STATE(2713),
    [sym_preproc_split_procedure] = STATE(2713),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2713),
    [sym_var_section] = STATE(2713),
    [sym_attribute_item] = STATE(2713),
    [sym_preproc_conditional] = STATE(2713),
    [sym_preproc_if] = STATE(2494),
    [sym_preproc_endif] = STATE(5922),
    [aux_sym_query_dataitem_repeat1] = STATE(2713),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(2799)] = {
    [sym__body_element] = STATE(2800),
    [sym_empty_statement] = STATE(2800),
    [sym_property] = STATE(2800),
    [sym_fields_section] = STATE(2800),
    [sym_keys_section] = STATE(2800),
    [sym_fieldgroups_section] = STATE(2800),
    [sym_enum_value_declaration] = STATE(2800),
    [sym_labels_section] = STATE(2800),
    [sym_layout_section] = STATE(2800),
    [sym_modify_modification] = STATE(2800),
    [sym_actions_section] = STATE(2800),
    [sym_views_section] = STATE(2800),
    [sym_dataset_section] = STATE(2800),
    [sym_requestpage_section] = STATE(2800),
    [sym_rendering_section] = STATE(2800),
    [sym_elements_section] = STATE(2800),
    [sym_query_dataitem] = STATE(2800),
    [sym__query_body_element] = STATE(2800),
    [sym_preproc_conditional_query] = STATE(2800),
    [sym_query_column] = STATE(2800),
    [sym_query_filter] = STATE(2800),
    [sym_schema_section] = STATE(2800),
    [sym_assembly_declaration] = STATE(2800),
    [sym_event_declaration] = STATE(2800),
    [sym_procedure] = STATE(2800),
    [sym_preproc_split_procedure] = STATE(2800),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2800),
    [sym_var_section] = STATE(2800),
    [sym_attribute_item] = STATE(2800),
    [sym_preproc_conditional] = STATE(2800),
    [sym_preproc_if] = STATE(2494),
    [sym_preproc_endif] = STATE(5922),
    [aux_sym_query_dataitem_repeat1] = STATE(2800),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(2800)] = {
    [sym__body_element] = STATE(2713),
    [sym_empty_statement] = STATE(2713),
    [sym_property] = STATE(2713),
    [sym_fields_section] = STATE(2713),
    [sym_keys_section] = STATE(2713),
    [sym_fieldgroups_section] = STATE(2713),
    [sym_enum_value_declaration] = STATE(2713),
    [sym_labels_section] = STATE(2713),
    [sym_layout_section] = STATE(2713),
    [sym_modify_modification] = STATE(2713),
    [sym_actions_section] = STATE(2713),
    [sym_views_section] = STATE(2713),
    [sym_dataset_section] = STATE(2713),
    [sym_requestpage_section] = STATE(2713),
    [sym_rendering_section] = STATE(2713),
    [sym_elements_section] = STATE(2713),
    [sym_query_dataitem] = STATE(2713),
    [sym__query_body_element] = STATE(2713),
    [sym_preproc_conditional_query] = STATE(2713),
    [sym_query_column] = STATE(2713),
    [sym_query_filter] = STATE(2713),
    [sym_schema_section] = STATE(2713),
    [sym_assembly_declaration] = STATE(2713),
    [sym_event_declaration] = STATE(2713),
    [sym_procedure] = STATE(2713),
    [sym_preproc_split_procedure] = STATE(2713),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2713),
    [sym_var_section] = STATE(2713),
    [sym_attribute_item] = STATE(2713),
    [sym_preproc_conditional] = STATE(2713),
    [sym_preproc_if] = STATE(2494),
    [sym_preproc_endif] = STATE(5951),
    [aux_sym_query_dataitem_repeat1] = STATE(2713),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5871),
    [sym_column_keyword] = ACTIONS(5873),
    [sym_filter_keyword] = ACTIONS(5875),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(2801)] = {
    [sym_boolean] = STATE(6220),
    [sym_assignment_expression] = STATE(6220),
    [sym__expression] = STATE(6220),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6220),
    [sym_multiplicative_expression] = STATE(6220),
    [sym_additive_expression] = STATE(6220),
    [sym_comparison_expression] = STATE(6220),
    [sym_logical_expression] = STATE(6220),
    [sym_ternary_expression] = STATE(6220),
    [sym_unary_expression] = STATE(6220),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6220),
    [sym_list_literal] = STATE(6220),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6220),
    [sym__literal_value] = STATE(6220),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6845),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_RBRACK] = ACTIONS(6847),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6849),
    [sym_date_literal] = ACTIONS(6845),
    [sym_time_literal] = ACTIONS(6845),
    [sym_biginteger_literal] = ACTIONS(6849),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6849),
    [sym_integer] = ACTIONS(6845),
    [sym_continue_as_identifier] = ACTIONS(6849),
  },
  [STATE(2802)] = {
    [sym_boolean] = STATE(6241),
    [sym_assignment_expression] = STATE(6241),
    [sym__expression] = STATE(6241),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6241),
    [sym_multiplicative_expression] = STATE(6241),
    [sym_additive_expression] = STATE(6241),
    [sym_comparison_expression] = STATE(6241),
    [sym_logical_expression] = STATE(6241),
    [sym_ternary_expression] = STATE(6241),
    [sym_unary_expression] = STATE(6241),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6241),
    [sym_list_literal] = STATE(6241),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6241),
    [sym__literal_value] = STATE(6241),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6851),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_RBRACK] = ACTIONS(6853),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6855),
    [sym_date_literal] = ACTIONS(6851),
    [sym_time_literal] = ACTIONS(6851),
    [sym_biginteger_literal] = ACTIONS(6855),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6855),
    [sym_integer] = ACTIONS(6851),
    [sym_continue_as_identifier] = ACTIONS(6855),
  },
  [STATE(2803)] = {
    [sym_boolean] = STATE(6376),
    [sym_assignment_expression] = STATE(6345),
    [sym__expression] = STATE(6345),
    [sym_keyword_identifier] = STATE(6249),
    [sym_range_expression] = STATE(6345),
    [sym_multiplicative_expression] = STATE(6345),
    [sym_additive_expression] = STATE(6345),
    [sym_comparison_expression] = STATE(6345),
    [sym_logical_expression] = STATE(6345),
    [sym_ternary_expression] = STATE(6345),
    [sym_unary_expression] = STATE(6345),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6345),
    [sym_list_literal] = STATE(6345),
    [sym_qualified_enum_value] = STATE(6249),
    [sym_database_reference] = STATE(6379),
    [sym__literal_value] = STATE(6345),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6857),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6859),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(5457),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5457),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6861),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6863),
    [sym_integer] = ACTIONS(6865),
    [sym_continue_as_identifier] = ACTIONS(5457),
  },
  [STATE(2804)] = {
    [sym_boolean] = STATE(6374),
    [sym_assignment_expression] = STATE(6345),
    [sym__expression] = STATE(6345),
    [sym_keyword_identifier] = STATE(6262),
    [sym_range_expression] = STATE(6345),
    [sym_multiplicative_expression] = STATE(6345),
    [sym_additive_expression] = STATE(6345),
    [sym_comparison_expression] = STATE(6345),
    [sym_logical_expression] = STATE(6345),
    [sym_ternary_expression] = STATE(6345),
    [sym_unary_expression] = STATE(6345),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6345),
    [sym_list_literal] = STATE(6345),
    [sym_qualified_enum_value] = STATE(6262),
    [sym_database_reference] = STATE(6375),
    [sym__literal_value] = STATE(6345),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6867),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6869),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(5457),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5457),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6873),
    [sym_integer] = ACTIONS(6875),
    [sym_continue_as_identifier] = ACTIONS(5457),
  },
  [STATE(2805)] = {
    [sym_boolean] = STATE(6315),
    [sym_aggregate_formula] = STATE(12141),
    [sym_assignment_expression] = STATE(6315),
    [sym__expression] = STATE(6315),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6315),
    [sym_multiplicative_expression] = STATE(6315),
    [sym_additive_expression] = STATE(6315),
    [sym_comparison_expression] = STATE(6315),
    [sym_logical_expression] = STATE(6315),
    [sym_ternary_expression] = STATE(6315),
    [sym_unary_expression] = STATE(6315),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6315),
    [sym_list_literal] = STATE(6315),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6315),
    [sym__literal_value] = STATE(6315),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6877),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6879),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(6881),
    [sym_date_literal] = ACTIONS(6879),
    [sym_time_literal] = ACTIONS(6879),
    [sym_biginteger_literal] = ACTIONS(6881),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6881),
    [sym_integer] = ACTIONS(6883),
    [sym_continue_as_identifier] = ACTIONS(6881),
  },
  [STATE(2806)] = {
    [sym_preproc_conditional_controladdin] = STATE(3019),
    [sym__body_element] = STATE(6269),
    [sym_empty_statement] = STATE(6269),
    [sym_property] = STATE(6269),
    [sym_fields_section] = STATE(6269),
    [sym_keys_section] = STATE(6269),
    [sym_fieldgroups_section] = STATE(6269),
    [sym_enum_value_declaration] = STATE(6269),
    [sym_labels_section] = STATE(6269),
    [sym_layout_section] = STATE(6269),
    [sym_modify_modification] = STATE(6269),
    [sym_actions_section] = STATE(6269),
    [sym_views_section] = STATE(6269),
    [sym_dataset_section] = STATE(6269),
    [sym_requestpage_section] = STATE(6269),
    [sym_rendering_section] = STATE(6269),
    [sym_elements_section] = STATE(6269),
    [sym_schema_section] = STATE(6269),
    [sym_assembly_declaration] = STATE(6269),
    [sym_event_declaration] = STATE(6269),
    [sym_procedure] = STATE(6269),
    [sym_preproc_split_procedure] = STATE(6269),
    [sym_interface_procedure] = STATE(3019),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(6269),
    [sym_var_section] = STATE(6269),
    [sym_attribute_item] = STATE(6269),
    [sym_preproc_conditional] = STATE(6269),
    [sym_preproc_if] = STATE(2635),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3335),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3019),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(6885),
    [anon_sym_POUNDELIF] = ACTIONS(6885),
    [anon_sym_POUNDElif] = ACTIONS(6885),
    [anon_sym_POUNDelse] = ACTIONS(6885),
    [anon_sym_POUNDELSE] = ACTIONS(6885),
    [anon_sym_POUNDElse] = ACTIONS(6885),
    [anon_sym_POUNDendif] = ACTIONS(6885),
    [anon_sym_POUNDENDIF] = ACTIONS(6885),
    [anon_sym_POUNDEndif] = ACTIONS(6885),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(6885),
  },
  [STATE(2807)] = {
    [sym_boolean] = STATE(6216),
    [sym_assignment_expression] = STATE(6216),
    [sym__expression] = STATE(6216),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6216),
    [sym_multiplicative_expression] = STATE(6216),
    [sym_additive_expression] = STATE(6216),
    [sym_comparison_expression] = STATE(6216),
    [sym_logical_expression] = STATE(6216),
    [sym_ternary_expression] = STATE(6216),
    [sym_unary_expression] = STATE(6216),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6216),
    [sym_list_literal] = STATE(6216),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6216),
    [sym__literal_value] = STATE(6216),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6888),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_RPAREN] = ACTIONS(6890),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6892),
    [sym_date_literal] = ACTIONS(6888),
    [sym_time_literal] = ACTIONS(6888),
    [sym_biginteger_literal] = ACTIONS(6892),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6892),
    [sym_integer] = ACTIONS(6888),
    [sym_continue_as_identifier] = ACTIONS(6892),
  },
  [STATE(2808)] = {
    [sym_boolean] = STATE(6225),
    [sym_assignment_expression] = STATE(6225),
    [sym__expression] = STATE(6225),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6225),
    [sym_multiplicative_expression] = STATE(6225),
    [sym_additive_expression] = STATE(6225),
    [sym_comparison_expression] = STATE(6225),
    [sym_logical_expression] = STATE(6225),
    [sym_ternary_expression] = STATE(6225),
    [sym_unary_expression] = STATE(6225),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6225),
    [sym_list_literal] = STATE(6225),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6225),
    [sym__literal_value] = STATE(6225),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6894),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_RBRACK] = ACTIONS(6896),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6898),
    [sym_date_literal] = ACTIONS(6894),
    [sym_time_literal] = ACTIONS(6894),
    [sym_biginteger_literal] = ACTIONS(6898),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6898),
    [sym_integer] = ACTIONS(6894),
    [sym_continue_as_identifier] = ACTIONS(6898),
  },
  [STATE(2809)] = {
    [sym_boolean] = STATE(6328),
    [sym__field_source] = STATE(11508),
    [sym_assignment_expression] = STATE(6328),
    [sym__expression] = STATE(6328),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6328),
    [sym_multiplicative_expression] = STATE(6328),
    [sym_additive_expression] = STATE(6328),
    [sym_comparison_expression] = STATE(6328),
    [sym_logical_expression] = STATE(6328),
    [sym_ternary_expression] = STATE(6328),
    [sym_unary_expression] = STATE(6328),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6328),
    [sym_list_literal] = STATE(6328),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6328),
    [sym__literal_value] = STATE(6328),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6739),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6741),
    [sym_date_literal] = ACTIONS(6739),
    [sym_time_literal] = ACTIONS(6739),
    [sym_biginteger_literal] = ACTIONS(6741),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6741),
    [sym_integer] = ACTIONS(6739),
    [sym_continue_as_identifier] = ACTIONS(6741),
  },
  [STATE(2810)] = {
    [sym_boolean] = STATE(6171),
    [sym_assignment_expression] = STATE(6171),
    [sym__expression] = STATE(6171),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6171),
    [sym_multiplicative_expression] = STATE(6171),
    [sym_additive_expression] = STATE(6171),
    [sym_comparison_expression] = STATE(6171),
    [sym_logical_expression] = STATE(6171),
    [sym_ternary_expression] = STATE(6171),
    [sym_unary_expression] = STATE(6171),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6171),
    [sym_list_literal] = STATE(6171),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6171),
    [sym__literal_value] = STATE(6171),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6900),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6902),
    [sym_date_literal] = ACTIONS(6900),
    [sym_time_literal] = ACTIONS(6900),
    [sym_biginteger_literal] = ACTIONS(6902),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6902),
    [sym_integer] = ACTIONS(6900),
    [sym_continue_as_identifier] = ACTIONS(6902),
  },
  [STATE(2811)] = {
    [sym_boolean] = STATE(6025),
    [sym_assignment_expression] = STATE(6025),
    [sym__expression] = STATE(6025),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6025),
    [sym_multiplicative_expression] = STATE(6025),
    [sym_additive_expression] = STATE(6025),
    [sym_comparison_expression] = STATE(6025),
    [sym_logical_expression] = STATE(6025),
    [sym_ternary_expression] = STATE(6025),
    [sym_unary_expression] = STATE(6025),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6025),
    [sym_list_literal] = STATE(6025),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6025),
    [sym__literal_value] = STATE(6025),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6904),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6906),
    [sym_date_literal] = ACTIONS(6904),
    [sym_time_literal] = ACTIONS(6904),
    [sym_biginteger_literal] = ACTIONS(6906),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6906),
    [sym_integer] = ACTIONS(6904),
    [sym_continue_as_identifier] = ACTIONS(6906),
  },
  [STATE(2812)] = {
    [sym_boolean] = STATE(6026),
    [sym_assignment_expression] = STATE(6026),
    [sym__expression] = STATE(6026),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6026),
    [sym_multiplicative_expression] = STATE(6026),
    [sym_additive_expression] = STATE(6026),
    [sym_comparison_expression] = STATE(6026),
    [sym_logical_expression] = STATE(6026),
    [sym_ternary_expression] = STATE(6026),
    [sym_unary_expression] = STATE(6026),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6026),
    [sym_list_literal] = STATE(6026),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6026),
    [sym__literal_value] = STATE(6026),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6908),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6910),
    [sym_date_literal] = ACTIONS(6908),
    [sym_time_literal] = ACTIONS(6908),
    [sym_biginteger_literal] = ACTIONS(6910),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6910),
    [sym_integer] = ACTIONS(6908),
    [sym_continue_as_identifier] = ACTIONS(6910),
  },
  [STATE(2813)] = {
    [sym_boolean] = STATE(6027),
    [sym_assignment_expression] = STATE(6027),
    [sym__expression] = STATE(6027),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6027),
    [sym_multiplicative_expression] = STATE(6027),
    [sym_additive_expression] = STATE(6027),
    [sym_comparison_expression] = STATE(6027),
    [sym_logical_expression] = STATE(6027),
    [sym_ternary_expression] = STATE(6027),
    [sym_unary_expression] = STATE(6027),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6027),
    [sym_list_literal] = STATE(6027),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6027),
    [sym__literal_value] = STATE(6027),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6912),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6914),
    [sym_date_literal] = ACTIONS(6912),
    [sym_time_literal] = ACTIONS(6912),
    [sym_biginteger_literal] = ACTIONS(6914),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6914),
    [sym_integer] = ACTIONS(6912),
    [sym_continue_as_identifier] = ACTIONS(6914),
  },
  [STATE(2814)] = {
    [sym_boolean] = STATE(6028),
    [sym_assignment_expression] = STATE(6028),
    [sym__expression] = STATE(6028),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6028),
    [sym_multiplicative_expression] = STATE(6028),
    [sym_additive_expression] = STATE(6028),
    [sym_comparison_expression] = STATE(6028),
    [sym_logical_expression] = STATE(6028),
    [sym_ternary_expression] = STATE(6028),
    [sym_unary_expression] = STATE(6028),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6028),
    [sym_list_literal] = STATE(6028),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6028),
    [sym__literal_value] = STATE(6028),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6916),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6918),
    [sym_date_literal] = ACTIONS(6916),
    [sym_time_literal] = ACTIONS(6916),
    [sym_biginteger_literal] = ACTIONS(6918),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6918),
    [sym_integer] = ACTIONS(6916),
    [sym_continue_as_identifier] = ACTIONS(6918),
  },
  [STATE(2815)] = {
    [sym_boolean] = STATE(6029),
    [sym_assignment_expression] = STATE(6029),
    [sym__expression] = STATE(6029),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6029),
    [sym_multiplicative_expression] = STATE(6029),
    [sym_additive_expression] = STATE(6029),
    [sym_comparison_expression] = STATE(6029),
    [sym_logical_expression] = STATE(6029),
    [sym_ternary_expression] = STATE(6029),
    [sym_unary_expression] = STATE(6029),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6029),
    [sym_list_literal] = STATE(6029),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6029),
    [sym__literal_value] = STATE(6029),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6920),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6922),
    [sym_date_literal] = ACTIONS(6920),
    [sym_time_literal] = ACTIONS(6920),
    [sym_biginteger_literal] = ACTIONS(6922),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6922),
    [sym_integer] = ACTIONS(6920),
    [sym_continue_as_identifier] = ACTIONS(6922),
  },
  [STATE(2816)] = {
    [sym_boolean] = STATE(6031),
    [sym_assignment_expression] = STATE(6031),
    [sym__expression] = STATE(6031),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6031),
    [sym_multiplicative_expression] = STATE(6031),
    [sym_additive_expression] = STATE(6031),
    [sym_comparison_expression] = STATE(6031),
    [sym_logical_expression] = STATE(6031),
    [sym_ternary_expression] = STATE(6031),
    [sym_unary_expression] = STATE(6031),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6031),
    [sym_list_literal] = STATE(6031),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6031),
    [sym__literal_value] = STATE(6031),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6924),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6926),
    [sym_date_literal] = ACTIONS(6924),
    [sym_time_literal] = ACTIONS(6924),
    [sym_biginteger_literal] = ACTIONS(6926),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6926),
    [sym_integer] = ACTIONS(6924),
    [sym_continue_as_identifier] = ACTIONS(6926),
  },
  [STATE(2817)] = {
    [sym_boolean] = STATE(6032),
    [sym_assignment_expression] = STATE(6032),
    [sym__expression] = STATE(6032),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6032),
    [sym_multiplicative_expression] = STATE(6032),
    [sym_additive_expression] = STATE(6032),
    [sym_comparison_expression] = STATE(6032),
    [sym_logical_expression] = STATE(6032),
    [sym_ternary_expression] = STATE(6032),
    [sym_unary_expression] = STATE(6032),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6032),
    [sym_list_literal] = STATE(6032),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6032),
    [sym__literal_value] = STATE(6032),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6928),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6930),
    [sym_date_literal] = ACTIONS(6928),
    [sym_time_literal] = ACTIONS(6928),
    [sym_biginteger_literal] = ACTIONS(6930),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6930),
    [sym_integer] = ACTIONS(6928),
    [sym_continue_as_identifier] = ACTIONS(6930),
  },
  [STATE(2818)] = {
    [sym_boolean] = STATE(6063),
    [sym_assignment_expression] = STATE(6063),
    [sym__expression] = STATE(6063),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6063),
    [sym_multiplicative_expression] = STATE(6063),
    [sym_additive_expression] = STATE(6063),
    [sym_comparison_expression] = STATE(6063),
    [sym_logical_expression] = STATE(6063),
    [sym_ternary_expression] = STATE(6063),
    [sym_unary_expression] = STATE(6063),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6063),
    [sym_list_literal] = STATE(6063),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6063),
    [sym__literal_value] = STATE(6063),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6932),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6934),
    [sym_date_literal] = ACTIONS(6932),
    [sym_time_literal] = ACTIONS(6932),
    [sym_biginteger_literal] = ACTIONS(6934),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6934),
    [sym_integer] = ACTIONS(6932),
    [sym_continue_as_identifier] = ACTIONS(6934),
  },
  [STATE(2819)] = {
    [sym_boolean] = STATE(6064),
    [sym_assignment_expression] = STATE(6064),
    [sym__expression] = STATE(6064),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6064),
    [sym_multiplicative_expression] = STATE(6064),
    [sym_additive_expression] = STATE(6064),
    [sym_comparison_expression] = STATE(6064),
    [sym_logical_expression] = STATE(6064),
    [sym_ternary_expression] = STATE(6064),
    [sym_unary_expression] = STATE(6064),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6064),
    [sym_list_literal] = STATE(6064),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6064),
    [sym__literal_value] = STATE(6064),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6936),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6938),
    [sym_date_literal] = ACTIONS(6936),
    [sym_time_literal] = ACTIONS(6936),
    [sym_biginteger_literal] = ACTIONS(6938),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6938),
    [sym_integer] = ACTIONS(6936),
    [sym_continue_as_identifier] = ACTIONS(6938),
  },
  [STATE(2820)] = {
    [sym_boolean] = STATE(6065),
    [sym_assignment_expression] = STATE(6065),
    [sym__expression] = STATE(6065),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6065),
    [sym_multiplicative_expression] = STATE(6065),
    [sym_additive_expression] = STATE(6065),
    [sym_comparison_expression] = STATE(6065),
    [sym_logical_expression] = STATE(6065),
    [sym_ternary_expression] = STATE(6065),
    [sym_unary_expression] = STATE(6065),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6065),
    [sym_list_literal] = STATE(6065),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6065),
    [sym__literal_value] = STATE(6065),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6940),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6942),
    [sym_date_literal] = ACTIONS(6940),
    [sym_time_literal] = ACTIONS(6940),
    [sym_biginteger_literal] = ACTIONS(6942),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6942),
    [sym_integer] = ACTIONS(6940),
    [sym_continue_as_identifier] = ACTIONS(6942),
  },
  [STATE(2821)] = {
    [sym_boolean] = STATE(6066),
    [sym_assignment_expression] = STATE(6066),
    [sym__expression] = STATE(6066),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6066),
    [sym_multiplicative_expression] = STATE(6066),
    [sym_additive_expression] = STATE(6066),
    [sym_comparison_expression] = STATE(6066),
    [sym_logical_expression] = STATE(6066),
    [sym_ternary_expression] = STATE(6066),
    [sym_unary_expression] = STATE(6066),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6066),
    [sym_list_literal] = STATE(6066),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6066),
    [sym__literal_value] = STATE(6066),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6944),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6946),
    [sym_date_literal] = ACTIONS(6944),
    [sym_time_literal] = ACTIONS(6944),
    [sym_biginteger_literal] = ACTIONS(6946),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6946),
    [sym_integer] = ACTIONS(6944),
    [sym_continue_as_identifier] = ACTIONS(6946),
  },
  [STATE(2822)] = {
    [sym_boolean] = STATE(6067),
    [sym_assignment_expression] = STATE(6067),
    [sym__expression] = STATE(6067),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6067),
    [sym_multiplicative_expression] = STATE(6067),
    [sym_additive_expression] = STATE(6067),
    [sym_comparison_expression] = STATE(6067),
    [sym_logical_expression] = STATE(6067),
    [sym_ternary_expression] = STATE(6067),
    [sym_unary_expression] = STATE(6067),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6067),
    [sym_list_literal] = STATE(6067),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6067),
    [sym__literal_value] = STATE(6067),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6948),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6950),
    [sym_date_literal] = ACTIONS(6948),
    [sym_time_literal] = ACTIONS(6948),
    [sym_biginteger_literal] = ACTIONS(6950),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6950),
    [sym_integer] = ACTIONS(6948),
    [sym_continue_as_identifier] = ACTIONS(6950),
  },
  [STATE(2823)] = {
    [sym_boolean] = STATE(6068),
    [sym_assignment_expression] = STATE(6068),
    [sym__expression] = STATE(6068),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6068),
    [sym_multiplicative_expression] = STATE(6068),
    [sym_additive_expression] = STATE(6068),
    [sym_comparison_expression] = STATE(6068),
    [sym_logical_expression] = STATE(6068),
    [sym_ternary_expression] = STATE(6068),
    [sym_unary_expression] = STATE(6068),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6068),
    [sym_list_literal] = STATE(6068),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6068),
    [sym__literal_value] = STATE(6068),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6952),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6954),
    [sym_date_literal] = ACTIONS(6952),
    [sym_time_literal] = ACTIONS(6952),
    [sym_biginteger_literal] = ACTIONS(6954),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6954),
    [sym_integer] = ACTIONS(6952),
    [sym_continue_as_identifier] = ACTIONS(6954),
  },
  [STATE(2824)] = {
    [sym_boolean] = STATE(6085),
    [sym_assignment_expression] = STATE(6085),
    [sym__expression] = STATE(6085),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6085),
    [sym_multiplicative_expression] = STATE(6085),
    [sym_additive_expression] = STATE(6085),
    [sym_comparison_expression] = STATE(6085),
    [sym_logical_expression] = STATE(6085),
    [sym_ternary_expression] = STATE(6085),
    [sym_unary_expression] = STATE(6085),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6085),
    [sym_list_literal] = STATE(6085),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6085),
    [sym__literal_value] = STATE(6085),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6956),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6958),
    [sym_date_literal] = ACTIONS(6956),
    [sym_time_literal] = ACTIONS(6956),
    [sym_biginteger_literal] = ACTIONS(6958),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6958),
    [sym_integer] = ACTIONS(6956),
    [sym_continue_as_identifier] = ACTIONS(6958),
  },
  [STATE(2825)] = {
    [sym_boolean] = STATE(6094),
    [sym_assignment_expression] = STATE(6094),
    [sym__expression] = STATE(6094),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6094),
    [sym_multiplicative_expression] = STATE(6094),
    [sym_additive_expression] = STATE(6094),
    [sym_comparison_expression] = STATE(6094),
    [sym_logical_expression] = STATE(6094),
    [sym_ternary_expression] = STATE(6094),
    [sym_unary_expression] = STATE(6094),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6094),
    [sym_list_literal] = STATE(6094),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6094),
    [sym__literal_value] = STATE(6094),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6960),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6962),
    [sym_date_literal] = ACTIONS(6960),
    [sym_time_literal] = ACTIONS(6960),
    [sym_biginteger_literal] = ACTIONS(6962),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6962),
    [sym_integer] = ACTIONS(6960),
    [sym_continue_as_identifier] = ACTIONS(6962),
  },
  [STATE(2826)] = {
    [sym_boolean] = STATE(6095),
    [sym_assignment_expression] = STATE(6095),
    [sym__expression] = STATE(6095),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6095),
    [sym_multiplicative_expression] = STATE(6095),
    [sym_additive_expression] = STATE(6095),
    [sym_comparison_expression] = STATE(6095),
    [sym_logical_expression] = STATE(6095),
    [sym_ternary_expression] = STATE(6095),
    [sym_unary_expression] = STATE(6095),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6095),
    [sym_list_literal] = STATE(6095),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6095),
    [sym__literal_value] = STATE(6095),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6964),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6966),
    [sym_date_literal] = ACTIONS(6964),
    [sym_time_literal] = ACTIONS(6964),
    [sym_biginteger_literal] = ACTIONS(6966),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6966),
    [sym_integer] = ACTIONS(6964),
    [sym_continue_as_identifier] = ACTIONS(6966),
  },
  [STATE(2827)] = {
    [sym_boolean] = STATE(6096),
    [sym_assignment_expression] = STATE(6096),
    [sym__expression] = STATE(6096),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6096),
    [sym_multiplicative_expression] = STATE(6096),
    [sym_additive_expression] = STATE(6096),
    [sym_comparison_expression] = STATE(6096),
    [sym_logical_expression] = STATE(6096),
    [sym_ternary_expression] = STATE(6096),
    [sym_unary_expression] = STATE(6096),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6096),
    [sym_list_literal] = STATE(6096),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6096),
    [sym__literal_value] = STATE(6096),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6968),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6970),
    [sym_date_literal] = ACTIONS(6968),
    [sym_time_literal] = ACTIONS(6968),
    [sym_biginteger_literal] = ACTIONS(6970),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6970),
    [sym_integer] = ACTIONS(6968),
    [sym_continue_as_identifier] = ACTIONS(6970),
  },
  [STATE(2828)] = {
    [sym_boolean] = STATE(6097),
    [sym_assignment_expression] = STATE(6097),
    [sym__expression] = STATE(6097),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6097),
    [sym_multiplicative_expression] = STATE(6097),
    [sym_additive_expression] = STATE(6097),
    [sym_comparison_expression] = STATE(6097),
    [sym_logical_expression] = STATE(6097),
    [sym_ternary_expression] = STATE(6097),
    [sym_unary_expression] = STATE(6097),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6097),
    [sym_list_literal] = STATE(6097),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6097),
    [sym__literal_value] = STATE(6097),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6972),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6974),
    [sym_date_literal] = ACTIONS(6972),
    [sym_time_literal] = ACTIONS(6972),
    [sym_biginteger_literal] = ACTIONS(6974),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6974),
    [sym_integer] = ACTIONS(6972),
    [sym_continue_as_identifier] = ACTIONS(6974),
  },
  [STATE(2829)] = {
    [sym_boolean] = STATE(4924),
    [sym_assignment_expression] = STATE(4924),
    [sym__expression] = STATE(4924),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4924),
    [sym_multiplicative_expression] = STATE(4924),
    [sym_additive_expression] = STATE(4924),
    [sym_comparison_expression] = STATE(4924),
    [sym_logical_expression] = STATE(4924),
    [sym_ternary_expression] = STATE(4924),
    [sym_unary_expression] = STATE(4924),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4924),
    [sym_list_literal] = STATE(4924),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4924),
    [sym__literal_value] = STATE(4924),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6706),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6708),
    [sym_date_literal] = ACTIONS(6706),
    [sym_time_literal] = ACTIONS(6706),
    [sym_biginteger_literal] = ACTIONS(6708),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6708),
    [sym_integer] = ACTIONS(6706),
    [sym_continue_as_identifier] = ACTIONS(6708),
  },
  [STATE(2830)] = {
    [sym_identifier] = ACTIONS(6976),
    [anon_sym_SEMI] = ACTIONS(6978),
    [aux_sym_where_condition_token1] = ACTIONS(6976),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6976),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6976),
    [anon_sym_LBRACK] = ACTIONS(6978),
    [aux_sym_basic_type_token6] = ACTIONS(6976),
    [aux_sym_basic_type_token22] = ACTIONS(6976),
    [aux_sym_basic_type_token53] = ACTIONS(6976),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6976),
    [aux_sym_addafter_modification_token1] = ACTIONS(6976),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6976),
    [aux_sym_modify_modification_token1] = ACTIONS(6976),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6976),
    [aux_sym_movelast_modification_token1] = ACTIONS(6976),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6976),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6976),
    [aux_sym_separator_action_token1] = ACTIONS(6976),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6976),
    [aux_sym_type_declaration_token1] = ACTIONS(6976),
    [anon_sym_POUNDif] = ACTIONS(6978),
    [anon_sym_POUNDIF] = ACTIONS(6978),
    [anon_sym_POUNDIf] = ACTIONS(6978),
    [anon_sym_POUNDelif] = ACTIONS(6978),
    [anon_sym_POUNDELIF] = ACTIONS(6978),
    [anon_sym_POUNDElif] = ACTIONS(6978),
    [anon_sym_POUNDelse] = ACTIONS(6978),
    [anon_sym_POUNDELSE] = ACTIONS(6978),
    [anon_sym_POUNDElse] = ACTIONS(6978),
    [anon_sym_POUNDendif] = ACTIONS(6978),
    [anon_sym_POUNDENDIF] = ACTIONS(6978),
    [anon_sym_POUNDEndif] = ACTIONS(6978),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6976),
    [sym_trigger_keyword] = ACTIONS(6976),
    [sym_var_keyword] = ACTIONS(6976),
    [sym_local_keyword] = ACTIONS(6976),
    [sym_internal_keyword] = ACTIONS(6976),
    [sym_protected_keyword] = ACTIONS(6976),
    [sym_event_keyword] = ACTIONS(6976),
    [sym_fields_keyword] = ACTIONS(6976),
    [sym_keys_keyword] = ACTIONS(6976),
    [sym_key_keyword] = ACTIONS(6976),
    [sym_fieldgroups_keyword] = ACTIONS(6976),
    [sym_actions_keyword] = ACTIONS(6976),
    [sym_layout_keyword] = ACTIONS(6976),
    [sym_area_keyword] = ACTIONS(6976),
    [sym_group_keyword] = ACTIONS(6976),
    [sym_repeater_keyword] = ACTIONS(6976),
    [sym_cuegroup_keyword] = ACTIONS(6976),
    [sym_fixed_keyword] = ACTIONS(6976),
    [sym_grid_keyword] = ACTIONS(6976),
    [sym_part_keyword] = ACTIONS(6976),
    [sym_systempart_keyword] = ACTIONS(6976),
    [sym_usercontrol_keyword] = ACTIONS(6976),
    [sym_dataset_keyword] = ACTIONS(6976),
    [sym_elements_keyword] = ACTIONS(6976),
    [sym_dataitem_keyword] = ACTIONS(6976),
    [sym_column_keyword] = ACTIONS(6976),
    [sym_filter_keyword] = ACTIONS(6976),
    [sym_labels_keyword] = ACTIONS(6976),
    [sym_rendering_keyword] = ACTIONS(6976),
    [sym_requestpage_keyword] = ACTIONS(6976),
    [sym_schema_keyword] = ACTIONS(6976),
    [sym_views_keyword] = ACTIONS(6976),
    [sym_quoted_identifier] = ACTIONS(6978),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6978),
    [sym_preproc_open] = ACTIONS(6978),
    [sym_preproc_close] = ACTIONS(6978),
    [sym_var_attribute_open] = ACTIONS(6978),
  },
  [STATE(2831)] = {
    [sym_boolean] = STATE(4931),
    [sym_assignment_expression] = STATE(4931),
    [sym__expression] = STATE(4931),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4931),
    [sym_multiplicative_expression] = STATE(4931),
    [sym_additive_expression] = STATE(4931),
    [sym_comparison_expression] = STATE(4931),
    [sym_logical_expression] = STATE(4931),
    [sym_ternary_expression] = STATE(4931),
    [sym_unary_expression] = STATE(4931),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4931),
    [sym_list_literal] = STATE(4931),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4931),
    [sym__literal_value] = STATE(4931),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6980),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6982),
    [sym_date_literal] = ACTIONS(6980),
    [sym_time_literal] = ACTIONS(6980),
    [sym_biginteger_literal] = ACTIONS(6982),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6982),
    [sym_integer] = ACTIONS(6980),
    [sym_continue_as_identifier] = ACTIONS(6982),
  },
  [STATE(2832)] = {
    [sym_boolean] = STATE(6318),
    [sym_assignment_expression] = STATE(6318),
    [sym__expression] = STATE(6318),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6318),
    [sym_multiplicative_expression] = STATE(6318),
    [sym_additive_expression] = STATE(6318),
    [sym_comparison_expression] = STATE(6318),
    [sym_logical_expression] = STATE(6318),
    [sym_ternary_expression] = STATE(6318),
    [sym_unary_expression] = STATE(6318),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6318),
    [sym_list_literal] = STATE(6318),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6318),
    [sym__literal_value] = STATE(6318),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6984),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(6986),
    [sym_date_literal] = ACTIONS(6984),
    [sym_time_literal] = ACTIONS(6984),
    [sym_biginteger_literal] = ACTIONS(6986),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6986),
    [sym_integer] = ACTIONS(6984),
    [sym_continue_as_identifier] = ACTIONS(6986),
  },
  [STATE(2833)] = {
    [sym_boolean] = STATE(4936),
    [sym_assignment_expression] = STATE(4936),
    [sym__expression] = STATE(4936),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4936),
    [sym_multiplicative_expression] = STATE(4936),
    [sym_additive_expression] = STATE(4936),
    [sym_comparison_expression] = STATE(4936),
    [sym_logical_expression] = STATE(4936),
    [sym_ternary_expression] = STATE(4936),
    [sym_unary_expression] = STATE(4936),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4936),
    [sym_list_literal] = STATE(4936),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4936),
    [sym__literal_value] = STATE(4936),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6988),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(6990),
    [sym_date_literal] = ACTIONS(6988),
    [sym_time_literal] = ACTIONS(6988),
    [sym_biginteger_literal] = ACTIONS(6990),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6990),
    [sym_integer] = ACTIONS(6988),
    [sym_continue_as_identifier] = ACTIONS(6990),
  },
  [STATE(2834)] = {
    [sym_boolean] = STATE(6104),
    [sym_assignment_expression] = STATE(6104),
    [sym__expression] = STATE(6104),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6104),
    [sym_multiplicative_expression] = STATE(6104),
    [sym_additive_expression] = STATE(6104),
    [sym_comparison_expression] = STATE(6104),
    [sym_logical_expression] = STATE(6104),
    [sym_ternary_expression] = STATE(6104),
    [sym_unary_expression] = STATE(6104),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6104),
    [sym_list_literal] = STATE(6104),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6104),
    [sym__literal_value] = STATE(6104),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6992),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(6994),
    [sym_date_literal] = ACTIONS(6992),
    [sym_time_literal] = ACTIONS(6992),
    [sym_biginteger_literal] = ACTIONS(6994),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6994),
    [sym_integer] = ACTIONS(6992),
    [sym_continue_as_identifier] = ACTIONS(6994),
  },
  [STATE(2835)] = {
    [sym_boolean] = STATE(6309),
    [sym_assignment_expression] = STATE(6309),
    [sym__expression] = STATE(6309),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6309),
    [sym_multiplicative_expression] = STATE(6309),
    [sym_additive_expression] = STATE(6309),
    [sym_comparison_expression] = STATE(6309),
    [sym_logical_expression] = STATE(6309),
    [sym_ternary_expression] = STATE(6309),
    [sym_unary_expression] = STATE(6309),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6309),
    [sym_list_literal] = STATE(6309),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6309),
    [sym__literal_value] = STATE(6309),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(6996),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(6998),
    [sym_date_literal] = ACTIONS(6996),
    [sym_time_literal] = ACTIONS(6996),
    [sym_biginteger_literal] = ACTIONS(6998),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6998),
    [sym_integer] = ACTIONS(6996),
    [sym_continue_as_identifier] = ACTIONS(6998),
  },
  [STATE(2836)] = {
    [sym_identifier] = ACTIONS(6976),
    [anon_sym_SEMI] = ACTIONS(6978),
    [aux_sym_where_condition_token1] = ACTIONS(6976),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6976),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6976),
    [anon_sym_LBRACK] = ACTIONS(6978),
    [aux_sym_basic_type_token6] = ACTIONS(6976),
    [aux_sym_basic_type_token22] = ACTIONS(6976),
    [aux_sym_basic_type_token53] = ACTIONS(6976),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6976),
    [aux_sym_addafter_modification_token1] = ACTIONS(6976),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6976),
    [aux_sym_modify_modification_token1] = ACTIONS(6976),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6976),
    [aux_sym_movelast_modification_token1] = ACTIONS(6976),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6976),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6976),
    [aux_sym_separator_action_token1] = ACTIONS(6976),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6976),
    [aux_sym_type_declaration_token1] = ACTIONS(6976),
    [anon_sym_POUNDif] = ACTIONS(6978),
    [anon_sym_POUNDIF] = ACTIONS(6978),
    [anon_sym_POUNDIf] = ACTIONS(6978),
    [anon_sym_POUNDelif] = ACTIONS(6978),
    [anon_sym_POUNDELIF] = ACTIONS(6978),
    [anon_sym_POUNDElif] = ACTIONS(6978),
    [anon_sym_POUNDelse] = ACTIONS(6978),
    [anon_sym_POUNDELSE] = ACTIONS(6978),
    [anon_sym_POUNDElse] = ACTIONS(6978),
    [anon_sym_POUNDendif] = ACTIONS(6978),
    [anon_sym_POUNDENDIF] = ACTIONS(6978),
    [anon_sym_POUNDEndif] = ACTIONS(6978),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6976),
    [sym_trigger_keyword] = ACTIONS(6976),
    [sym_var_keyword] = ACTIONS(6976),
    [sym_local_keyword] = ACTIONS(6976),
    [sym_internal_keyword] = ACTIONS(6976),
    [sym_protected_keyword] = ACTIONS(6976),
    [sym_event_keyword] = ACTIONS(6976),
    [sym_fields_keyword] = ACTIONS(6976),
    [sym_keys_keyword] = ACTIONS(6976),
    [sym_key_keyword] = ACTIONS(6976),
    [sym_fieldgroups_keyword] = ACTIONS(6976),
    [sym_actions_keyword] = ACTIONS(6976),
    [sym_layout_keyword] = ACTIONS(6976),
    [sym_area_keyword] = ACTIONS(6976),
    [sym_group_keyword] = ACTIONS(6976),
    [sym_repeater_keyword] = ACTIONS(6976),
    [sym_cuegroup_keyword] = ACTIONS(6976),
    [sym_fixed_keyword] = ACTIONS(6976),
    [sym_grid_keyword] = ACTIONS(6976),
    [sym_part_keyword] = ACTIONS(6976),
    [sym_systempart_keyword] = ACTIONS(6976),
    [sym_usercontrol_keyword] = ACTIONS(6976),
    [sym_dataset_keyword] = ACTIONS(6976),
    [sym_elements_keyword] = ACTIONS(6976),
    [sym_dataitem_keyword] = ACTIONS(6976),
    [sym_column_keyword] = ACTIONS(6976),
    [sym_filter_keyword] = ACTIONS(6976),
    [sym_labels_keyword] = ACTIONS(6976),
    [sym_rendering_keyword] = ACTIONS(6976),
    [sym_requestpage_keyword] = ACTIONS(6976),
    [sym_schema_keyword] = ACTIONS(6976),
    [sym_views_keyword] = ACTIONS(6976),
    [sym_quoted_identifier] = ACTIONS(6978),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6978),
    [sym_preproc_open] = ACTIONS(6978),
    [sym_preproc_close] = ACTIONS(6978),
    [sym_var_attribute_open] = ACTIONS(6978),
  },
  [STATE(2837)] = {
    [sym_boolean] = STATE(4937),
    [sym_assignment_expression] = STATE(4937),
    [sym__expression] = STATE(4937),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4937),
    [sym_multiplicative_expression] = STATE(4937),
    [sym_additive_expression] = STATE(4937),
    [sym_comparison_expression] = STATE(4937),
    [sym_logical_expression] = STATE(4937),
    [sym_ternary_expression] = STATE(4937),
    [sym_unary_expression] = STATE(4937),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4937),
    [sym_list_literal] = STATE(4937),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4937),
    [sym__literal_value] = STATE(4937),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7000),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7002),
    [sym_date_literal] = ACTIONS(7000),
    [sym_time_literal] = ACTIONS(7000),
    [sym_biginteger_literal] = ACTIONS(7002),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7002),
    [sym_integer] = ACTIONS(7000),
    [sym_continue_as_identifier] = ACTIONS(7002),
  },
  [STATE(2838)] = {
    [sym_boolean] = STATE(1073),
    [sym_assignment_expression] = STATE(1073),
    [sym__expression] = STATE(1073),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1073),
    [sym_multiplicative_expression] = STATE(1073),
    [sym_additive_expression] = STATE(1073),
    [sym_comparison_expression] = STATE(1073),
    [sym_logical_expression] = STATE(1073),
    [sym_ternary_expression] = STATE(1073),
    [sym_unary_expression] = STATE(1073),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1073),
    [sym_list_literal] = STATE(1073),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1073),
    [sym__literal_value] = STATE(1073),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7004),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7006),
    [sym_date_literal] = ACTIONS(7004),
    [sym_time_literal] = ACTIONS(7004),
    [sym_biginteger_literal] = ACTIONS(7006),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7006),
    [sym_integer] = ACTIONS(7004),
    [sym_continue_as_identifier] = ACTIONS(7006),
  },
  [STATE(2839)] = {
    [sym_boolean] = STATE(1074),
    [sym_assignment_expression] = STATE(1074),
    [sym__expression] = STATE(1074),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1074),
    [sym_multiplicative_expression] = STATE(1074),
    [sym_additive_expression] = STATE(1074),
    [sym_comparison_expression] = STATE(1074),
    [sym_logical_expression] = STATE(1074),
    [sym_ternary_expression] = STATE(1074),
    [sym_unary_expression] = STATE(1074),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1074),
    [sym_list_literal] = STATE(1074),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1074),
    [sym__literal_value] = STATE(1074),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7008),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7010),
    [sym_date_literal] = ACTIONS(7008),
    [sym_time_literal] = ACTIONS(7008),
    [sym_biginteger_literal] = ACTIONS(7010),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7010),
    [sym_integer] = ACTIONS(7008),
    [sym_continue_as_identifier] = ACTIONS(7010),
  },
  [STATE(2840)] = {
    [sym_boolean] = STATE(4940),
    [sym_assignment_expression] = STATE(4940),
    [sym__expression] = STATE(4940),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4940),
    [sym_multiplicative_expression] = STATE(4940),
    [sym_additive_expression] = STATE(4940),
    [sym_comparison_expression] = STATE(4940),
    [sym_logical_expression] = STATE(4940),
    [sym_ternary_expression] = STATE(4940),
    [sym_unary_expression] = STATE(4940),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4940),
    [sym_list_literal] = STATE(4940),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4940),
    [sym__literal_value] = STATE(4940),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7012),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7014),
    [sym_date_literal] = ACTIONS(7012),
    [sym_time_literal] = ACTIONS(7012),
    [sym_biginteger_literal] = ACTIONS(7014),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7014),
    [sym_integer] = ACTIONS(7012),
    [sym_continue_as_identifier] = ACTIONS(7014),
  },
  [STATE(2841)] = {
    [sym_boolean] = STATE(4941),
    [sym_assignment_expression] = STATE(4941),
    [sym__expression] = STATE(4941),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4941),
    [sym_multiplicative_expression] = STATE(4941),
    [sym_additive_expression] = STATE(4941),
    [sym_comparison_expression] = STATE(4941),
    [sym_logical_expression] = STATE(4941),
    [sym_ternary_expression] = STATE(4941),
    [sym_unary_expression] = STATE(4941),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4941),
    [sym_list_literal] = STATE(4941),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4941),
    [sym__literal_value] = STATE(4941),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7016),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7018),
    [sym_date_literal] = ACTIONS(7016),
    [sym_time_literal] = ACTIONS(7016),
    [sym_biginteger_literal] = ACTIONS(7018),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7018),
    [sym_integer] = ACTIONS(7016),
    [sym_continue_as_identifier] = ACTIONS(7018),
  },
  [STATE(2842)] = {
    [sym_boolean] = STATE(4951),
    [sym_assignment_expression] = STATE(4951),
    [sym__expression] = STATE(4951),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4951),
    [sym_multiplicative_expression] = STATE(4951),
    [sym_additive_expression] = STATE(4951),
    [sym_comparison_expression] = STATE(4951),
    [sym_logical_expression] = STATE(4951),
    [sym_ternary_expression] = STATE(4951),
    [sym_unary_expression] = STATE(4951),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4951),
    [sym_list_literal] = STATE(4951),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4951),
    [sym__literal_value] = STATE(4951),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7020),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7022),
    [sym_date_literal] = ACTIONS(7020),
    [sym_time_literal] = ACTIONS(7020),
    [sym_biginteger_literal] = ACTIONS(7022),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7022),
    [sym_integer] = ACTIONS(7020),
    [sym_continue_as_identifier] = ACTIONS(7022),
  },
  [STATE(2843)] = {
    [sym_boolean] = STATE(1075),
    [sym_assignment_expression] = STATE(1075),
    [sym__expression] = STATE(1075),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1075),
    [sym_multiplicative_expression] = STATE(1075),
    [sym_additive_expression] = STATE(1075),
    [sym_comparison_expression] = STATE(1075),
    [sym_logical_expression] = STATE(1075),
    [sym_ternary_expression] = STATE(1075),
    [sym_unary_expression] = STATE(1075),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1075),
    [sym_list_literal] = STATE(1075),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1075),
    [sym__literal_value] = STATE(1075),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7024),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7026),
    [sym_date_literal] = ACTIONS(7024),
    [sym_time_literal] = ACTIONS(7024),
    [sym_biginteger_literal] = ACTIONS(7026),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7026),
    [sym_integer] = ACTIONS(7024),
    [sym_continue_as_identifier] = ACTIONS(7026),
  },
  [STATE(2844)] = {
    [sym_boolean] = STATE(4952),
    [sym_assignment_expression] = STATE(4952),
    [sym__expression] = STATE(4952),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4952),
    [sym_multiplicative_expression] = STATE(4952),
    [sym_additive_expression] = STATE(4952),
    [sym_comparison_expression] = STATE(4952),
    [sym_logical_expression] = STATE(4952),
    [sym_ternary_expression] = STATE(4952),
    [sym_unary_expression] = STATE(4952),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4952),
    [sym_list_literal] = STATE(4952),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4952),
    [sym__literal_value] = STATE(4952),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7028),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7030),
    [sym_date_literal] = ACTIONS(7028),
    [sym_time_literal] = ACTIONS(7028),
    [sym_biginteger_literal] = ACTIONS(7030),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7030),
    [sym_integer] = ACTIONS(7028),
    [sym_continue_as_identifier] = ACTIONS(7030),
  },
  [STATE(2845)] = {
    [sym_boolean] = STATE(4953),
    [sym_assignment_expression] = STATE(4953),
    [sym__expression] = STATE(4953),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4953),
    [sym_multiplicative_expression] = STATE(4953),
    [sym_additive_expression] = STATE(4953),
    [sym_comparison_expression] = STATE(4953),
    [sym_logical_expression] = STATE(4953),
    [sym_ternary_expression] = STATE(4953),
    [sym_unary_expression] = STATE(4953),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4953),
    [sym_list_literal] = STATE(4953),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4953),
    [sym__literal_value] = STATE(4953),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7032),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7034),
    [sym_date_literal] = ACTIONS(7032),
    [sym_time_literal] = ACTIONS(7032),
    [sym_biginteger_literal] = ACTIONS(7034),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7034),
    [sym_integer] = ACTIONS(7032),
    [sym_continue_as_identifier] = ACTIONS(7034),
  },
  [STATE(2846)] = {
    [sym_boolean] = STATE(5893),
    [sym_assignment_expression] = STATE(5893),
    [sym__expression] = STATE(5893),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5893),
    [sym_multiplicative_expression] = STATE(5893),
    [sym_additive_expression] = STATE(5893),
    [sym_comparison_expression] = STATE(5893),
    [sym_logical_expression] = STATE(5893),
    [sym_ternary_expression] = STATE(5893),
    [sym_unary_expression] = STATE(5893),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5893),
    [sym_list_literal] = STATE(5893),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5893),
    [sym__literal_value] = STATE(5893),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7040),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7050),
    [sym_date_literal] = ACTIONS(7040),
    [sym_time_literal] = ACTIONS(7040),
    [sym_biginteger_literal] = ACTIONS(7050),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7050),
    [sym_integer] = ACTIONS(7040),
    [sym_continue_as_identifier] = ACTIONS(7050),
  },
  [STATE(2847)] = {
    [sym_boolean] = STATE(4955),
    [sym_assignment_expression] = STATE(4955),
    [sym__expression] = STATE(4955),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4955),
    [sym_multiplicative_expression] = STATE(4955),
    [sym_additive_expression] = STATE(4955),
    [sym_comparison_expression] = STATE(4955),
    [sym_logical_expression] = STATE(4955),
    [sym_ternary_expression] = STATE(4955),
    [sym_unary_expression] = STATE(4955),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4955),
    [sym_list_literal] = STATE(4955),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4955),
    [sym__literal_value] = STATE(4955),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7054),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7056),
    [sym_date_literal] = ACTIONS(7054),
    [sym_time_literal] = ACTIONS(7054),
    [sym_biginteger_literal] = ACTIONS(7056),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7056),
    [sym_integer] = ACTIONS(7054),
    [sym_continue_as_identifier] = ACTIONS(7056),
  },
  [STATE(2848)] = {
    [sym_boolean] = STATE(4961),
    [sym_assignment_expression] = STATE(4961),
    [sym__expression] = STATE(4961),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4961),
    [sym_multiplicative_expression] = STATE(4961),
    [sym_additive_expression] = STATE(4961),
    [sym_comparison_expression] = STATE(4961),
    [sym_logical_expression] = STATE(4961),
    [sym_ternary_expression] = STATE(4961),
    [sym_unary_expression] = STATE(4961),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4961),
    [sym_list_literal] = STATE(4961),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4961),
    [sym__literal_value] = STATE(4961),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7058),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7060),
    [sym_date_literal] = ACTIONS(7058),
    [sym_time_literal] = ACTIONS(7058),
    [sym_biginteger_literal] = ACTIONS(7060),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7060),
    [sym_integer] = ACTIONS(7058),
    [sym_continue_as_identifier] = ACTIONS(7060),
  },
  [STATE(2849)] = {
    [sym_boolean] = STATE(4962),
    [sym_assignment_expression] = STATE(4962),
    [sym__expression] = STATE(4962),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4962),
    [sym_multiplicative_expression] = STATE(4962),
    [sym_additive_expression] = STATE(4962),
    [sym_comparison_expression] = STATE(4962),
    [sym_logical_expression] = STATE(4962),
    [sym_ternary_expression] = STATE(4962),
    [sym_unary_expression] = STATE(4962),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4962),
    [sym_list_literal] = STATE(4962),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4962),
    [sym__literal_value] = STATE(4962),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7062),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7064),
    [sym_date_literal] = ACTIONS(7062),
    [sym_time_literal] = ACTIONS(7062),
    [sym_biginteger_literal] = ACTIONS(7064),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7064),
    [sym_integer] = ACTIONS(7062),
    [sym_continue_as_identifier] = ACTIONS(7064),
  },
  [STATE(2850)] = {
    [sym_boolean] = STATE(4866),
    [sym_assignment_expression] = STATE(4866),
    [sym__expression] = STATE(4866),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4866),
    [sym_multiplicative_expression] = STATE(4866),
    [sym_additive_expression] = STATE(4866),
    [sym_comparison_expression] = STATE(4866),
    [sym_logical_expression] = STATE(4866),
    [sym_ternary_expression] = STATE(4866),
    [sym_unary_expression] = STATE(4866),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4866),
    [sym_list_literal] = STATE(4866),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4866),
    [sym__literal_value] = STATE(4866),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7066),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7068),
    [sym_date_literal] = ACTIONS(7066),
    [sym_time_literal] = ACTIONS(7066),
    [sym_biginteger_literal] = ACTIONS(7068),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7068),
    [sym_integer] = ACTIONS(7066),
    [sym_continue_as_identifier] = ACTIONS(7068),
  },
  [STATE(2851)] = {
    [sym_boolean] = STATE(4967),
    [sym_assignment_expression] = STATE(4967),
    [sym__expression] = STATE(4967),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4967),
    [sym_multiplicative_expression] = STATE(4967),
    [sym_additive_expression] = STATE(4967),
    [sym_comparison_expression] = STATE(4967),
    [sym_logical_expression] = STATE(4967),
    [sym_ternary_expression] = STATE(4967),
    [sym_unary_expression] = STATE(4967),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4967),
    [sym_list_literal] = STATE(4967),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4967),
    [sym__literal_value] = STATE(4967),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7070),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7072),
    [sym_date_literal] = ACTIONS(7070),
    [sym_time_literal] = ACTIONS(7070),
    [sym_biginteger_literal] = ACTIONS(7072),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7072),
    [sym_integer] = ACTIONS(7070),
    [sym_continue_as_identifier] = ACTIONS(7072),
  },
  [STATE(2852)] = {
    [sym_boolean] = STATE(4938),
    [sym_assignment_expression] = STATE(4938),
    [sym__expression] = STATE(4938),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4938),
    [sym_multiplicative_expression] = STATE(4938),
    [sym_additive_expression] = STATE(4938),
    [sym_comparison_expression] = STATE(4938),
    [sym_logical_expression] = STATE(4938),
    [sym_ternary_expression] = STATE(4938),
    [sym_unary_expression] = STATE(4938),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4938),
    [sym_list_literal] = STATE(4938),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4938),
    [sym__literal_value] = STATE(4938),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7074),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7076),
    [sym_date_literal] = ACTIONS(7074),
    [sym_time_literal] = ACTIONS(7074),
    [sym_biginteger_literal] = ACTIONS(7076),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7076),
    [sym_integer] = ACTIONS(7074),
    [sym_continue_as_identifier] = ACTIONS(7076),
  },
  [STATE(2853)] = {
    [sym_boolean] = STATE(4972),
    [sym_assignment_expression] = STATE(4972),
    [sym__expression] = STATE(4972),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4972),
    [sym_multiplicative_expression] = STATE(4972),
    [sym_additive_expression] = STATE(4972),
    [sym_comparison_expression] = STATE(4972),
    [sym_logical_expression] = STATE(4972),
    [sym_ternary_expression] = STATE(4972),
    [sym_unary_expression] = STATE(4972),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4972),
    [sym_list_literal] = STATE(4972),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4972),
    [sym__literal_value] = STATE(4972),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7078),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7080),
    [sym_date_literal] = ACTIONS(7078),
    [sym_time_literal] = ACTIONS(7078),
    [sym_biginteger_literal] = ACTIONS(7080),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7080),
    [sym_integer] = ACTIONS(7078),
    [sym_continue_as_identifier] = ACTIONS(7080),
  },
  [STATE(2854)] = {
    [sym_boolean] = STATE(4973),
    [sym_assignment_expression] = STATE(4973),
    [sym__expression] = STATE(4973),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4973),
    [sym_multiplicative_expression] = STATE(4973),
    [sym_additive_expression] = STATE(4973),
    [sym_comparison_expression] = STATE(4973),
    [sym_logical_expression] = STATE(4973),
    [sym_ternary_expression] = STATE(4973),
    [sym_unary_expression] = STATE(4973),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4973),
    [sym_list_literal] = STATE(4973),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4973),
    [sym__literal_value] = STATE(4973),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7082),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7084),
    [sym_date_literal] = ACTIONS(7082),
    [sym_time_literal] = ACTIONS(7082),
    [sym_biginteger_literal] = ACTIONS(7084),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7084),
    [sym_integer] = ACTIONS(7082),
    [sym_continue_as_identifier] = ACTIONS(7084),
  },
  [STATE(2855)] = {
    [sym_boolean] = STATE(4963),
    [sym_assignment_expression] = STATE(4963),
    [sym__expression] = STATE(4963),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4963),
    [sym_multiplicative_expression] = STATE(4963),
    [sym_additive_expression] = STATE(4963),
    [sym_comparison_expression] = STATE(4963),
    [sym_logical_expression] = STATE(4963),
    [sym_ternary_expression] = STATE(4963),
    [sym_unary_expression] = STATE(4963),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4963),
    [sym_list_literal] = STATE(4963),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4963),
    [sym__literal_value] = STATE(4963),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7086),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7088),
    [sym_date_literal] = ACTIONS(7086),
    [sym_time_literal] = ACTIONS(7086),
    [sym_biginteger_literal] = ACTIONS(7088),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7088),
    [sym_integer] = ACTIONS(7086),
    [sym_continue_as_identifier] = ACTIONS(7088),
  },
  [STATE(2856)] = {
    [sym_boolean] = STATE(4922),
    [sym_assignment_expression] = STATE(4922),
    [sym__expression] = STATE(4922),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4922),
    [sym_multiplicative_expression] = STATE(4922),
    [sym_additive_expression] = STATE(4922),
    [sym_comparison_expression] = STATE(4922),
    [sym_logical_expression] = STATE(4922),
    [sym_ternary_expression] = STATE(4922),
    [sym_unary_expression] = STATE(4922),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4922),
    [sym_list_literal] = STATE(4922),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4922),
    [sym__literal_value] = STATE(4922),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7090),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7092),
    [sym_date_literal] = ACTIONS(7090),
    [sym_time_literal] = ACTIONS(7090),
    [sym_biginteger_literal] = ACTIONS(7092),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7092),
    [sym_integer] = ACTIONS(7090),
    [sym_continue_as_identifier] = ACTIONS(7092),
  },
  [STATE(2857)] = {
    [sym_boolean] = STATE(5882),
    [sym_assignment_expression] = STATE(5882),
    [sym__expression] = STATE(5882),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5882),
    [sym_multiplicative_expression] = STATE(5882),
    [sym_additive_expression] = STATE(5882),
    [sym_comparison_expression] = STATE(5882),
    [sym_logical_expression] = STATE(5882),
    [sym_ternary_expression] = STATE(5882),
    [sym_unary_expression] = STATE(5882),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5882),
    [sym_list_literal] = STATE(5882),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5882),
    [sym__literal_value] = STATE(5882),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7094),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7096),
    [sym_date_literal] = ACTIONS(7094),
    [sym_time_literal] = ACTIONS(7094),
    [sym_biginteger_literal] = ACTIONS(7096),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7096),
    [sym_integer] = ACTIONS(7094),
    [sym_continue_as_identifier] = ACTIONS(7096),
  },
  [STATE(2858)] = {
    [sym_boolean] = STATE(5883),
    [sym_assignment_expression] = STATE(5883),
    [sym__expression] = STATE(5883),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5883),
    [sym_multiplicative_expression] = STATE(5883),
    [sym_additive_expression] = STATE(5883),
    [sym_comparison_expression] = STATE(5883),
    [sym_logical_expression] = STATE(5883),
    [sym_ternary_expression] = STATE(5883),
    [sym_unary_expression] = STATE(5883),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5883),
    [sym_list_literal] = STATE(5883),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5883),
    [sym__literal_value] = STATE(5883),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7098),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7100),
    [sym_date_literal] = ACTIONS(7098),
    [sym_time_literal] = ACTIONS(7098),
    [sym_biginteger_literal] = ACTIONS(7100),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7100),
    [sym_integer] = ACTIONS(7098),
    [sym_continue_as_identifier] = ACTIONS(7100),
  },
  [STATE(2859)] = {
    [sym_boolean] = STATE(5884),
    [sym_assignment_expression] = STATE(5884),
    [sym__expression] = STATE(5884),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5884),
    [sym_multiplicative_expression] = STATE(5884),
    [sym_additive_expression] = STATE(5884),
    [sym_comparison_expression] = STATE(5884),
    [sym_logical_expression] = STATE(5884),
    [sym_ternary_expression] = STATE(5884),
    [sym_unary_expression] = STATE(5884),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5884),
    [sym_list_literal] = STATE(5884),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5884),
    [sym__literal_value] = STATE(5884),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7102),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7104),
    [sym_date_literal] = ACTIONS(7102),
    [sym_time_literal] = ACTIONS(7102),
    [sym_biginteger_literal] = ACTIONS(7104),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7104),
    [sym_integer] = ACTIONS(7102),
    [sym_continue_as_identifier] = ACTIONS(7104),
  },
  [STATE(2860)] = {
    [sym_boolean] = STATE(4950),
    [sym_assignment_expression] = STATE(4950),
    [sym__expression] = STATE(4950),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4950),
    [sym_multiplicative_expression] = STATE(4950),
    [sym_additive_expression] = STATE(4950),
    [sym_comparison_expression] = STATE(4950),
    [sym_logical_expression] = STATE(4950),
    [sym_ternary_expression] = STATE(4950),
    [sym_unary_expression] = STATE(4950),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4950),
    [sym_list_literal] = STATE(4950),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4950),
    [sym__literal_value] = STATE(4950),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7106),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7108),
    [sym_date_literal] = ACTIONS(7106),
    [sym_time_literal] = ACTIONS(7106),
    [sym_biginteger_literal] = ACTIONS(7108),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7108),
    [sym_integer] = ACTIONS(7106),
    [sym_continue_as_identifier] = ACTIONS(7108),
  },
  [STATE(2861)] = {
    [sym_boolean] = STATE(4969),
    [sym_assignment_expression] = STATE(4969),
    [sym__expression] = STATE(4969),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4969),
    [sym_multiplicative_expression] = STATE(4969),
    [sym_additive_expression] = STATE(4969),
    [sym_comparison_expression] = STATE(4969),
    [sym_logical_expression] = STATE(4969),
    [sym_ternary_expression] = STATE(4969),
    [sym_unary_expression] = STATE(4969),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4969),
    [sym_list_literal] = STATE(4969),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4969),
    [sym__literal_value] = STATE(4969),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7110),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7112),
    [sym_date_literal] = ACTIONS(7110),
    [sym_time_literal] = ACTIONS(7110),
    [sym_biginteger_literal] = ACTIONS(7112),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7112),
    [sym_integer] = ACTIONS(7110),
    [sym_continue_as_identifier] = ACTIONS(7112),
  },
  [STATE(2862)] = {
    [sym_boolean] = STATE(2025),
    [sym_assignment_expression] = STATE(2025),
    [sym__expression] = STATE(2025),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2025),
    [sym_multiplicative_expression] = STATE(2025),
    [sym_additive_expression] = STATE(2025),
    [sym_comparison_expression] = STATE(2025),
    [sym_logical_expression] = STATE(2025),
    [sym_ternary_expression] = STATE(2025),
    [sym_unary_expression] = STATE(2025),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2025),
    [sym_list_literal] = STATE(2025),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2025),
    [sym__literal_value] = STATE(2025),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7114),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7116),
    [sym_date_literal] = ACTIONS(7114),
    [sym_time_literal] = ACTIONS(7114),
    [sym_biginteger_literal] = ACTIONS(7116),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7116),
    [sym_integer] = ACTIONS(7114),
    [sym_continue_as_identifier] = ACTIONS(7116),
  },
  [STATE(2863)] = {
    [sym_boolean] = STATE(5885),
    [sym_assignment_expression] = STATE(5885),
    [sym__expression] = STATE(5885),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5885),
    [sym_multiplicative_expression] = STATE(5885),
    [sym_additive_expression] = STATE(5885),
    [sym_comparison_expression] = STATE(5885),
    [sym_logical_expression] = STATE(5885),
    [sym_ternary_expression] = STATE(5885),
    [sym_unary_expression] = STATE(5885),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5885),
    [sym_list_literal] = STATE(5885),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5885),
    [sym__literal_value] = STATE(5885),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7118),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7120),
    [sym_date_literal] = ACTIONS(7118),
    [sym_time_literal] = ACTIONS(7118),
    [sym_biginteger_literal] = ACTIONS(7120),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7120),
    [sym_integer] = ACTIONS(7118),
    [sym_continue_as_identifier] = ACTIONS(7120),
  },
  [STATE(2864)] = {
    [sym_boolean] = STATE(5886),
    [sym_assignment_expression] = STATE(5886),
    [sym__expression] = STATE(5886),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5886),
    [sym_multiplicative_expression] = STATE(5886),
    [sym_additive_expression] = STATE(5886),
    [sym_comparison_expression] = STATE(5886),
    [sym_logical_expression] = STATE(5886),
    [sym_ternary_expression] = STATE(5886),
    [sym_unary_expression] = STATE(5886),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5886),
    [sym_list_literal] = STATE(5886),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5886),
    [sym__literal_value] = STATE(5886),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7122),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7124),
    [sym_date_literal] = ACTIONS(7122),
    [sym_time_literal] = ACTIONS(7122),
    [sym_biginteger_literal] = ACTIONS(7124),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7124),
    [sym_integer] = ACTIONS(7122),
    [sym_continue_as_identifier] = ACTIONS(7124),
  },
  [STATE(2865)] = {
    [sym_boolean] = STATE(5887),
    [sym_assignment_expression] = STATE(5887),
    [sym__expression] = STATE(5887),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5887),
    [sym_multiplicative_expression] = STATE(5887),
    [sym_additive_expression] = STATE(5887),
    [sym_comparison_expression] = STATE(5887),
    [sym_logical_expression] = STATE(5887),
    [sym_ternary_expression] = STATE(5887),
    [sym_unary_expression] = STATE(5887),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5887),
    [sym_list_literal] = STATE(5887),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5887),
    [sym__literal_value] = STATE(5887),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7126),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7128),
    [sym_date_literal] = ACTIONS(7126),
    [sym_time_literal] = ACTIONS(7126),
    [sym_biginteger_literal] = ACTIONS(7128),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7128),
    [sym_integer] = ACTIONS(7126),
    [sym_continue_as_identifier] = ACTIONS(7128),
  },
  [STATE(2866)] = {
    [sym_boolean] = STATE(2042),
    [sym_assignment_expression] = STATE(2042),
    [sym__expression] = STATE(2042),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2042),
    [sym_multiplicative_expression] = STATE(2042),
    [sym_additive_expression] = STATE(2042),
    [sym_comparison_expression] = STATE(2042),
    [sym_logical_expression] = STATE(2042),
    [sym_ternary_expression] = STATE(2042),
    [sym_unary_expression] = STATE(2042),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2042),
    [sym_list_literal] = STATE(2042),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2042),
    [sym__literal_value] = STATE(2042),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(7132),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(7136),
    [sym_date_literal] = ACTIONS(7132),
    [sym_time_literal] = ACTIONS(7132),
    [sym_biginteger_literal] = ACTIONS(7136),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7136),
    [sym_integer] = ACTIONS(7132),
    [sym_continue_as_identifier] = ACTIONS(7136),
  },
  [STATE(2867)] = {
    [sym_boolean] = STATE(2033),
    [sym_assignment_expression] = STATE(2033),
    [sym__expression] = STATE(2033),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2033),
    [sym_multiplicative_expression] = STATE(2033),
    [sym_additive_expression] = STATE(2033),
    [sym_comparison_expression] = STATE(2033),
    [sym_logical_expression] = STATE(2033),
    [sym_ternary_expression] = STATE(2033),
    [sym_unary_expression] = STATE(2033),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2033),
    [sym_list_literal] = STATE(2033),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2033),
    [sym__literal_value] = STATE(2033),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(7140),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(7142),
    [sym_date_literal] = ACTIONS(7140),
    [sym_time_literal] = ACTIONS(7140),
    [sym_biginteger_literal] = ACTIONS(7142),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7142),
    [sym_integer] = ACTIONS(7140),
    [sym_continue_as_identifier] = ACTIONS(7142),
  },
  [STATE(2868)] = {
    [sym_boolean] = STATE(4870),
    [sym_assignment_expression] = STATE(4870),
    [sym__expression] = STATE(4870),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4870),
    [sym_multiplicative_expression] = STATE(4870),
    [sym_additive_expression] = STATE(4870),
    [sym_comparison_expression] = STATE(4870),
    [sym_logical_expression] = STATE(4870),
    [sym_ternary_expression] = STATE(4870),
    [sym_unary_expression] = STATE(4870),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4870),
    [sym_list_literal] = STATE(4870),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4870),
    [sym__literal_value] = STATE(4870),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7144),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7146),
    [sym_date_literal] = ACTIONS(7144),
    [sym_time_literal] = ACTIONS(7144),
    [sym_biginteger_literal] = ACTIONS(7146),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7146),
    [sym_integer] = ACTIONS(7144),
    [sym_continue_as_identifier] = ACTIONS(7146),
  },
  [STATE(2869)] = {
    [sym_boolean] = STATE(5888),
    [sym_assignment_expression] = STATE(5888),
    [sym__expression] = STATE(5888),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5888),
    [sym_multiplicative_expression] = STATE(5888),
    [sym_additive_expression] = STATE(5888),
    [sym_comparison_expression] = STATE(5888),
    [sym_logical_expression] = STATE(5888),
    [sym_ternary_expression] = STATE(5888),
    [sym_unary_expression] = STATE(5888),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5888),
    [sym_list_literal] = STATE(5888),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5888),
    [sym__literal_value] = STATE(5888),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7148),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7150),
    [sym_date_literal] = ACTIONS(7148),
    [sym_time_literal] = ACTIONS(7148),
    [sym_biginteger_literal] = ACTIONS(7150),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7150),
    [sym_integer] = ACTIONS(7148),
    [sym_continue_as_identifier] = ACTIONS(7150),
  },
  [STATE(2870)] = {
    [sym_identifier] = ACTIONS(7152),
    [anon_sym_SEMI] = ACTIONS(7154),
    [aux_sym_where_condition_token1] = ACTIONS(7152),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7152),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7152),
    [anon_sym_LBRACK] = ACTIONS(7154),
    [aux_sym_basic_type_token6] = ACTIONS(7152),
    [aux_sym_basic_type_token22] = ACTIONS(7152),
    [aux_sym_basic_type_token53] = ACTIONS(7152),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7152),
    [aux_sym_addafter_modification_token1] = ACTIONS(7152),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7152),
    [aux_sym_modify_modification_token1] = ACTIONS(7152),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7152),
    [aux_sym_movelast_modification_token1] = ACTIONS(7152),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7152),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7152),
    [aux_sym_separator_action_token1] = ACTIONS(7152),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7152),
    [aux_sym_type_declaration_token1] = ACTIONS(7152),
    [anon_sym_POUNDif] = ACTIONS(7154),
    [anon_sym_POUNDIF] = ACTIONS(7154),
    [anon_sym_POUNDIf] = ACTIONS(7154),
    [anon_sym_POUNDelif] = ACTIONS(7154),
    [anon_sym_POUNDELIF] = ACTIONS(7154),
    [anon_sym_POUNDElif] = ACTIONS(7154),
    [anon_sym_POUNDelse] = ACTIONS(7154),
    [anon_sym_POUNDELSE] = ACTIONS(7154),
    [anon_sym_POUNDElse] = ACTIONS(7154),
    [anon_sym_POUNDendif] = ACTIONS(7154),
    [anon_sym_POUNDENDIF] = ACTIONS(7154),
    [anon_sym_POUNDEndif] = ACTIONS(7154),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7152),
    [sym_trigger_keyword] = ACTIONS(7152),
    [sym_var_keyword] = ACTIONS(7152),
    [sym_local_keyword] = ACTIONS(7152),
    [sym_internal_keyword] = ACTIONS(7152),
    [sym_protected_keyword] = ACTIONS(7152),
    [sym_event_keyword] = ACTIONS(7152),
    [sym_fields_keyword] = ACTIONS(7152),
    [sym_keys_keyword] = ACTIONS(7152),
    [sym_key_keyword] = ACTIONS(7152),
    [sym_fieldgroups_keyword] = ACTIONS(7152),
    [sym_actions_keyword] = ACTIONS(7152),
    [sym_layout_keyword] = ACTIONS(7152),
    [sym_area_keyword] = ACTIONS(7152),
    [sym_group_keyword] = ACTIONS(7152),
    [sym_repeater_keyword] = ACTIONS(7152),
    [sym_cuegroup_keyword] = ACTIONS(7152),
    [sym_fixed_keyword] = ACTIONS(7152),
    [sym_grid_keyword] = ACTIONS(7152),
    [sym_part_keyword] = ACTIONS(7152),
    [sym_systempart_keyword] = ACTIONS(7152),
    [sym_usercontrol_keyword] = ACTIONS(7152),
    [sym_dataset_keyword] = ACTIONS(7152),
    [sym_elements_keyword] = ACTIONS(7152),
    [sym_dataitem_keyword] = ACTIONS(7152),
    [sym_column_keyword] = ACTIONS(7152),
    [sym_filter_keyword] = ACTIONS(7152),
    [sym_labels_keyword] = ACTIONS(7152),
    [sym_rendering_keyword] = ACTIONS(7152),
    [sym_requestpage_keyword] = ACTIONS(7152),
    [sym_schema_keyword] = ACTIONS(7152),
    [sym_views_keyword] = ACTIONS(7152),
    [sym_quoted_identifier] = ACTIONS(7154),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7154),
    [sym_preproc_open] = ACTIONS(7154),
    [sym_preproc_close] = ACTIONS(7154),
    [sym_var_attribute_open] = ACTIONS(7154),
  },
  [STATE(2871)] = {
    [sym_identifier] = ACTIONS(7152),
    [anon_sym_SEMI] = ACTIONS(7154),
    [aux_sym_where_condition_token1] = ACTIONS(7152),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7152),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7152),
    [anon_sym_LBRACK] = ACTIONS(7154),
    [aux_sym_basic_type_token6] = ACTIONS(7152),
    [aux_sym_basic_type_token22] = ACTIONS(7152),
    [aux_sym_basic_type_token53] = ACTIONS(7152),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7152),
    [aux_sym_addafter_modification_token1] = ACTIONS(7152),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7152),
    [aux_sym_modify_modification_token1] = ACTIONS(7152),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7152),
    [aux_sym_movelast_modification_token1] = ACTIONS(7152),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7152),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7152),
    [aux_sym_separator_action_token1] = ACTIONS(7152),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7152),
    [aux_sym_type_declaration_token1] = ACTIONS(7152),
    [anon_sym_POUNDif] = ACTIONS(7154),
    [anon_sym_POUNDIF] = ACTIONS(7154),
    [anon_sym_POUNDIf] = ACTIONS(7154),
    [anon_sym_POUNDelif] = ACTIONS(7154),
    [anon_sym_POUNDELIF] = ACTIONS(7154),
    [anon_sym_POUNDElif] = ACTIONS(7154),
    [anon_sym_POUNDelse] = ACTIONS(7154),
    [anon_sym_POUNDELSE] = ACTIONS(7154),
    [anon_sym_POUNDElse] = ACTIONS(7154),
    [anon_sym_POUNDendif] = ACTIONS(7154),
    [anon_sym_POUNDENDIF] = ACTIONS(7154),
    [anon_sym_POUNDEndif] = ACTIONS(7154),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7152),
    [sym_trigger_keyword] = ACTIONS(7152),
    [sym_var_keyword] = ACTIONS(7152),
    [sym_local_keyword] = ACTIONS(7152),
    [sym_internal_keyword] = ACTIONS(7152),
    [sym_protected_keyword] = ACTIONS(7152),
    [sym_event_keyword] = ACTIONS(7152),
    [sym_fields_keyword] = ACTIONS(7152),
    [sym_keys_keyword] = ACTIONS(7152),
    [sym_key_keyword] = ACTIONS(7152),
    [sym_fieldgroups_keyword] = ACTIONS(7152),
    [sym_actions_keyword] = ACTIONS(7152),
    [sym_layout_keyword] = ACTIONS(7152),
    [sym_area_keyword] = ACTIONS(7152),
    [sym_group_keyword] = ACTIONS(7152),
    [sym_repeater_keyword] = ACTIONS(7152),
    [sym_cuegroup_keyword] = ACTIONS(7152),
    [sym_fixed_keyword] = ACTIONS(7152),
    [sym_grid_keyword] = ACTIONS(7152),
    [sym_part_keyword] = ACTIONS(7152),
    [sym_systempart_keyword] = ACTIONS(7152),
    [sym_usercontrol_keyword] = ACTIONS(7152),
    [sym_dataset_keyword] = ACTIONS(7152),
    [sym_elements_keyword] = ACTIONS(7152),
    [sym_dataitem_keyword] = ACTIONS(7152),
    [sym_column_keyword] = ACTIONS(7152),
    [sym_filter_keyword] = ACTIONS(7152),
    [sym_labels_keyword] = ACTIONS(7152),
    [sym_rendering_keyword] = ACTIONS(7152),
    [sym_requestpage_keyword] = ACTIONS(7152),
    [sym_schema_keyword] = ACTIONS(7152),
    [sym_views_keyword] = ACTIONS(7152),
    [sym_quoted_identifier] = ACTIONS(7154),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7154),
    [sym_preproc_open] = ACTIONS(7154),
    [sym_preproc_close] = ACTIONS(7154),
    [sym_var_attribute_open] = ACTIONS(7154),
  },
  [STATE(2872)] = {
    [sym_identifier] = ACTIONS(7152),
    [anon_sym_SEMI] = ACTIONS(7154),
    [aux_sym_where_condition_token1] = ACTIONS(7152),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7152),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7152),
    [anon_sym_LBRACK] = ACTIONS(7154),
    [aux_sym_basic_type_token6] = ACTIONS(7152),
    [aux_sym_basic_type_token22] = ACTIONS(7152),
    [aux_sym_basic_type_token53] = ACTIONS(7152),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7152),
    [aux_sym_addafter_modification_token1] = ACTIONS(7152),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7152),
    [aux_sym_modify_modification_token1] = ACTIONS(7152),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7152),
    [aux_sym_movelast_modification_token1] = ACTIONS(7152),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7152),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7152),
    [aux_sym_separator_action_token1] = ACTIONS(7152),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7152),
    [aux_sym_type_declaration_token1] = ACTIONS(7152),
    [anon_sym_POUNDif] = ACTIONS(7154),
    [anon_sym_POUNDIF] = ACTIONS(7154),
    [anon_sym_POUNDIf] = ACTIONS(7154),
    [anon_sym_POUNDelif] = ACTIONS(7154),
    [anon_sym_POUNDELIF] = ACTIONS(7154),
    [anon_sym_POUNDElif] = ACTIONS(7154),
    [anon_sym_POUNDelse] = ACTIONS(7154),
    [anon_sym_POUNDELSE] = ACTIONS(7154),
    [anon_sym_POUNDElse] = ACTIONS(7154),
    [anon_sym_POUNDendif] = ACTIONS(7154),
    [anon_sym_POUNDENDIF] = ACTIONS(7154),
    [anon_sym_POUNDEndif] = ACTIONS(7154),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7152),
    [sym_trigger_keyword] = ACTIONS(7152),
    [sym_var_keyword] = ACTIONS(7152),
    [sym_local_keyword] = ACTIONS(7152),
    [sym_internal_keyword] = ACTIONS(7152),
    [sym_protected_keyword] = ACTIONS(7152),
    [sym_event_keyword] = ACTIONS(7152),
    [sym_fields_keyword] = ACTIONS(7152),
    [sym_keys_keyword] = ACTIONS(7152),
    [sym_key_keyword] = ACTIONS(7152),
    [sym_fieldgroups_keyword] = ACTIONS(7152),
    [sym_actions_keyword] = ACTIONS(7152),
    [sym_layout_keyword] = ACTIONS(7152),
    [sym_area_keyword] = ACTIONS(7152),
    [sym_group_keyword] = ACTIONS(7152),
    [sym_repeater_keyword] = ACTIONS(7152),
    [sym_cuegroup_keyword] = ACTIONS(7152),
    [sym_fixed_keyword] = ACTIONS(7152),
    [sym_grid_keyword] = ACTIONS(7152),
    [sym_part_keyword] = ACTIONS(7152),
    [sym_systempart_keyword] = ACTIONS(7152),
    [sym_usercontrol_keyword] = ACTIONS(7152),
    [sym_dataset_keyword] = ACTIONS(7152),
    [sym_elements_keyword] = ACTIONS(7152),
    [sym_dataitem_keyword] = ACTIONS(7152),
    [sym_column_keyword] = ACTIONS(7152),
    [sym_filter_keyword] = ACTIONS(7152),
    [sym_labels_keyword] = ACTIONS(7152),
    [sym_rendering_keyword] = ACTIONS(7152),
    [sym_requestpage_keyword] = ACTIONS(7152),
    [sym_schema_keyword] = ACTIONS(7152),
    [sym_views_keyword] = ACTIONS(7152),
    [sym_quoted_identifier] = ACTIONS(7154),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7154),
    [sym_preproc_open] = ACTIONS(7154),
    [sym_preproc_close] = ACTIONS(7154),
    [sym_var_attribute_open] = ACTIONS(7154),
  },
  [STATE(2873)] = {
    [sym_boolean] = STATE(5889),
    [sym_assignment_expression] = STATE(5889),
    [sym__expression] = STATE(5889),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5889),
    [sym_multiplicative_expression] = STATE(5889),
    [sym_additive_expression] = STATE(5889),
    [sym_comparison_expression] = STATE(5889),
    [sym_logical_expression] = STATE(5889),
    [sym_ternary_expression] = STATE(5889),
    [sym_unary_expression] = STATE(5889),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5889),
    [sym_list_literal] = STATE(5889),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5889),
    [sym__literal_value] = STATE(5889),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7156),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7158),
    [sym_date_literal] = ACTIONS(7156),
    [sym_time_literal] = ACTIONS(7156),
    [sym_biginteger_literal] = ACTIONS(7158),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7158),
    [sym_integer] = ACTIONS(7156),
    [sym_continue_as_identifier] = ACTIONS(7158),
  },
  [STATE(2874)] = {
    [sym_preproc_conditional_controladdin] = STATE(3019),
    [sym__body_element] = STATE(3019),
    [sym_empty_statement] = STATE(3019),
    [sym_property] = STATE(3019),
    [sym_fields_section] = STATE(3019),
    [sym_keys_section] = STATE(3019),
    [sym_fieldgroups_section] = STATE(3019),
    [sym_enum_value_declaration] = STATE(3019),
    [sym_labels_section] = STATE(3019),
    [sym_layout_section] = STATE(3019),
    [sym_modify_modification] = STATE(3019),
    [sym_actions_section] = STATE(3019),
    [sym_views_section] = STATE(3019),
    [sym_dataset_section] = STATE(3019),
    [sym_requestpage_section] = STATE(3019),
    [sym_rendering_section] = STATE(3019),
    [sym_elements_section] = STATE(3019),
    [sym_schema_section] = STATE(3019),
    [sym_assembly_declaration] = STATE(3019),
    [sym_event_declaration] = STATE(3019),
    [sym_procedure] = STATE(3019),
    [sym_preproc_split_procedure] = STATE(3019),
    [sym_interface_procedure] = STATE(3019),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3019),
    [sym_var_section] = STATE(3019),
    [sym_attribute_item] = STATE(3019),
    [sym_preproc_conditional] = STATE(3019),
    [sym_preproc_if] = STATE(2635),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3019),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(7160),
    [anon_sym_POUNDELIF] = ACTIONS(7160),
    [anon_sym_POUNDElif] = ACTIONS(7160),
    [anon_sym_POUNDelse] = ACTIONS(7160),
    [anon_sym_POUNDELSE] = ACTIONS(7160),
    [anon_sym_POUNDElse] = ACTIONS(7160),
    [anon_sym_POUNDendif] = ACTIONS(7160),
    [anon_sym_POUNDENDIF] = ACTIONS(7160),
    [anon_sym_POUNDEndif] = ACTIONS(7160),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(7160),
  },
  [STATE(2875)] = {
    [sym_boolean] = STATE(6292),
    [sym_assignment_expression] = STATE(6292),
    [sym__expression] = STATE(6292),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6292),
    [sym_multiplicative_expression] = STATE(6292),
    [sym_additive_expression] = STATE(6292),
    [sym_comparison_expression] = STATE(6292),
    [sym_logical_expression] = STATE(6292),
    [sym_ternary_expression] = STATE(6292),
    [sym_unary_expression] = STATE(6292),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6292),
    [sym_list_literal] = STATE(6292),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6292),
    [sym__literal_value] = STATE(6292),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7162),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7164),
    [sym_date_literal] = ACTIONS(7162),
    [sym_time_literal] = ACTIONS(7162),
    [sym_biginteger_literal] = ACTIONS(7164),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7164),
    [sym_integer] = ACTIONS(7162),
    [sym_continue_as_identifier] = ACTIONS(7164),
  },
  [STATE(2876)] = {
    [sym_identifier] = ACTIONS(7166),
    [anon_sym_SEMI] = ACTIONS(7168),
    [aux_sym_where_condition_token1] = ACTIONS(7166),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7166),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7166),
    [anon_sym_LBRACK] = ACTIONS(7168),
    [aux_sym_basic_type_token6] = ACTIONS(7166),
    [aux_sym_basic_type_token22] = ACTIONS(7166),
    [aux_sym_basic_type_token53] = ACTIONS(7166),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7166),
    [aux_sym_addafter_modification_token1] = ACTIONS(7166),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7166),
    [aux_sym_modify_modification_token1] = ACTIONS(7166),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7166),
    [aux_sym_movelast_modification_token1] = ACTIONS(7166),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7166),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7166),
    [aux_sym_separator_action_token1] = ACTIONS(7166),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7166),
    [aux_sym_type_declaration_token1] = ACTIONS(7166),
    [anon_sym_POUNDif] = ACTIONS(7168),
    [anon_sym_POUNDIF] = ACTIONS(7168),
    [anon_sym_POUNDIf] = ACTIONS(7168),
    [anon_sym_POUNDelif] = ACTIONS(7168),
    [anon_sym_POUNDELIF] = ACTIONS(7168),
    [anon_sym_POUNDElif] = ACTIONS(7168),
    [anon_sym_POUNDelse] = ACTIONS(7168),
    [anon_sym_POUNDELSE] = ACTIONS(7168),
    [anon_sym_POUNDElse] = ACTIONS(7168),
    [anon_sym_POUNDendif] = ACTIONS(7168),
    [anon_sym_POUNDENDIF] = ACTIONS(7168),
    [anon_sym_POUNDEndif] = ACTIONS(7168),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7166),
    [sym_trigger_keyword] = ACTIONS(7166),
    [sym_var_keyword] = ACTIONS(7166),
    [sym_local_keyword] = ACTIONS(7166),
    [sym_internal_keyword] = ACTIONS(7166),
    [sym_protected_keyword] = ACTIONS(7166),
    [sym_event_keyword] = ACTIONS(7166),
    [sym_fields_keyword] = ACTIONS(7166),
    [sym_keys_keyword] = ACTIONS(7166),
    [sym_key_keyword] = ACTIONS(7166),
    [sym_fieldgroups_keyword] = ACTIONS(7166),
    [sym_actions_keyword] = ACTIONS(7166),
    [sym_layout_keyword] = ACTIONS(7166),
    [sym_area_keyword] = ACTIONS(7166),
    [sym_group_keyword] = ACTIONS(7166),
    [sym_repeater_keyword] = ACTIONS(7166),
    [sym_cuegroup_keyword] = ACTIONS(7166),
    [sym_fixed_keyword] = ACTIONS(7166),
    [sym_grid_keyword] = ACTIONS(7166),
    [sym_part_keyword] = ACTIONS(7166),
    [sym_systempart_keyword] = ACTIONS(7166),
    [sym_usercontrol_keyword] = ACTIONS(7166),
    [sym_dataset_keyword] = ACTIONS(7166),
    [sym_elements_keyword] = ACTIONS(7166),
    [sym_dataitem_keyword] = ACTIONS(7166),
    [sym_column_keyword] = ACTIONS(7166),
    [sym_filter_keyword] = ACTIONS(7166),
    [sym_labels_keyword] = ACTIONS(7166),
    [sym_rendering_keyword] = ACTIONS(7166),
    [sym_requestpage_keyword] = ACTIONS(7166),
    [sym_schema_keyword] = ACTIONS(7166),
    [sym_views_keyword] = ACTIONS(7166),
    [sym_quoted_identifier] = ACTIONS(7168),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7168),
    [sym_preproc_open] = ACTIONS(7168),
    [sym_preproc_close] = ACTIONS(7168),
    [sym_var_attribute_open] = ACTIONS(7168),
  },
  [STATE(2877)] = {
    [sym_boolean] = STATE(5871),
    [sym_assignment_expression] = STATE(5871),
    [sym__expression] = STATE(5871),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5871),
    [sym_multiplicative_expression] = STATE(5871),
    [sym_additive_expression] = STATE(5871),
    [sym_comparison_expression] = STATE(5871),
    [sym_logical_expression] = STATE(5871),
    [sym_ternary_expression] = STATE(5871),
    [sym_unary_expression] = STATE(5871),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5871),
    [sym_list_literal] = STATE(5871),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5871),
    [sym__literal_value] = STATE(5871),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7170),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7172),
    [sym_date_literal] = ACTIONS(7170),
    [sym_time_literal] = ACTIONS(7170),
    [sym_biginteger_literal] = ACTIONS(7172),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7172),
    [sym_integer] = ACTIONS(7170),
    [sym_continue_as_identifier] = ACTIONS(7172),
  },
  [STATE(2878)] = {
    [sym_boolean] = STATE(5911),
    [sym_assignment_expression] = STATE(5911),
    [sym__expression] = STATE(5911),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5911),
    [sym_multiplicative_expression] = STATE(5911),
    [sym_additive_expression] = STATE(5911),
    [sym_comparison_expression] = STATE(5911),
    [sym_logical_expression] = STATE(5911),
    [sym_ternary_expression] = STATE(5911),
    [sym_unary_expression] = STATE(5911),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5911),
    [sym_list_literal] = STATE(5911),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5911),
    [sym__literal_value] = STATE(5911),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7174),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7176),
    [sym_date_literal] = ACTIONS(7174),
    [sym_time_literal] = ACTIONS(7174),
    [sym_biginteger_literal] = ACTIONS(7176),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7176),
    [sym_integer] = ACTIONS(7174),
    [sym_continue_as_identifier] = ACTIONS(7176),
  },
  [STATE(2879)] = {
    [sym_identifier] = ACTIONS(7166),
    [anon_sym_SEMI] = ACTIONS(7168),
    [aux_sym_where_condition_token1] = ACTIONS(7166),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7166),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7166),
    [anon_sym_LBRACK] = ACTIONS(7168),
    [aux_sym_basic_type_token6] = ACTIONS(7166),
    [aux_sym_basic_type_token22] = ACTIONS(7166),
    [aux_sym_basic_type_token53] = ACTIONS(7166),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7166),
    [aux_sym_addafter_modification_token1] = ACTIONS(7166),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7166),
    [aux_sym_modify_modification_token1] = ACTIONS(7166),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7166),
    [aux_sym_movelast_modification_token1] = ACTIONS(7166),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7166),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7166),
    [aux_sym_separator_action_token1] = ACTIONS(7166),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7166),
    [aux_sym_type_declaration_token1] = ACTIONS(7166),
    [anon_sym_POUNDif] = ACTIONS(7168),
    [anon_sym_POUNDIF] = ACTIONS(7168),
    [anon_sym_POUNDIf] = ACTIONS(7168),
    [anon_sym_POUNDelif] = ACTIONS(7168),
    [anon_sym_POUNDELIF] = ACTIONS(7168),
    [anon_sym_POUNDElif] = ACTIONS(7168),
    [anon_sym_POUNDelse] = ACTIONS(7168),
    [anon_sym_POUNDELSE] = ACTIONS(7168),
    [anon_sym_POUNDElse] = ACTIONS(7168),
    [anon_sym_POUNDendif] = ACTIONS(7168),
    [anon_sym_POUNDENDIF] = ACTIONS(7168),
    [anon_sym_POUNDEndif] = ACTIONS(7168),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7166),
    [sym_trigger_keyword] = ACTIONS(7166),
    [sym_var_keyword] = ACTIONS(7166),
    [sym_local_keyword] = ACTIONS(7166),
    [sym_internal_keyword] = ACTIONS(7166),
    [sym_protected_keyword] = ACTIONS(7166),
    [sym_event_keyword] = ACTIONS(7166),
    [sym_fields_keyword] = ACTIONS(7166),
    [sym_keys_keyword] = ACTIONS(7166),
    [sym_key_keyword] = ACTIONS(7166),
    [sym_fieldgroups_keyword] = ACTIONS(7166),
    [sym_actions_keyword] = ACTIONS(7166),
    [sym_layout_keyword] = ACTIONS(7166),
    [sym_area_keyword] = ACTIONS(7166),
    [sym_group_keyword] = ACTIONS(7166),
    [sym_repeater_keyword] = ACTIONS(7166),
    [sym_cuegroup_keyword] = ACTIONS(7166),
    [sym_fixed_keyword] = ACTIONS(7166),
    [sym_grid_keyword] = ACTIONS(7166),
    [sym_part_keyword] = ACTIONS(7166),
    [sym_systempart_keyword] = ACTIONS(7166),
    [sym_usercontrol_keyword] = ACTIONS(7166),
    [sym_dataset_keyword] = ACTIONS(7166),
    [sym_elements_keyword] = ACTIONS(7166),
    [sym_dataitem_keyword] = ACTIONS(7166),
    [sym_column_keyword] = ACTIONS(7166),
    [sym_filter_keyword] = ACTIONS(7166),
    [sym_labels_keyword] = ACTIONS(7166),
    [sym_rendering_keyword] = ACTIONS(7166),
    [sym_requestpage_keyword] = ACTIONS(7166),
    [sym_schema_keyword] = ACTIONS(7166),
    [sym_views_keyword] = ACTIONS(7166),
    [sym_quoted_identifier] = ACTIONS(7168),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7168),
    [sym_preproc_open] = ACTIONS(7168),
    [sym_preproc_close] = ACTIONS(7168),
    [sym_var_attribute_open] = ACTIONS(7168),
  },
  [STATE(2880)] = {
    [sym_identifier] = ACTIONS(7166),
    [anon_sym_SEMI] = ACTIONS(7168),
    [aux_sym_where_condition_token1] = ACTIONS(7166),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7166),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7166),
    [anon_sym_LBRACK] = ACTIONS(7168),
    [aux_sym_basic_type_token6] = ACTIONS(7166),
    [aux_sym_basic_type_token22] = ACTIONS(7166),
    [aux_sym_basic_type_token53] = ACTIONS(7166),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7166),
    [aux_sym_addafter_modification_token1] = ACTIONS(7166),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7166),
    [aux_sym_modify_modification_token1] = ACTIONS(7166),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7166),
    [aux_sym_movelast_modification_token1] = ACTIONS(7166),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7166),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7166),
    [aux_sym_separator_action_token1] = ACTIONS(7166),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7166),
    [aux_sym_type_declaration_token1] = ACTIONS(7166),
    [anon_sym_POUNDif] = ACTIONS(7168),
    [anon_sym_POUNDIF] = ACTIONS(7168),
    [anon_sym_POUNDIf] = ACTIONS(7168),
    [anon_sym_POUNDelif] = ACTIONS(7168),
    [anon_sym_POUNDELIF] = ACTIONS(7168),
    [anon_sym_POUNDElif] = ACTIONS(7168),
    [anon_sym_POUNDelse] = ACTIONS(7168),
    [anon_sym_POUNDELSE] = ACTIONS(7168),
    [anon_sym_POUNDElse] = ACTIONS(7168),
    [anon_sym_POUNDendif] = ACTIONS(7168),
    [anon_sym_POUNDENDIF] = ACTIONS(7168),
    [anon_sym_POUNDEndif] = ACTIONS(7168),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7166),
    [sym_trigger_keyword] = ACTIONS(7166),
    [sym_var_keyword] = ACTIONS(7166),
    [sym_local_keyword] = ACTIONS(7166),
    [sym_internal_keyword] = ACTIONS(7166),
    [sym_protected_keyword] = ACTIONS(7166),
    [sym_event_keyword] = ACTIONS(7166),
    [sym_fields_keyword] = ACTIONS(7166),
    [sym_keys_keyword] = ACTIONS(7166),
    [sym_key_keyword] = ACTIONS(7166),
    [sym_fieldgroups_keyword] = ACTIONS(7166),
    [sym_actions_keyword] = ACTIONS(7166),
    [sym_layout_keyword] = ACTIONS(7166),
    [sym_area_keyword] = ACTIONS(7166),
    [sym_group_keyword] = ACTIONS(7166),
    [sym_repeater_keyword] = ACTIONS(7166),
    [sym_cuegroup_keyword] = ACTIONS(7166),
    [sym_fixed_keyword] = ACTIONS(7166),
    [sym_grid_keyword] = ACTIONS(7166),
    [sym_part_keyword] = ACTIONS(7166),
    [sym_systempart_keyword] = ACTIONS(7166),
    [sym_usercontrol_keyword] = ACTIONS(7166),
    [sym_dataset_keyword] = ACTIONS(7166),
    [sym_elements_keyword] = ACTIONS(7166),
    [sym_dataitem_keyword] = ACTIONS(7166),
    [sym_column_keyword] = ACTIONS(7166),
    [sym_filter_keyword] = ACTIONS(7166),
    [sym_labels_keyword] = ACTIONS(7166),
    [sym_rendering_keyword] = ACTIONS(7166),
    [sym_requestpage_keyword] = ACTIONS(7166),
    [sym_schema_keyword] = ACTIONS(7166),
    [sym_views_keyword] = ACTIONS(7166),
    [sym_quoted_identifier] = ACTIONS(7168),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7168),
    [sym_preproc_open] = ACTIONS(7168),
    [sym_preproc_close] = ACTIONS(7168),
    [sym_var_attribute_open] = ACTIONS(7168),
  },
  [STATE(2881)] = {
    [sym_boolean] = STATE(5892),
    [sym_assignment_expression] = STATE(5892),
    [sym__expression] = STATE(5892),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5892),
    [sym_multiplicative_expression] = STATE(5892),
    [sym_additive_expression] = STATE(5892),
    [sym_comparison_expression] = STATE(5892),
    [sym_logical_expression] = STATE(5892),
    [sym_ternary_expression] = STATE(5892),
    [sym_unary_expression] = STATE(5892),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5892),
    [sym_list_literal] = STATE(5892),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5892),
    [sym__literal_value] = STATE(5892),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7178),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7180),
    [sym_date_literal] = ACTIONS(7178),
    [sym_time_literal] = ACTIONS(7178),
    [sym_biginteger_literal] = ACTIONS(7180),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7180),
    [sym_integer] = ACTIONS(7178),
    [sym_continue_as_identifier] = ACTIONS(7180),
  },
  [STATE(2882)] = {
    [sym_boolean] = STATE(1088),
    [sym_assignment_expression] = STATE(1088),
    [sym__expression] = STATE(1088),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1088),
    [sym_multiplicative_expression] = STATE(1088),
    [sym_additive_expression] = STATE(1088),
    [sym_comparison_expression] = STATE(1088),
    [sym_logical_expression] = STATE(1088),
    [sym_ternary_expression] = STATE(1088),
    [sym_unary_expression] = STATE(1088),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1088),
    [sym_list_literal] = STATE(1088),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1088),
    [sym__literal_value] = STATE(1088),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7182),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7184),
    [sym_date_literal] = ACTIONS(7182),
    [sym_time_literal] = ACTIONS(7182),
    [sym_biginteger_literal] = ACTIONS(7184),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7184),
    [sym_integer] = ACTIONS(7182),
    [sym_continue_as_identifier] = ACTIONS(7184),
  },
  [STATE(2883)] = {
    [sym_boolean] = STATE(5894),
    [sym_assignment_expression] = STATE(5894),
    [sym__expression] = STATE(5894),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5894),
    [sym_multiplicative_expression] = STATE(5894),
    [sym_additive_expression] = STATE(5894),
    [sym_comparison_expression] = STATE(5894),
    [sym_logical_expression] = STATE(5894),
    [sym_ternary_expression] = STATE(5894),
    [sym_unary_expression] = STATE(5894),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5894),
    [sym_list_literal] = STATE(5894),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5894),
    [sym__literal_value] = STATE(5894),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7186),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7188),
    [sym_date_literal] = ACTIONS(7186),
    [sym_time_literal] = ACTIONS(7186),
    [sym_biginteger_literal] = ACTIONS(7188),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7188),
    [sym_integer] = ACTIONS(7186),
    [sym_continue_as_identifier] = ACTIONS(7188),
  },
  [STATE(2884)] = {
    [sym_boolean] = STATE(5895),
    [sym_assignment_expression] = STATE(5895),
    [sym__expression] = STATE(5895),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5895),
    [sym_multiplicative_expression] = STATE(5895),
    [sym_additive_expression] = STATE(5895),
    [sym_comparison_expression] = STATE(5895),
    [sym_logical_expression] = STATE(5895),
    [sym_ternary_expression] = STATE(5895),
    [sym_unary_expression] = STATE(5895),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5895),
    [sym_list_literal] = STATE(5895),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5895),
    [sym__literal_value] = STATE(5895),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7190),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7192),
    [sym_date_literal] = ACTIONS(7190),
    [sym_time_literal] = ACTIONS(7190),
    [sym_biginteger_literal] = ACTIONS(7192),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7192),
    [sym_integer] = ACTIONS(7190),
    [sym_continue_as_identifier] = ACTIONS(7192),
  },
  [STATE(2885)] = {
    [sym_preproc_conditional_controladdin] = STATE(2885),
    [sym__body_element] = STATE(2885),
    [sym_empty_statement] = STATE(2885),
    [sym_property] = STATE(2885),
    [sym_fields_section] = STATE(2885),
    [sym_keys_section] = STATE(2885),
    [sym_fieldgroups_section] = STATE(2885),
    [sym_enum_value_declaration] = STATE(2885),
    [sym_labels_section] = STATE(2885),
    [sym_layout_section] = STATE(2885),
    [sym_modify_modification] = STATE(2885),
    [sym_actions_section] = STATE(2885),
    [sym_views_section] = STATE(2885),
    [sym_dataset_section] = STATE(2885),
    [sym_requestpage_section] = STATE(2885),
    [sym_rendering_section] = STATE(2885),
    [sym_elements_section] = STATE(2885),
    [sym_schema_section] = STATE(2885),
    [sym_assembly_declaration] = STATE(2885),
    [sym_event_declaration] = STATE(2885),
    [sym_procedure] = STATE(2885),
    [sym_preproc_split_procedure] = STATE(2885),
    [sym_interface_procedure] = STATE(2885),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2885),
    [sym_var_section] = STATE(2885),
    [sym_attribute_item] = STATE(2885),
    [sym_preproc_conditional] = STATE(2885),
    [sym_preproc_if] = STATE(2635),
    [aux_sym_controladdin_declaration_repeat1] = STATE(2885),
    [anon_sym_SEMI] = ACTIONS(7194),
    [anon_sym_LBRACK] = ACTIONS(7197),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7200),
    [aux_sym_modify_modification_token1] = ACTIONS(7203),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7206),
    [anon_sym_POUNDif] = ACTIONS(7209),
    [anon_sym_POUNDIF] = ACTIONS(7209),
    [anon_sym_POUNDIf] = ACTIONS(7209),
    [anon_sym_POUNDelif] = ACTIONS(7212),
    [anon_sym_POUNDELIF] = ACTIONS(7212),
    [anon_sym_POUNDElif] = ACTIONS(7212),
    [anon_sym_POUNDelse] = ACTIONS(7212),
    [anon_sym_POUNDELSE] = ACTIONS(7212),
    [anon_sym_POUNDElse] = ACTIONS(7212),
    [anon_sym_POUNDendif] = ACTIONS(7212),
    [anon_sym_POUNDENDIF] = ACTIONS(7212),
    [anon_sym_POUNDEndif] = ACTIONS(7212),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7214),
    [sym_trigger_keyword] = ACTIONS(7217),
    [sym_var_keyword] = ACTIONS(7220),
    [sym_local_keyword] = ACTIONS(7223),
    [sym_internal_keyword] = ACTIONS(7226),
    [sym_protected_keyword] = ACTIONS(7223),
    [sym_event_keyword] = ACTIONS(7229),
    [sym_fields_keyword] = ACTIONS(7232),
    [sym_keys_keyword] = ACTIONS(7235),
    [sym_fieldgroups_keyword] = ACTIONS(7238),
    [sym_actions_keyword] = ACTIONS(7241),
    [sym_layout_keyword] = ACTIONS(7244),
    [sym_dataset_keyword] = ACTIONS(7247),
    [sym_elements_keyword] = ACTIONS(7250),
    [sym_labels_keyword] = ACTIONS(7253),
    [sym_rendering_keyword] = ACTIONS(7256),
    [sym_requestpage_keyword] = ACTIONS(7259),
    [sym_schema_keyword] = ACTIONS(7262),
    [sym_views_keyword] = ACTIONS(7265),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7268),
    [sym_preproc_open] = ACTIONS(7209),
    [sym_preproc_close] = ACTIONS(7212),
  },
  [STATE(2886)] = {
    [sym_boolean] = STATE(2162),
    [sym_assignment_expression] = STATE(2162),
    [sym__expression] = STATE(2162),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2162),
    [sym_multiplicative_expression] = STATE(2162),
    [sym_additive_expression] = STATE(2162),
    [sym_comparison_expression] = STATE(2162),
    [sym_logical_expression] = STATE(2162),
    [sym_ternary_expression] = STATE(2162),
    [sym_unary_expression] = STATE(2162),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2162),
    [sym_list_literal] = STATE(2162),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2162),
    [sym__literal_value] = STATE(2162),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7271),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7273),
    [sym_date_literal] = ACTIONS(7271),
    [sym_time_literal] = ACTIONS(7271),
    [sym_biginteger_literal] = ACTIONS(7273),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7273),
    [sym_integer] = ACTIONS(7271),
    [sym_continue_as_identifier] = ACTIONS(7273),
  },
  [STATE(2887)] = {
    [sym_boolean] = STATE(2163),
    [sym_assignment_expression] = STATE(2163),
    [sym__expression] = STATE(2163),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2163),
    [sym_multiplicative_expression] = STATE(2163),
    [sym_additive_expression] = STATE(2163),
    [sym_comparison_expression] = STATE(2163),
    [sym_logical_expression] = STATE(2163),
    [sym_ternary_expression] = STATE(2163),
    [sym_unary_expression] = STATE(2163),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2163),
    [sym_list_literal] = STATE(2163),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2163),
    [sym__literal_value] = STATE(2163),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7275),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7277),
    [sym_date_literal] = ACTIONS(7275),
    [sym_time_literal] = ACTIONS(7275),
    [sym_biginteger_literal] = ACTIONS(7277),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7277),
    [sym_integer] = ACTIONS(7275),
    [sym_continue_as_identifier] = ACTIONS(7277),
  },
  [STATE(2888)] = {
    [sym_boolean] = STATE(2046),
    [sym_assignment_expression] = STATE(2046),
    [sym__expression] = STATE(2046),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2046),
    [sym_multiplicative_expression] = STATE(2046),
    [sym_additive_expression] = STATE(2046),
    [sym_comparison_expression] = STATE(2046),
    [sym_logical_expression] = STATE(2046),
    [sym_ternary_expression] = STATE(2046),
    [sym_unary_expression] = STATE(2046),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2046),
    [sym_list_literal] = STATE(2046),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2046),
    [sym__literal_value] = STATE(2046),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7279),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7281),
    [sym_date_literal] = ACTIONS(7279),
    [sym_time_literal] = ACTIONS(7279),
    [sym_biginteger_literal] = ACTIONS(7281),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7281),
    [sym_integer] = ACTIONS(7279),
    [sym_continue_as_identifier] = ACTIONS(7281),
  },
  [STATE(2889)] = {
    [sym_boolean] = STATE(5896),
    [sym_assignment_expression] = STATE(5896),
    [sym__expression] = STATE(5896),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5896),
    [sym_multiplicative_expression] = STATE(5896),
    [sym_additive_expression] = STATE(5896),
    [sym_comparison_expression] = STATE(5896),
    [sym_logical_expression] = STATE(5896),
    [sym_ternary_expression] = STATE(5896),
    [sym_unary_expression] = STATE(5896),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5896),
    [sym_list_literal] = STATE(5896),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5896),
    [sym__literal_value] = STATE(5896),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7283),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7285),
    [sym_date_literal] = ACTIONS(7283),
    [sym_time_literal] = ACTIONS(7283),
    [sym_biginteger_literal] = ACTIONS(7285),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7285),
    [sym_integer] = ACTIONS(7283),
    [sym_continue_as_identifier] = ACTIONS(7285),
  },
  [STATE(2890)] = {
    [sym_boolean] = STATE(5897),
    [sym_assignment_expression] = STATE(5897),
    [sym__expression] = STATE(5897),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5897),
    [sym_multiplicative_expression] = STATE(5897),
    [sym_additive_expression] = STATE(5897),
    [sym_comparison_expression] = STATE(5897),
    [sym_logical_expression] = STATE(5897),
    [sym_ternary_expression] = STATE(5897),
    [sym_unary_expression] = STATE(5897),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5897),
    [sym_list_literal] = STATE(5897),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5897),
    [sym__literal_value] = STATE(5897),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7287),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7289),
    [sym_date_literal] = ACTIONS(7287),
    [sym_time_literal] = ACTIONS(7287),
    [sym_biginteger_literal] = ACTIONS(7289),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7289),
    [sym_integer] = ACTIONS(7287),
    [sym_continue_as_identifier] = ACTIONS(7289),
  },
  [STATE(2891)] = {
    [sym_boolean] = STATE(5898),
    [sym_assignment_expression] = STATE(5898),
    [sym__expression] = STATE(5898),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5898),
    [sym_multiplicative_expression] = STATE(5898),
    [sym_additive_expression] = STATE(5898),
    [sym_comparison_expression] = STATE(5898),
    [sym_logical_expression] = STATE(5898),
    [sym_ternary_expression] = STATE(5898),
    [sym_unary_expression] = STATE(5898),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5898),
    [sym_list_literal] = STATE(5898),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5898),
    [sym__literal_value] = STATE(5898),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7291),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7293),
    [sym_date_literal] = ACTIONS(7291),
    [sym_time_literal] = ACTIONS(7291),
    [sym_biginteger_literal] = ACTIONS(7293),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7293),
    [sym_integer] = ACTIONS(7291),
    [sym_continue_as_identifier] = ACTIONS(7293),
  },
  [STATE(2892)] = {
    [sym_boolean] = STATE(5899),
    [sym_assignment_expression] = STATE(5899),
    [sym__expression] = STATE(5899),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5899),
    [sym_multiplicative_expression] = STATE(5899),
    [sym_additive_expression] = STATE(5899),
    [sym_comparison_expression] = STATE(5899),
    [sym_logical_expression] = STATE(5899),
    [sym_ternary_expression] = STATE(5899),
    [sym_unary_expression] = STATE(5899),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5899),
    [sym_list_literal] = STATE(5899),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5899),
    [sym__literal_value] = STATE(5899),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7295),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7297),
    [sym_date_literal] = ACTIONS(7295),
    [sym_time_literal] = ACTIONS(7295),
    [sym_biginteger_literal] = ACTIONS(7297),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7297),
    [sym_integer] = ACTIONS(7295),
    [sym_continue_as_identifier] = ACTIONS(7297),
  },
  [STATE(2893)] = {
    [sym_boolean] = STATE(5900),
    [sym_assignment_expression] = STATE(5900),
    [sym__expression] = STATE(5900),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5900),
    [sym_multiplicative_expression] = STATE(5900),
    [sym_additive_expression] = STATE(5900),
    [sym_comparison_expression] = STATE(5900),
    [sym_logical_expression] = STATE(5900),
    [sym_ternary_expression] = STATE(5900),
    [sym_unary_expression] = STATE(5900),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5900),
    [sym_list_literal] = STATE(5900),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5900),
    [sym__literal_value] = STATE(5900),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7299),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7301),
    [sym_date_literal] = ACTIONS(7299),
    [sym_time_literal] = ACTIONS(7299),
    [sym_biginteger_literal] = ACTIONS(7301),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7301),
    [sym_integer] = ACTIONS(7299),
    [sym_continue_as_identifier] = ACTIONS(7301),
  },
  [STATE(2894)] = {
    [sym_boolean] = STATE(5902),
    [sym_assignment_expression] = STATE(5902),
    [sym__expression] = STATE(5902),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5902),
    [sym_multiplicative_expression] = STATE(5902),
    [sym_additive_expression] = STATE(5902),
    [sym_comparison_expression] = STATE(5902),
    [sym_logical_expression] = STATE(5902),
    [sym_ternary_expression] = STATE(5902),
    [sym_unary_expression] = STATE(5902),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5902),
    [sym_list_literal] = STATE(5902),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5902),
    [sym__literal_value] = STATE(5902),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7303),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7305),
    [sym_date_literal] = ACTIONS(7303),
    [sym_time_literal] = ACTIONS(7303),
    [sym_biginteger_literal] = ACTIONS(7305),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7305),
    [sym_integer] = ACTIONS(7303),
    [sym_continue_as_identifier] = ACTIONS(7305),
  },
  [STATE(2895)] = {
    [sym_boolean] = STATE(5903),
    [sym_assignment_expression] = STATE(5903),
    [sym__expression] = STATE(5903),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5903),
    [sym_multiplicative_expression] = STATE(5903),
    [sym_additive_expression] = STATE(5903),
    [sym_comparison_expression] = STATE(5903),
    [sym_logical_expression] = STATE(5903),
    [sym_ternary_expression] = STATE(5903),
    [sym_unary_expression] = STATE(5903),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5903),
    [sym_list_literal] = STATE(5903),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5903),
    [sym__literal_value] = STATE(5903),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7307),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7309),
    [sym_date_literal] = ACTIONS(7307),
    [sym_time_literal] = ACTIONS(7307),
    [sym_biginteger_literal] = ACTIONS(7309),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7309),
    [sym_integer] = ACTIONS(7307),
    [sym_continue_as_identifier] = ACTIONS(7309),
  },
  [STATE(2896)] = {
    [sym_boolean] = STATE(5904),
    [sym_assignment_expression] = STATE(5904),
    [sym__expression] = STATE(5904),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5904),
    [sym_multiplicative_expression] = STATE(5904),
    [sym_additive_expression] = STATE(5904),
    [sym_comparison_expression] = STATE(5904),
    [sym_logical_expression] = STATE(5904),
    [sym_ternary_expression] = STATE(5904),
    [sym_unary_expression] = STATE(5904),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5904),
    [sym_list_literal] = STATE(5904),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5904),
    [sym__literal_value] = STATE(5904),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7311),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7313),
    [sym_date_literal] = ACTIONS(7311),
    [sym_time_literal] = ACTIONS(7311),
    [sym_biginteger_literal] = ACTIONS(7313),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7313),
    [sym_integer] = ACTIONS(7311),
    [sym_continue_as_identifier] = ACTIONS(7313),
  },
  [STATE(2897)] = {
    [sym_boolean] = STATE(1089),
    [sym_assignment_expression] = STATE(1089),
    [sym__expression] = STATE(1089),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1089),
    [sym_multiplicative_expression] = STATE(1089),
    [sym_additive_expression] = STATE(1089),
    [sym_comparison_expression] = STATE(1089),
    [sym_logical_expression] = STATE(1089),
    [sym_ternary_expression] = STATE(1089),
    [sym_unary_expression] = STATE(1089),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1089),
    [sym_list_literal] = STATE(1089),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1089),
    [sym__literal_value] = STATE(1089),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7315),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7317),
    [sym_date_literal] = ACTIONS(7315),
    [sym_time_literal] = ACTIONS(7315),
    [sym_biginteger_literal] = ACTIONS(7317),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7317),
    [sym_integer] = ACTIONS(7315),
    [sym_continue_as_identifier] = ACTIONS(7317),
  },
  [STATE(2898)] = {
    [sym_boolean] = STATE(2165),
    [sym_assignment_expression] = STATE(2165),
    [sym__expression] = STATE(2165),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2165),
    [sym_multiplicative_expression] = STATE(2165),
    [sym_additive_expression] = STATE(2165),
    [sym_comparison_expression] = STATE(2165),
    [sym_logical_expression] = STATE(2165),
    [sym_ternary_expression] = STATE(2165),
    [sym_unary_expression] = STATE(2165),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2165),
    [sym_list_literal] = STATE(2165),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2165),
    [sym__literal_value] = STATE(2165),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7319),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7321),
    [sym_date_literal] = ACTIONS(7319),
    [sym_time_literal] = ACTIONS(7319),
    [sym_biginteger_literal] = ACTIONS(7321),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7321),
    [sym_integer] = ACTIONS(7319),
    [sym_continue_as_identifier] = ACTIONS(7321),
  },
  [STATE(2899)] = {
    [sym_boolean] = STATE(6272),
    [sym_assignment_expression] = STATE(6272),
    [sym__expression] = STATE(6272),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6272),
    [sym_multiplicative_expression] = STATE(6272),
    [sym_additive_expression] = STATE(6272),
    [sym_comparison_expression] = STATE(6272),
    [sym_logical_expression] = STATE(6272),
    [sym_ternary_expression] = STATE(6272),
    [sym_unary_expression] = STATE(6272),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6272),
    [sym_list_literal] = STATE(6272),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6272),
    [sym__literal_value] = STATE(6272),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7323),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(7325),
    [sym_date_literal] = ACTIONS(7323),
    [sym_time_literal] = ACTIONS(7323),
    [sym_biginteger_literal] = ACTIONS(7325),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7325),
    [sym_integer] = ACTIONS(7323),
    [sym_continue_as_identifier] = ACTIONS(7325),
  },
  [STATE(2900)] = {
    [sym_boolean] = STATE(6304),
    [sym_assignment_expression] = STATE(6304),
    [sym__expression] = STATE(6304),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6304),
    [sym_multiplicative_expression] = STATE(6304),
    [sym_additive_expression] = STATE(6304),
    [sym_comparison_expression] = STATE(6304),
    [sym_logical_expression] = STATE(6304),
    [sym_ternary_expression] = STATE(6304),
    [sym_unary_expression] = STATE(6304),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6304),
    [sym_list_literal] = STATE(6304),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6304),
    [sym__literal_value] = STATE(6304),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7327),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(7329),
    [sym_date_literal] = ACTIONS(7327),
    [sym_time_literal] = ACTIONS(7327),
    [sym_biginteger_literal] = ACTIONS(7329),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7329),
    [sym_integer] = ACTIONS(7327),
    [sym_continue_as_identifier] = ACTIONS(7329),
  },
  [STATE(2901)] = {
    [sym_boolean] = STATE(1090),
    [sym_assignment_expression] = STATE(1090),
    [sym__expression] = STATE(1090),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1090),
    [sym_multiplicative_expression] = STATE(1090),
    [sym_additive_expression] = STATE(1090),
    [sym_comparison_expression] = STATE(1090),
    [sym_logical_expression] = STATE(1090),
    [sym_ternary_expression] = STATE(1090),
    [sym_unary_expression] = STATE(1090),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1090),
    [sym_list_literal] = STATE(1090),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1090),
    [sym__literal_value] = STATE(1090),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7331),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7333),
    [sym_date_literal] = ACTIONS(7331),
    [sym_time_literal] = ACTIONS(7331),
    [sym_biginteger_literal] = ACTIONS(7333),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7333),
    [sym_integer] = ACTIONS(7331),
    [sym_continue_as_identifier] = ACTIONS(7333),
  },
  [STATE(2902)] = {
    [sym_boolean] = STATE(6290),
    [sym_assignment_expression] = STATE(6290),
    [sym__expression] = STATE(6290),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6290),
    [sym_multiplicative_expression] = STATE(6290),
    [sym_additive_expression] = STATE(6290),
    [sym_comparison_expression] = STATE(6290),
    [sym_logical_expression] = STATE(6290),
    [sym_ternary_expression] = STATE(6290),
    [sym_unary_expression] = STATE(6290),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6290),
    [sym_list_literal] = STATE(6290),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6290),
    [sym__literal_value] = STATE(6290),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7335),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(7337),
    [sym_date_literal] = ACTIONS(7335),
    [sym_time_literal] = ACTIONS(7335),
    [sym_biginteger_literal] = ACTIONS(7337),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7337),
    [sym_integer] = ACTIONS(7335),
    [sym_continue_as_identifier] = ACTIONS(7337),
  },
  [STATE(2903)] = {
    [sym_identifier] = ACTIONS(4395),
    [anon_sym_SEMI] = ACTIONS(4397),
    [aux_sym_where_condition_token1] = ACTIONS(4395),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4395),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4395),
    [anon_sym_LBRACK] = ACTIONS(4397),
    [aux_sym_basic_type_token6] = ACTIONS(4395),
    [aux_sym_basic_type_token22] = ACTIONS(4395),
    [aux_sym_basic_type_token53] = ACTIONS(4395),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4395),
    [aux_sym_addafter_modification_token1] = ACTIONS(4395),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4395),
    [aux_sym_modify_modification_token1] = ACTIONS(4395),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4395),
    [aux_sym_movelast_modification_token1] = ACTIONS(4395),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4395),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4395),
    [aux_sym_separator_action_token1] = ACTIONS(4395),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4395),
    [aux_sym_type_declaration_token1] = ACTIONS(4395),
    [anon_sym_POUNDif] = ACTIONS(4397),
    [anon_sym_POUNDIF] = ACTIONS(4397),
    [anon_sym_POUNDIf] = ACTIONS(4397),
    [anon_sym_POUNDelif] = ACTIONS(4397),
    [anon_sym_POUNDELIF] = ACTIONS(4397),
    [anon_sym_POUNDElif] = ACTIONS(4397),
    [anon_sym_POUNDelse] = ACTIONS(4397),
    [anon_sym_POUNDELSE] = ACTIONS(4397),
    [anon_sym_POUNDElse] = ACTIONS(4397),
    [anon_sym_POUNDendif] = ACTIONS(4397),
    [anon_sym_POUNDENDIF] = ACTIONS(4397),
    [anon_sym_POUNDEndif] = ACTIONS(4397),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4395),
    [sym_trigger_keyword] = ACTIONS(4395),
    [sym_var_keyword] = ACTIONS(4395),
    [sym_local_keyword] = ACTIONS(4395),
    [sym_internal_keyword] = ACTIONS(4395),
    [sym_protected_keyword] = ACTIONS(4395),
    [sym_event_keyword] = ACTIONS(4395),
    [sym_fields_keyword] = ACTIONS(4395),
    [sym_keys_keyword] = ACTIONS(4395),
    [sym_key_keyword] = ACTIONS(4395),
    [sym_fieldgroups_keyword] = ACTIONS(4395),
    [sym_actions_keyword] = ACTIONS(4395),
    [sym_layout_keyword] = ACTIONS(4395),
    [sym_area_keyword] = ACTIONS(4395),
    [sym_group_keyword] = ACTIONS(4395),
    [sym_repeater_keyword] = ACTIONS(4395),
    [sym_cuegroup_keyword] = ACTIONS(4395),
    [sym_fixed_keyword] = ACTIONS(4395),
    [sym_grid_keyword] = ACTIONS(4395),
    [sym_part_keyword] = ACTIONS(4395),
    [sym_systempart_keyword] = ACTIONS(4395),
    [sym_usercontrol_keyword] = ACTIONS(4395),
    [sym_dataset_keyword] = ACTIONS(4395),
    [sym_elements_keyword] = ACTIONS(4395),
    [sym_dataitem_keyword] = ACTIONS(4395),
    [sym_column_keyword] = ACTIONS(4395),
    [sym_filter_keyword] = ACTIONS(4395),
    [sym_labels_keyword] = ACTIONS(4395),
    [sym_rendering_keyword] = ACTIONS(4395),
    [sym_requestpage_keyword] = ACTIONS(4395),
    [sym_schema_keyword] = ACTIONS(4395),
    [sym_views_keyword] = ACTIONS(4395),
    [sym_quoted_identifier] = ACTIONS(4397),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4397),
    [sym_preproc_open] = ACTIONS(4397),
    [sym_preproc_close] = ACTIONS(4397),
    [sym_var_attribute_open] = ACTIONS(4397),
  },
  [STATE(2904)] = {
    [sym_boolean] = STATE(6319),
    [sym_assignment_expression] = STATE(6319),
    [sym__expression] = STATE(6319),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6319),
    [sym_multiplicative_expression] = STATE(6319),
    [sym_additive_expression] = STATE(6319),
    [sym_comparison_expression] = STATE(6319),
    [sym_logical_expression] = STATE(6319),
    [sym_ternary_expression] = STATE(6319),
    [sym_unary_expression] = STATE(6319),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6319),
    [sym_list_literal] = STATE(6319),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6319),
    [sym__literal_value] = STATE(6319),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7339),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(7341),
    [sym_date_literal] = ACTIONS(7339),
    [sym_time_literal] = ACTIONS(7339),
    [sym_biginteger_literal] = ACTIONS(7341),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7341),
    [sym_integer] = ACTIONS(7339),
    [sym_continue_as_identifier] = ACTIONS(7341),
  },
  [STATE(2905)] = {
    [sym_boolean] = STATE(1070),
    [sym_assignment_expression] = STATE(1070),
    [sym__expression] = STATE(1070),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1070),
    [sym_multiplicative_expression] = STATE(1070),
    [sym_additive_expression] = STATE(1070),
    [sym_comparison_expression] = STATE(1070),
    [sym_logical_expression] = STATE(1070),
    [sym_ternary_expression] = STATE(1070),
    [sym_unary_expression] = STATE(1070),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1070),
    [sym_list_literal] = STATE(1070),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1070),
    [sym__literal_value] = STATE(1070),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7343),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7345),
    [sym_date_literal] = ACTIONS(7343),
    [sym_time_literal] = ACTIONS(7343),
    [sym_biginteger_literal] = ACTIONS(7345),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7345),
    [sym_integer] = ACTIONS(7343),
    [sym_continue_as_identifier] = ACTIONS(7345),
  },
  [STATE(2906)] = {
    [sym_identifier] = ACTIONS(4395),
    [anon_sym_SEMI] = ACTIONS(4397),
    [aux_sym_where_condition_token1] = ACTIONS(4395),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4395),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4395),
    [anon_sym_LBRACK] = ACTIONS(4397),
    [aux_sym_basic_type_token6] = ACTIONS(4395),
    [aux_sym_basic_type_token22] = ACTIONS(4395),
    [aux_sym_basic_type_token53] = ACTIONS(4395),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4395),
    [aux_sym_addafter_modification_token1] = ACTIONS(4395),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4395),
    [aux_sym_modify_modification_token1] = ACTIONS(4395),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4395),
    [aux_sym_movelast_modification_token1] = ACTIONS(4395),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4395),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4395),
    [aux_sym_separator_action_token1] = ACTIONS(4395),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4395),
    [aux_sym_type_declaration_token1] = ACTIONS(4395),
    [anon_sym_POUNDif] = ACTIONS(4397),
    [anon_sym_POUNDIF] = ACTIONS(4397),
    [anon_sym_POUNDIf] = ACTIONS(4397),
    [anon_sym_POUNDelif] = ACTIONS(4397),
    [anon_sym_POUNDELIF] = ACTIONS(4397),
    [anon_sym_POUNDElif] = ACTIONS(4397),
    [anon_sym_POUNDelse] = ACTIONS(4397),
    [anon_sym_POUNDELSE] = ACTIONS(4397),
    [anon_sym_POUNDElse] = ACTIONS(4397),
    [anon_sym_POUNDendif] = ACTIONS(4397),
    [anon_sym_POUNDENDIF] = ACTIONS(4397),
    [anon_sym_POUNDEndif] = ACTIONS(4397),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4395),
    [sym_trigger_keyword] = ACTIONS(4395),
    [sym_var_keyword] = ACTIONS(4395),
    [sym_local_keyword] = ACTIONS(4395),
    [sym_internal_keyword] = ACTIONS(4395),
    [sym_protected_keyword] = ACTIONS(4395),
    [sym_event_keyword] = ACTIONS(4395),
    [sym_fields_keyword] = ACTIONS(4395),
    [sym_keys_keyword] = ACTIONS(4395),
    [sym_key_keyword] = ACTIONS(4395),
    [sym_fieldgroups_keyword] = ACTIONS(4395),
    [sym_actions_keyword] = ACTIONS(4395),
    [sym_layout_keyword] = ACTIONS(4395),
    [sym_area_keyword] = ACTIONS(4395),
    [sym_group_keyword] = ACTIONS(4395),
    [sym_repeater_keyword] = ACTIONS(4395),
    [sym_cuegroup_keyword] = ACTIONS(4395),
    [sym_fixed_keyword] = ACTIONS(4395),
    [sym_grid_keyword] = ACTIONS(4395),
    [sym_part_keyword] = ACTIONS(4395),
    [sym_systempart_keyword] = ACTIONS(4395),
    [sym_usercontrol_keyword] = ACTIONS(4395),
    [sym_dataset_keyword] = ACTIONS(4395),
    [sym_elements_keyword] = ACTIONS(4395),
    [sym_dataitem_keyword] = ACTIONS(4395),
    [sym_column_keyword] = ACTIONS(4395),
    [sym_filter_keyword] = ACTIONS(4395),
    [sym_labels_keyword] = ACTIONS(4395),
    [sym_rendering_keyword] = ACTIONS(4395),
    [sym_requestpage_keyword] = ACTIONS(4395),
    [sym_schema_keyword] = ACTIONS(4395),
    [sym_views_keyword] = ACTIONS(4395),
    [sym_quoted_identifier] = ACTIONS(4397),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4397),
    [sym_preproc_open] = ACTIONS(4397),
    [sym_preproc_close] = ACTIONS(4397),
    [sym_var_attribute_open] = ACTIONS(4397),
  },
  [STATE(2907)] = {
    [sym_boolean] = STATE(1167),
    [sym_assignment_expression] = STATE(1167),
    [sym__expression] = STATE(1167),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1167),
    [sym_multiplicative_expression] = STATE(1167),
    [sym_additive_expression] = STATE(1167),
    [sym_comparison_expression] = STATE(1167),
    [sym_logical_expression] = STATE(1167),
    [sym_ternary_expression] = STATE(1167),
    [sym_unary_expression] = STATE(1167),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1167),
    [sym_list_literal] = STATE(1167),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1167),
    [sym__literal_value] = STATE(1167),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7347),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7349),
    [sym_date_literal] = ACTIONS(7347),
    [sym_time_literal] = ACTIONS(7347),
    [sym_biginteger_literal] = ACTIONS(7349),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7349),
    [sym_integer] = ACTIONS(7347),
    [sym_continue_as_identifier] = ACTIONS(7349),
  },
  [STATE(2908)] = {
    [sym_boolean] = STATE(981),
    [sym_assignment_expression] = STATE(981),
    [sym__expression] = STATE(981),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(981),
    [sym_multiplicative_expression] = STATE(981),
    [sym_additive_expression] = STATE(981),
    [sym_comparison_expression] = STATE(981),
    [sym_logical_expression] = STATE(981),
    [sym_ternary_expression] = STATE(981),
    [sym_unary_expression] = STATE(981),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(981),
    [sym_list_literal] = STATE(981),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(981),
    [sym__literal_value] = STATE(981),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7351),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7353),
    [sym_date_literal] = ACTIONS(7351),
    [sym_time_literal] = ACTIONS(7351),
    [sym_biginteger_literal] = ACTIONS(7353),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7353),
    [sym_integer] = ACTIONS(7351),
    [sym_continue_as_identifier] = ACTIONS(7353),
  },
  [STATE(2909)] = {
    [sym_boolean] = STATE(6326),
    [sym_assignment_expression] = STATE(6326),
    [sym__expression] = STATE(6326),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6326),
    [sym_multiplicative_expression] = STATE(6326),
    [sym_additive_expression] = STATE(6326),
    [sym_comparison_expression] = STATE(6326),
    [sym_logical_expression] = STATE(6326),
    [sym_ternary_expression] = STATE(6326),
    [sym_unary_expression] = STATE(6326),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6326),
    [sym_list_literal] = STATE(6326),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6326),
    [sym__literal_value] = STATE(6326),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7355),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(7357),
    [sym_date_literal] = ACTIONS(7355),
    [sym_time_literal] = ACTIONS(7355),
    [sym_biginteger_literal] = ACTIONS(7357),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7357),
    [sym_integer] = ACTIONS(7355),
    [sym_continue_as_identifier] = ACTIONS(7357),
  },
  [STATE(2910)] = {
    [sym_identifier] = ACTIONS(7359),
    [anon_sym_SEMI] = ACTIONS(7361),
    [aux_sym_where_condition_token1] = ACTIONS(7359),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7359),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7361),
    [aux_sym_basic_type_token6] = ACTIONS(7359),
    [aux_sym_basic_type_token22] = ACTIONS(7359),
    [aux_sym_basic_type_token53] = ACTIONS(7359),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7359),
    [aux_sym_addafter_modification_token1] = ACTIONS(7359),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7359),
    [aux_sym_modify_modification_token1] = ACTIONS(7359),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7359),
    [aux_sym_movelast_modification_token1] = ACTIONS(7359),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7359),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7359),
    [aux_sym_separator_action_token1] = ACTIONS(7359),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7359),
    [aux_sym_type_declaration_token1] = ACTIONS(7359),
    [anon_sym_POUNDif] = ACTIONS(7361),
    [anon_sym_POUNDIF] = ACTIONS(7361),
    [anon_sym_POUNDIf] = ACTIONS(7361),
    [anon_sym_POUNDelif] = ACTIONS(7361),
    [anon_sym_POUNDELIF] = ACTIONS(7361),
    [anon_sym_POUNDElif] = ACTIONS(7361),
    [anon_sym_POUNDelse] = ACTIONS(7361),
    [anon_sym_POUNDELSE] = ACTIONS(7361),
    [anon_sym_POUNDElse] = ACTIONS(7361),
    [anon_sym_POUNDendif] = ACTIONS(7361),
    [anon_sym_POUNDENDIF] = ACTIONS(7361),
    [anon_sym_POUNDEndif] = ACTIONS(7361),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7359),
    [sym_trigger_keyword] = ACTIONS(7359),
    [sym_var_keyword] = ACTIONS(7359),
    [sym_local_keyword] = ACTIONS(7359),
    [sym_internal_keyword] = ACTIONS(7359),
    [sym_protected_keyword] = ACTIONS(7359),
    [sym_event_keyword] = ACTIONS(7359),
    [sym_fields_keyword] = ACTIONS(7359),
    [sym_keys_keyword] = ACTIONS(7359),
    [sym_key_keyword] = ACTIONS(7359),
    [sym_fieldgroups_keyword] = ACTIONS(7359),
    [sym_actions_keyword] = ACTIONS(7359),
    [sym_layout_keyword] = ACTIONS(7359),
    [sym_area_keyword] = ACTIONS(7359),
    [sym_group_keyword] = ACTIONS(7359),
    [sym_repeater_keyword] = ACTIONS(7359),
    [sym_cuegroup_keyword] = ACTIONS(7359),
    [sym_fixed_keyword] = ACTIONS(7359),
    [sym_grid_keyword] = ACTIONS(7359),
    [sym_part_keyword] = ACTIONS(7359),
    [sym_systempart_keyword] = ACTIONS(7359),
    [sym_usercontrol_keyword] = ACTIONS(7359),
    [sym_dataset_keyword] = ACTIONS(7359),
    [sym_elements_keyword] = ACTIONS(7359),
    [sym_dataitem_keyword] = ACTIONS(7359),
    [sym_column_keyword] = ACTIONS(7359),
    [sym_filter_keyword] = ACTIONS(7359),
    [sym_labels_keyword] = ACTIONS(7359),
    [sym_rendering_keyword] = ACTIONS(7359),
    [sym_requestpage_keyword] = ACTIONS(7359),
    [sym_schema_keyword] = ACTIONS(7359),
    [sym_views_keyword] = ACTIONS(7359),
    [sym_quoted_identifier] = ACTIONS(7361),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7361),
    [sym_preproc_open] = ACTIONS(7361),
    [sym_preproc_close] = ACTIONS(7361),
    [sym_var_attribute_open] = ACTIONS(7361),
  },
  [STATE(2911)] = {
    [sym_boolean] = STATE(982),
    [sym_assignment_expression] = STATE(982),
    [sym__expression] = STATE(982),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(982),
    [sym_multiplicative_expression] = STATE(982),
    [sym_additive_expression] = STATE(982),
    [sym_comparison_expression] = STATE(982),
    [sym_logical_expression] = STATE(982),
    [sym_ternary_expression] = STATE(982),
    [sym_unary_expression] = STATE(982),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(982),
    [sym_list_literal] = STATE(982),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(982),
    [sym__literal_value] = STATE(982),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7363),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7365),
    [sym_date_literal] = ACTIONS(7363),
    [sym_time_literal] = ACTIONS(7363),
    [sym_biginteger_literal] = ACTIONS(7365),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7365),
    [sym_integer] = ACTIONS(7363),
    [sym_continue_as_identifier] = ACTIONS(7365),
  },
  [STATE(2912)] = {
    [sym_identifier] = ACTIONS(7367),
    [anon_sym_SEMI] = ACTIONS(7369),
    [aux_sym_where_condition_token1] = ACTIONS(7367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7367),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7367),
    [anon_sym_LBRACK] = ACTIONS(7369),
    [aux_sym_basic_type_token6] = ACTIONS(7367),
    [aux_sym_basic_type_token22] = ACTIONS(7367),
    [aux_sym_basic_type_token53] = ACTIONS(7367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7367),
    [aux_sym_addafter_modification_token1] = ACTIONS(7367),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7367),
    [aux_sym_modify_modification_token1] = ACTIONS(7367),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7367),
    [aux_sym_movelast_modification_token1] = ACTIONS(7367),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7367),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7367),
    [aux_sym_separator_action_token1] = ACTIONS(7367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7367),
    [aux_sym_type_declaration_token1] = ACTIONS(7367),
    [anon_sym_POUNDif] = ACTIONS(7369),
    [anon_sym_POUNDIF] = ACTIONS(7369),
    [anon_sym_POUNDIf] = ACTIONS(7369),
    [anon_sym_POUNDelif] = ACTIONS(7369),
    [anon_sym_POUNDELIF] = ACTIONS(7369),
    [anon_sym_POUNDElif] = ACTIONS(7369),
    [anon_sym_POUNDelse] = ACTIONS(7369),
    [anon_sym_POUNDELSE] = ACTIONS(7369),
    [anon_sym_POUNDElse] = ACTIONS(7369),
    [anon_sym_POUNDendif] = ACTIONS(7369),
    [anon_sym_POUNDENDIF] = ACTIONS(7369),
    [anon_sym_POUNDEndif] = ACTIONS(7369),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7367),
    [sym_trigger_keyword] = ACTIONS(7367),
    [sym_var_keyword] = ACTIONS(7367),
    [sym_local_keyword] = ACTIONS(7367),
    [sym_internal_keyword] = ACTIONS(7367),
    [sym_protected_keyword] = ACTIONS(7367),
    [sym_event_keyword] = ACTIONS(7367),
    [sym_fields_keyword] = ACTIONS(7367),
    [sym_keys_keyword] = ACTIONS(7367),
    [sym_key_keyword] = ACTIONS(7367),
    [sym_fieldgroups_keyword] = ACTIONS(7367),
    [sym_actions_keyword] = ACTIONS(7367),
    [sym_layout_keyword] = ACTIONS(7367),
    [sym_area_keyword] = ACTIONS(7367),
    [sym_group_keyword] = ACTIONS(7367),
    [sym_repeater_keyword] = ACTIONS(7367),
    [sym_cuegroup_keyword] = ACTIONS(7367),
    [sym_fixed_keyword] = ACTIONS(7367),
    [sym_grid_keyword] = ACTIONS(7367),
    [sym_part_keyword] = ACTIONS(7367),
    [sym_systempart_keyword] = ACTIONS(7367),
    [sym_usercontrol_keyword] = ACTIONS(7367),
    [sym_dataset_keyword] = ACTIONS(7367),
    [sym_elements_keyword] = ACTIONS(7367),
    [sym_dataitem_keyword] = ACTIONS(7367),
    [sym_column_keyword] = ACTIONS(7367),
    [sym_filter_keyword] = ACTIONS(7367),
    [sym_labels_keyword] = ACTIONS(7367),
    [sym_rendering_keyword] = ACTIONS(7367),
    [sym_requestpage_keyword] = ACTIONS(7367),
    [sym_schema_keyword] = ACTIONS(7367),
    [sym_views_keyword] = ACTIONS(7367),
    [sym_quoted_identifier] = ACTIONS(7369),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7369),
    [sym_preproc_open] = ACTIONS(7369),
    [sym_preproc_close] = ACTIONS(7369),
    [sym_var_attribute_open] = ACTIONS(7369),
  },
  [STATE(2913)] = {
    [sym_identifier] = ACTIONS(7371),
    [anon_sym_SEMI] = ACTIONS(7373),
    [aux_sym_where_condition_token1] = ACTIONS(7371),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7371),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7371),
    [anon_sym_LBRACK] = ACTIONS(7373),
    [aux_sym_basic_type_token6] = ACTIONS(7371),
    [aux_sym_basic_type_token22] = ACTIONS(7371),
    [aux_sym_basic_type_token53] = ACTIONS(7371),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7371),
    [aux_sym_addafter_modification_token1] = ACTIONS(7371),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7371),
    [aux_sym_modify_modification_token1] = ACTIONS(7371),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7371),
    [aux_sym_movelast_modification_token1] = ACTIONS(7371),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7371),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7371),
    [aux_sym_separator_action_token1] = ACTIONS(7371),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7371),
    [aux_sym_type_declaration_token1] = ACTIONS(7371),
    [anon_sym_POUNDif] = ACTIONS(7373),
    [anon_sym_POUNDIF] = ACTIONS(7373),
    [anon_sym_POUNDIf] = ACTIONS(7373),
    [anon_sym_POUNDelif] = ACTIONS(7373),
    [anon_sym_POUNDELIF] = ACTIONS(7373),
    [anon_sym_POUNDElif] = ACTIONS(7373),
    [anon_sym_POUNDelse] = ACTIONS(7373),
    [anon_sym_POUNDELSE] = ACTIONS(7373),
    [anon_sym_POUNDElse] = ACTIONS(7373),
    [anon_sym_POUNDendif] = ACTIONS(7373),
    [anon_sym_POUNDENDIF] = ACTIONS(7373),
    [anon_sym_POUNDEndif] = ACTIONS(7373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7371),
    [sym_trigger_keyword] = ACTIONS(7371),
    [sym_var_keyword] = ACTIONS(7371),
    [sym_local_keyword] = ACTIONS(7371),
    [sym_internal_keyword] = ACTIONS(7371),
    [sym_protected_keyword] = ACTIONS(7371),
    [sym_event_keyword] = ACTIONS(7371),
    [sym_fields_keyword] = ACTIONS(7371),
    [sym_keys_keyword] = ACTIONS(7371),
    [sym_key_keyword] = ACTIONS(7371),
    [sym_fieldgroups_keyword] = ACTIONS(7371),
    [sym_actions_keyword] = ACTIONS(7371),
    [sym_layout_keyword] = ACTIONS(7371),
    [sym_area_keyword] = ACTIONS(7371),
    [sym_group_keyword] = ACTIONS(7371),
    [sym_repeater_keyword] = ACTIONS(7371),
    [sym_cuegroup_keyword] = ACTIONS(7371),
    [sym_fixed_keyword] = ACTIONS(7371),
    [sym_grid_keyword] = ACTIONS(7371),
    [sym_part_keyword] = ACTIONS(7371),
    [sym_systempart_keyword] = ACTIONS(7371),
    [sym_usercontrol_keyword] = ACTIONS(7371),
    [sym_dataset_keyword] = ACTIONS(7371),
    [sym_elements_keyword] = ACTIONS(7371),
    [sym_dataitem_keyword] = ACTIONS(7371),
    [sym_column_keyword] = ACTIONS(7371),
    [sym_filter_keyword] = ACTIONS(7371),
    [sym_labels_keyword] = ACTIONS(7371),
    [sym_rendering_keyword] = ACTIONS(7371),
    [sym_requestpage_keyword] = ACTIONS(7371),
    [sym_schema_keyword] = ACTIONS(7371),
    [sym_views_keyword] = ACTIONS(7371),
    [sym_quoted_identifier] = ACTIONS(7373),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7373),
    [sym_preproc_open] = ACTIONS(7373),
    [sym_preproc_close] = ACTIONS(7373),
    [sym_var_attribute_open] = ACTIONS(7373),
  },
  [STATE(2914)] = {
    [sym_identifier] = ACTIONS(7371),
    [anon_sym_SEMI] = ACTIONS(7373),
    [aux_sym_where_condition_token1] = ACTIONS(7371),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7371),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7371),
    [anon_sym_LBRACK] = ACTIONS(7373),
    [aux_sym_basic_type_token6] = ACTIONS(7371),
    [aux_sym_basic_type_token22] = ACTIONS(7371),
    [aux_sym_basic_type_token53] = ACTIONS(7371),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7371),
    [aux_sym_addafter_modification_token1] = ACTIONS(7371),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7371),
    [aux_sym_modify_modification_token1] = ACTIONS(7371),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7371),
    [aux_sym_movelast_modification_token1] = ACTIONS(7371),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7371),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7371),
    [aux_sym_separator_action_token1] = ACTIONS(7371),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7371),
    [aux_sym_type_declaration_token1] = ACTIONS(7371),
    [anon_sym_POUNDif] = ACTIONS(7373),
    [anon_sym_POUNDIF] = ACTIONS(7373),
    [anon_sym_POUNDIf] = ACTIONS(7373),
    [anon_sym_POUNDelif] = ACTIONS(7373),
    [anon_sym_POUNDELIF] = ACTIONS(7373),
    [anon_sym_POUNDElif] = ACTIONS(7373),
    [anon_sym_POUNDelse] = ACTIONS(7373),
    [anon_sym_POUNDELSE] = ACTIONS(7373),
    [anon_sym_POUNDElse] = ACTIONS(7373),
    [anon_sym_POUNDendif] = ACTIONS(7373),
    [anon_sym_POUNDENDIF] = ACTIONS(7373),
    [anon_sym_POUNDEndif] = ACTIONS(7373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7371),
    [sym_trigger_keyword] = ACTIONS(7371),
    [sym_var_keyword] = ACTIONS(7371),
    [sym_local_keyword] = ACTIONS(7371),
    [sym_internal_keyword] = ACTIONS(7371),
    [sym_protected_keyword] = ACTIONS(7371),
    [sym_event_keyword] = ACTIONS(7371),
    [sym_fields_keyword] = ACTIONS(7371),
    [sym_keys_keyword] = ACTIONS(7371),
    [sym_key_keyword] = ACTIONS(7371),
    [sym_fieldgroups_keyword] = ACTIONS(7371),
    [sym_actions_keyword] = ACTIONS(7371),
    [sym_layout_keyword] = ACTIONS(7371),
    [sym_area_keyword] = ACTIONS(7371),
    [sym_group_keyword] = ACTIONS(7371),
    [sym_repeater_keyword] = ACTIONS(7371),
    [sym_cuegroup_keyword] = ACTIONS(7371),
    [sym_fixed_keyword] = ACTIONS(7371),
    [sym_grid_keyword] = ACTIONS(7371),
    [sym_part_keyword] = ACTIONS(7371),
    [sym_systempart_keyword] = ACTIONS(7371),
    [sym_usercontrol_keyword] = ACTIONS(7371),
    [sym_dataset_keyword] = ACTIONS(7371),
    [sym_elements_keyword] = ACTIONS(7371),
    [sym_dataitem_keyword] = ACTIONS(7371),
    [sym_column_keyword] = ACTIONS(7371),
    [sym_filter_keyword] = ACTIONS(7371),
    [sym_labels_keyword] = ACTIONS(7371),
    [sym_rendering_keyword] = ACTIONS(7371),
    [sym_requestpage_keyword] = ACTIONS(7371),
    [sym_schema_keyword] = ACTIONS(7371),
    [sym_views_keyword] = ACTIONS(7371),
    [sym_quoted_identifier] = ACTIONS(7373),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7373),
    [sym_preproc_open] = ACTIONS(7373),
    [sym_preproc_close] = ACTIONS(7373),
    [sym_var_attribute_open] = ACTIONS(7373),
  },
  [STATE(2915)] = {
    [sym_identifier] = ACTIONS(7375),
    [anon_sym_SEMI] = ACTIONS(7377),
    [aux_sym_where_condition_token1] = ACTIONS(7375),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7375),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7375),
    [anon_sym_LBRACK] = ACTIONS(7377),
    [aux_sym_basic_type_token6] = ACTIONS(7375),
    [aux_sym_basic_type_token22] = ACTIONS(7375),
    [aux_sym_basic_type_token53] = ACTIONS(7375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7375),
    [aux_sym_addafter_modification_token1] = ACTIONS(7375),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7375),
    [aux_sym_modify_modification_token1] = ACTIONS(7375),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7375),
    [aux_sym_movelast_modification_token1] = ACTIONS(7375),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7375),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7375),
    [aux_sym_separator_action_token1] = ACTIONS(7375),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7375),
    [aux_sym_type_declaration_token1] = ACTIONS(7375),
    [anon_sym_POUNDif] = ACTIONS(7377),
    [anon_sym_POUNDIF] = ACTIONS(7377),
    [anon_sym_POUNDIf] = ACTIONS(7377),
    [anon_sym_POUNDelif] = ACTIONS(7377),
    [anon_sym_POUNDELIF] = ACTIONS(7377),
    [anon_sym_POUNDElif] = ACTIONS(7377),
    [anon_sym_POUNDelse] = ACTIONS(7377),
    [anon_sym_POUNDELSE] = ACTIONS(7377),
    [anon_sym_POUNDElse] = ACTIONS(7377),
    [anon_sym_POUNDendif] = ACTIONS(7377),
    [anon_sym_POUNDENDIF] = ACTIONS(7377),
    [anon_sym_POUNDEndif] = ACTIONS(7377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7375),
    [sym_trigger_keyword] = ACTIONS(7375),
    [sym_var_keyword] = ACTIONS(7375),
    [sym_local_keyword] = ACTIONS(7375),
    [sym_internal_keyword] = ACTIONS(7375),
    [sym_protected_keyword] = ACTIONS(7375),
    [sym_event_keyword] = ACTIONS(7375),
    [sym_fields_keyword] = ACTIONS(7375),
    [sym_keys_keyword] = ACTIONS(7375),
    [sym_key_keyword] = ACTIONS(7375),
    [sym_fieldgroups_keyword] = ACTIONS(7375),
    [sym_actions_keyword] = ACTIONS(7375),
    [sym_layout_keyword] = ACTIONS(7375),
    [sym_area_keyword] = ACTIONS(7375),
    [sym_group_keyword] = ACTIONS(7375),
    [sym_repeater_keyword] = ACTIONS(7375),
    [sym_cuegroup_keyword] = ACTIONS(7375),
    [sym_fixed_keyword] = ACTIONS(7375),
    [sym_grid_keyword] = ACTIONS(7375),
    [sym_part_keyword] = ACTIONS(7375),
    [sym_systempart_keyword] = ACTIONS(7375),
    [sym_usercontrol_keyword] = ACTIONS(7375),
    [sym_dataset_keyword] = ACTIONS(7375),
    [sym_elements_keyword] = ACTIONS(7375),
    [sym_dataitem_keyword] = ACTIONS(7375),
    [sym_column_keyword] = ACTIONS(7375),
    [sym_filter_keyword] = ACTIONS(7375),
    [sym_labels_keyword] = ACTIONS(7375),
    [sym_rendering_keyword] = ACTIONS(7375),
    [sym_requestpage_keyword] = ACTIONS(7375),
    [sym_schema_keyword] = ACTIONS(7375),
    [sym_views_keyword] = ACTIONS(7375),
    [sym_quoted_identifier] = ACTIONS(7377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7377),
    [sym_preproc_open] = ACTIONS(7377),
    [sym_preproc_close] = ACTIONS(7377),
    [sym_var_attribute_open] = ACTIONS(7377),
  },
  [STATE(2916)] = {
    [sym_boolean] = STATE(6316),
    [sym_assignment_expression] = STATE(6316),
    [sym__expression] = STATE(6316),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6316),
    [sym_multiplicative_expression] = STATE(6316),
    [sym_additive_expression] = STATE(6316),
    [sym_comparison_expression] = STATE(6316),
    [sym_logical_expression] = STATE(6316),
    [sym_ternary_expression] = STATE(6316),
    [sym_unary_expression] = STATE(6316),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6316),
    [sym_list_literal] = STATE(6316),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6316),
    [sym__literal_value] = STATE(6316),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7379),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(7381),
    [sym_date_literal] = ACTIONS(7379),
    [sym_time_literal] = ACTIONS(7379),
    [sym_biginteger_literal] = ACTIONS(7381),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7381),
    [sym_integer] = ACTIONS(7379),
    [sym_continue_as_identifier] = ACTIONS(7381),
  },
  [STATE(2917)] = {
    [sym_boolean] = STATE(2017),
    [sym_assignment_expression] = STATE(2017),
    [sym__expression] = STATE(2017),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2017),
    [sym_multiplicative_expression] = STATE(2017),
    [sym_additive_expression] = STATE(2017),
    [sym_comparison_expression] = STATE(2017),
    [sym_logical_expression] = STATE(2017),
    [sym_ternary_expression] = STATE(2017),
    [sym_unary_expression] = STATE(2017),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2017),
    [sym_list_literal] = STATE(2017),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2017),
    [sym__literal_value] = STATE(2017),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7383),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7385),
    [sym_date_literal] = ACTIONS(7383),
    [sym_time_literal] = ACTIONS(7383),
    [sym_biginteger_literal] = ACTIONS(7385),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7385),
    [sym_integer] = ACTIONS(7383),
    [sym_continue_as_identifier] = ACTIONS(7385),
  },
  [STATE(2918)] = {
    [sym_boolean] = STATE(2060),
    [sym_assignment_expression] = STATE(2060),
    [sym__expression] = STATE(2060),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2060),
    [sym_multiplicative_expression] = STATE(2060),
    [sym_additive_expression] = STATE(2060),
    [sym_comparison_expression] = STATE(2060),
    [sym_logical_expression] = STATE(2060),
    [sym_ternary_expression] = STATE(2060),
    [sym_unary_expression] = STATE(2060),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2060),
    [sym_list_literal] = STATE(2060),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2060),
    [sym__literal_value] = STATE(2060),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7387),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7389),
    [sym_date_literal] = ACTIONS(7387),
    [sym_time_literal] = ACTIONS(7387),
    [sym_biginteger_literal] = ACTIONS(7389),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7389),
    [sym_integer] = ACTIONS(7387),
    [sym_continue_as_identifier] = ACTIONS(7389),
  },
  [STATE(2919)] = {
    [sym_boolean] = STATE(6114),
    [sym_assignment_expression] = STATE(6114),
    [sym__expression] = STATE(6114),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6114),
    [sym_multiplicative_expression] = STATE(6114),
    [sym_additive_expression] = STATE(6114),
    [sym_comparison_expression] = STATE(6114),
    [sym_logical_expression] = STATE(6114),
    [sym_ternary_expression] = STATE(6114),
    [sym_unary_expression] = STATE(6114),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6114),
    [sym_list_literal] = STATE(6114),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6114),
    [sym__literal_value] = STATE(6114),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7391),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7393),
    [sym_date_literal] = ACTIONS(7391),
    [sym_time_literal] = ACTIONS(7391),
    [sym_biginteger_literal] = ACTIONS(7393),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7393),
    [sym_integer] = ACTIONS(7391),
    [sym_continue_as_identifier] = ACTIONS(7393),
  },
  [STATE(2920)] = {
    [sym_boolean] = STATE(2061),
    [sym_assignment_expression] = STATE(2061),
    [sym__expression] = STATE(2061),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2061),
    [sym_multiplicative_expression] = STATE(2061),
    [sym_additive_expression] = STATE(2061),
    [sym_comparison_expression] = STATE(2061),
    [sym_logical_expression] = STATE(2061),
    [sym_ternary_expression] = STATE(2061),
    [sym_unary_expression] = STATE(2061),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2061),
    [sym_list_literal] = STATE(2061),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2061),
    [sym__literal_value] = STATE(2061),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7395),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7397),
    [sym_date_literal] = ACTIONS(7395),
    [sym_time_literal] = ACTIONS(7395),
    [sym_biginteger_literal] = ACTIONS(7397),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7397),
    [sym_integer] = ACTIONS(7395),
    [sym_continue_as_identifier] = ACTIONS(7397),
  },
  [STATE(2921)] = {
    [sym_boolean] = STATE(2062),
    [sym_assignment_expression] = STATE(2062),
    [sym__expression] = STATE(2062),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2062),
    [sym_multiplicative_expression] = STATE(2062),
    [sym_additive_expression] = STATE(2062),
    [sym_comparison_expression] = STATE(2062),
    [sym_logical_expression] = STATE(2062),
    [sym_ternary_expression] = STATE(2062),
    [sym_unary_expression] = STATE(2062),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2062),
    [sym_list_literal] = STATE(2062),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2062),
    [sym__literal_value] = STATE(2062),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7399),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7401),
    [sym_date_literal] = ACTIONS(7399),
    [sym_time_literal] = ACTIONS(7399),
    [sym_biginteger_literal] = ACTIONS(7401),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7401),
    [sym_integer] = ACTIONS(7399),
    [sym_continue_as_identifier] = ACTIONS(7401),
  },
  [STATE(2922)] = {
    [sym_boolean] = STATE(5881),
    [sym_assignment_expression] = STATE(5881),
    [sym__expression] = STATE(5881),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5881),
    [sym_multiplicative_expression] = STATE(5881),
    [sym_additive_expression] = STATE(5881),
    [sym_comparison_expression] = STATE(5881),
    [sym_logical_expression] = STATE(5881),
    [sym_ternary_expression] = STATE(5881),
    [sym_unary_expression] = STATE(5881),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5881),
    [sym_list_literal] = STATE(5881),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5881),
    [sym__literal_value] = STATE(5881),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(7403),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(7405),
    [sym_date_literal] = ACTIONS(7403),
    [sym_time_literal] = ACTIONS(7403),
    [sym_biginteger_literal] = ACTIONS(7405),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7405),
    [sym_integer] = ACTIONS(7403),
    [sym_continue_as_identifier] = ACTIONS(7405),
  },
  [STATE(2923)] = {
    [sym_boolean] = STATE(983),
    [sym_assignment_expression] = STATE(983),
    [sym__expression] = STATE(983),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(983),
    [sym_multiplicative_expression] = STATE(983),
    [sym_additive_expression] = STATE(983),
    [sym_comparison_expression] = STATE(983),
    [sym_logical_expression] = STATE(983),
    [sym_ternary_expression] = STATE(983),
    [sym_unary_expression] = STATE(983),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(983),
    [sym_list_literal] = STATE(983),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(983),
    [sym__literal_value] = STATE(983),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7407),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7409),
    [sym_date_literal] = ACTIONS(7407),
    [sym_time_literal] = ACTIONS(7407),
    [sym_biginteger_literal] = ACTIONS(7409),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7409),
    [sym_integer] = ACTIONS(7407),
    [sym_continue_as_identifier] = ACTIONS(7409),
  },
  [STATE(2924)] = {
    [sym_identifier] = ACTIONS(7375),
    [anon_sym_SEMI] = ACTIONS(7377),
    [aux_sym_where_condition_token1] = ACTIONS(7375),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7375),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7375),
    [anon_sym_LBRACK] = ACTIONS(7377),
    [aux_sym_basic_type_token6] = ACTIONS(7375),
    [aux_sym_basic_type_token22] = ACTIONS(7375),
    [aux_sym_basic_type_token53] = ACTIONS(7375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7375),
    [aux_sym_addafter_modification_token1] = ACTIONS(7375),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7375),
    [aux_sym_modify_modification_token1] = ACTIONS(7375),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7375),
    [aux_sym_movelast_modification_token1] = ACTIONS(7375),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7375),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7375),
    [aux_sym_separator_action_token1] = ACTIONS(7375),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7375),
    [aux_sym_type_declaration_token1] = ACTIONS(7375),
    [anon_sym_POUNDif] = ACTIONS(7377),
    [anon_sym_POUNDIF] = ACTIONS(7377),
    [anon_sym_POUNDIf] = ACTIONS(7377),
    [anon_sym_POUNDelif] = ACTIONS(7377),
    [anon_sym_POUNDELIF] = ACTIONS(7377),
    [anon_sym_POUNDElif] = ACTIONS(7377),
    [anon_sym_POUNDelse] = ACTIONS(7377),
    [anon_sym_POUNDELSE] = ACTIONS(7377),
    [anon_sym_POUNDElse] = ACTIONS(7377),
    [anon_sym_POUNDendif] = ACTIONS(7377),
    [anon_sym_POUNDENDIF] = ACTIONS(7377),
    [anon_sym_POUNDEndif] = ACTIONS(7377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7375),
    [sym_trigger_keyword] = ACTIONS(7375),
    [sym_var_keyword] = ACTIONS(7375),
    [sym_local_keyword] = ACTIONS(7375),
    [sym_internal_keyword] = ACTIONS(7375),
    [sym_protected_keyword] = ACTIONS(7375),
    [sym_event_keyword] = ACTIONS(7375),
    [sym_fields_keyword] = ACTIONS(7375),
    [sym_keys_keyword] = ACTIONS(7375),
    [sym_key_keyword] = ACTIONS(7375),
    [sym_fieldgroups_keyword] = ACTIONS(7375),
    [sym_actions_keyword] = ACTIONS(7375),
    [sym_layout_keyword] = ACTIONS(7375),
    [sym_area_keyword] = ACTIONS(7375),
    [sym_group_keyword] = ACTIONS(7375),
    [sym_repeater_keyword] = ACTIONS(7375),
    [sym_cuegroup_keyword] = ACTIONS(7375),
    [sym_fixed_keyword] = ACTIONS(7375),
    [sym_grid_keyword] = ACTIONS(7375),
    [sym_part_keyword] = ACTIONS(7375),
    [sym_systempart_keyword] = ACTIONS(7375),
    [sym_usercontrol_keyword] = ACTIONS(7375),
    [sym_dataset_keyword] = ACTIONS(7375),
    [sym_elements_keyword] = ACTIONS(7375),
    [sym_dataitem_keyword] = ACTIONS(7375),
    [sym_column_keyword] = ACTIONS(7375),
    [sym_filter_keyword] = ACTIONS(7375),
    [sym_labels_keyword] = ACTIONS(7375),
    [sym_rendering_keyword] = ACTIONS(7375),
    [sym_requestpage_keyword] = ACTIONS(7375),
    [sym_schema_keyword] = ACTIONS(7375),
    [sym_views_keyword] = ACTIONS(7375),
    [sym_quoted_identifier] = ACTIONS(7377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7377),
    [sym_preproc_open] = ACTIONS(7377),
    [sym_preproc_close] = ACTIONS(7377),
    [sym_var_attribute_open] = ACTIONS(7377),
  },
  [STATE(2925)] = {
    [sym_boolean] = STATE(6116),
    [sym_assignment_expression] = STATE(6116),
    [sym__expression] = STATE(6116),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6116),
    [sym_multiplicative_expression] = STATE(6116),
    [sym_additive_expression] = STATE(6116),
    [sym_comparison_expression] = STATE(6116),
    [sym_logical_expression] = STATE(6116),
    [sym_ternary_expression] = STATE(6116),
    [sym_unary_expression] = STATE(6116),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6116),
    [sym_list_literal] = STATE(6116),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6116),
    [sym__literal_value] = STATE(6116),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7411),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7413),
    [sym_date_literal] = ACTIONS(7411),
    [sym_time_literal] = ACTIONS(7411),
    [sym_biginteger_literal] = ACTIONS(7413),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7413),
    [sym_integer] = ACTIONS(7411),
    [sym_continue_as_identifier] = ACTIONS(7413),
  },
  [STATE(2926)] = {
    [sym_boolean] = STATE(2063),
    [sym_assignment_expression] = STATE(2063),
    [sym__expression] = STATE(2063),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2063),
    [sym_multiplicative_expression] = STATE(2063),
    [sym_additive_expression] = STATE(2063),
    [sym_comparison_expression] = STATE(2063),
    [sym_logical_expression] = STATE(2063),
    [sym_ternary_expression] = STATE(2063),
    [sym_unary_expression] = STATE(2063),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2063),
    [sym_list_literal] = STATE(2063),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2063),
    [sym__literal_value] = STATE(2063),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7415),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7417),
    [sym_date_literal] = ACTIONS(7415),
    [sym_time_literal] = ACTIONS(7415),
    [sym_biginteger_literal] = ACTIONS(7417),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7417),
    [sym_integer] = ACTIONS(7415),
    [sym_continue_as_identifier] = ACTIONS(7417),
  },
  [STATE(2927)] = {
    [sym_boolean] = STATE(2064),
    [sym_assignment_expression] = STATE(2064),
    [sym__expression] = STATE(2064),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2064),
    [sym_multiplicative_expression] = STATE(2064),
    [sym_additive_expression] = STATE(2064),
    [sym_comparison_expression] = STATE(2064),
    [sym_logical_expression] = STATE(2064),
    [sym_ternary_expression] = STATE(2064),
    [sym_unary_expression] = STATE(2064),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2064),
    [sym_list_literal] = STATE(2064),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2064),
    [sym__literal_value] = STATE(2064),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7419),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7421),
    [sym_date_literal] = ACTIONS(7419),
    [sym_time_literal] = ACTIONS(7419),
    [sym_biginteger_literal] = ACTIONS(7421),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7421),
    [sym_integer] = ACTIONS(7419),
    [sym_continue_as_identifier] = ACTIONS(7421),
  },
  [STATE(2928)] = {
    [sym_boolean] = STATE(2065),
    [sym_assignment_expression] = STATE(2065),
    [sym__expression] = STATE(2065),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2065),
    [sym_multiplicative_expression] = STATE(2065),
    [sym_additive_expression] = STATE(2065),
    [sym_comparison_expression] = STATE(2065),
    [sym_logical_expression] = STATE(2065),
    [sym_ternary_expression] = STATE(2065),
    [sym_unary_expression] = STATE(2065),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2065),
    [sym_list_literal] = STATE(2065),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2065),
    [sym__literal_value] = STATE(2065),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7423),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7425),
    [sym_date_literal] = ACTIONS(7423),
    [sym_time_literal] = ACTIONS(7423),
    [sym_biginteger_literal] = ACTIONS(7425),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7425),
    [sym_integer] = ACTIONS(7423),
    [sym_continue_as_identifier] = ACTIONS(7425),
  },
  [STATE(2929)] = {
    [sym_boolean] = STATE(2066),
    [sym_assignment_expression] = STATE(2066),
    [sym__expression] = STATE(2066),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2066),
    [sym_multiplicative_expression] = STATE(2066),
    [sym_additive_expression] = STATE(2066),
    [sym_comparison_expression] = STATE(2066),
    [sym_logical_expression] = STATE(2066),
    [sym_ternary_expression] = STATE(2066),
    [sym_unary_expression] = STATE(2066),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2066),
    [sym_list_literal] = STATE(2066),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2066),
    [sym__literal_value] = STATE(2066),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7427),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7429),
    [sym_date_literal] = ACTIONS(7427),
    [sym_time_literal] = ACTIONS(7427),
    [sym_biginteger_literal] = ACTIONS(7429),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7429),
    [sym_integer] = ACTIONS(7427),
    [sym_continue_as_identifier] = ACTIONS(7429),
  },
  [STATE(2930)] = {
    [sym_boolean] = STATE(1495),
    [sym_assignment_expression] = STATE(1495),
    [sym__expression] = STATE(1495),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1495),
    [sym_multiplicative_expression] = STATE(1495),
    [sym_additive_expression] = STATE(1495),
    [sym_comparison_expression] = STATE(1495),
    [sym_logical_expression] = STATE(1495),
    [sym_ternary_expression] = STATE(1495),
    [sym_unary_expression] = STATE(1495),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1495),
    [sym_list_literal] = STATE(1495),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1495),
    [sym__literal_value] = STATE(1495),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7431),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7433),
    [sym_date_literal] = ACTIONS(7431),
    [sym_time_literal] = ACTIONS(7431),
    [sym_biginteger_literal] = ACTIONS(7433),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7433),
    [sym_integer] = ACTIONS(7431),
    [sym_continue_as_identifier] = ACTIONS(7433),
  },
  [STATE(2931)] = {
    [sym_boolean] = STATE(1497),
    [sym_assignment_expression] = STATE(1497),
    [sym__expression] = STATE(1497),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1497),
    [sym_multiplicative_expression] = STATE(1497),
    [sym_additive_expression] = STATE(1497),
    [sym_comparison_expression] = STATE(1497),
    [sym_logical_expression] = STATE(1497),
    [sym_ternary_expression] = STATE(1497),
    [sym_unary_expression] = STATE(1497),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1497),
    [sym_list_literal] = STATE(1497),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1497),
    [sym__literal_value] = STATE(1497),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7435),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7437),
    [sym_date_literal] = ACTIONS(7435),
    [sym_time_literal] = ACTIONS(7435),
    [sym_biginteger_literal] = ACTIONS(7437),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7437),
    [sym_integer] = ACTIONS(7435),
    [sym_continue_as_identifier] = ACTIONS(7437),
  },
  [STATE(2932)] = {
    [sym_boolean] = STATE(1499),
    [sym_assignment_expression] = STATE(1499),
    [sym__expression] = STATE(1499),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1499),
    [sym_multiplicative_expression] = STATE(1499),
    [sym_additive_expression] = STATE(1499),
    [sym_comparison_expression] = STATE(1499),
    [sym_logical_expression] = STATE(1499),
    [sym_ternary_expression] = STATE(1499),
    [sym_unary_expression] = STATE(1499),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1499),
    [sym_list_literal] = STATE(1499),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1499),
    [sym__literal_value] = STATE(1499),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7439),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7441),
    [sym_date_literal] = ACTIONS(7439),
    [sym_time_literal] = ACTIONS(7439),
    [sym_biginteger_literal] = ACTIONS(7441),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7441),
    [sym_integer] = ACTIONS(7439),
    [sym_continue_as_identifier] = ACTIONS(7441),
  },
  [STATE(2933)] = {
    [sym_boolean] = STATE(2067),
    [sym_assignment_expression] = STATE(2067),
    [sym__expression] = STATE(2067),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2067),
    [sym_multiplicative_expression] = STATE(2067),
    [sym_additive_expression] = STATE(2067),
    [sym_comparison_expression] = STATE(2067),
    [sym_logical_expression] = STATE(2067),
    [sym_ternary_expression] = STATE(2067),
    [sym_unary_expression] = STATE(2067),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2067),
    [sym_list_literal] = STATE(2067),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2067),
    [sym__literal_value] = STATE(2067),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7443),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7445),
    [sym_date_literal] = ACTIONS(7443),
    [sym_time_literal] = ACTIONS(7443),
    [sym_biginteger_literal] = ACTIONS(7445),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7445),
    [sym_integer] = ACTIONS(7443),
    [sym_continue_as_identifier] = ACTIONS(7445),
  },
  [STATE(2934)] = {
    [sym_boolean] = STATE(992),
    [sym_assignment_expression] = STATE(992),
    [sym__expression] = STATE(992),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(992),
    [sym_multiplicative_expression] = STATE(992),
    [sym_additive_expression] = STATE(992),
    [sym_comparison_expression] = STATE(992),
    [sym_logical_expression] = STATE(992),
    [sym_ternary_expression] = STATE(992),
    [sym_unary_expression] = STATE(992),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(992),
    [sym_list_literal] = STATE(992),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(992),
    [sym__literal_value] = STATE(992),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7447),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7449),
    [sym_date_literal] = ACTIONS(7447),
    [sym_time_literal] = ACTIONS(7447),
    [sym_biginteger_literal] = ACTIONS(7449),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7449),
    [sym_integer] = ACTIONS(7447),
    [sym_continue_as_identifier] = ACTIONS(7449),
  },
  [STATE(2935)] = {
    [sym_boolean] = STATE(1200),
    [sym_assignment_expression] = STATE(1200),
    [sym__expression] = STATE(1200),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1200),
    [sym_multiplicative_expression] = STATE(1200),
    [sym_additive_expression] = STATE(1200),
    [sym_comparison_expression] = STATE(1200),
    [sym_logical_expression] = STATE(1200),
    [sym_ternary_expression] = STATE(1200),
    [sym_unary_expression] = STATE(1200),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1200),
    [sym_list_literal] = STATE(1200),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1200),
    [sym__literal_value] = STATE(1200),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7451),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7453),
    [sym_date_literal] = ACTIONS(7451),
    [sym_time_literal] = ACTIONS(7451),
    [sym_biginteger_literal] = ACTIONS(7453),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7453),
    [sym_integer] = ACTIONS(7451),
    [sym_continue_as_identifier] = ACTIONS(7453),
  },
  [STATE(2936)] = {
    [sym_boolean] = STATE(1173),
    [sym_assignment_expression] = STATE(1173),
    [sym__expression] = STATE(1173),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1173),
    [sym_multiplicative_expression] = STATE(1173),
    [sym_additive_expression] = STATE(1173),
    [sym_comparison_expression] = STATE(1173),
    [sym_logical_expression] = STATE(1173),
    [sym_ternary_expression] = STATE(1173),
    [sym_unary_expression] = STATE(1173),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1173),
    [sym_list_literal] = STATE(1173),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1173),
    [sym__literal_value] = STATE(1173),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7455),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7457),
    [sym_date_literal] = ACTIONS(7455),
    [sym_time_literal] = ACTIONS(7455),
    [sym_biginteger_literal] = ACTIONS(7457),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7457),
    [sym_integer] = ACTIONS(7455),
    [sym_continue_as_identifier] = ACTIONS(7457),
  },
  [STATE(2937)] = {
    [sym_boolean] = STATE(1174),
    [sym_assignment_expression] = STATE(1174),
    [sym__expression] = STATE(1174),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1174),
    [sym_multiplicative_expression] = STATE(1174),
    [sym_additive_expression] = STATE(1174),
    [sym_comparison_expression] = STATE(1174),
    [sym_logical_expression] = STATE(1174),
    [sym_ternary_expression] = STATE(1174),
    [sym_unary_expression] = STATE(1174),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1174),
    [sym_list_literal] = STATE(1174),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1174),
    [sym__literal_value] = STATE(1174),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7459),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7461),
    [sym_date_literal] = ACTIONS(7459),
    [sym_time_literal] = ACTIONS(7459),
    [sym_biginteger_literal] = ACTIONS(7461),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7461),
    [sym_integer] = ACTIONS(7459),
    [sym_continue_as_identifier] = ACTIONS(7461),
  },
  [STATE(2938)] = {
    [sym_boolean] = STATE(1175),
    [sym_assignment_expression] = STATE(1175),
    [sym__expression] = STATE(1175),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1175),
    [sym_multiplicative_expression] = STATE(1175),
    [sym_additive_expression] = STATE(1175),
    [sym_comparison_expression] = STATE(1175),
    [sym_logical_expression] = STATE(1175),
    [sym_ternary_expression] = STATE(1175),
    [sym_unary_expression] = STATE(1175),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1175),
    [sym_list_literal] = STATE(1175),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1175),
    [sym__literal_value] = STATE(1175),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7463),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7465),
    [sym_date_literal] = ACTIONS(7463),
    [sym_time_literal] = ACTIONS(7463),
    [sym_biginteger_literal] = ACTIONS(7465),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7465),
    [sym_integer] = ACTIONS(7463),
    [sym_continue_as_identifier] = ACTIONS(7465),
  },
  [STATE(2939)] = {
    [sym_boolean] = STATE(1176),
    [sym_assignment_expression] = STATE(1176),
    [sym__expression] = STATE(1176),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1176),
    [sym_multiplicative_expression] = STATE(1176),
    [sym_additive_expression] = STATE(1176),
    [sym_comparison_expression] = STATE(1176),
    [sym_logical_expression] = STATE(1176),
    [sym_ternary_expression] = STATE(1176),
    [sym_unary_expression] = STATE(1176),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1176),
    [sym_list_literal] = STATE(1176),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1176),
    [sym__literal_value] = STATE(1176),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7467),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7469),
    [sym_date_literal] = ACTIONS(7467),
    [sym_time_literal] = ACTIONS(7467),
    [sym_biginteger_literal] = ACTIONS(7469),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7469),
    [sym_integer] = ACTIONS(7467),
    [sym_continue_as_identifier] = ACTIONS(7469),
  },
  [STATE(2940)] = {
    [sym_boolean] = STATE(1154),
    [sym_assignment_expression] = STATE(1154),
    [sym__expression] = STATE(1154),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1154),
    [sym_multiplicative_expression] = STATE(1154),
    [sym_additive_expression] = STATE(1154),
    [sym_comparison_expression] = STATE(1154),
    [sym_logical_expression] = STATE(1154),
    [sym_ternary_expression] = STATE(1154),
    [sym_unary_expression] = STATE(1154),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1154),
    [sym_list_literal] = STATE(1154),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1154),
    [sym__literal_value] = STATE(1154),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7471),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7473),
    [sym_date_literal] = ACTIONS(7471),
    [sym_time_literal] = ACTIONS(7471),
    [sym_biginteger_literal] = ACTIONS(7473),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7473),
    [sym_integer] = ACTIONS(7471),
    [sym_continue_as_identifier] = ACTIONS(7473),
  },
  [STATE(2941)] = {
    [sym_boolean] = STATE(1178),
    [sym_assignment_expression] = STATE(1178),
    [sym__expression] = STATE(1178),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1178),
    [sym_multiplicative_expression] = STATE(1178),
    [sym_additive_expression] = STATE(1178),
    [sym_comparison_expression] = STATE(1178),
    [sym_logical_expression] = STATE(1178),
    [sym_ternary_expression] = STATE(1178),
    [sym_unary_expression] = STATE(1178),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1178),
    [sym_list_literal] = STATE(1178),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1178),
    [sym__literal_value] = STATE(1178),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7475),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7477),
    [sym_date_literal] = ACTIONS(7475),
    [sym_time_literal] = ACTIONS(7475),
    [sym_biginteger_literal] = ACTIONS(7477),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7477),
    [sym_integer] = ACTIONS(7475),
    [sym_continue_as_identifier] = ACTIONS(7477),
  },
  [STATE(2942)] = {
    [sym_boolean] = STATE(1180),
    [sym_assignment_expression] = STATE(1180),
    [sym__expression] = STATE(1180),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1180),
    [sym_multiplicative_expression] = STATE(1180),
    [sym_additive_expression] = STATE(1180),
    [sym_comparison_expression] = STATE(1180),
    [sym_logical_expression] = STATE(1180),
    [sym_ternary_expression] = STATE(1180),
    [sym_unary_expression] = STATE(1180),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1180),
    [sym_list_literal] = STATE(1180),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1180),
    [sym__literal_value] = STATE(1180),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7479),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7481),
    [sym_date_literal] = ACTIONS(7479),
    [sym_time_literal] = ACTIONS(7479),
    [sym_biginteger_literal] = ACTIONS(7481),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7481),
    [sym_integer] = ACTIONS(7479),
    [sym_continue_as_identifier] = ACTIONS(7481),
  },
  [STATE(2943)] = {
    [sym_boolean] = STATE(1181),
    [sym_assignment_expression] = STATE(1181),
    [sym__expression] = STATE(1181),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1181),
    [sym_multiplicative_expression] = STATE(1181),
    [sym_additive_expression] = STATE(1181),
    [sym_comparison_expression] = STATE(1181),
    [sym_logical_expression] = STATE(1181),
    [sym_ternary_expression] = STATE(1181),
    [sym_unary_expression] = STATE(1181),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1181),
    [sym_list_literal] = STATE(1181),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1181),
    [sym__literal_value] = STATE(1181),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7483),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7485),
    [sym_date_literal] = ACTIONS(7483),
    [sym_time_literal] = ACTIONS(7483),
    [sym_biginteger_literal] = ACTIONS(7485),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7485),
    [sym_integer] = ACTIONS(7483),
    [sym_continue_as_identifier] = ACTIONS(7485),
  },
  [STATE(2944)] = {
    [sym_boolean] = STATE(1182),
    [sym_assignment_expression] = STATE(1182),
    [sym__expression] = STATE(1182),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1182),
    [sym_multiplicative_expression] = STATE(1182),
    [sym_additive_expression] = STATE(1182),
    [sym_comparison_expression] = STATE(1182),
    [sym_logical_expression] = STATE(1182),
    [sym_ternary_expression] = STATE(1182),
    [sym_unary_expression] = STATE(1182),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1182),
    [sym_list_literal] = STATE(1182),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1182),
    [sym__literal_value] = STATE(1182),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7487),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7489),
    [sym_date_literal] = ACTIONS(7487),
    [sym_time_literal] = ACTIONS(7487),
    [sym_biginteger_literal] = ACTIONS(7489),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7489),
    [sym_integer] = ACTIONS(7487),
    [sym_continue_as_identifier] = ACTIONS(7489),
  },
  [STATE(2945)] = {
    [sym_boolean] = STATE(1183),
    [sym_assignment_expression] = STATE(1183),
    [sym__expression] = STATE(1183),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1183),
    [sym_multiplicative_expression] = STATE(1183),
    [sym_additive_expression] = STATE(1183),
    [sym_comparison_expression] = STATE(1183),
    [sym_logical_expression] = STATE(1183),
    [sym_ternary_expression] = STATE(1183),
    [sym_unary_expression] = STATE(1183),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1183),
    [sym_list_literal] = STATE(1183),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1183),
    [sym__literal_value] = STATE(1183),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7491),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7493),
    [sym_date_literal] = ACTIONS(7491),
    [sym_time_literal] = ACTIONS(7491),
    [sym_biginteger_literal] = ACTIONS(7493),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7493),
    [sym_integer] = ACTIONS(7491),
    [sym_continue_as_identifier] = ACTIONS(7493),
  },
  [STATE(2946)] = {
    [sym_boolean] = STATE(1184),
    [sym_assignment_expression] = STATE(1184),
    [sym__expression] = STATE(1184),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1184),
    [sym_multiplicative_expression] = STATE(1184),
    [sym_additive_expression] = STATE(1184),
    [sym_comparison_expression] = STATE(1184),
    [sym_logical_expression] = STATE(1184),
    [sym_ternary_expression] = STATE(1184),
    [sym_unary_expression] = STATE(1184),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1184),
    [sym_list_literal] = STATE(1184),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1184),
    [sym__literal_value] = STATE(1184),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7497),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7497),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7497),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7497),
  },
  [STATE(2947)] = {
    [sym_boolean] = STATE(1171),
    [sym_assignment_expression] = STATE(1171),
    [sym__expression] = STATE(1171),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1171),
    [sym_multiplicative_expression] = STATE(1171),
    [sym_additive_expression] = STATE(1171),
    [sym_comparison_expression] = STATE(1171),
    [sym_logical_expression] = STATE(1171),
    [sym_ternary_expression] = STATE(1171),
    [sym_unary_expression] = STATE(1171),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1171),
    [sym_list_literal] = STATE(1171),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1171),
    [sym__literal_value] = STATE(1171),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7499),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7501),
    [sym_date_literal] = ACTIONS(7499),
    [sym_time_literal] = ACTIONS(7499),
    [sym_biginteger_literal] = ACTIONS(7501),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7501),
    [sym_integer] = ACTIONS(7499),
    [sym_continue_as_identifier] = ACTIONS(7501),
  },
  [STATE(2948)] = {
    [sym_boolean] = STATE(1172),
    [sym_assignment_expression] = STATE(1172),
    [sym__expression] = STATE(1172),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1172),
    [sym_multiplicative_expression] = STATE(1172),
    [sym_additive_expression] = STATE(1172),
    [sym_comparison_expression] = STATE(1172),
    [sym_logical_expression] = STATE(1172),
    [sym_ternary_expression] = STATE(1172),
    [sym_unary_expression] = STATE(1172),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1172),
    [sym_list_literal] = STATE(1172),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1172),
    [sym__literal_value] = STATE(1172),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7503),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7505),
    [sym_date_literal] = ACTIONS(7503),
    [sym_time_literal] = ACTIONS(7503),
    [sym_biginteger_literal] = ACTIONS(7505),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7505),
    [sym_integer] = ACTIONS(7503),
    [sym_continue_as_identifier] = ACTIONS(7505),
  },
  [STATE(2949)] = {
    [sym_boolean] = STATE(1177),
    [sym_assignment_expression] = STATE(1177),
    [sym__expression] = STATE(1177),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1177),
    [sym_multiplicative_expression] = STATE(1177),
    [sym_additive_expression] = STATE(1177),
    [sym_comparison_expression] = STATE(1177),
    [sym_logical_expression] = STATE(1177),
    [sym_ternary_expression] = STATE(1177),
    [sym_unary_expression] = STATE(1177),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1177),
    [sym_list_literal] = STATE(1177),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1177),
    [sym__literal_value] = STATE(1177),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7507),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7509),
    [sym_date_literal] = ACTIONS(7507),
    [sym_time_literal] = ACTIONS(7507),
    [sym_biginteger_literal] = ACTIONS(7509),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7509),
    [sym_integer] = ACTIONS(7507),
    [sym_continue_as_identifier] = ACTIONS(7509),
  },
  [STATE(2950)] = {
    [sym_boolean] = STATE(1185),
    [sym_assignment_expression] = STATE(1185),
    [sym__expression] = STATE(1185),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1185),
    [sym_multiplicative_expression] = STATE(1185),
    [sym_additive_expression] = STATE(1185),
    [sym_comparison_expression] = STATE(1185),
    [sym_logical_expression] = STATE(1185),
    [sym_ternary_expression] = STATE(1185),
    [sym_unary_expression] = STATE(1185),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1185),
    [sym_list_literal] = STATE(1185),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1185),
    [sym__literal_value] = STATE(1185),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7511),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7513),
    [sym_date_literal] = ACTIONS(7511),
    [sym_time_literal] = ACTIONS(7511),
    [sym_biginteger_literal] = ACTIONS(7513),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7513),
    [sym_integer] = ACTIONS(7511),
    [sym_continue_as_identifier] = ACTIONS(7513),
  },
  [STATE(2951)] = {
    [sym_boolean] = STATE(1186),
    [sym_assignment_expression] = STATE(1186),
    [sym__expression] = STATE(1186),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1186),
    [sym_multiplicative_expression] = STATE(1186),
    [sym_additive_expression] = STATE(1186),
    [sym_comparison_expression] = STATE(1186),
    [sym_logical_expression] = STATE(1186),
    [sym_ternary_expression] = STATE(1186),
    [sym_unary_expression] = STATE(1186),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1186),
    [sym_list_literal] = STATE(1186),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1186),
    [sym__literal_value] = STATE(1186),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7515),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7517),
    [sym_date_literal] = ACTIONS(7515),
    [sym_time_literal] = ACTIONS(7515),
    [sym_biginteger_literal] = ACTIONS(7517),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7517),
    [sym_integer] = ACTIONS(7515),
    [sym_continue_as_identifier] = ACTIONS(7517),
  },
  [STATE(2952)] = {
    [sym_boolean] = STATE(1189),
    [sym_assignment_expression] = STATE(1189),
    [sym__expression] = STATE(1189),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1189),
    [sym_multiplicative_expression] = STATE(1189),
    [sym_additive_expression] = STATE(1189),
    [sym_comparison_expression] = STATE(1189),
    [sym_logical_expression] = STATE(1189),
    [sym_ternary_expression] = STATE(1189),
    [sym_unary_expression] = STATE(1189),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1189),
    [sym_list_literal] = STATE(1189),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1189),
    [sym__literal_value] = STATE(1189),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7519),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7521),
    [sym_date_literal] = ACTIONS(7519),
    [sym_time_literal] = ACTIONS(7519),
    [sym_biginteger_literal] = ACTIONS(7521),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7521),
    [sym_integer] = ACTIONS(7519),
    [sym_continue_as_identifier] = ACTIONS(7521),
  },
  [STATE(2953)] = {
    [sym_boolean] = STATE(1191),
    [sym_assignment_expression] = STATE(1191),
    [sym__expression] = STATE(1191),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1191),
    [sym_multiplicative_expression] = STATE(1191),
    [sym_additive_expression] = STATE(1191),
    [sym_comparison_expression] = STATE(1191),
    [sym_logical_expression] = STATE(1191),
    [sym_ternary_expression] = STATE(1191),
    [sym_unary_expression] = STATE(1191),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1191),
    [sym_list_literal] = STATE(1191),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1191),
    [sym__literal_value] = STATE(1191),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7523),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7525),
    [sym_date_literal] = ACTIONS(7523),
    [sym_time_literal] = ACTIONS(7523),
    [sym_biginteger_literal] = ACTIONS(7525),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7525),
    [sym_integer] = ACTIONS(7523),
    [sym_continue_as_identifier] = ACTIONS(7525),
  },
  [STATE(2954)] = {
    [sym_boolean] = STATE(1192),
    [sym_assignment_expression] = STATE(1192),
    [sym__expression] = STATE(1192),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1192),
    [sym_multiplicative_expression] = STATE(1192),
    [sym_additive_expression] = STATE(1192),
    [sym_comparison_expression] = STATE(1192),
    [sym_logical_expression] = STATE(1192),
    [sym_ternary_expression] = STATE(1192),
    [sym_unary_expression] = STATE(1192),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1192),
    [sym_list_literal] = STATE(1192),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1192),
    [sym__literal_value] = STATE(1192),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7527),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7529),
    [sym_date_literal] = ACTIONS(7527),
    [sym_time_literal] = ACTIONS(7527),
    [sym_biginteger_literal] = ACTIONS(7529),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7529),
    [sym_integer] = ACTIONS(7527),
    [sym_continue_as_identifier] = ACTIONS(7529),
  },
  [STATE(2955)] = {
    [sym_boolean] = STATE(1194),
    [sym_assignment_expression] = STATE(1194),
    [sym__expression] = STATE(1194),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1194),
    [sym_multiplicative_expression] = STATE(1194),
    [sym_additive_expression] = STATE(1194),
    [sym_comparison_expression] = STATE(1194),
    [sym_logical_expression] = STATE(1194),
    [sym_ternary_expression] = STATE(1194),
    [sym_unary_expression] = STATE(1194),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1194),
    [sym_list_literal] = STATE(1194),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1194),
    [sym__literal_value] = STATE(1194),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7531),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7533),
    [sym_date_literal] = ACTIONS(7531),
    [sym_time_literal] = ACTIONS(7531),
    [sym_biginteger_literal] = ACTIONS(7533),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7533),
    [sym_integer] = ACTIONS(7531),
    [sym_continue_as_identifier] = ACTIONS(7533),
  },
  [STATE(2956)] = {
    [sym_boolean] = STATE(1195),
    [sym_assignment_expression] = STATE(1195),
    [sym__expression] = STATE(1195),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1195),
    [sym_multiplicative_expression] = STATE(1195),
    [sym_additive_expression] = STATE(1195),
    [sym_comparison_expression] = STATE(1195),
    [sym_logical_expression] = STATE(1195),
    [sym_ternary_expression] = STATE(1195),
    [sym_unary_expression] = STATE(1195),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1195),
    [sym_list_literal] = STATE(1195),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1195),
    [sym__literal_value] = STATE(1195),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7535),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7537),
    [sym_date_literal] = ACTIONS(7535),
    [sym_time_literal] = ACTIONS(7535),
    [sym_biginteger_literal] = ACTIONS(7537),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7537),
    [sym_integer] = ACTIONS(7535),
    [sym_continue_as_identifier] = ACTIONS(7537),
  },
  [STATE(2957)] = {
    [sym_identifier] = ACTIONS(7539),
    [anon_sym_SEMI] = ACTIONS(7541),
    [aux_sym_where_condition_token1] = ACTIONS(7539),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7539),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7539),
    [anon_sym_LBRACK] = ACTIONS(7541),
    [aux_sym_basic_type_token6] = ACTIONS(7539),
    [aux_sym_basic_type_token22] = ACTIONS(7539),
    [aux_sym_basic_type_token53] = ACTIONS(7539),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7539),
    [aux_sym_addafter_modification_token1] = ACTIONS(7539),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7539),
    [aux_sym_modify_modification_token1] = ACTIONS(7539),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7539),
    [aux_sym_movelast_modification_token1] = ACTIONS(7539),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7539),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7539),
    [aux_sym_separator_action_token1] = ACTIONS(7539),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7539),
    [aux_sym_type_declaration_token1] = ACTIONS(7539),
    [anon_sym_POUNDif] = ACTIONS(7541),
    [anon_sym_POUNDIF] = ACTIONS(7541),
    [anon_sym_POUNDIf] = ACTIONS(7541),
    [anon_sym_POUNDelif] = ACTIONS(7541),
    [anon_sym_POUNDELIF] = ACTIONS(7541),
    [anon_sym_POUNDElif] = ACTIONS(7541),
    [anon_sym_POUNDelse] = ACTIONS(7541),
    [anon_sym_POUNDELSE] = ACTIONS(7541),
    [anon_sym_POUNDElse] = ACTIONS(7541),
    [anon_sym_POUNDendif] = ACTIONS(7541),
    [anon_sym_POUNDENDIF] = ACTIONS(7541),
    [anon_sym_POUNDEndif] = ACTIONS(7541),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7539),
    [sym_trigger_keyword] = ACTIONS(7539),
    [sym_var_keyword] = ACTIONS(7539),
    [sym_local_keyword] = ACTIONS(7539),
    [sym_internal_keyword] = ACTIONS(7539),
    [sym_protected_keyword] = ACTIONS(7539),
    [sym_event_keyword] = ACTIONS(7539),
    [sym_fields_keyword] = ACTIONS(7539),
    [sym_keys_keyword] = ACTIONS(7539),
    [sym_key_keyword] = ACTIONS(7539),
    [sym_fieldgroups_keyword] = ACTIONS(7539),
    [sym_actions_keyword] = ACTIONS(7539),
    [sym_layout_keyword] = ACTIONS(7539),
    [sym_area_keyword] = ACTIONS(7539),
    [sym_group_keyword] = ACTIONS(7539),
    [sym_repeater_keyword] = ACTIONS(7539),
    [sym_cuegroup_keyword] = ACTIONS(7539),
    [sym_fixed_keyword] = ACTIONS(7539),
    [sym_grid_keyword] = ACTIONS(7539),
    [sym_part_keyword] = ACTIONS(7539),
    [sym_systempart_keyword] = ACTIONS(7539),
    [sym_usercontrol_keyword] = ACTIONS(7539),
    [sym_dataset_keyword] = ACTIONS(7539),
    [sym_elements_keyword] = ACTIONS(7539),
    [sym_dataitem_keyword] = ACTIONS(7539),
    [sym_column_keyword] = ACTIONS(7539),
    [sym_filter_keyword] = ACTIONS(7539),
    [sym_labels_keyword] = ACTIONS(7539),
    [sym_rendering_keyword] = ACTIONS(7539),
    [sym_requestpage_keyword] = ACTIONS(7539),
    [sym_schema_keyword] = ACTIONS(7539),
    [sym_views_keyword] = ACTIONS(7539),
    [sym_quoted_identifier] = ACTIONS(7541),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7541),
    [sym_preproc_open] = ACTIONS(7541),
    [sym_preproc_close] = ACTIONS(7541),
    [sym_var_attribute_open] = ACTIONS(7541),
  },
  [STATE(2958)] = {
    [sym_identifier] = ACTIONS(7543),
    [anon_sym_SEMI] = ACTIONS(7545),
    [aux_sym_where_condition_token1] = ACTIONS(7543),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7543),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7543),
    [anon_sym_LBRACK] = ACTIONS(7545),
    [aux_sym_basic_type_token6] = ACTIONS(7543),
    [aux_sym_basic_type_token22] = ACTIONS(7543),
    [aux_sym_basic_type_token53] = ACTIONS(7543),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7543),
    [aux_sym_addafter_modification_token1] = ACTIONS(7543),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7543),
    [aux_sym_modify_modification_token1] = ACTIONS(7543),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7543),
    [aux_sym_movelast_modification_token1] = ACTIONS(7543),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7543),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7543),
    [aux_sym_separator_action_token1] = ACTIONS(7543),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7543),
    [aux_sym_type_declaration_token1] = ACTIONS(7543),
    [anon_sym_POUNDif] = ACTIONS(7545),
    [anon_sym_POUNDIF] = ACTIONS(7545),
    [anon_sym_POUNDIf] = ACTIONS(7545),
    [anon_sym_POUNDelif] = ACTIONS(7545),
    [anon_sym_POUNDELIF] = ACTIONS(7545),
    [anon_sym_POUNDElif] = ACTIONS(7545),
    [anon_sym_POUNDelse] = ACTIONS(7545),
    [anon_sym_POUNDELSE] = ACTIONS(7545),
    [anon_sym_POUNDElse] = ACTIONS(7545),
    [anon_sym_POUNDendif] = ACTIONS(7545),
    [anon_sym_POUNDENDIF] = ACTIONS(7545),
    [anon_sym_POUNDEndif] = ACTIONS(7545),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7543),
    [sym_trigger_keyword] = ACTIONS(7543),
    [sym_var_keyword] = ACTIONS(7543),
    [sym_local_keyword] = ACTIONS(7543),
    [sym_internal_keyword] = ACTIONS(7543),
    [sym_protected_keyword] = ACTIONS(7543),
    [sym_event_keyword] = ACTIONS(7543),
    [sym_fields_keyword] = ACTIONS(7543),
    [sym_keys_keyword] = ACTIONS(7543),
    [sym_key_keyword] = ACTIONS(7543),
    [sym_fieldgroups_keyword] = ACTIONS(7543),
    [sym_actions_keyword] = ACTIONS(7543),
    [sym_layout_keyword] = ACTIONS(7543),
    [sym_area_keyword] = ACTIONS(7543),
    [sym_group_keyword] = ACTIONS(7543),
    [sym_repeater_keyword] = ACTIONS(7543),
    [sym_cuegroup_keyword] = ACTIONS(7543),
    [sym_fixed_keyword] = ACTIONS(7543),
    [sym_grid_keyword] = ACTIONS(7543),
    [sym_part_keyword] = ACTIONS(7543),
    [sym_systempart_keyword] = ACTIONS(7543),
    [sym_usercontrol_keyword] = ACTIONS(7543),
    [sym_dataset_keyword] = ACTIONS(7543),
    [sym_elements_keyword] = ACTIONS(7543),
    [sym_dataitem_keyword] = ACTIONS(7543),
    [sym_column_keyword] = ACTIONS(7543),
    [sym_filter_keyword] = ACTIONS(7543),
    [sym_labels_keyword] = ACTIONS(7543),
    [sym_rendering_keyword] = ACTIONS(7543),
    [sym_requestpage_keyword] = ACTIONS(7543),
    [sym_schema_keyword] = ACTIONS(7543),
    [sym_views_keyword] = ACTIONS(7543),
    [sym_quoted_identifier] = ACTIONS(7545),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7545),
    [sym_preproc_open] = ACTIONS(7545),
    [sym_preproc_close] = ACTIONS(7545),
    [sym_var_attribute_open] = ACTIONS(7545),
  },
  [STATE(2959)] = {
    [sym_boolean] = STATE(2068),
    [sym_assignment_expression] = STATE(2068),
    [sym__expression] = STATE(2068),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2068),
    [sym_multiplicative_expression] = STATE(2068),
    [sym_additive_expression] = STATE(2068),
    [sym_comparison_expression] = STATE(2068),
    [sym_logical_expression] = STATE(2068),
    [sym_ternary_expression] = STATE(2068),
    [sym_unary_expression] = STATE(2068),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2068),
    [sym_list_literal] = STATE(2068),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2068),
    [sym__literal_value] = STATE(2068),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7547),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7549),
    [sym_date_literal] = ACTIONS(7547),
    [sym_time_literal] = ACTIONS(7547),
    [sym_biginteger_literal] = ACTIONS(7549),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7549),
    [sym_integer] = ACTIONS(7547),
    [sym_continue_as_identifier] = ACTIONS(7549),
  },
  [STATE(2960)] = {
    [sym_boolean] = STATE(2069),
    [sym_assignment_expression] = STATE(2069),
    [sym__expression] = STATE(2069),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2069),
    [sym_multiplicative_expression] = STATE(2069),
    [sym_additive_expression] = STATE(2069),
    [sym_comparison_expression] = STATE(2069),
    [sym_logical_expression] = STATE(2069),
    [sym_ternary_expression] = STATE(2069),
    [sym_unary_expression] = STATE(2069),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2069),
    [sym_list_literal] = STATE(2069),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2069),
    [sym__literal_value] = STATE(2069),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7551),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7553),
    [sym_date_literal] = ACTIONS(7551),
    [sym_time_literal] = ACTIONS(7551),
    [sym_biginteger_literal] = ACTIONS(7553),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7553),
    [sym_integer] = ACTIONS(7551),
    [sym_continue_as_identifier] = ACTIONS(7553),
  },
  [STATE(2961)] = {
    [sym_boolean] = STATE(1399),
    [sym_assignment_expression] = STATE(1399),
    [sym__expression] = STATE(1399),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1399),
    [sym_multiplicative_expression] = STATE(1399),
    [sym_additive_expression] = STATE(1399),
    [sym_comparison_expression] = STATE(1399),
    [sym_logical_expression] = STATE(1399),
    [sym_ternary_expression] = STATE(1399),
    [sym_unary_expression] = STATE(1399),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1399),
    [sym_list_literal] = STATE(1399),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1399),
    [sym__literal_value] = STATE(1399),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7555),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7557),
    [sym_date_literal] = ACTIONS(7555),
    [sym_time_literal] = ACTIONS(7555),
    [sym_biginteger_literal] = ACTIONS(7557),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7557),
    [sym_integer] = ACTIONS(7555),
    [sym_continue_as_identifier] = ACTIONS(7557),
  },
  [STATE(2962)] = {
    [sym_boolean] = STATE(2070),
    [sym_assignment_expression] = STATE(2070),
    [sym__expression] = STATE(2070),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2070),
    [sym_multiplicative_expression] = STATE(2070),
    [sym_additive_expression] = STATE(2070),
    [sym_comparison_expression] = STATE(2070),
    [sym_logical_expression] = STATE(2070),
    [sym_ternary_expression] = STATE(2070),
    [sym_unary_expression] = STATE(2070),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2070),
    [sym_list_literal] = STATE(2070),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2070),
    [sym__literal_value] = STATE(2070),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7559),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7561),
    [sym_date_literal] = ACTIONS(7559),
    [sym_time_literal] = ACTIONS(7559),
    [sym_biginteger_literal] = ACTIONS(7561),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7561),
    [sym_integer] = ACTIONS(7559),
    [sym_continue_as_identifier] = ACTIONS(7561),
  },
  [STATE(2963)] = {
    [sym_boolean] = STATE(2071),
    [sym_assignment_expression] = STATE(2071),
    [sym__expression] = STATE(2071),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2071),
    [sym_multiplicative_expression] = STATE(2071),
    [sym_additive_expression] = STATE(2071),
    [sym_comparison_expression] = STATE(2071),
    [sym_logical_expression] = STATE(2071),
    [sym_ternary_expression] = STATE(2071),
    [sym_unary_expression] = STATE(2071),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2071),
    [sym_list_literal] = STATE(2071),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2071),
    [sym__literal_value] = STATE(2071),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7563),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7565),
    [sym_date_literal] = ACTIONS(7563),
    [sym_time_literal] = ACTIONS(7563),
    [sym_biginteger_literal] = ACTIONS(7565),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7565),
    [sym_integer] = ACTIONS(7563),
    [sym_continue_as_identifier] = ACTIONS(7565),
  },
  [STATE(2964)] = {
    [sym_boolean] = STATE(1051),
    [sym_assignment_expression] = STATE(1051),
    [sym__expression] = STATE(1051),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1051),
    [sym_multiplicative_expression] = STATE(1051),
    [sym_additive_expression] = STATE(1051),
    [sym_comparison_expression] = STATE(1051),
    [sym_logical_expression] = STATE(1051),
    [sym_ternary_expression] = STATE(1051),
    [sym_unary_expression] = STATE(1051),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1051),
    [sym_list_literal] = STATE(1051),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1051),
    [sym__literal_value] = STATE(1051),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7567),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7569),
    [sym_date_literal] = ACTIONS(7567),
    [sym_time_literal] = ACTIONS(7567),
    [sym_biginteger_literal] = ACTIONS(7569),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7569),
    [sym_integer] = ACTIONS(7567),
    [sym_continue_as_identifier] = ACTIONS(7569),
  },
  [STATE(2965)] = {
    [sym_boolean] = STATE(2072),
    [sym_assignment_expression] = STATE(2072),
    [sym__expression] = STATE(2072),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2072),
    [sym_multiplicative_expression] = STATE(2072),
    [sym_additive_expression] = STATE(2072),
    [sym_comparison_expression] = STATE(2072),
    [sym_logical_expression] = STATE(2072),
    [sym_ternary_expression] = STATE(2072),
    [sym_unary_expression] = STATE(2072),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2072),
    [sym_list_literal] = STATE(2072),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2072),
    [sym__literal_value] = STATE(2072),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7571),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7573),
    [sym_date_literal] = ACTIONS(7571),
    [sym_time_literal] = ACTIONS(7571),
    [sym_biginteger_literal] = ACTIONS(7573),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7573),
    [sym_integer] = ACTIONS(7571),
    [sym_continue_as_identifier] = ACTIONS(7573),
  },
  [STATE(2966)] = {
    [sym_identifier] = ACTIONS(7575),
    [anon_sym_SEMI] = ACTIONS(7577),
    [aux_sym_where_condition_token1] = ACTIONS(7575),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7575),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7575),
    [anon_sym_LBRACK] = ACTIONS(7577),
    [aux_sym_basic_type_token6] = ACTIONS(7575),
    [aux_sym_basic_type_token22] = ACTIONS(7575),
    [aux_sym_basic_type_token53] = ACTIONS(7575),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7575),
    [aux_sym_addafter_modification_token1] = ACTIONS(7575),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7575),
    [aux_sym_modify_modification_token1] = ACTIONS(7575),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7575),
    [aux_sym_movelast_modification_token1] = ACTIONS(7575),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7575),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7575),
    [aux_sym_separator_action_token1] = ACTIONS(7575),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7575),
    [aux_sym_type_declaration_token1] = ACTIONS(7575),
    [anon_sym_POUNDif] = ACTIONS(7577),
    [anon_sym_POUNDIF] = ACTIONS(7577),
    [anon_sym_POUNDIf] = ACTIONS(7577),
    [anon_sym_POUNDelif] = ACTIONS(7577),
    [anon_sym_POUNDELIF] = ACTIONS(7577),
    [anon_sym_POUNDElif] = ACTIONS(7577),
    [anon_sym_POUNDelse] = ACTIONS(7577),
    [anon_sym_POUNDELSE] = ACTIONS(7577),
    [anon_sym_POUNDElse] = ACTIONS(7577),
    [anon_sym_POUNDendif] = ACTIONS(7577),
    [anon_sym_POUNDENDIF] = ACTIONS(7577),
    [anon_sym_POUNDEndif] = ACTIONS(7577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7575),
    [sym_trigger_keyword] = ACTIONS(7575),
    [sym_var_keyword] = ACTIONS(7575),
    [sym_local_keyword] = ACTIONS(7575),
    [sym_internal_keyword] = ACTIONS(7575),
    [sym_protected_keyword] = ACTIONS(7575),
    [sym_event_keyword] = ACTIONS(7575),
    [sym_fields_keyword] = ACTIONS(7575),
    [sym_keys_keyword] = ACTIONS(7575),
    [sym_key_keyword] = ACTIONS(7575),
    [sym_fieldgroups_keyword] = ACTIONS(7575),
    [sym_actions_keyword] = ACTIONS(7575),
    [sym_layout_keyword] = ACTIONS(7575),
    [sym_area_keyword] = ACTIONS(7575),
    [sym_group_keyword] = ACTIONS(7575),
    [sym_repeater_keyword] = ACTIONS(7575),
    [sym_cuegroup_keyword] = ACTIONS(7575),
    [sym_fixed_keyword] = ACTIONS(7575),
    [sym_grid_keyword] = ACTIONS(7575),
    [sym_part_keyword] = ACTIONS(7575),
    [sym_systempart_keyword] = ACTIONS(7575),
    [sym_usercontrol_keyword] = ACTIONS(7575),
    [sym_dataset_keyword] = ACTIONS(7575),
    [sym_elements_keyword] = ACTIONS(7575),
    [sym_dataitem_keyword] = ACTIONS(7575),
    [sym_column_keyword] = ACTIONS(7575),
    [sym_filter_keyword] = ACTIONS(7575),
    [sym_labels_keyword] = ACTIONS(7575),
    [sym_rendering_keyword] = ACTIONS(7575),
    [sym_requestpage_keyword] = ACTIONS(7575),
    [sym_schema_keyword] = ACTIONS(7575),
    [sym_views_keyword] = ACTIONS(7575),
    [sym_quoted_identifier] = ACTIONS(7577),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7577),
    [sym_preproc_open] = ACTIONS(7577),
    [sym_preproc_close] = ACTIONS(7577),
    [sym_var_attribute_open] = ACTIONS(7577),
  },
  [STATE(2967)] = {
    [sym_boolean] = STATE(2073),
    [sym_assignment_expression] = STATE(2073),
    [sym__expression] = STATE(2073),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2073),
    [sym_multiplicative_expression] = STATE(2073),
    [sym_additive_expression] = STATE(2073),
    [sym_comparison_expression] = STATE(2073),
    [sym_logical_expression] = STATE(2073),
    [sym_ternary_expression] = STATE(2073),
    [sym_unary_expression] = STATE(2073),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2073),
    [sym_list_literal] = STATE(2073),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2073),
    [sym__literal_value] = STATE(2073),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7579),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7581),
    [sym_date_literal] = ACTIONS(7579),
    [sym_time_literal] = ACTIONS(7579),
    [sym_biginteger_literal] = ACTIONS(7581),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7581),
    [sym_integer] = ACTIONS(7579),
    [sym_continue_as_identifier] = ACTIONS(7581),
  },
  [STATE(2968)] = {
    [sym_boolean] = STATE(6217),
    [sym_assignment_expression] = STATE(6217),
    [sym__expression] = STATE(6217),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6217),
    [sym_multiplicative_expression] = STATE(6217),
    [sym_additive_expression] = STATE(6217),
    [sym_comparison_expression] = STATE(6217),
    [sym_logical_expression] = STATE(6217),
    [sym_ternary_expression] = STATE(6217),
    [sym_unary_expression] = STATE(6217),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6217),
    [sym_list_literal] = STATE(6217),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6217),
    [sym__literal_value] = STATE(6217),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7583),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7585),
    [sym_date_literal] = ACTIONS(7583),
    [sym_time_literal] = ACTIONS(7583),
    [sym_biginteger_literal] = ACTIONS(7585),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7585),
    [sym_integer] = ACTIONS(7583),
    [sym_continue_as_identifier] = ACTIONS(7585),
  },
  [STATE(2969)] = {
    [sym_identifier] = ACTIONS(7575),
    [anon_sym_SEMI] = ACTIONS(7577),
    [aux_sym_where_condition_token1] = ACTIONS(7575),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7575),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7575),
    [anon_sym_LBRACK] = ACTIONS(7577),
    [aux_sym_basic_type_token6] = ACTIONS(7575),
    [aux_sym_basic_type_token22] = ACTIONS(7575),
    [aux_sym_basic_type_token53] = ACTIONS(7575),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7575),
    [aux_sym_addafter_modification_token1] = ACTIONS(7575),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7575),
    [aux_sym_modify_modification_token1] = ACTIONS(7575),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7575),
    [aux_sym_movelast_modification_token1] = ACTIONS(7575),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7575),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7575),
    [aux_sym_separator_action_token1] = ACTIONS(7575),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7575),
    [aux_sym_type_declaration_token1] = ACTIONS(7575),
    [anon_sym_POUNDif] = ACTIONS(7577),
    [anon_sym_POUNDIF] = ACTIONS(7577),
    [anon_sym_POUNDIf] = ACTIONS(7577),
    [anon_sym_POUNDelif] = ACTIONS(7577),
    [anon_sym_POUNDELIF] = ACTIONS(7577),
    [anon_sym_POUNDElif] = ACTIONS(7577),
    [anon_sym_POUNDelse] = ACTIONS(7577),
    [anon_sym_POUNDELSE] = ACTIONS(7577),
    [anon_sym_POUNDElse] = ACTIONS(7577),
    [anon_sym_POUNDendif] = ACTIONS(7577),
    [anon_sym_POUNDENDIF] = ACTIONS(7577),
    [anon_sym_POUNDEndif] = ACTIONS(7577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7575),
    [sym_trigger_keyword] = ACTIONS(7575),
    [sym_var_keyword] = ACTIONS(7575),
    [sym_local_keyword] = ACTIONS(7575),
    [sym_internal_keyword] = ACTIONS(7575),
    [sym_protected_keyword] = ACTIONS(7575),
    [sym_event_keyword] = ACTIONS(7575),
    [sym_fields_keyword] = ACTIONS(7575),
    [sym_keys_keyword] = ACTIONS(7575),
    [sym_key_keyword] = ACTIONS(7575),
    [sym_fieldgroups_keyword] = ACTIONS(7575),
    [sym_actions_keyword] = ACTIONS(7575),
    [sym_layout_keyword] = ACTIONS(7575),
    [sym_area_keyword] = ACTIONS(7575),
    [sym_group_keyword] = ACTIONS(7575),
    [sym_repeater_keyword] = ACTIONS(7575),
    [sym_cuegroup_keyword] = ACTIONS(7575),
    [sym_fixed_keyword] = ACTIONS(7575),
    [sym_grid_keyword] = ACTIONS(7575),
    [sym_part_keyword] = ACTIONS(7575),
    [sym_systempart_keyword] = ACTIONS(7575),
    [sym_usercontrol_keyword] = ACTIONS(7575),
    [sym_dataset_keyword] = ACTIONS(7575),
    [sym_elements_keyword] = ACTIONS(7575),
    [sym_dataitem_keyword] = ACTIONS(7575),
    [sym_column_keyword] = ACTIONS(7575),
    [sym_filter_keyword] = ACTIONS(7575),
    [sym_labels_keyword] = ACTIONS(7575),
    [sym_rendering_keyword] = ACTIONS(7575),
    [sym_requestpage_keyword] = ACTIONS(7575),
    [sym_schema_keyword] = ACTIONS(7575),
    [sym_views_keyword] = ACTIONS(7575),
    [sym_quoted_identifier] = ACTIONS(7577),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7577),
    [sym_preproc_open] = ACTIONS(7577),
    [sym_preproc_close] = ACTIONS(7577),
    [sym_var_attribute_open] = ACTIONS(7577),
  },
  [STATE(2970)] = {
    [sym_identifier] = ACTIONS(7575),
    [anon_sym_SEMI] = ACTIONS(7577),
    [aux_sym_where_condition_token1] = ACTIONS(7575),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7575),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7575),
    [anon_sym_LBRACK] = ACTIONS(7577),
    [aux_sym_basic_type_token6] = ACTIONS(7575),
    [aux_sym_basic_type_token22] = ACTIONS(7575),
    [aux_sym_basic_type_token53] = ACTIONS(7575),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7575),
    [aux_sym_addafter_modification_token1] = ACTIONS(7575),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7575),
    [aux_sym_modify_modification_token1] = ACTIONS(7575),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7575),
    [aux_sym_movelast_modification_token1] = ACTIONS(7575),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7575),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7575),
    [aux_sym_separator_action_token1] = ACTIONS(7575),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7575),
    [aux_sym_type_declaration_token1] = ACTIONS(7575),
    [anon_sym_POUNDif] = ACTIONS(7577),
    [anon_sym_POUNDIF] = ACTIONS(7577),
    [anon_sym_POUNDIf] = ACTIONS(7577),
    [anon_sym_POUNDelif] = ACTIONS(7577),
    [anon_sym_POUNDELIF] = ACTIONS(7577),
    [anon_sym_POUNDElif] = ACTIONS(7577),
    [anon_sym_POUNDelse] = ACTIONS(7577),
    [anon_sym_POUNDELSE] = ACTIONS(7577),
    [anon_sym_POUNDElse] = ACTIONS(7577),
    [anon_sym_POUNDendif] = ACTIONS(7577),
    [anon_sym_POUNDENDIF] = ACTIONS(7577),
    [anon_sym_POUNDEndif] = ACTIONS(7577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7575),
    [sym_trigger_keyword] = ACTIONS(7575),
    [sym_var_keyword] = ACTIONS(7575),
    [sym_local_keyword] = ACTIONS(7575),
    [sym_internal_keyword] = ACTIONS(7575),
    [sym_protected_keyword] = ACTIONS(7575),
    [sym_event_keyword] = ACTIONS(7575),
    [sym_fields_keyword] = ACTIONS(7575),
    [sym_keys_keyword] = ACTIONS(7575),
    [sym_key_keyword] = ACTIONS(7575),
    [sym_fieldgroups_keyword] = ACTIONS(7575),
    [sym_actions_keyword] = ACTIONS(7575),
    [sym_layout_keyword] = ACTIONS(7575),
    [sym_area_keyword] = ACTIONS(7575),
    [sym_group_keyword] = ACTIONS(7575),
    [sym_repeater_keyword] = ACTIONS(7575),
    [sym_cuegroup_keyword] = ACTIONS(7575),
    [sym_fixed_keyword] = ACTIONS(7575),
    [sym_grid_keyword] = ACTIONS(7575),
    [sym_part_keyword] = ACTIONS(7575),
    [sym_systempart_keyword] = ACTIONS(7575),
    [sym_usercontrol_keyword] = ACTIONS(7575),
    [sym_dataset_keyword] = ACTIONS(7575),
    [sym_elements_keyword] = ACTIONS(7575),
    [sym_dataitem_keyword] = ACTIONS(7575),
    [sym_column_keyword] = ACTIONS(7575),
    [sym_filter_keyword] = ACTIONS(7575),
    [sym_labels_keyword] = ACTIONS(7575),
    [sym_rendering_keyword] = ACTIONS(7575),
    [sym_requestpage_keyword] = ACTIONS(7575),
    [sym_schema_keyword] = ACTIONS(7575),
    [sym_views_keyword] = ACTIONS(7575),
    [sym_quoted_identifier] = ACTIONS(7577),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7577),
    [sym_preproc_open] = ACTIONS(7577),
    [sym_preproc_close] = ACTIONS(7577),
    [sym_var_attribute_open] = ACTIONS(7577),
  },
  [STATE(2971)] = {
    [sym_boolean] = STATE(2074),
    [sym_assignment_expression] = STATE(2074),
    [sym__expression] = STATE(2074),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2074),
    [sym_multiplicative_expression] = STATE(2074),
    [sym_additive_expression] = STATE(2074),
    [sym_comparison_expression] = STATE(2074),
    [sym_logical_expression] = STATE(2074),
    [sym_ternary_expression] = STATE(2074),
    [sym_unary_expression] = STATE(2074),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2074),
    [sym_list_literal] = STATE(2074),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2074),
    [sym__literal_value] = STATE(2074),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7587),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7589),
    [sym_date_literal] = ACTIONS(7587),
    [sym_time_literal] = ACTIONS(7587),
    [sym_biginteger_literal] = ACTIONS(7589),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7589),
    [sym_integer] = ACTIONS(7587),
    [sym_continue_as_identifier] = ACTIONS(7589),
  },
  [STATE(2972)] = {
    [sym_boolean] = STATE(2078),
    [sym_assignment_expression] = STATE(2078),
    [sym__expression] = STATE(2078),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2078),
    [sym_multiplicative_expression] = STATE(2078),
    [sym_additive_expression] = STATE(2078),
    [sym_comparison_expression] = STATE(2078),
    [sym_logical_expression] = STATE(2078),
    [sym_ternary_expression] = STATE(2078),
    [sym_unary_expression] = STATE(2078),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2078),
    [sym_list_literal] = STATE(2078),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2078),
    [sym__literal_value] = STATE(2078),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7591),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7593),
    [sym_date_literal] = ACTIONS(7591),
    [sym_time_literal] = ACTIONS(7591),
    [sym_biginteger_literal] = ACTIONS(7593),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7593),
    [sym_integer] = ACTIONS(7591),
    [sym_continue_as_identifier] = ACTIONS(7593),
  },
  [STATE(2973)] = {
    [sym_identifier] = ACTIONS(2843),
    [anon_sym_SEMI] = ACTIONS(2841),
    [aux_sym_where_condition_token1] = ACTIONS(2843),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2843),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2843),
    [anon_sym_LBRACK] = ACTIONS(2841),
    [aux_sym_basic_type_token6] = ACTIONS(2843),
    [aux_sym_basic_type_token22] = ACTIONS(2843),
    [aux_sym_basic_type_token53] = ACTIONS(2843),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2843),
    [aux_sym_addafter_modification_token1] = ACTIONS(2843),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2843),
    [aux_sym_modify_modification_token1] = ACTIONS(2843),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2843),
    [aux_sym_movelast_modification_token1] = ACTIONS(2843),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2843),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2843),
    [aux_sym_separator_action_token1] = ACTIONS(2843),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2843),
    [aux_sym_type_declaration_token1] = ACTIONS(2843),
    [anon_sym_POUNDif] = ACTIONS(2841),
    [anon_sym_POUNDIF] = ACTIONS(2841),
    [anon_sym_POUNDIf] = ACTIONS(2841),
    [anon_sym_POUNDelif] = ACTIONS(2841),
    [anon_sym_POUNDELIF] = ACTIONS(2841),
    [anon_sym_POUNDElif] = ACTIONS(2841),
    [anon_sym_POUNDelse] = ACTIONS(2841),
    [anon_sym_POUNDELSE] = ACTIONS(2841),
    [anon_sym_POUNDElse] = ACTIONS(2841),
    [anon_sym_POUNDendif] = ACTIONS(2841),
    [anon_sym_POUNDENDIF] = ACTIONS(2841),
    [anon_sym_POUNDEndif] = ACTIONS(2841),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(2843),
    [sym_trigger_keyword] = ACTIONS(2843),
    [sym_var_keyword] = ACTIONS(2843),
    [sym_local_keyword] = ACTIONS(2843),
    [sym_internal_keyword] = ACTIONS(2843),
    [sym_protected_keyword] = ACTIONS(2843),
    [sym_event_keyword] = ACTIONS(2843),
    [sym_fields_keyword] = ACTIONS(2843),
    [sym_keys_keyword] = ACTIONS(2843),
    [sym_key_keyword] = ACTIONS(2843),
    [sym_fieldgroups_keyword] = ACTIONS(2843),
    [sym_actions_keyword] = ACTIONS(2843),
    [sym_layout_keyword] = ACTIONS(2843),
    [sym_area_keyword] = ACTIONS(2843),
    [sym_group_keyword] = ACTIONS(2843),
    [sym_repeater_keyword] = ACTIONS(2843),
    [sym_cuegroup_keyword] = ACTIONS(2843),
    [sym_fixed_keyword] = ACTIONS(2843),
    [sym_grid_keyword] = ACTIONS(2843),
    [sym_part_keyword] = ACTIONS(2843),
    [sym_systempart_keyword] = ACTIONS(2843),
    [sym_usercontrol_keyword] = ACTIONS(2843),
    [sym_dataset_keyword] = ACTIONS(2843),
    [sym_elements_keyword] = ACTIONS(2843),
    [sym_dataitem_keyword] = ACTIONS(2843),
    [sym_column_keyword] = ACTIONS(2843),
    [sym_filter_keyword] = ACTIONS(2843),
    [sym_labels_keyword] = ACTIONS(2843),
    [sym_rendering_keyword] = ACTIONS(2843),
    [sym_requestpage_keyword] = ACTIONS(2843),
    [sym_schema_keyword] = ACTIONS(2843),
    [sym_views_keyword] = ACTIONS(2843),
    [sym_quoted_identifier] = ACTIONS(2841),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2841),
    [sym_preproc_open] = ACTIONS(2841),
    [sym_preproc_close] = ACTIONS(2841),
    [sym_var_attribute_open] = ACTIONS(2841),
  },
  [STATE(2974)] = {
    [sym_boolean] = STATE(1052),
    [sym_assignment_expression] = STATE(1052),
    [sym__expression] = STATE(1052),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1052),
    [sym_multiplicative_expression] = STATE(1052),
    [sym_additive_expression] = STATE(1052),
    [sym_comparison_expression] = STATE(1052),
    [sym_logical_expression] = STATE(1052),
    [sym_ternary_expression] = STATE(1052),
    [sym_unary_expression] = STATE(1052),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1052),
    [sym_list_literal] = STATE(1052),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1052),
    [sym__literal_value] = STATE(1052),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7595),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7597),
    [sym_date_literal] = ACTIONS(7595),
    [sym_time_literal] = ACTIONS(7595),
    [sym_biginteger_literal] = ACTIONS(7597),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7597),
    [sym_integer] = ACTIONS(7595),
    [sym_continue_as_identifier] = ACTIONS(7597),
  },
  [STATE(2975)] = {
    [sym_boolean] = STATE(6019),
    [sym_assignment_expression] = STATE(6019),
    [sym__expression] = STATE(6019),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6019),
    [sym_multiplicative_expression] = STATE(6019),
    [sym_additive_expression] = STATE(6019),
    [sym_comparison_expression] = STATE(6019),
    [sym_logical_expression] = STATE(6019),
    [sym_ternary_expression] = STATE(6019),
    [sym_unary_expression] = STATE(6019),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6019),
    [sym_list_literal] = STATE(6019),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6019),
    [sym__literal_value] = STATE(6019),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7599),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7601),
    [sym_date_literal] = ACTIONS(7599),
    [sym_time_literal] = ACTIONS(7599),
    [sym_biginteger_literal] = ACTIONS(7601),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7601),
    [sym_integer] = ACTIONS(7599),
    [sym_continue_as_identifier] = ACTIONS(7601),
  },
  [STATE(2976)] = {
    [sym_boolean] = STATE(2079),
    [sym_assignment_expression] = STATE(2079),
    [sym__expression] = STATE(2079),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2079),
    [sym_multiplicative_expression] = STATE(2079),
    [sym_additive_expression] = STATE(2079),
    [sym_comparison_expression] = STATE(2079),
    [sym_logical_expression] = STATE(2079),
    [sym_ternary_expression] = STATE(2079),
    [sym_unary_expression] = STATE(2079),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2079),
    [sym_list_literal] = STATE(2079),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2079),
    [sym__literal_value] = STATE(2079),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7603),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7605),
    [sym_date_literal] = ACTIONS(7603),
    [sym_time_literal] = ACTIONS(7603),
    [sym_biginteger_literal] = ACTIONS(7605),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7605),
    [sym_integer] = ACTIONS(7603),
    [sym_continue_as_identifier] = ACTIONS(7605),
  },
  [STATE(2977)] = {
    [sym_boolean] = STATE(6020),
    [sym_assignment_expression] = STATE(6020),
    [sym__expression] = STATE(6020),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6020),
    [sym_multiplicative_expression] = STATE(6020),
    [sym_additive_expression] = STATE(6020),
    [sym_comparison_expression] = STATE(6020),
    [sym_logical_expression] = STATE(6020),
    [sym_ternary_expression] = STATE(6020),
    [sym_unary_expression] = STATE(6020),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6020),
    [sym_list_literal] = STATE(6020),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6020),
    [sym__literal_value] = STATE(6020),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7607),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7609),
    [sym_date_literal] = ACTIONS(7607),
    [sym_time_literal] = ACTIONS(7607),
    [sym_biginteger_literal] = ACTIONS(7609),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7609),
    [sym_integer] = ACTIONS(7607),
    [sym_continue_as_identifier] = ACTIONS(7609),
  },
  [STATE(2978)] = {
    [sym_boolean] = STATE(1053),
    [sym_assignment_expression] = STATE(1053),
    [sym__expression] = STATE(1053),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1053),
    [sym_multiplicative_expression] = STATE(1053),
    [sym_additive_expression] = STATE(1053),
    [sym_comparison_expression] = STATE(1053),
    [sym_logical_expression] = STATE(1053),
    [sym_ternary_expression] = STATE(1053),
    [sym_unary_expression] = STATE(1053),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1053),
    [sym_list_literal] = STATE(1053),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1053),
    [sym__literal_value] = STATE(1053),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7611),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7613),
    [sym_date_literal] = ACTIONS(7611),
    [sym_time_literal] = ACTIONS(7611),
    [sym_biginteger_literal] = ACTIONS(7613),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7613),
    [sym_integer] = ACTIONS(7611),
    [sym_continue_as_identifier] = ACTIONS(7613),
  },
  [STATE(2979)] = {
    [sym_identifier] = ACTIONS(7615),
    [anon_sym_SEMI] = ACTIONS(7617),
    [aux_sym_where_condition_token1] = ACTIONS(7615),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7615),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7615),
    [anon_sym_LBRACK] = ACTIONS(7617),
    [aux_sym_basic_type_token6] = ACTIONS(7615),
    [aux_sym_basic_type_token22] = ACTIONS(7615),
    [aux_sym_basic_type_token53] = ACTIONS(7615),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7615),
    [aux_sym_addafter_modification_token1] = ACTIONS(7615),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7615),
    [aux_sym_modify_modification_token1] = ACTIONS(7615),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7615),
    [aux_sym_movelast_modification_token1] = ACTIONS(7615),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7615),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7615),
    [aux_sym_separator_action_token1] = ACTIONS(7615),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7615),
    [aux_sym_type_declaration_token1] = ACTIONS(7615),
    [anon_sym_POUNDif] = ACTIONS(7617),
    [anon_sym_POUNDIF] = ACTIONS(7617),
    [anon_sym_POUNDIf] = ACTIONS(7617),
    [anon_sym_POUNDelif] = ACTIONS(7617),
    [anon_sym_POUNDELIF] = ACTIONS(7617),
    [anon_sym_POUNDElif] = ACTIONS(7617),
    [anon_sym_POUNDelse] = ACTIONS(7617),
    [anon_sym_POUNDELSE] = ACTIONS(7617),
    [anon_sym_POUNDElse] = ACTIONS(7617),
    [anon_sym_POUNDendif] = ACTIONS(7617),
    [anon_sym_POUNDENDIF] = ACTIONS(7617),
    [anon_sym_POUNDEndif] = ACTIONS(7617),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7615),
    [sym_trigger_keyword] = ACTIONS(7615),
    [sym_var_keyword] = ACTIONS(7615),
    [sym_local_keyword] = ACTIONS(7615),
    [sym_internal_keyword] = ACTIONS(7615),
    [sym_protected_keyword] = ACTIONS(7615),
    [sym_event_keyword] = ACTIONS(7615),
    [sym_fields_keyword] = ACTIONS(7615),
    [sym_keys_keyword] = ACTIONS(7615),
    [sym_key_keyword] = ACTIONS(7615),
    [sym_fieldgroups_keyword] = ACTIONS(7615),
    [sym_actions_keyword] = ACTIONS(7615),
    [sym_layout_keyword] = ACTIONS(7615),
    [sym_area_keyword] = ACTIONS(7615),
    [sym_group_keyword] = ACTIONS(7615),
    [sym_repeater_keyword] = ACTIONS(7615),
    [sym_cuegroup_keyword] = ACTIONS(7615),
    [sym_fixed_keyword] = ACTIONS(7615),
    [sym_grid_keyword] = ACTIONS(7615),
    [sym_part_keyword] = ACTIONS(7615),
    [sym_systempart_keyword] = ACTIONS(7615),
    [sym_usercontrol_keyword] = ACTIONS(7615),
    [sym_dataset_keyword] = ACTIONS(7615),
    [sym_elements_keyword] = ACTIONS(7615),
    [sym_dataitem_keyword] = ACTIONS(7615),
    [sym_column_keyword] = ACTIONS(7615),
    [sym_filter_keyword] = ACTIONS(7615),
    [sym_labels_keyword] = ACTIONS(7615),
    [sym_rendering_keyword] = ACTIONS(7615),
    [sym_requestpage_keyword] = ACTIONS(7615),
    [sym_schema_keyword] = ACTIONS(7615),
    [sym_views_keyword] = ACTIONS(7615),
    [sym_quoted_identifier] = ACTIONS(7617),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7617),
    [sym_preproc_open] = ACTIONS(7617),
    [sym_preproc_close] = ACTIONS(7617),
    [sym_var_attribute_open] = ACTIONS(7617),
  },
  [STATE(2980)] = {
    [sym_identifier] = ACTIONS(7615),
    [anon_sym_SEMI] = ACTIONS(7617),
    [aux_sym_where_condition_token1] = ACTIONS(7615),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7615),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7615),
    [anon_sym_LBRACK] = ACTIONS(7617),
    [aux_sym_basic_type_token6] = ACTIONS(7615),
    [aux_sym_basic_type_token22] = ACTIONS(7615),
    [aux_sym_basic_type_token53] = ACTIONS(7615),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7615),
    [aux_sym_addafter_modification_token1] = ACTIONS(7615),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7615),
    [aux_sym_modify_modification_token1] = ACTIONS(7615),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7615),
    [aux_sym_movelast_modification_token1] = ACTIONS(7615),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7615),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7615),
    [aux_sym_separator_action_token1] = ACTIONS(7615),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7615),
    [aux_sym_type_declaration_token1] = ACTIONS(7615),
    [anon_sym_POUNDif] = ACTIONS(7617),
    [anon_sym_POUNDIF] = ACTIONS(7617),
    [anon_sym_POUNDIf] = ACTIONS(7617),
    [anon_sym_POUNDelif] = ACTIONS(7617),
    [anon_sym_POUNDELIF] = ACTIONS(7617),
    [anon_sym_POUNDElif] = ACTIONS(7617),
    [anon_sym_POUNDelse] = ACTIONS(7617),
    [anon_sym_POUNDELSE] = ACTIONS(7617),
    [anon_sym_POUNDElse] = ACTIONS(7617),
    [anon_sym_POUNDendif] = ACTIONS(7617),
    [anon_sym_POUNDENDIF] = ACTIONS(7617),
    [anon_sym_POUNDEndif] = ACTIONS(7617),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7615),
    [sym_trigger_keyword] = ACTIONS(7615),
    [sym_var_keyword] = ACTIONS(7615),
    [sym_local_keyword] = ACTIONS(7615),
    [sym_internal_keyword] = ACTIONS(7615),
    [sym_protected_keyword] = ACTIONS(7615),
    [sym_event_keyword] = ACTIONS(7615),
    [sym_fields_keyword] = ACTIONS(7615),
    [sym_keys_keyword] = ACTIONS(7615),
    [sym_key_keyword] = ACTIONS(7615),
    [sym_fieldgroups_keyword] = ACTIONS(7615),
    [sym_actions_keyword] = ACTIONS(7615),
    [sym_layout_keyword] = ACTIONS(7615),
    [sym_area_keyword] = ACTIONS(7615),
    [sym_group_keyword] = ACTIONS(7615),
    [sym_repeater_keyword] = ACTIONS(7615),
    [sym_cuegroup_keyword] = ACTIONS(7615),
    [sym_fixed_keyword] = ACTIONS(7615),
    [sym_grid_keyword] = ACTIONS(7615),
    [sym_part_keyword] = ACTIONS(7615),
    [sym_systempart_keyword] = ACTIONS(7615),
    [sym_usercontrol_keyword] = ACTIONS(7615),
    [sym_dataset_keyword] = ACTIONS(7615),
    [sym_elements_keyword] = ACTIONS(7615),
    [sym_dataitem_keyword] = ACTIONS(7615),
    [sym_column_keyword] = ACTIONS(7615),
    [sym_filter_keyword] = ACTIONS(7615),
    [sym_labels_keyword] = ACTIONS(7615),
    [sym_rendering_keyword] = ACTIONS(7615),
    [sym_requestpage_keyword] = ACTIONS(7615),
    [sym_schema_keyword] = ACTIONS(7615),
    [sym_views_keyword] = ACTIONS(7615),
    [sym_quoted_identifier] = ACTIONS(7617),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7617),
    [sym_preproc_open] = ACTIONS(7617),
    [sym_preproc_close] = ACTIONS(7617),
    [sym_var_attribute_open] = ACTIONS(7617),
  },
  [STATE(2981)] = {
    [sym_boolean] = STATE(1054),
    [sym_assignment_expression] = STATE(1054),
    [sym__expression] = STATE(1054),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1054),
    [sym_multiplicative_expression] = STATE(1054),
    [sym_additive_expression] = STATE(1054),
    [sym_comparison_expression] = STATE(1054),
    [sym_logical_expression] = STATE(1054),
    [sym_ternary_expression] = STATE(1054),
    [sym_unary_expression] = STATE(1054),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1054),
    [sym_list_literal] = STATE(1054),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1054),
    [sym__literal_value] = STATE(1054),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7619),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7621),
    [sym_date_literal] = ACTIONS(7619),
    [sym_time_literal] = ACTIONS(7619),
    [sym_biginteger_literal] = ACTIONS(7621),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7621),
    [sym_integer] = ACTIONS(7619),
    [sym_continue_as_identifier] = ACTIONS(7621),
  },
  [STATE(2982)] = {
    [sym_boolean] = STATE(1055),
    [sym_assignment_expression] = STATE(1055),
    [sym__expression] = STATE(1055),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1055),
    [sym_multiplicative_expression] = STATE(1055),
    [sym_additive_expression] = STATE(1055),
    [sym_comparison_expression] = STATE(1055),
    [sym_logical_expression] = STATE(1055),
    [sym_ternary_expression] = STATE(1055),
    [sym_unary_expression] = STATE(1055),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1055),
    [sym_list_literal] = STATE(1055),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1055),
    [sym__literal_value] = STATE(1055),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7623),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7625),
    [sym_date_literal] = ACTIONS(7623),
    [sym_time_literal] = ACTIONS(7623),
    [sym_biginteger_literal] = ACTIONS(7625),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7625),
    [sym_integer] = ACTIONS(7623),
    [sym_continue_as_identifier] = ACTIONS(7625),
  },
  [STATE(2983)] = {
    [sym_boolean] = STATE(1056),
    [sym_assignment_expression] = STATE(1056),
    [sym__expression] = STATE(1056),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1056),
    [sym_multiplicative_expression] = STATE(1056),
    [sym_additive_expression] = STATE(1056),
    [sym_comparison_expression] = STATE(1056),
    [sym_logical_expression] = STATE(1056),
    [sym_ternary_expression] = STATE(1056),
    [sym_unary_expression] = STATE(1056),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1056),
    [sym_list_literal] = STATE(1056),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1056),
    [sym__literal_value] = STATE(1056),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7627),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7629),
    [sym_date_literal] = ACTIONS(7627),
    [sym_time_literal] = ACTIONS(7627),
    [sym_biginteger_literal] = ACTIONS(7629),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7629),
    [sym_integer] = ACTIONS(7627),
    [sym_continue_as_identifier] = ACTIONS(7629),
  },
  [STATE(2984)] = {
    [sym_boolean] = STATE(2080),
    [sym_assignment_expression] = STATE(2080),
    [sym__expression] = STATE(2080),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2080),
    [sym_multiplicative_expression] = STATE(2080),
    [sym_additive_expression] = STATE(2080),
    [sym_comparison_expression] = STATE(2080),
    [sym_logical_expression] = STATE(2080),
    [sym_ternary_expression] = STATE(2080),
    [sym_unary_expression] = STATE(2080),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2080),
    [sym_list_literal] = STATE(2080),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2080),
    [sym__literal_value] = STATE(2080),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7631),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7633),
    [sym_date_literal] = ACTIONS(7631),
    [sym_time_literal] = ACTIONS(7631),
    [sym_biginteger_literal] = ACTIONS(7633),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7633),
    [sym_integer] = ACTIONS(7631),
    [sym_continue_as_identifier] = ACTIONS(7633),
  },
  [STATE(2985)] = {
    [sym_boolean] = STATE(1057),
    [sym_assignment_expression] = STATE(1057),
    [sym__expression] = STATE(1057),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1057),
    [sym_multiplicative_expression] = STATE(1057),
    [sym_additive_expression] = STATE(1057),
    [sym_comparison_expression] = STATE(1057),
    [sym_logical_expression] = STATE(1057),
    [sym_ternary_expression] = STATE(1057),
    [sym_unary_expression] = STATE(1057),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_list_literal] = STATE(1057),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1057),
    [sym__literal_value] = STATE(1057),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7635),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7637),
    [sym_date_literal] = ACTIONS(7635),
    [sym_time_literal] = ACTIONS(7635),
    [sym_biginteger_literal] = ACTIONS(7637),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7637),
    [sym_integer] = ACTIONS(7635),
    [sym_continue_as_identifier] = ACTIONS(7637),
  },
  [STATE(2986)] = {
    [sym_boolean] = STATE(2081),
    [sym_assignment_expression] = STATE(2081),
    [sym__expression] = STATE(2081),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2081),
    [sym_multiplicative_expression] = STATE(2081),
    [sym_additive_expression] = STATE(2081),
    [sym_comparison_expression] = STATE(2081),
    [sym_logical_expression] = STATE(2081),
    [sym_ternary_expression] = STATE(2081),
    [sym_unary_expression] = STATE(2081),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2081),
    [sym_list_literal] = STATE(2081),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2081),
    [sym__literal_value] = STATE(2081),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7639),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7641),
    [sym_date_literal] = ACTIONS(7639),
    [sym_time_literal] = ACTIONS(7639),
    [sym_biginteger_literal] = ACTIONS(7641),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7641),
    [sym_integer] = ACTIONS(7639),
    [sym_continue_as_identifier] = ACTIONS(7641),
  },
  [STATE(2987)] = {
    [sym_boolean] = STATE(1401),
    [sym_assignment_expression] = STATE(1401),
    [sym__expression] = STATE(1401),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1401),
    [sym_multiplicative_expression] = STATE(1401),
    [sym_additive_expression] = STATE(1401),
    [sym_comparison_expression] = STATE(1401),
    [sym_logical_expression] = STATE(1401),
    [sym_ternary_expression] = STATE(1401),
    [sym_unary_expression] = STATE(1401),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1401),
    [sym_list_literal] = STATE(1401),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1401),
    [sym__literal_value] = STATE(1401),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7643),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7645),
    [sym_date_literal] = ACTIONS(7643),
    [sym_time_literal] = ACTIONS(7643),
    [sym_biginteger_literal] = ACTIONS(7645),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7645),
    [sym_integer] = ACTIONS(7643),
    [sym_continue_as_identifier] = ACTIONS(7645),
  },
  [STATE(2988)] = {
    [sym_boolean] = STATE(1402),
    [sym_assignment_expression] = STATE(1402),
    [sym__expression] = STATE(1402),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1402),
    [sym_multiplicative_expression] = STATE(1402),
    [sym_additive_expression] = STATE(1402),
    [sym_comparison_expression] = STATE(1402),
    [sym_logical_expression] = STATE(1402),
    [sym_ternary_expression] = STATE(1402),
    [sym_unary_expression] = STATE(1402),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1402),
    [sym_list_literal] = STATE(1402),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1402),
    [sym__literal_value] = STATE(1402),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7647),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7649),
    [sym_date_literal] = ACTIONS(7647),
    [sym_time_literal] = ACTIONS(7647),
    [sym_biginteger_literal] = ACTIONS(7649),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7649),
    [sym_integer] = ACTIONS(7647),
    [sym_continue_as_identifier] = ACTIONS(7649),
  },
  [STATE(2989)] = {
    [sym_boolean] = STATE(1403),
    [sym_assignment_expression] = STATE(1403),
    [sym__expression] = STATE(1403),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1403),
    [sym_multiplicative_expression] = STATE(1403),
    [sym_additive_expression] = STATE(1403),
    [sym_comparison_expression] = STATE(1403),
    [sym_logical_expression] = STATE(1403),
    [sym_ternary_expression] = STATE(1403),
    [sym_unary_expression] = STATE(1403),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1403),
    [sym_list_literal] = STATE(1403),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1403),
    [sym__literal_value] = STATE(1403),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7651),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7653),
    [sym_date_literal] = ACTIONS(7651),
    [sym_time_literal] = ACTIONS(7651),
    [sym_biginteger_literal] = ACTIONS(7653),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7653),
    [sym_integer] = ACTIONS(7651),
    [sym_continue_as_identifier] = ACTIONS(7653),
  },
  [STATE(2990)] = {
    [sym_boolean] = STATE(1405),
    [sym_assignment_expression] = STATE(1405),
    [sym__expression] = STATE(1405),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1405),
    [sym_multiplicative_expression] = STATE(1405),
    [sym_additive_expression] = STATE(1405),
    [sym_comparison_expression] = STATE(1405),
    [sym_logical_expression] = STATE(1405),
    [sym_ternary_expression] = STATE(1405),
    [sym_unary_expression] = STATE(1405),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1405),
    [sym_list_literal] = STATE(1405),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1405),
    [sym__literal_value] = STATE(1405),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7655),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7657),
    [sym_date_literal] = ACTIONS(7655),
    [sym_time_literal] = ACTIONS(7655),
    [sym_biginteger_literal] = ACTIONS(7657),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7657),
    [sym_integer] = ACTIONS(7655),
    [sym_continue_as_identifier] = ACTIONS(7657),
  },
  [STATE(2991)] = {
    [sym_boolean] = STATE(1406),
    [sym_assignment_expression] = STATE(1406),
    [sym__expression] = STATE(1406),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1406),
    [sym_multiplicative_expression] = STATE(1406),
    [sym_additive_expression] = STATE(1406),
    [sym_comparison_expression] = STATE(1406),
    [sym_logical_expression] = STATE(1406),
    [sym_ternary_expression] = STATE(1406),
    [sym_unary_expression] = STATE(1406),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1406),
    [sym_list_literal] = STATE(1406),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1406),
    [sym__literal_value] = STATE(1406),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7659),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7661),
    [sym_date_literal] = ACTIONS(7659),
    [sym_time_literal] = ACTIONS(7659),
    [sym_biginteger_literal] = ACTIONS(7661),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7661),
    [sym_integer] = ACTIONS(7659),
    [sym_continue_as_identifier] = ACTIONS(7661),
  },
  [STATE(2992)] = {
    [sym_boolean] = STATE(1407),
    [sym_assignment_expression] = STATE(1407),
    [sym__expression] = STATE(1407),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1407),
    [sym_multiplicative_expression] = STATE(1407),
    [sym_additive_expression] = STATE(1407),
    [sym_comparison_expression] = STATE(1407),
    [sym_logical_expression] = STATE(1407),
    [sym_ternary_expression] = STATE(1407),
    [sym_unary_expression] = STATE(1407),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1407),
    [sym_list_literal] = STATE(1407),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1407),
    [sym__literal_value] = STATE(1407),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7663),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7665),
    [sym_date_literal] = ACTIONS(7663),
    [sym_time_literal] = ACTIONS(7663),
    [sym_biginteger_literal] = ACTIONS(7665),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7665),
    [sym_integer] = ACTIONS(7663),
    [sym_continue_as_identifier] = ACTIONS(7665),
  },
  [STATE(2993)] = {
    [sym_boolean] = STATE(1408),
    [sym_assignment_expression] = STATE(1408),
    [sym__expression] = STATE(1408),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1408),
    [sym_multiplicative_expression] = STATE(1408),
    [sym_additive_expression] = STATE(1408),
    [sym_comparison_expression] = STATE(1408),
    [sym_logical_expression] = STATE(1408),
    [sym_ternary_expression] = STATE(1408),
    [sym_unary_expression] = STATE(1408),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1408),
    [sym_list_literal] = STATE(1408),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1408),
    [sym__literal_value] = STATE(1408),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7667),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7669),
    [sym_date_literal] = ACTIONS(7667),
    [sym_time_literal] = ACTIONS(7667),
    [sym_biginteger_literal] = ACTIONS(7669),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7669),
    [sym_integer] = ACTIONS(7667),
    [sym_continue_as_identifier] = ACTIONS(7669),
  },
  [STATE(2994)] = {
    [sym_boolean] = STATE(1409),
    [sym_assignment_expression] = STATE(1409),
    [sym__expression] = STATE(1409),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1409),
    [sym_multiplicative_expression] = STATE(1409),
    [sym_additive_expression] = STATE(1409),
    [sym_comparison_expression] = STATE(1409),
    [sym_logical_expression] = STATE(1409),
    [sym_ternary_expression] = STATE(1409),
    [sym_unary_expression] = STATE(1409),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1409),
    [sym_list_literal] = STATE(1409),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1409),
    [sym__literal_value] = STATE(1409),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7671),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7673),
    [sym_date_literal] = ACTIONS(7671),
    [sym_time_literal] = ACTIONS(7671),
    [sym_biginteger_literal] = ACTIONS(7673),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7673),
    [sym_integer] = ACTIONS(7671),
    [sym_continue_as_identifier] = ACTIONS(7673),
  },
  [STATE(2995)] = {
    [sym_boolean] = STATE(1058),
    [sym_assignment_expression] = STATE(1058),
    [sym__expression] = STATE(1058),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1058),
    [sym_multiplicative_expression] = STATE(1058),
    [sym_additive_expression] = STATE(1058),
    [sym_comparison_expression] = STATE(1058),
    [sym_logical_expression] = STATE(1058),
    [sym_ternary_expression] = STATE(1058),
    [sym_unary_expression] = STATE(1058),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1058),
    [sym_list_literal] = STATE(1058),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1058),
    [sym__literal_value] = STATE(1058),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7675),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7677),
    [sym_date_literal] = ACTIONS(7675),
    [sym_time_literal] = ACTIONS(7675),
    [sym_biginteger_literal] = ACTIONS(7677),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7677),
    [sym_integer] = ACTIONS(7675),
    [sym_continue_as_identifier] = ACTIONS(7677),
  },
  [STATE(2996)] = {
    [sym_boolean] = STATE(2082),
    [sym_assignment_expression] = STATE(2082),
    [sym__expression] = STATE(2082),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2082),
    [sym_multiplicative_expression] = STATE(2082),
    [sym_additive_expression] = STATE(2082),
    [sym_comparison_expression] = STATE(2082),
    [sym_logical_expression] = STATE(2082),
    [sym_ternary_expression] = STATE(2082),
    [sym_unary_expression] = STATE(2082),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2082),
    [sym_list_literal] = STATE(2082),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2082),
    [sym__literal_value] = STATE(2082),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7679),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7681),
    [sym_date_literal] = ACTIONS(7679),
    [sym_time_literal] = ACTIONS(7679),
    [sym_biginteger_literal] = ACTIONS(7681),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7681),
    [sym_integer] = ACTIONS(7679),
    [sym_continue_as_identifier] = ACTIONS(7681),
  },
  [STATE(2997)] = {
    [sym_boolean] = STATE(1410),
    [sym_assignment_expression] = STATE(1410),
    [sym__expression] = STATE(1410),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1410),
    [sym_multiplicative_expression] = STATE(1410),
    [sym_additive_expression] = STATE(1410),
    [sym_comparison_expression] = STATE(1410),
    [sym_logical_expression] = STATE(1410),
    [sym_ternary_expression] = STATE(1410),
    [sym_unary_expression] = STATE(1410),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_list_literal] = STATE(1410),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1410),
    [sym__literal_value] = STATE(1410),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7683),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7685),
    [sym_date_literal] = ACTIONS(7683),
    [sym_time_literal] = ACTIONS(7683),
    [sym_biginteger_literal] = ACTIONS(7685),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7685),
    [sym_integer] = ACTIONS(7683),
    [sym_continue_as_identifier] = ACTIONS(7685),
  },
  [STATE(2998)] = {
    [sym_boolean] = STATE(1411),
    [sym_assignment_expression] = STATE(1411),
    [sym__expression] = STATE(1411),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1411),
    [sym_multiplicative_expression] = STATE(1411),
    [sym_additive_expression] = STATE(1411),
    [sym_comparison_expression] = STATE(1411),
    [sym_logical_expression] = STATE(1411),
    [sym_ternary_expression] = STATE(1411),
    [sym_unary_expression] = STATE(1411),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1411),
    [sym_list_literal] = STATE(1411),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1411),
    [sym__literal_value] = STATE(1411),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7687),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7689),
    [sym_date_literal] = ACTIONS(7687),
    [sym_time_literal] = ACTIONS(7687),
    [sym_biginteger_literal] = ACTIONS(7689),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7689),
    [sym_integer] = ACTIONS(7687),
    [sym_continue_as_identifier] = ACTIONS(7689),
  },
  [STATE(2999)] = {
    [sym_boolean] = STATE(6152),
    [sym_assignment_expression] = STATE(6152),
    [sym__expression] = STATE(6152),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6152),
    [sym_multiplicative_expression] = STATE(6152),
    [sym_additive_expression] = STATE(6152),
    [sym_comparison_expression] = STATE(6152),
    [sym_logical_expression] = STATE(6152),
    [sym_ternary_expression] = STATE(6152),
    [sym_unary_expression] = STATE(6152),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6152),
    [sym_list_literal] = STATE(6152),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6152),
    [sym__literal_value] = STATE(6152),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7691),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7693),
    [sym_date_literal] = ACTIONS(7691),
    [sym_time_literal] = ACTIONS(7691),
    [sym_biginteger_literal] = ACTIONS(7693),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7693),
    [sym_integer] = ACTIONS(7691),
    [sym_continue_as_identifier] = ACTIONS(7693),
  },
  [STATE(3000)] = {
    [sym_boolean] = STATE(1412),
    [sym_assignment_expression] = STATE(1412),
    [sym__expression] = STATE(1412),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1412),
    [sym_multiplicative_expression] = STATE(1412),
    [sym_additive_expression] = STATE(1412),
    [sym_comparison_expression] = STATE(1412),
    [sym_logical_expression] = STATE(1412),
    [sym_ternary_expression] = STATE(1412),
    [sym_unary_expression] = STATE(1412),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1412),
    [sym_list_literal] = STATE(1412),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1412),
    [sym__literal_value] = STATE(1412),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7695),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7697),
    [sym_date_literal] = ACTIONS(7695),
    [sym_time_literal] = ACTIONS(7695),
    [sym_biginteger_literal] = ACTIONS(7697),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7697),
    [sym_integer] = ACTIONS(7695),
    [sym_continue_as_identifier] = ACTIONS(7697),
  },
  [STATE(3001)] = {
    [sym_boolean] = STATE(2083),
    [sym_assignment_expression] = STATE(2083),
    [sym__expression] = STATE(2083),
    [sym_keyword_identifier] = STATE(2047),
    [sym_range_expression] = STATE(2083),
    [sym_multiplicative_expression] = STATE(2083),
    [sym_additive_expression] = STATE(2083),
    [sym_comparison_expression] = STATE(2083),
    [sym_logical_expression] = STATE(2083),
    [sym_ternary_expression] = STATE(2083),
    [sym_unary_expression] = STATE(2083),
    [sym_call_expression] = STATE(2115),
    [sym_member_expression] = STATE(2047),
    [sym_subscript_expression] = STATE(2047),
    [sym_parenthesized_expression] = STATE(2083),
    [sym_list_literal] = STATE(2083),
    [sym_qualified_enum_value] = STATE(2047),
    [sym_database_reference] = STATE(2083),
    [sym__literal_value] = STATE(2083),
    [sym_codeunit_keyword] = STATE(2134),
    [sym_xmlport_keyword] = STATE(2134),
    [sym_enum_keyword] = STATE(2098),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(604),
    [aux_sym_boolean_token1] = ACTIONS(606),
    [aux_sym_boolean_token2] = ACTIONS(606),
    [sym_decimal] = ACTIONS(7699),
    [anon_sym_LPAREN] = ACTIONS(610),
    [aux_sym_tabledata_permission_token2] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(614),
    [aux_sym_record_type_token1] = ACTIONS(612),
    [aux_sym_basic_type_token21] = ACTIONS(612),
    [aux_sym_basic_type_token22] = ACTIONS(612),
    [aux_sym_basic_type_token48] = ACTIONS(612),
    [anon_sym_not] = ACTIONS(616),
    [anon_sym_NOT] = ACTIONS(616),
    [anon_sym_Not] = ACTIONS(616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(612),
    [aux_sym_keyword_identifier_token2] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(604),
    [sym_datetime_literal] = ACTIONS(7701),
    [sym_date_literal] = ACTIONS(7699),
    [sym_time_literal] = ACTIONS(7699),
    [sym_biginteger_literal] = ACTIONS(7701),
    [sym_page_keyword] = ACTIONS(618),
    [anon_sym_codeunit] = ACTIONS(624),
    [anon_sym_CODEUNIT] = ACTIONS(624),
    [anon_sym_Codeunit] = ACTIONS(624),
    [anon_sym_CodeUnit] = ACTIONS(624),
    [anon_sym_COdeunit] = ACTIONS(624),
    [anon_sym_codeUnit] = ACTIONS(624),
    [sym_report_keyword] = ACTIONS(618),
    [sym_query_keyword] = ACTIONS(618),
    [anon_sym_xmlport] = ACTIONS(626),
    [anon_sym_XMLPORT] = ACTIONS(626),
    [anon_sym_Xmlport] = ACTIONS(626),
    [anon_sym_XMLport] = ACTIONS(626),
    [anon_sym_XMLPort] = ACTIONS(626),
    [anon_sym_XmlPort] = ACTIONS(626),
    [anon_sym_enum] = ACTIONS(628),
    [anon_sym_ENUM] = ACTIONS(628),
    [anon_sym_Enum] = ACTIONS(628),
    [anon_sym_eNUM] = ACTIONS(628),
    [anon_sym_eNum] = ACTIONS(628),
    [anon_sym_ENum] = ACTIONS(628),
    [sym_quoted_identifier] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7701),
    [sym_integer] = ACTIONS(7699),
    [sym_continue_as_identifier] = ACTIONS(7701),
  },
  [STATE(3002)] = {
    [sym_boolean] = STATE(1413),
    [sym_assignment_expression] = STATE(1413),
    [sym__expression] = STATE(1413),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1413),
    [sym_multiplicative_expression] = STATE(1413),
    [sym_additive_expression] = STATE(1413),
    [sym_comparison_expression] = STATE(1413),
    [sym_logical_expression] = STATE(1413),
    [sym_ternary_expression] = STATE(1413),
    [sym_unary_expression] = STATE(1413),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1413),
    [sym_list_literal] = STATE(1413),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1413),
    [sym__literal_value] = STATE(1413),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7703),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7705),
    [sym_date_literal] = ACTIONS(7703),
    [sym_time_literal] = ACTIONS(7703),
    [sym_biginteger_literal] = ACTIONS(7705),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7705),
    [sym_integer] = ACTIONS(7703),
    [sym_continue_as_identifier] = ACTIONS(7705),
  },
  [STATE(3003)] = {
    [sym_boolean] = STATE(1190),
    [sym_assignment_expression] = STATE(1190),
    [sym__expression] = STATE(1190),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1190),
    [sym_multiplicative_expression] = STATE(1190),
    [sym_additive_expression] = STATE(1190),
    [sym_comparison_expression] = STATE(1190),
    [sym_logical_expression] = STATE(1190),
    [sym_ternary_expression] = STATE(1190),
    [sym_unary_expression] = STATE(1190),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1190),
    [sym_list_literal] = STATE(1190),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1190),
    [sym__literal_value] = STATE(1190),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7707),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7709),
    [sym_date_literal] = ACTIONS(7707),
    [sym_time_literal] = ACTIONS(7707),
    [sym_biginteger_literal] = ACTIONS(7709),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7709),
    [sym_integer] = ACTIONS(7707),
    [sym_continue_as_identifier] = ACTIONS(7709),
  },
  [STATE(3004)] = {
    [sym_boolean] = STATE(1158),
    [sym_assignment_expression] = STATE(1158),
    [sym__expression] = STATE(1158),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1158),
    [sym_multiplicative_expression] = STATE(1158),
    [sym_additive_expression] = STATE(1158),
    [sym_comparison_expression] = STATE(1158),
    [sym_logical_expression] = STATE(1158),
    [sym_ternary_expression] = STATE(1158),
    [sym_unary_expression] = STATE(1158),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1158),
    [sym_list_literal] = STATE(1158),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1158),
    [sym__literal_value] = STATE(1158),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7711),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7713),
    [sym_date_literal] = ACTIONS(7711),
    [sym_time_literal] = ACTIONS(7711),
    [sym_biginteger_literal] = ACTIONS(7713),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7713),
    [sym_integer] = ACTIONS(7711),
    [sym_continue_as_identifier] = ACTIONS(7713),
  },
  [STATE(3005)] = {
    [sym_boolean] = STATE(6327),
    [sym_assignment_expression] = STATE(6327),
    [sym__expression] = STATE(6327),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6327),
    [sym_multiplicative_expression] = STATE(6327),
    [sym_additive_expression] = STATE(6327),
    [sym_comparison_expression] = STATE(6327),
    [sym_logical_expression] = STATE(6327),
    [sym_ternary_expression] = STATE(6327),
    [sym_unary_expression] = STATE(6327),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6327),
    [sym_list_literal] = STATE(6327),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6327),
    [sym__literal_value] = STATE(6327),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7715),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7717),
    [sym_date_literal] = ACTIONS(7715),
    [sym_time_literal] = ACTIONS(7715),
    [sym_biginteger_literal] = ACTIONS(7717),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7717),
    [sym_integer] = ACTIONS(7715),
    [sym_continue_as_identifier] = ACTIONS(7717),
  },
  [STATE(3006)] = {
    [sym_boolean] = STATE(1059),
    [sym_assignment_expression] = STATE(1059),
    [sym__expression] = STATE(1059),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1059),
    [sym_multiplicative_expression] = STATE(1059),
    [sym_additive_expression] = STATE(1059),
    [sym_comparison_expression] = STATE(1059),
    [sym_logical_expression] = STATE(1059),
    [sym_ternary_expression] = STATE(1059),
    [sym_unary_expression] = STATE(1059),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1059),
    [sym_list_literal] = STATE(1059),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1059),
    [sym__literal_value] = STATE(1059),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7719),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7721),
    [sym_date_literal] = ACTIONS(7719),
    [sym_time_literal] = ACTIONS(7719),
    [sym_biginteger_literal] = ACTIONS(7721),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7721),
    [sym_integer] = ACTIONS(7719),
    [sym_continue_as_identifier] = ACTIONS(7721),
  },
  [STATE(3007)] = {
    [sym_boolean] = STATE(6211),
    [sym_assignment_expression] = STATE(6211),
    [sym__expression] = STATE(6211),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6211),
    [sym_multiplicative_expression] = STATE(6211),
    [sym_additive_expression] = STATE(6211),
    [sym_comparison_expression] = STATE(6211),
    [sym_logical_expression] = STATE(6211),
    [sym_ternary_expression] = STATE(6211),
    [sym_unary_expression] = STATE(6211),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6211),
    [sym_list_literal] = STATE(6211),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6211),
    [sym__literal_value] = STATE(6211),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7723),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7725),
    [sym_date_literal] = ACTIONS(7723),
    [sym_time_literal] = ACTIONS(7723),
    [sym_biginteger_literal] = ACTIONS(7725),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7725),
    [sym_integer] = ACTIONS(7723),
    [sym_continue_as_identifier] = ACTIONS(7725),
  },
  [STATE(3008)] = {
    [sym_boolean] = STATE(6312),
    [sym_assignment_expression] = STATE(6312),
    [sym__expression] = STATE(6312),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6312),
    [sym_multiplicative_expression] = STATE(6312),
    [sym_additive_expression] = STATE(6312),
    [sym_comparison_expression] = STATE(6312),
    [sym_logical_expression] = STATE(6312),
    [sym_ternary_expression] = STATE(6312),
    [sym_unary_expression] = STATE(6312),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6312),
    [sym_list_literal] = STATE(6312),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6312),
    [sym__literal_value] = STATE(6312),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7727),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7729),
    [sym_date_literal] = ACTIONS(7727),
    [sym_time_literal] = ACTIONS(7727),
    [sym_biginteger_literal] = ACTIONS(7729),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7729),
    [sym_integer] = ACTIONS(7727),
    [sym_continue_as_identifier] = ACTIONS(7729),
  },
  [STATE(3009)] = {
    [sym_boolean] = STATE(6105),
    [sym_assignment_expression] = STATE(6105),
    [sym__expression] = STATE(6105),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6105),
    [sym_multiplicative_expression] = STATE(6105),
    [sym_additive_expression] = STATE(6105),
    [sym_comparison_expression] = STATE(6105),
    [sym_logical_expression] = STATE(6105),
    [sym_ternary_expression] = STATE(6105),
    [sym_unary_expression] = STATE(6105),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6105),
    [sym_list_literal] = STATE(6105),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6105),
    [sym__literal_value] = STATE(6105),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7731),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7733),
    [sym_date_literal] = ACTIONS(7731),
    [sym_time_literal] = ACTIONS(7731),
    [sym_biginteger_literal] = ACTIONS(7733),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7733),
    [sym_integer] = ACTIONS(7731),
    [sym_continue_as_identifier] = ACTIONS(7733),
  },
  [STATE(3010)] = {
    [sym_boolean] = STATE(6110),
    [sym_assignment_expression] = STATE(6110),
    [sym__expression] = STATE(6110),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6110),
    [sym_multiplicative_expression] = STATE(6110),
    [sym_additive_expression] = STATE(6110),
    [sym_comparison_expression] = STATE(6110),
    [sym_logical_expression] = STATE(6110),
    [sym_ternary_expression] = STATE(6110),
    [sym_unary_expression] = STATE(6110),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6110),
    [sym_list_literal] = STATE(6110),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6110),
    [sym__literal_value] = STATE(6110),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7735),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7737),
    [sym_date_literal] = ACTIONS(7735),
    [sym_time_literal] = ACTIONS(7735),
    [sym_biginteger_literal] = ACTIONS(7737),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7737),
    [sym_integer] = ACTIONS(7735),
    [sym_continue_as_identifier] = ACTIONS(7737),
  },
  [STATE(3011)] = {
    [sym_boolean] = STATE(1060),
    [sym_assignment_expression] = STATE(1060),
    [sym__expression] = STATE(1060),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1060),
    [sym_multiplicative_expression] = STATE(1060),
    [sym_additive_expression] = STATE(1060),
    [sym_comparison_expression] = STATE(1060),
    [sym_logical_expression] = STATE(1060),
    [sym_ternary_expression] = STATE(1060),
    [sym_unary_expression] = STATE(1060),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1060),
    [sym_list_literal] = STATE(1060),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1060),
    [sym__literal_value] = STATE(1060),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7739),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7741),
    [sym_date_literal] = ACTIONS(7739),
    [sym_time_literal] = ACTIONS(7739),
    [sym_biginteger_literal] = ACTIONS(7741),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7741),
    [sym_integer] = ACTIONS(7739),
    [sym_continue_as_identifier] = ACTIONS(7741),
  },
  [STATE(3012)] = {
    [sym_boolean] = STATE(6118),
    [sym_assignment_expression] = STATE(6118),
    [sym__expression] = STATE(6118),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6118),
    [sym_multiplicative_expression] = STATE(6118),
    [sym_additive_expression] = STATE(6118),
    [sym_comparison_expression] = STATE(6118),
    [sym_logical_expression] = STATE(6118),
    [sym_ternary_expression] = STATE(6118),
    [sym_unary_expression] = STATE(6118),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6118),
    [sym_list_literal] = STATE(6118),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6118),
    [sym__literal_value] = STATE(6118),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7743),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7745),
    [sym_date_literal] = ACTIONS(7743),
    [sym_time_literal] = ACTIONS(7743),
    [sym_biginteger_literal] = ACTIONS(7745),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7745),
    [sym_integer] = ACTIONS(7743),
    [sym_continue_as_identifier] = ACTIONS(7745),
  },
  [STATE(3013)] = {
    [sym__body_element] = STATE(6090),
    [sym_empty_statement] = STATE(6090),
    [sym_property] = STATE(6090),
    [sym_fields_section] = STATE(6090),
    [sym_keys_section] = STATE(6090),
    [sym_fieldgroups_section] = STATE(6090),
    [sym_enum_value_declaration] = STATE(6090),
    [sym_labels_section] = STATE(6090),
    [sym_layout_section] = STATE(6090),
    [sym_modify_modification] = STATE(6090),
    [sym_actions_section] = STATE(6090),
    [sym_views_section] = STATE(6090),
    [sym_dataset_section] = STATE(6090),
    [sym_report_dataitem] = STATE(3259),
    [sym__report_body_element] = STATE(3259),
    [sym_preproc_conditional_report] = STATE(3259),
    [sym_report_column] = STATE(3259),
    [sym_requestpage_section] = STATE(6090),
    [sym_rendering_section] = STATE(6090),
    [sym_elements_section] = STATE(6090),
    [sym_schema_section] = STATE(6090),
    [sym_assembly_declaration] = STATE(6090),
    [sym_event_declaration] = STATE(6090),
    [sym_procedure] = STATE(6090),
    [sym_preproc_split_procedure] = STATE(6090),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(6090),
    [sym_var_section] = STATE(6090),
    [sym_attribute_item] = STATE(6090),
    [sym_preproc_conditional] = STATE(6090),
    [sym_preproc_if] = STATE(2557),
    [sym_preproc_endif] = STATE(6017),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3482),
    [aux_sym_report_dataitem_repeat1] = STATE(3259),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3014)] = {
    [sym_boolean] = STATE(1061),
    [sym_assignment_expression] = STATE(1061),
    [sym__expression] = STATE(1061),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1061),
    [sym_multiplicative_expression] = STATE(1061),
    [sym_additive_expression] = STATE(1061),
    [sym_comparison_expression] = STATE(1061),
    [sym_logical_expression] = STATE(1061),
    [sym_ternary_expression] = STATE(1061),
    [sym_unary_expression] = STATE(1061),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1061),
    [sym_list_literal] = STATE(1061),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1061),
    [sym__literal_value] = STATE(1061),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7747),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7749),
    [sym_date_literal] = ACTIONS(7747),
    [sym_time_literal] = ACTIONS(7747),
    [sym_biginteger_literal] = ACTIONS(7749),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7749),
    [sym_integer] = ACTIONS(7747),
    [sym_continue_as_identifier] = ACTIONS(7749),
  },
  [STATE(3015)] = {
    [sym_identifier] = ACTIONS(4399),
    [anon_sym_SEMI] = ACTIONS(4401),
    [aux_sym_where_condition_token1] = ACTIONS(4399),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4399),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4399),
    [anon_sym_LBRACK] = ACTIONS(4401),
    [aux_sym_basic_type_token6] = ACTIONS(4399),
    [aux_sym_basic_type_token22] = ACTIONS(4399),
    [aux_sym_basic_type_token53] = ACTIONS(4399),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4399),
    [aux_sym_addafter_modification_token1] = ACTIONS(4399),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4399),
    [aux_sym_modify_modification_token1] = ACTIONS(4399),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4399),
    [aux_sym_movelast_modification_token1] = ACTIONS(4399),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4399),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4399),
    [aux_sym_separator_action_token1] = ACTIONS(4399),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4399),
    [aux_sym_type_declaration_token1] = ACTIONS(4399),
    [anon_sym_POUNDif] = ACTIONS(4401),
    [anon_sym_POUNDIF] = ACTIONS(4401),
    [anon_sym_POUNDIf] = ACTIONS(4401),
    [anon_sym_POUNDelif] = ACTIONS(4401),
    [anon_sym_POUNDELIF] = ACTIONS(4401),
    [anon_sym_POUNDElif] = ACTIONS(4401),
    [anon_sym_POUNDelse] = ACTIONS(4401),
    [anon_sym_POUNDELSE] = ACTIONS(4401),
    [anon_sym_POUNDElse] = ACTIONS(4401),
    [anon_sym_POUNDendif] = ACTIONS(4401),
    [anon_sym_POUNDENDIF] = ACTIONS(4401),
    [anon_sym_POUNDEndif] = ACTIONS(4401),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4399),
    [sym_trigger_keyword] = ACTIONS(4399),
    [sym_var_keyword] = ACTIONS(4399),
    [sym_local_keyword] = ACTIONS(4399),
    [sym_internal_keyword] = ACTIONS(4399),
    [sym_protected_keyword] = ACTIONS(4399),
    [sym_event_keyword] = ACTIONS(4399),
    [sym_fields_keyword] = ACTIONS(4399),
    [sym_keys_keyword] = ACTIONS(4399),
    [sym_key_keyword] = ACTIONS(4399),
    [sym_fieldgroups_keyword] = ACTIONS(4399),
    [sym_actions_keyword] = ACTIONS(4399),
    [sym_layout_keyword] = ACTIONS(4399),
    [sym_area_keyword] = ACTIONS(4399),
    [sym_group_keyword] = ACTIONS(4399),
    [sym_repeater_keyword] = ACTIONS(4399),
    [sym_cuegroup_keyword] = ACTIONS(4399),
    [sym_fixed_keyword] = ACTIONS(4399),
    [sym_grid_keyword] = ACTIONS(4399),
    [sym_part_keyword] = ACTIONS(4399),
    [sym_systempart_keyword] = ACTIONS(4399),
    [sym_usercontrol_keyword] = ACTIONS(4399),
    [sym_dataset_keyword] = ACTIONS(4399),
    [sym_elements_keyword] = ACTIONS(4399),
    [sym_dataitem_keyword] = ACTIONS(4399),
    [sym_column_keyword] = ACTIONS(4399),
    [sym_filter_keyword] = ACTIONS(4399),
    [sym_labels_keyword] = ACTIONS(4399),
    [sym_rendering_keyword] = ACTIONS(4399),
    [sym_requestpage_keyword] = ACTIONS(4399),
    [sym_schema_keyword] = ACTIONS(4399),
    [sym_views_keyword] = ACTIONS(4399),
    [sym_quoted_identifier] = ACTIONS(4401),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4401),
    [sym_preproc_open] = ACTIONS(4401),
    [sym_preproc_close] = ACTIONS(4401),
    [sym_var_attribute_open] = ACTIONS(4401),
  },
  [STATE(3016)] = {
    [sym_boolean] = STATE(1062),
    [sym_assignment_expression] = STATE(1062),
    [sym__expression] = STATE(1062),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1062),
    [sym_multiplicative_expression] = STATE(1062),
    [sym_additive_expression] = STATE(1062),
    [sym_comparison_expression] = STATE(1062),
    [sym_logical_expression] = STATE(1062),
    [sym_ternary_expression] = STATE(1062),
    [sym_unary_expression] = STATE(1062),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1062),
    [sym_list_literal] = STATE(1062),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1062),
    [sym__literal_value] = STATE(1062),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7751),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7753),
    [sym_date_literal] = ACTIONS(7751),
    [sym_time_literal] = ACTIONS(7751),
    [sym_biginteger_literal] = ACTIONS(7753),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7753),
    [sym_integer] = ACTIONS(7751),
    [sym_continue_as_identifier] = ACTIONS(7753),
  },
  [STATE(3017)] = {
    [sym_boolean] = STATE(1063),
    [sym_assignment_expression] = STATE(1063),
    [sym__expression] = STATE(1063),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1063),
    [sym_multiplicative_expression] = STATE(1063),
    [sym_additive_expression] = STATE(1063),
    [sym_comparison_expression] = STATE(1063),
    [sym_logical_expression] = STATE(1063),
    [sym_ternary_expression] = STATE(1063),
    [sym_unary_expression] = STATE(1063),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1063),
    [sym_list_literal] = STATE(1063),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1063),
    [sym__literal_value] = STATE(1063),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7755),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7757),
    [sym_date_literal] = ACTIONS(7755),
    [sym_time_literal] = ACTIONS(7755),
    [sym_biginteger_literal] = ACTIONS(7757),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7757),
    [sym_integer] = ACTIONS(7755),
    [sym_continue_as_identifier] = ACTIONS(7757),
  },
  [STATE(3018)] = {
    [sym_boolean] = STATE(6060),
    [sym_assignment_expression] = STATE(6060),
    [sym__expression] = STATE(6060),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6060),
    [sym_multiplicative_expression] = STATE(6060),
    [sym_additive_expression] = STATE(6060),
    [sym_comparison_expression] = STATE(6060),
    [sym_logical_expression] = STATE(6060),
    [sym_ternary_expression] = STATE(6060),
    [sym_unary_expression] = STATE(6060),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6060),
    [sym_list_literal] = STATE(6060),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6060),
    [sym__literal_value] = STATE(6060),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7759),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7761),
    [sym_date_literal] = ACTIONS(7759),
    [sym_time_literal] = ACTIONS(7759),
    [sym_biginteger_literal] = ACTIONS(7761),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7761),
    [sym_integer] = ACTIONS(7759),
    [sym_continue_as_identifier] = ACTIONS(7761),
  },
  [STATE(3019)] = {
    [sym_preproc_conditional_controladdin] = STATE(2885),
    [sym__body_element] = STATE(2885),
    [sym_empty_statement] = STATE(2885),
    [sym_property] = STATE(2885),
    [sym_fields_section] = STATE(2885),
    [sym_keys_section] = STATE(2885),
    [sym_fieldgroups_section] = STATE(2885),
    [sym_enum_value_declaration] = STATE(2885),
    [sym_labels_section] = STATE(2885),
    [sym_layout_section] = STATE(2885),
    [sym_modify_modification] = STATE(2885),
    [sym_actions_section] = STATE(2885),
    [sym_views_section] = STATE(2885),
    [sym_dataset_section] = STATE(2885),
    [sym_requestpage_section] = STATE(2885),
    [sym_rendering_section] = STATE(2885),
    [sym_elements_section] = STATE(2885),
    [sym_schema_section] = STATE(2885),
    [sym_assembly_declaration] = STATE(2885),
    [sym_event_declaration] = STATE(2885),
    [sym_procedure] = STATE(2885),
    [sym_preproc_split_procedure] = STATE(2885),
    [sym_interface_procedure] = STATE(2885),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2885),
    [sym_var_section] = STATE(2885),
    [sym_attribute_item] = STATE(2885),
    [sym_preproc_conditional] = STATE(2885),
    [sym_preproc_if] = STATE(2635),
    [aux_sym_controladdin_declaration_repeat1] = STATE(2885),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(7763),
    [anon_sym_POUNDELIF] = ACTIONS(7763),
    [anon_sym_POUNDElif] = ACTIONS(7763),
    [anon_sym_POUNDelse] = ACTIONS(7763),
    [anon_sym_POUNDELSE] = ACTIONS(7763),
    [anon_sym_POUNDElse] = ACTIONS(7763),
    [anon_sym_POUNDendif] = ACTIONS(7763),
    [anon_sym_POUNDENDIF] = ACTIONS(7763),
    [anon_sym_POUNDEndif] = ACTIONS(7763),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(7763),
  },
  [STATE(3020)] = {
    [sym_boolean] = STATE(1414),
    [sym_assignment_expression] = STATE(1414),
    [sym__expression] = STATE(1414),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1414),
    [sym_multiplicative_expression] = STATE(1414),
    [sym_additive_expression] = STATE(1414),
    [sym_comparison_expression] = STATE(1414),
    [sym_logical_expression] = STATE(1414),
    [sym_ternary_expression] = STATE(1414),
    [sym_unary_expression] = STATE(1414),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1414),
    [sym_list_literal] = STATE(1414),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1414),
    [sym__literal_value] = STATE(1414),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7765),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7767),
    [sym_date_literal] = ACTIONS(7765),
    [sym_time_literal] = ACTIONS(7765),
    [sym_biginteger_literal] = ACTIONS(7767),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7767),
    [sym_integer] = ACTIONS(7765),
    [sym_continue_as_identifier] = ACTIONS(7767),
  },
  [STATE(3021)] = {
    [sym_boolean] = STATE(1064),
    [sym_assignment_expression] = STATE(1064),
    [sym__expression] = STATE(1064),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1064),
    [sym_multiplicative_expression] = STATE(1064),
    [sym_additive_expression] = STATE(1064),
    [sym_comparison_expression] = STATE(1064),
    [sym_logical_expression] = STATE(1064),
    [sym_ternary_expression] = STATE(1064),
    [sym_unary_expression] = STATE(1064),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1064),
    [sym_list_literal] = STATE(1064),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1064),
    [sym__literal_value] = STATE(1064),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7769),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7771),
    [sym_date_literal] = ACTIONS(7769),
    [sym_time_literal] = ACTIONS(7769),
    [sym_biginteger_literal] = ACTIONS(7771),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7771),
    [sym_integer] = ACTIONS(7769),
    [sym_continue_as_identifier] = ACTIONS(7771),
  },
  [STATE(3022)] = {
    [sym_boolean] = STATE(1415),
    [sym_assignment_expression] = STATE(1415),
    [sym__expression] = STATE(1415),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1415),
    [sym_multiplicative_expression] = STATE(1415),
    [sym_additive_expression] = STATE(1415),
    [sym_comparison_expression] = STATE(1415),
    [sym_logical_expression] = STATE(1415),
    [sym_ternary_expression] = STATE(1415),
    [sym_unary_expression] = STATE(1415),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1415),
    [sym_list_literal] = STATE(1415),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1415),
    [sym__literal_value] = STATE(1415),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7773),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7775),
    [sym_date_literal] = ACTIONS(7773),
    [sym_time_literal] = ACTIONS(7773),
    [sym_biginteger_literal] = ACTIONS(7775),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7775),
    [sym_integer] = ACTIONS(7773),
    [sym_continue_as_identifier] = ACTIONS(7775),
  },
  [STATE(3023)] = {
    [sym_boolean] = STATE(1416),
    [sym_assignment_expression] = STATE(1416),
    [sym__expression] = STATE(1416),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1416),
    [sym_multiplicative_expression] = STATE(1416),
    [sym_additive_expression] = STATE(1416),
    [sym_comparison_expression] = STATE(1416),
    [sym_logical_expression] = STATE(1416),
    [sym_ternary_expression] = STATE(1416),
    [sym_unary_expression] = STATE(1416),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1416),
    [sym_list_literal] = STATE(1416),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1416),
    [sym__literal_value] = STATE(1416),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7777),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7779),
    [sym_date_literal] = ACTIONS(7777),
    [sym_time_literal] = ACTIONS(7777),
    [sym_biginteger_literal] = ACTIONS(7779),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7779),
    [sym_integer] = ACTIONS(7777),
    [sym_continue_as_identifier] = ACTIONS(7779),
  },
  [STATE(3024)] = {
    [sym_boolean] = STATE(6012),
    [sym_assignment_expression] = STATE(6012),
    [sym__expression] = STATE(6012),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6012),
    [sym_multiplicative_expression] = STATE(6012),
    [sym_additive_expression] = STATE(6012),
    [sym_comparison_expression] = STATE(6012),
    [sym_logical_expression] = STATE(6012),
    [sym_ternary_expression] = STATE(6012),
    [sym_unary_expression] = STATE(6012),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6012),
    [sym_list_literal] = STATE(6012),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6012),
    [sym__literal_value] = STATE(6012),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7781),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7783),
    [sym_date_literal] = ACTIONS(7781),
    [sym_time_literal] = ACTIONS(7781),
    [sym_biginteger_literal] = ACTIONS(7783),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7783),
    [sym_integer] = ACTIONS(7781),
    [sym_continue_as_identifier] = ACTIONS(7783),
  },
  [STATE(3025)] = {
    [sym_boolean] = STATE(6013),
    [sym_assignment_expression] = STATE(6013),
    [sym__expression] = STATE(6013),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6013),
    [sym_multiplicative_expression] = STATE(6013),
    [sym_additive_expression] = STATE(6013),
    [sym_comparison_expression] = STATE(6013),
    [sym_logical_expression] = STATE(6013),
    [sym_ternary_expression] = STATE(6013),
    [sym_unary_expression] = STATE(6013),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6013),
    [sym_list_literal] = STATE(6013),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6013),
    [sym__literal_value] = STATE(6013),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7785),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7787),
    [sym_date_literal] = ACTIONS(7785),
    [sym_time_literal] = ACTIONS(7785),
    [sym_biginteger_literal] = ACTIONS(7787),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7787),
    [sym_integer] = ACTIONS(7785),
    [sym_continue_as_identifier] = ACTIONS(7787),
  },
  [STATE(3026)] = {
    [sym_boolean] = STATE(1417),
    [sym_assignment_expression] = STATE(1417),
    [sym__expression] = STATE(1417),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1417),
    [sym_multiplicative_expression] = STATE(1417),
    [sym_additive_expression] = STATE(1417),
    [sym_comparison_expression] = STATE(1417),
    [sym_logical_expression] = STATE(1417),
    [sym_ternary_expression] = STATE(1417),
    [sym_unary_expression] = STATE(1417),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1417),
    [sym_list_literal] = STATE(1417),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1417),
    [sym__literal_value] = STATE(1417),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7789),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7791),
    [sym_date_literal] = ACTIONS(7789),
    [sym_time_literal] = ACTIONS(7789),
    [sym_biginteger_literal] = ACTIONS(7791),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7791),
    [sym_integer] = ACTIONS(7789),
    [sym_continue_as_identifier] = ACTIONS(7791),
  },
  [STATE(3027)] = {
    [sym_boolean] = STATE(1065),
    [sym_assignment_expression] = STATE(1065),
    [sym__expression] = STATE(1065),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1065),
    [sym_multiplicative_expression] = STATE(1065),
    [sym_additive_expression] = STATE(1065),
    [sym_comparison_expression] = STATE(1065),
    [sym_logical_expression] = STATE(1065),
    [sym_ternary_expression] = STATE(1065),
    [sym_unary_expression] = STATE(1065),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1065),
    [sym_list_literal] = STATE(1065),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1065),
    [sym__literal_value] = STATE(1065),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7793),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7795),
    [sym_date_literal] = ACTIONS(7793),
    [sym_time_literal] = ACTIONS(7793),
    [sym_biginteger_literal] = ACTIONS(7795),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7795),
    [sym_integer] = ACTIONS(7793),
    [sym_continue_as_identifier] = ACTIONS(7795),
  },
  [STATE(3028)] = {
    [sym_identifier] = ACTIONS(4403),
    [anon_sym_SEMI] = ACTIONS(4405),
    [aux_sym_where_condition_token1] = ACTIONS(4403),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4403),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4403),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [aux_sym_basic_type_token6] = ACTIONS(4403),
    [aux_sym_basic_type_token22] = ACTIONS(4403),
    [aux_sym_basic_type_token53] = ACTIONS(4403),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4403),
    [aux_sym_addafter_modification_token1] = ACTIONS(4403),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4403),
    [aux_sym_modify_modification_token1] = ACTIONS(4403),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4403),
    [aux_sym_movelast_modification_token1] = ACTIONS(4403),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4403),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4403),
    [aux_sym_separator_action_token1] = ACTIONS(4403),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4403),
    [aux_sym_type_declaration_token1] = ACTIONS(4403),
    [anon_sym_POUNDif] = ACTIONS(4405),
    [anon_sym_POUNDIF] = ACTIONS(4405),
    [anon_sym_POUNDIf] = ACTIONS(4405),
    [anon_sym_POUNDelif] = ACTIONS(4405),
    [anon_sym_POUNDELIF] = ACTIONS(4405),
    [anon_sym_POUNDElif] = ACTIONS(4405),
    [anon_sym_POUNDelse] = ACTIONS(4405),
    [anon_sym_POUNDELSE] = ACTIONS(4405),
    [anon_sym_POUNDElse] = ACTIONS(4405),
    [anon_sym_POUNDendif] = ACTIONS(4405),
    [anon_sym_POUNDENDIF] = ACTIONS(4405),
    [anon_sym_POUNDEndif] = ACTIONS(4405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4403),
    [sym_trigger_keyword] = ACTIONS(4403),
    [sym_var_keyword] = ACTIONS(4403),
    [sym_local_keyword] = ACTIONS(4403),
    [sym_internal_keyword] = ACTIONS(4403),
    [sym_protected_keyword] = ACTIONS(4403),
    [sym_event_keyword] = ACTIONS(4403),
    [sym_fields_keyword] = ACTIONS(4403),
    [sym_keys_keyword] = ACTIONS(4403),
    [sym_key_keyword] = ACTIONS(4403),
    [sym_fieldgroups_keyword] = ACTIONS(4403),
    [sym_actions_keyword] = ACTIONS(4403),
    [sym_layout_keyword] = ACTIONS(4403),
    [sym_area_keyword] = ACTIONS(4403),
    [sym_group_keyword] = ACTIONS(4403),
    [sym_repeater_keyword] = ACTIONS(4403),
    [sym_cuegroup_keyword] = ACTIONS(4403),
    [sym_fixed_keyword] = ACTIONS(4403),
    [sym_grid_keyword] = ACTIONS(4403),
    [sym_part_keyword] = ACTIONS(4403),
    [sym_systempart_keyword] = ACTIONS(4403),
    [sym_usercontrol_keyword] = ACTIONS(4403),
    [sym_dataset_keyword] = ACTIONS(4403),
    [sym_elements_keyword] = ACTIONS(4403),
    [sym_dataitem_keyword] = ACTIONS(4403),
    [sym_column_keyword] = ACTIONS(4403),
    [sym_filter_keyword] = ACTIONS(4403),
    [sym_labels_keyword] = ACTIONS(4403),
    [sym_rendering_keyword] = ACTIONS(4403),
    [sym_requestpage_keyword] = ACTIONS(4403),
    [sym_schema_keyword] = ACTIONS(4403),
    [sym_views_keyword] = ACTIONS(4403),
    [sym_quoted_identifier] = ACTIONS(4405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4405),
    [sym_preproc_open] = ACTIONS(4405),
    [sym_preproc_close] = ACTIONS(4405),
    [sym_var_attribute_open] = ACTIONS(4405),
  },
  [STATE(3029)] = {
    [sym_boolean] = STATE(6006),
    [sym_assignment_expression] = STATE(6006),
    [sym__expression] = STATE(6006),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6006),
    [sym_multiplicative_expression] = STATE(6006),
    [sym_additive_expression] = STATE(6006),
    [sym_comparison_expression] = STATE(6006),
    [sym_logical_expression] = STATE(6006),
    [sym_ternary_expression] = STATE(6006),
    [sym_unary_expression] = STATE(6006),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6006),
    [sym_list_literal] = STATE(6006),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6006),
    [sym__literal_value] = STATE(6006),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7797),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7799),
    [sym_date_literal] = ACTIONS(7797),
    [sym_time_literal] = ACTIONS(7797),
    [sym_biginteger_literal] = ACTIONS(7799),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7799),
    [sym_integer] = ACTIONS(7797),
    [sym_continue_as_identifier] = ACTIONS(7799),
  },
  [STATE(3030)] = {
    [sym_identifier] = ACTIONS(4407),
    [anon_sym_SEMI] = ACTIONS(4409),
    [aux_sym_where_condition_token1] = ACTIONS(4407),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4407),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4407),
    [anon_sym_LBRACK] = ACTIONS(4409),
    [aux_sym_basic_type_token6] = ACTIONS(4407),
    [aux_sym_basic_type_token22] = ACTIONS(4407),
    [aux_sym_basic_type_token53] = ACTIONS(4407),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4407),
    [aux_sym_addafter_modification_token1] = ACTIONS(4407),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4407),
    [aux_sym_modify_modification_token1] = ACTIONS(4407),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4407),
    [aux_sym_movelast_modification_token1] = ACTIONS(4407),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4407),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4407),
    [aux_sym_separator_action_token1] = ACTIONS(4407),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4407),
    [aux_sym_type_declaration_token1] = ACTIONS(4407),
    [anon_sym_POUNDif] = ACTIONS(4409),
    [anon_sym_POUNDIF] = ACTIONS(4409),
    [anon_sym_POUNDIf] = ACTIONS(4409),
    [anon_sym_POUNDelif] = ACTIONS(4409),
    [anon_sym_POUNDELIF] = ACTIONS(4409),
    [anon_sym_POUNDElif] = ACTIONS(4409),
    [anon_sym_POUNDelse] = ACTIONS(4409),
    [anon_sym_POUNDELSE] = ACTIONS(4409),
    [anon_sym_POUNDElse] = ACTIONS(4409),
    [anon_sym_POUNDendif] = ACTIONS(4409),
    [anon_sym_POUNDENDIF] = ACTIONS(4409),
    [anon_sym_POUNDEndif] = ACTIONS(4409),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4407),
    [sym_trigger_keyword] = ACTIONS(4407),
    [sym_var_keyword] = ACTIONS(4407),
    [sym_local_keyword] = ACTIONS(4407),
    [sym_internal_keyword] = ACTIONS(4407),
    [sym_protected_keyword] = ACTIONS(4407),
    [sym_event_keyword] = ACTIONS(4407),
    [sym_fields_keyword] = ACTIONS(4407),
    [sym_keys_keyword] = ACTIONS(4407),
    [sym_key_keyword] = ACTIONS(4407),
    [sym_fieldgroups_keyword] = ACTIONS(4407),
    [sym_actions_keyword] = ACTIONS(4407),
    [sym_layout_keyword] = ACTIONS(4407),
    [sym_area_keyword] = ACTIONS(4407),
    [sym_group_keyword] = ACTIONS(4407),
    [sym_repeater_keyword] = ACTIONS(4407),
    [sym_cuegroup_keyword] = ACTIONS(4407),
    [sym_fixed_keyword] = ACTIONS(4407),
    [sym_grid_keyword] = ACTIONS(4407),
    [sym_part_keyword] = ACTIONS(4407),
    [sym_systempart_keyword] = ACTIONS(4407),
    [sym_usercontrol_keyword] = ACTIONS(4407),
    [sym_dataset_keyword] = ACTIONS(4407),
    [sym_elements_keyword] = ACTIONS(4407),
    [sym_dataitem_keyword] = ACTIONS(4407),
    [sym_column_keyword] = ACTIONS(4407),
    [sym_filter_keyword] = ACTIONS(4407),
    [sym_labels_keyword] = ACTIONS(4407),
    [sym_rendering_keyword] = ACTIONS(4407),
    [sym_requestpage_keyword] = ACTIONS(4407),
    [sym_schema_keyword] = ACTIONS(4407),
    [sym_views_keyword] = ACTIONS(4407),
    [sym_quoted_identifier] = ACTIONS(4409),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4409),
    [sym_preproc_open] = ACTIONS(4409),
    [sym_preproc_close] = ACTIONS(4409),
    [sym_var_attribute_open] = ACTIONS(4409),
  },
  [STATE(3031)] = {
    [sym_identifier] = ACTIONS(4411),
    [anon_sym_SEMI] = ACTIONS(4413),
    [aux_sym_where_condition_token1] = ACTIONS(4411),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4411),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4411),
    [anon_sym_LBRACK] = ACTIONS(4413),
    [aux_sym_basic_type_token6] = ACTIONS(4411),
    [aux_sym_basic_type_token22] = ACTIONS(4411),
    [aux_sym_basic_type_token53] = ACTIONS(4411),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4411),
    [aux_sym_addafter_modification_token1] = ACTIONS(4411),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4411),
    [aux_sym_modify_modification_token1] = ACTIONS(4411),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4411),
    [aux_sym_movelast_modification_token1] = ACTIONS(4411),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4411),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4411),
    [aux_sym_separator_action_token1] = ACTIONS(4411),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4411),
    [aux_sym_type_declaration_token1] = ACTIONS(4411),
    [anon_sym_POUNDif] = ACTIONS(4413),
    [anon_sym_POUNDIF] = ACTIONS(4413),
    [anon_sym_POUNDIf] = ACTIONS(4413),
    [anon_sym_POUNDelif] = ACTIONS(4413),
    [anon_sym_POUNDELIF] = ACTIONS(4413),
    [anon_sym_POUNDElif] = ACTIONS(4413),
    [anon_sym_POUNDelse] = ACTIONS(4413),
    [anon_sym_POUNDELSE] = ACTIONS(4413),
    [anon_sym_POUNDElse] = ACTIONS(4413),
    [anon_sym_POUNDendif] = ACTIONS(4413),
    [anon_sym_POUNDENDIF] = ACTIONS(4413),
    [anon_sym_POUNDEndif] = ACTIONS(4413),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4411),
    [sym_trigger_keyword] = ACTIONS(4411),
    [sym_var_keyword] = ACTIONS(4411),
    [sym_local_keyword] = ACTIONS(4411),
    [sym_internal_keyword] = ACTIONS(4411),
    [sym_protected_keyword] = ACTIONS(4411),
    [sym_event_keyword] = ACTIONS(4411),
    [sym_fields_keyword] = ACTIONS(4411),
    [sym_keys_keyword] = ACTIONS(4411),
    [sym_key_keyword] = ACTIONS(4411),
    [sym_fieldgroups_keyword] = ACTIONS(4411),
    [sym_actions_keyword] = ACTIONS(4411),
    [sym_layout_keyword] = ACTIONS(4411),
    [sym_area_keyword] = ACTIONS(4411),
    [sym_group_keyword] = ACTIONS(4411),
    [sym_repeater_keyword] = ACTIONS(4411),
    [sym_cuegroup_keyword] = ACTIONS(4411),
    [sym_fixed_keyword] = ACTIONS(4411),
    [sym_grid_keyword] = ACTIONS(4411),
    [sym_part_keyword] = ACTIONS(4411),
    [sym_systempart_keyword] = ACTIONS(4411),
    [sym_usercontrol_keyword] = ACTIONS(4411),
    [sym_dataset_keyword] = ACTIONS(4411),
    [sym_elements_keyword] = ACTIONS(4411),
    [sym_dataitem_keyword] = ACTIONS(4411),
    [sym_column_keyword] = ACTIONS(4411),
    [sym_filter_keyword] = ACTIONS(4411),
    [sym_labels_keyword] = ACTIONS(4411),
    [sym_rendering_keyword] = ACTIONS(4411),
    [sym_requestpage_keyword] = ACTIONS(4411),
    [sym_schema_keyword] = ACTIONS(4411),
    [sym_views_keyword] = ACTIONS(4411),
    [sym_quoted_identifier] = ACTIONS(4413),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4413),
    [sym_preproc_open] = ACTIONS(4413),
    [sym_preproc_close] = ACTIONS(4413),
    [sym_var_attribute_open] = ACTIONS(4413),
  },
  [STATE(3032)] = {
    [sym_identifier] = ACTIONS(4415),
    [anon_sym_SEMI] = ACTIONS(4417),
    [aux_sym_where_condition_token1] = ACTIONS(4415),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4415),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4415),
    [anon_sym_LBRACK] = ACTIONS(4417),
    [aux_sym_basic_type_token6] = ACTIONS(4415),
    [aux_sym_basic_type_token22] = ACTIONS(4415),
    [aux_sym_basic_type_token53] = ACTIONS(4415),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4415),
    [aux_sym_addafter_modification_token1] = ACTIONS(4415),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4415),
    [aux_sym_modify_modification_token1] = ACTIONS(4415),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4415),
    [aux_sym_movelast_modification_token1] = ACTIONS(4415),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4415),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4415),
    [aux_sym_separator_action_token1] = ACTIONS(4415),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4415),
    [aux_sym_type_declaration_token1] = ACTIONS(4415),
    [anon_sym_POUNDif] = ACTIONS(4417),
    [anon_sym_POUNDIF] = ACTIONS(4417),
    [anon_sym_POUNDIf] = ACTIONS(4417),
    [anon_sym_POUNDelif] = ACTIONS(4417),
    [anon_sym_POUNDELIF] = ACTIONS(4417),
    [anon_sym_POUNDElif] = ACTIONS(4417),
    [anon_sym_POUNDelse] = ACTIONS(4417),
    [anon_sym_POUNDELSE] = ACTIONS(4417),
    [anon_sym_POUNDElse] = ACTIONS(4417),
    [anon_sym_POUNDendif] = ACTIONS(4417),
    [anon_sym_POUNDENDIF] = ACTIONS(4417),
    [anon_sym_POUNDEndif] = ACTIONS(4417),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4415),
    [sym_trigger_keyword] = ACTIONS(4415),
    [sym_var_keyword] = ACTIONS(4415),
    [sym_local_keyword] = ACTIONS(4415),
    [sym_internal_keyword] = ACTIONS(4415),
    [sym_protected_keyword] = ACTIONS(4415),
    [sym_event_keyword] = ACTIONS(4415),
    [sym_fields_keyword] = ACTIONS(4415),
    [sym_keys_keyword] = ACTIONS(4415),
    [sym_key_keyword] = ACTIONS(4415),
    [sym_fieldgroups_keyword] = ACTIONS(4415),
    [sym_actions_keyword] = ACTIONS(4415),
    [sym_layout_keyword] = ACTIONS(4415),
    [sym_area_keyword] = ACTIONS(4415),
    [sym_group_keyword] = ACTIONS(4415),
    [sym_repeater_keyword] = ACTIONS(4415),
    [sym_cuegroup_keyword] = ACTIONS(4415),
    [sym_fixed_keyword] = ACTIONS(4415),
    [sym_grid_keyword] = ACTIONS(4415),
    [sym_part_keyword] = ACTIONS(4415),
    [sym_systempart_keyword] = ACTIONS(4415),
    [sym_usercontrol_keyword] = ACTIONS(4415),
    [sym_dataset_keyword] = ACTIONS(4415),
    [sym_elements_keyword] = ACTIONS(4415),
    [sym_dataitem_keyword] = ACTIONS(4415),
    [sym_column_keyword] = ACTIONS(4415),
    [sym_filter_keyword] = ACTIONS(4415),
    [sym_labels_keyword] = ACTIONS(4415),
    [sym_rendering_keyword] = ACTIONS(4415),
    [sym_requestpage_keyword] = ACTIONS(4415),
    [sym_schema_keyword] = ACTIONS(4415),
    [sym_views_keyword] = ACTIONS(4415),
    [sym_quoted_identifier] = ACTIONS(4417),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4417),
    [sym_preproc_open] = ACTIONS(4417),
    [sym_preproc_close] = ACTIONS(4417),
    [sym_var_attribute_open] = ACTIONS(4417),
  },
  [STATE(3033)] = {
    [sym_identifier] = ACTIONS(4419),
    [anon_sym_SEMI] = ACTIONS(4421),
    [aux_sym_where_condition_token1] = ACTIONS(4419),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4419),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4419),
    [anon_sym_LBRACK] = ACTIONS(4421),
    [aux_sym_basic_type_token6] = ACTIONS(4419),
    [aux_sym_basic_type_token22] = ACTIONS(4419),
    [aux_sym_basic_type_token53] = ACTIONS(4419),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4419),
    [aux_sym_addafter_modification_token1] = ACTIONS(4419),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4419),
    [aux_sym_modify_modification_token1] = ACTIONS(4419),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4419),
    [aux_sym_movelast_modification_token1] = ACTIONS(4419),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4419),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4419),
    [aux_sym_separator_action_token1] = ACTIONS(4419),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4419),
    [aux_sym_type_declaration_token1] = ACTIONS(4419),
    [anon_sym_POUNDif] = ACTIONS(4421),
    [anon_sym_POUNDIF] = ACTIONS(4421),
    [anon_sym_POUNDIf] = ACTIONS(4421),
    [anon_sym_POUNDelif] = ACTIONS(4421),
    [anon_sym_POUNDELIF] = ACTIONS(4421),
    [anon_sym_POUNDElif] = ACTIONS(4421),
    [anon_sym_POUNDelse] = ACTIONS(4421),
    [anon_sym_POUNDELSE] = ACTIONS(4421),
    [anon_sym_POUNDElse] = ACTIONS(4421),
    [anon_sym_POUNDendif] = ACTIONS(4421),
    [anon_sym_POUNDENDIF] = ACTIONS(4421),
    [anon_sym_POUNDEndif] = ACTIONS(4421),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4419),
    [sym_trigger_keyword] = ACTIONS(4419),
    [sym_var_keyword] = ACTIONS(4419),
    [sym_local_keyword] = ACTIONS(4419),
    [sym_internal_keyword] = ACTIONS(4419),
    [sym_protected_keyword] = ACTIONS(4419),
    [sym_event_keyword] = ACTIONS(4419),
    [sym_fields_keyword] = ACTIONS(4419),
    [sym_keys_keyword] = ACTIONS(4419),
    [sym_key_keyword] = ACTIONS(4419),
    [sym_fieldgroups_keyword] = ACTIONS(4419),
    [sym_actions_keyword] = ACTIONS(4419),
    [sym_layout_keyword] = ACTIONS(4419),
    [sym_area_keyword] = ACTIONS(4419),
    [sym_group_keyword] = ACTIONS(4419),
    [sym_repeater_keyword] = ACTIONS(4419),
    [sym_cuegroup_keyword] = ACTIONS(4419),
    [sym_fixed_keyword] = ACTIONS(4419),
    [sym_grid_keyword] = ACTIONS(4419),
    [sym_part_keyword] = ACTIONS(4419),
    [sym_systempart_keyword] = ACTIONS(4419),
    [sym_usercontrol_keyword] = ACTIONS(4419),
    [sym_dataset_keyword] = ACTIONS(4419),
    [sym_elements_keyword] = ACTIONS(4419),
    [sym_dataitem_keyword] = ACTIONS(4419),
    [sym_column_keyword] = ACTIONS(4419),
    [sym_filter_keyword] = ACTIONS(4419),
    [sym_labels_keyword] = ACTIONS(4419),
    [sym_rendering_keyword] = ACTIONS(4419),
    [sym_requestpage_keyword] = ACTIONS(4419),
    [sym_schema_keyword] = ACTIONS(4419),
    [sym_views_keyword] = ACTIONS(4419),
    [sym_quoted_identifier] = ACTIONS(4421),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4421),
    [sym_preproc_open] = ACTIONS(4421),
    [sym_preproc_close] = ACTIONS(4421),
    [sym_var_attribute_open] = ACTIONS(4421),
  },
  [STATE(3034)] = {
    [sym_identifier] = ACTIONS(4423),
    [anon_sym_SEMI] = ACTIONS(4425),
    [aux_sym_where_condition_token1] = ACTIONS(4423),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4423),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4423),
    [anon_sym_LBRACK] = ACTIONS(4425),
    [aux_sym_basic_type_token6] = ACTIONS(4423),
    [aux_sym_basic_type_token22] = ACTIONS(4423),
    [aux_sym_basic_type_token53] = ACTIONS(4423),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4423),
    [aux_sym_addafter_modification_token1] = ACTIONS(4423),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4423),
    [aux_sym_modify_modification_token1] = ACTIONS(4423),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4423),
    [aux_sym_movelast_modification_token1] = ACTIONS(4423),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4423),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4423),
    [aux_sym_separator_action_token1] = ACTIONS(4423),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4423),
    [aux_sym_type_declaration_token1] = ACTIONS(4423),
    [anon_sym_POUNDif] = ACTIONS(4425),
    [anon_sym_POUNDIF] = ACTIONS(4425),
    [anon_sym_POUNDIf] = ACTIONS(4425),
    [anon_sym_POUNDelif] = ACTIONS(4425),
    [anon_sym_POUNDELIF] = ACTIONS(4425),
    [anon_sym_POUNDElif] = ACTIONS(4425),
    [anon_sym_POUNDelse] = ACTIONS(4425),
    [anon_sym_POUNDELSE] = ACTIONS(4425),
    [anon_sym_POUNDElse] = ACTIONS(4425),
    [anon_sym_POUNDendif] = ACTIONS(4425),
    [anon_sym_POUNDENDIF] = ACTIONS(4425),
    [anon_sym_POUNDEndif] = ACTIONS(4425),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4423),
    [sym_trigger_keyword] = ACTIONS(4423),
    [sym_var_keyword] = ACTIONS(4423),
    [sym_local_keyword] = ACTIONS(4423),
    [sym_internal_keyword] = ACTIONS(4423),
    [sym_protected_keyword] = ACTIONS(4423),
    [sym_event_keyword] = ACTIONS(4423),
    [sym_fields_keyword] = ACTIONS(4423),
    [sym_keys_keyword] = ACTIONS(4423),
    [sym_key_keyword] = ACTIONS(4423),
    [sym_fieldgroups_keyword] = ACTIONS(4423),
    [sym_actions_keyword] = ACTIONS(4423),
    [sym_layout_keyword] = ACTIONS(4423),
    [sym_area_keyword] = ACTIONS(4423),
    [sym_group_keyword] = ACTIONS(4423),
    [sym_repeater_keyword] = ACTIONS(4423),
    [sym_cuegroup_keyword] = ACTIONS(4423),
    [sym_fixed_keyword] = ACTIONS(4423),
    [sym_grid_keyword] = ACTIONS(4423),
    [sym_part_keyword] = ACTIONS(4423),
    [sym_systempart_keyword] = ACTIONS(4423),
    [sym_usercontrol_keyword] = ACTIONS(4423),
    [sym_dataset_keyword] = ACTIONS(4423),
    [sym_elements_keyword] = ACTIONS(4423),
    [sym_dataitem_keyword] = ACTIONS(4423),
    [sym_column_keyword] = ACTIONS(4423),
    [sym_filter_keyword] = ACTIONS(4423),
    [sym_labels_keyword] = ACTIONS(4423),
    [sym_rendering_keyword] = ACTIONS(4423),
    [sym_requestpage_keyword] = ACTIONS(4423),
    [sym_schema_keyword] = ACTIONS(4423),
    [sym_views_keyword] = ACTIONS(4423),
    [sym_quoted_identifier] = ACTIONS(4425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4425),
    [sym_preproc_open] = ACTIONS(4425),
    [sym_preproc_close] = ACTIONS(4425),
    [sym_var_attribute_open] = ACTIONS(4425),
  },
  [STATE(3035)] = {
    [sym_boolean] = STATE(6011),
    [sym_assignment_expression] = STATE(6011),
    [sym__expression] = STATE(6011),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6011),
    [sym_multiplicative_expression] = STATE(6011),
    [sym_additive_expression] = STATE(6011),
    [sym_comparison_expression] = STATE(6011),
    [sym_logical_expression] = STATE(6011),
    [sym_ternary_expression] = STATE(6011),
    [sym_unary_expression] = STATE(6011),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6011),
    [sym_list_literal] = STATE(6011),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6011),
    [sym__literal_value] = STATE(6011),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7801),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7803),
    [sym_date_literal] = ACTIONS(7801),
    [sym_time_literal] = ACTIONS(7801),
    [sym_biginteger_literal] = ACTIONS(7803),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7803),
    [sym_integer] = ACTIONS(7801),
    [sym_continue_as_identifier] = ACTIONS(7803),
  },
  [STATE(3036)] = {
    [sym_identifier] = ACTIONS(4427),
    [anon_sym_SEMI] = ACTIONS(4429),
    [aux_sym_where_condition_token1] = ACTIONS(4427),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4427),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4427),
    [anon_sym_LBRACK] = ACTIONS(4429),
    [aux_sym_basic_type_token6] = ACTIONS(4427),
    [aux_sym_basic_type_token22] = ACTIONS(4427),
    [aux_sym_basic_type_token53] = ACTIONS(4427),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4427),
    [aux_sym_addafter_modification_token1] = ACTIONS(4427),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4427),
    [aux_sym_modify_modification_token1] = ACTIONS(4427),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4427),
    [aux_sym_movelast_modification_token1] = ACTIONS(4427),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4427),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4427),
    [aux_sym_separator_action_token1] = ACTIONS(4427),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4427),
    [aux_sym_type_declaration_token1] = ACTIONS(4427),
    [anon_sym_POUNDif] = ACTIONS(4429),
    [anon_sym_POUNDIF] = ACTIONS(4429),
    [anon_sym_POUNDIf] = ACTIONS(4429),
    [anon_sym_POUNDelif] = ACTIONS(4429),
    [anon_sym_POUNDELIF] = ACTIONS(4429),
    [anon_sym_POUNDElif] = ACTIONS(4429),
    [anon_sym_POUNDelse] = ACTIONS(4429),
    [anon_sym_POUNDELSE] = ACTIONS(4429),
    [anon_sym_POUNDElse] = ACTIONS(4429),
    [anon_sym_POUNDendif] = ACTIONS(4429),
    [anon_sym_POUNDENDIF] = ACTIONS(4429),
    [anon_sym_POUNDEndif] = ACTIONS(4429),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4427),
    [sym_trigger_keyword] = ACTIONS(4427),
    [sym_var_keyword] = ACTIONS(4427),
    [sym_local_keyword] = ACTIONS(4427),
    [sym_internal_keyword] = ACTIONS(4427),
    [sym_protected_keyword] = ACTIONS(4427),
    [sym_event_keyword] = ACTIONS(4427),
    [sym_fields_keyword] = ACTIONS(4427),
    [sym_keys_keyword] = ACTIONS(4427),
    [sym_key_keyword] = ACTIONS(4427),
    [sym_fieldgroups_keyword] = ACTIONS(4427),
    [sym_actions_keyword] = ACTIONS(4427),
    [sym_layout_keyword] = ACTIONS(4427),
    [sym_area_keyword] = ACTIONS(4427),
    [sym_group_keyword] = ACTIONS(4427),
    [sym_repeater_keyword] = ACTIONS(4427),
    [sym_cuegroup_keyword] = ACTIONS(4427),
    [sym_fixed_keyword] = ACTIONS(4427),
    [sym_grid_keyword] = ACTIONS(4427),
    [sym_part_keyword] = ACTIONS(4427),
    [sym_systempart_keyword] = ACTIONS(4427),
    [sym_usercontrol_keyword] = ACTIONS(4427),
    [sym_dataset_keyword] = ACTIONS(4427),
    [sym_elements_keyword] = ACTIONS(4427),
    [sym_dataitem_keyword] = ACTIONS(4427),
    [sym_column_keyword] = ACTIONS(4427),
    [sym_filter_keyword] = ACTIONS(4427),
    [sym_labels_keyword] = ACTIONS(4427),
    [sym_rendering_keyword] = ACTIONS(4427),
    [sym_requestpage_keyword] = ACTIONS(4427),
    [sym_schema_keyword] = ACTIONS(4427),
    [sym_views_keyword] = ACTIONS(4427),
    [sym_quoted_identifier] = ACTIONS(4429),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4429),
    [sym_preproc_open] = ACTIONS(4429),
    [sym_preproc_close] = ACTIONS(4429),
    [sym_var_attribute_open] = ACTIONS(4429),
  },
  [STATE(3037)] = {
    [sym_identifier] = ACTIONS(4431),
    [anon_sym_SEMI] = ACTIONS(4433),
    [aux_sym_where_condition_token1] = ACTIONS(4431),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4431),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4431),
    [anon_sym_LBRACK] = ACTIONS(4433),
    [aux_sym_basic_type_token6] = ACTIONS(4431),
    [aux_sym_basic_type_token22] = ACTIONS(4431),
    [aux_sym_basic_type_token53] = ACTIONS(4431),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4431),
    [aux_sym_addafter_modification_token1] = ACTIONS(4431),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4431),
    [aux_sym_modify_modification_token1] = ACTIONS(4431),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4431),
    [aux_sym_movelast_modification_token1] = ACTIONS(4431),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4431),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4431),
    [aux_sym_separator_action_token1] = ACTIONS(4431),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4431),
    [aux_sym_type_declaration_token1] = ACTIONS(4431),
    [anon_sym_POUNDif] = ACTIONS(4433),
    [anon_sym_POUNDIF] = ACTIONS(4433),
    [anon_sym_POUNDIf] = ACTIONS(4433),
    [anon_sym_POUNDelif] = ACTIONS(4433),
    [anon_sym_POUNDELIF] = ACTIONS(4433),
    [anon_sym_POUNDElif] = ACTIONS(4433),
    [anon_sym_POUNDelse] = ACTIONS(4433),
    [anon_sym_POUNDELSE] = ACTIONS(4433),
    [anon_sym_POUNDElse] = ACTIONS(4433),
    [anon_sym_POUNDendif] = ACTIONS(4433),
    [anon_sym_POUNDENDIF] = ACTIONS(4433),
    [anon_sym_POUNDEndif] = ACTIONS(4433),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4431),
    [sym_trigger_keyword] = ACTIONS(4431),
    [sym_var_keyword] = ACTIONS(4431),
    [sym_local_keyword] = ACTIONS(4431),
    [sym_internal_keyword] = ACTIONS(4431),
    [sym_protected_keyword] = ACTIONS(4431),
    [sym_event_keyword] = ACTIONS(4431),
    [sym_fields_keyword] = ACTIONS(4431),
    [sym_keys_keyword] = ACTIONS(4431),
    [sym_key_keyword] = ACTIONS(4431),
    [sym_fieldgroups_keyword] = ACTIONS(4431),
    [sym_actions_keyword] = ACTIONS(4431),
    [sym_layout_keyword] = ACTIONS(4431),
    [sym_area_keyword] = ACTIONS(4431),
    [sym_group_keyword] = ACTIONS(4431),
    [sym_repeater_keyword] = ACTIONS(4431),
    [sym_cuegroup_keyword] = ACTIONS(4431),
    [sym_fixed_keyword] = ACTIONS(4431),
    [sym_grid_keyword] = ACTIONS(4431),
    [sym_part_keyword] = ACTIONS(4431),
    [sym_systempart_keyword] = ACTIONS(4431),
    [sym_usercontrol_keyword] = ACTIONS(4431),
    [sym_dataset_keyword] = ACTIONS(4431),
    [sym_elements_keyword] = ACTIONS(4431),
    [sym_dataitem_keyword] = ACTIONS(4431),
    [sym_column_keyword] = ACTIONS(4431),
    [sym_filter_keyword] = ACTIONS(4431),
    [sym_labels_keyword] = ACTIONS(4431),
    [sym_rendering_keyword] = ACTIONS(4431),
    [sym_requestpage_keyword] = ACTIONS(4431),
    [sym_schema_keyword] = ACTIONS(4431),
    [sym_views_keyword] = ACTIONS(4431),
    [sym_quoted_identifier] = ACTIONS(4433),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4433),
    [sym_preproc_open] = ACTIONS(4433),
    [sym_preproc_close] = ACTIONS(4433),
    [sym_var_attribute_open] = ACTIONS(4433),
  },
  [STATE(3038)] = {
    [sym_identifier] = ACTIONS(7805),
    [anon_sym_SEMI] = ACTIONS(7807),
    [aux_sym_where_condition_token1] = ACTIONS(7805),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7805),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7805),
    [anon_sym_LBRACK] = ACTIONS(7807),
    [aux_sym_basic_type_token6] = ACTIONS(7805),
    [aux_sym_basic_type_token22] = ACTIONS(7805),
    [aux_sym_basic_type_token53] = ACTIONS(7805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7805),
    [aux_sym_addafter_modification_token1] = ACTIONS(7805),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7805),
    [aux_sym_modify_modification_token1] = ACTIONS(7805),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7805),
    [aux_sym_movelast_modification_token1] = ACTIONS(7805),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7805),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7805),
    [aux_sym_separator_action_token1] = ACTIONS(7805),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7805),
    [aux_sym_type_declaration_token1] = ACTIONS(7805),
    [anon_sym_POUNDif] = ACTIONS(7807),
    [anon_sym_POUNDIF] = ACTIONS(7807),
    [anon_sym_POUNDIf] = ACTIONS(7807),
    [anon_sym_POUNDelif] = ACTIONS(7807),
    [anon_sym_POUNDELIF] = ACTIONS(7807),
    [anon_sym_POUNDElif] = ACTIONS(7807),
    [anon_sym_POUNDelse] = ACTIONS(7807),
    [anon_sym_POUNDELSE] = ACTIONS(7807),
    [anon_sym_POUNDElse] = ACTIONS(7807),
    [anon_sym_POUNDendif] = ACTIONS(7807),
    [anon_sym_POUNDENDIF] = ACTIONS(7807),
    [anon_sym_POUNDEndif] = ACTIONS(7807),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7805),
    [sym_trigger_keyword] = ACTIONS(7805),
    [sym_var_keyword] = ACTIONS(7805),
    [sym_local_keyword] = ACTIONS(7805),
    [sym_internal_keyword] = ACTIONS(7805),
    [sym_protected_keyword] = ACTIONS(7805),
    [sym_event_keyword] = ACTIONS(7805),
    [sym_fields_keyword] = ACTIONS(7805),
    [sym_keys_keyword] = ACTIONS(7805),
    [sym_key_keyword] = ACTIONS(7805),
    [sym_fieldgroups_keyword] = ACTIONS(7805),
    [sym_actions_keyword] = ACTIONS(7805),
    [sym_layout_keyword] = ACTIONS(7805),
    [sym_area_keyword] = ACTIONS(7805),
    [sym_group_keyword] = ACTIONS(7805),
    [sym_repeater_keyword] = ACTIONS(7805),
    [sym_cuegroup_keyword] = ACTIONS(7805),
    [sym_fixed_keyword] = ACTIONS(7805),
    [sym_grid_keyword] = ACTIONS(7805),
    [sym_part_keyword] = ACTIONS(7805),
    [sym_systempart_keyword] = ACTIONS(7805),
    [sym_usercontrol_keyword] = ACTIONS(7805),
    [sym_dataset_keyword] = ACTIONS(7805),
    [sym_elements_keyword] = ACTIONS(7805),
    [sym_dataitem_keyword] = ACTIONS(7805),
    [sym_column_keyword] = ACTIONS(7805),
    [sym_filter_keyword] = ACTIONS(7805),
    [sym_labels_keyword] = ACTIONS(7805),
    [sym_rendering_keyword] = ACTIONS(7805),
    [sym_requestpage_keyword] = ACTIONS(7805),
    [sym_schema_keyword] = ACTIONS(7805),
    [sym_views_keyword] = ACTIONS(7805),
    [sym_quoted_identifier] = ACTIONS(7807),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7807),
    [sym_preproc_open] = ACTIONS(7807),
    [sym_preproc_close] = ACTIONS(7807),
    [sym_var_attribute_open] = ACTIONS(7807),
  },
  [STATE(3039)] = {
    [sym_identifier] = ACTIONS(7809),
    [anon_sym_SEMI] = ACTIONS(7811),
    [aux_sym_where_condition_token1] = ACTIONS(7809),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7809),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7809),
    [anon_sym_LBRACK] = ACTIONS(7811),
    [aux_sym_basic_type_token6] = ACTIONS(7809),
    [aux_sym_basic_type_token22] = ACTIONS(7809),
    [aux_sym_basic_type_token53] = ACTIONS(7809),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7809),
    [aux_sym_addafter_modification_token1] = ACTIONS(7809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7809),
    [aux_sym_modify_modification_token1] = ACTIONS(7809),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7809),
    [aux_sym_movelast_modification_token1] = ACTIONS(7809),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7809),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7809),
    [aux_sym_separator_action_token1] = ACTIONS(7809),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7809),
    [aux_sym_type_declaration_token1] = ACTIONS(7809),
    [anon_sym_POUNDif] = ACTIONS(7811),
    [anon_sym_POUNDIF] = ACTIONS(7811),
    [anon_sym_POUNDIf] = ACTIONS(7811),
    [anon_sym_POUNDelif] = ACTIONS(7811),
    [anon_sym_POUNDELIF] = ACTIONS(7811),
    [anon_sym_POUNDElif] = ACTIONS(7811),
    [anon_sym_POUNDelse] = ACTIONS(7811),
    [anon_sym_POUNDELSE] = ACTIONS(7811),
    [anon_sym_POUNDElse] = ACTIONS(7811),
    [anon_sym_POUNDendif] = ACTIONS(7811),
    [anon_sym_POUNDENDIF] = ACTIONS(7811),
    [anon_sym_POUNDEndif] = ACTIONS(7811),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7809),
    [sym_trigger_keyword] = ACTIONS(7809),
    [sym_var_keyword] = ACTIONS(7809),
    [sym_local_keyword] = ACTIONS(7809),
    [sym_internal_keyword] = ACTIONS(7809),
    [sym_protected_keyword] = ACTIONS(7809),
    [sym_event_keyword] = ACTIONS(7809),
    [sym_fields_keyword] = ACTIONS(7809),
    [sym_keys_keyword] = ACTIONS(7809),
    [sym_key_keyword] = ACTIONS(7809),
    [sym_fieldgroups_keyword] = ACTIONS(7809),
    [sym_actions_keyword] = ACTIONS(7809),
    [sym_layout_keyword] = ACTIONS(7809),
    [sym_area_keyword] = ACTIONS(7809),
    [sym_group_keyword] = ACTIONS(7809),
    [sym_repeater_keyword] = ACTIONS(7809),
    [sym_cuegroup_keyword] = ACTIONS(7809),
    [sym_fixed_keyword] = ACTIONS(7809),
    [sym_grid_keyword] = ACTIONS(7809),
    [sym_part_keyword] = ACTIONS(7809),
    [sym_systempart_keyword] = ACTIONS(7809),
    [sym_usercontrol_keyword] = ACTIONS(7809),
    [sym_dataset_keyword] = ACTIONS(7809),
    [sym_elements_keyword] = ACTIONS(7809),
    [sym_dataitem_keyword] = ACTIONS(7809),
    [sym_column_keyword] = ACTIONS(7809),
    [sym_filter_keyword] = ACTIONS(7809),
    [sym_labels_keyword] = ACTIONS(7809),
    [sym_rendering_keyword] = ACTIONS(7809),
    [sym_requestpage_keyword] = ACTIONS(7809),
    [sym_schema_keyword] = ACTIONS(7809),
    [sym_views_keyword] = ACTIONS(7809),
    [sym_quoted_identifier] = ACTIONS(7811),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7811),
    [sym_preproc_open] = ACTIONS(7811),
    [sym_preproc_close] = ACTIONS(7811),
    [sym_var_attribute_open] = ACTIONS(7811),
  },
  [STATE(3040)] = {
    [sym_identifier] = ACTIONS(4435),
    [anon_sym_SEMI] = ACTIONS(4437),
    [aux_sym_where_condition_token1] = ACTIONS(4435),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4435),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4435),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [aux_sym_basic_type_token6] = ACTIONS(4435),
    [aux_sym_basic_type_token22] = ACTIONS(4435),
    [aux_sym_basic_type_token53] = ACTIONS(4435),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4435),
    [aux_sym_addafter_modification_token1] = ACTIONS(4435),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4435),
    [aux_sym_modify_modification_token1] = ACTIONS(4435),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4435),
    [aux_sym_movelast_modification_token1] = ACTIONS(4435),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4435),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4435),
    [aux_sym_separator_action_token1] = ACTIONS(4435),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4435),
    [aux_sym_type_declaration_token1] = ACTIONS(4435),
    [anon_sym_POUNDif] = ACTIONS(4437),
    [anon_sym_POUNDIF] = ACTIONS(4437),
    [anon_sym_POUNDIf] = ACTIONS(4437),
    [anon_sym_POUNDelif] = ACTIONS(4437),
    [anon_sym_POUNDELIF] = ACTIONS(4437),
    [anon_sym_POUNDElif] = ACTIONS(4437),
    [anon_sym_POUNDelse] = ACTIONS(4437),
    [anon_sym_POUNDELSE] = ACTIONS(4437),
    [anon_sym_POUNDElse] = ACTIONS(4437),
    [anon_sym_POUNDendif] = ACTIONS(4437),
    [anon_sym_POUNDENDIF] = ACTIONS(4437),
    [anon_sym_POUNDEndif] = ACTIONS(4437),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4435),
    [sym_trigger_keyword] = ACTIONS(4435),
    [sym_var_keyword] = ACTIONS(4435),
    [sym_local_keyword] = ACTIONS(4435),
    [sym_internal_keyword] = ACTIONS(4435),
    [sym_protected_keyword] = ACTIONS(4435),
    [sym_event_keyword] = ACTIONS(4435),
    [sym_fields_keyword] = ACTIONS(4435),
    [sym_keys_keyword] = ACTIONS(4435),
    [sym_key_keyword] = ACTIONS(4435),
    [sym_fieldgroups_keyword] = ACTIONS(4435),
    [sym_actions_keyword] = ACTIONS(4435),
    [sym_layout_keyword] = ACTIONS(4435),
    [sym_area_keyword] = ACTIONS(4435),
    [sym_group_keyword] = ACTIONS(4435),
    [sym_repeater_keyword] = ACTIONS(4435),
    [sym_cuegroup_keyword] = ACTIONS(4435),
    [sym_fixed_keyword] = ACTIONS(4435),
    [sym_grid_keyword] = ACTIONS(4435),
    [sym_part_keyword] = ACTIONS(4435),
    [sym_systempart_keyword] = ACTIONS(4435),
    [sym_usercontrol_keyword] = ACTIONS(4435),
    [sym_dataset_keyword] = ACTIONS(4435),
    [sym_elements_keyword] = ACTIONS(4435),
    [sym_dataitem_keyword] = ACTIONS(4435),
    [sym_column_keyword] = ACTIONS(4435),
    [sym_filter_keyword] = ACTIONS(4435),
    [sym_labels_keyword] = ACTIONS(4435),
    [sym_rendering_keyword] = ACTIONS(4435),
    [sym_requestpage_keyword] = ACTIONS(4435),
    [sym_schema_keyword] = ACTIONS(4435),
    [sym_views_keyword] = ACTIONS(4435),
    [sym_quoted_identifier] = ACTIONS(4437),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4437),
    [sym_preproc_open] = ACTIONS(4437),
    [sym_preproc_close] = ACTIONS(4437),
    [sym_var_attribute_open] = ACTIONS(4437),
  },
  [STATE(3041)] = {
    [sym_identifier] = ACTIONS(4439),
    [anon_sym_SEMI] = ACTIONS(4441),
    [aux_sym_where_condition_token1] = ACTIONS(4439),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4439),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(4439),
    [aux_sym_basic_type_token22] = ACTIONS(4439),
    [aux_sym_basic_type_token53] = ACTIONS(4439),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4439),
    [aux_sym_addafter_modification_token1] = ACTIONS(4439),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4439),
    [aux_sym_modify_modification_token1] = ACTIONS(4439),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4439),
    [aux_sym_movelast_modification_token1] = ACTIONS(4439),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4439),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4439),
    [aux_sym_separator_action_token1] = ACTIONS(4439),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4439),
    [aux_sym_type_declaration_token1] = ACTIONS(4439),
    [anon_sym_POUNDif] = ACTIONS(4441),
    [anon_sym_POUNDIF] = ACTIONS(4441),
    [anon_sym_POUNDIf] = ACTIONS(4441),
    [anon_sym_POUNDelif] = ACTIONS(4441),
    [anon_sym_POUNDELIF] = ACTIONS(4441),
    [anon_sym_POUNDElif] = ACTIONS(4441),
    [anon_sym_POUNDelse] = ACTIONS(4441),
    [anon_sym_POUNDELSE] = ACTIONS(4441),
    [anon_sym_POUNDElse] = ACTIONS(4441),
    [anon_sym_POUNDendif] = ACTIONS(4441),
    [anon_sym_POUNDENDIF] = ACTIONS(4441),
    [anon_sym_POUNDEndif] = ACTIONS(4441),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4439),
    [sym_trigger_keyword] = ACTIONS(4439),
    [sym_var_keyword] = ACTIONS(4439),
    [sym_local_keyword] = ACTIONS(4439),
    [sym_internal_keyword] = ACTIONS(4439),
    [sym_protected_keyword] = ACTIONS(4439),
    [sym_event_keyword] = ACTIONS(4439),
    [sym_fields_keyword] = ACTIONS(4439),
    [sym_keys_keyword] = ACTIONS(4439),
    [sym_key_keyword] = ACTIONS(4439),
    [sym_fieldgroups_keyword] = ACTIONS(4439),
    [sym_actions_keyword] = ACTIONS(4439),
    [sym_layout_keyword] = ACTIONS(4439),
    [sym_area_keyword] = ACTIONS(4439),
    [sym_group_keyword] = ACTIONS(4439),
    [sym_repeater_keyword] = ACTIONS(4439),
    [sym_cuegroup_keyword] = ACTIONS(4439),
    [sym_fixed_keyword] = ACTIONS(4439),
    [sym_grid_keyword] = ACTIONS(4439),
    [sym_part_keyword] = ACTIONS(4439),
    [sym_systempart_keyword] = ACTIONS(4439),
    [sym_usercontrol_keyword] = ACTIONS(4439),
    [sym_dataset_keyword] = ACTIONS(4439),
    [sym_elements_keyword] = ACTIONS(4439),
    [sym_dataitem_keyword] = ACTIONS(4439),
    [sym_column_keyword] = ACTIONS(4439),
    [sym_filter_keyword] = ACTIONS(4439),
    [sym_labels_keyword] = ACTIONS(4439),
    [sym_rendering_keyword] = ACTIONS(4439),
    [sym_requestpage_keyword] = ACTIONS(4439),
    [sym_schema_keyword] = ACTIONS(4439),
    [sym_views_keyword] = ACTIONS(4439),
    [sym_quoted_identifier] = ACTIONS(4441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4441),
    [sym_preproc_open] = ACTIONS(4441),
    [sym_preproc_close] = ACTIONS(4441),
    [sym_var_attribute_open] = ACTIONS(4441),
  },
  [STATE(3042)] = {
    [sym_boolean] = STATE(1066),
    [sym_assignment_expression] = STATE(1066),
    [sym__expression] = STATE(1066),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1066),
    [sym_multiplicative_expression] = STATE(1066),
    [sym_additive_expression] = STATE(1066),
    [sym_comparison_expression] = STATE(1066),
    [sym_logical_expression] = STATE(1066),
    [sym_ternary_expression] = STATE(1066),
    [sym_unary_expression] = STATE(1066),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1066),
    [sym_list_literal] = STATE(1066),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1066),
    [sym__literal_value] = STATE(1066),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7813),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7815),
    [sym_date_literal] = ACTIONS(7813),
    [sym_time_literal] = ACTIONS(7813),
    [sym_biginteger_literal] = ACTIONS(7815),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7815),
    [sym_integer] = ACTIONS(7813),
    [sym_continue_as_identifier] = ACTIONS(7815),
  },
  [STATE(3043)] = {
    [sym_boolean] = STATE(1418),
    [sym_assignment_expression] = STATE(1418),
    [sym__expression] = STATE(1418),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1418),
    [sym_multiplicative_expression] = STATE(1418),
    [sym_additive_expression] = STATE(1418),
    [sym_comparison_expression] = STATE(1418),
    [sym_logical_expression] = STATE(1418),
    [sym_ternary_expression] = STATE(1418),
    [sym_unary_expression] = STATE(1418),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1418),
    [sym_list_literal] = STATE(1418),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1418),
    [sym__literal_value] = STATE(1418),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7817),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7819),
    [sym_date_literal] = ACTIONS(7817),
    [sym_time_literal] = ACTIONS(7817),
    [sym_biginteger_literal] = ACTIONS(7819),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7819),
    [sym_integer] = ACTIONS(7817),
    [sym_continue_as_identifier] = ACTIONS(7819),
  },
  [STATE(3044)] = {
    [sym_boolean] = STATE(1419),
    [sym_assignment_expression] = STATE(1419),
    [sym__expression] = STATE(1419),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1419),
    [sym_multiplicative_expression] = STATE(1419),
    [sym_additive_expression] = STATE(1419),
    [sym_comparison_expression] = STATE(1419),
    [sym_logical_expression] = STATE(1419),
    [sym_ternary_expression] = STATE(1419),
    [sym_unary_expression] = STATE(1419),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1419),
    [sym_list_literal] = STATE(1419),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1419),
    [sym__literal_value] = STATE(1419),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7821),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7823),
    [sym_date_literal] = ACTIONS(7821),
    [sym_time_literal] = ACTIONS(7821),
    [sym_biginteger_literal] = ACTIONS(7823),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7823),
    [sym_integer] = ACTIONS(7821),
    [sym_continue_as_identifier] = ACTIONS(7823),
  },
  [STATE(3045)] = {
    [sym_boolean] = STATE(1420),
    [sym_assignment_expression] = STATE(1420),
    [sym__expression] = STATE(1420),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1420),
    [sym_multiplicative_expression] = STATE(1420),
    [sym_additive_expression] = STATE(1420),
    [sym_comparison_expression] = STATE(1420),
    [sym_logical_expression] = STATE(1420),
    [sym_ternary_expression] = STATE(1420),
    [sym_unary_expression] = STATE(1420),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1420),
    [sym_list_literal] = STATE(1420),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1420),
    [sym__literal_value] = STATE(1420),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7825),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7827),
    [sym_date_literal] = ACTIONS(7825),
    [sym_time_literal] = ACTIONS(7825),
    [sym_biginteger_literal] = ACTIONS(7827),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7827),
    [sym_integer] = ACTIONS(7825),
    [sym_continue_as_identifier] = ACTIONS(7827),
  },
  [STATE(3046)] = {
    [sym_boolean] = STATE(1396),
    [sym_assignment_expression] = STATE(1396),
    [sym__expression] = STATE(1396),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1396),
    [sym_multiplicative_expression] = STATE(1396),
    [sym_additive_expression] = STATE(1396),
    [sym_comparison_expression] = STATE(1396),
    [sym_logical_expression] = STATE(1396),
    [sym_ternary_expression] = STATE(1396),
    [sym_unary_expression] = STATE(1396),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1396),
    [sym_list_literal] = STATE(1396),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1396),
    [sym__literal_value] = STATE(1396),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7829),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7831),
    [sym_date_literal] = ACTIONS(7829),
    [sym_time_literal] = ACTIONS(7829),
    [sym_biginteger_literal] = ACTIONS(7831),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7831),
    [sym_integer] = ACTIONS(7829),
    [sym_continue_as_identifier] = ACTIONS(7831),
  },
  [STATE(3047)] = {
    [sym_boolean] = STATE(1421),
    [sym_assignment_expression] = STATE(1421),
    [sym__expression] = STATE(1421),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1421),
    [sym_multiplicative_expression] = STATE(1421),
    [sym_additive_expression] = STATE(1421),
    [sym_comparison_expression] = STATE(1421),
    [sym_logical_expression] = STATE(1421),
    [sym_ternary_expression] = STATE(1421),
    [sym_unary_expression] = STATE(1421),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1421),
    [sym_list_literal] = STATE(1421),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1421),
    [sym__literal_value] = STATE(1421),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(7833),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(7835),
    [sym_date_literal] = ACTIONS(7833),
    [sym_time_literal] = ACTIONS(7833),
    [sym_biginteger_literal] = ACTIONS(7835),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7835),
    [sym_integer] = ACTIONS(7833),
    [sym_continue_as_identifier] = ACTIONS(7835),
  },
  [STATE(3048)] = {
    [sym_boolean] = STATE(972),
    [sym_assignment_expression] = STATE(972),
    [sym__expression] = STATE(972),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(972),
    [sym_multiplicative_expression] = STATE(972),
    [sym_additive_expression] = STATE(972),
    [sym_comparison_expression] = STATE(972),
    [sym_logical_expression] = STATE(972),
    [sym_ternary_expression] = STATE(972),
    [sym_unary_expression] = STATE(972),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(972),
    [sym_list_literal] = STATE(972),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(972),
    [sym__literal_value] = STATE(972),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7837),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7839),
    [sym_date_literal] = ACTIONS(7837),
    [sym_time_literal] = ACTIONS(7837),
    [sym_biginteger_literal] = ACTIONS(7839),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7839),
    [sym_integer] = ACTIONS(7837),
    [sym_continue_as_identifier] = ACTIONS(7839),
  },
  [STATE(3049)] = {
    [sym_boolean] = STATE(1084),
    [sym_assignment_expression] = STATE(1084),
    [sym__expression] = STATE(1084),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1084),
    [sym_multiplicative_expression] = STATE(1084),
    [sym_additive_expression] = STATE(1084),
    [sym_comparison_expression] = STATE(1084),
    [sym_logical_expression] = STATE(1084),
    [sym_ternary_expression] = STATE(1084),
    [sym_unary_expression] = STATE(1084),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1084),
    [sym_list_literal] = STATE(1084),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1084),
    [sym__literal_value] = STATE(1084),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(7841),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(7843),
    [sym_date_literal] = ACTIONS(7841),
    [sym_time_literal] = ACTIONS(7841),
    [sym_biginteger_literal] = ACTIONS(7843),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7843),
    [sym_integer] = ACTIONS(7841),
    [sym_continue_as_identifier] = ACTIONS(7843),
  },
  [STATE(3050)] = {
    [sym_boolean] = STATE(953),
    [sym_assignment_expression] = STATE(953),
    [sym__expression] = STATE(953),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(953),
    [sym_multiplicative_expression] = STATE(953),
    [sym_additive_expression] = STATE(953),
    [sym_comparison_expression] = STATE(953),
    [sym_logical_expression] = STATE(953),
    [sym_ternary_expression] = STATE(953),
    [sym_unary_expression] = STATE(953),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(953),
    [sym_list_literal] = STATE(953),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(953),
    [sym__literal_value] = STATE(953),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7845),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7847),
    [sym_date_literal] = ACTIONS(7845),
    [sym_time_literal] = ACTIONS(7845),
    [sym_biginteger_literal] = ACTIONS(7847),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7847),
    [sym_integer] = ACTIONS(7845),
    [sym_continue_as_identifier] = ACTIONS(7847),
  },
  [STATE(3051)] = {
    [sym_boolean] = STATE(954),
    [sym_assignment_expression] = STATE(954),
    [sym__expression] = STATE(954),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(954),
    [sym_multiplicative_expression] = STATE(954),
    [sym_additive_expression] = STATE(954),
    [sym_comparison_expression] = STATE(954),
    [sym_logical_expression] = STATE(954),
    [sym_ternary_expression] = STATE(954),
    [sym_unary_expression] = STATE(954),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(954),
    [sym_list_literal] = STATE(954),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(954),
    [sym__literal_value] = STATE(954),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7849),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7851),
    [sym_date_literal] = ACTIONS(7849),
    [sym_time_literal] = ACTIONS(7849),
    [sym_biginteger_literal] = ACTIONS(7851),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7851),
    [sym_integer] = ACTIONS(7849),
    [sym_continue_as_identifier] = ACTIONS(7851),
  },
  [STATE(3052)] = {
    [sym_boolean] = STATE(956),
    [sym_assignment_expression] = STATE(956),
    [sym__expression] = STATE(956),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(956),
    [sym_multiplicative_expression] = STATE(956),
    [sym_additive_expression] = STATE(956),
    [sym_comparison_expression] = STATE(956),
    [sym_logical_expression] = STATE(956),
    [sym_ternary_expression] = STATE(956),
    [sym_unary_expression] = STATE(956),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(956),
    [sym_list_literal] = STATE(956),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(956),
    [sym__literal_value] = STATE(956),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7853),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7855),
    [sym_date_literal] = ACTIONS(7853),
    [sym_time_literal] = ACTIONS(7853),
    [sym_biginteger_literal] = ACTIONS(7855),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7855),
    [sym_integer] = ACTIONS(7853),
    [sym_continue_as_identifier] = ACTIONS(7855),
  },
  [STATE(3053)] = {
    [sym_boolean] = STATE(6303),
    [sym_assignment_expression] = STATE(6303),
    [sym__expression] = STATE(6303),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6303),
    [sym_multiplicative_expression] = STATE(6303),
    [sym_additive_expression] = STATE(6303),
    [sym_comparison_expression] = STATE(6303),
    [sym_logical_expression] = STATE(6303),
    [sym_ternary_expression] = STATE(6303),
    [sym_unary_expression] = STATE(6303),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6303),
    [sym_list_literal] = STATE(6303),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6303),
    [sym__literal_value] = STATE(6303),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7857),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7859),
    [sym_date_literal] = ACTIONS(7857),
    [sym_time_literal] = ACTIONS(7857),
    [sym_biginteger_literal] = ACTIONS(7859),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7859),
    [sym_integer] = ACTIONS(7857),
    [sym_continue_as_identifier] = ACTIONS(7859),
  },
  [STATE(3054)] = {
    [sym_boolean] = STATE(6214),
    [sym_assignment_expression] = STATE(6214),
    [sym__expression] = STATE(6214),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6214),
    [sym_multiplicative_expression] = STATE(6214),
    [sym_additive_expression] = STATE(6214),
    [sym_comparison_expression] = STATE(6214),
    [sym_logical_expression] = STATE(6214),
    [sym_ternary_expression] = STATE(6214),
    [sym_unary_expression] = STATE(6214),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6214),
    [sym_list_literal] = STATE(6214),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6214),
    [sym__literal_value] = STATE(6214),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7861),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7863),
    [sym_date_literal] = ACTIONS(7861),
    [sym_time_literal] = ACTIONS(7861),
    [sym_biginteger_literal] = ACTIONS(7863),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7863),
    [sym_integer] = ACTIONS(7861),
    [sym_continue_as_identifier] = ACTIONS(7863),
  },
  [STATE(3055)] = {
    [sym_boolean] = STATE(6296),
    [sym_assignment_expression] = STATE(6296),
    [sym__expression] = STATE(6296),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6296),
    [sym_multiplicative_expression] = STATE(6296),
    [sym_additive_expression] = STATE(6296),
    [sym_comparison_expression] = STATE(6296),
    [sym_logical_expression] = STATE(6296),
    [sym_ternary_expression] = STATE(6296),
    [sym_unary_expression] = STATE(6296),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6296),
    [sym_list_literal] = STATE(6296),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6296),
    [sym__literal_value] = STATE(6296),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7865),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7867),
    [sym_date_literal] = ACTIONS(7865),
    [sym_time_literal] = ACTIONS(7865),
    [sym_biginteger_literal] = ACTIONS(7867),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7867),
    [sym_integer] = ACTIONS(7865),
    [sym_continue_as_identifier] = ACTIONS(7867),
  },
  [STATE(3056)] = {
    [sym_boolean] = STATE(978),
    [sym_assignment_expression] = STATE(978),
    [sym__expression] = STATE(978),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(978),
    [sym_multiplicative_expression] = STATE(978),
    [sym_additive_expression] = STATE(978),
    [sym_comparison_expression] = STATE(978),
    [sym_logical_expression] = STATE(978),
    [sym_ternary_expression] = STATE(978),
    [sym_unary_expression] = STATE(978),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(978),
    [sym_list_literal] = STATE(978),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(978),
    [sym__literal_value] = STATE(978),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7869),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7871),
    [sym_date_literal] = ACTIONS(7869),
    [sym_time_literal] = ACTIONS(7869),
    [sym_biginteger_literal] = ACTIONS(7871),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7871),
    [sym_integer] = ACTIONS(7869),
    [sym_continue_as_identifier] = ACTIONS(7871),
  },
  [STATE(3057)] = {
    [sym_boolean] = STATE(6100),
    [sym_assignment_expression] = STATE(6100),
    [sym__expression] = STATE(6100),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6100),
    [sym_multiplicative_expression] = STATE(6100),
    [sym_additive_expression] = STATE(6100),
    [sym_comparison_expression] = STATE(6100),
    [sym_logical_expression] = STATE(6100),
    [sym_ternary_expression] = STATE(6100),
    [sym_unary_expression] = STATE(6100),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6100),
    [sym_list_literal] = STATE(6100),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6100),
    [sym__literal_value] = STATE(6100),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7873),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7875),
    [sym_date_literal] = ACTIONS(7873),
    [sym_time_literal] = ACTIONS(7873),
    [sym_biginteger_literal] = ACTIONS(7875),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7875),
    [sym_integer] = ACTIONS(7873),
    [sym_continue_as_identifier] = ACTIONS(7875),
  },
  [STATE(3058)] = {
    [sym_boolean] = STATE(6101),
    [sym_assignment_expression] = STATE(6101),
    [sym__expression] = STATE(6101),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6101),
    [sym_multiplicative_expression] = STATE(6101),
    [sym_additive_expression] = STATE(6101),
    [sym_comparison_expression] = STATE(6101),
    [sym_logical_expression] = STATE(6101),
    [sym_ternary_expression] = STATE(6101),
    [sym_unary_expression] = STATE(6101),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6101),
    [sym_list_literal] = STATE(6101),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6101),
    [sym__literal_value] = STATE(6101),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7877),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7879),
    [sym_date_literal] = ACTIONS(7877),
    [sym_time_literal] = ACTIONS(7877),
    [sym_biginteger_literal] = ACTIONS(7879),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7879),
    [sym_integer] = ACTIONS(7877),
    [sym_continue_as_identifier] = ACTIONS(7879),
  },
  [STATE(3059)] = {
    [sym_boolean] = STATE(6279),
    [sym_assignment_expression] = STATE(6279),
    [sym__expression] = STATE(6279),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6279),
    [sym_multiplicative_expression] = STATE(6279),
    [sym_additive_expression] = STATE(6279),
    [sym_comparison_expression] = STATE(6279),
    [sym_logical_expression] = STATE(6279),
    [sym_ternary_expression] = STATE(6279),
    [sym_unary_expression] = STATE(6279),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6279),
    [sym_list_literal] = STATE(6279),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6279),
    [sym__literal_value] = STATE(6279),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7881),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(7883),
    [sym_date_literal] = ACTIONS(7881),
    [sym_time_literal] = ACTIONS(7881),
    [sym_biginteger_literal] = ACTIONS(7883),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7883),
    [sym_integer] = ACTIONS(7881),
    [sym_continue_as_identifier] = ACTIONS(7883),
  },
  [STATE(3060)] = {
    [sym_boolean] = STATE(6103),
    [sym_assignment_expression] = STATE(6103),
    [sym__expression] = STATE(6103),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6103),
    [sym_multiplicative_expression] = STATE(6103),
    [sym_additive_expression] = STATE(6103),
    [sym_comparison_expression] = STATE(6103),
    [sym_logical_expression] = STATE(6103),
    [sym_ternary_expression] = STATE(6103),
    [sym_unary_expression] = STATE(6103),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6103),
    [sym_list_literal] = STATE(6103),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6103),
    [sym__literal_value] = STATE(6103),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7885),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7887),
    [sym_date_literal] = ACTIONS(7885),
    [sym_time_literal] = ACTIONS(7885),
    [sym_biginteger_literal] = ACTIONS(7887),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7887),
    [sym_integer] = ACTIONS(7885),
    [sym_continue_as_identifier] = ACTIONS(7887),
  },
  [STATE(3061)] = {
    [sym_boolean] = STATE(6270),
    [sym_assignment_expression] = STATE(6270),
    [sym__expression] = STATE(6270),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6270),
    [sym_multiplicative_expression] = STATE(6270),
    [sym_additive_expression] = STATE(6270),
    [sym_comparison_expression] = STATE(6270),
    [sym_logical_expression] = STATE(6270),
    [sym_ternary_expression] = STATE(6270),
    [sym_unary_expression] = STATE(6270),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6270),
    [sym_list_literal] = STATE(6270),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6270),
    [sym__literal_value] = STATE(6270),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7889),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(7891),
    [sym_date_literal] = ACTIONS(7889),
    [sym_time_literal] = ACTIONS(7889),
    [sym_biginteger_literal] = ACTIONS(7891),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7891),
    [sym_integer] = ACTIONS(7889),
    [sym_continue_as_identifier] = ACTIONS(7891),
  },
  [STATE(3062)] = {
    [sym_identifier] = ACTIONS(4443),
    [anon_sym_SEMI] = ACTIONS(4445),
    [aux_sym_where_condition_token1] = ACTIONS(4443),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4443),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4443),
    [anon_sym_LBRACK] = ACTIONS(4445),
    [aux_sym_basic_type_token6] = ACTIONS(4443),
    [aux_sym_basic_type_token22] = ACTIONS(4443),
    [aux_sym_basic_type_token53] = ACTIONS(4443),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4443),
    [aux_sym_addafter_modification_token1] = ACTIONS(4443),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4443),
    [aux_sym_modify_modification_token1] = ACTIONS(4443),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4443),
    [aux_sym_movelast_modification_token1] = ACTIONS(4443),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4443),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4443),
    [aux_sym_separator_action_token1] = ACTIONS(4443),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4443),
    [aux_sym_type_declaration_token1] = ACTIONS(4443),
    [anon_sym_POUNDif] = ACTIONS(4445),
    [anon_sym_POUNDIF] = ACTIONS(4445),
    [anon_sym_POUNDIf] = ACTIONS(4445),
    [anon_sym_POUNDelif] = ACTIONS(4445),
    [anon_sym_POUNDELIF] = ACTIONS(4445),
    [anon_sym_POUNDElif] = ACTIONS(4445),
    [anon_sym_POUNDelse] = ACTIONS(4445),
    [anon_sym_POUNDELSE] = ACTIONS(4445),
    [anon_sym_POUNDElse] = ACTIONS(4445),
    [anon_sym_POUNDendif] = ACTIONS(4445),
    [anon_sym_POUNDENDIF] = ACTIONS(4445),
    [anon_sym_POUNDEndif] = ACTIONS(4445),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4443),
    [sym_trigger_keyword] = ACTIONS(4443),
    [sym_var_keyword] = ACTIONS(4443),
    [sym_local_keyword] = ACTIONS(4443),
    [sym_internal_keyword] = ACTIONS(4443),
    [sym_protected_keyword] = ACTIONS(4443),
    [sym_event_keyword] = ACTIONS(4443),
    [sym_fields_keyword] = ACTIONS(4443),
    [sym_keys_keyword] = ACTIONS(4443),
    [sym_key_keyword] = ACTIONS(4443),
    [sym_fieldgroups_keyword] = ACTIONS(4443),
    [sym_actions_keyword] = ACTIONS(4443),
    [sym_layout_keyword] = ACTIONS(4443),
    [sym_area_keyword] = ACTIONS(4443),
    [sym_group_keyword] = ACTIONS(4443),
    [sym_repeater_keyword] = ACTIONS(4443),
    [sym_cuegroup_keyword] = ACTIONS(4443),
    [sym_fixed_keyword] = ACTIONS(4443),
    [sym_grid_keyword] = ACTIONS(4443),
    [sym_part_keyword] = ACTIONS(4443),
    [sym_systempart_keyword] = ACTIONS(4443),
    [sym_usercontrol_keyword] = ACTIONS(4443),
    [sym_dataset_keyword] = ACTIONS(4443),
    [sym_elements_keyword] = ACTIONS(4443),
    [sym_dataitem_keyword] = ACTIONS(4443),
    [sym_column_keyword] = ACTIONS(4443),
    [sym_filter_keyword] = ACTIONS(4443),
    [sym_labels_keyword] = ACTIONS(4443),
    [sym_rendering_keyword] = ACTIONS(4443),
    [sym_requestpage_keyword] = ACTIONS(4443),
    [sym_schema_keyword] = ACTIONS(4443),
    [sym_views_keyword] = ACTIONS(4443),
    [sym_quoted_identifier] = ACTIONS(4445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4445),
    [sym_preproc_open] = ACTIONS(4445),
    [sym_preproc_close] = ACTIONS(4445),
    [sym_var_attribute_open] = ACTIONS(4445),
  },
  [STATE(3063)] = {
    [sym_boolean] = STATE(959),
    [sym_assignment_expression] = STATE(959),
    [sym__expression] = STATE(959),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(959),
    [sym_multiplicative_expression] = STATE(959),
    [sym_additive_expression] = STATE(959),
    [sym_comparison_expression] = STATE(959),
    [sym_logical_expression] = STATE(959),
    [sym_ternary_expression] = STATE(959),
    [sym_unary_expression] = STATE(959),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(959),
    [sym_list_literal] = STATE(959),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(959),
    [sym__literal_value] = STATE(959),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7893),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7895),
    [sym_date_literal] = ACTIONS(7893),
    [sym_time_literal] = ACTIONS(7893),
    [sym_biginteger_literal] = ACTIONS(7895),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7895),
    [sym_integer] = ACTIONS(7893),
    [sym_continue_as_identifier] = ACTIONS(7895),
  },
  [STATE(3064)] = {
    [sym_boolean] = STATE(6136),
    [sym_assignment_expression] = STATE(6136),
    [sym__expression] = STATE(6136),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6136),
    [sym_multiplicative_expression] = STATE(6136),
    [sym_additive_expression] = STATE(6136),
    [sym_comparison_expression] = STATE(6136),
    [sym_logical_expression] = STATE(6136),
    [sym_ternary_expression] = STATE(6136),
    [sym_unary_expression] = STATE(6136),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6136),
    [sym_list_literal] = STATE(6136),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6136),
    [sym__literal_value] = STATE(6136),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7897),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7899),
    [sym_date_literal] = ACTIONS(7897),
    [sym_time_literal] = ACTIONS(7897),
    [sym_biginteger_literal] = ACTIONS(7899),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7899),
    [sym_integer] = ACTIONS(7897),
    [sym_continue_as_identifier] = ACTIONS(7899),
  },
  [STATE(3065)] = {
    [sym_boolean] = STATE(6278),
    [sym_assignment_expression] = STATE(6278),
    [sym__expression] = STATE(6278),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6278),
    [sym_multiplicative_expression] = STATE(6278),
    [sym_additive_expression] = STATE(6278),
    [sym_comparison_expression] = STATE(6278),
    [sym_logical_expression] = STATE(6278),
    [sym_ternary_expression] = STATE(6278),
    [sym_unary_expression] = STATE(6278),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6278),
    [sym_list_literal] = STATE(6278),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6278),
    [sym__literal_value] = STATE(6278),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7901),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(7903),
    [sym_date_literal] = ACTIONS(7901),
    [sym_time_literal] = ACTIONS(7901),
    [sym_biginteger_literal] = ACTIONS(7903),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7903),
    [sym_integer] = ACTIONS(7901),
    [sym_continue_as_identifier] = ACTIONS(7903),
  },
  [STATE(3066)] = {
    [sym_boolean] = STATE(962),
    [sym_assignment_expression] = STATE(962),
    [sym__expression] = STATE(962),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(962),
    [sym_multiplicative_expression] = STATE(962),
    [sym_additive_expression] = STATE(962),
    [sym_comparison_expression] = STATE(962),
    [sym_logical_expression] = STATE(962),
    [sym_ternary_expression] = STATE(962),
    [sym_unary_expression] = STATE(962),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(962),
    [sym_list_literal] = STATE(962),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(962),
    [sym__literal_value] = STATE(962),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7905),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7907),
    [sym_date_literal] = ACTIONS(7905),
    [sym_time_literal] = ACTIONS(7905),
    [sym_biginteger_literal] = ACTIONS(7907),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7907),
    [sym_integer] = ACTIONS(7905),
    [sym_continue_as_identifier] = ACTIONS(7907),
  },
  [STATE(3067)] = {
    [sym_boolean] = STATE(963),
    [sym_assignment_expression] = STATE(963),
    [sym__expression] = STATE(963),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(963),
    [sym_multiplicative_expression] = STATE(963),
    [sym_additive_expression] = STATE(963),
    [sym_comparison_expression] = STATE(963),
    [sym_logical_expression] = STATE(963),
    [sym_ternary_expression] = STATE(963),
    [sym_unary_expression] = STATE(963),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(963),
    [sym_list_literal] = STATE(963),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(963),
    [sym__literal_value] = STATE(963),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7909),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7911),
    [sym_date_literal] = ACTIONS(7909),
    [sym_time_literal] = ACTIONS(7909),
    [sym_biginteger_literal] = ACTIONS(7911),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7911),
    [sym_integer] = ACTIONS(7909),
    [sym_continue_as_identifier] = ACTIONS(7911),
  },
  [STATE(3068)] = {
    [sym_boolean] = STATE(6137),
    [sym_assignment_expression] = STATE(6137),
    [sym__expression] = STATE(6137),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6137),
    [sym_multiplicative_expression] = STATE(6137),
    [sym_additive_expression] = STATE(6137),
    [sym_comparison_expression] = STATE(6137),
    [sym_logical_expression] = STATE(6137),
    [sym_ternary_expression] = STATE(6137),
    [sym_unary_expression] = STATE(6137),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6137),
    [sym_list_literal] = STATE(6137),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6137),
    [sym__literal_value] = STATE(6137),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7913),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7915),
    [sym_date_literal] = ACTIONS(7913),
    [sym_time_literal] = ACTIONS(7913),
    [sym_biginteger_literal] = ACTIONS(7915),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7915),
    [sym_integer] = ACTIONS(7913),
    [sym_continue_as_identifier] = ACTIONS(7915),
  },
  [STATE(3069)] = {
    [sym_boolean] = STATE(6192),
    [sym_assignment_expression] = STATE(6192),
    [sym__expression] = STATE(6192),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6192),
    [sym_multiplicative_expression] = STATE(6192),
    [sym_additive_expression] = STATE(6192),
    [sym_comparison_expression] = STATE(6192),
    [sym_logical_expression] = STATE(6192),
    [sym_ternary_expression] = STATE(6192),
    [sym_unary_expression] = STATE(6192),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6192),
    [sym_list_literal] = STATE(6192),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6192),
    [sym__literal_value] = STATE(6192),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7917),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7919),
    [sym_date_literal] = ACTIONS(7917),
    [sym_time_literal] = ACTIONS(7917),
    [sym_biginteger_literal] = ACTIONS(7919),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7919),
    [sym_integer] = ACTIONS(7917),
    [sym_continue_as_identifier] = ACTIONS(7919),
  },
  [STATE(3070)] = {
    [sym_boolean] = STATE(964),
    [sym_assignment_expression] = STATE(964),
    [sym__expression] = STATE(964),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(964),
    [sym_multiplicative_expression] = STATE(964),
    [sym_additive_expression] = STATE(964),
    [sym_comparison_expression] = STATE(964),
    [sym_logical_expression] = STATE(964),
    [sym_ternary_expression] = STATE(964),
    [sym_unary_expression] = STATE(964),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(964),
    [sym_list_literal] = STATE(964),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(964),
    [sym__literal_value] = STATE(964),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7921),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7923),
    [sym_date_literal] = ACTIONS(7921),
    [sym_time_literal] = ACTIONS(7921),
    [sym_biginteger_literal] = ACTIONS(7923),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7923),
    [sym_integer] = ACTIONS(7921),
    [sym_continue_as_identifier] = ACTIONS(7923),
  },
  [STATE(3071)] = {
    [sym_identifier] = ACTIONS(4447),
    [anon_sym_SEMI] = ACTIONS(4449),
    [aux_sym_where_condition_token1] = ACTIONS(4447),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4447),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4447),
    [anon_sym_LBRACK] = ACTIONS(4449),
    [aux_sym_basic_type_token6] = ACTIONS(4447),
    [aux_sym_basic_type_token22] = ACTIONS(4447),
    [aux_sym_basic_type_token53] = ACTIONS(4447),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4447),
    [aux_sym_addafter_modification_token1] = ACTIONS(4447),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(4447),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4447),
    [aux_sym_movelast_modification_token1] = ACTIONS(4447),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4447),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4447),
    [aux_sym_separator_action_token1] = ACTIONS(4447),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4447),
    [aux_sym_type_declaration_token1] = ACTIONS(4447),
    [anon_sym_POUNDif] = ACTIONS(4449),
    [anon_sym_POUNDIF] = ACTIONS(4449),
    [anon_sym_POUNDIf] = ACTIONS(4449),
    [anon_sym_POUNDelif] = ACTIONS(4449),
    [anon_sym_POUNDELIF] = ACTIONS(4449),
    [anon_sym_POUNDElif] = ACTIONS(4449),
    [anon_sym_POUNDelse] = ACTIONS(4449),
    [anon_sym_POUNDELSE] = ACTIONS(4449),
    [anon_sym_POUNDElse] = ACTIONS(4449),
    [anon_sym_POUNDendif] = ACTIONS(4449),
    [anon_sym_POUNDENDIF] = ACTIONS(4449),
    [anon_sym_POUNDEndif] = ACTIONS(4449),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4447),
    [sym_trigger_keyword] = ACTIONS(4447),
    [sym_var_keyword] = ACTIONS(4447),
    [sym_local_keyword] = ACTIONS(4447),
    [sym_internal_keyword] = ACTIONS(4447),
    [sym_protected_keyword] = ACTIONS(4447),
    [sym_event_keyword] = ACTIONS(4447),
    [sym_fields_keyword] = ACTIONS(4447),
    [sym_keys_keyword] = ACTIONS(4447),
    [sym_key_keyword] = ACTIONS(4447),
    [sym_fieldgroups_keyword] = ACTIONS(4447),
    [sym_actions_keyword] = ACTIONS(4447),
    [sym_layout_keyword] = ACTIONS(4447),
    [sym_area_keyword] = ACTIONS(4447),
    [sym_group_keyword] = ACTIONS(4447),
    [sym_repeater_keyword] = ACTIONS(4447),
    [sym_cuegroup_keyword] = ACTIONS(4447),
    [sym_fixed_keyword] = ACTIONS(4447),
    [sym_grid_keyword] = ACTIONS(4447),
    [sym_part_keyword] = ACTIONS(4447),
    [sym_systempart_keyword] = ACTIONS(4447),
    [sym_usercontrol_keyword] = ACTIONS(4447),
    [sym_dataset_keyword] = ACTIONS(4447),
    [sym_elements_keyword] = ACTIONS(4447),
    [sym_dataitem_keyword] = ACTIONS(4447),
    [sym_column_keyword] = ACTIONS(4447),
    [sym_filter_keyword] = ACTIONS(4447),
    [sym_labels_keyword] = ACTIONS(4447),
    [sym_rendering_keyword] = ACTIONS(4447),
    [sym_requestpage_keyword] = ACTIONS(4447),
    [sym_schema_keyword] = ACTIONS(4447),
    [sym_views_keyword] = ACTIONS(4447),
    [sym_quoted_identifier] = ACTIONS(4449),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4449),
    [sym_preproc_open] = ACTIONS(4449),
    [sym_preproc_close] = ACTIONS(4449),
    [sym_var_attribute_open] = ACTIONS(4449),
  },
  [STATE(3072)] = {
    [sym_boolean] = STATE(6294),
    [sym_assignment_expression] = STATE(6294),
    [sym__expression] = STATE(6294),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6294),
    [sym_multiplicative_expression] = STATE(6294),
    [sym_additive_expression] = STATE(6294),
    [sym_comparison_expression] = STATE(6294),
    [sym_logical_expression] = STATE(6294),
    [sym_ternary_expression] = STATE(6294),
    [sym_unary_expression] = STATE(6294),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6294),
    [sym_list_literal] = STATE(6294),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6294),
    [sym__literal_value] = STATE(6294),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7925),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(7927),
    [sym_date_literal] = ACTIONS(7925),
    [sym_time_literal] = ACTIONS(7925),
    [sym_biginteger_literal] = ACTIONS(7927),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7927),
    [sym_integer] = ACTIONS(7925),
    [sym_continue_as_identifier] = ACTIONS(7927),
  },
  [STATE(3073)] = {
    [sym_boolean] = STATE(1156),
    [sym_assignment_expression] = STATE(1156),
    [sym__expression] = STATE(1156),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1156),
    [sym_multiplicative_expression] = STATE(1156),
    [sym_additive_expression] = STATE(1156),
    [sym_comparison_expression] = STATE(1156),
    [sym_logical_expression] = STATE(1156),
    [sym_ternary_expression] = STATE(1156),
    [sym_unary_expression] = STATE(1156),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1156),
    [sym_list_literal] = STATE(1156),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1156),
    [sym__literal_value] = STATE(1156),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(7929),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(7931),
    [sym_date_literal] = ACTIONS(7929),
    [sym_time_literal] = ACTIONS(7929),
    [sym_biginteger_literal] = ACTIONS(7931),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7931),
    [sym_integer] = ACTIONS(7929),
    [sym_continue_as_identifier] = ACTIONS(7931),
  },
  [STATE(3074)] = {
    [sym_identifier] = ACTIONS(7933),
    [anon_sym_SEMI] = ACTIONS(7935),
    [aux_sym_where_condition_token1] = ACTIONS(7933),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7933),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7933),
    [anon_sym_LBRACK] = ACTIONS(7935),
    [aux_sym_basic_type_token6] = ACTIONS(7933),
    [aux_sym_basic_type_token22] = ACTIONS(7933),
    [aux_sym_basic_type_token53] = ACTIONS(7933),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7933),
    [aux_sym_addafter_modification_token1] = ACTIONS(7933),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7933),
    [aux_sym_modify_modification_token1] = ACTIONS(7933),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7933),
    [aux_sym_movelast_modification_token1] = ACTIONS(7933),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7933),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7933),
    [aux_sym_separator_action_token1] = ACTIONS(7933),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7933),
    [aux_sym_type_declaration_token1] = ACTIONS(7933),
    [anon_sym_POUNDif] = ACTIONS(7935),
    [anon_sym_POUNDIF] = ACTIONS(7935),
    [anon_sym_POUNDIf] = ACTIONS(7935),
    [anon_sym_POUNDelif] = ACTIONS(7935),
    [anon_sym_POUNDELIF] = ACTIONS(7935),
    [anon_sym_POUNDElif] = ACTIONS(7935),
    [anon_sym_POUNDelse] = ACTIONS(7935),
    [anon_sym_POUNDELSE] = ACTIONS(7935),
    [anon_sym_POUNDElse] = ACTIONS(7935),
    [anon_sym_POUNDendif] = ACTIONS(7935),
    [anon_sym_POUNDENDIF] = ACTIONS(7935),
    [anon_sym_POUNDEndif] = ACTIONS(7935),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7933),
    [sym_trigger_keyword] = ACTIONS(7933),
    [sym_var_keyword] = ACTIONS(7933),
    [sym_local_keyword] = ACTIONS(7933),
    [sym_internal_keyword] = ACTIONS(7933),
    [sym_protected_keyword] = ACTIONS(7933),
    [sym_event_keyword] = ACTIONS(7933),
    [sym_fields_keyword] = ACTIONS(7933),
    [sym_keys_keyword] = ACTIONS(7933),
    [sym_key_keyword] = ACTIONS(7933),
    [sym_fieldgroups_keyword] = ACTIONS(7933),
    [sym_actions_keyword] = ACTIONS(7933),
    [sym_layout_keyword] = ACTIONS(7933),
    [sym_area_keyword] = ACTIONS(7933),
    [sym_group_keyword] = ACTIONS(7933),
    [sym_repeater_keyword] = ACTIONS(7933),
    [sym_cuegroup_keyword] = ACTIONS(7933),
    [sym_fixed_keyword] = ACTIONS(7933),
    [sym_grid_keyword] = ACTIONS(7933),
    [sym_part_keyword] = ACTIONS(7933),
    [sym_systempart_keyword] = ACTIONS(7933),
    [sym_usercontrol_keyword] = ACTIONS(7933),
    [sym_dataset_keyword] = ACTIONS(7933),
    [sym_elements_keyword] = ACTIONS(7933),
    [sym_dataitem_keyword] = ACTIONS(7933),
    [sym_column_keyword] = ACTIONS(7933),
    [sym_filter_keyword] = ACTIONS(7933),
    [sym_labels_keyword] = ACTIONS(7933),
    [sym_rendering_keyword] = ACTIONS(7933),
    [sym_requestpage_keyword] = ACTIONS(7933),
    [sym_schema_keyword] = ACTIONS(7933),
    [sym_views_keyword] = ACTIONS(7933),
    [sym_quoted_identifier] = ACTIONS(7935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7935),
    [sym_preproc_open] = ACTIONS(7935),
    [sym_preproc_close] = ACTIONS(7935),
    [sym_var_attribute_open] = ACTIONS(7935),
  },
  [STATE(3075)] = {
    [sym_identifier] = ACTIONS(7937),
    [anon_sym_SEMI] = ACTIONS(7939),
    [aux_sym_where_condition_token1] = ACTIONS(7937),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7937),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7937),
    [anon_sym_LBRACK] = ACTIONS(7939),
    [aux_sym_basic_type_token6] = ACTIONS(7937),
    [aux_sym_basic_type_token22] = ACTIONS(7937),
    [aux_sym_basic_type_token53] = ACTIONS(7937),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7937),
    [aux_sym_addafter_modification_token1] = ACTIONS(7937),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7937),
    [aux_sym_modify_modification_token1] = ACTIONS(7937),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7937),
    [aux_sym_movelast_modification_token1] = ACTIONS(7937),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7937),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7937),
    [aux_sym_separator_action_token1] = ACTIONS(7937),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7937),
    [aux_sym_type_declaration_token1] = ACTIONS(7937),
    [anon_sym_POUNDif] = ACTIONS(7939),
    [anon_sym_POUNDIF] = ACTIONS(7939),
    [anon_sym_POUNDIf] = ACTIONS(7939),
    [anon_sym_POUNDelif] = ACTIONS(7939),
    [anon_sym_POUNDELIF] = ACTIONS(7939),
    [anon_sym_POUNDElif] = ACTIONS(7939),
    [anon_sym_POUNDelse] = ACTIONS(7939),
    [anon_sym_POUNDELSE] = ACTIONS(7939),
    [anon_sym_POUNDElse] = ACTIONS(7939),
    [anon_sym_POUNDendif] = ACTIONS(7939),
    [anon_sym_POUNDENDIF] = ACTIONS(7939),
    [anon_sym_POUNDEndif] = ACTIONS(7939),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7937),
    [sym_trigger_keyword] = ACTIONS(7937),
    [sym_var_keyword] = ACTIONS(7937),
    [sym_local_keyword] = ACTIONS(7937),
    [sym_internal_keyword] = ACTIONS(7937),
    [sym_protected_keyword] = ACTIONS(7937),
    [sym_event_keyword] = ACTIONS(7937),
    [sym_fields_keyword] = ACTIONS(7937),
    [sym_keys_keyword] = ACTIONS(7937),
    [sym_key_keyword] = ACTIONS(7937),
    [sym_fieldgroups_keyword] = ACTIONS(7937),
    [sym_actions_keyword] = ACTIONS(7937),
    [sym_layout_keyword] = ACTIONS(7937),
    [sym_area_keyword] = ACTIONS(7937),
    [sym_group_keyword] = ACTIONS(7937),
    [sym_repeater_keyword] = ACTIONS(7937),
    [sym_cuegroup_keyword] = ACTIONS(7937),
    [sym_fixed_keyword] = ACTIONS(7937),
    [sym_grid_keyword] = ACTIONS(7937),
    [sym_part_keyword] = ACTIONS(7937),
    [sym_systempart_keyword] = ACTIONS(7937),
    [sym_usercontrol_keyword] = ACTIONS(7937),
    [sym_dataset_keyword] = ACTIONS(7937),
    [sym_elements_keyword] = ACTIONS(7937),
    [sym_dataitem_keyword] = ACTIONS(7937),
    [sym_column_keyword] = ACTIONS(7937),
    [sym_filter_keyword] = ACTIONS(7937),
    [sym_labels_keyword] = ACTIONS(7937),
    [sym_rendering_keyword] = ACTIONS(7937),
    [sym_requestpage_keyword] = ACTIONS(7937),
    [sym_schema_keyword] = ACTIONS(7937),
    [sym_views_keyword] = ACTIONS(7937),
    [sym_quoted_identifier] = ACTIONS(7939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7939),
    [sym_preproc_open] = ACTIONS(7939),
    [sym_preproc_close] = ACTIONS(7939),
    [sym_var_attribute_open] = ACTIONS(7939),
  },
  [STATE(3076)] = {
    [sym_identifier] = ACTIONS(7941),
    [anon_sym_SEMI] = ACTIONS(7943),
    [aux_sym_where_condition_token1] = ACTIONS(7941),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7941),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7941),
    [anon_sym_LBRACK] = ACTIONS(7943),
    [aux_sym_basic_type_token6] = ACTIONS(7941),
    [aux_sym_basic_type_token22] = ACTIONS(7941),
    [aux_sym_basic_type_token53] = ACTIONS(7941),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7941),
    [aux_sym_addafter_modification_token1] = ACTIONS(7941),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7941),
    [aux_sym_modify_modification_token1] = ACTIONS(7941),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7941),
    [aux_sym_movelast_modification_token1] = ACTIONS(7941),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7941),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7941),
    [aux_sym_separator_action_token1] = ACTIONS(7941),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7941),
    [aux_sym_type_declaration_token1] = ACTIONS(7941),
    [anon_sym_POUNDif] = ACTIONS(7943),
    [anon_sym_POUNDIF] = ACTIONS(7943),
    [anon_sym_POUNDIf] = ACTIONS(7943),
    [anon_sym_POUNDelif] = ACTIONS(7943),
    [anon_sym_POUNDELIF] = ACTIONS(7943),
    [anon_sym_POUNDElif] = ACTIONS(7943),
    [anon_sym_POUNDelse] = ACTIONS(7943),
    [anon_sym_POUNDELSE] = ACTIONS(7943),
    [anon_sym_POUNDElse] = ACTIONS(7943),
    [anon_sym_POUNDendif] = ACTIONS(7943),
    [anon_sym_POUNDENDIF] = ACTIONS(7943),
    [anon_sym_POUNDEndif] = ACTIONS(7943),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7941),
    [sym_trigger_keyword] = ACTIONS(7941),
    [sym_var_keyword] = ACTIONS(7941),
    [sym_local_keyword] = ACTIONS(7941),
    [sym_internal_keyword] = ACTIONS(7941),
    [sym_protected_keyword] = ACTIONS(7941),
    [sym_event_keyword] = ACTIONS(7941),
    [sym_fields_keyword] = ACTIONS(7941),
    [sym_keys_keyword] = ACTIONS(7941),
    [sym_key_keyword] = ACTIONS(7941),
    [sym_fieldgroups_keyword] = ACTIONS(7941),
    [sym_actions_keyword] = ACTIONS(7941),
    [sym_layout_keyword] = ACTIONS(7941),
    [sym_area_keyword] = ACTIONS(7941),
    [sym_group_keyword] = ACTIONS(7941),
    [sym_repeater_keyword] = ACTIONS(7941),
    [sym_cuegroup_keyword] = ACTIONS(7941),
    [sym_fixed_keyword] = ACTIONS(7941),
    [sym_grid_keyword] = ACTIONS(7941),
    [sym_part_keyword] = ACTIONS(7941),
    [sym_systempart_keyword] = ACTIONS(7941),
    [sym_usercontrol_keyword] = ACTIONS(7941),
    [sym_dataset_keyword] = ACTIONS(7941),
    [sym_elements_keyword] = ACTIONS(7941),
    [sym_dataitem_keyword] = ACTIONS(7941),
    [sym_column_keyword] = ACTIONS(7941),
    [sym_filter_keyword] = ACTIONS(7941),
    [sym_labels_keyword] = ACTIONS(7941),
    [sym_rendering_keyword] = ACTIONS(7941),
    [sym_requestpage_keyword] = ACTIONS(7941),
    [sym_schema_keyword] = ACTIONS(7941),
    [sym_views_keyword] = ACTIONS(7941),
    [sym_quoted_identifier] = ACTIONS(7943),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7943),
    [sym_preproc_open] = ACTIONS(7943),
    [sym_preproc_close] = ACTIONS(7943),
    [sym_var_attribute_open] = ACTIONS(7943),
  },
  [STATE(3077)] = {
    [sym_boolean] = STATE(965),
    [sym_assignment_expression] = STATE(965),
    [sym__expression] = STATE(965),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(965),
    [sym_multiplicative_expression] = STATE(965),
    [sym_additive_expression] = STATE(965),
    [sym_comparison_expression] = STATE(965),
    [sym_logical_expression] = STATE(965),
    [sym_ternary_expression] = STATE(965),
    [sym_unary_expression] = STATE(965),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(965),
    [sym_list_literal] = STATE(965),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(965),
    [sym__literal_value] = STATE(965),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7945),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7947),
    [sym_date_literal] = ACTIONS(7945),
    [sym_time_literal] = ACTIONS(7945),
    [sym_biginteger_literal] = ACTIONS(7947),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7947),
    [sym_integer] = ACTIONS(7945),
    [sym_continue_as_identifier] = ACTIONS(7947),
  },
  [STATE(3078)] = {
    [sym_boolean] = STATE(966),
    [sym_assignment_expression] = STATE(966),
    [sym__expression] = STATE(966),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(966),
    [sym_multiplicative_expression] = STATE(966),
    [sym_additive_expression] = STATE(966),
    [sym_comparison_expression] = STATE(966),
    [sym_logical_expression] = STATE(966),
    [sym_ternary_expression] = STATE(966),
    [sym_unary_expression] = STATE(966),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(966),
    [sym_list_literal] = STATE(966),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(966),
    [sym__literal_value] = STATE(966),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7949),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7951),
    [sym_date_literal] = ACTIONS(7949),
    [sym_time_literal] = ACTIONS(7949),
    [sym_biginteger_literal] = ACTIONS(7951),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7951),
    [sym_integer] = ACTIONS(7949),
    [sym_continue_as_identifier] = ACTIONS(7951),
  },
  [STATE(3079)] = {
    [sym_boolean] = STATE(967),
    [sym_assignment_expression] = STATE(967),
    [sym__expression] = STATE(967),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(967),
    [sym_multiplicative_expression] = STATE(967),
    [sym_additive_expression] = STATE(967),
    [sym_comparison_expression] = STATE(967),
    [sym_logical_expression] = STATE(967),
    [sym_ternary_expression] = STATE(967),
    [sym_unary_expression] = STATE(967),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(967),
    [sym_list_literal] = STATE(967),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(967),
    [sym__literal_value] = STATE(967),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7953),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7955),
    [sym_date_literal] = ACTIONS(7953),
    [sym_time_literal] = ACTIONS(7953),
    [sym_biginteger_literal] = ACTIONS(7955),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7955),
    [sym_integer] = ACTIONS(7953),
    [sym_continue_as_identifier] = ACTIONS(7955),
  },
  [STATE(3080)] = {
    [sym_boolean] = STATE(968),
    [sym_assignment_expression] = STATE(968),
    [sym__expression] = STATE(968),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(968),
    [sym_multiplicative_expression] = STATE(968),
    [sym_additive_expression] = STATE(968),
    [sym_comparison_expression] = STATE(968),
    [sym_logical_expression] = STATE(968),
    [sym_ternary_expression] = STATE(968),
    [sym_unary_expression] = STATE(968),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(968),
    [sym_list_literal] = STATE(968),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(968),
    [sym__literal_value] = STATE(968),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(7957),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(7959),
    [sym_date_literal] = ACTIONS(7957),
    [sym_time_literal] = ACTIONS(7957),
    [sym_biginteger_literal] = ACTIONS(7959),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7959),
    [sym_integer] = ACTIONS(7957),
    [sym_continue_as_identifier] = ACTIONS(7959),
  },
  [STATE(3081)] = {
    [sym_boolean] = STATE(6132),
    [sym_assignment_expression] = STATE(6132),
    [sym__expression] = STATE(6132),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6132),
    [sym_multiplicative_expression] = STATE(6132),
    [sym_additive_expression] = STATE(6132),
    [sym_comparison_expression] = STATE(6132),
    [sym_logical_expression] = STATE(6132),
    [sym_ternary_expression] = STATE(6132),
    [sym_unary_expression] = STATE(6132),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6132),
    [sym_list_literal] = STATE(6132),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6132),
    [sym__literal_value] = STATE(6132),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7961),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(7963),
    [sym_date_literal] = ACTIONS(7961),
    [sym_time_literal] = ACTIONS(7961),
    [sym_biginteger_literal] = ACTIONS(7963),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7963),
    [sym_integer] = ACTIONS(7961),
    [sym_continue_as_identifier] = ACTIONS(7963),
  },
  [STATE(3082)] = {
    [sym_boolean] = STATE(6133),
    [sym_assignment_expression] = STATE(6133),
    [sym__expression] = STATE(6133),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6133),
    [sym_multiplicative_expression] = STATE(6133),
    [sym_additive_expression] = STATE(6133),
    [sym_comparison_expression] = STATE(6133),
    [sym_logical_expression] = STATE(6133),
    [sym_ternary_expression] = STATE(6133),
    [sym_unary_expression] = STATE(6133),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6133),
    [sym_list_literal] = STATE(6133),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6133),
    [sym__literal_value] = STATE(6133),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7965),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(7967),
    [sym_date_literal] = ACTIONS(7965),
    [sym_time_literal] = ACTIONS(7965),
    [sym_biginteger_literal] = ACTIONS(7967),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7967),
    [sym_integer] = ACTIONS(7965),
    [sym_continue_as_identifier] = ACTIONS(7967),
  },
  [STATE(3083)] = {
    [sym_boolean] = STATE(6277),
    [sym_assignment_expression] = STATE(6277),
    [sym__expression] = STATE(6277),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6277),
    [sym_multiplicative_expression] = STATE(6277),
    [sym_additive_expression] = STATE(6277),
    [sym_comparison_expression] = STATE(6277),
    [sym_logical_expression] = STATE(6277),
    [sym_ternary_expression] = STATE(6277),
    [sym_unary_expression] = STATE(6277),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6277),
    [sym_list_literal] = STATE(6277),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6277),
    [sym__literal_value] = STATE(6277),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7969),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7971),
    [sym_date_literal] = ACTIONS(7969),
    [sym_time_literal] = ACTIONS(7969),
    [sym_biginteger_literal] = ACTIONS(7971),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7971),
    [sym_integer] = ACTIONS(7969),
    [sym_continue_as_identifier] = ACTIONS(7971),
  },
  [STATE(3084)] = {
    [sym_boolean] = STATE(6242),
    [sym_assignment_expression] = STATE(6242),
    [sym__expression] = STATE(6242),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6242),
    [sym_multiplicative_expression] = STATE(6242),
    [sym_additive_expression] = STATE(6242),
    [sym_comparison_expression] = STATE(6242),
    [sym_logical_expression] = STATE(6242),
    [sym_ternary_expression] = STATE(6242),
    [sym_unary_expression] = STATE(6242),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6242),
    [sym_list_literal] = STATE(6242),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6242),
    [sym__literal_value] = STATE(6242),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7973),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7975),
    [sym_date_literal] = ACTIONS(7973),
    [sym_time_literal] = ACTIONS(7973),
    [sym_biginteger_literal] = ACTIONS(7975),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7975),
    [sym_integer] = ACTIONS(7973),
    [sym_continue_as_identifier] = ACTIONS(7975),
  },
  [STATE(3085)] = {
    [sym_boolean] = STATE(6287),
    [sym_assignment_expression] = STATE(6287),
    [sym__expression] = STATE(6287),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6287),
    [sym_multiplicative_expression] = STATE(6287),
    [sym_additive_expression] = STATE(6287),
    [sym_comparison_expression] = STATE(6287),
    [sym_logical_expression] = STATE(6287),
    [sym_ternary_expression] = STATE(6287),
    [sym_unary_expression] = STATE(6287),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6287),
    [sym_list_literal] = STATE(6287),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6287),
    [sym__literal_value] = STATE(6287),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7977),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7979),
    [sym_date_literal] = ACTIONS(7977),
    [sym_time_literal] = ACTIONS(7977),
    [sym_biginteger_literal] = ACTIONS(7979),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7979),
    [sym_integer] = ACTIONS(7977),
    [sym_continue_as_identifier] = ACTIONS(7979),
  },
  [STATE(3086)] = {
    [sym_boolean] = STATE(6014),
    [sym_assignment_expression] = STATE(6014),
    [sym__expression] = STATE(6014),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6014),
    [sym_multiplicative_expression] = STATE(6014),
    [sym_additive_expression] = STATE(6014),
    [sym_comparison_expression] = STATE(6014),
    [sym_logical_expression] = STATE(6014),
    [sym_ternary_expression] = STATE(6014),
    [sym_unary_expression] = STATE(6014),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6014),
    [sym_list_literal] = STATE(6014),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6014),
    [sym__literal_value] = STATE(6014),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7981),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7983),
    [sym_date_literal] = ACTIONS(7981),
    [sym_time_literal] = ACTIONS(7981),
    [sym_biginteger_literal] = ACTIONS(7983),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7983),
    [sym_integer] = ACTIONS(7981),
    [sym_continue_as_identifier] = ACTIONS(7983),
  },
  [STATE(3087)] = {
    [sym_boolean] = STATE(6034),
    [sym_assignment_expression] = STATE(6034),
    [sym__expression] = STATE(6034),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6034),
    [sym_multiplicative_expression] = STATE(6034),
    [sym_additive_expression] = STATE(6034),
    [sym_comparison_expression] = STATE(6034),
    [sym_logical_expression] = STATE(6034),
    [sym_ternary_expression] = STATE(6034),
    [sym_unary_expression] = STATE(6034),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6034),
    [sym_list_literal] = STATE(6034),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6034),
    [sym__literal_value] = STATE(6034),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7985),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7987),
    [sym_date_literal] = ACTIONS(7985),
    [sym_time_literal] = ACTIONS(7985),
    [sym_biginteger_literal] = ACTIONS(7987),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7987),
    [sym_integer] = ACTIONS(7985),
    [sym_continue_as_identifier] = ACTIONS(7987),
  },
  [STATE(3088)] = {
    [sym_boolean] = STATE(6072),
    [sym_assignment_expression] = STATE(6072),
    [sym__expression] = STATE(6072),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6072),
    [sym_multiplicative_expression] = STATE(6072),
    [sym_additive_expression] = STATE(6072),
    [sym_comparison_expression] = STATE(6072),
    [sym_logical_expression] = STATE(6072),
    [sym_ternary_expression] = STATE(6072),
    [sym_unary_expression] = STATE(6072),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6072),
    [sym_list_literal] = STATE(6072),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6072),
    [sym__literal_value] = STATE(6072),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7989),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7991),
    [sym_date_literal] = ACTIONS(7989),
    [sym_time_literal] = ACTIONS(7989),
    [sym_biginteger_literal] = ACTIONS(7991),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7991),
    [sym_integer] = ACTIONS(7989),
    [sym_continue_as_identifier] = ACTIONS(7991),
  },
  [STATE(3089)] = {
    [sym_identifier] = ACTIONS(4451),
    [anon_sym_SEMI] = ACTIONS(4453),
    [aux_sym_where_condition_token1] = ACTIONS(4451),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4451),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4451),
    [anon_sym_LBRACK] = ACTIONS(4453),
    [aux_sym_basic_type_token6] = ACTIONS(4451),
    [aux_sym_basic_type_token22] = ACTIONS(4451),
    [aux_sym_basic_type_token53] = ACTIONS(4451),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4451),
    [aux_sym_addafter_modification_token1] = ACTIONS(4451),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4451),
    [aux_sym_modify_modification_token1] = ACTIONS(4451),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4451),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4451),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4451),
    [aux_sym_separator_action_token1] = ACTIONS(4451),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4451),
    [aux_sym_type_declaration_token1] = ACTIONS(4451),
    [anon_sym_POUNDif] = ACTIONS(4453),
    [anon_sym_POUNDIF] = ACTIONS(4453),
    [anon_sym_POUNDIf] = ACTIONS(4453),
    [anon_sym_POUNDelif] = ACTIONS(4453),
    [anon_sym_POUNDELIF] = ACTIONS(4453),
    [anon_sym_POUNDElif] = ACTIONS(4453),
    [anon_sym_POUNDelse] = ACTIONS(4453),
    [anon_sym_POUNDELSE] = ACTIONS(4453),
    [anon_sym_POUNDElse] = ACTIONS(4453),
    [anon_sym_POUNDendif] = ACTIONS(4453),
    [anon_sym_POUNDENDIF] = ACTIONS(4453),
    [anon_sym_POUNDEndif] = ACTIONS(4453),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4451),
    [sym_trigger_keyword] = ACTIONS(4451),
    [sym_var_keyword] = ACTIONS(4451),
    [sym_local_keyword] = ACTIONS(4451),
    [sym_internal_keyword] = ACTIONS(4451),
    [sym_protected_keyword] = ACTIONS(4451),
    [sym_event_keyword] = ACTIONS(4451),
    [sym_fields_keyword] = ACTIONS(4451),
    [sym_keys_keyword] = ACTIONS(4451),
    [sym_key_keyword] = ACTIONS(4451),
    [sym_fieldgroups_keyword] = ACTIONS(4451),
    [sym_actions_keyword] = ACTIONS(4451),
    [sym_layout_keyword] = ACTIONS(4451),
    [sym_area_keyword] = ACTIONS(4451),
    [sym_group_keyword] = ACTIONS(4451),
    [sym_repeater_keyword] = ACTIONS(4451),
    [sym_cuegroup_keyword] = ACTIONS(4451),
    [sym_fixed_keyword] = ACTIONS(4451),
    [sym_grid_keyword] = ACTIONS(4451),
    [sym_part_keyword] = ACTIONS(4451),
    [sym_systempart_keyword] = ACTIONS(4451),
    [sym_usercontrol_keyword] = ACTIONS(4451),
    [sym_dataset_keyword] = ACTIONS(4451),
    [sym_elements_keyword] = ACTIONS(4451),
    [sym_dataitem_keyword] = ACTIONS(4451),
    [sym_column_keyword] = ACTIONS(4451),
    [sym_filter_keyword] = ACTIONS(4451),
    [sym_labels_keyword] = ACTIONS(4451),
    [sym_rendering_keyword] = ACTIONS(4451),
    [sym_requestpage_keyword] = ACTIONS(4451),
    [sym_schema_keyword] = ACTIONS(4451),
    [sym_views_keyword] = ACTIONS(4451),
    [sym_quoted_identifier] = ACTIONS(4453),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4453),
    [sym_preproc_open] = ACTIONS(4453),
    [sym_preproc_close] = ACTIONS(4453),
    [sym_var_attribute_open] = ACTIONS(4453),
  },
  [STATE(3090)] = {
    [sym_boolean] = STATE(6045),
    [sym_assignment_expression] = STATE(6045),
    [sym__expression] = STATE(6045),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6045),
    [sym_multiplicative_expression] = STATE(6045),
    [sym_additive_expression] = STATE(6045),
    [sym_comparison_expression] = STATE(6045),
    [sym_logical_expression] = STATE(6045),
    [sym_ternary_expression] = STATE(6045),
    [sym_unary_expression] = STATE(6045),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6045),
    [sym_list_literal] = STATE(6045),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6045),
    [sym__literal_value] = STATE(6045),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7993),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7995),
    [sym_date_literal] = ACTIONS(7993),
    [sym_time_literal] = ACTIONS(7993),
    [sym_biginteger_literal] = ACTIONS(7995),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7995),
    [sym_integer] = ACTIONS(7993),
    [sym_continue_as_identifier] = ACTIONS(7995),
  },
  [STATE(3091)] = {
    [sym_boolean] = STATE(6062),
    [sym_assignment_expression] = STATE(6062),
    [sym__expression] = STATE(6062),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6062),
    [sym_multiplicative_expression] = STATE(6062),
    [sym_additive_expression] = STATE(6062),
    [sym_comparison_expression] = STATE(6062),
    [sym_logical_expression] = STATE(6062),
    [sym_ternary_expression] = STATE(6062),
    [sym_unary_expression] = STATE(6062),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6062),
    [sym_list_literal] = STATE(6062),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6062),
    [sym__literal_value] = STATE(6062),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(7997),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(7999),
    [sym_date_literal] = ACTIONS(7997),
    [sym_time_literal] = ACTIONS(7997),
    [sym_biginteger_literal] = ACTIONS(7999),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7999),
    [sym_integer] = ACTIONS(7997),
    [sym_continue_as_identifier] = ACTIONS(7999),
  },
  [STATE(3092)] = {
    [sym_boolean] = STATE(6069),
    [sym_assignment_expression] = STATE(6069),
    [sym__expression] = STATE(6069),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6069),
    [sym_multiplicative_expression] = STATE(6069),
    [sym_additive_expression] = STATE(6069),
    [sym_comparison_expression] = STATE(6069),
    [sym_logical_expression] = STATE(6069),
    [sym_ternary_expression] = STATE(6069),
    [sym_unary_expression] = STATE(6069),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6069),
    [sym_list_literal] = STATE(6069),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6069),
    [sym__literal_value] = STATE(6069),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8001),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8003),
    [sym_date_literal] = ACTIONS(8001),
    [sym_time_literal] = ACTIONS(8001),
    [sym_biginteger_literal] = ACTIONS(8003),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8003),
    [sym_integer] = ACTIONS(8001),
    [sym_continue_as_identifier] = ACTIONS(8003),
  },
  [STATE(3093)] = {
    [sym_boolean] = STATE(969),
    [sym_assignment_expression] = STATE(969),
    [sym__expression] = STATE(969),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(969),
    [sym_multiplicative_expression] = STATE(969),
    [sym_additive_expression] = STATE(969),
    [sym_comparison_expression] = STATE(969),
    [sym_logical_expression] = STATE(969),
    [sym_ternary_expression] = STATE(969),
    [sym_unary_expression] = STATE(969),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(969),
    [sym_list_literal] = STATE(969),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(969),
    [sym__literal_value] = STATE(969),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(8005),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(8007),
    [sym_date_literal] = ACTIONS(8005),
    [sym_time_literal] = ACTIONS(8005),
    [sym_biginteger_literal] = ACTIONS(8007),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8007),
    [sym_integer] = ACTIONS(8005),
    [sym_continue_as_identifier] = ACTIONS(8007),
  },
  [STATE(3094)] = {
    [sym_boolean] = STATE(970),
    [sym_assignment_expression] = STATE(970),
    [sym__expression] = STATE(970),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(970),
    [sym_multiplicative_expression] = STATE(970),
    [sym_additive_expression] = STATE(970),
    [sym_comparison_expression] = STATE(970),
    [sym_logical_expression] = STATE(970),
    [sym_ternary_expression] = STATE(970),
    [sym_unary_expression] = STATE(970),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(970),
    [sym_list_literal] = STATE(970),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(970),
    [sym__literal_value] = STATE(970),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(8009),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(8011),
    [sym_date_literal] = ACTIONS(8009),
    [sym_time_literal] = ACTIONS(8009),
    [sym_biginteger_literal] = ACTIONS(8011),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8011),
    [sym_integer] = ACTIONS(8009),
    [sym_continue_as_identifier] = ACTIONS(8011),
  },
  [STATE(3095)] = {
    [sym_identifier] = ACTIONS(8013),
    [anon_sym_SEMI] = ACTIONS(8015),
    [aux_sym_where_condition_token1] = ACTIONS(8013),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8013),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8013),
    [anon_sym_LBRACK] = ACTIONS(8015),
    [aux_sym_basic_type_token6] = ACTIONS(8013),
    [aux_sym_basic_type_token22] = ACTIONS(8013),
    [aux_sym_basic_type_token53] = ACTIONS(8013),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8013),
    [aux_sym_addafter_modification_token1] = ACTIONS(8013),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8013),
    [aux_sym_modify_modification_token1] = ACTIONS(8013),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8013),
    [aux_sym_movelast_modification_token1] = ACTIONS(8013),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8013),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8013),
    [aux_sym_separator_action_token1] = ACTIONS(8013),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8013),
    [aux_sym_type_declaration_token1] = ACTIONS(8013),
    [anon_sym_POUNDif] = ACTIONS(8015),
    [anon_sym_POUNDIF] = ACTIONS(8015),
    [anon_sym_POUNDIf] = ACTIONS(8015),
    [anon_sym_POUNDelif] = ACTIONS(8015),
    [anon_sym_POUNDELIF] = ACTIONS(8015),
    [anon_sym_POUNDElif] = ACTIONS(8015),
    [anon_sym_POUNDelse] = ACTIONS(8015),
    [anon_sym_POUNDELSE] = ACTIONS(8015),
    [anon_sym_POUNDElse] = ACTIONS(8015),
    [anon_sym_POUNDendif] = ACTIONS(8015),
    [anon_sym_POUNDENDIF] = ACTIONS(8015),
    [anon_sym_POUNDEndif] = ACTIONS(8015),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8013),
    [sym_trigger_keyword] = ACTIONS(8013),
    [sym_var_keyword] = ACTIONS(8013),
    [sym_local_keyword] = ACTIONS(8013),
    [sym_internal_keyword] = ACTIONS(8013),
    [sym_protected_keyword] = ACTIONS(8013),
    [sym_event_keyword] = ACTIONS(8013),
    [sym_fields_keyword] = ACTIONS(8013),
    [sym_keys_keyword] = ACTIONS(8013),
    [sym_key_keyword] = ACTIONS(8013),
    [sym_fieldgroups_keyword] = ACTIONS(8013),
    [sym_actions_keyword] = ACTIONS(8013),
    [sym_layout_keyword] = ACTIONS(8013),
    [sym_area_keyword] = ACTIONS(8013),
    [sym_group_keyword] = ACTIONS(8013),
    [sym_repeater_keyword] = ACTIONS(8013),
    [sym_cuegroup_keyword] = ACTIONS(8013),
    [sym_fixed_keyword] = ACTIONS(8013),
    [sym_grid_keyword] = ACTIONS(8013),
    [sym_part_keyword] = ACTIONS(8013),
    [sym_systempart_keyword] = ACTIONS(8013),
    [sym_usercontrol_keyword] = ACTIONS(8013),
    [sym_dataset_keyword] = ACTIONS(8013),
    [sym_elements_keyword] = ACTIONS(8013),
    [sym_dataitem_keyword] = ACTIONS(8013),
    [sym_column_keyword] = ACTIONS(8013),
    [sym_filter_keyword] = ACTIONS(8013),
    [sym_labels_keyword] = ACTIONS(8013),
    [sym_rendering_keyword] = ACTIONS(8013),
    [sym_requestpage_keyword] = ACTIONS(8013),
    [sym_schema_keyword] = ACTIONS(8013),
    [sym_views_keyword] = ACTIONS(8013),
    [sym_quoted_identifier] = ACTIONS(8015),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8015),
    [sym_preproc_open] = ACTIONS(8015),
    [sym_preproc_close] = ACTIONS(8015),
    [sym_var_attribute_open] = ACTIONS(8015),
  },
  [STATE(3096)] = {
    [sym_identifier] = ACTIONS(8017),
    [anon_sym_SEMI] = ACTIONS(8019),
    [aux_sym_where_condition_token1] = ACTIONS(8017),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8017),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8017),
    [anon_sym_LBRACK] = ACTIONS(8019),
    [aux_sym_basic_type_token6] = ACTIONS(8017),
    [aux_sym_basic_type_token22] = ACTIONS(8017),
    [aux_sym_basic_type_token53] = ACTIONS(8017),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8017),
    [aux_sym_addafter_modification_token1] = ACTIONS(8017),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8017),
    [aux_sym_modify_modification_token1] = ACTIONS(8017),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8017),
    [aux_sym_movelast_modification_token1] = ACTIONS(8017),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8017),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8017),
    [aux_sym_separator_action_token1] = ACTIONS(8017),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8017),
    [aux_sym_type_declaration_token1] = ACTIONS(8017),
    [anon_sym_POUNDif] = ACTIONS(8019),
    [anon_sym_POUNDIF] = ACTIONS(8019),
    [anon_sym_POUNDIf] = ACTIONS(8019),
    [anon_sym_POUNDelif] = ACTIONS(8019),
    [anon_sym_POUNDELIF] = ACTIONS(8019),
    [anon_sym_POUNDElif] = ACTIONS(8019),
    [anon_sym_POUNDelse] = ACTIONS(8019),
    [anon_sym_POUNDELSE] = ACTIONS(8019),
    [anon_sym_POUNDElse] = ACTIONS(8019),
    [anon_sym_POUNDendif] = ACTIONS(8019),
    [anon_sym_POUNDENDIF] = ACTIONS(8019),
    [anon_sym_POUNDEndif] = ACTIONS(8019),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8017),
    [sym_trigger_keyword] = ACTIONS(8017),
    [sym_var_keyword] = ACTIONS(8017),
    [sym_local_keyword] = ACTIONS(8017),
    [sym_internal_keyword] = ACTIONS(8017),
    [sym_protected_keyword] = ACTIONS(8017),
    [sym_event_keyword] = ACTIONS(8017),
    [sym_fields_keyword] = ACTIONS(8017),
    [sym_keys_keyword] = ACTIONS(8017),
    [sym_key_keyword] = ACTIONS(8017),
    [sym_fieldgroups_keyword] = ACTIONS(8017),
    [sym_actions_keyword] = ACTIONS(8017),
    [sym_layout_keyword] = ACTIONS(8017),
    [sym_area_keyword] = ACTIONS(8017),
    [sym_group_keyword] = ACTIONS(8017),
    [sym_repeater_keyword] = ACTIONS(8017),
    [sym_cuegroup_keyword] = ACTIONS(8017),
    [sym_fixed_keyword] = ACTIONS(8017),
    [sym_grid_keyword] = ACTIONS(8017),
    [sym_part_keyword] = ACTIONS(8017),
    [sym_systempart_keyword] = ACTIONS(8017),
    [sym_usercontrol_keyword] = ACTIONS(8017),
    [sym_dataset_keyword] = ACTIONS(8017),
    [sym_elements_keyword] = ACTIONS(8017),
    [sym_dataitem_keyword] = ACTIONS(8017),
    [sym_column_keyword] = ACTIONS(8017),
    [sym_filter_keyword] = ACTIONS(8017),
    [sym_labels_keyword] = ACTIONS(8017),
    [sym_rendering_keyword] = ACTIONS(8017),
    [sym_requestpage_keyword] = ACTIONS(8017),
    [sym_schema_keyword] = ACTIONS(8017),
    [sym_views_keyword] = ACTIONS(8017),
    [sym_quoted_identifier] = ACTIONS(8019),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8019),
    [sym_preproc_open] = ACTIONS(8019),
    [sym_preproc_close] = ACTIONS(8019),
    [sym_var_attribute_open] = ACTIONS(8019),
  },
  [STATE(3097)] = {
    [sym_boolean] = STATE(6280),
    [sym_assignment_expression] = STATE(6280),
    [sym__expression] = STATE(6280),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6280),
    [sym_multiplicative_expression] = STATE(6280),
    [sym_additive_expression] = STATE(6280),
    [sym_comparison_expression] = STATE(6280),
    [sym_logical_expression] = STATE(6280),
    [sym_ternary_expression] = STATE(6280),
    [sym_unary_expression] = STATE(6280),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6280),
    [sym_list_literal] = STATE(6280),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6280),
    [sym__literal_value] = STATE(6280),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8021),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8023),
    [sym_date_literal] = ACTIONS(8021),
    [sym_time_literal] = ACTIONS(8021),
    [sym_biginteger_literal] = ACTIONS(8023),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8023),
    [sym_integer] = ACTIONS(8021),
    [sym_continue_as_identifier] = ACTIONS(8023),
  },
  [STATE(3098)] = {
    [sym_boolean] = STATE(6218),
    [sym_assignment_expression] = STATE(6218),
    [sym__expression] = STATE(6218),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6218),
    [sym_multiplicative_expression] = STATE(6218),
    [sym_additive_expression] = STATE(6218),
    [sym_comparison_expression] = STATE(6218),
    [sym_logical_expression] = STATE(6218),
    [sym_ternary_expression] = STATE(6218),
    [sym_unary_expression] = STATE(6218),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6218),
    [sym_list_literal] = STATE(6218),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6218),
    [sym__literal_value] = STATE(6218),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8025),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8027),
    [sym_date_literal] = ACTIONS(8025),
    [sym_time_literal] = ACTIONS(8025),
    [sym_biginteger_literal] = ACTIONS(8027),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8027),
    [sym_integer] = ACTIONS(8025),
    [sym_continue_as_identifier] = ACTIONS(8027),
  },
  [STATE(3099)] = {
    [sym_boolean] = STATE(6301),
    [sym_assignment_expression] = STATE(6301),
    [sym__expression] = STATE(6301),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6301),
    [sym_multiplicative_expression] = STATE(6301),
    [sym_additive_expression] = STATE(6301),
    [sym_comparison_expression] = STATE(6301),
    [sym_logical_expression] = STATE(6301),
    [sym_ternary_expression] = STATE(6301),
    [sym_unary_expression] = STATE(6301),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6301),
    [sym_list_literal] = STATE(6301),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6301),
    [sym__literal_value] = STATE(6301),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8029),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8031),
    [sym_date_literal] = ACTIONS(8029),
    [sym_time_literal] = ACTIONS(8029),
    [sym_biginteger_literal] = ACTIONS(8031),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8031),
    [sym_integer] = ACTIONS(8029),
    [sym_continue_as_identifier] = ACTIONS(8031),
  },
  [STATE(3100)] = {
    [sym_boolean] = STATE(5994),
    [sym_assignment_expression] = STATE(5994),
    [sym__expression] = STATE(5994),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(5994),
    [sym_multiplicative_expression] = STATE(5994),
    [sym_additive_expression] = STATE(5994),
    [sym_comparison_expression] = STATE(5994),
    [sym_logical_expression] = STATE(5994),
    [sym_ternary_expression] = STATE(5994),
    [sym_unary_expression] = STATE(5994),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(5994),
    [sym_list_literal] = STATE(5994),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(5994),
    [sym__literal_value] = STATE(5994),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8033),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8035),
    [sym_date_literal] = ACTIONS(8033),
    [sym_time_literal] = ACTIONS(8033),
    [sym_biginteger_literal] = ACTIONS(8035),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8035),
    [sym_integer] = ACTIONS(8033),
    [sym_continue_as_identifier] = ACTIONS(8035),
  },
  [STATE(3101)] = {
    [sym_boolean] = STATE(5995),
    [sym_assignment_expression] = STATE(5995),
    [sym__expression] = STATE(5995),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(5995),
    [sym_multiplicative_expression] = STATE(5995),
    [sym_additive_expression] = STATE(5995),
    [sym_comparison_expression] = STATE(5995),
    [sym_logical_expression] = STATE(5995),
    [sym_ternary_expression] = STATE(5995),
    [sym_unary_expression] = STATE(5995),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(5995),
    [sym_list_literal] = STATE(5995),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(5995),
    [sym__literal_value] = STATE(5995),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8037),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8039),
    [sym_date_literal] = ACTIONS(8037),
    [sym_time_literal] = ACTIONS(8037),
    [sym_biginteger_literal] = ACTIONS(8039),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8039),
    [sym_integer] = ACTIONS(8037),
    [sym_continue_as_identifier] = ACTIONS(8039),
  },
  [STATE(3102)] = {
    [sym_boolean] = STATE(5998),
    [sym_assignment_expression] = STATE(5998),
    [sym__expression] = STATE(5998),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(5998),
    [sym_multiplicative_expression] = STATE(5998),
    [sym_additive_expression] = STATE(5998),
    [sym_comparison_expression] = STATE(5998),
    [sym_logical_expression] = STATE(5998),
    [sym_ternary_expression] = STATE(5998),
    [sym_unary_expression] = STATE(5998),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(5998),
    [sym_list_literal] = STATE(5998),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(5998),
    [sym__literal_value] = STATE(5998),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8041),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8043),
    [sym_date_literal] = ACTIONS(8041),
    [sym_time_literal] = ACTIONS(8041),
    [sym_biginteger_literal] = ACTIONS(8043),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8043),
    [sym_integer] = ACTIONS(8041),
    [sym_continue_as_identifier] = ACTIONS(8043),
  },
  [STATE(3103)] = {
    [sym_boolean] = STATE(6075),
    [sym_assignment_expression] = STATE(6075),
    [sym__expression] = STATE(6075),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6075),
    [sym_multiplicative_expression] = STATE(6075),
    [sym_additive_expression] = STATE(6075),
    [sym_comparison_expression] = STATE(6075),
    [sym_logical_expression] = STATE(6075),
    [sym_ternary_expression] = STATE(6075),
    [sym_unary_expression] = STATE(6075),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6075),
    [sym_list_literal] = STATE(6075),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6075),
    [sym__literal_value] = STATE(6075),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8045),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8047),
    [sym_date_literal] = ACTIONS(8045),
    [sym_time_literal] = ACTIONS(8045),
    [sym_biginteger_literal] = ACTIONS(8047),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8047),
    [sym_integer] = ACTIONS(8045),
    [sym_continue_as_identifier] = ACTIONS(8047),
  },
  [STATE(3104)] = {
    [sym_boolean] = STATE(971),
    [sym_assignment_expression] = STATE(971),
    [sym__expression] = STATE(971),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(971),
    [sym_multiplicative_expression] = STATE(971),
    [sym_additive_expression] = STATE(971),
    [sym_comparison_expression] = STATE(971),
    [sym_logical_expression] = STATE(971),
    [sym_ternary_expression] = STATE(971),
    [sym_unary_expression] = STATE(971),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(971),
    [sym_list_literal] = STATE(971),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(971),
    [sym__literal_value] = STATE(971),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(8049),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(8051),
    [sym_date_literal] = ACTIONS(8049),
    [sym_time_literal] = ACTIONS(8049),
    [sym_biginteger_literal] = ACTIONS(8051),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8051),
    [sym_integer] = ACTIONS(8049),
    [sym_continue_as_identifier] = ACTIONS(8051),
  },
  [STATE(3105)] = {
    [sym_boolean] = STATE(997),
    [sym_assignment_expression] = STATE(997),
    [sym__expression] = STATE(997),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(997),
    [sym_multiplicative_expression] = STATE(997),
    [sym_additive_expression] = STATE(997),
    [sym_comparison_expression] = STATE(997),
    [sym_logical_expression] = STATE(997),
    [sym_ternary_expression] = STATE(997),
    [sym_unary_expression] = STATE(997),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(997),
    [sym_list_literal] = STATE(997),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(997),
    [sym__literal_value] = STATE(997),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(8053),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(8055),
    [sym_date_literal] = ACTIONS(8053),
    [sym_time_literal] = ACTIONS(8053),
    [sym_biginteger_literal] = ACTIONS(8055),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8055),
    [sym_integer] = ACTIONS(8053),
    [sym_continue_as_identifier] = ACTIONS(8055),
  },
  [STATE(3106)] = {
    [sym_boolean] = STATE(6143),
    [sym_assignment_expression] = STATE(6143),
    [sym__expression] = STATE(6143),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6143),
    [sym_multiplicative_expression] = STATE(6143),
    [sym_additive_expression] = STATE(6143),
    [sym_comparison_expression] = STATE(6143),
    [sym_logical_expression] = STATE(6143),
    [sym_ternary_expression] = STATE(6143),
    [sym_unary_expression] = STATE(6143),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6143),
    [sym_list_literal] = STATE(6143),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6143),
    [sym__literal_value] = STATE(6143),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8057),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8059),
    [sym_date_literal] = ACTIONS(8057),
    [sym_time_literal] = ACTIONS(8057),
    [sym_biginteger_literal] = ACTIONS(8059),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8059),
    [sym_integer] = ACTIONS(8057),
    [sym_continue_as_identifier] = ACTIONS(8059),
  },
  [STATE(3107)] = {
    [sym_boolean] = STATE(6144),
    [sym_assignment_expression] = STATE(6144),
    [sym__expression] = STATE(6144),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6144),
    [sym_multiplicative_expression] = STATE(6144),
    [sym_additive_expression] = STATE(6144),
    [sym_comparison_expression] = STATE(6144),
    [sym_logical_expression] = STATE(6144),
    [sym_ternary_expression] = STATE(6144),
    [sym_unary_expression] = STATE(6144),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6144),
    [sym_list_literal] = STATE(6144),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6144),
    [sym__literal_value] = STATE(6144),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8061),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8063),
    [sym_date_literal] = ACTIONS(8061),
    [sym_time_literal] = ACTIONS(8061),
    [sym_biginteger_literal] = ACTIONS(8063),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8063),
    [sym_integer] = ACTIONS(8061),
    [sym_continue_as_identifier] = ACTIONS(8063),
  },
  [STATE(3108)] = {
    [sym_boolean] = STATE(973),
    [sym_assignment_expression] = STATE(973),
    [sym__expression] = STATE(973),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(973),
    [sym_multiplicative_expression] = STATE(973),
    [sym_additive_expression] = STATE(973),
    [sym_comparison_expression] = STATE(973),
    [sym_logical_expression] = STATE(973),
    [sym_ternary_expression] = STATE(973),
    [sym_unary_expression] = STATE(973),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(973),
    [sym_list_literal] = STATE(973),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(973),
    [sym__literal_value] = STATE(973),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(8065),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(8067),
    [sym_date_literal] = ACTIONS(8065),
    [sym_time_literal] = ACTIONS(8065),
    [sym_biginteger_literal] = ACTIONS(8067),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8067),
    [sym_integer] = ACTIONS(8065),
    [sym_continue_as_identifier] = ACTIONS(8067),
  },
  [STATE(3109)] = {
    [sym_boolean] = STATE(974),
    [sym_assignment_expression] = STATE(974),
    [sym__expression] = STATE(974),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(974),
    [sym_multiplicative_expression] = STATE(974),
    [sym_additive_expression] = STATE(974),
    [sym_comparison_expression] = STATE(974),
    [sym_logical_expression] = STATE(974),
    [sym_ternary_expression] = STATE(974),
    [sym_unary_expression] = STATE(974),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(974),
    [sym_list_literal] = STATE(974),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(974),
    [sym__literal_value] = STATE(974),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(8069),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(8071),
    [sym_date_literal] = ACTIONS(8069),
    [sym_time_literal] = ACTIONS(8069),
    [sym_biginteger_literal] = ACTIONS(8071),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8071),
    [sym_integer] = ACTIONS(8069),
    [sym_continue_as_identifier] = ACTIONS(8071),
  },
  [STATE(3110)] = {
    [sym_boolean] = STATE(975),
    [sym_assignment_expression] = STATE(975),
    [sym__expression] = STATE(975),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(975),
    [sym_multiplicative_expression] = STATE(975),
    [sym_additive_expression] = STATE(975),
    [sym_comparison_expression] = STATE(975),
    [sym_logical_expression] = STATE(975),
    [sym_ternary_expression] = STATE(975),
    [sym_unary_expression] = STATE(975),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(975),
    [sym_list_literal] = STATE(975),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(975),
    [sym__literal_value] = STATE(975),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(8073),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(8075),
    [sym_date_literal] = ACTIONS(8073),
    [sym_time_literal] = ACTIONS(8073),
    [sym_biginteger_literal] = ACTIONS(8075),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8075),
    [sym_integer] = ACTIONS(8073),
    [sym_continue_as_identifier] = ACTIONS(8075),
  },
  [STATE(3111)] = {
    [sym_boolean] = STATE(6293),
    [sym_assignment_expression] = STATE(6293),
    [sym__expression] = STATE(6293),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6293),
    [sym_multiplicative_expression] = STATE(6293),
    [sym_additive_expression] = STATE(6293),
    [sym_comparison_expression] = STATE(6293),
    [sym_logical_expression] = STATE(6293),
    [sym_ternary_expression] = STATE(6293),
    [sym_unary_expression] = STATE(6293),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6293),
    [sym_list_literal] = STATE(6293),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6293),
    [sym__literal_value] = STATE(6293),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8077),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8079),
    [sym_date_literal] = ACTIONS(8077),
    [sym_time_literal] = ACTIONS(8077),
    [sym_biginteger_literal] = ACTIONS(8079),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8079),
    [sym_integer] = ACTIONS(8077),
    [sym_continue_as_identifier] = ACTIONS(8079),
  },
  [STATE(3112)] = {
    [sym_boolean] = STATE(6222),
    [sym_assignment_expression] = STATE(6222),
    [sym__expression] = STATE(6222),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6222),
    [sym_multiplicative_expression] = STATE(6222),
    [sym_additive_expression] = STATE(6222),
    [sym_comparison_expression] = STATE(6222),
    [sym_logical_expression] = STATE(6222),
    [sym_ternary_expression] = STATE(6222),
    [sym_unary_expression] = STATE(6222),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6222),
    [sym_list_literal] = STATE(6222),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6222),
    [sym__literal_value] = STATE(6222),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8081),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8083),
    [sym_date_literal] = ACTIONS(8081),
    [sym_time_literal] = ACTIONS(8081),
    [sym_biginteger_literal] = ACTIONS(8083),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8083),
    [sym_integer] = ACTIONS(8081),
    [sym_continue_as_identifier] = ACTIONS(8083),
  },
  [STATE(3113)] = {
    [sym_boolean] = STATE(6311),
    [sym_assignment_expression] = STATE(6311),
    [sym__expression] = STATE(6311),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6311),
    [sym_multiplicative_expression] = STATE(6311),
    [sym_additive_expression] = STATE(6311),
    [sym_comparison_expression] = STATE(6311),
    [sym_logical_expression] = STATE(6311),
    [sym_ternary_expression] = STATE(6311),
    [sym_unary_expression] = STATE(6311),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6311),
    [sym_list_literal] = STATE(6311),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6311),
    [sym__literal_value] = STATE(6311),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8085),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8087),
    [sym_date_literal] = ACTIONS(8085),
    [sym_time_literal] = ACTIONS(8085),
    [sym_biginteger_literal] = ACTIONS(8087),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8087),
    [sym_integer] = ACTIONS(8085),
    [sym_continue_as_identifier] = ACTIONS(8087),
  },
  [STATE(3114)] = {
    [sym_boolean] = STATE(6051),
    [sym_assignment_expression] = STATE(6051),
    [sym__expression] = STATE(6051),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6051),
    [sym_multiplicative_expression] = STATE(6051),
    [sym_additive_expression] = STATE(6051),
    [sym_comparison_expression] = STATE(6051),
    [sym_logical_expression] = STATE(6051),
    [sym_ternary_expression] = STATE(6051),
    [sym_unary_expression] = STATE(6051),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6051),
    [sym_list_literal] = STATE(6051),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6051),
    [sym__literal_value] = STATE(6051),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8089),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8091),
    [sym_date_literal] = ACTIONS(8089),
    [sym_time_literal] = ACTIONS(8089),
    [sym_biginteger_literal] = ACTIONS(8091),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8091),
    [sym_integer] = ACTIONS(8089),
    [sym_continue_as_identifier] = ACTIONS(8091),
  },
  [STATE(3115)] = {
    [sym_boolean] = STATE(6052),
    [sym_assignment_expression] = STATE(6052),
    [sym__expression] = STATE(6052),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6052),
    [sym_multiplicative_expression] = STATE(6052),
    [sym_additive_expression] = STATE(6052),
    [sym_comparison_expression] = STATE(6052),
    [sym_logical_expression] = STATE(6052),
    [sym_ternary_expression] = STATE(6052),
    [sym_unary_expression] = STATE(6052),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6052),
    [sym_list_literal] = STATE(6052),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6052),
    [sym__literal_value] = STATE(6052),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8093),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8095),
    [sym_date_literal] = ACTIONS(8093),
    [sym_time_literal] = ACTIONS(8093),
    [sym_biginteger_literal] = ACTIONS(8095),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8095),
    [sym_integer] = ACTIONS(8093),
    [sym_continue_as_identifier] = ACTIONS(8095),
  },
  [STATE(3116)] = {
    [sym_boolean] = STATE(6053),
    [sym_assignment_expression] = STATE(6053),
    [sym__expression] = STATE(6053),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6053),
    [sym_multiplicative_expression] = STATE(6053),
    [sym_additive_expression] = STATE(6053),
    [sym_comparison_expression] = STATE(6053),
    [sym_logical_expression] = STATE(6053),
    [sym_ternary_expression] = STATE(6053),
    [sym_unary_expression] = STATE(6053),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6053),
    [sym_list_literal] = STATE(6053),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6053),
    [sym__literal_value] = STATE(6053),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8097),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8099),
    [sym_date_literal] = ACTIONS(8097),
    [sym_time_literal] = ACTIONS(8097),
    [sym_biginteger_literal] = ACTIONS(8099),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8099),
    [sym_integer] = ACTIONS(8097),
    [sym_continue_as_identifier] = ACTIONS(8099),
  },
  [STATE(3117)] = {
    [sym_identifier] = ACTIONS(4455),
    [anon_sym_SEMI] = ACTIONS(4457),
    [aux_sym_where_condition_token1] = ACTIONS(4455),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4455),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4455),
    [anon_sym_LBRACK] = ACTIONS(4457),
    [aux_sym_basic_type_token6] = ACTIONS(4455),
    [aux_sym_basic_type_token22] = ACTIONS(4455),
    [aux_sym_basic_type_token53] = ACTIONS(4455),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4455),
    [aux_sym_addafter_modification_token1] = ACTIONS(4455),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4455),
    [aux_sym_modify_modification_token1] = ACTIONS(4455),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4455),
    [aux_sym_movelast_modification_token1] = ACTIONS(4455),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4455),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [aux_sym_separator_action_token1] = ACTIONS(4455),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4455),
    [aux_sym_type_declaration_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(4457),
    [anon_sym_POUNDIF] = ACTIONS(4457),
    [anon_sym_POUNDIf] = ACTIONS(4457),
    [anon_sym_POUNDelif] = ACTIONS(4457),
    [anon_sym_POUNDELIF] = ACTIONS(4457),
    [anon_sym_POUNDElif] = ACTIONS(4457),
    [anon_sym_POUNDelse] = ACTIONS(4457),
    [anon_sym_POUNDELSE] = ACTIONS(4457),
    [anon_sym_POUNDElse] = ACTIONS(4457),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4455),
    [sym_trigger_keyword] = ACTIONS(4455),
    [sym_var_keyword] = ACTIONS(4455),
    [sym_local_keyword] = ACTIONS(4455),
    [sym_internal_keyword] = ACTIONS(4455),
    [sym_protected_keyword] = ACTIONS(4455),
    [sym_event_keyword] = ACTIONS(4455),
    [sym_fields_keyword] = ACTIONS(4455),
    [sym_keys_keyword] = ACTIONS(4455),
    [sym_key_keyword] = ACTIONS(4455),
    [sym_fieldgroups_keyword] = ACTIONS(4455),
    [sym_actions_keyword] = ACTIONS(4455),
    [sym_layout_keyword] = ACTIONS(4455),
    [sym_area_keyword] = ACTIONS(4455),
    [sym_group_keyword] = ACTIONS(4455),
    [sym_repeater_keyword] = ACTIONS(4455),
    [sym_cuegroup_keyword] = ACTIONS(4455),
    [sym_fixed_keyword] = ACTIONS(4455),
    [sym_grid_keyword] = ACTIONS(4455),
    [sym_part_keyword] = ACTIONS(4455),
    [sym_systempart_keyword] = ACTIONS(4455),
    [sym_usercontrol_keyword] = ACTIONS(4455),
    [sym_dataset_keyword] = ACTIONS(4455),
    [sym_elements_keyword] = ACTIONS(4455),
    [sym_dataitem_keyword] = ACTIONS(4455),
    [sym_column_keyword] = ACTIONS(4455),
    [sym_filter_keyword] = ACTIONS(4455),
    [sym_labels_keyword] = ACTIONS(4455),
    [sym_rendering_keyword] = ACTIONS(4455),
    [sym_requestpage_keyword] = ACTIONS(4455),
    [sym_schema_keyword] = ACTIONS(4455),
    [sym_views_keyword] = ACTIONS(4455),
    [sym_quoted_identifier] = ACTIONS(4457),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4457),
    [sym_preproc_open] = ACTIONS(4457),
    [sym_preproc_close] = ACTIONS(4457),
    [sym_var_attribute_open] = ACTIONS(4457),
  },
  [STATE(3118)] = {
    [sym_boolean] = STATE(6055),
    [sym_assignment_expression] = STATE(6055),
    [sym__expression] = STATE(6055),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6055),
    [sym_multiplicative_expression] = STATE(6055),
    [sym_additive_expression] = STATE(6055),
    [sym_comparison_expression] = STATE(6055),
    [sym_logical_expression] = STATE(6055),
    [sym_ternary_expression] = STATE(6055),
    [sym_unary_expression] = STATE(6055),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6055),
    [sym_list_literal] = STATE(6055),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6055),
    [sym__literal_value] = STATE(6055),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8101),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8103),
    [sym_date_literal] = ACTIONS(8101),
    [sym_time_literal] = ACTIONS(8101),
    [sym_biginteger_literal] = ACTIONS(8103),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8103),
    [sym_integer] = ACTIONS(8101),
    [sym_continue_as_identifier] = ACTIONS(8103),
  },
  [STATE(3119)] = {
    [sym_boolean] = STATE(6175),
    [sym_assignment_expression] = STATE(6175),
    [sym__expression] = STATE(6175),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6175),
    [sym_multiplicative_expression] = STATE(6175),
    [sym_additive_expression] = STATE(6175),
    [sym_comparison_expression] = STATE(6175),
    [sym_logical_expression] = STATE(6175),
    [sym_ternary_expression] = STATE(6175),
    [sym_unary_expression] = STATE(6175),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6175),
    [sym_list_literal] = STATE(6175),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6175),
    [sym__literal_value] = STATE(6175),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8105),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(8107),
    [sym_date_literal] = ACTIONS(8105),
    [sym_time_literal] = ACTIONS(8105),
    [sym_biginteger_literal] = ACTIONS(8107),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8107),
    [sym_integer] = ACTIONS(8105),
    [sym_continue_as_identifier] = ACTIONS(8107),
  },
  [STATE(3120)] = {
    [sym_boolean] = STATE(976),
    [sym_assignment_expression] = STATE(976),
    [sym__expression] = STATE(976),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(976),
    [sym_multiplicative_expression] = STATE(976),
    [sym_additive_expression] = STATE(976),
    [sym_comparison_expression] = STATE(976),
    [sym_logical_expression] = STATE(976),
    [sym_ternary_expression] = STATE(976),
    [sym_unary_expression] = STATE(976),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(976),
    [sym_list_literal] = STATE(976),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(976),
    [sym__literal_value] = STATE(976),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(8109),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(8111),
    [sym_date_literal] = ACTIONS(8109),
    [sym_time_literal] = ACTIONS(8109),
    [sym_biginteger_literal] = ACTIONS(8111),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8111),
    [sym_integer] = ACTIONS(8109),
    [sym_continue_as_identifier] = ACTIONS(8111),
  },
  [STATE(3121)] = {
    [sym_boolean] = STATE(952),
    [sym_assignment_expression] = STATE(952),
    [sym__expression] = STATE(952),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(952),
    [sym_multiplicative_expression] = STATE(952),
    [sym_additive_expression] = STATE(952),
    [sym_comparison_expression] = STATE(952),
    [sym_logical_expression] = STATE(952),
    [sym_ternary_expression] = STATE(952),
    [sym_unary_expression] = STATE(952),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(952),
    [sym_list_literal] = STATE(952),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(952),
    [sym__literal_value] = STATE(952),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(8113),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(8115),
    [sym_date_literal] = ACTIONS(8113),
    [sym_time_literal] = ACTIONS(8113),
    [sym_biginteger_literal] = ACTIONS(8115),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8115),
    [sym_integer] = ACTIONS(8113),
    [sym_continue_as_identifier] = ACTIONS(8115),
  },
  [STATE(3122)] = {
    [sym_boolean] = STATE(6057),
    [sym_assignment_expression] = STATE(6057),
    [sym__expression] = STATE(6057),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6057),
    [sym_multiplicative_expression] = STATE(6057),
    [sym_additive_expression] = STATE(6057),
    [sym_comparison_expression] = STATE(6057),
    [sym_logical_expression] = STATE(6057),
    [sym_ternary_expression] = STATE(6057),
    [sym_unary_expression] = STATE(6057),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6057),
    [sym_list_literal] = STATE(6057),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6057),
    [sym__literal_value] = STATE(6057),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8117),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8119),
    [sym_date_literal] = ACTIONS(8117),
    [sym_time_literal] = ACTIONS(8117),
    [sym_biginteger_literal] = ACTIONS(8119),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8119),
    [sym_integer] = ACTIONS(8117),
    [sym_continue_as_identifier] = ACTIONS(8119),
  },
  [STATE(3123)] = {
    [sym_boolean] = STATE(6058),
    [sym_assignment_expression] = STATE(6058),
    [sym__expression] = STATE(6058),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6058),
    [sym_multiplicative_expression] = STATE(6058),
    [sym_additive_expression] = STATE(6058),
    [sym_comparison_expression] = STATE(6058),
    [sym_logical_expression] = STATE(6058),
    [sym_ternary_expression] = STATE(6058),
    [sym_unary_expression] = STATE(6058),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6058),
    [sym_list_literal] = STATE(6058),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6058),
    [sym__literal_value] = STATE(6058),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8121),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8123),
    [sym_date_literal] = ACTIONS(8121),
    [sym_time_literal] = ACTIONS(8121),
    [sym_biginteger_literal] = ACTIONS(8123),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8123),
    [sym_integer] = ACTIONS(8121),
    [sym_continue_as_identifier] = ACTIONS(8123),
  },
  [STATE(3124)] = {
    [sym_boolean] = STATE(977),
    [sym_assignment_expression] = STATE(977),
    [sym__expression] = STATE(977),
    [sym_keyword_identifier] = STATE(993),
    [sym_range_expression] = STATE(977),
    [sym_multiplicative_expression] = STATE(977),
    [sym_additive_expression] = STATE(977),
    [sym_comparison_expression] = STATE(977),
    [sym_logical_expression] = STATE(977),
    [sym_ternary_expression] = STATE(977),
    [sym_unary_expression] = STATE(977),
    [sym_call_expression] = STATE(1012),
    [sym_member_expression] = STATE(993),
    [sym_subscript_expression] = STATE(993),
    [sym_parenthesized_expression] = STATE(977),
    [sym_list_literal] = STATE(977),
    [sym_qualified_enum_value] = STATE(993),
    [sym_database_reference] = STATE(977),
    [sym__literal_value] = STATE(977),
    [sym_codeunit_keyword] = STATE(1011),
    [sym_xmlport_keyword] = STATE(1011),
    [sym_enum_keyword] = STATE(991),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(8125),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(8127),
    [sym_date_literal] = ACTIONS(8125),
    [sym_time_literal] = ACTIONS(8125),
    [sym_biginteger_literal] = ACTIONS(8127),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8127),
    [sym_integer] = ACTIONS(8125),
    [sym_continue_as_identifier] = ACTIONS(8127),
  },
  [STATE(3125)] = {
    [sym_identifier] = ACTIONS(4373),
    [anon_sym_SEMI] = ACTIONS(8129),
    [aux_sym_where_condition_token1] = ACTIONS(4373),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4373),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4373),
    [anon_sym_LBRACK] = ACTIONS(4377),
    [aux_sym_basic_type_token6] = ACTIONS(4373),
    [aux_sym_basic_type_token22] = ACTIONS(4373),
    [aux_sym_basic_type_token53] = ACTIONS(4373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4373),
    [aux_sym_addafter_modification_token1] = ACTIONS(4373),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4373),
    [aux_sym_modify_modification_token1] = ACTIONS(4373),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4373),
    [aux_sym_movelast_modification_token1] = ACTIONS(4373),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4373),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4373),
    [aux_sym_separator_action_token1] = ACTIONS(4373),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4373),
    [aux_sym_type_declaration_token1] = ACTIONS(4373),
    [anon_sym_POUNDif] = ACTIONS(4377),
    [anon_sym_POUNDIF] = ACTIONS(4377),
    [anon_sym_POUNDIf] = ACTIONS(4377),
    [anon_sym_POUNDelif] = ACTIONS(4377),
    [anon_sym_POUNDELIF] = ACTIONS(4377),
    [anon_sym_POUNDElif] = ACTIONS(4377),
    [anon_sym_POUNDelse] = ACTIONS(4377),
    [anon_sym_POUNDELSE] = ACTIONS(4377),
    [anon_sym_POUNDElse] = ACTIONS(4377),
    [anon_sym_POUNDendif] = ACTIONS(4377),
    [anon_sym_POUNDENDIF] = ACTIONS(4377),
    [anon_sym_POUNDEndif] = ACTIONS(4377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4373),
    [sym_trigger_keyword] = ACTIONS(4373),
    [sym_var_keyword] = ACTIONS(4373),
    [sym_local_keyword] = ACTIONS(4373),
    [sym_internal_keyword] = ACTIONS(4373),
    [sym_protected_keyword] = ACTIONS(4373),
    [sym_event_keyword] = ACTIONS(4373),
    [sym_fields_keyword] = ACTIONS(4373),
    [sym_keys_keyword] = ACTIONS(4373),
    [sym_key_keyword] = ACTIONS(4373),
    [sym_fieldgroups_keyword] = ACTIONS(4373),
    [sym_actions_keyword] = ACTIONS(4373),
    [sym_layout_keyword] = ACTIONS(4373),
    [sym_area_keyword] = ACTIONS(4373),
    [sym_group_keyword] = ACTIONS(4373),
    [sym_repeater_keyword] = ACTIONS(4373),
    [sym_cuegroup_keyword] = ACTIONS(4373),
    [sym_fixed_keyword] = ACTIONS(4373),
    [sym_grid_keyword] = ACTIONS(4373),
    [sym_part_keyword] = ACTIONS(4373),
    [sym_systempart_keyword] = ACTIONS(4373),
    [sym_usercontrol_keyword] = ACTIONS(4373),
    [sym_dataset_keyword] = ACTIONS(4373),
    [sym_elements_keyword] = ACTIONS(4373),
    [sym_dataitem_keyword] = ACTIONS(4373),
    [sym_column_keyword] = ACTIONS(4373),
    [sym_filter_keyword] = ACTIONS(4373),
    [sym_labels_keyword] = ACTIONS(4373),
    [sym_rendering_keyword] = ACTIONS(4373),
    [sym_requestpage_keyword] = ACTIONS(4373),
    [sym_schema_keyword] = ACTIONS(4373),
    [sym_views_keyword] = ACTIONS(4373),
    [sym_quoted_identifier] = ACTIONS(4377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4377),
    [sym_preproc_open] = ACTIONS(4377),
    [sym_preproc_close] = ACTIONS(4377),
    [sym_var_attribute_open] = ACTIONS(4377),
  },
  [STATE(3126)] = {
    [sym_boolean] = STATE(6321),
    [sym_assignment_expression] = STATE(6321),
    [sym__expression] = STATE(6321),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6321),
    [sym_multiplicative_expression] = STATE(6321),
    [sym_additive_expression] = STATE(6321),
    [sym_comparison_expression] = STATE(6321),
    [sym_logical_expression] = STATE(6321),
    [sym_ternary_expression] = STATE(6321),
    [sym_unary_expression] = STATE(6321),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6321),
    [sym_list_literal] = STATE(6321),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6321),
    [sym__literal_value] = STATE(6321),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8131),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8133),
    [sym_date_literal] = ACTIONS(8131),
    [sym_time_literal] = ACTIONS(8131),
    [sym_biginteger_literal] = ACTIONS(8133),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8133),
    [sym_integer] = ACTIONS(8131),
    [sym_continue_as_identifier] = ACTIONS(8133),
  },
  [STATE(3127)] = {
    [sym_boolean] = STATE(6061),
    [sym_assignment_expression] = STATE(6061),
    [sym__expression] = STATE(6061),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6061),
    [sym_multiplicative_expression] = STATE(6061),
    [sym_additive_expression] = STATE(6061),
    [sym_comparison_expression] = STATE(6061),
    [sym_logical_expression] = STATE(6061),
    [sym_ternary_expression] = STATE(6061),
    [sym_unary_expression] = STATE(6061),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6061),
    [sym_list_literal] = STATE(6061),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6061),
    [sym__literal_value] = STATE(6061),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8135),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8137),
    [sym_date_literal] = ACTIONS(8135),
    [sym_time_literal] = ACTIONS(8135),
    [sym_biginteger_literal] = ACTIONS(8137),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8137),
    [sym_integer] = ACTIONS(8135),
    [sym_continue_as_identifier] = ACTIONS(8137),
  },
  [STATE(3128)] = {
    [sym_boolean] = STATE(6209),
    [sym_assignment_expression] = STATE(6209),
    [sym__expression] = STATE(6209),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6209),
    [sym_multiplicative_expression] = STATE(6209),
    [sym_additive_expression] = STATE(6209),
    [sym_comparison_expression] = STATE(6209),
    [sym_logical_expression] = STATE(6209),
    [sym_ternary_expression] = STATE(6209),
    [sym_unary_expression] = STATE(6209),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6209),
    [sym_list_literal] = STATE(6209),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6209),
    [sym__literal_value] = STATE(6209),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8139),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8141),
    [sym_date_literal] = ACTIONS(8139),
    [sym_time_literal] = ACTIONS(8139),
    [sym_biginteger_literal] = ACTIONS(8141),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8141),
    [sym_integer] = ACTIONS(8139),
    [sym_continue_as_identifier] = ACTIONS(8141),
  },
  [STATE(3129)] = {
    [sym_boolean] = STATE(6299),
    [sym_assignment_expression] = STATE(6299),
    [sym__expression] = STATE(6299),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6299),
    [sym_multiplicative_expression] = STATE(6299),
    [sym_additive_expression] = STATE(6299),
    [sym_comparison_expression] = STATE(6299),
    [sym_logical_expression] = STATE(6299),
    [sym_ternary_expression] = STATE(6299),
    [sym_unary_expression] = STATE(6299),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6299),
    [sym_list_literal] = STATE(6299),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6299),
    [sym__literal_value] = STATE(6299),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8143),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8145),
    [sym_date_literal] = ACTIONS(8143),
    [sym_time_literal] = ACTIONS(8143),
    [sym_biginteger_literal] = ACTIONS(8145),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8145),
    [sym_integer] = ACTIONS(8143),
    [sym_continue_as_identifier] = ACTIONS(8145),
  },
  [STATE(3130)] = {
    [sym_boolean] = STATE(6178),
    [sym_assignment_expression] = STATE(6178),
    [sym__expression] = STATE(6178),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6178),
    [sym_multiplicative_expression] = STATE(6178),
    [sym_additive_expression] = STATE(6178),
    [sym_comparison_expression] = STATE(6178),
    [sym_logical_expression] = STATE(6178),
    [sym_ternary_expression] = STATE(6178),
    [sym_unary_expression] = STATE(6178),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6178),
    [sym_list_literal] = STATE(6178),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6178),
    [sym__literal_value] = STATE(6178),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8147),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8149),
    [sym_date_literal] = ACTIONS(8147),
    [sym_time_literal] = ACTIONS(8147),
    [sym_biginteger_literal] = ACTIONS(8149),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8149),
    [sym_integer] = ACTIONS(8147),
    [sym_continue_as_identifier] = ACTIONS(8149),
  },
  [STATE(3131)] = {
    [sym_boolean] = STATE(5993),
    [sym_assignment_expression] = STATE(5993),
    [sym__expression] = STATE(5993),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(5993),
    [sym_multiplicative_expression] = STATE(5993),
    [sym_additive_expression] = STATE(5993),
    [sym_comparison_expression] = STATE(5993),
    [sym_logical_expression] = STATE(5993),
    [sym_ternary_expression] = STATE(5993),
    [sym_unary_expression] = STATE(5993),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(5993),
    [sym_list_literal] = STATE(5993),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(5993),
    [sym__literal_value] = STATE(5993),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8151),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8153),
    [sym_date_literal] = ACTIONS(8151),
    [sym_time_literal] = ACTIONS(8151),
    [sym_biginteger_literal] = ACTIONS(8153),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8153),
    [sym_integer] = ACTIONS(8151),
    [sym_continue_as_identifier] = ACTIONS(8153),
  },
  [STATE(3132)] = {
    [sym_boolean] = STATE(6288),
    [sym_assignment_expression] = STATE(6288),
    [sym__expression] = STATE(6288),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6288),
    [sym_multiplicative_expression] = STATE(6288),
    [sym_additive_expression] = STATE(6288),
    [sym_comparison_expression] = STATE(6288),
    [sym_logical_expression] = STATE(6288),
    [sym_ternary_expression] = STATE(6288),
    [sym_unary_expression] = STATE(6288),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6288),
    [sym_list_literal] = STATE(6288),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6288),
    [sym__literal_value] = STATE(6288),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8155),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8157),
    [sym_date_literal] = ACTIONS(8155),
    [sym_time_literal] = ACTIONS(8155),
    [sym_biginteger_literal] = ACTIONS(8157),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8157),
    [sym_integer] = ACTIONS(8155),
    [sym_continue_as_identifier] = ACTIONS(8157),
  },
  [STATE(3133)] = {
    [sym_boolean] = STATE(6226),
    [sym_assignment_expression] = STATE(6226),
    [sym__expression] = STATE(6226),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6226),
    [sym_multiplicative_expression] = STATE(6226),
    [sym_additive_expression] = STATE(6226),
    [sym_comparison_expression] = STATE(6226),
    [sym_logical_expression] = STATE(6226),
    [sym_ternary_expression] = STATE(6226),
    [sym_unary_expression] = STATE(6226),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6226),
    [sym_list_literal] = STATE(6226),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6226),
    [sym__literal_value] = STATE(6226),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8159),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8161),
    [sym_date_literal] = ACTIONS(8159),
    [sym_time_literal] = ACTIONS(8159),
    [sym_biginteger_literal] = ACTIONS(8161),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8161),
    [sym_integer] = ACTIONS(8159),
    [sym_continue_as_identifier] = ACTIONS(8161),
  },
  [STATE(3134)] = {
    [sym_boolean] = STATE(6285),
    [sym_assignment_expression] = STATE(6285),
    [sym__expression] = STATE(6285),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6285),
    [sym_multiplicative_expression] = STATE(6285),
    [sym_additive_expression] = STATE(6285),
    [sym_comparison_expression] = STATE(6285),
    [sym_logical_expression] = STATE(6285),
    [sym_ternary_expression] = STATE(6285),
    [sym_unary_expression] = STATE(6285),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6285),
    [sym_list_literal] = STATE(6285),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6285),
    [sym__literal_value] = STATE(6285),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8163),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8165),
    [sym_date_literal] = ACTIONS(8163),
    [sym_time_literal] = ACTIONS(8163),
    [sym_biginteger_literal] = ACTIONS(8165),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8165),
    [sym_integer] = ACTIONS(8163),
    [sym_continue_as_identifier] = ACTIONS(8165),
  },
  [STATE(3135)] = {
    [sym_boolean] = STATE(6337),
    [sym_assignment_expression] = STATE(6337),
    [sym__expression] = STATE(6337),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6337),
    [sym_multiplicative_expression] = STATE(6337),
    [sym_additive_expression] = STATE(6337),
    [sym_comparison_expression] = STATE(6337),
    [sym_logical_expression] = STATE(6337),
    [sym_ternary_expression] = STATE(6337),
    [sym_unary_expression] = STATE(6337),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(6247),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6337),
    [sym_list_literal] = STATE(6337),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6337),
    [sym__literal_value] = STATE(6337),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(8167),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8169),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8171),
    [sym_date_literal] = ACTIONS(8169),
    [sym_time_literal] = ACTIONS(8169),
    [sym_biginteger_literal] = ACTIONS(8171),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8173),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8171),
    [sym_integer] = ACTIONS(8169),
    [sym_continue_as_identifier] = ACTIONS(8171),
  },
  [STATE(3136)] = {
    [sym_identifier] = ACTIONS(8175),
    [anon_sym_SEMI] = ACTIONS(8177),
    [aux_sym_where_condition_token1] = ACTIONS(8175),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8175),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8175),
    [anon_sym_LBRACK] = ACTIONS(8177),
    [aux_sym_basic_type_token6] = ACTIONS(8175),
    [aux_sym_basic_type_token22] = ACTIONS(8175),
    [aux_sym_basic_type_token53] = ACTIONS(8175),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8175),
    [aux_sym_addafter_modification_token1] = ACTIONS(8175),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8175),
    [aux_sym_modify_modification_token1] = ACTIONS(8175),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8175),
    [aux_sym_movelast_modification_token1] = ACTIONS(8175),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8175),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8175),
    [aux_sym_separator_action_token1] = ACTIONS(8175),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8175),
    [aux_sym_type_declaration_token1] = ACTIONS(8175),
    [anon_sym_POUNDif] = ACTIONS(8177),
    [anon_sym_POUNDIF] = ACTIONS(8177),
    [anon_sym_POUNDIf] = ACTIONS(8177),
    [anon_sym_POUNDelif] = ACTIONS(8177),
    [anon_sym_POUNDELIF] = ACTIONS(8177),
    [anon_sym_POUNDElif] = ACTIONS(8177),
    [anon_sym_POUNDelse] = ACTIONS(8177),
    [anon_sym_POUNDELSE] = ACTIONS(8177),
    [anon_sym_POUNDElse] = ACTIONS(8177),
    [anon_sym_POUNDendif] = ACTIONS(8177),
    [anon_sym_POUNDENDIF] = ACTIONS(8177),
    [anon_sym_POUNDEndif] = ACTIONS(8177),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8175),
    [sym_trigger_keyword] = ACTIONS(8175),
    [sym_var_keyword] = ACTIONS(8175),
    [sym_local_keyword] = ACTIONS(8175),
    [sym_internal_keyword] = ACTIONS(8175),
    [sym_protected_keyword] = ACTIONS(8175),
    [sym_event_keyword] = ACTIONS(8175),
    [sym_fields_keyword] = ACTIONS(8175),
    [sym_keys_keyword] = ACTIONS(8175),
    [sym_key_keyword] = ACTIONS(8175),
    [sym_fieldgroups_keyword] = ACTIONS(8175),
    [sym_actions_keyword] = ACTIONS(8175),
    [sym_layout_keyword] = ACTIONS(8175),
    [sym_area_keyword] = ACTIONS(8175),
    [sym_group_keyword] = ACTIONS(8175),
    [sym_repeater_keyword] = ACTIONS(8175),
    [sym_cuegroup_keyword] = ACTIONS(8175),
    [sym_fixed_keyword] = ACTIONS(8175),
    [sym_grid_keyword] = ACTIONS(8175),
    [sym_part_keyword] = ACTIONS(8175),
    [sym_systempart_keyword] = ACTIONS(8175),
    [sym_usercontrol_keyword] = ACTIONS(8175),
    [sym_dataset_keyword] = ACTIONS(8175),
    [sym_elements_keyword] = ACTIONS(8175),
    [sym_dataitem_keyword] = ACTIONS(8175),
    [sym_column_keyword] = ACTIONS(8175),
    [sym_filter_keyword] = ACTIONS(8175),
    [sym_labels_keyword] = ACTIONS(8175),
    [sym_rendering_keyword] = ACTIONS(8175),
    [sym_requestpage_keyword] = ACTIONS(8175),
    [sym_schema_keyword] = ACTIONS(8175),
    [sym_views_keyword] = ACTIONS(8175),
    [sym_quoted_identifier] = ACTIONS(8177),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8177),
    [sym_preproc_open] = ACTIONS(8177),
    [sym_preproc_close] = ACTIONS(8177),
    [sym_var_attribute_open] = ACTIONS(8177),
  },
  [STATE(3137)] = {
    [sym_boolean] = STATE(6071),
    [sym_assignment_expression] = STATE(6071),
    [sym__expression] = STATE(6071),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6071),
    [sym_multiplicative_expression] = STATE(6071),
    [sym_additive_expression] = STATE(6071),
    [sym_comparison_expression] = STATE(6071),
    [sym_logical_expression] = STATE(6071),
    [sym_ternary_expression] = STATE(6071),
    [sym_unary_expression] = STATE(6071),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6071),
    [sym_list_literal] = STATE(6071),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6071),
    [sym__literal_value] = STATE(6071),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8179),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8181),
    [sym_date_literal] = ACTIONS(8179),
    [sym_time_literal] = ACTIONS(8179),
    [sym_biginteger_literal] = ACTIONS(8181),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8181),
    [sym_integer] = ACTIONS(8179),
    [sym_continue_as_identifier] = ACTIONS(8181),
  },
  [STATE(3138)] = {
    [sym_boolean] = STATE(6286),
    [sym_assignment_expression] = STATE(6286),
    [sym__expression] = STATE(6286),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6286),
    [sym_multiplicative_expression] = STATE(6286),
    [sym_additive_expression] = STATE(6286),
    [sym_comparison_expression] = STATE(6286),
    [sym_logical_expression] = STATE(6286),
    [sym_ternary_expression] = STATE(6286),
    [sym_unary_expression] = STATE(6286),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6286),
    [sym_list_literal] = STATE(6286),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6286),
    [sym__literal_value] = STATE(6286),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8183),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(8185),
    [sym_date_literal] = ACTIONS(8183),
    [sym_time_literal] = ACTIONS(8183),
    [sym_biginteger_literal] = ACTIONS(8185),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8185),
    [sym_integer] = ACTIONS(8183),
    [sym_continue_as_identifier] = ACTIONS(8185),
  },
  [STATE(3139)] = {
    [sym_boolean] = STATE(6010),
    [sym_assignment_expression] = STATE(6010),
    [sym__expression] = STATE(6010),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6010),
    [sym_multiplicative_expression] = STATE(6010),
    [sym_additive_expression] = STATE(6010),
    [sym_comparison_expression] = STATE(6010),
    [sym_logical_expression] = STATE(6010),
    [sym_ternary_expression] = STATE(6010),
    [sym_unary_expression] = STATE(6010),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6010),
    [sym_list_literal] = STATE(6010),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6010),
    [sym__literal_value] = STATE(6010),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8187),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8189),
    [sym_date_literal] = ACTIONS(8187),
    [sym_time_literal] = ACTIONS(8187),
    [sym_biginteger_literal] = ACTIONS(8189),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8189),
    [sym_integer] = ACTIONS(8187),
    [sym_continue_as_identifier] = ACTIONS(8189),
  },
  [STATE(3140)] = {
    [sym_identifier] = ACTIONS(4373),
    [anon_sym_SEMI] = ACTIONS(4377),
    [aux_sym_where_condition_token1] = ACTIONS(4373),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4373),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4373),
    [anon_sym_LBRACK] = ACTIONS(4377),
    [aux_sym_basic_type_token6] = ACTIONS(4373),
    [aux_sym_basic_type_token22] = ACTIONS(4373),
    [aux_sym_basic_type_token53] = ACTIONS(4373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4373),
    [aux_sym_addafter_modification_token1] = ACTIONS(4373),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4373),
    [aux_sym_modify_modification_token1] = ACTIONS(4373),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4373),
    [aux_sym_movelast_modification_token1] = ACTIONS(4373),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4373),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4373),
    [aux_sym_separator_action_token1] = ACTIONS(4373),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4373),
    [aux_sym_type_declaration_token1] = ACTIONS(4373),
    [anon_sym_POUNDif] = ACTIONS(4377),
    [anon_sym_POUNDIF] = ACTIONS(4377),
    [anon_sym_POUNDIf] = ACTIONS(4377),
    [anon_sym_POUNDelif] = ACTIONS(4377),
    [anon_sym_POUNDELIF] = ACTIONS(4377),
    [anon_sym_POUNDElif] = ACTIONS(4377),
    [anon_sym_POUNDelse] = ACTIONS(4377),
    [anon_sym_POUNDELSE] = ACTIONS(4377),
    [anon_sym_POUNDElse] = ACTIONS(4377),
    [anon_sym_POUNDendif] = ACTIONS(4377),
    [anon_sym_POUNDENDIF] = ACTIONS(4377),
    [anon_sym_POUNDEndif] = ACTIONS(4377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4373),
    [sym_trigger_keyword] = ACTIONS(4373),
    [sym_var_keyword] = ACTIONS(4373),
    [sym_local_keyword] = ACTIONS(4373),
    [sym_internal_keyword] = ACTIONS(4373),
    [sym_protected_keyword] = ACTIONS(4373),
    [sym_event_keyword] = ACTIONS(4373),
    [sym_fields_keyword] = ACTIONS(4373),
    [sym_keys_keyword] = ACTIONS(4373),
    [sym_key_keyword] = ACTIONS(4373),
    [sym_fieldgroups_keyword] = ACTIONS(4373),
    [sym_actions_keyword] = ACTIONS(4373),
    [sym_layout_keyword] = ACTIONS(4373),
    [sym_area_keyword] = ACTIONS(4373),
    [sym_group_keyword] = ACTIONS(4373),
    [sym_repeater_keyword] = ACTIONS(4373),
    [sym_cuegroup_keyword] = ACTIONS(4373),
    [sym_fixed_keyword] = ACTIONS(4373),
    [sym_grid_keyword] = ACTIONS(4373),
    [sym_part_keyword] = ACTIONS(4373),
    [sym_systempart_keyword] = ACTIONS(4373),
    [sym_usercontrol_keyword] = ACTIONS(4373),
    [sym_dataset_keyword] = ACTIONS(4373),
    [sym_elements_keyword] = ACTIONS(4373),
    [sym_dataitem_keyword] = ACTIONS(4373),
    [sym_column_keyword] = ACTIONS(4373),
    [sym_filter_keyword] = ACTIONS(4373),
    [sym_labels_keyword] = ACTIONS(4373),
    [sym_rendering_keyword] = ACTIONS(4373),
    [sym_requestpage_keyword] = ACTIONS(4373),
    [sym_schema_keyword] = ACTIONS(4373),
    [sym_views_keyword] = ACTIONS(4373),
    [sym_quoted_identifier] = ACTIONS(4377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4377),
    [sym_preproc_open] = ACTIONS(4377),
    [sym_preproc_close] = ACTIONS(4377),
    [sym_var_attribute_open] = ACTIONS(4377),
  },
  [STATE(3141)] = {
    [sym_boolean] = STATE(6135),
    [sym_assignment_expression] = STATE(6135),
    [sym__expression] = STATE(6135),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6135),
    [sym_multiplicative_expression] = STATE(6135),
    [sym_additive_expression] = STATE(6135),
    [sym_comparison_expression] = STATE(6135),
    [sym_logical_expression] = STATE(6135),
    [sym_ternary_expression] = STATE(6135),
    [sym_unary_expression] = STATE(6135),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6135),
    [sym_list_literal] = STATE(6135),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6135),
    [sym__literal_value] = STATE(6135),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8191),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8193),
    [sym_date_literal] = ACTIONS(8191),
    [sym_time_literal] = ACTIONS(8191),
    [sym_biginteger_literal] = ACTIONS(8193),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8193),
    [sym_integer] = ACTIONS(8191),
    [sym_continue_as_identifier] = ACTIONS(8193),
  },
  [STATE(3142)] = {
    [sym_boolean] = STATE(6306),
    [sym_assignment_expression] = STATE(6306),
    [sym__expression] = STATE(6306),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6306),
    [sym_multiplicative_expression] = STATE(6306),
    [sym_additive_expression] = STATE(6306),
    [sym_comparison_expression] = STATE(6306),
    [sym_logical_expression] = STATE(6306),
    [sym_ternary_expression] = STATE(6306),
    [sym_unary_expression] = STATE(6306),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6306),
    [sym_list_literal] = STATE(6306),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6306),
    [sym__literal_value] = STATE(6306),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8195),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(8197),
    [sym_date_literal] = ACTIONS(8195),
    [sym_time_literal] = ACTIONS(8195),
    [sym_biginteger_literal] = ACTIONS(8197),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8197),
    [sym_integer] = ACTIONS(8195),
    [sym_continue_as_identifier] = ACTIONS(8197),
  },
  [STATE(3143)] = {
    [sym_identifier] = ACTIONS(8199),
    [anon_sym_SEMI] = ACTIONS(8201),
    [aux_sym_where_condition_token1] = ACTIONS(8199),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8199),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8199),
    [anon_sym_LBRACK] = ACTIONS(8201),
    [aux_sym_basic_type_token6] = ACTIONS(8199),
    [aux_sym_basic_type_token22] = ACTIONS(8199),
    [aux_sym_basic_type_token53] = ACTIONS(8199),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8199),
    [aux_sym_addafter_modification_token1] = ACTIONS(8199),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8199),
    [aux_sym_modify_modification_token1] = ACTIONS(8199),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8199),
    [aux_sym_movelast_modification_token1] = ACTIONS(8199),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8199),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8199),
    [aux_sym_separator_action_token1] = ACTIONS(8199),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8199),
    [aux_sym_type_declaration_token1] = ACTIONS(8199),
    [anon_sym_POUNDif] = ACTIONS(8201),
    [anon_sym_POUNDIF] = ACTIONS(8201),
    [anon_sym_POUNDIf] = ACTIONS(8201),
    [anon_sym_POUNDelif] = ACTIONS(8201),
    [anon_sym_POUNDELIF] = ACTIONS(8201),
    [anon_sym_POUNDElif] = ACTIONS(8201),
    [anon_sym_POUNDelse] = ACTIONS(8201),
    [anon_sym_POUNDELSE] = ACTIONS(8201),
    [anon_sym_POUNDElse] = ACTIONS(8201),
    [anon_sym_POUNDendif] = ACTIONS(8201),
    [anon_sym_POUNDENDIF] = ACTIONS(8201),
    [anon_sym_POUNDEndif] = ACTIONS(8201),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8199),
    [sym_trigger_keyword] = ACTIONS(8199),
    [sym_var_keyword] = ACTIONS(8199),
    [sym_local_keyword] = ACTIONS(8199),
    [sym_internal_keyword] = ACTIONS(8199),
    [sym_protected_keyword] = ACTIONS(8199),
    [sym_event_keyword] = ACTIONS(8199),
    [sym_fields_keyword] = ACTIONS(8199),
    [sym_keys_keyword] = ACTIONS(8199),
    [sym_key_keyword] = ACTIONS(8199),
    [sym_fieldgroups_keyword] = ACTIONS(8199),
    [sym_actions_keyword] = ACTIONS(8199),
    [sym_layout_keyword] = ACTIONS(8199),
    [sym_area_keyword] = ACTIONS(8199),
    [sym_group_keyword] = ACTIONS(8199),
    [sym_repeater_keyword] = ACTIONS(8199),
    [sym_cuegroup_keyword] = ACTIONS(8199),
    [sym_fixed_keyword] = ACTIONS(8199),
    [sym_grid_keyword] = ACTIONS(8199),
    [sym_part_keyword] = ACTIONS(8199),
    [sym_systempart_keyword] = ACTIONS(8199),
    [sym_usercontrol_keyword] = ACTIONS(8199),
    [sym_dataset_keyword] = ACTIONS(8199),
    [sym_elements_keyword] = ACTIONS(8199),
    [sym_dataitem_keyword] = ACTIONS(8199),
    [sym_column_keyword] = ACTIONS(8199),
    [sym_filter_keyword] = ACTIONS(8199),
    [sym_labels_keyword] = ACTIONS(8199),
    [sym_rendering_keyword] = ACTIONS(8199),
    [sym_requestpage_keyword] = ACTIONS(8199),
    [sym_schema_keyword] = ACTIONS(8199),
    [sym_views_keyword] = ACTIONS(8199),
    [sym_quoted_identifier] = ACTIONS(8201),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8201),
    [sym_preproc_open] = ACTIONS(8201),
    [sym_preproc_close] = ACTIONS(8201),
    [sym_var_attribute_open] = ACTIONS(8201),
  },
  [STATE(3144)] = {
    [sym_boolean] = STATE(6289),
    [sym_assignment_expression] = STATE(6289),
    [sym__expression] = STATE(6289),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6289),
    [sym_multiplicative_expression] = STATE(6289),
    [sym_additive_expression] = STATE(6289),
    [sym_comparison_expression] = STATE(6289),
    [sym_logical_expression] = STATE(6289),
    [sym_ternary_expression] = STATE(6289),
    [sym_unary_expression] = STATE(6289),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6289),
    [sym_list_literal] = STATE(6289),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6289),
    [sym__literal_value] = STATE(6289),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8203),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(8205),
    [sym_date_literal] = ACTIONS(8203),
    [sym_time_literal] = ACTIONS(8203),
    [sym_biginteger_literal] = ACTIONS(8205),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8205),
    [sym_integer] = ACTIONS(8203),
    [sym_continue_as_identifier] = ACTIONS(8205),
  },
  [STATE(3145)] = {
    [sym_identifier] = ACTIONS(8199),
    [anon_sym_SEMI] = ACTIONS(8201),
    [aux_sym_where_condition_token1] = ACTIONS(8199),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8199),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8199),
    [anon_sym_LBRACK] = ACTIONS(8201),
    [aux_sym_basic_type_token6] = ACTIONS(8199),
    [aux_sym_basic_type_token22] = ACTIONS(8199),
    [aux_sym_basic_type_token53] = ACTIONS(8199),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8199),
    [aux_sym_addafter_modification_token1] = ACTIONS(8199),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8199),
    [aux_sym_modify_modification_token1] = ACTIONS(8199),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8199),
    [aux_sym_movelast_modification_token1] = ACTIONS(8199),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8199),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8199),
    [aux_sym_separator_action_token1] = ACTIONS(8199),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8199),
    [aux_sym_type_declaration_token1] = ACTIONS(8199),
    [anon_sym_POUNDif] = ACTIONS(8201),
    [anon_sym_POUNDIF] = ACTIONS(8201),
    [anon_sym_POUNDIf] = ACTIONS(8201),
    [anon_sym_POUNDelif] = ACTIONS(8201),
    [anon_sym_POUNDELIF] = ACTIONS(8201),
    [anon_sym_POUNDElif] = ACTIONS(8201),
    [anon_sym_POUNDelse] = ACTIONS(8201),
    [anon_sym_POUNDELSE] = ACTIONS(8201),
    [anon_sym_POUNDElse] = ACTIONS(8201),
    [anon_sym_POUNDendif] = ACTIONS(8201),
    [anon_sym_POUNDENDIF] = ACTIONS(8201),
    [anon_sym_POUNDEndif] = ACTIONS(8201),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8199),
    [sym_trigger_keyword] = ACTIONS(8199),
    [sym_var_keyword] = ACTIONS(8199),
    [sym_local_keyword] = ACTIONS(8199),
    [sym_internal_keyword] = ACTIONS(8199),
    [sym_protected_keyword] = ACTIONS(8199),
    [sym_event_keyword] = ACTIONS(8199),
    [sym_fields_keyword] = ACTIONS(8199),
    [sym_keys_keyword] = ACTIONS(8199),
    [sym_key_keyword] = ACTIONS(8199),
    [sym_fieldgroups_keyword] = ACTIONS(8199),
    [sym_actions_keyword] = ACTIONS(8199),
    [sym_layout_keyword] = ACTIONS(8199),
    [sym_area_keyword] = ACTIONS(8199),
    [sym_group_keyword] = ACTIONS(8199),
    [sym_repeater_keyword] = ACTIONS(8199),
    [sym_cuegroup_keyword] = ACTIONS(8199),
    [sym_fixed_keyword] = ACTIONS(8199),
    [sym_grid_keyword] = ACTIONS(8199),
    [sym_part_keyword] = ACTIONS(8199),
    [sym_systempart_keyword] = ACTIONS(8199),
    [sym_usercontrol_keyword] = ACTIONS(8199),
    [sym_dataset_keyword] = ACTIONS(8199),
    [sym_elements_keyword] = ACTIONS(8199),
    [sym_dataitem_keyword] = ACTIONS(8199),
    [sym_column_keyword] = ACTIONS(8199),
    [sym_filter_keyword] = ACTIONS(8199),
    [sym_labels_keyword] = ACTIONS(8199),
    [sym_rendering_keyword] = ACTIONS(8199),
    [sym_requestpage_keyword] = ACTIONS(8199),
    [sym_schema_keyword] = ACTIONS(8199),
    [sym_views_keyword] = ACTIONS(8199),
    [sym_quoted_identifier] = ACTIONS(8201),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8201),
    [sym_preproc_open] = ACTIONS(8201),
    [sym_preproc_close] = ACTIONS(8201),
    [sym_var_attribute_open] = ACTIONS(8201),
  },
  [STATE(3146)] = {
    [sym_boolean] = STATE(1067),
    [sym_assignment_expression] = STATE(1067),
    [sym__expression] = STATE(1067),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1067),
    [sym_multiplicative_expression] = STATE(1067),
    [sym_additive_expression] = STATE(1067),
    [sym_comparison_expression] = STATE(1067),
    [sym_logical_expression] = STATE(1067),
    [sym_ternary_expression] = STATE(1067),
    [sym_unary_expression] = STATE(1067),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1067),
    [sym_list_literal] = STATE(1067),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1067),
    [sym__literal_value] = STATE(1067),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(8207),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(8209),
    [sym_date_literal] = ACTIONS(8207),
    [sym_time_literal] = ACTIONS(8207),
    [sym_biginteger_literal] = ACTIONS(8209),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8209),
    [sym_integer] = ACTIONS(8207),
    [sym_continue_as_identifier] = ACTIONS(8209),
  },
  [STATE(3147)] = {
    [sym_identifier] = ACTIONS(8211),
    [anon_sym_SEMI] = ACTIONS(8213),
    [aux_sym_where_condition_token1] = ACTIONS(8211),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8211),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8211),
    [anon_sym_LBRACK] = ACTIONS(8213),
    [aux_sym_basic_type_token6] = ACTIONS(8211),
    [aux_sym_basic_type_token22] = ACTIONS(8211),
    [aux_sym_basic_type_token53] = ACTIONS(8211),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8211),
    [aux_sym_addafter_modification_token1] = ACTIONS(8211),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8211),
    [aux_sym_modify_modification_token1] = ACTIONS(8211),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8211),
    [aux_sym_movelast_modification_token1] = ACTIONS(8211),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8211),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8211),
    [aux_sym_separator_action_token1] = ACTIONS(8211),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8211),
    [aux_sym_type_declaration_token1] = ACTIONS(8211),
    [anon_sym_POUNDif] = ACTIONS(8213),
    [anon_sym_POUNDIF] = ACTIONS(8213),
    [anon_sym_POUNDIf] = ACTIONS(8213),
    [anon_sym_POUNDelif] = ACTIONS(8213),
    [anon_sym_POUNDELIF] = ACTIONS(8213),
    [anon_sym_POUNDElif] = ACTIONS(8213),
    [anon_sym_POUNDelse] = ACTIONS(8213),
    [anon_sym_POUNDELSE] = ACTIONS(8213),
    [anon_sym_POUNDElse] = ACTIONS(8213),
    [anon_sym_POUNDendif] = ACTIONS(8213),
    [anon_sym_POUNDENDIF] = ACTIONS(8213),
    [anon_sym_POUNDEndif] = ACTIONS(8213),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8211),
    [sym_trigger_keyword] = ACTIONS(8211),
    [sym_var_keyword] = ACTIONS(8211),
    [sym_local_keyword] = ACTIONS(8211),
    [sym_internal_keyword] = ACTIONS(8211),
    [sym_protected_keyword] = ACTIONS(8211),
    [sym_event_keyword] = ACTIONS(8211),
    [sym_fields_keyword] = ACTIONS(8211),
    [sym_keys_keyword] = ACTIONS(8211),
    [sym_key_keyword] = ACTIONS(8211),
    [sym_fieldgroups_keyword] = ACTIONS(8211),
    [sym_actions_keyword] = ACTIONS(8211),
    [sym_layout_keyword] = ACTIONS(8211),
    [sym_area_keyword] = ACTIONS(8211),
    [sym_group_keyword] = ACTIONS(8211),
    [sym_repeater_keyword] = ACTIONS(8211),
    [sym_cuegroup_keyword] = ACTIONS(8211),
    [sym_fixed_keyword] = ACTIONS(8211),
    [sym_grid_keyword] = ACTIONS(8211),
    [sym_part_keyword] = ACTIONS(8211),
    [sym_systempart_keyword] = ACTIONS(8211),
    [sym_usercontrol_keyword] = ACTIONS(8211),
    [sym_dataset_keyword] = ACTIONS(8211),
    [sym_elements_keyword] = ACTIONS(8211),
    [sym_dataitem_keyword] = ACTIONS(8211),
    [sym_column_keyword] = ACTIONS(8211),
    [sym_filter_keyword] = ACTIONS(8211),
    [sym_labels_keyword] = ACTIONS(8211),
    [sym_rendering_keyword] = ACTIONS(8211),
    [sym_requestpage_keyword] = ACTIONS(8211),
    [sym_schema_keyword] = ACTIONS(8211),
    [sym_views_keyword] = ACTIONS(8211),
    [sym_quoted_identifier] = ACTIONS(8213),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8213),
    [sym_preproc_open] = ACTIONS(8213),
    [sym_preproc_close] = ACTIONS(8213),
    [sym_var_attribute_open] = ACTIONS(8213),
  },
  [STATE(3148)] = {
    [sym_boolean] = STATE(4932),
    [sym_assignment_expression] = STATE(4932),
    [sym__expression] = STATE(4932),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4932),
    [sym_multiplicative_expression] = STATE(4932),
    [sym_additive_expression] = STATE(4932),
    [sym_comparison_expression] = STATE(4932),
    [sym_logical_expression] = STATE(4932),
    [sym_ternary_expression] = STATE(4932),
    [sym_unary_expression] = STATE(4932),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4932),
    [sym_list_literal] = STATE(4932),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4932),
    [sym__literal_value] = STATE(4932),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8215),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8217),
    [sym_date_literal] = ACTIONS(8215),
    [sym_time_literal] = ACTIONS(8215),
    [sym_biginteger_literal] = ACTIONS(8217),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8217),
    [sym_integer] = ACTIONS(8215),
    [sym_continue_as_identifier] = ACTIONS(8217),
  },
  [STATE(3149)] = {
    [sym_boolean] = STATE(5996),
    [sym_assignment_expression] = STATE(5996),
    [sym__expression] = STATE(5996),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(5996),
    [sym_multiplicative_expression] = STATE(5996),
    [sym_additive_expression] = STATE(5996),
    [sym_comparison_expression] = STATE(5996),
    [sym_logical_expression] = STATE(5996),
    [sym_ternary_expression] = STATE(5996),
    [sym_unary_expression] = STATE(5996),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(5996),
    [sym_list_literal] = STATE(5996),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(5996),
    [sym__literal_value] = STATE(5996),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8219),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8221),
    [sym_date_literal] = ACTIONS(8219),
    [sym_time_literal] = ACTIONS(8219),
    [sym_biginteger_literal] = ACTIONS(8221),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8221),
    [sym_integer] = ACTIONS(8219),
    [sym_continue_as_identifier] = ACTIONS(8221),
  },
  [STATE(3150)] = {
    [sym_boolean] = STATE(6000),
    [sym_assignment_expression] = STATE(6000),
    [sym__expression] = STATE(6000),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6000),
    [sym_multiplicative_expression] = STATE(6000),
    [sym_additive_expression] = STATE(6000),
    [sym_comparison_expression] = STATE(6000),
    [sym_logical_expression] = STATE(6000),
    [sym_ternary_expression] = STATE(6000),
    [sym_unary_expression] = STATE(6000),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6000),
    [sym_list_literal] = STATE(6000),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6000),
    [sym__literal_value] = STATE(6000),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8223),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8225),
    [sym_date_literal] = ACTIONS(8223),
    [sym_time_literal] = ACTIONS(8223),
    [sym_biginteger_literal] = ACTIONS(8225),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8225),
    [sym_integer] = ACTIONS(8223),
    [sym_continue_as_identifier] = ACTIONS(8225),
  },
  [STATE(3151)] = {
    [sym_identifier] = ACTIONS(8199),
    [anon_sym_SEMI] = ACTIONS(8201),
    [aux_sym_where_condition_token1] = ACTIONS(8199),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8199),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8199),
    [anon_sym_LBRACK] = ACTIONS(8201),
    [aux_sym_basic_type_token6] = ACTIONS(8199),
    [aux_sym_basic_type_token22] = ACTIONS(8199),
    [aux_sym_basic_type_token53] = ACTIONS(8199),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8199),
    [aux_sym_addafter_modification_token1] = ACTIONS(8199),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8199),
    [aux_sym_modify_modification_token1] = ACTIONS(8199),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8199),
    [aux_sym_movelast_modification_token1] = ACTIONS(8199),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8199),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8199),
    [aux_sym_separator_action_token1] = ACTIONS(8199),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8199),
    [aux_sym_type_declaration_token1] = ACTIONS(8199),
    [anon_sym_POUNDif] = ACTIONS(8201),
    [anon_sym_POUNDIF] = ACTIONS(8201),
    [anon_sym_POUNDIf] = ACTIONS(8201),
    [anon_sym_POUNDelif] = ACTIONS(8201),
    [anon_sym_POUNDELIF] = ACTIONS(8201),
    [anon_sym_POUNDElif] = ACTIONS(8201),
    [anon_sym_POUNDelse] = ACTIONS(8201),
    [anon_sym_POUNDELSE] = ACTIONS(8201),
    [anon_sym_POUNDElse] = ACTIONS(8201),
    [anon_sym_POUNDendif] = ACTIONS(8201),
    [anon_sym_POUNDENDIF] = ACTIONS(8201),
    [anon_sym_POUNDEndif] = ACTIONS(8201),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8199),
    [sym_trigger_keyword] = ACTIONS(8199),
    [sym_var_keyword] = ACTIONS(8199),
    [sym_local_keyword] = ACTIONS(8199),
    [sym_internal_keyword] = ACTIONS(8199),
    [sym_protected_keyword] = ACTIONS(8199),
    [sym_event_keyword] = ACTIONS(8199),
    [sym_fields_keyword] = ACTIONS(8199),
    [sym_keys_keyword] = ACTIONS(8199),
    [sym_key_keyword] = ACTIONS(8199),
    [sym_fieldgroups_keyword] = ACTIONS(8199),
    [sym_actions_keyword] = ACTIONS(8199),
    [sym_layout_keyword] = ACTIONS(8199),
    [sym_area_keyword] = ACTIONS(8199),
    [sym_group_keyword] = ACTIONS(8199),
    [sym_repeater_keyword] = ACTIONS(8199),
    [sym_cuegroup_keyword] = ACTIONS(8199),
    [sym_fixed_keyword] = ACTIONS(8199),
    [sym_grid_keyword] = ACTIONS(8199),
    [sym_part_keyword] = ACTIONS(8199),
    [sym_systempart_keyword] = ACTIONS(8199),
    [sym_usercontrol_keyword] = ACTIONS(8199),
    [sym_dataset_keyword] = ACTIONS(8199),
    [sym_elements_keyword] = ACTIONS(8199),
    [sym_dataitem_keyword] = ACTIONS(8199),
    [sym_column_keyword] = ACTIONS(8199),
    [sym_filter_keyword] = ACTIONS(8199),
    [sym_labels_keyword] = ACTIONS(8199),
    [sym_rendering_keyword] = ACTIONS(8199),
    [sym_requestpage_keyword] = ACTIONS(8199),
    [sym_schema_keyword] = ACTIONS(8199),
    [sym_views_keyword] = ACTIONS(8199),
    [sym_quoted_identifier] = ACTIONS(8201),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8201),
    [sym_preproc_open] = ACTIONS(8201),
    [sym_preproc_close] = ACTIONS(8201),
    [sym_var_attribute_open] = ACTIONS(8201),
  },
  [STATE(3152)] = {
    [sym_boolean] = STATE(6305),
    [sym_assignment_expression] = STATE(6305),
    [sym__expression] = STATE(6305),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6305),
    [sym_multiplicative_expression] = STATE(6305),
    [sym_additive_expression] = STATE(6305),
    [sym_comparison_expression] = STATE(6305),
    [sym_logical_expression] = STATE(6305),
    [sym_ternary_expression] = STATE(6305),
    [sym_unary_expression] = STATE(6305),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6305),
    [sym_list_literal] = STATE(6305),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6305),
    [sym__literal_value] = STATE(6305),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8227),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8229),
    [sym_date_literal] = ACTIONS(8227),
    [sym_time_literal] = ACTIONS(8227),
    [sym_biginteger_literal] = ACTIONS(8229),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8229),
    [sym_integer] = ACTIONS(8227),
    [sym_continue_as_identifier] = ACTIONS(8229),
  },
  [STATE(3153)] = {
    [sym_boolean] = STATE(6176),
    [sym_assignment_expression] = STATE(6176),
    [sym__expression] = STATE(6176),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6176),
    [sym_multiplicative_expression] = STATE(6176),
    [sym_additive_expression] = STATE(6176),
    [sym_comparison_expression] = STATE(6176),
    [sym_logical_expression] = STATE(6176),
    [sym_ternary_expression] = STATE(6176),
    [sym_unary_expression] = STATE(6176),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6176),
    [sym_list_literal] = STATE(6176),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6176),
    [sym__literal_value] = STATE(6176),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8231),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8233),
    [sym_date_literal] = ACTIONS(8231),
    [sym_time_literal] = ACTIONS(8231),
    [sym_biginteger_literal] = ACTIONS(8233),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8233),
    [sym_integer] = ACTIONS(8231),
    [sym_continue_as_identifier] = ACTIONS(8233),
  },
  [STATE(3154)] = {
    [sym_identifier] = ACTIONS(8235),
    [anon_sym_SEMI] = ACTIONS(8237),
    [aux_sym_where_condition_token1] = ACTIONS(8235),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8235),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8235),
    [anon_sym_LBRACK] = ACTIONS(8237),
    [aux_sym_basic_type_token6] = ACTIONS(8235),
    [aux_sym_basic_type_token22] = ACTIONS(8235),
    [aux_sym_basic_type_token53] = ACTIONS(8235),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8235),
    [aux_sym_addafter_modification_token1] = ACTIONS(8235),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8235),
    [aux_sym_modify_modification_token1] = ACTIONS(8235),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8235),
    [aux_sym_movelast_modification_token1] = ACTIONS(8235),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8235),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8235),
    [aux_sym_separator_action_token1] = ACTIONS(8235),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8235),
    [aux_sym_type_declaration_token1] = ACTIONS(8235),
    [anon_sym_POUNDif] = ACTIONS(8237),
    [anon_sym_POUNDIF] = ACTIONS(8237),
    [anon_sym_POUNDIf] = ACTIONS(8237),
    [anon_sym_POUNDelif] = ACTIONS(8237),
    [anon_sym_POUNDELIF] = ACTIONS(8237),
    [anon_sym_POUNDElif] = ACTIONS(8237),
    [anon_sym_POUNDelse] = ACTIONS(8237),
    [anon_sym_POUNDELSE] = ACTIONS(8237),
    [anon_sym_POUNDElse] = ACTIONS(8237),
    [anon_sym_POUNDendif] = ACTIONS(8237),
    [anon_sym_POUNDENDIF] = ACTIONS(8237),
    [anon_sym_POUNDEndif] = ACTIONS(8237),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8235),
    [sym_trigger_keyword] = ACTIONS(8235),
    [sym_var_keyword] = ACTIONS(8235),
    [sym_local_keyword] = ACTIONS(8235),
    [sym_internal_keyword] = ACTIONS(8235),
    [sym_protected_keyword] = ACTIONS(8235),
    [sym_event_keyword] = ACTIONS(8235),
    [sym_fields_keyword] = ACTIONS(8235),
    [sym_keys_keyword] = ACTIONS(8235),
    [sym_key_keyword] = ACTIONS(8235),
    [sym_fieldgroups_keyword] = ACTIONS(8235),
    [sym_actions_keyword] = ACTIONS(8235),
    [sym_layout_keyword] = ACTIONS(8235),
    [sym_area_keyword] = ACTIONS(8235),
    [sym_group_keyword] = ACTIONS(8235),
    [sym_repeater_keyword] = ACTIONS(8235),
    [sym_cuegroup_keyword] = ACTIONS(8235),
    [sym_fixed_keyword] = ACTIONS(8235),
    [sym_grid_keyword] = ACTIONS(8235),
    [sym_part_keyword] = ACTIONS(8235),
    [sym_systempart_keyword] = ACTIONS(8235),
    [sym_usercontrol_keyword] = ACTIONS(8235),
    [sym_dataset_keyword] = ACTIONS(8235),
    [sym_elements_keyword] = ACTIONS(8235),
    [sym_dataitem_keyword] = ACTIONS(8235),
    [sym_column_keyword] = ACTIONS(8235),
    [sym_filter_keyword] = ACTIONS(8235),
    [sym_labels_keyword] = ACTIONS(8235),
    [sym_rendering_keyword] = ACTIONS(8235),
    [sym_requestpage_keyword] = ACTIONS(8235),
    [sym_schema_keyword] = ACTIONS(8235),
    [sym_views_keyword] = ACTIONS(8235),
    [sym_quoted_identifier] = ACTIONS(8237),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8237),
    [sym_preproc_open] = ACTIONS(8237),
    [sym_preproc_close] = ACTIONS(8237),
    [sym_var_attribute_open] = ACTIONS(8237),
  },
  [STATE(3155)] = {
    [sym_boolean] = STATE(5873),
    [sym_assignment_expression] = STATE(5873),
    [sym__expression] = STATE(5873),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5873),
    [sym_multiplicative_expression] = STATE(5873),
    [sym_additive_expression] = STATE(5873),
    [sym_comparison_expression] = STATE(5873),
    [sym_logical_expression] = STATE(5873),
    [sym_ternary_expression] = STATE(5873),
    [sym_unary_expression] = STATE(5873),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5873),
    [sym_list_literal] = STATE(5873),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5873),
    [sym__literal_value] = STATE(5873),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(8239),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(8241),
    [sym_date_literal] = ACTIONS(8239),
    [sym_time_literal] = ACTIONS(8239),
    [sym_biginteger_literal] = ACTIONS(8241),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8241),
    [sym_integer] = ACTIONS(8239),
    [sym_continue_as_identifier] = ACTIONS(8241),
  },
  [STATE(3156)] = {
    [sym_boolean] = STATE(6308),
    [sym_assignment_expression] = STATE(6308),
    [sym__expression] = STATE(6308),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6308),
    [sym_multiplicative_expression] = STATE(6308),
    [sym_additive_expression] = STATE(6308),
    [sym_comparison_expression] = STATE(6308),
    [sym_logical_expression] = STATE(6308),
    [sym_ternary_expression] = STATE(6308),
    [sym_unary_expression] = STATE(6308),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6308),
    [sym_list_literal] = STATE(6308),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6308),
    [sym__literal_value] = STATE(6308),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8243),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(8245),
    [sym_date_literal] = ACTIONS(8243),
    [sym_time_literal] = ACTIONS(8243),
    [sym_biginteger_literal] = ACTIONS(8245),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8245),
    [sym_integer] = ACTIONS(8243),
    [sym_continue_as_identifier] = ACTIONS(8245),
  },
  [STATE(3157)] = {
    [sym_boolean] = STATE(6196),
    [sym_assignment_expression] = STATE(6196),
    [sym__expression] = STATE(6196),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6196),
    [sym_multiplicative_expression] = STATE(6196),
    [sym_additive_expression] = STATE(6196),
    [sym_comparison_expression] = STATE(6196),
    [sym_logical_expression] = STATE(6196),
    [sym_ternary_expression] = STATE(6196),
    [sym_unary_expression] = STATE(6196),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6196),
    [sym_list_literal] = STATE(6196),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6196),
    [sym__literal_value] = STATE(6196),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8247),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8249),
    [sym_date_literal] = ACTIONS(8247),
    [sym_time_literal] = ACTIONS(8247),
    [sym_biginteger_literal] = ACTIONS(8249),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8249),
    [sym_integer] = ACTIONS(8247),
    [sym_continue_as_identifier] = ACTIONS(8249),
  },
  [STATE(3158)] = {
    [sym_boolean] = STATE(6089),
    [sym_assignment_expression] = STATE(6089),
    [sym__expression] = STATE(6089),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6089),
    [sym_multiplicative_expression] = STATE(6089),
    [sym_additive_expression] = STATE(6089),
    [sym_comparison_expression] = STATE(6089),
    [sym_logical_expression] = STATE(6089),
    [sym_ternary_expression] = STATE(6089),
    [sym_unary_expression] = STATE(6089),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6089),
    [sym_list_literal] = STATE(6089),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6089),
    [sym__literal_value] = STATE(6089),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8251),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8253),
    [sym_date_literal] = ACTIONS(8251),
    [sym_time_literal] = ACTIONS(8251),
    [sym_biginteger_literal] = ACTIONS(8253),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8253),
    [sym_integer] = ACTIONS(8251),
    [sym_continue_as_identifier] = ACTIONS(8253),
  },
  [STATE(3159)] = {
    [sym_boolean] = STATE(6235),
    [sym_assignment_expression] = STATE(6235),
    [sym__expression] = STATE(6235),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6235),
    [sym_multiplicative_expression] = STATE(6235),
    [sym_additive_expression] = STATE(6235),
    [sym_comparison_expression] = STATE(6235),
    [sym_logical_expression] = STATE(6235),
    [sym_ternary_expression] = STATE(6235),
    [sym_unary_expression] = STATE(6235),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6235),
    [sym_list_literal] = STATE(6235),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6235),
    [sym__literal_value] = STATE(6235),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8255),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8257),
    [sym_date_literal] = ACTIONS(8255),
    [sym_time_literal] = ACTIONS(8255),
    [sym_biginteger_literal] = ACTIONS(8257),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8257),
    [sym_integer] = ACTIONS(8255),
    [sym_continue_as_identifier] = ACTIONS(8257),
  },
  [STATE(3160)] = {
    [sym_boolean] = STATE(4933),
    [sym_assignment_expression] = STATE(4933),
    [sym__expression] = STATE(4933),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(4933),
    [sym_multiplicative_expression] = STATE(4933),
    [sym_additive_expression] = STATE(4933),
    [sym_comparison_expression] = STATE(4933),
    [sym_logical_expression] = STATE(4933),
    [sym_ternary_expression] = STATE(4933),
    [sym_unary_expression] = STATE(4933),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(4933),
    [sym_list_literal] = STATE(4933),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(4933),
    [sym__literal_value] = STATE(4933),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8259),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8261),
    [sym_date_literal] = ACTIONS(8259),
    [sym_time_literal] = ACTIONS(8259),
    [sym_biginteger_literal] = ACTIONS(8261),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8261),
    [sym_integer] = ACTIONS(8259),
    [sym_continue_as_identifier] = ACTIONS(8261),
  },
  [STATE(3161)] = {
    [sym_identifier] = ACTIONS(8263),
    [anon_sym_SEMI] = ACTIONS(8265),
    [aux_sym_where_condition_token1] = ACTIONS(8263),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8263),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8263),
    [anon_sym_LBRACK] = ACTIONS(8265),
    [aux_sym_basic_type_token6] = ACTIONS(8263),
    [aux_sym_basic_type_token22] = ACTIONS(8263),
    [aux_sym_basic_type_token53] = ACTIONS(8263),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8263),
    [aux_sym_addafter_modification_token1] = ACTIONS(8263),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8263),
    [aux_sym_modify_modification_token1] = ACTIONS(8263),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8263),
    [aux_sym_movelast_modification_token1] = ACTIONS(8263),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8263),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8263),
    [aux_sym_separator_action_token1] = ACTIONS(8263),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8263),
    [aux_sym_type_declaration_token1] = ACTIONS(8263),
    [anon_sym_POUNDif] = ACTIONS(8265),
    [anon_sym_POUNDIF] = ACTIONS(8265),
    [anon_sym_POUNDIf] = ACTIONS(8265),
    [anon_sym_POUNDelif] = ACTIONS(8265),
    [anon_sym_POUNDELIF] = ACTIONS(8265),
    [anon_sym_POUNDElif] = ACTIONS(8265),
    [anon_sym_POUNDelse] = ACTIONS(8265),
    [anon_sym_POUNDELSE] = ACTIONS(8265),
    [anon_sym_POUNDElse] = ACTIONS(8265),
    [anon_sym_POUNDendif] = ACTIONS(8265),
    [anon_sym_POUNDENDIF] = ACTIONS(8265),
    [anon_sym_POUNDEndif] = ACTIONS(8265),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8263),
    [sym_trigger_keyword] = ACTIONS(8263),
    [sym_var_keyword] = ACTIONS(8263),
    [sym_local_keyword] = ACTIONS(8263),
    [sym_internal_keyword] = ACTIONS(8263),
    [sym_protected_keyword] = ACTIONS(8263),
    [sym_event_keyword] = ACTIONS(8263),
    [sym_fields_keyword] = ACTIONS(8263),
    [sym_keys_keyword] = ACTIONS(8263),
    [sym_key_keyword] = ACTIONS(8263),
    [sym_fieldgroups_keyword] = ACTIONS(8263),
    [sym_actions_keyword] = ACTIONS(8263),
    [sym_layout_keyword] = ACTIONS(8263),
    [sym_area_keyword] = ACTIONS(8263),
    [sym_group_keyword] = ACTIONS(8263),
    [sym_repeater_keyword] = ACTIONS(8263),
    [sym_cuegroup_keyword] = ACTIONS(8263),
    [sym_fixed_keyword] = ACTIONS(8263),
    [sym_grid_keyword] = ACTIONS(8263),
    [sym_part_keyword] = ACTIONS(8263),
    [sym_systempart_keyword] = ACTIONS(8263),
    [sym_usercontrol_keyword] = ACTIONS(8263),
    [sym_dataset_keyword] = ACTIONS(8263),
    [sym_elements_keyword] = ACTIONS(8263),
    [sym_dataitem_keyword] = ACTIONS(8263),
    [sym_column_keyword] = ACTIONS(8263),
    [sym_filter_keyword] = ACTIONS(8263),
    [sym_labels_keyword] = ACTIONS(8263),
    [sym_rendering_keyword] = ACTIONS(8263),
    [sym_requestpage_keyword] = ACTIONS(8263),
    [sym_schema_keyword] = ACTIONS(8263),
    [sym_views_keyword] = ACTIONS(8263),
    [sym_quoted_identifier] = ACTIONS(8265),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8265),
    [sym_preproc_open] = ACTIONS(8265),
    [sym_preproc_close] = ACTIONS(8265),
    [sym_var_attribute_open] = ACTIONS(8265),
  },
  [STATE(3162)] = {
    [sym_boolean] = STATE(6324),
    [sym_assignment_expression] = STATE(6324),
    [sym__expression] = STATE(6324),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6324),
    [sym_multiplicative_expression] = STATE(6324),
    [sym_additive_expression] = STATE(6324),
    [sym_comparison_expression] = STATE(6324),
    [sym_logical_expression] = STATE(6324),
    [sym_ternary_expression] = STATE(6324),
    [sym_unary_expression] = STATE(6324),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6324),
    [sym_list_literal] = STATE(6324),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6324),
    [sym__literal_value] = STATE(6324),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8267),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8269),
    [sym_date_literal] = ACTIONS(8267),
    [sym_time_literal] = ACTIONS(8267),
    [sym_biginteger_literal] = ACTIONS(8269),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8269),
    [sym_integer] = ACTIONS(8267),
    [sym_continue_as_identifier] = ACTIONS(8269),
  },
  [STATE(3163)] = {
    [sym_boolean] = STATE(6282),
    [sym_assignment_expression] = STATE(6282),
    [sym__expression] = STATE(6282),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6282),
    [sym_multiplicative_expression] = STATE(6282),
    [sym_additive_expression] = STATE(6282),
    [sym_comparison_expression] = STATE(6282),
    [sym_logical_expression] = STATE(6282),
    [sym_ternary_expression] = STATE(6282),
    [sym_unary_expression] = STATE(6282),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6282),
    [sym_list_literal] = STATE(6282),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6282),
    [sym__literal_value] = STATE(6282),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8271),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(8273),
    [sym_date_literal] = ACTIONS(8271),
    [sym_time_literal] = ACTIONS(8271),
    [sym_biginteger_literal] = ACTIONS(8273),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8273),
    [sym_integer] = ACTIONS(8271),
    [sym_continue_as_identifier] = ACTIONS(8273),
  },
  [STATE(3164)] = {
    [sym_boolean] = STATE(6313),
    [sym_assignment_expression] = STATE(6313),
    [sym__expression] = STATE(6313),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6313),
    [sym_multiplicative_expression] = STATE(6313),
    [sym_additive_expression] = STATE(6313),
    [sym_comparison_expression] = STATE(6313),
    [sym_logical_expression] = STATE(6313),
    [sym_ternary_expression] = STATE(6313),
    [sym_unary_expression] = STATE(6313),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6313),
    [sym_list_literal] = STATE(6313),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6313),
    [sym__literal_value] = STATE(6313),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8275),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(8277),
    [sym_date_literal] = ACTIONS(8275),
    [sym_time_literal] = ACTIONS(8275),
    [sym_biginteger_literal] = ACTIONS(8277),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8277),
    [sym_integer] = ACTIONS(8275),
    [sym_continue_as_identifier] = ACTIONS(8277),
  },
  [STATE(3165)] = {
    [sym_boolean] = STATE(1404),
    [sym_assignment_expression] = STATE(1404),
    [sym__expression] = STATE(1404),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1404),
    [sym_multiplicative_expression] = STATE(1404),
    [sym_additive_expression] = STATE(1404),
    [sym_comparison_expression] = STATE(1404),
    [sym_logical_expression] = STATE(1404),
    [sym_ternary_expression] = STATE(1404),
    [sym_unary_expression] = STATE(1404),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1404),
    [sym_list_literal] = STATE(1404),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1404),
    [sym__literal_value] = STATE(1404),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(8279),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(8281),
    [sym_date_literal] = ACTIONS(8279),
    [sym_time_literal] = ACTIONS(8279),
    [sym_biginteger_literal] = ACTIONS(8281),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8281),
    [sym_integer] = ACTIONS(8279),
    [sym_continue_as_identifier] = ACTIONS(8281),
  },
  [STATE(3166)] = {
    [sym_boolean] = STATE(1422),
    [sym_assignment_expression] = STATE(1422),
    [sym__expression] = STATE(1422),
    [sym_keyword_identifier] = STATE(1400),
    [sym_range_expression] = STATE(1422),
    [sym_multiplicative_expression] = STATE(1422),
    [sym_additive_expression] = STATE(1422),
    [sym_comparison_expression] = STATE(1422),
    [sym_logical_expression] = STATE(1422),
    [sym_ternary_expression] = STATE(1422),
    [sym_unary_expression] = STATE(1422),
    [sym_call_expression] = STATE(1484),
    [sym_member_expression] = STATE(1400),
    [sym_subscript_expression] = STATE(1400),
    [sym_parenthesized_expression] = STATE(1422),
    [sym_list_literal] = STATE(1422),
    [sym_qualified_enum_value] = STATE(1400),
    [sym_database_reference] = STATE(1422),
    [sym__literal_value] = STATE(1422),
    [sym_codeunit_keyword] = STATE(1446),
    [sym_xmlport_keyword] = STATE(1446),
    [sym_enum_keyword] = STATE(1440),
    [sym_identifier] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(574),
    [aux_sym_boolean_token1] = ACTIONS(576),
    [aux_sym_boolean_token2] = ACTIONS(576),
    [sym_decimal] = ACTIONS(8283),
    [anon_sym_LPAREN] = ACTIONS(580),
    [aux_sym_tabledata_permission_token2] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(584),
    [aux_sym_record_type_token1] = ACTIONS(582),
    [aux_sym_basic_type_token21] = ACTIONS(582),
    [aux_sym_basic_type_token22] = ACTIONS(582),
    [aux_sym_basic_type_token48] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(586),
    [anon_sym_NOT] = ACTIONS(586),
    [anon_sym_Not] = ACTIONS(586),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(582),
    [aux_sym_keyword_identifier_token2] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(574),
    [sym_datetime_literal] = ACTIONS(8285),
    [sym_date_literal] = ACTIONS(8283),
    [sym_time_literal] = ACTIONS(8283),
    [sym_biginteger_literal] = ACTIONS(8285),
    [sym_page_keyword] = ACTIONS(588),
    [anon_sym_codeunit] = ACTIONS(594),
    [anon_sym_CODEUNIT] = ACTIONS(594),
    [anon_sym_Codeunit] = ACTIONS(594),
    [anon_sym_CodeUnit] = ACTIONS(594),
    [anon_sym_COdeunit] = ACTIONS(594),
    [anon_sym_codeUnit] = ACTIONS(594),
    [sym_report_keyword] = ACTIONS(588),
    [sym_query_keyword] = ACTIONS(588),
    [anon_sym_xmlport] = ACTIONS(596),
    [anon_sym_XMLPORT] = ACTIONS(596),
    [anon_sym_Xmlport] = ACTIONS(596),
    [anon_sym_XMLport] = ACTIONS(596),
    [anon_sym_XMLPort] = ACTIONS(596),
    [anon_sym_XmlPort] = ACTIONS(596),
    [anon_sym_enum] = ACTIONS(598),
    [anon_sym_ENUM] = ACTIONS(598),
    [anon_sym_Enum] = ACTIONS(598),
    [anon_sym_eNUM] = ACTIONS(598),
    [anon_sym_eNum] = ACTIONS(598),
    [anon_sym_ENum] = ACTIONS(598),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8285),
    [sym_integer] = ACTIONS(8283),
    [sym_continue_as_identifier] = ACTIONS(8285),
  },
  [STATE(3167)] = {
    [sym_boolean] = STATE(2018),
    [sym_assignment_expression] = STATE(2018),
    [sym__expression] = STATE(2018),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2018),
    [sym_multiplicative_expression] = STATE(2018),
    [sym_additive_expression] = STATE(2018),
    [sym_comparison_expression] = STATE(2018),
    [sym_logical_expression] = STATE(2018),
    [sym_ternary_expression] = STATE(2018),
    [sym_unary_expression] = STATE(2018),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2018),
    [sym_list_literal] = STATE(2018),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2018),
    [sym__literal_value] = STATE(2018),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8287),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8289),
    [sym_date_literal] = ACTIONS(8287),
    [sym_time_literal] = ACTIONS(8287),
    [sym_biginteger_literal] = ACTIONS(8289),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8289),
    [sym_integer] = ACTIONS(8287),
    [sym_continue_as_identifier] = ACTIONS(8289),
  },
  [STATE(3168)] = {
    [sym_boolean] = STATE(2030),
    [sym_assignment_expression] = STATE(2030),
    [sym__expression] = STATE(2030),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2030),
    [sym_multiplicative_expression] = STATE(2030),
    [sym_additive_expression] = STATE(2030),
    [sym_comparison_expression] = STATE(2030),
    [sym_logical_expression] = STATE(2030),
    [sym_ternary_expression] = STATE(2030),
    [sym_unary_expression] = STATE(2030),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2030),
    [sym_list_literal] = STATE(2030),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2030),
    [sym__literal_value] = STATE(2030),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8291),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8293),
    [sym_date_literal] = ACTIONS(8291),
    [sym_time_literal] = ACTIONS(8291),
    [sym_biginteger_literal] = ACTIONS(8293),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8293),
    [sym_integer] = ACTIONS(8291),
    [sym_continue_as_identifier] = ACTIONS(8293),
  },
  [STATE(3169)] = {
    [sym_boolean] = STATE(6298),
    [sym_assignment_expression] = STATE(6298),
    [sym__expression] = STATE(6298),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6298),
    [sym_multiplicative_expression] = STATE(6298),
    [sym_additive_expression] = STATE(6298),
    [sym_comparison_expression] = STATE(6298),
    [sym_logical_expression] = STATE(6298),
    [sym_ternary_expression] = STATE(6298),
    [sym_unary_expression] = STATE(6298),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6298),
    [sym_list_literal] = STATE(6298),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6298),
    [sym__literal_value] = STATE(6298),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8295),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8297),
    [sym_date_literal] = ACTIONS(8295),
    [sym_time_literal] = ACTIONS(8295),
    [sym_biginteger_literal] = ACTIONS(8297),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8297),
    [sym_integer] = ACTIONS(8295),
    [sym_continue_as_identifier] = ACTIONS(8297),
  },
  [STATE(3170)] = {
    [sym_boolean] = STATE(6146),
    [sym_assignment_expression] = STATE(6146),
    [sym__expression] = STATE(6146),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6146),
    [sym_multiplicative_expression] = STATE(6146),
    [sym_additive_expression] = STATE(6146),
    [sym_comparison_expression] = STATE(6146),
    [sym_logical_expression] = STATE(6146),
    [sym_ternary_expression] = STATE(6146),
    [sym_unary_expression] = STATE(6146),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6146),
    [sym_list_literal] = STATE(6146),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6146),
    [sym__literal_value] = STATE(6146),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8299),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8301),
    [sym_date_literal] = ACTIONS(8299),
    [sym_time_literal] = ACTIONS(8299),
    [sym_biginteger_literal] = ACTIONS(8301),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8301),
    [sym_integer] = ACTIONS(8299),
    [sym_continue_as_identifier] = ACTIONS(8301),
  },
  [STATE(3171)] = {
    [sym_boolean] = STATE(2031),
    [sym_assignment_expression] = STATE(2031),
    [sym__expression] = STATE(2031),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2031),
    [sym_multiplicative_expression] = STATE(2031),
    [sym_additive_expression] = STATE(2031),
    [sym_comparison_expression] = STATE(2031),
    [sym_logical_expression] = STATE(2031),
    [sym_ternary_expression] = STATE(2031),
    [sym_unary_expression] = STATE(2031),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2031),
    [sym_list_literal] = STATE(2031),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2031),
    [sym__literal_value] = STATE(2031),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8303),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8305),
    [sym_date_literal] = ACTIONS(8303),
    [sym_time_literal] = ACTIONS(8303),
    [sym_biginteger_literal] = ACTIONS(8305),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8305),
    [sym_integer] = ACTIONS(8303),
    [sym_continue_as_identifier] = ACTIONS(8305),
  },
  [STATE(3172)] = {
    [sym_boolean] = STATE(2037),
    [sym_assignment_expression] = STATE(2037),
    [sym__expression] = STATE(2037),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2037),
    [sym_multiplicative_expression] = STATE(2037),
    [sym_additive_expression] = STATE(2037),
    [sym_comparison_expression] = STATE(2037),
    [sym_logical_expression] = STATE(2037),
    [sym_ternary_expression] = STATE(2037),
    [sym_unary_expression] = STATE(2037),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2037),
    [sym_list_literal] = STATE(2037),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2037),
    [sym__literal_value] = STATE(2037),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8307),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8309),
    [sym_date_literal] = ACTIONS(8307),
    [sym_time_literal] = ACTIONS(8307),
    [sym_biginteger_literal] = ACTIONS(8309),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8309),
    [sym_integer] = ACTIONS(8307),
    [sym_continue_as_identifier] = ACTIONS(8309),
  },
  [STATE(3173)] = {
    [sym_boolean] = STATE(6005),
    [sym_assignment_expression] = STATE(6005),
    [sym__expression] = STATE(6005),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6005),
    [sym_multiplicative_expression] = STATE(6005),
    [sym_additive_expression] = STATE(6005),
    [sym_comparison_expression] = STATE(6005),
    [sym_logical_expression] = STATE(6005),
    [sym_ternary_expression] = STATE(6005),
    [sym_unary_expression] = STATE(6005),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6005),
    [sym_list_literal] = STATE(6005),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6005),
    [sym__literal_value] = STATE(6005),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8311),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8313),
    [sym_date_literal] = ACTIONS(8311),
    [sym_time_literal] = ACTIONS(8311),
    [sym_biginteger_literal] = ACTIONS(8313),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8313),
    [sym_integer] = ACTIONS(8311),
    [sym_continue_as_identifier] = ACTIONS(8313),
  },
  [STATE(3174)] = {
    [sym_boolean] = STATE(2043),
    [sym_assignment_expression] = STATE(2043),
    [sym__expression] = STATE(2043),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2043),
    [sym_multiplicative_expression] = STATE(2043),
    [sym_additive_expression] = STATE(2043),
    [sym_comparison_expression] = STATE(2043),
    [sym_logical_expression] = STATE(2043),
    [sym_ternary_expression] = STATE(2043),
    [sym_unary_expression] = STATE(2043),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2043),
    [sym_list_literal] = STATE(2043),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2043),
    [sym__literal_value] = STATE(2043),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8315),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8317),
    [sym_date_literal] = ACTIONS(8315),
    [sym_time_literal] = ACTIONS(8315),
    [sym_biginteger_literal] = ACTIONS(8317),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8317),
    [sym_integer] = ACTIONS(8315),
    [sym_continue_as_identifier] = ACTIONS(8317),
  },
  [STATE(3175)] = {
    [sym_boolean] = STATE(2044),
    [sym_assignment_expression] = STATE(2044),
    [sym__expression] = STATE(2044),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2044),
    [sym_multiplicative_expression] = STATE(2044),
    [sym_additive_expression] = STATE(2044),
    [sym_comparison_expression] = STATE(2044),
    [sym_logical_expression] = STATE(2044),
    [sym_ternary_expression] = STATE(2044),
    [sym_unary_expression] = STATE(2044),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2044),
    [sym_list_literal] = STATE(2044),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2044),
    [sym__literal_value] = STATE(2044),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8319),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8321),
    [sym_date_literal] = ACTIONS(8319),
    [sym_time_literal] = ACTIONS(8319),
    [sym_biginteger_literal] = ACTIONS(8321),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8321),
    [sym_integer] = ACTIONS(8319),
    [sym_continue_as_identifier] = ACTIONS(8321),
  },
  [STATE(3176)] = {
    [sym_boolean] = STATE(2045),
    [sym_assignment_expression] = STATE(2045),
    [sym__expression] = STATE(2045),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2045),
    [sym_multiplicative_expression] = STATE(2045),
    [sym_additive_expression] = STATE(2045),
    [sym_comparison_expression] = STATE(2045),
    [sym_logical_expression] = STATE(2045),
    [sym_ternary_expression] = STATE(2045),
    [sym_unary_expression] = STATE(2045),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2045),
    [sym_list_literal] = STATE(2045),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2045),
    [sym__literal_value] = STATE(2045),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8323),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8325),
    [sym_date_literal] = ACTIONS(8323),
    [sym_time_literal] = ACTIONS(8323),
    [sym_biginteger_literal] = ACTIONS(8325),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8325),
    [sym_integer] = ACTIONS(8323),
    [sym_continue_as_identifier] = ACTIONS(8325),
  },
  [STATE(3177)] = {
    [sym_boolean] = STATE(6307),
    [sym_assignment_expression] = STATE(6307),
    [sym__expression] = STATE(6307),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6307),
    [sym_multiplicative_expression] = STATE(6307),
    [sym_additive_expression] = STATE(6307),
    [sym_comparison_expression] = STATE(6307),
    [sym_logical_expression] = STATE(6307),
    [sym_ternary_expression] = STATE(6307),
    [sym_unary_expression] = STATE(6307),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6307),
    [sym_list_literal] = STATE(6307),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6307),
    [sym__literal_value] = STATE(6307),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8327),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(8329),
    [sym_date_literal] = ACTIONS(8327),
    [sym_time_literal] = ACTIONS(8327),
    [sym_biginteger_literal] = ACTIONS(8329),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8329),
    [sym_integer] = ACTIONS(8327),
    [sym_continue_as_identifier] = ACTIONS(8329),
  },
  [STATE(3178)] = {
    [sym_boolean] = STATE(6274),
    [sym_assignment_expression] = STATE(6274),
    [sym__expression] = STATE(6274),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6274),
    [sym_multiplicative_expression] = STATE(6274),
    [sym_additive_expression] = STATE(6274),
    [sym_comparison_expression] = STATE(6274),
    [sym_logical_expression] = STATE(6274),
    [sym_ternary_expression] = STATE(6274),
    [sym_unary_expression] = STATE(6274),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6274),
    [sym_list_literal] = STATE(6274),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6274),
    [sym__literal_value] = STATE(6274),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8331),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(8333),
    [sym_date_literal] = ACTIONS(8331),
    [sym_time_literal] = ACTIONS(8331),
    [sym_biginteger_literal] = ACTIONS(8333),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8333),
    [sym_integer] = ACTIONS(8331),
    [sym_continue_as_identifier] = ACTIONS(8333),
  },
  [STATE(3179)] = {
    [sym_boolean] = STATE(2052),
    [sym_assignment_expression] = STATE(2052),
    [sym__expression] = STATE(2052),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2052),
    [sym_multiplicative_expression] = STATE(2052),
    [sym_additive_expression] = STATE(2052),
    [sym_comparison_expression] = STATE(2052),
    [sym_logical_expression] = STATE(2052),
    [sym_ternary_expression] = STATE(2052),
    [sym_unary_expression] = STATE(2052),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2052),
    [sym_list_literal] = STATE(2052),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2052),
    [sym__literal_value] = STATE(2052),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8335),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8337),
    [sym_date_literal] = ACTIONS(8335),
    [sym_time_literal] = ACTIONS(8335),
    [sym_biginteger_literal] = ACTIONS(8337),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8337),
    [sym_integer] = ACTIONS(8335),
    [sym_continue_as_identifier] = ACTIONS(8337),
  },
  [STATE(3180)] = {
    [sym_boolean] = STATE(2053),
    [sym_assignment_expression] = STATE(2053),
    [sym__expression] = STATE(2053),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2053),
    [sym_multiplicative_expression] = STATE(2053),
    [sym_additive_expression] = STATE(2053),
    [sym_comparison_expression] = STATE(2053),
    [sym_logical_expression] = STATE(2053),
    [sym_ternary_expression] = STATE(2053),
    [sym_unary_expression] = STATE(2053),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2053),
    [sym_list_literal] = STATE(2053),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2053),
    [sym__literal_value] = STATE(2053),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8339),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8341),
    [sym_date_literal] = ACTIONS(8339),
    [sym_time_literal] = ACTIONS(8339),
    [sym_biginteger_literal] = ACTIONS(8341),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8341),
    [sym_integer] = ACTIONS(8339),
    [sym_continue_as_identifier] = ACTIONS(8341),
  },
  [STATE(3181)] = {
    [sym_boolean] = STATE(5443),
    [sym_assignment_expression] = STATE(5443),
    [sym__expression] = STATE(5443),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5443),
    [sym_multiplicative_expression] = STATE(5443),
    [sym_additive_expression] = STATE(5443),
    [sym_comparison_expression] = STATE(5443),
    [sym_logical_expression] = STATE(5443),
    [sym_ternary_expression] = STATE(5443),
    [sym_unary_expression] = STATE(5443),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5443),
    [sym_list_literal] = STATE(5443),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5443),
    [sym__literal_value] = STATE(5443),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(8343),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(8345),
    [sym_date_literal] = ACTIONS(8343),
    [sym_time_literal] = ACTIONS(8343),
    [sym_biginteger_literal] = ACTIONS(8345),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8345),
    [sym_integer] = ACTIONS(8343),
    [sym_continue_as_identifier] = ACTIONS(8345),
  },
  [STATE(3182)] = {
    [sym_boolean] = STATE(2058),
    [sym_assignment_expression] = STATE(2058),
    [sym__expression] = STATE(2058),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2058),
    [sym_multiplicative_expression] = STATE(2058),
    [sym_additive_expression] = STATE(2058),
    [sym_comparison_expression] = STATE(2058),
    [sym_logical_expression] = STATE(2058),
    [sym_ternary_expression] = STATE(2058),
    [sym_unary_expression] = STATE(2058),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2058),
    [sym_list_literal] = STATE(2058),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2058),
    [sym__literal_value] = STATE(2058),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8347),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8349),
    [sym_date_literal] = ACTIONS(8347),
    [sym_time_literal] = ACTIONS(8347),
    [sym_biginteger_literal] = ACTIONS(8349),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8349),
    [sym_integer] = ACTIONS(8347),
    [sym_continue_as_identifier] = ACTIONS(8349),
  },
  [STATE(3183)] = {
    [sym_boolean] = STATE(6314),
    [sym_assignment_expression] = STATE(6314),
    [sym__expression] = STATE(6314),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6314),
    [sym_multiplicative_expression] = STATE(6314),
    [sym_additive_expression] = STATE(6314),
    [sym_comparison_expression] = STATE(6314),
    [sym_logical_expression] = STATE(6314),
    [sym_ternary_expression] = STATE(6314),
    [sym_unary_expression] = STATE(6314),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6314),
    [sym_list_literal] = STATE(6314),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6314),
    [sym__literal_value] = STATE(6314),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8351),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(8353),
    [sym_date_literal] = ACTIONS(8351),
    [sym_time_literal] = ACTIONS(8351),
    [sym_biginteger_literal] = ACTIONS(8353),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8353),
    [sym_integer] = ACTIONS(8351),
    [sym_continue_as_identifier] = ACTIONS(8353),
  },
  [STATE(3184)] = {
    [sym_boolean] = STATE(2059),
    [sym_assignment_expression] = STATE(2059),
    [sym__expression] = STATE(2059),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2059),
    [sym_multiplicative_expression] = STATE(2059),
    [sym_additive_expression] = STATE(2059),
    [sym_comparison_expression] = STATE(2059),
    [sym_logical_expression] = STATE(2059),
    [sym_ternary_expression] = STATE(2059),
    [sym_unary_expression] = STATE(2059),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2059),
    [sym_list_literal] = STATE(2059),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2059),
    [sym__literal_value] = STATE(2059),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8355),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8357),
    [sym_date_literal] = ACTIONS(8355),
    [sym_time_literal] = ACTIONS(8355),
    [sym_biginteger_literal] = ACTIONS(8357),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8357),
    [sym_integer] = ACTIONS(8355),
    [sym_continue_as_identifier] = ACTIONS(8357),
  },
  [STATE(3185)] = {
    [sym_boolean] = STATE(2085),
    [sym_assignment_expression] = STATE(2085),
    [sym__expression] = STATE(2085),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2085),
    [sym_multiplicative_expression] = STATE(2085),
    [sym_additive_expression] = STATE(2085),
    [sym_comparison_expression] = STATE(2085),
    [sym_logical_expression] = STATE(2085),
    [sym_ternary_expression] = STATE(2085),
    [sym_unary_expression] = STATE(2085),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2085),
    [sym_list_literal] = STATE(2085),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2085),
    [sym__literal_value] = STATE(2085),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8359),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8361),
    [sym_date_literal] = ACTIONS(8359),
    [sym_time_literal] = ACTIONS(8359),
    [sym_biginteger_literal] = ACTIONS(8361),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8361),
    [sym_integer] = ACTIONS(8359),
    [sym_continue_as_identifier] = ACTIONS(8361),
  },
  [STATE(3186)] = {
    [sym_boolean] = STATE(2086),
    [sym_assignment_expression] = STATE(2086),
    [sym__expression] = STATE(2086),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2086),
    [sym_multiplicative_expression] = STATE(2086),
    [sym_additive_expression] = STATE(2086),
    [sym_comparison_expression] = STATE(2086),
    [sym_logical_expression] = STATE(2086),
    [sym_ternary_expression] = STATE(2086),
    [sym_unary_expression] = STATE(2086),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2086),
    [sym_list_literal] = STATE(2086),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2086),
    [sym__literal_value] = STATE(2086),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8363),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8365),
    [sym_date_literal] = ACTIONS(8363),
    [sym_time_literal] = ACTIONS(8363),
    [sym_biginteger_literal] = ACTIONS(8365),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8365),
    [sym_integer] = ACTIONS(8363),
    [sym_continue_as_identifier] = ACTIONS(8365),
  },
  [STATE(3187)] = {
    [sym_boolean] = STATE(2087),
    [sym_assignment_expression] = STATE(2087),
    [sym__expression] = STATE(2087),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2087),
    [sym_multiplicative_expression] = STATE(2087),
    [sym_additive_expression] = STATE(2087),
    [sym_comparison_expression] = STATE(2087),
    [sym_logical_expression] = STATE(2087),
    [sym_ternary_expression] = STATE(2087),
    [sym_unary_expression] = STATE(2087),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2087),
    [sym_list_literal] = STATE(2087),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2087),
    [sym__literal_value] = STATE(2087),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8367),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8369),
    [sym_date_literal] = ACTIONS(8367),
    [sym_time_literal] = ACTIONS(8367),
    [sym_biginteger_literal] = ACTIONS(8369),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8369),
    [sym_integer] = ACTIONS(8367),
    [sym_continue_as_identifier] = ACTIONS(8369),
  },
  [STATE(3188)] = {
    [sym_boolean] = STATE(2023),
    [sym_assignment_expression] = STATE(2023),
    [sym__expression] = STATE(2023),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2023),
    [sym_multiplicative_expression] = STATE(2023),
    [sym_additive_expression] = STATE(2023),
    [sym_comparison_expression] = STATE(2023),
    [sym_logical_expression] = STATE(2023),
    [sym_ternary_expression] = STATE(2023),
    [sym_unary_expression] = STATE(2023),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2023),
    [sym_list_literal] = STATE(2023),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2023),
    [sym__literal_value] = STATE(2023),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8371),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8373),
    [sym_date_literal] = ACTIONS(8371),
    [sym_time_literal] = ACTIONS(8371),
    [sym_biginteger_literal] = ACTIONS(8373),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8373),
    [sym_integer] = ACTIONS(8371),
    [sym_continue_as_identifier] = ACTIONS(8373),
  },
  [STATE(3189)] = {
    [sym_boolean] = STATE(2024),
    [sym_assignment_expression] = STATE(2024),
    [sym__expression] = STATE(2024),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(2024),
    [sym_multiplicative_expression] = STATE(2024),
    [sym_additive_expression] = STATE(2024),
    [sym_comparison_expression] = STATE(2024),
    [sym_logical_expression] = STATE(2024),
    [sym_ternary_expression] = STATE(2024),
    [sym_unary_expression] = STATE(2024),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(2024),
    [sym_list_literal] = STATE(2024),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(2024),
    [sym__literal_value] = STATE(2024),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8375),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8377),
    [sym_date_literal] = ACTIONS(8375),
    [sym_time_literal] = ACTIONS(8375),
    [sym_biginteger_literal] = ACTIONS(8377),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8377),
    [sym_integer] = ACTIONS(8375),
    [sym_continue_as_identifier] = ACTIONS(8377),
  },
  [STATE(3190)] = {
    [sym_boolean] = STATE(1949),
    [sym_assignment_expression] = STATE(1949),
    [sym__expression] = STATE(1949),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(1949),
    [sym_multiplicative_expression] = STATE(1949),
    [sym_additive_expression] = STATE(1949),
    [sym_comparison_expression] = STATE(1949),
    [sym_logical_expression] = STATE(1949),
    [sym_ternary_expression] = STATE(1949),
    [sym_unary_expression] = STATE(1949),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(1949),
    [sym_list_literal] = STATE(1949),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(1949),
    [sym__literal_value] = STATE(1949),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8379),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8381),
    [sym_date_literal] = ACTIONS(8379),
    [sym_time_literal] = ACTIONS(8379),
    [sym_biginteger_literal] = ACTIONS(8381),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8381),
    [sym_integer] = ACTIONS(8379),
    [sym_continue_as_identifier] = ACTIONS(8381),
  },
  [STATE(3191)] = {
    [sym_boolean] = STATE(1954),
    [sym_assignment_expression] = STATE(1954),
    [sym__expression] = STATE(1954),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(1954),
    [sym_multiplicative_expression] = STATE(1954),
    [sym_additive_expression] = STATE(1954),
    [sym_comparison_expression] = STATE(1954),
    [sym_logical_expression] = STATE(1954),
    [sym_ternary_expression] = STATE(1954),
    [sym_unary_expression] = STATE(1954),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(1954),
    [sym_list_literal] = STATE(1954),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(1954),
    [sym__literal_value] = STATE(1954),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8383),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8385),
    [sym_date_literal] = ACTIONS(8383),
    [sym_time_literal] = ACTIONS(8383),
    [sym_biginteger_literal] = ACTIONS(8385),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8385),
    [sym_integer] = ACTIONS(8383),
    [sym_continue_as_identifier] = ACTIONS(8385),
  },
  [STATE(3192)] = {
    [sym_boolean] = STATE(6284),
    [sym_assignment_expression] = STATE(6284),
    [sym__expression] = STATE(6284),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6284),
    [sym_multiplicative_expression] = STATE(6284),
    [sym_additive_expression] = STATE(6284),
    [sym_comparison_expression] = STATE(6284),
    [sym_logical_expression] = STATE(6284),
    [sym_ternary_expression] = STATE(6284),
    [sym_unary_expression] = STATE(6284),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6284),
    [sym_list_literal] = STATE(6284),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6284),
    [sym__literal_value] = STATE(6284),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8387),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(8389),
    [sym_date_literal] = ACTIONS(8387),
    [sym_time_literal] = ACTIONS(8387),
    [sym_biginteger_literal] = ACTIONS(8389),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8389),
    [sym_integer] = ACTIONS(8387),
    [sym_continue_as_identifier] = ACTIONS(8389),
  },
  [STATE(3193)] = {
    [sym_boolean] = STATE(6310),
    [sym_assignment_expression] = STATE(6310),
    [sym__expression] = STATE(6310),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6310),
    [sym_multiplicative_expression] = STATE(6310),
    [sym_additive_expression] = STATE(6310),
    [sym_comparison_expression] = STATE(6310),
    [sym_logical_expression] = STATE(6310),
    [sym_ternary_expression] = STATE(6310),
    [sym_unary_expression] = STATE(6310),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6310),
    [sym_list_literal] = STATE(6310),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6310),
    [sym__literal_value] = STATE(6310),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8391),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8393),
    [sym_date_literal] = ACTIONS(8391),
    [sym_time_literal] = ACTIONS(8391),
    [sym_biginteger_literal] = ACTIONS(8393),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8393),
    [sym_integer] = ACTIONS(8391),
    [sym_continue_as_identifier] = ACTIONS(8393),
  },
  [STATE(3194)] = {
    [sym_boolean] = STATE(1975),
    [sym_assignment_expression] = STATE(1975),
    [sym__expression] = STATE(1975),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(1975),
    [sym_multiplicative_expression] = STATE(1975),
    [sym_additive_expression] = STATE(1975),
    [sym_comparison_expression] = STATE(1975),
    [sym_logical_expression] = STATE(1975),
    [sym_ternary_expression] = STATE(1975),
    [sym_unary_expression] = STATE(1975),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(1975),
    [sym_list_literal] = STATE(1975),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(1975),
    [sym__literal_value] = STATE(1975),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8395),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8397),
    [sym_date_literal] = ACTIONS(8395),
    [sym_time_literal] = ACTIONS(8395),
    [sym_biginteger_literal] = ACTIONS(8397),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8397),
    [sym_integer] = ACTIONS(8395),
    [sym_continue_as_identifier] = ACTIONS(8397),
  },
  [STATE(3195)] = {
    [sym_boolean] = STATE(5444),
    [sym_assignment_expression] = STATE(5444),
    [sym__expression] = STATE(5444),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5444),
    [sym_multiplicative_expression] = STATE(5444),
    [sym_additive_expression] = STATE(5444),
    [sym_comparison_expression] = STATE(5444),
    [sym_logical_expression] = STATE(5444),
    [sym_ternary_expression] = STATE(5444),
    [sym_unary_expression] = STATE(5444),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5444),
    [sym_list_literal] = STATE(5444),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5444),
    [sym__literal_value] = STATE(5444),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(8399),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(8401),
    [sym_date_literal] = ACTIONS(8399),
    [sym_time_literal] = ACTIONS(8399),
    [sym_biginteger_literal] = ACTIONS(8401),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8401),
    [sym_integer] = ACTIONS(8399),
    [sym_continue_as_identifier] = ACTIONS(8401),
  },
  [STATE(3196)] = {
    [sym_boolean] = STATE(6323),
    [sym_assignment_expression] = STATE(6323),
    [sym__expression] = STATE(6323),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6323),
    [sym_multiplicative_expression] = STATE(6323),
    [sym_additive_expression] = STATE(6323),
    [sym_comparison_expression] = STATE(6323),
    [sym_logical_expression] = STATE(6323),
    [sym_ternary_expression] = STATE(6323),
    [sym_unary_expression] = STATE(6323),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6323),
    [sym_list_literal] = STATE(6323),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6323),
    [sym__literal_value] = STATE(6323),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8403),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(8405),
    [sym_date_literal] = ACTIONS(8403),
    [sym_time_literal] = ACTIONS(8403),
    [sym_biginteger_literal] = ACTIONS(8405),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8405),
    [sym_integer] = ACTIONS(8403),
    [sym_continue_as_identifier] = ACTIONS(8405),
  },
  [STATE(3197)] = {
    [sym_boolean] = STATE(1976),
    [sym_assignment_expression] = STATE(1976),
    [sym__expression] = STATE(1976),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(1976),
    [sym_multiplicative_expression] = STATE(1976),
    [sym_additive_expression] = STATE(1976),
    [sym_comparison_expression] = STATE(1976),
    [sym_logical_expression] = STATE(1976),
    [sym_ternary_expression] = STATE(1976),
    [sym_unary_expression] = STATE(1976),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(1976),
    [sym_list_literal] = STATE(1976),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(1976),
    [sym__literal_value] = STATE(1976),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8407),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8409),
    [sym_date_literal] = ACTIONS(8407),
    [sym_time_literal] = ACTIONS(8407),
    [sym_biginteger_literal] = ACTIONS(8409),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8409),
    [sym_integer] = ACTIONS(8407),
    [sym_continue_as_identifier] = ACTIONS(8409),
  },
  [STATE(3198)] = {
    [sym_boolean] = STATE(1977),
    [sym_assignment_expression] = STATE(1977),
    [sym__expression] = STATE(1977),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(1977),
    [sym_multiplicative_expression] = STATE(1977),
    [sym_additive_expression] = STATE(1977),
    [sym_comparison_expression] = STATE(1977),
    [sym_logical_expression] = STATE(1977),
    [sym_ternary_expression] = STATE(1977),
    [sym_unary_expression] = STATE(1977),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(1977),
    [sym_list_literal] = STATE(1977),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(1977),
    [sym__literal_value] = STATE(1977),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8411),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8413),
    [sym_date_literal] = ACTIONS(8411),
    [sym_time_literal] = ACTIONS(8411),
    [sym_biginteger_literal] = ACTIONS(8413),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8413),
    [sym_integer] = ACTIONS(8411),
    [sym_continue_as_identifier] = ACTIONS(8413),
  },
  [STATE(3199)] = {
    [sym_boolean] = STATE(5445),
    [sym_assignment_expression] = STATE(5445),
    [sym__expression] = STATE(5445),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5445),
    [sym_multiplicative_expression] = STATE(5445),
    [sym_additive_expression] = STATE(5445),
    [sym_comparison_expression] = STATE(5445),
    [sym_logical_expression] = STATE(5445),
    [sym_ternary_expression] = STATE(5445),
    [sym_unary_expression] = STATE(5445),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5445),
    [sym_list_literal] = STATE(5445),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5445),
    [sym__literal_value] = STATE(5445),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(8415),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(8417),
    [sym_date_literal] = ACTIONS(8415),
    [sym_time_literal] = ACTIONS(8415),
    [sym_biginteger_literal] = ACTIONS(8417),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8417),
    [sym_integer] = ACTIONS(8415),
    [sym_continue_as_identifier] = ACTIONS(8417),
  },
  [STATE(3200)] = {
    [sym_boolean] = STATE(1981),
    [sym_assignment_expression] = STATE(1981),
    [sym__expression] = STATE(1981),
    [sym_keyword_identifier] = STATE(2019),
    [sym_range_expression] = STATE(1981),
    [sym_multiplicative_expression] = STATE(1981),
    [sym_additive_expression] = STATE(1981),
    [sym_comparison_expression] = STATE(1981),
    [sym_logical_expression] = STATE(1981),
    [sym_ternary_expression] = STATE(1981),
    [sym_unary_expression] = STATE(1981),
    [sym_call_expression] = STATE(2090),
    [sym_member_expression] = STATE(2019),
    [sym_subscript_expression] = STATE(2019),
    [sym_parenthesized_expression] = STATE(1981),
    [sym_list_literal] = STATE(1981),
    [sym_qualified_enum_value] = STATE(2019),
    [sym_database_reference] = STATE(1981),
    [sym__literal_value] = STATE(1981),
    [sym_codeunit_keyword] = STATE(2105),
    [sym_xmlport_keyword] = STATE(2105),
    [sym_enum_keyword] = STATE(2124),
    [sym_identifier] = ACTIONS(7130),
    [anon_sym_DASH] = ACTIONS(5612),
    [aux_sym_boolean_token1] = ACTIONS(3454),
    [aux_sym_boolean_token2] = ACTIONS(3454),
    [sym_decimal] = ACTIONS(8419),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3458),
    [anon_sym_LBRACK] = ACTIONS(7134),
    [aux_sym_record_type_token1] = ACTIONS(3458),
    [aux_sym_basic_type_token21] = ACTIONS(3458),
    [aux_sym_basic_type_token22] = ACTIONS(3458),
    [aux_sym_basic_type_token48] = ACTIONS(3458),
    [anon_sym_not] = ACTIONS(5618),
    [anon_sym_NOT] = ACTIONS(5618),
    [anon_sym_Not] = ACTIONS(5618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3458),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5612),
    [sym_datetime_literal] = ACTIONS(8421),
    [sym_date_literal] = ACTIONS(8419),
    [sym_time_literal] = ACTIONS(8419),
    [sym_biginteger_literal] = ACTIONS(8421),
    [sym_page_keyword] = ACTIONS(5624),
    [anon_sym_codeunit] = ACTIONS(3462),
    [anon_sym_CODEUNIT] = ACTIONS(3462),
    [anon_sym_Codeunit] = ACTIONS(3462),
    [anon_sym_CodeUnit] = ACTIONS(3462),
    [anon_sym_COdeunit] = ACTIONS(3462),
    [anon_sym_codeUnit] = ACTIONS(3462),
    [sym_report_keyword] = ACTIONS(5624),
    [sym_query_keyword] = ACTIONS(5624),
    [anon_sym_xmlport] = ACTIONS(3464),
    [anon_sym_XMLPORT] = ACTIONS(3464),
    [anon_sym_Xmlport] = ACTIONS(3464),
    [anon_sym_XMLport] = ACTIONS(3464),
    [anon_sym_XMLPort] = ACTIONS(3464),
    [anon_sym_XmlPort] = ACTIONS(3464),
    [anon_sym_enum] = ACTIONS(3466),
    [anon_sym_ENUM] = ACTIONS(3466),
    [anon_sym_Enum] = ACTIONS(3466),
    [anon_sym_eNUM] = ACTIONS(3466),
    [anon_sym_eNum] = ACTIONS(3466),
    [anon_sym_ENum] = ACTIONS(3466),
    [sym_quoted_identifier] = ACTIONS(7138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8421),
    [sym_integer] = ACTIONS(8419),
    [sym_continue_as_identifier] = ACTIONS(8421),
  },
  [STATE(3201)] = {
    [sym_boolean] = STATE(1087),
    [sym_assignment_expression] = STATE(1087),
    [sym__expression] = STATE(1087),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1087),
    [sym_multiplicative_expression] = STATE(1087),
    [sym_additive_expression] = STATE(1087),
    [sym_comparison_expression] = STATE(1087),
    [sym_logical_expression] = STATE(1087),
    [sym_ternary_expression] = STATE(1087),
    [sym_unary_expression] = STATE(1087),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1087),
    [sym_list_literal] = STATE(1087),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1087),
    [sym__literal_value] = STATE(1087),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(8423),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(8425),
    [sym_date_literal] = ACTIONS(8423),
    [sym_time_literal] = ACTIONS(8423),
    [sym_biginteger_literal] = ACTIONS(8425),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8425),
    [sym_integer] = ACTIONS(8423),
    [sym_continue_as_identifier] = ACTIONS(8425),
  },
  [STATE(3202)] = {
    [sym_boolean] = STATE(5424),
    [sym_assignment_expression] = STATE(5424),
    [sym__expression] = STATE(5424),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5424),
    [sym_multiplicative_expression] = STATE(5424),
    [sym_additive_expression] = STATE(5424),
    [sym_comparison_expression] = STATE(5424),
    [sym_logical_expression] = STATE(5424),
    [sym_ternary_expression] = STATE(5424),
    [sym_unary_expression] = STATE(5424),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5424),
    [sym_list_literal] = STATE(5424),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5424),
    [sym__literal_value] = STATE(5424),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(8427),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(8429),
    [sym_date_literal] = ACTIONS(8427),
    [sym_time_literal] = ACTIONS(8427),
    [sym_biginteger_literal] = ACTIONS(8429),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8429),
    [sym_integer] = ACTIONS(8427),
    [sym_continue_as_identifier] = ACTIONS(8429),
  },
  [STATE(3203)] = {
    [sym_boolean] = STATE(5423),
    [sym_assignment_expression] = STATE(5423),
    [sym__expression] = STATE(5423),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5423),
    [sym_multiplicative_expression] = STATE(5423),
    [sym_additive_expression] = STATE(5423),
    [sym_comparison_expression] = STATE(5423),
    [sym_logical_expression] = STATE(5423),
    [sym_ternary_expression] = STATE(5423),
    [sym_unary_expression] = STATE(5423),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5423),
    [sym_list_literal] = STATE(5423),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5423),
    [sym__literal_value] = STATE(5423),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(8431),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(8433),
    [sym_date_literal] = ACTIONS(8431),
    [sym_time_literal] = ACTIONS(8431),
    [sym_biginteger_literal] = ACTIONS(8433),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8433),
    [sym_integer] = ACTIONS(8431),
    [sym_continue_as_identifier] = ACTIONS(8433),
  },
  [STATE(3204)] = {
    [sym_boolean] = STATE(1068),
    [sym_assignment_expression] = STATE(1068),
    [sym__expression] = STATE(1068),
    [sym_keyword_identifier] = STATE(1085),
    [sym_range_expression] = STATE(1068),
    [sym_multiplicative_expression] = STATE(1068),
    [sym_additive_expression] = STATE(1068),
    [sym_comparison_expression] = STATE(1068),
    [sym_logical_expression] = STATE(1068),
    [sym_ternary_expression] = STATE(1068),
    [sym_unary_expression] = STATE(1068),
    [sym_call_expression] = STATE(1126),
    [sym_member_expression] = STATE(1085),
    [sym_subscript_expression] = STATE(1085),
    [sym_parenthesized_expression] = STATE(1068),
    [sym_list_literal] = STATE(1068),
    [sym_qualified_enum_value] = STATE(1085),
    [sym_database_reference] = STATE(1068),
    [sym__literal_value] = STATE(1068),
    [sym_codeunit_keyword] = STATE(1106),
    [sym_xmlport_keyword] = STATE(1106),
    [sym_enum_keyword] = STATE(1050),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(529),
    [aux_sym_boolean_token1] = ACTIONS(423),
    [aux_sym_boolean_token2] = ACTIONS(423),
    [sym_decimal] = ACTIONS(8435),
    [anon_sym_LPAREN] = ACTIONS(533),
    [aux_sym_tabledata_permission_token2] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(535),
    [aux_sym_record_type_token1] = ACTIONS(427),
    [aux_sym_basic_type_token21] = ACTIONS(427),
    [aux_sym_basic_type_token22] = ACTIONS(427),
    [aux_sym_basic_type_token48] = ACTIONS(427),
    [anon_sym_not] = ACTIONS(537),
    [anon_sym_NOT] = ACTIONS(537),
    [anon_sym_Not] = ACTIONS(537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(427),
    [aux_sym_keyword_identifier_token2] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(529),
    [sym_datetime_literal] = ACTIONS(8437),
    [sym_date_literal] = ACTIONS(8435),
    [sym_time_literal] = ACTIONS(8435),
    [sym_biginteger_literal] = ACTIONS(8437),
    [sym_page_keyword] = ACTIONS(539),
    [anon_sym_codeunit] = ACTIONS(431),
    [anon_sym_CODEUNIT] = ACTIONS(431),
    [anon_sym_Codeunit] = ACTIONS(431),
    [anon_sym_CodeUnit] = ACTIONS(431),
    [anon_sym_COdeunit] = ACTIONS(431),
    [anon_sym_codeUnit] = ACTIONS(431),
    [sym_report_keyword] = ACTIONS(539),
    [sym_query_keyword] = ACTIONS(539),
    [anon_sym_xmlport] = ACTIONS(433),
    [anon_sym_XMLPORT] = ACTIONS(433),
    [anon_sym_Xmlport] = ACTIONS(433),
    [anon_sym_XMLport] = ACTIONS(433),
    [anon_sym_XMLPort] = ACTIONS(433),
    [anon_sym_XmlPort] = ACTIONS(433),
    [anon_sym_enum] = ACTIONS(435),
    [anon_sym_ENUM] = ACTIONS(435),
    [anon_sym_Enum] = ACTIONS(435),
    [anon_sym_eNUM] = ACTIONS(435),
    [anon_sym_eNum] = ACTIONS(435),
    [anon_sym_ENum] = ACTIONS(435),
    [sym_quoted_identifier] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8437),
    [sym_integer] = ACTIONS(8435),
    [sym_continue_as_identifier] = ACTIONS(8437),
  },
  [STATE(3205)] = {
    [sym__body_element] = STATE(6090),
    [sym_empty_statement] = STATE(6090),
    [sym_property] = STATE(6090),
    [sym_fields_section] = STATE(6090),
    [sym_keys_section] = STATE(6090),
    [sym_fieldgroups_section] = STATE(6090),
    [sym_enum_value_declaration] = STATE(6090),
    [sym_labels_section] = STATE(6090),
    [sym_layout_section] = STATE(6090),
    [sym_modify_modification] = STATE(6090),
    [sym_actions_section] = STATE(6090),
    [sym_views_section] = STATE(6090),
    [sym_dataset_section] = STATE(6090),
    [sym_report_dataitem] = STATE(3255),
    [sym__report_body_element] = STATE(3255),
    [sym_preproc_conditional_report] = STATE(3255),
    [sym_report_column] = STATE(3255),
    [sym_requestpage_section] = STATE(6090),
    [sym_rendering_section] = STATE(6090),
    [sym_elements_section] = STATE(6090),
    [sym_schema_section] = STATE(6090),
    [sym_assembly_declaration] = STATE(6090),
    [sym_event_declaration] = STATE(6090),
    [sym_procedure] = STATE(6090),
    [sym_preproc_split_procedure] = STATE(6090),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(6090),
    [sym_var_section] = STATE(6090),
    [sym_attribute_item] = STATE(6090),
    [sym_preproc_conditional] = STATE(6090),
    [sym_preproc_if] = STATE(2557),
    [sym_preproc_endif] = STATE(6879),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3490),
    [aux_sym_report_dataitem_repeat1] = STATE(3255),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3206)] = {
    [sym_boolean] = STATE(6142),
    [sym_assignment_expression] = STATE(6142),
    [sym__expression] = STATE(6142),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6142),
    [sym_multiplicative_expression] = STATE(6142),
    [sym_additive_expression] = STATE(6142),
    [sym_comparison_expression] = STATE(6142),
    [sym_logical_expression] = STATE(6142),
    [sym_ternary_expression] = STATE(6142),
    [sym_unary_expression] = STATE(6142),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6142),
    [sym_list_literal] = STATE(6142),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6142),
    [sym__literal_value] = STATE(6142),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8439),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8441),
    [sym_date_literal] = ACTIONS(8439),
    [sym_time_literal] = ACTIONS(8439),
    [sym_biginteger_literal] = ACTIONS(8441),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8441),
    [sym_integer] = ACTIONS(8439),
    [sym_continue_as_identifier] = ACTIONS(8441),
  },
  [STATE(3207)] = {
    [sym_boolean] = STATE(5438),
    [sym_assignment_expression] = STATE(5438),
    [sym__expression] = STATE(5438),
    [sym_keyword_identifier] = STATE(5592),
    [sym_range_expression] = STATE(5438),
    [sym_multiplicative_expression] = STATE(5438),
    [sym_additive_expression] = STATE(5438),
    [sym_comparison_expression] = STATE(5438),
    [sym_logical_expression] = STATE(5438),
    [sym_ternary_expression] = STATE(5438),
    [sym_unary_expression] = STATE(5438),
    [sym_call_expression] = STATE(5926),
    [sym_member_expression] = STATE(5592),
    [sym_subscript_expression] = STATE(5592),
    [sym_parenthesized_expression] = STATE(5438),
    [sym_list_literal] = STATE(5438),
    [sym_qualified_enum_value] = STATE(5592),
    [sym_database_reference] = STATE(5438),
    [sym__literal_value] = STATE(5438),
    [sym_codeunit_keyword] = STATE(5909),
    [sym_xmlport_keyword] = STATE(5909),
    [sym_enum_keyword] = STATE(5754),
    [sym_identifier] = ACTIONS(7036),
    [anon_sym_DASH] = ACTIONS(7038),
    [aux_sym_boolean_token1] = ACTIONS(4842),
    [aux_sym_boolean_token2] = ACTIONS(4842),
    [sym_decimal] = ACTIONS(8443),
    [anon_sym_LPAREN] = ACTIONS(7042),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(7044),
    [aux_sym_record_type_token1] = ACTIONS(4846),
    [aux_sym_basic_type_token21] = ACTIONS(4846),
    [aux_sym_basic_type_token22] = ACTIONS(4846),
    [aux_sym_basic_type_token48] = ACTIONS(4846),
    [anon_sym_not] = ACTIONS(7046),
    [anon_sym_NOT] = ACTIONS(7046),
    [anon_sym_Not] = ACTIONS(7046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4846),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7048),
    [anon_sym_PLUS] = ACTIONS(7038),
    [sym_datetime_literal] = ACTIONS(8445),
    [sym_date_literal] = ACTIONS(8443),
    [sym_time_literal] = ACTIONS(8443),
    [sym_biginteger_literal] = ACTIONS(8445),
    [sym_page_keyword] = ACTIONS(7048),
    [anon_sym_codeunit] = ACTIONS(4850),
    [anon_sym_CODEUNIT] = ACTIONS(4850),
    [anon_sym_Codeunit] = ACTIONS(4850),
    [anon_sym_CodeUnit] = ACTIONS(4850),
    [anon_sym_COdeunit] = ACTIONS(4850),
    [anon_sym_codeUnit] = ACTIONS(4850),
    [sym_report_keyword] = ACTIONS(7048),
    [sym_query_keyword] = ACTIONS(7048),
    [anon_sym_xmlport] = ACTIONS(4852),
    [anon_sym_XMLPORT] = ACTIONS(4852),
    [anon_sym_Xmlport] = ACTIONS(4852),
    [anon_sym_XMLport] = ACTIONS(4852),
    [anon_sym_XMLPort] = ACTIONS(4852),
    [anon_sym_XmlPort] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_ENUM] = ACTIONS(4854),
    [anon_sym_Enum] = ACTIONS(4854),
    [anon_sym_eNUM] = ACTIONS(4854),
    [anon_sym_eNum] = ACTIONS(4854),
    [anon_sym_ENum] = ACTIONS(4854),
    [sym_quoted_identifier] = ACTIONS(7052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8445),
    [sym_integer] = ACTIONS(8443),
    [sym_continue_as_identifier] = ACTIONS(8445),
  },
  [STATE(3208)] = {
    [sym_boolean] = STATE(6018),
    [sym_assignment_expression] = STATE(6018),
    [sym__expression] = STATE(6018),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6018),
    [sym_multiplicative_expression] = STATE(6018),
    [sym_additive_expression] = STATE(6018),
    [sym_comparison_expression] = STATE(6018),
    [sym_logical_expression] = STATE(6018),
    [sym_ternary_expression] = STATE(6018),
    [sym_unary_expression] = STATE(6018),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6018),
    [sym_list_literal] = STATE(6018),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6018),
    [sym__literal_value] = STATE(6018),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8447),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8449),
    [sym_date_literal] = ACTIONS(8447),
    [sym_time_literal] = ACTIONS(8447),
    [sym_biginteger_literal] = ACTIONS(8449),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8449),
    [sym_integer] = ACTIONS(8447),
    [sym_continue_as_identifier] = ACTIONS(8449),
  },
  [STATE(3209)] = {
    [sym_boolean] = STATE(6148),
    [sym_assignment_expression] = STATE(6148),
    [sym__expression] = STATE(6148),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6148),
    [sym_multiplicative_expression] = STATE(6148),
    [sym_additive_expression] = STATE(6148),
    [sym_comparison_expression] = STATE(6148),
    [sym_logical_expression] = STATE(6148),
    [sym_ternary_expression] = STATE(6148),
    [sym_unary_expression] = STATE(6148),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6148),
    [sym_list_literal] = STATE(6148),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6148),
    [sym__literal_value] = STATE(6148),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8451),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8453),
    [sym_date_literal] = ACTIONS(8451),
    [sym_time_literal] = ACTIONS(8451),
    [sym_biginteger_literal] = ACTIONS(8453),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8453),
    [sym_integer] = ACTIONS(8451),
    [sym_continue_as_identifier] = ACTIONS(8453),
  },
  [STATE(3210)] = {
    [sym_boolean] = STATE(6149),
    [sym_assignment_expression] = STATE(6149),
    [sym__expression] = STATE(6149),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6149),
    [sym_multiplicative_expression] = STATE(6149),
    [sym_additive_expression] = STATE(6149),
    [sym_comparison_expression] = STATE(6149),
    [sym_logical_expression] = STATE(6149),
    [sym_ternary_expression] = STATE(6149),
    [sym_unary_expression] = STATE(6149),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6149),
    [sym_list_literal] = STATE(6149),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6149),
    [sym__literal_value] = STATE(6149),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8455),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8457),
    [sym_date_literal] = ACTIONS(8455),
    [sym_time_literal] = ACTIONS(8455),
    [sym_biginteger_literal] = ACTIONS(8457),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8457),
    [sym_integer] = ACTIONS(8455),
    [sym_continue_as_identifier] = ACTIONS(8457),
  },
  [STATE(3211)] = {
    [sym_boolean] = STATE(6150),
    [sym_assignment_expression] = STATE(6150),
    [sym__expression] = STATE(6150),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6150),
    [sym_multiplicative_expression] = STATE(6150),
    [sym_additive_expression] = STATE(6150),
    [sym_comparison_expression] = STATE(6150),
    [sym_logical_expression] = STATE(6150),
    [sym_ternary_expression] = STATE(6150),
    [sym_unary_expression] = STATE(6150),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6150),
    [sym_list_literal] = STATE(6150),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6150),
    [sym__literal_value] = STATE(6150),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8459),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8461),
    [sym_date_literal] = ACTIONS(8459),
    [sym_time_literal] = ACTIONS(8459),
    [sym_biginteger_literal] = ACTIONS(8461),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8461),
    [sym_integer] = ACTIONS(8459),
    [sym_continue_as_identifier] = ACTIONS(8461),
  },
  [STATE(3212)] = {
    [sym_boolean] = STATE(6151),
    [sym_assignment_expression] = STATE(6151),
    [sym__expression] = STATE(6151),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6151),
    [sym_multiplicative_expression] = STATE(6151),
    [sym_additive_expression] = STATE(6151),
    [sym_comparison_expression] = STATE(6151),
    [sym_logical_expression] = STATE(6151),
    [sym_ternary_expression] = STATE(6151),
    [sym_unary_expression] = STATE(6151),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6151),
    [sym_list_literal] = STATE(6151),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6151),
    [sym__literal_value] = STATE(6151),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8463),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8465),
    [sym_date_literal] = ACTIONS(8463),
    [sym_time_literal] = ACTIONS(8463),
    [sym_biginteger_literal] = ACTIONS(8465),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8465),
    [sym_integer] = ACTIONS(8463),
    [sym_continue_as_identifier] = ACTIONS(8465),
  },
  [STATE(3213)] = {
    [sym_boolean] = STATE(6154),
    [sym_assignment_expression] = STATE(6154),
    [sym__expression] = STATE(6154),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6154),
    [sym_multiplicative_expression] = STATE(6154),
    [sym_additive_expression] = STATE(6154),
    [sym_comparison_expression] = STATE(6154),
    [sym_logical_expression] = STATE(6154),
    [sym_ternary_expression] = STATE(6154),
    [sym_unary_expression] = STATE(6154),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6154),
    [sym_list_literal] = STATE(6154),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6154),
    [sym__literal_value] = STATE(6154),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8467),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8469),
    [sym_date_literal] = ACTIONS(8467),
    [sym_time_literal] = ACTIONS(8467),
    [sym_biginteger_literal] = ACTIONS(8469),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8469),
    [sym_integer] = ACTIONS(8467),
    [sym_continue_as_identifier] = ACTIONS(8469),
  },
  [STATE(3214)] = {
    [sym_identifier] = ACTIONS(8471),
    [anon_sym_SEMI] = ACTIONS(8473),
    [aux_sym_where_condition_token1] = ACTIONS(8471),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8471),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8471),
    [anon_sym_LBRACK] = ACTIONS(8473),
    [aux_sym_basic_type_token6] = ACTIONS(8471),
    [aux_sym_basic_type_token22] = ACTIONS(8471),
    [aux_sym_basic_type_token53] = ACTIONS(8471),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8471),
    [aux_sym_addafter_modification_token1] = ACTIONS(8471),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8471),
    [aux_sym_modify_modification_token1] = ACTIONS(8471),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8471),
    [aux_sym_movelast_modification_token1] = ACTIONS(8471),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8471),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8471),
    [aux_sym_separator_action_token1] = ACTIONS(8471),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8471),
    [aux_sym_type_declaration_token1] = ACTIONS(8471),
    [anon_sym_POUNDif] = ACTIONS(8473),
    [anon_sym_POUNDIF] = ACTIONS(8473),
    [anon_sym_POUNDIf] = ACTIONS(8473),
    [anon_sym_POUNDelif] = ACTIONS(8473),
    [anon_sym_POUNDELIF] = ACTIONS(8473),
    [anon_sym_POUNDElif] = ACTIONS(8473),
    [anon_sym_POUNDelse] = ACTIONS(8473),
    [anon_sym_POUNDELSE] = ACTIONS(8473),
    [anon_sym_POUNDElse] = ACTIONS(8473),
    [anon_sym_POUNDendif] = ACTIONS(8473),
    [anon_sym_POUNDENDIF] = ACTIONS(8473),
    [anon_sym_POUNDEndif] = ACTIONS(8473),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8471),
    [sym_trigger_keyword] = ACTIONS(8471),
    [sym_var_keyword] = ACTIONS(8471),
    [sym_local_keyword] = ACTIONS(8471),
    [sym_internal_keyword] = ACTIONS(8471),
    [sym_protected_keyword] = ACTIONS(8471),
    [sym_event_keyword] = ACTIONS(8471),
    [sym_fields_keyword] = ACTIONS(8471),
    [sym_keys_keyword] = ACTIONS(8471),
    [sym_key_keyword] = ACTIONS(8471),
    [sym_fieldgroups_keyword] = ACTIONS(8471),
    [sym_actions_keyword] = ACTIONS(8471),
    [sym_layout_keyword] = ACTIONS(8471),
    [sym_area_keyword] = ACTIONS(8471),
    [sym_group_keyword] = ACTIONS(8471),
    [sym_repeater_keyword] = ACTIONS(8471),
    [sym_cuegroup_keyword] = ACTIONS(8471),
    [sym_fixed_keyword] = ACTIONS(8471),
    [sym_grid_keyword] = ACTIONS(8471),
    [sym_part_keyword] = ACTIONS(8471),
    [sym_systempart_keyword] = ACTIONS(8471),
    [sym_usercontrol_keyword] = ACTIONS(8471),
    [sym_dataset_keyword] = ACTIONS(8471),
    [sym_elements_keyword] = ACTIONS(8471),
    [sym_dataitem_keyword] = ACTIONS(8471),
    [sym_column_keyword] = ACTIONS(8471),
    [sym_filter_keyword] = ACTIONS(8471),
    [sym_labels_keyword] = ACTIONS(8471),
    [sym_rendering_keyword] = ACTIONS(8471),
    [sym_requestpage_keyword] = ACTIONS(8471),
    [sym_schema_keyword] = ACTIONS(8471),
    [sym_views_keyword] = ACTIONS(8471),
    [sym_quoted_identifier] = ACTIONS(8473),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8473),
    [sym_preproc_open] = ACTIONS(8473),
    [sym_preproc_close] = ACTIONS(8473),
    [sym_var_attribute_open] = ACTIONS(8473),
  },
  [STATE(3215)] = {
    [sym_identifier] = ACTIONS(4379),
    [anon_sym_SEMI] = ACTIONS(4381),
    [aux_sym_where_condition_token1] = ACTIONS(4379),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4379),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4379),
    [anon_sym_LBRACK] = ACTIONS(4381),
    [aux_sym_basic_type_token6] = ACTIONS(4379),
    [aux_sym_basic_type_token22] = ACTIONS(4379),
    [aux_sym_basic_type_token53] = ACTIONS(4379),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4379),
    [aux_sym_addafter_modification_token1] = ACTIONS(4379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4379),
    [aux_sym_modify_modification_token1] = ACTIONS(4379),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4379),
    [aux_sym_movelast_modification_token1] = ACTIONS(4379),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4379),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4379),
    [aux_sym_separator_action_token1] = ACTIONS(4379),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4379),
    [aux_sym_type_declaration_token1] = ACTIONS(4379),
    [anon_sym_POUNDif] = ACTIONS(4381),
    [anon_sym_POUNDIF] = ACTIONS(4381),
    [anon_sym_POUNDIf] = ACTIONS(4381),
    [anon_sym_POUNDelif] = ACTIONS(4381),
    [anon_sym_POUNDELIF] = ACTIONS(4381),
    [anon_sym_POUNDElif] = ACTIONS(4381),
    [anon_sym_POUNDelse] = ACTIONS(4381),
    [anon_sym_POUNDELSE] = ACTIONS(4381),
    [anon_sym_POUNDElse] = ACTIONS(4381),
    [anon_sym_POUNDendif] = ACTIONS(4381),
    [anon_sym_POUNDENDIF] = ACTIONS(4381),
    [anon_sym_POUNDEndif] = ACTIONS(4381),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4379),
    [sym_trigger_keyword] = ACTIONS(4379),
    [sym_var_keyword] = ACTIONS(4379),
    [sym_local_keyword] = ACTIONS(4379),
    [sym_internal_keyword] = ACTIONS(4379),
    [sym_protected_keyword] = ACTIONS(4379),
    [sym_event_keyword] = ACTIONS(4379),
    [sym_fields_keyword] = ACTIONS(4379),
    [sym_keys_keyword] = ACTIONS(4379),
    [sym_key_keyword] = ACTIONS(4379),
    [sym_fieldgroups_keyword] = ACTIONS(4379),
    [sym_actions_keyword] = ACTIONS(4379),
    [sym_layout_keyword] = ACTIONS(4379),
    [sym_area_keyword] = ACTIONS(4379),
    [sym_group_keyword] = ACTIONS(4379),
    [sym_repeater_keyword] = ACTIONS(4379),
    [sym_cuegroup_keyword] = ACTIONS(4379),
    [sym_fixed_keyword] = ACTIONS(4379),
    [sym_grid_keyword] = ACTIONS(4379),
    [sym_part_keyword] = ACTIONS(4379),
    [sym_systempart_keyword] = ACTIONS(4379),
    [sym_usercontrol_keyword] = ACTIONS(4379),
    [sym_dataset_keyword] = ACTIONS(4379),
    [sym_elements_keyword] = ACTIONS(4379),
    [sym_dataitem_keyword] = ACTIONS(4379),
    [sym_column_keyword] = ACTIONS(4379),
    [sym_filter_keyword] = ACTIONS(4379),
    [sym_labels_keyword] = ACTIONS(4379),
    [sym_rendering_keyword] = ACTIONS(4379),
    [sym_requestpage_keyword] = ACTIONS(4379),
    [sym_schema_keyword] = ACTIONS(4379),
    [sym_views_keyword] = ACTIONS(4379),
    [sym_quoted_identifier] = ACTIONS(4381),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4381),
    [sym_preproc_open] = ACTIONS(4381),
    [sym_preproc_close] = ACTIONS(4381),
    [sym_var_attribute_open] = ACTIONS(4381),
  },
  [STATE(3216)] = {
    [sym_boolean] = STATE(6081),
    [sym_assignment_expression] = STATE(6081),
    [sym__expression] = STATE(6081),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6081),
    [sym_multiplicative_expression] = STATE(6081),
    [sym_additive_expression] = STATE(6081),
    [sym_comparison_expression] = STATE(6081),
    [sym_logical_expression] = STATE(6081),
    [sym_ternary_expression] = STATE(6081),
    [sym_unary_expression] = STATE(6081),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6081),
    [sym_list_literal] = STATE(6081),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6081),
    [sym__literal_value] = STATE(6081),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8475),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(8477),
    [sym_date_literal] = ACTIONS(8475),
    [sym_time_literal] = ACTIONS(8475),
    [sym_biginteger_literal] = ACTIONS(8477),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8477),
    [sym_integer] = ACTIONS(8475),
    [sym_continue_as_identifier] = ACTIONS(8477),
  },
  [STATE(3217)] = {
    [sym_boolean] = STATE(6156),
    [sym_assignment_expression] = STATE(6156),
    [sym__expression] = STATE(6156),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6156),
    [sym_multiplicative_expression] = STATE(6156),
    [sym_additive_expression] = STATE(6156),
    [sym_comparison_expression] = STATE(6156),
    [sym_logical_expression] = STATE(6156),
    [sym_ternary_expression] = STATE(6156),
    [sym_unary_expression] = STATE(6156),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6156),
    [sym_list_literal] = STATE(6156),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6156),
    [sym__literal_value] = STATE(6156),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8479),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8481),
    [sym_date_literal] = ACTIONS(8479),
    [sym_time_literal] = ACTIONS(8479),
    [sym_biginteger_literal] = ACTIONS(8481),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8481),
    [sym_integer] = ACTIONS(8479),
    [sym_continue_as_identifier] = ACTIONS(8481),
  },
  [STATE(3218)] = {
    [sym_boolean] = STATE(6157),
    [sym_assignment_expression] = STATE(6157),
    [sym__expression] = STATE(6157),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6157),
    [sym_multiplicative_expression] = STATE(6157),
    [sym_additive_expression] = STATE(6157),
    [sym_comparison_expression] = STATE(6157),
    [sym_logical_expression] = STATE(6157),
    [sym_ternary_expression] = STATE(6157),
    [sym_unary_expression] = STATE(6157),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6157),
    [sym_list_literal] = STATE(6157),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6157),
    [sym__literal_value] = STATE(6157),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8483),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8485),
    [sym_date_literal] = ACTIONS(8483),
    [sym_time_literal] = ACTIONS(8483),
    [sym_biginteger_literal] = ACTIONS(8485),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8485),
    [sym_integer] = ACTIONS(8483),
    [sym_continue_as_identifier] = ACTIONS(8485),
  },
  [STATE(3219)] = {
    [sym_boolean] = STATE(6158),
    [sym_assignment_expression] = STATE(6158),
    [sym__expression] = STATE(6158),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6158),
    [sym_multiplicative_expression] = STATE(6158),
    [sym_additive_expression] = STATE(6158),
    [sym_comparison_expression] = STATE(6158),
    [sym_logical_expression] = STATE(6158),
    [sym_ternary_expression] = STATE(6158),
    [sym_unary_expression] = STATE(6158),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6158),
    [sym_list_literal] = STATE(6158),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6158),
    [sym__literal_value] = STATE(6158),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8487),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8489),
    [sym_date_literal] = ACTIONS(8487),
    [sym_time_literal] = ACTIONS(8487),
    [sym_biginteger_literal] = ACTIONS(8489),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8489),
    [sym_integer] = ACTIONS(8487),
    [sym_continue_as_identifier] = ACTIONS(8489),
  },
  [STATE(3220)] = {
    [sym_boolean] = STATE(6159),
    [sym_assignment_expression] = STATE(6159),
    [sym__expression] = STATE(6159),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6159),
    [sym_multiplicative_expression] = STATE(6159),
    [sym_additive_expression] = STATE(6159),
    [sym_comparison_expression] = STATE(6159),
    [sym_logical_expression] = STATE(6159),
    [sym_ternary_expression] = STATE(6159),
    [sym_unary_expression] = STATE(6159),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6159),
    [sym_list_literal] = STATE(6159),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6159),
    [sym__literal_value] = STATE(6159),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8491),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8493),
    [sym_date_literal] = ACTIONS(8491),
    [sym_time_literal] = ACTIONS(8491),
    [sym_biginteger_literal] = ACTIONS(8493),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8493),
    [sym_integer] = ACTIONS(8491),
    [sym_continue_as_identifier] = ACTIONS(8493),
  },
  [STATE(3221)] = {
    [sym_boolean] = STATE(6160),
    [sym_assignment_expression] = STATE(6160),
    [sym__expression] = STATE(6160),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6160),
    [sym_multiplicative_expression] = STATE(6160),
    [sym_additive_expression] = STATE(6160),
    [sym_comparison_expression] = STATE(6160),
    [sym_logical_expression] = STATE(6160),
    [sym_ternary_expression] = STATE(6160),
    [sym_unary_expression] = STATE(6160),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6160),
    [sym_list_literal] = STATE(6160),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6160),
    [sym__literal_value] = STATE(6160),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8495),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8497),
    [sym_date_literal] = ACTIONS(8495),
    [sym_time_literal] = ACTIONS(8495),
    [sym_biginteger_literal] = ACTIONS(8497),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8497),
    [sym_integer] = ACTIONS(8495),
    [sym_continue_as_identifier] = ACTIONS(8497),
  },
  [STATE(3222)] = {
    [sym_identifier] = ACTIONS(4383),
    [anon_sym_SEMI] = ACTIONS(8499),
    [aux_sym_where_condition_token1] = ACTIONS(4383),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4383),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4383),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_basic_type_token6] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_basic_type_token53] = ACTIONS(4383),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4383),
    [aux_sym_addafter_modification_token1] = ACTIONS(4383),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4383),
    [aux_sym_modify_modification_token1] = ACTIONS(4383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4383),
    [aux_sym_movelast_modification_token1] = ACTIONS(4383),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4383),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4383),
    [aux_sym_separator_action_token1] = ACTIONS(4383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4383),
    [aux_sym_type_declaration_token1] = ACTIONS(4383),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [anon_sym_POUNDelif] = ACTIONS(4387),
    [anon_sym_POUNDELIF] = ACTIONS(4387),
    [anon_sym_POUNDElif] = ACTIONS(4387),
    [anon_sym_POUNDelse] = ACTIONS(4387),
    [anon_sym_POUNDELSE] = ACTIONS(4387),
    [anon_sym_POUNDElse] = ACTIONS(4387),
    [anon_sym_POUNDendif] = ACTIONS(4387),
    [anon_sym_POUNDENDIF] = ACTIONS(4387),
    [anon_sym_POUNDEndif] = ACTIONS(4387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4383),
    [sym_trigger_keyword] = ACTIONS(4383),
    [sym_var_keyword] = ACTIONS(4383),
    [sym_local_keyword] = ACTIONS(4383),
    [sym_internal_keyword] = ACTIONS(4383),
    [sym_protected_keyword] = ACTIONS(4383),
    [sym_event_keyword] = ACTIONS(4383),
    [sym_fields_keyword] = ACTIONS(4383),
    [sym_keys_keyword] = ACTIONS(4383),
    [sym_key_keyword] = ACTIONS(4383),
    [sym_fieldgroups_keyword] = ACTIONS(4383),
    [sym_actions_keyword] = ACTIONS(4383),
    [sym_layout_keyword] = ACTIONS(4383),
    [sym_area_keyword] = ACTIONS(4383),
    [sym_group_keyword] = ACTIONS(4383),
    [sym_repeater_keyword] = ACTIONS(4383),
    [sym_cuegroup_keyword] = ACTIONS(4383),
    [sym_fixed_keyword] = ACTIONS(4383),
    [sym_grid_keyword] = ACTIONS(4383),
    [sym_part_keyword] = ACTIONS(4383),
    [sym_systempart_keyword] = ACTIONS(4383),
    [sym_usercontrol_keyword] = ACTIONS(4383),
    [sym_dataset_keyword] = ACTIONS(4383),
    [sym_elements_keyword] = ACTIONS(4383),
    [sym_dataitem_keyword] = ACTIONS(4383),
    [sym_column_keyword] = ACTIONS(4383),
    [sym_filter_keyword] = ACTIONS(4383),
    [sym_labels_keyword] = ACTIONS(4383),
    [sym_rendering_keyword] = ACTIONS(4383),
    [sym_requestpage_keyword] = ACTIONS(4383),
    [sym_schema_keyword] = ACTIONS(4383),
    [sym_views_keyword] = ACTIONS(4383),
    [sym_quoted_identifier] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
    [sym_preproc_close] = ACTIONS(4387),
    [sym_var_attribute_open] = ACTIONS(4387),
  },
  [STATE(3223)] = {
    [sym_boolean] = STATE(6161),
    [sym_assignment_expression] = STATE(6161),
    [sym__expression] = STATE(6161),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6161),
    [sym_multiplicative_expression] = STATE(6161),
    [sym_additive_expression] = STATE(6161),
    [sym_comparison_expression] = STATE(6161),
    [sym_logical_expression] = STATE(6161),
    [sym_ternary_expression] = STATE(6161),
    [sym_unary_expression] = STATE(6161),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6161),
    [sym_list_literal] = STATE(6161),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6161),
    [sym__literal_value] = STATE(6161),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8501),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8503),
    [sym_date_literal] = ACTIONS(8501),
    [sym_time_literal] = ACTIONS(8501),
    [sym_biginteger_literal] = ACTIONS(8503),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8503),
    [sym_integer] = ACTIONS(8501),
    [sym_continue_as_identifier] = ACTIONS(8503),
  },
  [STATE(3224)] = {
    [sym_boolean] = STATE(6162),
    [sym_assignment_expression] = STATE(6162),
    [sym__expression] = STATE(6162),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6162),
    [sym_multiplicative_expression] = STATE(6162),
    [sym_additive_expression] = STATE(6162),
    [sym_comparison_expression] = STATE(6162),
    [sym_logical_expression] = STATE(6162),
    [sym_ternary_expression] = STATE(6162),
    [sym_unary_expression] = STATE(6162),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6162),
    [sym_list_literal] = STATE(6162),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6162),
    [sym__literal_value] = STATE(6162),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8505),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8507),
    [sym_date_literal] = ACTIONS(8505),
    [sym_time_literal] = ACTIONS(8505),
    [sym_biginteger_literal] = ACTIONS(8507),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8507),
    [sym_integer] = ACTIONS(8505),
    [sym_continue_as_identifier] = ACTIONS(8507),
  },
  [STATE(3225)] = {
    [sym_boolean] = STATE(6163),
    [sym_assignment_expression] = STATE(6163),
    [sym__expression] = STATE(6163),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6163),
    [sym_multiplicative_expression] = STATE(6163),
    [sym_additive_expression] = STATE(6163),
    [sym_comparison_expression] = STATE(6163),
    [sym_logical_expression] = STATE(6163),
    [sym_ternary_expression] = STATE(6163),
    [sym_unary_expression] = STATE(6163),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6163),
    [sym_list_literal] = STATE(6163),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6163),
    [sym__literal_value] = STATE(6163),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8509),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8511),
    [sym_date_literal] = ACTIONS(8509),
    [sym_time_literal] = ACTIONS(8509),
    [sym_biginteger_literal] = ACTIONS(8511),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8511),
    [sym_integer] = ACTIONS(8509),
    [sym_continue_as_identifier] = ACTIONS(8511),
  },
  [STATE(3226)] = {
    [sym_boolean] = STATE(6164),
    [sym_assignment_expression] = STATE(6164),
    [sym__expression] = STATE(6164),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6164),
    [sym_multiplicative_expression] = STATE(6164),
    [sym_additive_expression] = STATE(6164),
    [sym_comparison_expression] = STATE(6164),
    [sym_logical_expression] = STATE(6164),
    [sym_ternary_expression] = STATE(6164),
    [sym_unary_expression] = STATE(6164),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6164),
    [sym_list_literal] = STATE(6164),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6164),
    [sym__literal_value] = STATE(6164),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8513),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8515),
    [sym_date_literal] = ACTIONS(8513),
    [sym_time_literal] = ACTIONS(8513),
    [sym_biginteger_literal] = ACTIONS(8515),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8515),
    [sym_integer] = ACTIONS(8513),
    [sym_continue_as_identifier] = ACTIONS(8515),
  },
  [STATE(3227)] = {
    [sym_boolean] = STATE(6165),
    [sym_assignment_expression] = STATE(6165),
    [sym__expression] = STATE(6165),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6165),
    [sym_multiplicative_expression] = STATE(6165),
    [sym_additive_expression] = STATE(6165),
    [sym_comparison_expression] = STATE(6165),
    [sym_logical_expression] = STATE(6165),
    [sym_ternary_expression] = STATE(6165),
    [sym_unary_expression] = STATE(6165),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6165),
    [sym_list_literal] = STATE(6165),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6165),
    [sym__literal_value] = STATE(6165),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8517),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8519),
    [sym_date_literal] = ACTIONS(8517),
    [sym_time_literal] = ACTIONS(8517),
    [sym_biginteger_literal] = ACTIONS(8519),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8519),
    [sym_integer] = ACTIONS(8517),
    [sym_continue_as_identifier] = ACTIONS(8519),
  },
  [STATE(3228)] = {
    [sym_identifier] = ACTIONS(4383),
    [anon_sym_SEMI] = ACTIONS(8521),
    [aux_sym_where_condition_token1] = ACTIONS(4383),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4383),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4383),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_basic_type_token6] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_basic_type_token53] = ACTIONS(4383),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4383),
    [aux_sym_addafter_modification_token1] = ACTIONS(4383),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4383),
    [aux_sym_modify_modification_token1] = ACTIONS(4383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4383),
    [aux_sym_movelast_modification_token1] = ACTIONS(4383),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4383),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4383),
    [aux_sym_separator_action_token1] = ACTIONS(4383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4383),
    [aux_sym_type_declaration_token1] = ACTIONS(4383),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [anon_sym_POUNDelif] = ACTIONS(4387),
    [anon_sym_POUNDELIF] = ACTIONS(4387),
    [anon_sym_POUNDElif] = ACTIONS(4387),
    [anon_sym_POUNDelse] = ACTIONS(4387),
    [anon_sym_POUNDELSE] = ACTIONS(4387),
    [anon_sym_POUNDElse] = ACTIONS(4387),
    [anon_sym_POUNDendif] = ACTIONS(4387),
    [anon_sym_POUNDENDIF] = ACTIONS(4387),
    [anon_sym_POUNDEndif] = ACTIONS(4387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4383),
    [sym_trigger_keyword] = ACTIONS(4383),
    [sym_var_keyword] = ACTIONS(4383),
    [sym_local_keyword] = ACTIONS(4383),
    [sym_internal_keyword] = ACTIONS(4383),
    [sym_protected_keyword] = ACTIONS(4383),
    [sym_event_keyword] = ACTIONS(4383),
    [sym_fields_keyword] = ACTIONS(4383),
    [sym_keys_keyword] = ACTIONS(4383),
    [sym_key_keyword] = ACTIONS(4383),
    [sym_fieldgroups_keyword] = ACTIONS(4383),
    [sym_actions_keyword] = ACTIONS(4383),
    [sym_layout_keyword] = ACTIONS(4383),
    [sym_area_keyword] = ACTIONS(4383),
    [sym_group_keyword] = ACTIONS(4383),
    [sym_repeater_keyword] = ACTIONS(4383),
    [sym_cuegroup_keyword] = ACTIONS(4383),
    [sym_fixed_keyword] = ACTIONS(4383),
    [sym_grid_keyword] = ACTIONS(4383),
    [sym_part_keyword] = ACTIONS(4383),
    [sym_systempart_keyword] = ACTIONS(4383),
    [sym_usercontrol_keyword] = ACTIONS(4383),
    [sym_dataset_keyword] = ACTIONS(4383),
    [sym_elements_keyword] = ACTIONS(4383),
    [sym_dataitem_keyword] = ACTIONS(4383),
    [sym_column_keyword] = ACTIONS(4383),
    [sym_filter_keyword] = ACTIONS(4383),
    [sym_labels_keyword] = ACTIONS(4383),
    [sym_rendering_keyword] = ACTIONS(4383),
    [sym_requestpage_keyword] = ACTIONS(4383),
    [sym_schema_keyword] = ACTIONS(4383),
    [sym_views_keyword] = ACTIONS(4383),
    [sym_quoted_identifier] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
    [sym_preproc_close] = ACTIONS(4387),
    [sym_var_attribute_open] = ACTIONS(4387),
  },
  [STATE(3229)] = {
    [sym_boolean] = STATE(1166),
    [sym_assignment_expression] = STATE(1166),
    [sym__expression] = STATE(1166),
    [sym_keyword_identifier] = STATE(1169),
    [sym_range_expression] = STATE(1166),
    [sym_multiplicative_expression] = STATE(1166),
    [sym_additive_expression] = STATE(1166),
    [sym_comparison_expression] = STATE(1166),
    [sym_logical_expression] = STATE(1166),
    [sym_ternary_expression] = STATE(1166),
    [sym_unary_expression] = STATE(1166),
    [sym_call_expression] = STATE(1205),
    [sym_member_expression] = STATE(1169),
    [sym_subscript_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1166),
    [sym_list_literal] = STATE(1166),
    [sym_qualified_enum_value] = STATE(1169),
    [sym_database_reference] = STATE(1166),
    [sym__literal_value] = STATE(1166),
    [sym_codeunit_keyword] = STATE(1208),
    [sym_xmlport_keyword] = STATE(1208),
    [sym_enum_keyword] = STATE(1157),
    [sym_identifier] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(636),
    [aux_sym_boolean_token1] = ACTIONS(638),
    [aux_sym_boolean_token2] = ACTIONS(638),
    [sym_decimal] = ACTIONS(8523),
    [anon_sym_LPAREN] = ACTIONS(642),
    [aux_sym_tabledata_permission_token2] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(646),
    [aux_sym_record_type_token1] = ACTIONS(644),
    [aux_sym_basic_type_token21] = ACTIONS(644),
    [aux_sym_basic_type_token22] = ACTIONS(644),
    [aux_sym_basic_type_token48] = ACTIONS(644),
    [anon_sym_not] = ACTIONS(652),
    [anon_sym_NOT] = ACTIONS(652),
    [anon_sym_Not] = ACTIONS(652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(644),
    [aux_sym_keyword_identifier_token2] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(636),
    [sym_datetime_literal] = ACTIONS(8525),
    [sym_date_literal] = ACTIONS(8523),
    [sym_time_literal] = ACTIONS(8523),
    [sym_biginteger_literal] = ACTIONS(8525),
    [sym_page_keyword] = ACTIONS(654),
    [anon_sym_codeunit] = ACTIONS(666),
    [anon_sym_CODEUNIT] = ACTIONS(666),
    [anon_sym_Codeunit] = ACTIONS(666),
    [anon_sym_CodeUnit] = ACTIONS(666),
    [anon_sym_COdeunit] = ACTIONS(666),
    [anon_sym_codeUnit] = ACTIONS(666),
    [sym_report_keyword] = ACTIONS(654),
    [sym_query_keyword] = ACTIONS(654),
    [anon_sym_xmlport] = ACTIONS(668),
    [anon_sym_XMLPORT] = ACTIONS(668),
    [anon_sym_Xmlport] = ACTIONS(668),
    [anon_sym_XMLport] = ACTIONS(668),
    [anon_sym_XMLPort] = ACTIONS(668),
    [anon_sym_XmlPort] = ACTIONS(668),
    [anon_sym_enum] = ACTIONS(670),
    [anon_sym_ENUM] = ACTIONS(670),
    [anon_sym_Enum] = ACTIONS(670),
    [anon_sym_eNUM] = ACTIONS(670),
    [anon_sym_eNum] = ACTIONS(670),
    [anon_sym_ENum] = ACTIONS(670),
    [sym_quoted_identifier] = ACTIONS(672),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8525),
    [sym_integer] = ACTIONS(8523),
    [sym_continue_as_identifier] = ACTIONS(8525),
  },
  [STATE(3230)] = {
    [sym_boolean] = STATE(6166),
    [sym_assignment_expression] = STATE(6166),
    [sym__expression] = STATE(6166),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6166),
    [sym_multiplicative_expression] = STATE(6166),
    [sym_additive_expression] = STATE(6166),
    [sym_comparison_expression] = STATE(6166),
    [sym_logical_expression] = STATE(6166),
    [sym_ternary_expression] = STATE(6166),
    [sym_unary_expression] = STATE(6166),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6166),
    [sym_list_literal] = STATE(6166),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6166),
    [sym__literal_value] = STATE(6166),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8527),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8529),
    [sym_date_literal] = ACTIONS(8527),
    [sym_time_literal] = ACTIONS(8527),
    [sym_biginteger_literal] = ACTIONS(8529),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8529),
    [sym_integer] = ACTIONS(8527),
    [sym_continue_as_identifier] = ACTIONS(8529),
  },
  [STATE(3231)] = {
    [sym_boolean] = STATE(6167),
    [sym_assignment_expression] = STATE(6167),
    [sym__expression] = STATE(6167),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6167),
    [sym_multiplicative_expression] = STATE(6167),
    [sym_additive_expression] = STATE(6167),
    [sym_comparison_expression] = STATE(6167),
    [sym_logical_expression] = STATE(6167),
    [sym_ternary_expression] = STATE(6167),
    [sym_unary_expression] = STATE(6167),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6167),
    [sym_list_literal] = STATE(6167),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6167),
    [sym__literal_value] = STATE(6167),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8531),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8533),
    [sym_date_literal] = ACTIONS(8531),
    [sym_time_literal] = ACTIONS(8531),
    [sym_biginteger_literal] = ACTIONS(8533),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8533),
    [sym_integer] = ACTIONS(8531),
    [sym_continue_as_identifier] = ACTIONS(8533),
  },
  [STATE(3232)] = {
    [sym_boolean] = STATE(6168),
    [sym_assignment_expression] = STATE(6168),
    [sym__expression] = STATE(6168),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6168),
    [sym_multiplicative_expression] = STATE(6168),
    [sym_additive_expression] = STATE(6168),
    [sym_comparison_expression] = STATE(6168),
    [sym_logical_expression] = STATE(6168),
    [sym_ternary_expression] = STATE(6168),
    [sym_unary_expression] = STATE(6168),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6168),
    [sym_list_literal] = STATE(6168),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6168),
    [sym__literal_value] = STATE(6168),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8535),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8537),
    [sym_date_literal] = ACTIONS(8535),
    [sym_time_literal] = ACTIONS(8535),
    [sym_biginteger_literal] = ACTIONS(8537),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8537),
    [sym_integer] = ACTIONS(8535),
    [sym_continue_as_identifier] = ACTIONS(8537),
  },
  [STATE(3233)] = {
    [sym_boolean] = STATE(6169),
    [sym_assignment_expression] = STATE(6169),
    [sym__expression] = STATE(6169),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6169),
    [sym_multiplicative_expression] = STATE(6169),
    [sym_additive_expression] = STATE(6169),
    [sym_comparison_expression] = STATE(6169),
    [sym_logical_expression] = STATE(6169),
    [sym_ternary_expression] = STATE(6169),
    [sym_unary_expression] = STATE(6169),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6169),
    [sym_list_literal] = STATE(6169),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6169),
    [sym__literal_value] = STATE(6169),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8539),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8541),
    [sym_date_literal] = ACTIONS(8539),
    [sym_time_literal] = ACTIONS(8539),
    [sym_biginteger_literal] = ACTIONS(8541),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8541),
    [sym_integer] = ACTIONS(8539),
    [sym_continue_as_identifier] = ACTIONS(8541),
  },
  [STATE(3234)] = {
    [sym_boolean] = STATE(6170),
    [sym_assignment_expression] = STATE(6170),
    [sym__expression] = STATE(6170),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6170),
    [sym_multiplicative_expression] = STATE(6170),
    [sym_additive_expression] = STATE(6170),
    [sym_comparison_expression] = STATE(6170),
    [sym_logical_expression] = STATE(6170),
    [sym_ternary_expression] = STATE(6170),
    [sym_unary_expression] = STATE(6170),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6170),
    [sym_list_literal] = STATE(6170),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6170),
    [sym__literal_value] = STATE(6170),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8543),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8545),
    [sym_date_literal] = ACTIONS(8543),
    [sym_time_literal] = ACTIONS(8543),
    [sym_biginteger_literal] = ACTIONS(8545),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8545),
    [sym_integer] = ACTIONS(8543),
    [sym_continue_as_identifier] = ACTIONS(8545),
  },
  [STATE(3235)] = {
    [sym_boolean] = STATE(6022),
    [sym_assignment_expression] = STATE(6022),
    [sym__expression] = STATE(6022),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6022),
    [sym_multiplicative_expression] = STATE(6022),
    [sym_additive_expression] = STATE(6022),
    [sym_comparison_expression] = STATE(6022),
    [sym_logical_expression] = STATE(6022),
    [sym_ternary_expression] = STATE(6022),
    [sym_unary_expression] = STATE(6022),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6022),
    [sym_list_literal] = STATE(6022),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6022),
    [sym__literal_value] = STATE(6022),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8547),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(8549),
    [sym_date_literal] = ACTIONS(8547),
    [sym_time_literal] = ACTIONS(8547),
    [sym_biginteger_literal] = ACTIONS(8549),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8549),
    [sym_integer] = ACTIONS(8547),
    [sym_continue_as_identifier] = ACTIONS(8549),
  },
  [STATE(3236)] = {
    [sym_boolean] = STATE(6172),
    [sym_assignment_expression] = STATE(6172),
    [sym__expression] = STATE(6172),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6172),
    [sym_multiplicative_expression] = STATE(6172),
    [sym_additive_expression] = STATE(6172),
    [sym_comparison_expression] = STATE(6172),
    [sym_logical_expression] = STATE(6172),
    [sym_ternary_expression] = STATE(6172),
    [sym_unary_expression] = STATE(6172),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6172),
    [sym_list_literal] = STATE(6172),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6172),
    [sym__literal_value] = STATE(6172),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8551),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8553),
    [sym_date_literal] = ACTIONS(8551),
    [sym_time_literal] = ACTIONS(8551),
    [sym_biginteger_literal] = ACTIONS(8553),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8553),
    [sym_integer] = ACTIONS(8551),
    [sym_continue_as_identifier] = ACTIONS(8553),
  },
  [STATE(3237)] = {
    [sym_boolean] = STATE(6173),
    [sym_assignment_expression] = STATE(6173),
    [sym__expression] = STATE(6173),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6173),
    [sym_multiplicative_expression] = STATE(6173),
    [sym_additive_expression] = STATE(6173),
    [sym_comparison_expression] = STATE(6173),
    [sym_logical_expression] = STATE(6173),
    [sym_ternary_expression] = STATE(6173),
    [sym_unary_expression] = STATE(6173),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6173),
    [sym_list_literal] = STATE(6173),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6173),
    [sym__literal_value] = STATE(6173),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8555),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8557),
    [sym_date_literal] = ACTIONS(8555),
    [sym_time_literal] = ACTIONS(8555),
    [sym_biginteger_literal] = ACTIONS(8557),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8557),
    [sym_integer] = ACTIONS(8555),
    [sym_continue_as_identifier] = ACTIONS(8557),
  },
  [STATE(3238)] = {
    [sym_boolean] = STATE(6174),
    [sym_assignment_expression] = STATE(6174),
    [sym__expression] = STATE(6174),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6174),
    [sym_multiplicative_expression] = STATE(6174),
    [sym_additive_expression] = STATE(6174),
    [sym_comparison_expression] = STATE(6174),
    [sym_logical_expression] = STATE(6174),
    [sym_ternary_expression] = STATE(6174),
    [sym_unary_expression] = STATE(6174),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6174),
    [sym_list_literal] = STATE(6174),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6174),
    [sym__literal_value] = STATE(6174),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8559),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8561),
    [sym_date_literal] = ACTIONS(8559),
    [sym_time_literal] = ACTIONS(8559),
    [sym_biginteger_literal] = ACTIONS(8561),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8561),
    [sym_integer] = ACTIONS(8559),
    [sym_continue_as_identifier] = ACTIONS(8561),
  },
  [STATE(3239)] = {
    [sym_boolean] = STATE(6138),
    [sym_assignment_expression] = STATE(6138),
    [sym__expression] = STATE(6138),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6138),
    [sym_multiplicative_expression] = STATE(6138),
    [sym_additive_expression] = STATE(6138),
    [sym_comparison_expression] = STATE(6138),
    [sym_logical_expression] = STATE(6138),
    [sym_ternary_expression] = STATE(6138),
    [sym_unary_expression] = STATE(6138),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6138),
    [sym_list_literal] = STATE(6138),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6138),
    [sym__literal_value] = STATE(6138),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8563),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(8565),
    [sym_date_literal] = ACTIONS(8563),
    [sym_time_literal] = ACTIONS(8563),
    [sym_biginteger_literal] = ACTIONS(8565),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8565),
    [sym_integer] = ACTIONS(8563),
    [sym_continue_as_identifier] = ACTIONS(8565),
  },
  [STATE(3240)] = {
    [sym_boolean] = STATE(6023),
    [sym_assignment_expression] = STATE(6023),
    [sym__expression] = STATE(6023),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6023),
    [sym_multiplicative_expression] = STATE(6023),
    [sym_additive_expression] = STATE(6023),
    [sym_comparison_expression] = STATE(6023),
    [sym_logical_expression] = STATE(6023),
    [sym_ternary_expression] = STATE(6023),
    [sym_unary_expression] = STATE(6023),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6023),
    [sym_list_literal] = STATE(6023),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6023),
    [sym__literal_value] = STATE(6023),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8567),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(8569),
    [sym_date_literal] = ACTIONS(8567),
    [sym_time_literal] = ACTIONS(8567),
    [sym_biginteger_literal] = ACTIONS(8569),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8569),
    [sym_integer] = ACTIONS(8567),
    [sym_continue_as_identifier] = ACTIONS(8569),
  },
  [STATE(3241)] = {
    [sym_boolean] = STATE(6024),
    [sym_assignment_expression] = STATE(6024),
    [sym__expression] = STATE(6024),
    [sym_keyword_identifier] = STATE(5923),
    [sym_range_expression] = STATE(6024),
    [sym_multiplicative_expression] = STATE(6024),
    [sym_additive_expression] = STATE(6024),
    [sym_comparison_expression] = STATE(6024),
    [sym_logical_expression] = STATE(6024),
    [sym_ternary_expression] = STATE(6024),
    [sym_unary_expression] = STATE(6024),
    [sym_call_expression] = STATE(6212),
    [sym_member_expression] = STATE(5923),
    [sym_subscript_expression] = STATE(5923),
    [sym_parenthesized_expression] = STATE(6024),
    [sym_list_literal] = STATE(6024),
    [sym_qualified_enum_value] = STATE(5923),
    [sym_database_reference] = STATE(6024),
    [sym__literal_value] = STATE(6024),
    [sym_codeunit_keyword] = STATE(6044),
    [sym_xmlport_keyword] = STATE(6044),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(909),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8571),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(921),
    [anon_sym_NOT] = ACTIONS(921),
    [anon_sym_Not] = ACTIONS(921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(909),
    [sym_datetime_literal] = ACTIONS(8573),
    [sym_date_literal] = ACTIONS(8571),
    [sym_time_literal] = ACTIONS(8571),
    [sym_biginteger_literal] = ACTIONS(8573),
    [sym_page_keyword] = ACTIONS(923),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(923),
    [sym_query_keyword] = ACTIONS(923),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8573),
    [sym_integer] = ACTIONS(8571),
    [sym_continue_as_identifier] = ACTIONS(8573),
  },
  [STATE(3242)] = {
    [sym_identifier] = ACTIONS(4383),
    [anon_sym_SEMI] = ACTIONS(4387),
    [aux_sym_where_condition_token1] = ACTIONS(4383),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4383),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4383),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_basic_type_token6] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_basic_type_token53] = ACTIONS(4383),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4383),
    [aux_sym_addafter_modification_token1] = ACTIONS(4383),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4383),
    [aux_sym_modify_modification_token1] = ACTIONS(4383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4383),
    [aux_sym_movelast_modification_token1] = ACTIONS(4383),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4383),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4383),
    [aux_sym_separator_action_token1] = ACTIONS(4383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4383),
    [aux_sym_type_declaration_token1] = ACTIONS(4383),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [anon_sym_POUNDelif] = ACTIONS(4387),
    [anon_sym_POUNDELIF] = ACTIONS(4387),
    [anon_sym_POUNDElif] = ACTIONS(4387),
    [anon_sym_POUNDelse] = ACTIONS(4387),
    [anon_sym_POUNDELSE] = ACTIONS(4387),
    [anon_sym_POUNDElse] = ACTIONS(4387),
    [anon_sym_POUNDendif] = ACTIONS(4387),
    [anon_sym_POUNDENDIF] = ACTIONS(4387),
    [anon_sym_POUNDEndif] = ACTIONS(4387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4383),
    [sym_trigger_keyword] = ACTIONS(4383),
    [sym_var_keyword] = ACTIONS(4383),
    [sym_local_keyword] = ACTIONS(4383),
    [sym_internal_keyword] = ACTIONS(4383),
    [sym_protected_keyword] = ACTIONS(4383),
    [sym_event_keyword] = ACTIONS(4383),
    [sym_fields_keyword] = ACTIONS(4383),
    [sym_keys_keyword] = ACTIONS(4383),
    [sym_key_keyword] = ACTIONS(4383),
    [sym_fieldgroups_keyword] = ACTIONS(4383),
    [sym_actions_keyword] = ACTIONS(4383),
    [sym_layout_keyword] = ACTIONS(4383),
    [sym_area_keyword] = ACTIONS(4383),
    [sym_group_keyword] = ACTIONS(4383),
    [sym_repeater_keyword] = ACTIONS(4383),
    [sym_cuegroup_keyword] = ACTIONS(4383),
    [sym_fixed_keyword] = ACTIONS(4383),
    [sym_grid_keyword] = ACTIONS(4383),
    [sym_part_keyword] = ACTIONS(4383),
    [sym_systempart_keyword] = ACTIONS(4383),
    [sym_usercontrol_keyword] = ACTIONS(4383),
    [sym_dataset_keyword] = ACTIONS(4383),
    [sym_elements_keyword] = ACTIONS(4383),
    [sym_dataitem_keyword] = ACTIONS(4383),
    [sym_column_keyword] = ACTIONS(4383),
    [sym_filter_keyword] = ACTIONS(4383),
    [sym_labels_keyword] = ACTIONS(4383),
    [sym_rendering_keyword] = ACTIONS(4383),
    [sym_requestpage_keyword] = ACTIONS(4383),
    [sym_schema_keyword] = ACTIONS(4383),
    [sym_views_keyword] = ACTIONS(4383),
    [sym_quoted_identifier] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
    [sym_preproc_close] = ACTIONS(4387),
    [sym_var_attribute_open] = ACTIONS(4387),
  },
  [STATE(3243)] = {
    [sym_boolean] = STATE(6337),
    [sym_assignment_expression] = STATE(6337),
    [sym__expression] = STATE(6337),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6337),
    [sym_multiplicative_expression] = STATE(6337),
    [sym_additive_expression] = STATE(6337),
    [sym_comparison_expression] = STATE(6337),
    [sym_logical_expression] = STATE(6337),
    [sym_ternary_expression] = STATE(6337),
    [sym_unary_expression] = STATE(6337),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(6253),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6337),
    [sym_list_literal] = STATE(6337),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6337),
    [sym__literal_value] = STATE(6337),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(8575),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8169),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8171),
    [sym_date_literal] = ACTIONS(8169),
    [sym_time_literal] = ACTIONS(8169),
    [sym_biginteger_literal] = ACTIONS(8171),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8577),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8171),
    [sym_integer] = ACTIONS(8169),
    [sym_continue_as_identifier] = ACTIONS(8171),
  },
  [STATE(3244)] = {
    [sym_boolean] = STATE(6337),
    [sym_assignment_expression] = STATE(6337),
    [sym__expression] = STATE(6337),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6337),
    [sym_multiplicative_expression] = STATE(6337),
    [sym_additive_expression] = STATE(6337),
    [sym_comparison_expression] = STATE(6337),
    [sym_logical_expression] = STATE(6337),
    [sym_ternary_expression] = STATE(6337),
    [sym_unary_expression] = STATE(6337),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(6255),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6337),
    [sym_list_literal] = STATE(6337),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6337),
    [sym__literal_value] = STATE(6337),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(8579),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8169),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8171),
    [sym_date_literal] = ACTIONS(8169),
    [sym_time_literal] = ACTIONS(8169),
    [sym_biginteger_literal] = ACTIONS(8171),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8581),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8171),
    [sym_integer] = ACTIONS(8169),
    [sym_continue_as_identifier] = ACTIONS(8171),
  },
  [STATE(3245)] = {
    [sym_boolean] = STATE(6337),
    [sym_assignment_expression] = STATE(6337),
    [sym__expression] = STATE(6337),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6337),
    [sym_multiplicative_expression] = STATE(6337),
    [sym_additive_expression] = STATE(6337),
    [sym_comparison_expression] = STATE(6337),
    [sym_logical_expression] = STATE(6337),
    [sym_ternary_expression] = STATE(6337),
    [sym_unary_expression] = STATE(6337),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(6258),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6337),
    [sym_list_literal] = STATE(6337),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6337),
    [sym__literal_value] = STATE(6337),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(8583),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8169),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8171),
    [sym_date_literal] = ACTIONS(8169),
    [sym_time_literal] = ACTIONS(8169),
    [sym_biginteger_literal] = ACTIONS(8171),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8585),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8171),
    [sym_integer] = ACTIONS(8169),
    [sym_continue_as_identifier] = ACTIONS(8171),
  },
  [STATE(3246)] = {
    [sym_boolean] = STATE(6337),
    [sym_assignment_expression] = STATE(6337),
    [sym__expression] = STATE(6337),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6337),
    [sym_multiplicative_expression] = STATE(6337),
    [sym_additive_expression] = STATE(6337),
    [sym_comparison_expression] = STATE(6337),
    [sym_logical_expression] = STATE(6337),
    [sym_ternary_expression] = STATE(6337),
    [sym_unary_expression] = STATE(6337),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(6260),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6337),
    [sym_list_literal] = STATE(6337),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6337),
    [sym__literal_value] = STATE(6337),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(8587),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8169),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8171),
    [sym_date_literal] = ACTIONS(8169),
    [sym_time_literal] = ACTIONS(8169),
    [sym_biginteger_literal] = ACTIONS(8171),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8589),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8171),
    [sym_integer] = ACTIONS(8169),
    [sym_continue_as_identifier] = ACTIONS(8171),
  },
  [STATE(3247)] = {
    [sym_boolean] = STATE(6337),
    [sym_assignment_expression] = STATE(6337),
    [sym__expression] = STATE(6337),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6337),
    [sym_multiplicative_expression] = STATE(6337),
    [sym_additive_expression] = STATE(6337),
    [sym_comparison_expression] = STATE(6337),
    [sym_logical_expression] = STATE(6337),
    [sym_ternary_expression] = STATE(6337),
    [sym_unary_expression] = STATE(6337),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(6261),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6337),
    [sym_list_literal] = STATE(6337),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6337),
    [sym__literal_value] = STATE(6337),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(8591),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8169),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8171),
    [sym_date_literal] = ACTIONS(8169),
    [sym_time_literal] = ACTIONS(8169),
    [sym_biginteger_literal] = ACTIONS(8171),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8593),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8171),
    [sym_integer] = ACTIONS(8169),
    [sym_continue_as_identifier] = ACTIONS(8171),
  },
  [STATE(3248)] = {
    [sym_boolean] = STATE(6201),
    [sym_assignment_expression] = STATE(6201),
    [sym__expression] = STATE(6201),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6201),
    [sym_multiplicative_expression] = STATE(6201),
    [sym_additive_expression] = STATE(6201),
    [sym_comparison_expression] = STATE(6201),
    [sym_logical_expression] = STATE(6201),
    [sym_ternary_expression] = STATE(6201),
    [sym_unary_expression] = STATE(6201),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6201),
    [sym_list_literal] = STATE(6201),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6201),
    [sym__literal_value] = STATE(6201),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8595),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8597),
    [sym_date_literal] = ACTIONS(8595),
    [sym_time_literal] = ACTIONS(8595),
    [sym_biginteger_literal] = ACTIONS(8597),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8597),
    [sym_integer] = ACTIONS(8595),
    [sym_continue_as_identifier] = ACTIONS(8597),
  },
  [STATE(3249)] = {
    [sym_boolean] = STATE(6202),
    [sym_assignment_expression] = STATE(6202),
    [sym__expression] = STATE(6202),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6202),
    [sym_multiplicative_expression] = STATE(6202),
    [sym_additive_expression] = STATE(6202),
    [sym_comparison_expression] = STATE(6202),
    [sym_logical_expression] = STATE(6202),
    [sym_ternary_expression] = STATE(6202),
    [sym_unary_expression] = STATE(6202),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6202),
    [sym_list_literal] = STATE(6202),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6202),
    [sym__literal_value] = STATE(6202),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8599),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8601),
    [sym_date_literal] = ACTIONS(8599),
    [sym_time_literal] = ACTIONS(8599),
    [sym_biginteger_literal] = ACTIONS(8601),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8601),
    [sym_integer] = ACTIONS(8599),
    [sym_continue_as_identifier] = ACTIONS(8601),
  },
  [STATE(3250)] = {
    [sym_boolean] = STATE(6203),
    [sym_assignment_expression] = STATE(6203),
    [sym__expression] = STATE(6203),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6203),
    [sym_multiplicative_expression] = STATE(6203),
    [sym_additive_expression] = STATE(6203),
    [sym_comparison_expression] = STATE(6203),
    [sym_logical_expression] = STATE(6203),
    [sym_ternary_expression] = STATE(6203),
    [sym_unary_expression] = STATE(6203),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6203),
    [sym_list_literal] = STATE(6203),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6203),
    [sym__literal_value] = STATE(6203),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(3056),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8603),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(3070),
    [anon_sym_NOT] = ACTIONS(3070),
    [anon_sym_Not] = ACTIONS(3070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(3056),
    [sym_datetime_literal] = ACTIONS(8605),
    [sym_date_literal] = ACTIONS(8603),
    [sym_time_literal] = ACTIONS(8603),
    [sym_biginteger_literal] = ACTIONS(8605),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8605),
    [sym_integer] = ACTIONS(8603),
    [sym_continue_as_identifier] = ACTIONS(8605),
  },
  [STATE(3251)] = {
    [sym_boolean] = STATE(6300),
    [sym_assignment_expression] = STATE(6300),
    [sym__expression] = STATE(6300),
    [sym_keyword_identifier] = STATE(4801),
    [sym_range_expression] = STATE(6300),
    [sym_multiplicative_expression] = STATE(6300),
    [sym_additive_expression] = STATE(6300),
    [sym_comparison_expression] = STATE(6300),
    [sym_logical_expression] = STATE(6300),
    [sym_ternary_expression] = STATE(6300),
    [sym_unary_expression] = STATE(6300),
    [sym_call_expression] = STATE(4872),
    [sym_member_expression] = STATE(4801),
    [sym_subscript_expression] = STATE(4801),
    [sym_parenthesized_expression] = STATE(6300),
    [sym_list_literal] = STATE(6300),
    [sym_qualified_enum_value] = STATE(4801),
    [sym_database_reference] = STATE(6300),
    [sym__literal_value] = STATE(6300),
    [sym_codeunit_keyword] = STATE(4836),
    [sym_xmlport_keyword] = STATE(4836),
    [sym_enum_keyword] = STATE(4642),
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_DASH] = ACTIONS(2229),
    [aux_sym_boolean_token1] = ACTIONS(911),
    [aux_sym_boolean_token2] = ACTIONS(911),
    [sym_decimal] = ACTIONS(8607),
    [anon_sym_LPAREN] = ACTIONS(915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [aux_sym_record_type_token1] = ACTIONS(917),
    [aux_sym_basic_type_token21] = ACTIONS(917),
    [aux_sym_basic_type_token22] = ACTIONS(917),
    [aux_sym_basic_type_token48] = ACTIONS(917),
    [anon_sym_not] = ACTIONS(2225),
    [anon_sym_NOT] = ACTIONS(2225),
    [anon_sym_Not] = ACTIONS(2225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(2227),
    [anon_sym_PLUS] = ACTIONS(2229),
    [sym_datetime_literal] = ACTIONS(8609),
    [sym_date_literal] = ACTIONS(8607),
    [sym_time_literal] = ACTIONS(8607),
    [sym_biginteger_literal] = ACTIONS(8609),
    [sym_page_keyword] = ACTIONS(2227),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(2227),
    [sym_query_keyword] = ACTIONS(2227),
    [anon_sym_xmlport] = ACTIONS(937),
    [anon_sym_XMLPORT] = ACTIONS(937),
    [anon_sym_Xmlport] = ACTIONS(937),
    [anon_sym_XMLport] = ACTIONS(937),
    [anon_sym_XMLPort] = ACTIONS(937),
    [anon_sym_XmlPort] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8609),
    [sym_integer] = ACTIONS(8607),
    [sym_continue_as_identifier] = ACTIONS(8609),
  },
  [STATE(3252)] = {
    [sym__body_element] = STATE(2729),
    [sym_empty_statement] = STATE(2729),
    [sym_property] = STATE(2729),
    [sym_fields_section] = STATE(2729),
    [sym_keys_section] = STATE(2729),
    [sym_fieldgroups_section] = STATE(2729),
    [sym_enum_value_declaration] = STATE(2729),
    [sym_labels_section] = STATE(2729),
    [sym_layout_section] = STATE(2729),
    [sym_modify_modification] = STATE(2729),
    [sym_actions_section] = STATE(2729),
    [sym_views_section] = STATE(2729),
    [sym_dataset_section] = STATE(2729),
    [sym_report_dataitem] = STATE(2729),
    [sym__report_body_element] = STATE(2729),
    [sym_preproc_conditional_report] = STATE(2729),
    [sym_report_column] = STATE(2729),
    [sym_requestpage_section] = STATE(2729),
    [sym_rendering_section] = STATE(2729),
    [sym_elements_section] = STATE(2729),
    [sym_schema_section] = STATE(2729),
    [sym_assembly_declaration] = STATE(2729),
    [sym_event_declaration] = STATE(2729),
    [sym_procedure] = STATE(2729),
    [sym_preproc_split_procedure] = STATE(2729),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2729),
    [sym_var_section] = STATE(2729),
    [sym_attribute_item] = STATE(2729),
    [sym_preproc_conditional] = STATE(2729),
    [sym_preproc_if] = STATE(2557),
    [sym_preproc_endif] = STATE(6849),
    [aux_sym_report_dataitem_repeat1] = STATE(2729),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3253)] = {
    [sym_preproc_split_procedure] = STATE(3263),
    [sym_var_attribute_item] = STATE(3263),
    [sym_preproc_conditional_var] = STATE(3263),
    [sym_variable_declaration] = STATE(3263),
    [sym_preproc_if] = STATE(2420),
    [sym__identifier_or_quoted] = STATE(10406),
    [sym_keyword_as_identifier] = STATE(10406),
    [aux_sym_var_section_repeat1] = STATE(3263),
    [sym_identifier] = ACTIONS(8611),
    [anon_sym_SEMI] = ACTIONS(6255),
    [anon_sym_RBRACE] = ACTIONS(6255),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6257),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6257),
    [anon_sym_LBRACK] = ACTIONS(6255),
    [aux_sym_basic_type_token6] = ACTIONS(6257),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_addafter_modification_token1] = ACTIONS(6257),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6257),
    [aux_sym_modify_modification_token1] = ACTIONS(6257),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6257),
    [aux_sym_movelast_modification_token1] = ACTIONS(6257),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6257),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6257),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6257),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(6259),
    [anon_sym_POUNDIF] = ACTIONS(6259),
    [anon_sym_POUNDIf] = ACTIONS(6259),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6257),
    [sym_trigger_keyword] = ACTIONS(6257),
    [sym_var_keyword] = ACTIONS(6257),
    [sym_local_keyword] = ACTIONS(6257),
    [sym_internal_keyword] = ACTIONS(6257),
    [sym_protected_keyword] = ACTIONS(6257),
    [sym_event_keyword] = ACTIONS(6257),
    [sym_fields_keyword] = ACTIONS(6257),
    [sym_keys_keyword] = ACTIONS(6257),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(6257),
    [sym_actions_keyword] = ACTIONS(6257),
    [sym_layout_keyword] = ACTIONS(6257),
    [sym_area_keyword] = ACTIONS(6257),
    [sym_group_keyword] = ACTIONS(6257),
    [sym_repeater_keyword] = ACTIONS(6257),
    [sym_cuegroup_keyword] = ACTIONS(6257),
    [sym_fixed_keyword] = ACTIONS(6257),
    [sym_grid_keyword] = ACTIONS(6257),
    [sym_part_keyword] = ACTIONS(6257),
    [sym_systempart_keyword] = ACTIONS(6257),
    [sym_usercontrol_keyword] = ACTIONS(6257),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_elements_keyword] = ACTIONS(6257),
    [sym_dataitem_keyword] = ACTIONS(6257),
    [sym_column_keyword] = ACTIONS(6257),
    [sym_filter_keyword] = ACTIONS(6257),
    [sym_labels_keyword] = ACTIONS(6257),
    [sym_rendering_keyword] = ACTIONS(6257),
    [sym_requestpage_keyword] = ACTIONS(6257),
    [sym_schema_keyword] = ACTIONS(6257),
    [sym_views_keyword] = ACTIONS(6257),
    [sym_quoted_identifier] = ACTIONS(8613),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6255),
    [sym_preproc_open] = ACTIONS(6259),
    [sym_var_attribute_open] = ACTIONS(8615),
  },
  [STATE(3254)] = {
    [sym__body_element] = STATE(2729),
    [sym_empty_statement] = STATE(2729),
    [sym_property] = STATE(2729),
    [sym_fields_section] = STATE(2729),
    [sym_keys_section] = STATE(2729),
    [sym_fieldgroups_section] = STATE(2729),
    [sym_enum_value_declaration] = STATE(2729),
    [sym_labels_section] = STATE(2729),
    [sym_layout_section] = STATE(2729),
    [sym_modify_modification] = STATE(2729),
    [sym_actions_section] = STATE(2729),
    [sym_views_section] = STATE(2729),
    [sym_dataset_section] = STATE(2729),
    [sym_report_dataitem] = STATE(2729),
    [sym__report_body_element] = STATE(2729),
    [sym_preproc_conditional_report] = STATE(2729),
    [sym_report_column] = STATE(2729),
    [sym_requestpage_section] = STATE(2729),
    [sym_rendering_section] = STATE(2729),
    [sym_elements_section] = STATE(2729),
    [sym_schema_section] = STATE(2729),
    [sym_assembly_declaration] = STATE(2729),
    [sym_event_declaration] = STATE(2729),
    [sym_procedure] = STATE(2729),
    [sym_preproc_split_procedure] = STATE(2729),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2729),
    [sym_var_section] = STATE(2729),
    [sym_attribute_item] = STATE(2729),
    [sym_preproc_conditional] = STATE(2729),
    [sym_preproc_if] = STATE(2557),
    [sym_preproc_endif] = STATE(6015),
    [aux_sym_report_dataitem_repeat1] = STATE(2729),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3255)] = {
    [sym__body_element] = STATE(2729),
    [sym_empty_statement] = STATE(2729),
    [sym_property] = STATE(2729),
    [sym_fields_section] = STATE(2729),
    [sym_keys_section] = STATE(2729),
    [sym_fieldgroups_section] = STATE(2729),
    [sym_enum_value_declaration] = STATE(2729),
    [sym_labels_section] = STATE(2729),
    [sym_layout_section] = STATE(2729),
    [sym_modify_modification] = STATE(2729),
    [sym_actions_section] = STATE(2729),
    [sym_views_section] = STATE(2729),
    [sym_dataset_section] = STATE(2729),
    [sym_report_dataitem] = STATE(2729),
    [sym__report_body_element] = STATE(2729),
    [sym_preproc_conditional_report] = STATE(2729),
    [sym_report_column] = STATE(2729),
    [sym_requestpage_section] = STATE(2729),
    [sym_rendering_section] = STATE(2729),
    [sym_elements_section] = STATE(2729),
    [sym_schema_section] = STATE(2729),
    [sym_assembly_declaration] = STATE(2729),
    [sym_event_declaration] = STATE(2729),
    [sym_procedure] = STATE(2729),
    [sym_preproc_split_procedure] = STATE(2729),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2729),
    [sym_var_section] = STATE(2729),
    [sym_attribute_item] = STATE(2729),
    [sym_preproc_conditional] = STATE(2729),
    [sym_preproc_if] = STATE(2557),
    [sym_preproc_endif] = STATE(6851),
    [aux_sym_report_dataitem_repeat1] = STATE(2729),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3256)] = {
    [sym__object_header] = STATE(9540),
    [sym_preproc_if] = STATE(3459),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [anon_sym_POUNDif] = ACTIONS(8617),
    [anon_sym_POUNDIF] = ACTIONS(8617),
    [anon_sym_POUNDIf] = ACTIONS(8617),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(8617),
  },
  [STATE(3257)] = {
    [sym__body_element] = STATE(3266),
    [sym_empty_statement] = STATE(3266),
    [sym_property] = STATE(3266),
    [sym_fields_section] = STATE(3266),
    [sym_keys_section] = STATE(3266),
    [sym_fieldgroups_section] = STATE(3266),
    [sym_enum_value_declaration] = STATE(3266),
    [sym_labels_section] = STATE(3266),
    [sym_layout_section] = STATE(3266),
    [sym_modify_modification] = STATE(3266),
    [sym_actions_section] = STATE(3266),
    [sym_views_section] = STATE(3266),
    [sym_dataset_section] = STATE(3266),
    [sym_report_dataitem] = STATE(3266),
    [sym__report_body_element] = STATE(3266),
    [sym_preproc_conditional_report] = STATE(3266),
    [sym_report_column] = STATE(3266),
    [sym_requestpage_section] = STATE(3266),
    [sym_rendering_section] = STATE(3266),
    [sym_elements_section] = STATE(3266),
    [sym_schema_section] = STATE(3266),
    [sym_assembly_declaration] = STATE(3266),
    [sym_event_declaration] = STATE(3266),
    [sym_procedure] = STATE(3266),
    [sym_preproc_split_procedure] = STATE(3266),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3266),
    [sym_var_section] = STATE(3266),
    [sym_attribute_item] = STATE(3266),
    [sym_preproc_conditional] = STATE(3266),
    [sym_preproc_if] = STATE(2557),
    [sym_preproc_endif] = STATE(6849),
    [aux_sym_report_dataitem_repeat1] = STATE(3266),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3258)] = {
    [sym_preproc_split_procedure] = STATE(3269),
    [sym_var_attribute_item] = STATE(3269),
    [sym_preproc_conditional_var] = STATE(3269),
    [sym_variable_declaration] = STATE(3269),
    [sym_preproc_if] = STATE(2420),
    [sym__identifier_or_quoted] = STATE(10406),
    [sym_keyword_as_identifier] = STATE(10406),
    [aux_sym_var_section_repeat1] = STATE(3269),
    [sym_identifier] = ACTIONS(8611),
    [anon_sym_SEMI] = ACTIONS(6261),
    [anon_sym_RBRACE] = ACTIONS(6261),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6263),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6263),
    [anon_sym_LBRACK] = ACTIONS(6261),
    [aux_sym_basic_type_token6] = ACTIONS(6263),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_addafter_modification_token1] = ACTIONS(6263),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6263),
    [aux_sym_modify_modification_token1] = ACTIONS(6263),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6263),
    [aux_sym_movelast_modification_token1] = ACTIONS(6263),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6263),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6263),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6263),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(6259),
    [anon_sym_POUNDIF] = ACTIONS(6259),
    [anon_sym_POUNDIf] = ACTIONS(6259),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6263),
    [sym_trigger_keyword] = ACTIONS(6263),
    [sym_var_keyword] = ACTIONS(6263),
    [sym_local_keyword] = ACTIONS(6263),
    [sym_internal_keyword] = ACTIONS(6263),
    [sym_protected_keyword] = ACTIONS(6263),
    [sym_event_keyword] = ACTIONS(6263),
    [sym_fields_keyword] = ACTIONS(6263),
    [sym_keys_keyword] = ACTIONS(6263),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(6263),
    [sym_actions_keyword] = ACTIONS(6263),
    [sym_layout_keyword] = ACTIONS(6263),
    [sym_area_keyword] = ACTIONS(6263),
    [sym_group_keyword] = ACTIONS(6263),
    [sym_repeater_keyword] = ACTIONS(6263),
    [sym_cuegroup_keyword] = ACTIONS(6263),
    [sym_fixed_keyword] = ACTIONS(6263),
    [sym_grid_keyword] = ACTIONS(6263),
    [sym_part_keyword] = ACTIONS(6263),
    [sym_systempart_keyword] = ACTIONS(6263),
    [sym_usercontrol_keyword] = ACTIONS(6263),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_elements_keyword] = ACTIONS(6263),
    [sym_dataitem_keyword] = ACTIONS(6263),
    [sym_column_keyword] = ACTIONS(6263),
    [sym_filter_keyword] = ACTIONS(6263),
    [sym_labels_keyword] = ACTIONS(6263),
    [sym_rendering_keyword] = ACTIONS(6263),
    [sym_requestpage_keyword] = ACTIONS(6263),
    [sym_schema_keyword] = ACTIONS(6263),
    [sym_views_keyword] = ACTIONS(6263),
    [sym_quoted_identifier] = ACTIONS(8613),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6261),
    [sym_preproc_open] = ACTIONS(6259),
    [sym_var_attribute_open] = ACTIONS(8615),
  },
  [STATE(3259)] = {
    [sym__body_element] = STATE(2729),
    [sym_empty_statement] = STATE(2729),
    [sym_property] = STATE(2729),
    [sym_fields_section] = STATE(2729),
    [sym_keys_section] = STATE(2729),
    [sym_fieldgroups_section] = STATE(2729),
    [sym_enum_value_declaration] = STATE(2729),
    [sym_labels_section] = STATE(2729),
    [sym_layout_section] = STATE(2729),
    [sym_modify_modification] = STATE(2729),
    [sym_actions_section] = STATE(2729),
    [sym_views_section] = STATE(2729),
    [sym_dataset_section] = STATE(2729),
    [sym_report_dataitem] = STATE(2729),
    [sym__report_body_element] = STATE(2729),
    [sym_preproc_conditional_report] = STATE(2729),
    [sym_report_column] = STATE(2729),
    [sym_requestpage_section] = STATE(2729),
    [sym_rendering_section] = STATE(2729),
    [sym_elements_section] = STATE(2729),
    [sym_schema_section] = STATE(2729),
    [sym_assembly_declaration] = STATE(2729),
    [sym_event_declaration] = STATE(2729),
    [sym_procedure] = STATE(2729),
    [sym_preproc_split_procedure] = STATE(2729),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2729),
    [sym_var_section] = STATE(2729),
    [sym_attribute_item] = STATE(2729),
    [sym_preproc_conditional] = STATE(2729),
    [sym_preproc_if] = STATE(2557),
    [sym_preproc_endif] = STATE(6134),
    [aux_sym_report_dataitem_repeat1] = STATE(2729),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3260)] = {
    [sym__body_element] = STATE(2729),
    [sym_empty_statement] = STATE(2729),
    [sym_property] = STATE(2729),
    [sym_fields_section] = STATE(2729),
    [sym_keys_section] = STATE(2729),
    [sym_fieldgroups_section] = STATE(2729),
    [sym_enum_value_declaration] = STATE(2729),
    [sym_labels_section] = STATE(2729),
    [sym_layout_section] = STATE(2729),
    [sym_modify_modification] = STATE(2729),
    [sym_actions_section] = STATE(2729),
    [sym_views_section] = STATE(2729),
    [sym_dataset_section] = STATE(2729),
    [sym_report_dataitem] = STATE(2729),
    [sym__report_body_element] = STATE(2729),
    [sym_preproc_conditional_report] = STATE(2729),
    [sym_report_column] = STATE(2729),
    [sym_requestpage_section] = STATE(2729),
    [sym_rendering_section] = STATE(2729),
    [sym_elements_section] = STATE(2729),
    [sym_schema_section] = STATE(2729),
    [sym_assembly_declaration] = STATE(2729),
    [sym_event_declaration] = STATE(2729),
    [sym_procedure] = STATE(2729),
    [sym_preproc_split_procedure] = STATE(2729),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2729),
    [sym_var_section] = STATE(2729),
    [sym_attribute_item] = STATE(2729),
    [sym_preproc_conditional] = STATE(2729),
    [sym_preproc_if] = STATE(2557),
    [sym_preproc_endif] = STATE(6008),
    [aux_sym_report_dataitem_repeat1] = STATE(2729),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3261)] = {
    [sym__body_element] = STATE(3260),
    [sym_empty_statement] = STATE(3260),
    [sym_property] = STATE(3260),
    [sym_fields_section] = STATE(3260),
    [sym_keys_section] = STATE(3260),
    [sym_fieldgroups_section] = STATE(3260),
    [sym_enum_value_declaration] = STATE(3260),
    [sym_labels_section] = STATE(3260),
    [sym_layout_section] = STATE(3260),
    [sym_modify_modification] = STATE(3260),
    [sym_actions_section] = STATE(3260),
    [sym_views_section] = STATE(3260),
    [sym_dataset_section] = STATE(3260),
    [sym_report_dataitem] = STATE(3260),
    [sym__report_body_element] = STATE(3260),
    [sym_preproc_conditional_report] = STATE(3260),
    [sym_report_column] = STATE(3260),
    [sym_requestpage_section] = STATE(3260),
    [sym_rendering_section] = STATE(3260),
    [sym_elements_section] = STATE(3260),
    [sym_schema_section] = STATE(3260),
    [sym_assembly_declaration] = STATE(3260),
    [sym_event_declaration] = STATE(3260),
    [sym_procedure] = STATE(3260),
    [sym_preproc_split_procedure] = STATE(3260),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3260),
    [sym_var_section] = STATE(3260),
    [sym_attribute_item] = STATE(3260),
    [sym_preproc_conditional] = STATE(3260),
    [sym_preproc_if] = STATE(2557),
    [sym_preproc_endif] = STATE(6134),
    [aux_sym_report_dataitem_repeat1] = STATE(3260),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3262)] = {
    [sym__body_element] = STATE(3252),
    [sym_empty_statement] = STATE(3252),
    [sym_property] = STATE(3252),
    [sym_fields_section] = STATE(3252),
    [sym_keys_section] = STATE(3252),
    [sym_fieldgroups_section] = STATE(3252),
    [sym_enum_value_declaration] = STATE(3252),
    [sym_labels_section] = STATE(3252),
    [sym_layout_section] = STATE(3252),
    [sym_modify_modification] = STATE(3252),
    [sym_actions_section] = STATE(3252),
    [sym_views_section] = STATE(3252),
    [sym_dataset_section] = STATE(3252),
    [sym_report_dataitem] = STATE(3252),
    [sym__report_body_element] = STATE(3252),
    [sym_preproc_conditional_report] = STATE(3252),
    [sym_report_column] = STATE(3252),
    [sym_requestpage_section] = STATE(3252),
    [sym_rendering_section] = STATE(3252),
    [sym_elements_section] = STATE(3252),
    [sym_schema_section] = STATE(3252),
    [sym_assembly_declaration] = STATE(3252),
    [sym_event_declaration] = STATE(3252),
    [sym_procedure] = STATE(3252),
    [sym_preproc_split_procedure] = STATE(3252),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3252),
    [sym_var_section] = STATE(3252),
    [sym_attribute_item] = STATE(3252),
    [sym_preproc_conditional] = STATE(3252),
    [sym_preproc_if] = STATE(2557),
    [sym_preproc_endif] = STATE(6851),
    [aux_sym_report_dataitem_repeat1] = STATE(3252),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3263)] = {
    [sym_preproc_split_procedure] = STATE(3269),
    [sym_var_attribute_item] = STATE(3269),
    [sym_preproc_conditional_var] = STATE(3269),
    [sym_variable_declaration] = STATE(3269),
    [sym_preproc_if] = STATE(2420),
    [sym__identifier_or_quoted] = STATE(10406),
    [sym_keyword_as_identifier] = STATE(10406),
    [aux_sym_var_section_repeat1] = STATE(3269),
    [sym_identifier] = ACTIONS(8611),
    [anon_sym_SEMI] = ACTIONS(6265),
    [anon_sym_RBRACE] = ACTIONS(6265),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6267),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6267),
    [anon_sym_LBRACK] = ACTIONS(6265),
    [aux_sym_basic_type_token6] = ACTIONS(6267),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_addafter_modification_token1] = ACTIONS(6267),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6267),
    [aux_sym_modify_modification_token1] = ACTIONS(6267),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6267),
    [aux_sym_movelast_modification_token1] = ACTIONS(6267),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6267),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6267),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6267),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(6259),
    [anon_sym_POUNDIF] = ACTIONS(6259),
    [anon_sym_POUNDIf] = ACTIONS(6259),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6267),
    [sym_trigger_keyword] = ACTIONS(6267),
    [sym_var_keyword] = ACTIONS(6267),
    [sym_local_keyword] = ACTIONS(6267),
    [sym_internal_keyword] = ACTIONS(6267),
    [sym_protected_keyword] = ACTIONS(6267),
    [sym_event_keyword] = ACTIONS(6267),
    [sym_fields_keyword] = ACTIONS(6267),
    [sym_keys_keyword] = ACTIONS(6267),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(6267),
    [sym_actions_keyword] = ACTIONS(6267),
    [sym_layout_keyword] = ACTIONS(6267),
    [sym_area_keyword] = ACTIONS(6267),
    [sym_group_keyword] = ACTIONS(6267),
    [sym_repeater_keyword] = ACTIONS(6267),
    [sym_cuegroup_keyword] = ACTIONS(6267),
    [sym_fixed_keyword] = ACTIONS(6267),
    [sym_grid_keyword] = ACTIONS(6267),
    [sym_part_keyword] = ACTIONS(6267),
    [sym_systempart_keyword] = ACTIONS(6267),
    [sym_usercontrol_keyword] = ACTIONS(6267),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_elements_keyword] = ACTIONS(6267),
    [sym_dataitem_keyword] = ACTIONS(6267),
    [sym_column_keyword] = ACTIONS(6267),
    [sym_filter_keyword] = ACTIONS(6267),
    [sym_labels_keyword] = ACTIONS(6267),
    [sym_rendering_keyword] = ACTIONS(6267),
    [sym_requestpage_keyword] = ACTIONS(6267),
    [sym_schema_keyword] = ACTIONS(6267),
    [sym_views_keyword] = ACTIONS(6267),
    [sym_quoted_identifier] = ACTIONS(8613),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6265),
    [sym_preproc_open] = ACTIONS(6259),
    [sym_var_attribute_open] = ACTIONS(8615),
  },
  [STATE(3264)] = {
    [sym__body_element] = STATE(3254),
    [sym_empty_statement] = STATE(3254),
    [sym_property] = STATE(3254),
    [sym_fields_section] = STATE(3254),
    [sym_keys_section] = STATE(3254),
    [sym_fieldgroups_section] = STATE(3254),
    [sym_enum_value_declaration] = STATE(3254),
    [sym_labels_section] = STATE(3254),
    [sym_layout_section] = STATE(3254),
    [sym_modify_modification] = STATE(3254),
    [sym_actions_section] = STATE(3254),
    [sym_views_section] = STATE(3254),
    [sym_dataset_section] = STATE(3254),
    [sym_report_dataitem] = STATE(3254),
    [sym__report_body_element] = STATE(3254),
    [sym_preproc_conditional_report] = STATE(3254),
    [sym_report_column] = STATE(3254),
    [sym_requestpage_section] = STATE(3254),
    [sym_rendering_section] = STATE(3254),
    [sym_elements_section] = STATE(3254),
    [sym_schema_section] = STATE(3254),
    [sym_assembly_declaration] = STATE(3254),
    [sym_event_declaration] = STATE(3254),
    [sym_procedure] = STATE(3254),
    [sym_preproc_split_procedure] = STATE(3254),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3254),
    [sym_var_section] = STATE(3254),
    [sym_attribute_item] = STATE(3254),
    [sym_preproc_conditional] = STATE(3254),
    [sym_preproc_if] = STATE(2557),
    [sym_preproc_endif] = STATE(6008),
    [aux_sym_report_dataitem_repeat1] = STATE(3254),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3265)] = {
    [sym_preproc_split_procedure] = STATE(3258),
    [sym_var_attribute_item] = STATE(3258),
    [sym_preproc_conditional_var] = STATE(3258),
    [sym_variable_declaration] = STATE(3258),
    [sym_preproc_if] = STATE(2420),
    [sym__identifier_or_quoted] = STATE(10406),
    [sym_keyword_as_identifier] = STATE(10406),
    [aux_sym_var_section_repeat1] = STATE(3258),
    [sym_identifier] = ACTIONS(8611),
    [anon_sym_SEMI] = ACTIONS(6265),
    [anon_sym_RBRACE] = ACTIONS(6265),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6267),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6267),
    [anon_sym_LBRACK] = ACTIONS(6265),
    [aux_sym_basic_type_token6] = ACTIONS(6267),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_addafter_modification_token1] = ACTIONS(6267),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6267),
    [aux_sym_modify_modification_token1] = ACTIONS(6267),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6267),
    [aux_sym_movelast_modification_token1] = ACTIONS(6267),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6267),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6267),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6267),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(6259),
    [anon_sym_POUNDIF] = ACTIONS(6259),
    [anon_sym_POUNDIf] = ACTIONS(6259),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6267),
    [sym_trigger_keyword] = ACTIONS(6267),
    [sym_var_keyword] = ACTIONS(6267),
    [sym_local_keyword] = ACTIONS(6267),
    [sym_internal_keyword] = ACTIONS(6267),
    [sym_protected_keyword] = ACTIONS(6267),
    [sym_event_keyword] = ACTIONS(6267),
    [sym_fields_keyword] = ACTIONS(6267),
    [sym_keys_keyword] = ACTIONS(6267),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(6267),
    [sym_actions_keyword] = ACTIONS(6267),
    [sym_layout_keyword] = ACTIONS(6267),
    [sym_area_keyword] = ACTIONS(6267),
    [sym_group_keyword] = ACTIONS(6267),
    [sym_repeater_keyword] = ACTIONS(6267),
    [sym_cuegroup_keyword] = ACTIONS(6267),
    [sym_fixed_keyword] = ACTIONS(6267),
    [sym_grid_keyword] = ACTIONS(6267),
    [sym_part_keyword] = ACTIONS(6267),
    [sym_systempart_keyword] = ACTIONS(6267),
    [sym_usercontrol_keyword] = ACTIONS(6267),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_elements_keyword] = ACTIONS(6267),
    [sym_dataitem_keyword] = ACTIONS(6267),
    [sym_column_keyword] = ACTIONS(6267),
    [sym_filter_keyword] = ACTIONS(6267),
    [sym_labels_keyword] = ACTIONS(6267),
    [sym_rendering_keyword] = ACTIONS(6267),
    [sym_requestpage_keyword] = ACTIONS(6267),
    [sym_schema_keyword] = ACTIONS(6267),
    [sym_views_keyword] = ACTIONS(6267),
    [sym_quoted_identifier] = ACTIONS(8613),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6265),
    [sym_preproc_open] = ACTIONS(6259),
    [sym_var_attribute_open] = ACTIONS(8615),
  },
  [STATE(3266)] = {
    [sym__body_element] = STATE(2729),
    [sym_empty_statement] = STATE(2729),
    [sym_property] = STATE(2729),
    [sym_fields_section] = STATE(2729),
    [sym_keys_section] = STATE(2729),
    [sym_fieldgroups_section] = STATE(2729),
    [sym_enum_value_declaration] = STATE(2729),
    [sym_labels_section] = STATE(2729),
    [sym_layout_section] = STATE(2729),
    [sym_modify_modification] = STATE(2729),
    [sym_actions_section] = STATE(2729),
    [sym_views_section] = STATE(2729),
    [sym_dataset_section] = STATE(2729),
    [sym_report_dataitem] = STATE(2729),
    [sym__report_body_element] = STATE(2729),
    [sym_preproc_conditional_report] = STATE(2729),
    [sym_report_column] = STATE(2729),
    [sym_requestpage_section] = STATE(2729),
    [sym_rendering_section] = STATE(2729),
    [sym_elements_section] = STATE(2729),
    [sym_schema_section] = STATE(2729),
    [sym_assembly_declaration] = STATE(2729),
    [sym_event_declaration] = STATE(2729),
    [sym_procedure] = STATE(2729),
    [sym_preproc_split_procedure] = STATE(2729),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2729),
    [sym_var_section] = STATE(2729),
    [sym_attribute_item] = STATE(2729),
    [sym_preproc_conditional] = STATE(2729),
    [sym_preproc_if] = STATE(2557),
    [sym_preproc_endif] = STATE(6865),
    [aux_sym_report_dataitem_repeat1] = STATE(2729),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_dataitem_keyword] = ACTIONS(5942),
    [sym_column_keyword] = ACTIONS(5944),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3267)] = {
    [anon_sym_SEMI] = ACTIONS(2841),
    [anon_sym_LBRACE] = ACTIONS(2841),
    [aux_sym_where_condition_token1] = ACTIONS(2843),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2841),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2841),
    [anon_sym_LBRACK] = ACTIONS(2841),
    [aux_sym_basic_type_token6] = ACTIONS(2843),
    [aux_sym_basic_type_token22] = ACTIONS(2843),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2841),
    [aux_sym_addafter_modification_token1] = ACTIONS(2841),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2841),
    [aux_sym_modify_modification_token1] = ACTIONS(2841),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2841),
    [aux_sym_movelast_modification_token1] = ACTIONS(2841),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2841),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2841),
    [aux_sym_separator_action_token1] = ACTIONS(2841),
    [aux_sym_actionref_declaration_token1] = ACTIONS(2841),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(2841),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(2841),
    [aux_sym_customaction_declaration_token1] = ACTIONS(2841),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2841),
    [anon_sym_POUNDif] = ACTIONS(2841),
    [anon_sym_POUNDIF] = ACTIONS(2841),
    [anon_sym_POUNDIf] = ACTIONS(2841),
    [anon_sym_POUNDelif] = ACTIONS(2841),
    [anon_sym_POUNDELIF] = ACTIONS(2841),
    [anon_sym_POUNDElif] = ACTIONS(2841),
    [anon_sym_POUNDelse] = ACTIONS(2841),
    [anon_sym_POUNDELSE] = ACTIONS(2841),
    [anon_sym_POUNDElse] = ACTIONS(2841),
    [anon_sym_POUNDendif] = ACTIONS(2841),
    [anon_sym_POUNDENDIF] = ACTIONS(2841),
    [anon_sym_POUNDEndif] = ACTIONS(2841),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(2841),
    [sym_trigger_keyword] = ACTIONS(2841),
    [sym_var_keyword] = ACTIONS(2841),
    [sym_local_keyword] = ACTIONS(2841),
    [sym_internal_keyword] = ACTIONS(2841),
    [sym_protected_keyword] = ACTIONS(2841),
    [sym_event_keyword] = ACTIONS(2841),
    [sym_fields_keyword] = ACTIONS(2841),
    [sym_keys_keyword] = ACTIONS(2841),
    [sym_fieldgroups_keyword] = ACTIONS(2841),
    [sym_actions_keyword] = ACTIONS(2841),
    [sym_layout_keyword] = ACTIONS(2841),
    [sym_area_keyword] = ACTIONS(2841),
    [sym_group_keyword] = ACTIONS(2841),
    [sym_repeater_keyword] = ACTIONS(2841),
    [sym_cuegroup_keyword] = ACTIONS(2841),
    [sym_fixed_keyword] = ACTIONS(2841),
    [sym_grid_keyword] = ACTIONS(2841),
    [sym_part_keyword] = ACTIONS(2841),
    [sym_systempart_keyword] = ACTIONS(2841),
    [sym_usercontrol_keyword] = ACTIONS(2841),
    [sym_dataset_keyword] = ACTIONS(2841),
    [sym_elements_keyword] = ACTIONS(2841),
    [sym_dataitem_keyword] = ACTIONS(2841),
    [sym_column_keyword] = ACTIONS(2841),
    [sym_filter_keyword] = ACTIONS(2841),
    [sym_labels_keyword] = ACTIONS(2841),
    [sym_rendering_keyword] = ACTIONS(2841),
    [sym_requestpage_keyword] = ACTIONS(2841),
    [sym_schema_keyword] = ACTIONS(2841),
    [sym_views_keyword] = ACTIONS(2841),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2841),
    [sym_preproc_open] = ACTIONS(2841),
    [sym_preproc_close] = ACTIONS(2841),
  },
  [STATE(3268)] = {
    [sym__object_header] = STATE(9482),
    [sym_preproc_if] = STATE(3460),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [anon_sym_POUNDif] = ACTIONS(8617),
    [anon_sym_POUNDIF] = ACTIONS(8617),
    [anon_sym_POUNDIf] = ACTIONS(8617),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(8617),
  },
  [STATE(3269)] = {
    [sym_preproc_split_procedure] = STATE(3269),
    [sym_var_attribute_item] = STATE(3269),
    [sym_preproc_conditional_var] = STATE(3269),
    [sym_variable_declaration] = STATE(3269),
    [sym_preproc_if] = STATE(2420),
    [sym__identifier_or_quoted] = STATE(10406),
    [sym_keyword_as_identifier] = STATE(10406),
    [aux_sym_var_section_repeat1] = STATE(3269),
    [sym_identifier] = ACTIONS(8625),
    [anon_sym_SEMI] = ACTIONS(6239),
    [anon_sym_RBRACE] = ACTIONS(6239),
    [aux_sym_where_condition_token1] = ACTIONS(6241),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6244),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6244),
    [anon_sym_LBRACK] = ACTIONS(6239),
    [aux_sym_basic_type_token6] = ACTIONS(6244),
    [aux_sym_basic_type_token22] = ACTIONS(6241),
    [aux_sym_basic_type_token53] = ACTIONS(6241),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6241),
    [aux_sym_addafter_modification_token1] = ACTIONS(6244),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6244),
    [aux_sym_modify_modification_token1] = ACTIONS(6244),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6244),
    [aux_sym_movelast_modification_token1] = ACTIONS(6244),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6244),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6244),
    [aux_sym_separator_action_token1] = ACTIONS(6241),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6244),
    [aux_sym_type_declaration_token1] = ACTIONS(6241),
    [anon_sym_POUNDif] = ACTIONS(6246),
    [anon_sym_POUNDIF] = ACTIONS(6246),
    [anon_sym_POUNDIf] = ACTIONS(6246),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6244),
    [sym_trigger_keyword] = ACTIONS(6244),
    [sym_var_keyword] = ACTIONS(6244),
    [sym_local_keyword] = ACTIONS(6244),
    [sym_internal_keyword] = ACTIONS(6244),
    [sym_protected_keyword] = ACTIONS(6244),
    [sym_event_keyword] = ACTIONS(6244),
    [sym_fields_keyword] = ACTIONS(6244),
    [sym_keys_keyword] = ACTIONS(6244),
    [sym_key_keyword] = ACTIONS(6241),
    [sym_fieldgroups_keyword] = ACTIONS(6244),
    [sym_actions_keyword] = ACTIONS(6244),
    [sym_layout_keyword] = ACTIONS(6244),
    [sym_area_keyword] = ACTIONS(6244),
    [sym_group_keyword] = ACTIONS(6244),
    [sym_repeater_keyword] = ACTIONS(6244),
    [sym_cuegroup_keyword] = ACTIONS(6244),
    [sym_fixed_keyword] = ACTIONS(6244),
    [sym_grid_keyword] = ACTIONS(6244),
    [sym_part_keyword] = ACTIONS(6244),
    [sym_systempart_keyword] = ACTIONS(6244),
    [sym_usercontrol_keyword] = ACTIONS(6244),
    [sym_dataset_keyword] = ACTIONS(6241),
    [sym_elements_keyword] = ACTIONS(6244),
    [sym_dataitem_keyword] = ACTIONS(6244),
    [sym_column_keyword] = ACTIONS(6244),
    [sym_filter_keyword] = ACTIONS(6244),
    [sym_labels_keyword] = ACTIONS(6244),
    [sym_rendering_keyword] = ACTIONS(6244),
    [sym_requestpage_keyword] = ACTIONS(6244),
    [sym_schema_keyword] = ACTIONS(6244),
    [sym_views_keyword] = ACTIONS(6244),
    [sym_quoted_identifier] = ACTIONS(8628),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6239),
    [sym_preproc_open] = ACTIONS(6246),
    [sym_var_attribute_open] = ACTIONS(8631),
  },
  [STATE(3270)] = {
    [sym__object_header] = STATE(9599),
    [sym_preproc_if] = STATE(3451),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [anon_sym_POUNDif] = ACTIONS(8617),
    [anon_sym_POUNDIF] = ACTIONS(8617),
    [anon_sym_POUNDIf] = ACTIONS(8617),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(8617),
  },
  [STATE(3271)] = {
    [sym__object_header] = STATE(9605),
    [sym_preproc_if] = STATE(3452),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [anon_sym_POUNDif] = ACTIONS(8617),
    [anon_sym_POUNDIF] = ACTIONS(8617),
    [anon_sym_POUNDIf] = ACTIONS(8617),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(8617),
  },
  [STATE(3272)] = {
    [sym__body_element] = STATE(3335),
    [sym_empty_statement] = STATE(3335),
    [sym_property] = STATE(3335),
    [sym_fields_section] = STATE(3335),
    [sym_keys_section] = STATE(3335),
    [sym_fieldgroups_section] = STATE(3335),
    [sym_enum_value_declaration] = STATE(3335),
    [sym_labels_section] = STATE(3335),
    [sym_layout_section] = STATE(3335),
    [sym_modify_modification] = STATE(3335),
    [sym_actions_section] = STATE(3335),
    [sym_views_section] = STATE(3335),
    [sym_dataset_section] = STATE(3335),
    [sym_requestpage_section] = STATE(3335),
    [sym_rendering_section] = STATE(3335),
    [sym_elements_section] = STATE(3335),
    [sym_schema_section] = STATE(3335),
    [sym_assembly_declaration] = STATE(3335),
    [sym_event_declaration] = STATE(3335),
    [sym_procedure] = STATE(3335),
    [sym_preproc_split_procedure] = STATE(3335),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3335),
    [sym_var_section] = STATE(3335),
    [sym_attribute_item] = STATE(3335),
    [sym_preproc_conditional] = STATE(3335),
    [sym_preproc_if] = STATE(2733),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3335),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(8634),
    [anon_sym_POUNDELIF] = ACTIONS(8634),
    [anon_sym_POUNDElif] = ACTIONS(8634),
    [anon_sym_POUNDelse] = ACTIONS(8634),
    [anon_sym_POUNDELSE] = ACTIONS(8634),
    [anon_sym_POUNDElse] = ACTIONS(8634),
    [anon_sym_POUNDendif] = ACTIONS(8634),
    [anon_sym_POUNDENDIF] = ACTIONS(8634),
    [anon_sym_POUNDEndif] = ACTIONS(8634),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(8634),
  },
  [STATE(3273)] = {
    [anon_sym_SEMI] = ACTIONS(4397),
    [aux_sym_where_condition_token1] = ACTIONS(4395),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4397),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4397),
    [anon_sym_LBRACK] = ACTIONS(4397),
    [aux_sym_basic_type_token6] = ACTIONS(4395),
    [aux_sym_basic_type_token22] = ACTIONS(4395),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4397),
    [aux_sym_addafter_modification_token1] = ACTIONS(4397),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4397),
    [aux_sym_modify_modification_token1] = ACTIONS(4397),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4397),
    [aux_sym_movelast_modification_token1] = ACTIONS(4397),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4397),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4397),
    [aux_sym_separator_action_token1] = ACTIONS(4397),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4397),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4397),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4397),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4397),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4397),
    [anon_sym_POUNDif] = ACTIONS(4397),
    [anon_sym_POUNDIF] = ACTIONS(4397),
    [anon_sym_POUNDIf] = ACTIONS(4397),
    [anon_sym_POUNDelif] = ACTIONS(4397),
    [anon_sym_POUNDELIF] = ACTIONS(4397),
    [anon_sym_POUNDElif] = ACTIONS(4397),
    [anon_sym_POUNDelse] = ACTIONS(4397),
    [anon_sym_POUNDELSE] = ACTIONS(4397),
    [anon_sym_POUNDElse] = ACTIONS(4397),
    [anon_sym_POUNDendif] = ACTIONS(4397),
    [anon_sym_POUNDENDIF] = ACTIONS(4397),
    [anon_sym_POUNDEndif] = ACTIONS(4397),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4397),
    [sym_trigger_keyword] = ACTIONS(4397),
    [sym_var_keyword] = ACTIONS(4397),
    [sym_local_keyword] = ACTIONS(4397),
    [sym_internal_keyword] = ACTIONS(4397),
    [sym_protected_keyword] = ACTIONS(4397),
    [sym_event_keyword] = ACTIONS(4397),
    [sym_fields_keyword] = ACTIONS(4397),
    [sym_keys_keyword] = ACTIONS(4397),
    [sym_fieldgroups_keyword] = ACTIONS(4397),
    [sym_actions_keyword] = ACTIONS(4397),
    [sym_layout_keyword] = ACTIONS(4397),
    [sym_area_keyword] = ACTIONS(4397),
    [sym_group_keyword] = ACTIONS(4397),
    [sym_repeater_keyword] = ACTIONS(4397),
    [sym_cuegroup_keyword] = ACTIONS(4397),
    [sym_fixed_keyword] = ACTIONS(4397),
    [sym_grid_keyword] = ACTIONS(4397),
    [sym_part_keyword] = ACTIONS(4397),
    [sym_systempart_keyword] = ACTIONS(4397),
    [sym_usercontrol_keyword] = ACTIONS(4397),
    [sym_dataset_keyword] = ACTIONS(4397),
    [sym_elements_keyword] = ACTIONS(4397),
    [sym_dataitem_keyword] = ACTIONS(4397),
    [sym_column_keyword] = ACTIONS(4397),
    [sym_filter_keyword] = ACTIONS(4397),
    [sym_labels_keyword] = ACTIONS(4397),
    [sym_rendering_keyword] = ACTIONS(4397),
    [sym_requestpage_keyword] = ACTIONS(4397),
    [sym_schema_keyword] = ACTIONS(4397),
    [sym_views_keyword] = ACTIONS(4397),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4397),
    [sym_preproc_open] = ACTIONS(4397),
    [sym_preproc_close] = ACTIONS(4397),
  },
  [STATE(3274)] = {
    [anon_sym_SEMI] = ACTIONS(4465),
    [aux_sym_where_condition_token1] = ACTIONS(4463),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4465),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4465),
    [anon_sym_LBRACK] = ACTIONS(4465),
    [aux_sym_basic_type_token6] = ACTIONS(4463),
    [aux_sym_basic_type_token22] = ACTIONS(4463),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4465),
    [aux_sym_addafter_modification_token1] = ACTIONS(4465),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4465),
    [aux_sym_modify_modification_token1] = ACTIONS(4465),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4465),
    [aux_sym_movelast_modification_token1] = ACTIONS(4465),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4465),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4465),
    [aux_sym_separator_action_token1] = ACTIONS(4465),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4465),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4465),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4465),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4465),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4465),
    [anon_sym_POUNDif] = ACTIONS(4465),
    [anon_sym_POUNDIF] = ACTIONS(4465),
    [anon_sym_POUNDIf] = ACTIONS(4465),
    [anon_sym_POUNDelif] = ACTIONS(4465),
    [anon_sym_POUNDELIF] = ACTIONS(4465),
    [anon_sym_POUNDElif] = ACTIONS(4465),
    [anon_sym_POUNDelse] = ACTIONS(4465),
    [anon_sym_POUNDELSE] = ACTIONS(4465),
    [anon_sym_POUNDElse] = ACTIONS(4465),
    [anon_sym_POUNDendif] = ACTIONS(4465),
    [anon_sym_POUNDENDIF] = ACTIONS(4465),
    [anon_sym_POUNDEndif] = ACTIONS(4465),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4465),
    [sym_trigger_keyword] = ACTIONS(4465),
    [sym_var_keyword] = ACTIONS(4465),
    [sym_local_keyword] = ACTIONS(4465),
    [sym_internal_keyword] = ACTIONS(4465),
    [sym_protected_keyword] = ACTIONS(4465),
    [sym_event_keyword] = ACTIONS(4465),
    [sym_fields_keyword] = ACTIONS(4465),
    [sym_keys_keyword] = ACTIONS(4465),
    [sym_fieldgroups_keyword] = ACTIONS(4465),
    [sym_actions_keyword] = ACTIONS(4465),
    [sym_layout_keyword] = ACTIONS(4465),
    [sym_area_keyword] = ACTIONS(4465),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4465),
    [sym_cuegroup_keyword] = ACTIONS(4465),
    [sym_fixed_keyword] = ACTIONS(4465),
    [sym_grid_keyword] = ACTIONS(4465),
    [sym_part_keyword] = ACTIONS(4465),
    [sym_systempart_keyword] = ACTIONS(4465),
    [sym_usercontrol_keyword] = ACTIONS(4465),
    [sym_dataset_keyword] = ACTIONS(4465),
    [sym_elements_keyword] = ACTIONS(4465),
    [sym_dataitem_keyword] = ACTIONS(4465),
    [sym_column_keyword] = ACTIONS(4465),
    [sym_filter_keyword] = ACTIONS(4465),
    [sym_labels_keyword] = ACTIONS(4465),
    [sym_rendering_keyword] = ACTIONS(4465),
    [sym_requestpage_keyword] = ACTIONS(4465),
    [sym_schema_keyword] = ACTIONS(4465),
    [sym_views_keyword] = ACTIONS(4465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4465),
    [sym_preproc_open] = ACTIONS(4465),
    [sym_preproc_close] = ACTIONS(4465),
  },
  [STATE(3275)] = {
    [anon_sym_SEMI] = ACTIONS(8636),
    [aux_sym_where_condition_token1] = ACTIONS(4383),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4387),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4387),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_basic_type_token6] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4387),
    [aux_sym_addafter_modification_token1] = ACTIONS(4387),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4387),
    [aux_sym_modify_modification_token1] = ACTIONS(4387),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4387),
    [aux_sym_movelast_modification_token1] = ACTIONS(4387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4387),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4387),
    [aux_sym_separator_action_token1] = ACTIONS(4387),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4387),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4387),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4387),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4387),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4387),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [anon_sym_POUNDelif] = ACTIONS(4387),
    [anon_sym_POUNDELIF] = ACTIONS(4387),
    [anon_sym_POUNDElif] = ACTIONS(4387),
    [anon_sym_POUNDelse] = ACTIONS(4387),
    [anon_sym_POUNDELSE] = ACTIONS(4387),
    [anon_sym_POUNDElse] = ACTIONS(4387),
    [anon_sym_POUNDendif] = ACTIONS(4387),
    [anon_sym_POUNDENDIF] = ACTIONS(4387),
    [anon_sym_POUNDEndif] = ACTIONS(4387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4387),
    [sym_trigger_keyword] = ACTIONS(4387),
    [sym_var_keyword] = ACTIONS(4387),
    [sym_local_keyword] = ACTIONS(4387),
    [sym_internal_keyword] = ACTIONS(4387),
    [sym_protected_keyword] = ACTIONS(4387),
    [sym_event_keyword] = ACTIONS(4387),
    [sym_fields_keyword] = ACTIONS(4387),
    [sym_keys_keyword] = ACTIONS(4387),
    [sym_fieldgroups_keyword] = ACTIONS(4387),
    [sym_actions_keyword] = ACTIONS(4387),
    [sym_layout_keyword] = ACTIONS(4387),
    [sym_area_keyword] = ACTIONS(4387),
    [sym_group_keyword] = ACTIONS(4387),
    [sym_repeater_keyword] = ACTIONS(4387),
    [sym_cuegroup_keyword] = ACTIONS(4387),
    [sym_fixed_keyword] = ACTIONS(4387),
    [sym_grid_keyword] = ACTIONS(4387),
    [sym_part_keyword] = ACTIONS(4387),
    [sym_systempart_keyword] = ACTIONS(4387),
    [sym_usercontrol_keyword] = ACTIONS(4387),
    [sym_dataset_keyword] = ACTIONS(4387),
    [sym_elements_keyword] = ACTIONS(4387),
    [sym_dataitem_keyword] = ACTIONS(4387),
    [sym_column_keyword] = ACTIONS(4387),
    [sym_filter_keyword] = ACTIONS(4387),
    [sym_labels_keyword] = ACTIONS(4387),
    [sym_rendering_keyword] = ACTIONS(4387),
    [sym_requestpage_keyword] = ACTIONS(4387),
    [sym_schema_keyword] = ACTIONS(4387),
    [sym_views_keyword] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
    [sym_preproc_close] = ACTIONS(4387),
  },
  [STATE(3276)] = {
    [sym__body_element] = STATE(3278),
    [sym_empty_statement] = STATE(3278),
    [sym_property] = STATE(3278),
    [sym_fields_section] = STATE(3278),
    [sym_keys_section] = STATE(3278),
    [sym_fieldgroups_section] = STATE(3278),
    [sym_enum_value_declaration] = STATE(3278),
    [sym_labels_section] = STATE(3278),
    [sym_layout_section] = STATE(3278),
    [sym_modify_modification] = STATE(3278),
    [sym_actions_section] = STATE(3278),
    [sym_views_section] = STATE(3278),
    [sym_dataset_section] = STATE(3278),
    [sym_requestpage_section] = STATE(3278),
    [sym_rendering_section] = STATE(3278),
    [sym_elements_section] = STATE(3278),
    [sym_schema_section] = STATE(3278),
    [sym_xmlport_element] = STATE(3278),
    [sym__xmlport_body_element] = STATE(3278),
    [sym_preproc_conditional_xmlport] = STATE(3278),
    [sym_xmlport_attribute] = STATE(3278),
    [sym_assembly_declaration] = STATE(3278),
    [sym_event_declaration] = STATE(3278),
    [sym_procedure] = STATE(3278),
    [sym_preproc_split_procedure] = STATE(3278),
    [sym_procedure_modifier] = STATE(12392),
    [sym_trigger_declaration] = STATE(3278),
    [sym_var_section] = STATE(3278),
    [sym_attribute_item] = STATE(3278),
    [sym_preproc_conditional] = STATE(3278),
    [sym_preproc_if] = STATE(2456),
    [aux_sym_xmlport_element_repeat1] = STATE(3278),
    [anon_sym_SEMI] = ACTIONS(8638),
    [anon_sym_RBRACE] = ACTIONS(8640),
    [anon_sym_LBRACK] = ACTIONS(8642),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8644),
    [aux_sym_modify_modification_token1] = ACTIONS(8646),
    [aux_sym_xmlport_element_token1] = ACTIONS(8648),
    [aux_sym_xmlport_element_token2] = ACTIONS(8648),
    [aux_sym_xmlport_element_token3] = ACTIONS(8648),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8650),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8650),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8652),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8654),
    [sym_trigger_keyword] = ACTIONS(8656),
    [sym_var_keyword] = ACTIONS(8658),
    [sym_local_keyword] = ACTIONS(8660),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(8660),
    [sym_event_keyword] = ACTIONS(8662),
    [sym_fields_keyword] = ACTIONS(8664),
    [sym_keys_keyword] = ACTIONS(8666),
    [sym_fieldgroups_keyword] = ACTIONS(8668),
    [sym_actions_keyword] = ACTIONS(8670),
    [sym_layout_keyword] = ACTIONS(8672),
    [sym_dataset_keyword] = ACTIONS(8674),
    [sym_elements_keyword] = ACTIONS(8676),
    [sym_labels_keyword] = ACTIONS(8678),
    [sym_rendering_keyword] = ACTIONS(8680),
    [sym_requestpage_keyword] = ACTIONS(8682),
    [sym_schema_keyword] = ACTIONS(8684),
    [sym_views_keyword] = ACTIONS(8686),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8688),
    [sym_preproc_open] = ACTIONS(5823),
  },
  [STATE(3277)] = {
    [anon_sym_SEMI] = ACTIONS(4397),
    [aux_sym_where_condition_token1] = ACTIONS(4395),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4397),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4397),
    [anon_sym_LBRACK] = ACTIONS(4397),
    [aux_sym_basic_type_token6] = ACTIONS(4395),
    [aux_sym_basic_type_token22] = ACTIONS(4395),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4397),
    [aux_sym_addafter_modification_token1] = ACTIONS(4397),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4397),
    [aux_sym_modify_modification_token1] = ACTIONS(4397),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4397),
    [aux_sym_movelast_modification_token1] = ACTIONS(4397),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4397),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4397),
    [aux_sym_separator_action_token1] = ACTIONS(4397),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4397),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4397),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4397),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4397),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4397),
    [anon_sym_POUNDif] = ACTIONS(4397),
    [anon_sym_POUNDIF] = ACTIONS(4397),
    [anon_sym_POUNDIf] = ACTIONS(4397),
    [anon_sym_POUNDelif] = ACTIONS(4397),
    [anon_sym_POUNDELIF] = ACTIONS(4397),
    [anon_sym_POUNDElif] = ACTIONS(4397),
    [anon_sym_POUNDelse] = ACTIONS(4397),
    [anon_sym_POUNDELSE] = ACTIONS(4397),
    [anon_sym_POUNDElse] = ACTIONS(4397),
    [anon_sym_POUNDendif] = ACTIONS(4397),
    [anon_sym_POUNDENDIF] = ACTIONS(4397),
    [anon_sym_POUNDEndif] = ACTIONS(4397),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4397),
    [sym_trigger_keyword] = ACTIONS(4397),
    [sym_var_keyword] = ACTIONS(4397),
    [sym_local_keyword] = ACTIONS(4397),
    [sym_internal_keyword] = ACTIONS(4397),
    [sym_protected_keyword] = ACTIONS(4397),
    [sym_event_keyword] = ACTIONS(4397),
    [sym_fields_keyword] = ACTIONS(4397),
    [sym_keys_keyword] = ACTIONS(4397),
    [sym_fieldgroups_keyword] = ACTIONS(4397),
    [sym_actions_keyword] = ACTIONS(4397),
    [sym_layout_keyword] = ACTIONS(4397),
    [sym_area_keyword] = ACTIONS(4397),
    [sym_group_keyword] = ACTIONS(4397),
    [sym_repeater_keyword] = ACTIONS(4397),
    [sym_cuegroup_keyword] = ACTIONS(4397),
    [sym_fixed_keyword] = ACTIONS(4397),
    [sym_grid_keyword] = ACTIONS(4397),
    [sym_part_keyword] = ACTIONS(4397),
    [sym_systempart_keyword] = ACTIONS(4397),
    [sym_usercontrol_keyword] = ACTIONS(4397),
    [sym_dataset_keyword] = ACTIONS(4397),
    [sym_elements_keyword] = ACTIONS(4397),
    [sym_dataitem_keyword] = ACTIONS(4397),
    [sym_column_keyword] = ACTIONS(4397),
    [sym_filter_keyword] = ACTIONS(4397),
    [sym_labels_keyword] = ACTIONS(4397),
    [sym_rendering_keyword] = ACTIONS(4397),
    [sym_requestpage_keyword] = ACTIONS(4397),
    [sym_schema_keyword] = ACTIONS(4397),
    [sym_views_keyword] = ACTIONS(4397),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4397),
    [sym_preproc_open] = ACTIONS(4397),
    [sym_preproc_close] = ACTIONS(4397),
  },
  [STATE(3278)] = {
    [sym__body_element] = STATE(3330),
    [sym_empty_statement] = STATE(3330),
    [sym_property] = STATE(3330),
    [sym_fields_section] = STATE(3330),
    [sym_keys_section] = STATE(3330),
    [sym_fieldgroups_section] = STATE(3330),
    [sym_enum_value_declaration] = STATE(3330),
    [sym_labels_section] = STATE(3330),
    [sym_layout_section] = STATE(3330),
    [sym_modify_modification] = STATE(3330),
    [sym_actions_section] = STATE(3330),
    [sym_views_section] = STATE(3330),
    [sym_dataset_section] = STATE(3330),
    [sym_requestpage_section] = STATE(3330),
    [sym_rendering_section] = STATE(3330),
    [sym_elements_section] = STATE(3330),
    [sym_schema_section] = STATE(3330),
    [sym_xmlport_element] = STATE(3330),
    [sym__xmlport_body_element] = STATE(3330),
    [sym_preproc_conditional_xmlport] = STATE(3330),
    [sym_xmlport_attribute] = STATE(3330),
    [sym_assembly_declaration] = STATE(3330),
    [sym_event_declaration] = STATE(3330),
    [sym_procedure] = STATE(3330),
    [sym_preproc_split_procedure] = STATE(3330),
    [sym_procedure_modifier] = STATE(12392),
    [sym_trigger_declaration] = STATE(3330),
    [sym_var_section] = STATE(3330),
    [sym_attribute_item] = STATE(3330),
    [sym_preproc_conditional] = STATE(3330),
    [sym_preproc_if] = STATE(2456),
    [aux_sym_xmlport_element_repeat1] = STATE(3330),
    [anon_sym_SEMI] = ACTIONS(8638),
    [anon_sym_RBRACE] = ACTIONS(8690),
    [anon_sym_LBRACK] = ACTIONS(8642),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8644),
    [aux_sym_modify_modification_token1] = ACTIONS(8646),
    [aux_sym_xmlport_element_token1] = ACTIONS(8648),
    [aux_sym_xmlport_element_token2] = ACTIONS(8648),
    [aux_sym_xmlport_element_token3] = ACTIONS(8648),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8650),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8650),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8652),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8654),
    [sym_trigger_keyword] = ACTIONS(8656),
    [sym_var_keyword] = ACTIONS(8658),
    [sym_local_keyword] = ACTIONS(8660),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(8660),
    [sym_event_keyword] = ACTIONS(8662),
    [sym_fields_keyword] = ACTIONS(8664),
    [sym_keys_keyword] = ACTIONS(8666),
    [sym_fieldgroups_keyword] = ACTIONS(8668),
    [sym_actions_keyword] = ACTIONS(8670),
    [sym_layout_keyword] = ACTIONS(8672),
    [sym_dataset_keyword] = ACTIONS(8674),
    [sym_elements_keyword] = ACTIONS(8676),
    [sym_labels_keyword] = ACTIONS(8678),
    [sym_rendering_keyword] = ACTIONS(8680),
    [sym_requestpage_keyword] = ACTIONS(8682),
    [sym_schema_keyword] = ACTIONS(8684),
    [sym_views_keyword] = ACTIONS(8686),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8688),
    [sym_preproc_open] = ACTIONS(5823),
  },
  [STATE(3279)] = {
    [sym__body_element] = STATE(3281),
    [sym_empty_statement] = STATE(3281),
    [sym_property] = STATE(3281),
    [sym_fields_section] = STATE(3281),
    [sym_keys_section] = STATE(3281),
    [sym_fieldgroups_section] = STATE(3281),
    [sym_enum_value_declaration] = STATE(3281),
    [sym_labels_section] = STATE(3281),
    [sym_layout_section] = STATE(3281),
    [sym_modify_modification] = STATE(3281),
    [sym_actions_section] = STATE(3281),
    [sym_views_section] = STATE(3281),
    [sym_dataset_section] = STATE(3281),
    [sym_requestpage_section] = STATE(3281),
    [sym_rendering_section] = STATE(3281),
    [sym_elements_section] = STATE(3281),
    [sym_schema_section] = STATE(3281),
    [sym_xmlport_element] = STATE(3281),
    [sym__xmlport_body_element] = STATE(3281),
    [sym_preproc_conditional_xmlport] = STATE(3281),
    [sym_xmlport_attribute] = STATE(3281),
    [sym_assembly_declaration] = STATE(3281),
    [sym_event_declaration] = STATE(3281),
    [sym_procedure] = STATE(3281),
    [sym_preproc_split_procedure] = STATE(3281),
    [sym_procedure_modifier] = STATE(12392),
    [sym_trigger_declaration] = STATE(3281),
    [sym_var_section] = STATE(3281),
    [sym_attribute_item] = STATE(3281),
    [sym_preproc_conditional] = STATE(3281),
    [sym_preproc_if] = STATE(2456),
    [aux_sym_xmlport_element_repeat1] = STATE(3281),
    [anon_sym_SEMI] = ACTIONS(8638),
    [anon_sym_RBRACE] = ACTIONS(8692),
    [anon_sym_LBRACK] = ACTIONS(8642),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8644),
    [aux_sym_modify_modification_token1] = ACTIONS(8646),
    [aux_sym_xmlport_element_token1] = ACTIONS(8648),
    [aux_sym_xmlport_element_token2] = ACTIONS(8648),
    [aux_sym_xmlport_element_token3] = ACTIONS(8648),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8650),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8650),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8652),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8654),
    [sym_trigger_keyword] = ACTIONS(8656),
    [sym_var_keyword] = ACTIONS(8658),
    [sym_local_keyword] = ACTIONS(8660),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(8660),
    [sym_event_keyword] = ACTIONS(8662),
    [sym_fields_keyword] = ACTIONS(8664),
    [sym_keys_keyword] = ACTIONS(8666),
    [sym_fieldgroups_keyword] = ACTIONS(8668),
    [sym_actions_keyword] = ACTIONS(8670),
    [sym_layout_keyword] = ACTIONS(8672),
    [sym_dataset_keyword] = ACTIONS(8674),
    [sym_elements_keyword] = ACTIONS(8676),
    [sym_labels_keyword] = ACTIONS(8678),
    [sym_rendering_keyword] = ACTIONS(8680),
    [sym_requestpage_keyword] = ACTIONS(8682),
    [sym_schema_keyword] = ACTIONS(8684),
    [sym_views_keyword] = ACTIONS(8686),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8688),
    [sym_preproc_open] = ACTIONS(5823),
  },
  [STATE(3280)] = {
    [anon_sym_SEMI] = ACTIONS(8694),
    [aux_sym_where_condition_token1] = ACTIONS(8696),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8694),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8694),
    [anon_sym_LBRACK] = ACTIONS(8694),
    [aux_sym_basic_type_token6] = ACTIONS(8696),
    [aux_sym_basic_type_token22] = ACTIONS(8696),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8694),
    [aux_sym_addafter_modification_token1] = ACTIONS(8694),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8694),
    [aux_sym_modify_modification_token1] = ACTIONS(8694),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8694),
    [aux_sym_movelast_modification_token1] = ACTIONS(8694),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8694),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8694),
    [aux_sym_separator_action_token1] = ACTIONS(8694),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8694),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8694),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8694),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8694),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8694),
    [anon_sym_POUNDif] = ACTIONS(8694),
    [anon_sym_POUNDIF] = ACTIONS(8694),
    [anon_sym_POUNDIf] = ACTIONS(8694),
    [anon_sym_POUNDelif] = ACTIONS(8694),
    [anon_sym_POUNDELIF] = ACTIONS(8694),
    [anon_sym_POUNDElif] = ACTIONS(8694),
    [anon_sym_POUNDelse] = ACTIONS(8694),
    [anon_sym_POUNDELSE] = ACTIONS(8694),
    [anon_sym_POUNDElse] = ACTIONS(8694),
    [anon_sym_POUNDendif] = ACTIONS(8694),
    [anon_sym_POUNDENDIF] = ACTIONS(8694),
    [anon_sym_POUNDEndif] = ACTIONS(8694),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8694),
    [sym_trigger_keyword] = ACTIONS(8694),
    [sym_var_keyword] = ACTIONS(8694),
    [sym_local_keyword] = ACTIONS(8694),
    [sym_internal_keyword] = ACTIONS(8694),
    [sym_protected_keyword] = ACTIONS(8694),
    [sym_event_keyword] = ACTIONS(8694),
    [sym_fields_keyword] = ACTIONS(8694),
    [sym_keys_keyword] = ACTIONS(8694),
    [sym_fieldgroups_keyword] = ACTIONS(8694),
    [sym_actions_keyword] = ACTIONS(8694),
    [sym_layout_keyword] = ACTIONS(8694),
    [sym_area_keyword] = ACTIONS(8694),
    [sym_group_keyword] = ACTIONS(8694),
    [sym_repeater_keyword] = ACTIONS(8694),
    [sym_cuegroup_keyword] = ACTIONS(8694),
    [sym_fixed_keyword] = ACTIONS(8694),
    [sym_grid_keyword] = ACTIONS(8694),
    [sym_part_keyword] = ACTIONS(8694),
    [sym_systempart_keyword] = ACTIONS(8694),
    [sym_usercontrol_keyword] = ACTIONS(8694),
    [sym_dataset_keyword] = ACTIONS(8694),
    [sym_elements_keyword] = ACTIONS(8694),
    [sym_dataitem_keyword] = ACTIONS(8694),
    [sym_column_keyword] = ACTIONS(8694),
    [sym_filter_keyword] = ACTIONS(8694),
    [sym_labels_keyword] = ACTIONS(8694),
    [sym_rendering_keyword] = ACTIONS(8694),
    [sym_requestpage_keyword] = ACTIONS(8694),
    [sym_schema_keyword] = ACTIONS(8694),
    [sym_views_keyword] = ACTIONS(8694),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8694),
    [sym_preproc_open] = ACTIONS(8694),
    [sym_preproc_close] = ACTIONS(8694),
  },
  [STATE(3281)] = {
    [sym__body_element] = STATE(3330),
    [sym_empty_statement] = STATE(3330),
    [sym_property] = STATE(3330),
    [sym_fields_section] = STATE(3330),
    [sym_keys_section] = STATE(3330),
    [sym_fieldgroups_section] = STATE(3330),
    [sym_enum_value_declaration] = STATE(3330),
    [sym_labels_section] = STATE(3330),
    [sym_layout_section] = STATE(3330),
    [sym_modify_modification] = STATE(3330),
    [sym_actions_section] = STATE(3330),
    [sym_views_section] = STATE(3330),
    [sym_dataset_section] = STATE(3330),
    [sym_requestpage_section] = STATE(3330),
    [sym_rendering_section] = STATE(3330),
    [sym_elements_section] = STATE(3330),
    [sym_schema_section] = STATE(3330),
    [sym_xmlport_element] = STATE(3330),
    [sym__xmlport_body_element] = STATE(3330),
    [sym_preproc_conditional_xmlport] = STATE(3330),
    [sym_xmlport_attribute] = STATE(3330),
    [sym_assembly_declaration] = STATE(3330),
    [sym_event_declaration] = STATE(3330),
    [sym_procedure] = STATE(3330),
    [sym_preproc_split_procedure] = STATE(3330),
    [sym_procedure_modifier] = STATE(12392),
    [sym_trigger_declaration] = STATE(3330),
    [sym_var_section] = STATE(3330),
    [sym_attribute_item] = STATE(3330),
    [sym_preproc_conditional] = STATE(3330),
    [sym_preproc_if] = STATE(2456),
    [aux_sym_xmlport_element_repeat1] = STATE(3330),
    [anon_sym_SEMI] = ACTIONS(8638),
    [anon_sym_RBRACE] = ACTIONS(8698),
    [anon_sym_LBRACK] = ACTIONS(8642),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8644),
    [aux_sym_modify_modification_token1] = ACTIONS(8646),
    [aux_sym_xmlport_element_token1] = ACTIONS(8648),
    [aux_sym_xmlport_element_token2] = ACTIONS(8648),
    [aux_sym_xmlport_element_token3] = ACTIONS(8648),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8650),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8650),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8652),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8654),
    [sym_trigger_keyword] = ACTIONS(8656),
    [sym_var_keyword] = ACTIONS(8658),
    [sym_local_keyword] = ACTIONS(8660),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(8660),
    [sym_event_keyword] = ACTIONS(8662),
    [sym_fields_keyword] = ACTIONS(8664),
    [sym_keys_keyword] = ACTIONS(8666),
    [sym_fieldgroups_keyword] = ACTIONS(8668),
    [sym_actions_keyword] = ACTIONS(8670),
    [sym_layout_keyword] = ACTIONS(8672),
    [sym_dataset_keyword] = ACTIONS(8674),
    [sym_elements_keyword] = ACTIONS(8676),
    [sym_labels_keyword] = ACTIONS(8678),
    [sym_rendering_keyword] = ACTIONS(8680),
    [sym_requestpage_keyword] = ACTIONS(8682),
    [sym_schema_keyword] = ACTIONS(8684),
    [sym_views_keyword] = ACTIONS(8686),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8688),
    [sym_preproc_open] = ACTIONS(5823),
  },
  [STATE(3282)] = {
    [sym__body_element] = STATE(3338),
    [sym_empty_statement] = STATE(3338),
    [sym_property] = STATE(3338),
    [sym_fields_section] = STATE(3338),
    [sym_keys_section] = STATE(3338),
    [sym_fieldgroups_section] = STATE(3338),
    [sym_enum_value_declaration] = STATE(3338),
    [sym_labels_section] = STATE(3338),
    [sym_layout_section] = STATE(3338),
    [sym_modify_modification] = STATE(3338),
    [sym_actions_section] = STATE(3338),
    [sym_views_section] = STATE(3338),
    [sym_dataset_section] = STATE(3338),
    [sym_requestpage_section] = STATE(3338),
    [sym_rendering_section] = STATE(3338),
    [sym_elements_section] = STATE(3338),
    [sym_schema_section] = STATE(3338),
    [sym_xmlport_element] = STATE(3338),
    [sym__xmlport_body_element] = STATE(3338),
    [sym_preproc_conditional_xmlport] = STATE(3338),
    [sym_xmlport_attribute] = STATE(3338),
    [sym_assembly_declaration] = STATE(3338),
    [sym_event_declaration] = STATE(3338),
    [sym_procedure] = STATE(3338),
    [sym_preproc_split_procedure] = STATE(3338),
    [sym_procedure_modifier] = STATE(12392),
    [sym_trigger_declaration] = STATE(3338),
    [sym_var_section] = STATE(3338),
    [sym_attribute_item] = STATE(3338),
    [sym_preproc_conditional] = STATE(3338),
    [sym_preproc_if] = STATE(2456),
    [aux_sym_xmlport_element_repeat1] = STATE(3338),
    [anon_sym_SEMI] = ACTIONS(8638),
    [anon_sym_RBRACE] = ACTIONS(8700),
    [anon_sym_LBRACK] = ACTIONS(8642),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8644),
    [aux_sym_modify_modification_token1] = ACTIONS(8646),
    [aux_sym_xmlport_element_token1] = ACTIONS(8648),
    [aux_sym_xmlport_element_token2] = ACTIONS(8648),
    [aux_sym_xmlport_element_token3] = ACTIONS(8648),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8650),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8650),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8652),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8654),
    [sym_trigger_keyword] = ACTIONS(8656),
    [sym_var_keyword] = ACTIONS(8658),
    [sym_local_keyword] = ACTIONS(8660),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(8660),
    [sym_event_keyword] = ACTIONS(8662),
    [sym_fields_keyword] = ACTIONS(8664),
    [sym_keys_keyword] = ACTIONS(8666),
    [sym_fieldgroups_keyword] = ACTIONS(8668),
    [sym_actions_keyword] = ACTIONS(8670),
    [sym_layout_keyword] = ACTIONS(8672),
    [sym_dataset_keyword] = ACTIONS(8674),
    [sym_elements_keyword] = ACTIONS(8676),
    [sym_labels_keyword] = ACTIONS(8678),
    [sym_rendering_keyword] = ACTIONS(8680),
    [sym_requestpage_keyword] = ACTIONS(8682),
    [sym_schema_keyword] = ACTIONS(8684),
    [sym_views_keyword] = ACTIONS(8686),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8688),
    [sym_preproc_open] = ACTIONS(5823),
  },
  [STATE(3283)] = {
    [anon_sym_SEMI] = ACTIONS(8702),
    [aux_sym_where_condition_token1] = ACTIONS(4383),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4387),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4387),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_basic_type_token6] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4387),
    [aux_sym_addafter_modification_token1] = ACTIONS(4387),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4387),
    [aux_sym_modify_modification_token1] = ACTIONS(4387),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4387),
    [aux_sym_movelast_modification_token1] = ACTIONS(4387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4387),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4387),
    [aux_sym_separator_action_token1] = ACTIONS(4387),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4387),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4387),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4387),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4387),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4387),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [anon_sym_POUNDelif] = ACTIONS(4387),
    [anon_sym_POUNDELIF] = ACTIONS(4387),
    [anon_sym_POUNDElif] = ACTIONS(4387),
    [anon_sym_POUNDelse] = ACTIONS(4387),
    [anon_sym_POUNDELSE] = ACTIONS(4387),
    [anon_sym_POUNDElse] = ACTIONS(4387),
    [anon_sym_POUNDendif] = ACTIONS(4387),
    [anon_sym_POUNDENDIF] = ACTIONS(4387),
    [anon_sym_POUNDEndif] = ACTIONS(4387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4387),
    [sym_trigger_keyword] = ACTIONS(4387),
    [sym_var_keyword] = ACTIONS(4387),
    [sym_local_keyword] = ACTIONS(4387),
    [sym_internal_keyword] = ACTIONS(4387),
    [sym_protected_keyword] = ACTIONS(4387),
    [sym_event_keyword] = ACTIONS(4387),
    [sym_fields_keyword] = ACTIONS(4387),
    [sym_keys_keyword] = ACTIONS(4387),
    [sym_fieldgroups_keyword] = ACTIONS(4387),
    [sym_actions_keyword] = ACTIONS(4387),
    [sym_layout_keyword] = ACTIONS(4387),
    [sym_area_keyword] = ACTIONS(4387),
    [sym_group_keyword] = ACTIONS(4387),
    [sym_repeater_keyword] = ACTIONS(4387),
    [sym_cuegroup_keyword] = ACTIONS(4387),
    [sym_fixed_keyword] = ACTIONS(4387),
    [sym_grid_keyword] = ACTIONS(4387),
    [sym_part_keyword] = ACTIONS(4387),
    [sym_systempart_keyword] = ACTIONS(4387),
    [sym_usercontrol_keyword] = ACTIONS(4387),
    [sym_dataset_keyword] = ACTIONS(4387),
    [sym_elements_keyword] = ACTIONS(4387),
    [sym_dataitem_keyword] = ACTIONS(4387),
    [sym_column_keyword] = ACTIONS(4387),
    [sym_filter_keyword] = ACTIONS(4387),
    [sym_labels_keyword] = ACTIONS(4387),
    [sym_rendering_keyword] = ACTIONS(4387),
    [sym_requestpage_keyword] = ACTIONS(4387),
    [sym_schema_keyword] = ACTIONS(4387),
    [sym_views_keyword] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
    [sym_preproc_close] = ACTIONS(4387),
  },
  [STATE(3284)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(8704),
    [anon_sym_LBRACK] = ACTIONS(8707),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8710),
    [aux_sym_modify_modification_token1] = ACTIONS(8713),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8716),
    [anon_sym_POUNDif] = ACTIONS(8719),
    [anon_sym_POUNDIF] = ACTIONS(8719),
    [anon_sym_POUNDIf] = ACTIONS(8719),
    [anon_sym_POUNDelif] = ACTIONS(8722),
    [anon_sym_POUNDELIF] = ACTIONS(8722),
    [anon_sym_POUNDElif] = ACTIONS(8722),
    [anon_sym_POUNDelse] = ACTIONS(8722),
    [anon_sym_POUNDELSE] = ACTIONS(8722),
    [anon_sym_POUNDElse] = ACTIONS(8722),
    [anon_sym_POUNDendif] = ACTIONS(8722),
    [anon_sym_POUNDENDIF] = ACTIONS(8722),
    [anon_sym_POUNDEndif] = ACTIONS(8722),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8724),
    [sym_trigger_keyword] = ACTIONS(8727),
    [sym_var_keyword] = ACTIONS(8730),
    [sym_local_keyword] = ACTIONS(8733),
    [sym_internal_keyword] = ACTIONS(8736),
    [sym_protected_keyword] = ACTIONS(8733),
    [sym_event_keyword] = ACTIONS(8739),
    [sym_fields_keyword] = ACTIONS(8742),
    [sym_keys_keyword] = ACTIONS(8745),
    [sym_fieldgroups_keyword] = ACTIONS(8748),
    [sym_actions_keyword] = ACTIONS(8751),
    [sym_layout_keyword] = ACTIONS(8754),
    [sym_dataset_keyword] = ACTIONS(8757),
    [sym_elements_keyword] = ACTIONS(8760),
    [sym_labels_keyword] = ACTIONS(8763),
    [sym_rendering_keyword] = ACTIONS(8766),
    [sym_requestpage_keyword] = ACTIONS(8769),
    [sym_schema_keyword] = ACTIONS(8772),
    [sym_views_keyword] = ACTIONS(8775),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8778),
    [sym_preproc_open] = ACTIONS(8719),
    [sym_preproc_close] = ACTIONS(8722),
  },
  [STATE(3285)] = {
    [anon_sym_SEMI] = ACTIONS(4417),
    [aux_sym_where_condition_token1] = ACTIONS(4415),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4417),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4417),
    [anon_sym_LBRACK] = ACTIONS(4417),
    [aux_sym_basic_type_token6] = ACTIONS(4415),
    [aux_sym_basic_type_token22] = ACTIONS(4415),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4417),
    [aux_sym_addafter_modification_token1] = ACTIONS(4417),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4417),
    [aux_sym_modify_modification_token1] = ACTIONS(4417),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4417),
    [aux_sym_movelast_modification_token1] = ACTIONS(4417),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4417),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4417),
    [aux_sym_separator_action_token1] = ACTIONS(4417),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4417),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4417),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4417),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4417),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4417),
    [anon_sym_POUNDif] = ACTIONS(4417),
    [anon_sym_POUNDIF] = ACTIONS(4417),
    [anon_sym_POUNDIf] = ACTIONS(4417),
    [anon_sym_POUNDelif] = ACTIONS(4417),
    [anon_sym_POUNDELIF] = ACTIONS(4417),
    [anon_sym_POUNDElif] = ACTIONS(4417),
    [anon_sym_POUNDelse] = ACTIONS(4417),
    [anon_sym_POUNDELSE] = ACTIONS(4417),
    [anon_sym_POUNDElse] = ACTIONS(4417),
    [anon_sym_POUNDendif] = ACTIONS(4417),
    [anon_sym_POUNDENDIF] = ACTIONS(4417),
    [anon_sym_POUNDEndif] = ACTIONS(4417),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4417),
    [sym_trigger_keyword] = ACTIONS(4417),
    [sym_var_keyword] = ACTIONS(4417),
    [sym_local_keyword] = ACTIONS(4417),
    [sym_internal_keyword] = ACTIONS(4417),
    [sym_protected_keyword] = ACTIONS(4417),
    [sym_event_keyword] = ACTIONS(4417),
    [sym_fields_keyword] = ACTIONS(4417),
    [sym_keys_keyword] = ACTIONS(4417),
    [sym_fieldgroups_keyword] = ACTIONS(4417),
    [sym_actions_keyword] = ACTIONS(4417),
    [sym_layout_keyword] = ACTIONS(4417),
    [sym_area_keyword] = ACTIONS(4417),
    [sym_group_keyword] = ACTIONS(4417),
    [sym_repeater_keyword] = ACTIONS(4417),
    [sym_cuegroup_keyword] = ACTIONS(4417),
    [sym_fixed_keyword] = ACTIONS(4417),
    [sym_grid_keyword] = ACTIONS(4417),
    [sym_part_keyword] = ACTIONS(4417),
    [sym_systempart_keyword] = ACTIONS(4417),
    [sym_usercontrol_keyword] = ACTIONS(4417),
    [sym_dataset_keyword] = ACTIONS(4417),
    [sym_elements_keyword] = ACTIONS(4417),
    [sym_dataitem_keyword] = ACTIONS(4417),
    [sym_column_keyword] = ACTIONS(4417),
    [sym_filter_keyword] = ACTIONS(4417),
    [sym_labels_keyword] = ACTIONS(4417),
    [sym_rendering_keyword] = ACTIONS(4417),
    [sym_requestpage_keyword] = ACTIONS(4417),
    [sym_schema_keyword] = ACTIONS(4417),
    [sym_views_keyword] = ACTIONS(4417),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4417),
    [sym_preproc_open] = ACTIONS(4417),
    [sym_preproc_close] = ACTIONS(4417),
  },
  [STATE(3286)] = {
    [anon_sym_SEMI] = ACTIONS(4421),
    [aux_sym_where_condition_token1] = ACTIONS(4419),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4421),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4421),
    [anon_sym_LBRACK] = ACTIONS(4421),
    [aux_sym_basic_type_token6] = ACTIONS(4419),
    [aux_sym_basic_type_token22] = ACTIONS(4419),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4421),
    [aux_sym_addafter_modification_token1] = ACTIONS(4421),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4421),
    [aux_sym_modify_modification_token1] = ACTIONS(4421),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4421),
    [aux_sym_movelast_modification_token1] = ACTIONS(4421),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4421),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4421),
    [aux_sym_separator_action_token1] = ACTIONS(4421),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4421),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4421),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4421),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4421),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4421),
    [anon_sym_POUNDif] = ACTIONS(4421),
    [anon_sym_POUNDIF] = ACTIONS(4421),
    [anon_sym_POUNDIf] = ACTIONS(4421),
    [anon_sym_POUNDelif] = ACTIONS(4421),
    [anon_sym_POUNDELIF] = ACTIONS(4421),
    [anon_sym_POUNDElif] = ACTIONS(4421),
    [anon_sym_POUNDelse] = ACTIONS(4421),
    [anon_sym_POUNDELSE] = ACTIONS(4421),
    [anon_sym_POUNDElse] = ACTIONS(4421),
    [anon_sym_POUNDendif] = ACTIONS(4421),
    [anon_sym_POUNDENDIF] = ACTIONS(4421),
    [anon_sym_POUNDEndif] = ACTIONS(4421),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4421),
    [sym_trigger_keyword] = ACTIONS(4421),
    [sym_var_keyword] = ACTIONS(4421),
    [sym_local_keyword] = ACTIONS(4421),
    [sym_internal_keyword] = ACTIONS(4421),
    [sym_protected_keyword] = ACTIONS(4421),
    [sym_event_keyword] = ACTIONS(4421),
    [sym_fields_keyword] = ACTIONS(4421),
    [sym_keys_keyword] = ACTIONS(4421),
    [sym_fieldgroups_keyword] = ACTIONS(4421),
    [sym_actions_keyword] = ACTIONS(4421),
    [sym_layout_keyword] = ACTIONS(4421),
    [sym_area_keyword] = ACTIONS(4421),
    [sym_group_keyword] = ACTIONS(4421),
    [sym_repeater_keyword] = ACTIONS(4421),
    [sym_cuegroup_keyword] = ACTIONS(4421),
    [sym_fixed_keyword] = ACTIONS(4421),
    [sym_grid_keyword] = ACTIONS(4421),
    [sym_part_keyword] = ACTIONS(4421),
    [sym_systempart_keyword] = ACTIONS(4421),
    [sym_usercontrol_keyword] = ACTIONS(4421),
    [sym_dataset_keyword] = ACTIONS(4421),
    [sym_elements_keyword] = ACTIONS(4421),
    [sym_dataitem_keyword] = ACTIONS(4421),
    [sym_column_keyword] = ACTIONS(4421),
    [sym_filter_keyword] = ACTIONS(4421),
    [sym_labels_keyword] = ACTIONS(4421),
    [sym_rendering_keyword] = ACTIONS(4421),
    [sym_requestpage_keyword] = ACTIONS(4421),
    [sym_schema_keyword] = ACTIONS(4421),
    [sym_views_keyword] = ACTIONS(4421),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4421),
    [sym_preproc_open] = ACTIONS(4421),
    [sym_preproc_close] = ACTIONS(4421),
  },
  [STATE(3287)] = {
    [anon_sym_SEMI] = ACTIONS(4425),
    [aux_sym_where_condition_token1] = ACTIONS(4423),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4425),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4425),
    [anon_sym_LBRACK] = ACTIONS(4425),
    [aux_sym_basic_type_token6] = ACTIONS(4423),
    [aux_sym_basic_type_token22] = ACTIONS(4423),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4425),
    [aux_sym_addafter_modification_token1] = ACTIONS(4425),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4425),
    [aux_sym_modify_modification_token1] = ACTIONS(4425),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4425),
    [aux_sym_movelast_modification_token1] = ACTIONS(4425),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4425),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4425),
    [aux_sym_separator_action_token1] = ACTIONS(4425),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4425),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4425),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4425),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4425),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4425),
    [anon_sym_POUNDif] = ACTIONS(4425),
    [anon_sym_POUNDIF] = ACTIONS(4425),
    [anon_sym_POUNDIf] = ACTIONS(4425),
    [anon_sym_POUNDelif] = ACTIONS(4425),
    [anon_sym_POUNDELIF] = ACTIONS(4425),
    [anon_sym_POUNDElif] = ACTIONS(4425),
    [anon_sym_POUNDelse] = ACTIONS(4425),
    [anon_sym_POUNDELSE] = ACTIONS(4425),
    [anon_sym_POUNDElse] = ACTIONS(4425),
    [anon_sym_POUNDendif] = ACTIONS(4425),
    [anon_sym_POUNDENDIF] = ACTIONS(4425),
    [anon_sym_POUNDEndif] = ACTIONS(4425),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4425),
    [sym_trigger_keyword] = ACTIONS(4425),
    [sym_var_keyword] = ACTIONS(4425),
    [sym_local_keyword] = ACTIONS(4425),
    [sym_internal_keyword] = ACTIONS(4425),
    [sym_protected_keyword] = ACTIONS(4425),
    [sym_event_keyword] = ACTIONS(4425),
    [sym_fields_keyword] = ACTIONS(4425),
    [sym_keys_keyword] = ACTIONS(4425),
    [sym_fieldgroups_keyword] = ACTIONS(4425),
    [sym_actions_keyword] = ACTIONS(4425),
    [sym_layout_keyword] = ACTIONS(4425),
    [sym_area_keyword] = ACTIONS(4425),
    [sym_group_keyword] = ACTIONS(4425),
    [sym_repeater_keyword] = ACTIONS(4425),
    [sym_cuegroup_keyword] = ACTIONS(4425),
    [sym_fixed_keyword] = ACTIONS(4425),
    [sym_grid_keyword] = ACTIONS(4425),
    [sym_part_keyword] = ACTIONS(4425),
    [sym_systempart_keyword] = ACTIONS(4425),
    [sym_usercontrol_keyword] = ACTIONS(4425),
    [sym_dataset_keyword] = ACTIONS(4425),
    [sym_elements_keyword] = ACTIONS(4425),
    [sym_dataitem_keyword] = ACTIONS(4425),
    [sym_column_keyword] = ACTIONS(4425),
    [sym_filter_keyword] = ACTIONS(4425),
    [sym_labels_keyword] = ACTIONS(4425),
    [sym_rendering_keyword] = ACTIONS(4425),
    [sym_requestpage_keyword] = ACTIONS(4425),
    [sym_schema_keyword] = ACTIONS(4425),
    [sym_views_keyword] = ACTIONS(4425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4425),
    [sym_preproc_open] = ACTIONS(4425),
    [sym_preproc_close] = ACTIONS(4425),
  },
  [STATE(3288)] = {
    [anon_sym_SEMI] = ACTIONS(4429),
    [aux_sym_where_condition_token1] = ACTIONS(4427),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4429),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4429),
    [anon_sym_LBRACK] = ACTIONS(4429),
    [aux_sym_basic_type_token6] = ACTIONS(4427),
    [aux_sym_basic_type_token22] = ACTIONS(4427),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4429),
    [aux_sym_addafter_modification_token1] = ACTIONS(4429),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4429),
    [aux_sym_modify_modification_token1] = ACTIONS(4429),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4429),
    [aux_sym_movelast_modification_token1] = ACTIONS(4429),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4429),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4429),
    [aux_sym_separator_action_token1] = ACTIONS(4429),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4429),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4429),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4429),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4429),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4429),
    [anon_sym_POUNDif] = ACTIONS(4429),
    [anon_sym_POUNDIF] = ACTIONS(4429),
    [anon_sym_POUNDIf] = ACTIONS(4429),
    [anon_sym_POUNDelif] = ACTIONS(4429),
    [anon_sym_POUNDELIF] = ACTIONS(4429),
    [anon_sym_POUNDElif] = ACTIONS(4429),
    [anon_sym_POUNDelse] = ACTIONS(4429),
    [anon_sym_POUNDELSE] = ACTIONS(4429),
    [anon_sym_POUNDElse] = ACTIONS(4429),
    [anon_sym_POUNDendif] = ACTIONS(4429),
    [anon_sym_POUNDENDIF] = ACTIONS(4429),
    [anon_sym_POUNDEndif] = ACTIONS(4429),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4429),
    [sym_trigger_keyword] = ACTIONS(4429),
    [sym_var_keyword] = ACTIONS(4429),
    [sym_local_keyword] = ACTIONS(4429),
    [sym_internal_keyword] = ACTIONS(4429),
    [sym_protected_keyword] = ACTIONS(4429),
    [sym_event_keyword] = ACTIONS(4429),
    [sym_fields_keyword] = ACTIONS(4429),
    [sym_keys_keyword] = ACTIONS(4429),
    [sym_fieldgroups_keyword] = ACTIONS(4429),
    [sym_actions_keyword] = ACTIONS(4429),
    [sym_layout_keyword] = ACTIONS(4429),
    [sym_area_keyword] = ACTIONS(4429),
    [sym_group_keyword] = ACTIONS(4429),
    [sym_repeater_keyword] = ACTIONS(4429),
    [sym_cuegroup_keyword] = ACTIONS(4429),
    [sym_fixed_keyword] = ACTIONS(4429),
    [sym_grid_keyword] = ACTIONS(4429),
    [sym_part_keyword] = ACTIONS(4429),
    [sym_systempart_keyword] = ACTIONS(4429),
    [sym_usercontrol_keyword] = ACTIONS(4429),
    [sym_dataset_keyword] = ACTIONS(4429),
    [sym_elements_keyword] = ACTIONS(4429),
    [sym_dataitem_keyword] = ACTIONS(4429),
    [sym_column_keyword] = ACTIONS(4429),
    [sym_filter_keyword] = ACTIONS(4429),
    [sym_labels_keyword] = ACTIONS(4429),
    [sym_rendering_keyword] = ACTIONS(4429),
    [sym_requestpage_keyword] = ACTIONS(4429),
    [sym_schema_keyword] = ACTIONS(4429),
    [sym_views_keyword] = ACTIONS(4429),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4429),
    [sym_preproc_open] = ACTIONS(4429),
    [sym_preproc_close] = ACTIONS(4429),
  },
  [STATE(3289)] = {
    [anon_sym_SEMI] = ACTIONS(4433),
    [aux_sym_where_condition_token1] = ACTIONS(4431),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4433),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4433),
    [anon_sym_LBRACK] = ACTIONS(4433),
    [aux_sym_basic_type_token6] = ACTIONS(4431),
    [aux_sym_basic_type_token22] = ACTIONS(4431),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4433),
    [aux_sym_addafter_modification_token1] = ACTIONS(4433),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4433),
    [aux_sym_modify_modification_token1] = ACTIONS(4433),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4433),
    [aux_sym_movelast_modification_token1] = ACTIONS(4433),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4433),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4433),
    [aux_sym_separator_action_token1] = ACTIONS(4433),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4433),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4433),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4433),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4433),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4433),
    [anon_sym_POUNDif] = ACTIONS(4433),
    [anon_sym_POUNDIF] = ACTIONS(4433),
    [anon_sym_POUNDIf] = ACTIONS(4433),
    [anon_sym_POUNDelif] = ACTIONS(4433),
    [anon_sym_POUNDELIF] = ACTIONS(4433),
    [anon_sym_POUNDElif] = ACTIONS(4433),
    [anon_sym_POUNDelse] = ACTIONS(4433),
    [anon_sym_POUNDELSE] = ACTIONS(4433),
    [anon_sym_POUNDElse] = ACTIONS(4433),
    [anon_sym_POUNDendif] = ACTIONS(4433),
    [anon_sym_POUNDENDIF] = ACTIONS(4433),
    [anon_sym_POUNDEndif] = ACTIONS(4433),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4433),
    [sym_trigger_keyword] = ACTIONS(4433),
    [sym_var_keyword] = ACTIONS(4433),
    [sym_local_keyword] = ACTIONS(4433),
    [sym_internal_keyword] = ACTIONS(4433),
    [sym_protected_keyword] = ACTIONS(4433),
    [sym_event_keyword] = ACTIONS(4433),
    [sym_fields_keyword] = ACTIONS(4433),
    [sym_keys_keyword] = ACTIONS(4433),
    [sym_fieldgroups_keyword] = ACTIONS(4433),
    [sym_actions_keyword] = ACTIONS(4433),
    [sym_layout_keyword] = ACTIONS(4433),
    [sym_area_keyword] = ACTIONS(4433),
    [sym_group_keyword] = ACTIONS(4433),
    [sym_repeater_keyword] = ACTIONS(4433),
    [sym_cuegroup_keyword] = ACTIONS(4433),
    [sym_fixed_keyword] = ACTIONS(4433),
    [sym_grid_keyword] = ACTIONS(4433),
    [sym_part_keyword] = ACTIONS(4433),
    [sym_systempart_keyword] = ACTIONS(4433),
    [sym_usercontrol_keyword] = ACTIONS(4433),
    [sym_dataset_keyword] = ACTIONS(4433),
    [sym_elements_keyword] = ACTIONS(4433),
    [sym_dataitem_keyword] = ACTIONS(4433),
    [sym_column_keyword] = ACTIONS(4433),
    [sym_filter_keyword] = ACTIONS(4433),
    [sym_labels_keyword] = ACTIONS(4433),
    [sym_rendering_keyword] = ACTIONS(4433),
    [sym_requestpage_keyword] = ACTIONS(4433),
    [sym_schema_keyword] = ACTIONS(4433),
    [sym_views_keyword] = ACTIONS(4433),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4433),
    [sym_preproc_open] = ACTIONS(4433),
    [sym_preproc_close] = ACTIONS(4433),
  },
  [STATE(3290)] = {
    [anon_sym_SEMI] = ACTIONS(8781),
    [aux_sym_where_condition_token1] = ACTIONS(8783),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8781),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8781),
    [anon_sym_LBRACK] = ACTIONS(8781),
    [aux_sym_basic_type_token6] = ACTIONS(8783),
    [aux_sym_basic_type_token22] = ACTIONS(8783),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8781),
    [aux_sym_addafter_modification_token1] = ACTIONS(8781),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8781),
    [aux_sym_modify_modification_token1] = ACTIONS(8781),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8781),
    [aux_sym_movelast_modification_token1] = ACTIONS(8781),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8781),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8781),
    [aux_sym_separator_action_token1] = ACTIONS(8781),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8781),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8781),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8781),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8781),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8781),
    [anon_sym_POUNDif] = ACTIONS(8781),
    [anon_sym_POUNDIF] = ACTIONS(8781),
    [anon_sym_POUNDIf] = ACTIONS(8781),
    [anon_sym_POUNDelif] = ACTIONS(8781),
    [anon_sym_POUNDELIF] = ACTIONS(8781),
    [anon_sym_POUNDElif] = ACTIONS(8781),
    [anon_sym_POUNDelse] = ACTIONS(8781),
    [anon_sym_POUNDELSE] = ACTIONS(8781),
    [anon_sym_POUNDElse] = ACTIONS(8781),
    [anon_sym_POUNDendif] = ACTIONS(8781),
    [anon_sym_POUNDENDIF] = ACTIONS(8781),
    [anon_sym_POUNDEndif] = ACTIONS(8781),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8781),
    [sym_trigger_keyword] = ACTIONS(8781),
    [sym_var_keyword] = ACTIONS(8781),
    [sym_local_keyword] = ACTIONS(8781),
    [sym_internal_keyword] = ACTIONS(8781),
    [sym_protected_keyword] = ACTIONS(8781),
    [sym_event_keyword] = ACTIONS(8781),
    [sym_fields_keyword] = ACTIONS(8781),
    [sym_keys_keyword] = ACTIONS(8781),
    [sym_fieldgroups_keyword] = ACTIONS(8781),
    [sym_actions_keyword] = ACTIONS(8781),
    [sym_layout_keyword] = ACTIONS(8781),
    [sym_area_keyword] = ACTIONS(8781),
    [sym_group_keyword] = ACTIONS(8781),
    [sym_repeater_keyword] = ACTIONS(8781),
    [sym_cuegroup_keyword] = ACTIONS(8781),
    [sym_fixed_keyword] = ACTIONS(8781),
    [sym_grid_keyword] = ACTIONS(8781),
    [sym_part_keyword] = ACTIONS(8781),
    [sym_systempart_keyword] = ACTIONS(8781),
    [sym_usercontrol_keyword] = ACTIONS(8781),
    [sym_dataset_keyword] = ACTIONS(8781),
    [sym_elements_keyword] = ACTIONS(8781),
    [sym_dataitem_keyword] = ACTIONS(8781),
    [sym_column_keyword] = ACTIONS(8781),
    [sym_filter_keyword] = ACTIONS(8781),
    [sym_labels_keyword] = ACTIONS(8781),
    [sym_rendering_keyword] = ACTIONS(8781),
    [sym_requestpage_keyword] = ACTIONS(8781),
    [sym_schema_keyword] = ACTIONS(8781),
    [sym_views_keyword] = ACTIONS(8781),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8781),
    [sym_preproc_open] = ACTIONS(8781),
    [sym_preproc_close] = ACTIONS(8781),
  },
  [STATE(3291)] = {
    [anon_sym_SEMI] = ACTIONS(8785),
    [aux_sym_where_condition_token1] = ACTIONS(8787),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8785),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8785),
    [anon_sym_LBRACK] = ACTIONS(8785),
    [aux_sym_basic_type_token6] = ACTIONS(8787),
    [aux_sym_basic_type_token22] = ACTIONS(8787),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8785),
    [aux_sym_addafter_modification_token1] = ACTIONS(8785),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8785),
    [aux_sym_modify_modification_token1] = ACTIONS(8785),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8785),
    [aux_sym_movelast_modification_token1] = ACTIONS(8785),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8785),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8785),
    [aux_sym_separator_action_token1] = ACTIONS(8785),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8785),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8785),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8785),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8785),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8785),
    [anon_sym_POUNDif] = ACTIONS(8785),
    [anon_sym_POUNDIF] = ACTIONS(8785),
    [anon_sym_POUNDIf] = ACTIONS(8785),
    [anon_sym_POUNDelif] = ACTIONS(8785),
    [anon_sym_POUNDELIF] = ACTIONS(8785),
    [anon_sym_POUNDElif] = ACTIONS(8785),
    [anon_sym_POUNDelse] = ACTIONS(8785),
    [anon_sym_POUNDELSE] = ACTIONS(8785),
    [anon_sym_POUNDElse] = ACTIONS(8785),
    [anon_sym_POUNDendif] = ACTIONS(8785),
    [anon_sym_POUNDENDIF] = ACTIONS(8785),
    [anon_sym_POUNDEndif] = ACTIONS(8785),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8785),
    [sym_trigger_keyword] = ACTIONS(8785),
    [sym_var_keyword] = ACTIONS(8785),
    [sym_local_keyword] = ACTIONS(8785),
    [sym_internal_keyword] = ACTIONS(8785),
    [sym_protected_keyword] = ACTIONS(8785),
    [sym_event_keyword] = ACTIONS(8785),
    [sym_fields_keyword] = ACTIONS(8785),
    [sym_keys_keyword] = ACTIONS(8785),
    [sym_fieldgroups_keyword] = ACTIONS(8785),
    [sym_actions_keyword] = ACTIONS(8785),
    [sym_layout_keyword] = ACTIONS(8785),
    [sym_area_keyword] = ACTIONS(8785),
    [sym_group_keyword] = ACTIONS(8785),
    [sym_repeater_keyword] = ACTIONS(8785),
    [sym_cuegroup_keyword] = ACTIONS(8785),
    [sym_fixed_keyword] = ACTIONS(8785),
    [sym_grid_keyword] = ACTIONS(8785),
    [sym_part_keyword] = ACTIONS(8785),
    [sym_systempart_keyword] = ACTIONS(8785),
    [sym_usercontrol_keyword] = ACTIONS(8785),
    [sym_dataset_keyword] = ACTIONS(8785),
    [sym_elements_keyword] = ACTIONS(8785),
    [sym_dataitem_keyword] = ACTIONS(8785),
    [sym_column_keyword] = ACTIONS(8785),
    [sym_filter_keyword] = ACTIONS(8785),
    [sym_labels_keyword] = ACTIONS(8785),
    [sym_rendering_keyword] = ACTIONS(8785),
    [sym_requestpage_keyword] = ACTIONS(8785),
    [sym_schema_keyword] = ACTIONS(8785),
    [sym_views_keyword] = ACTIONS(8785),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8785),
    [sym_preproc_open] = ACTIONS(8785),
    [sym_preproc_close] = ACTIONS(8785),
  },
  [STATE(3292)] = {
    [anon_sym_SEMI] = ACTIONS(8789),
    [aux_sym_where_condition_token1] = ACTIONS(8791),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8789),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8789),
    [anon_sym_LBRACK] = ACTIONS(8789),
    [aux_sym_basic_type_token6] = ACTIONS(8791),
    [aux_sym_basic_type_token22] = ACTIONS(8791),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8789),
    [aux_sym_addafter_modification_token1] = ACTIONS(8789),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8789),
    [aux_sym_modify_modification_token1] = ACTIONS(8789),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8789),
    [aux_sym_movelast_modification_token1] = ACTIONS(8789),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8789),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8789),
    [aux_sym_separator_action_token1] = ACTIONS(8789),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8789),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8789),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8789),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8789),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8789),
    [anon_sym_POUNDif] = ACTIONS(8789),
    [anon_sym_POUNDIF] = ACTIONS(8789),
    [anon_sym_POUNDIf] = ACTIONS(8789),
    [anon_sym_POUNDelif] = ACTIONS(8789),
    [anon_sym_POUNDELIF] = ACTIONS(8789),
    [anon_sym_POUNDElif] = ACTIONS(8789),
    [anon_sym_POUNDelse] = ACTIONS(8789),
    [anon_sym_POUNDELSE] = ACTIONS(8789),
    [anon_sym_POUNDElse] = ACTIONS(8789),
    [anon_sym_POUNDendif] = ACTIONS(8789),
    [anon_sym_POUNDENDIF] = ACTIONS(8789),
    [anon_sym_POUNDEndif] = ACTIONS(8789),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8789),
    [sym_trigger_keyword] = ACTIONS(8789),
    [sym_var_keyword] = ACTIONS(8789),
    [sym_local_keyword] = ACTIONS(8789),
    [sym_internal_keyword] = ACTIONS(8789),
    [sym_protected_keyword] = ACTIONS(8789),
    [sym_event_keyword] = ACTIONS(8789),
    [sym_fields_keyword] = ACTIONS(8789),
    [sym_keys_keyword] = ACTIONS(8789),
    [sym_fieldgroups_keyword] = ACTIONS(8789),
    [sym_actions_keyword] = ACTIONS(8789),
    [sym_layout_keyword] = ACTIONS(8789),
    [sym_area_keyword] = ACTIONS(8789),
    [sym_group_keyword] = ACTIONS(8789),
    [sym_repeater_keyword] = ACTIONS(8789),
    [sym_cuegroup_keyword] = ACTIONS(8789),
    [sym_fixed_keyword] = ACTIONS(8789),
    [sym_grid_keyword] = ACTIONS(8789),
    [sym_part_keyword] = ACTIONS(8789),
    [sym_systempart_keyword] = ACTIONS(8789),
    [sym_usercontrol_keyword] = ACTIONS(8789),
    [sym_dataset_keyword] = ACTIONS(8789),
    [sym_elements_keyword] = ACTIONS(8789),
    [sym_dataitem_keyword] = ACTIONS(8789),
    [sym_column_keyword] = ACTIONS(8789),
    [sym_filter_keyword] = ACTIONS(8789),
    [sym_labels_keyword] = ACTIONS(8789),
    [sym_rendering_keyword] = ACTIONS(8789),
    [sym_requestpage_keyword] = ACTIONS(8789),
    [sym_schema_keyword] = ACTIONS(8789),
    [sym_views_keyword] = ACTIONS(8789),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8789),
    [sym_preproc_open] = ACTIONS(8789),
    [sym_preproc_close] = ACTIONS(8789),
  },
  [STATE(3293)] = {
    [anon_sym_SEMI] = ACTIONS(4437),
    [aux_sym_where_condition_token1] = ACTIONS(4435),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4437),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4437),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [aux_sym_basic_type_token6] = ACTIONS(4435),
    [aux_sym_basic_type_token22] = ACTIONS(4435),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4437),
    [aux_sym_addafter_modification_token1] = ACTIONS(4437),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4437),
    [aux_sym_modify_modification_token1] = ACTIONS(4437),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4437),
    [aux_sym_movelast_modification_token1] = ACTIONS(4437),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4437),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4437),
    [aux_sym_separator_action_token1] = ACTIONS(4437),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4437),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4437),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4437),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4437),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4437),
    [anon_sym_POUNDif] = ACTIONS(4437),
    [anon_sym_POUNDIF] = ACTIONS(4437),
    [anon_sym_POUNDIf] = ACTIONS(4437),
    [anon_sym_POUNDelif] = ACTIONS(4437),
    [anon_sym_POUNDELIF] = ACTIONS(4437),
    [anon_sym_POUNDElif] = ACTIONS(4437),
    [anon_sym_POUNDelse] = ACTIONS(4437),
    [anon_sym_POUNDELSE] = ACTIONS(4437),
    [anon_sym_POUNDElse] = ACTIONS(4437),
    [anon_sym_POUNDendif] = ACTIONS(4437),
    [anon_sym_POUNDENDIF] = ACTIONS(4437),
    [anon_sym_POUNDEndif] = ACTIONS(4437),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4437),
    [sym_trigger_keyword] = ACTIONS(4437),
    [sym_var_keyword] = ACTIONS(4437),
    [sym_local_keyword] = ACTIONS(4437),
    [sym_internal_keyword] = ACTIONS(4437),
    [sym_protected_keyword] = ACTIONS(4437),
    [sym_event_keyword] = ACTIONS(4437),
    [sym_fields_keyword] = ACTIONS(4437),
    [sym_keys_keyword] = ACTIONS(4437),
    [sym_fieldgroups_keyword] = ACTIONS(4437),
    [sym_actions_keyword] = ACTIONS(4437),
    [sym_layout_keyword] = ACTIONS(4437),
    [sym_area_keyword] = ACTIONS(4437),
    [sym_group_keyword] = ACTIONS(4437),
    [sym_repeater_keyword] = ACTIONS(4437),
    [sym_cuegroup_keyword] = ACTIONS(4437),
    [sym_fixed_keyword] = ACTIONS(4437),
    [sym_grid_keyword] = ACTIONS(4437),
    [sym_part_keyword] = ACTIONS(4437),
    [sym_systempart_keyword] = ACTIONS(4437),
    [sym_usercontrol_keyword] = ACTIONS(4437),
    [sym_dataset_keyword] = ACTIONS(4437),
    [sym_elements_keyword] = ACTIONS(4437),
    [sym_dataitem_keyword] = ACTIONS(4437),
    [sym_column_keyword] = ACTIONS(4437),
    [sym_filter_keyword] = ACTIONS(4437),
    [sym_labels_keyword] = ACTIONS(4437),
    [sym_rendering_keyword] = ACTIONS(4437),
    [sym_requestpage_keyword] = ACTIONS(4437),
    [sym_schema_keyword] = ACTIONS(4437),
    [sym_views_keyword] = ACTIONS(4437),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4437),
    [sym_preproc_open] = ACTIONS(4437),
    [sym_preproc_close] = ACTIONS(4437),
  },
  [STATE(3294)] = {
    [anon_sym_SEMI] = ACTIONS(4441),
    [aux_sym_where_condition_token1] = ACTIONS(4439),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(4439),
    [aux_sym_basic_type_token22] = ACTIONS(4439),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4441),
    [aux_sym_addafter_modification_token1] = ACTIONS(4441),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4441),
    [aux_sym_modify_modification_token1] = ACTIONS(4441),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4441),
    [aux_sym_movelast_modification_token1] = ACTIONS(4441),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4441),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4441),
    [aux_sym_separator_action_token1] = ACTIONS(4441),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4441),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4441),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4441),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4441),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4441),
    [anon_sym_POUNDif] = ACTIONS(4441),
    [anon_sym_POUNDIF] = ACTIONS(4441),
    [anon_sym_POUNDIf] = ACTIONS(4441),
    [anon_sym_POUNDelif] = ACTIONS(4441),
    [anon_sym_POUNDELIF] = ACTIONS(4441),
    [anon_sym_POUNDElif] = ACTIONS(4441),
    [anon_sym_POUNDelse] = ACTIONS(4441),
    [anon_sym_POUNDELSE] = ACTIONS(4441),
    [anon_sym_POUNDElse] = ACTIONS(4441),
    [anon_sym_POUNDendif] = ACTIONS(4441),
    [anon_sym_POUNDENDIF] = ACTIONS(4441),
    [anon_sym_POUNDEndif] = ACTIONS(4441),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4441),
    [sym_trigger_keyword] = ACTIONS(4441),
    [sym_var_keyword] = ACTIONS(4441),
    [sym_local_keyword] = ACTIONS(4441),
    [sym_internal_keyword] = ACTIONS(4441),
    [sym_protected_keyword] = ACTIONS(4441),
    [sym_event_keyword] = ACTIONS(4441),
    [sym_fields_keyword] = ACTIONS(4441),
    [sym_keys_keyword] = ACTIONS(4441),
    [sym_fieldgroups_keyword] = ACTIONS(4441),
    [sym_actions_keyword] = ACTIONS(4441),
    [sym_layout_keyword] = ACTIONS(4441),
    [sym_area_keyword] = ACTIONS(4441),
    [sym_group_keyword] = ACTIONS(4441),
    [sym_repeater_keyword] = ACTIONS(4441),
    [sym_cuegroup_keyword] = ACTIONS(4441),
    [sym_fixed_keyword] = ACTIONS(4441),
    [sym_grid_keyword] = ACTIONS(4441),
    [sym_part_keyword] = ACTIONS(4441),
    [sym_systempart_keyword] = ACTIONS(4441),
    [sym_usercontrol_keyword] = ACTIONS(4441),
    [sym_dataset_keyword] = ACTIONS(4441),
    [sym_elements_keyword] = ACTIONS(4441),
    [sym_dataitem_keyword] = ACTIONS(4441),
    [sym_column_keyword] = ACTIONS(4441),
    [sym_filter_keyword] = ACTIONS(4441),
    [sym_labels_keyword] = ACTIONS(4441),
    [sym_rendering_keyword] = ACTIONS(4441),
    [sym_requestpage_keyword] = ACTIONS(4441),
    [sym_schema_keyword] = ACTIONS(4441),
    [sym_views_keyword] = ACTIONS(4441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4441),
    [sym_preproc_open] = ACTIONS(4441),
    [sym_preproc_close] = ACTIONS(4441),
  },
  [STATE(3295)] = {
    [anon_sym_SEMI] = ACTIONS(4445),
    [aux_sym_where_condition_token1] = ACTIONS(4443),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4445),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4445),
    [anon_sym_LBRACK] = ACTIONS(4445),
    [aux_sym_basic_type_token6] = ACTIONS(4443),
    [aux_sym_basic_type_token22] = ACTIONS(4443),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4445),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4445),
    [aux_sym_modify_modification_token1] = ACTIONS(4445),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4445),
    [aux_sym_movelast_modification_token1] = ACTIONS(4445),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4445),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4445),
    [aux_sym_separator_action_token1] = ACTIONS(4445),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4445),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4445),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4445),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4445),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4445),
    [anon_sym_POUNDif] = ACTIONS(4445),
    [anon_sym_POUNDIF] = ACTIONS(4445),
    [anon_sym_POUNDIf] = ACTIONS(4445),
    [anon_sym_POUNDelif] = ACTIONS(4445),
    [anon_sym_POUNDELIF] = ACTIONS(4445),
    [anon_sym_POUNDElif] = ACTIONS(4445),
    [anon_sym_POUNDelse] = ACTIONS(4445),
    [anon_sym_POUNDELSE] = ACTIONS(4445),
    [anon_sym_POUNDElse] = ACTIONS(4445),
    [anon_sym_POUNDendif] = ACTIONS(4445),
    [anon_sym_POUNDENDIF] = ACTIONS(4445),
    [anon_sym_POUNDEndif] = ACTIONS(4445),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4445),
    [sym_trigger_keyword] = ACTIONS(4445),
    [sym_var_keyword] = ACTIONS(4445),
    [sym_local_keyword] = ACTIONS(4445),
    [sym_internal_keyword] = ACTIONS(4445),
    [sym_protected_keyword] = ACTIONS(4445),
    [sym_event_keyword] = ACTIONS(4445),
    [sym_fields_keyword] = ACTIONS(4445),
    [sym_keys_keyword] = ACTIONS(4445),
    [sym_fieldgroups_keyword] = ACTIONS(4445),
    [sym_actions_keyword] = ACTIONS(4445),
    [sym_layout_keyword] = ACTIONS(4445),
    [sym_area_keyword] = ACTIONS(4445),
    [sym_group_keyword] = ACTIONS(4445),
    [sym_repeater_keyword] = ACTIONS(4445),
    [sym_cuegroup_keyword] = ACTIONS(4445),
    [sym_fixed_keyword] = ACTIONS(4445),
    [sym_grid_keyword] = ACTIONS(4445),
    [sym_part_keyword] = ACTIONS(4445),
    [sym_systempart_keyword] = ACTIONS(4445),
    [sym_usercontrol_keyword] = ACTIONS(4445),
    [sym_dataset_keyword] = ACTIONS(4445),
    [sym_elements_keyword] = ACTIONS(4445),
    [sym_dataitem_keyword] = ACTIONS(4445),
    [sym_column_keyword] = ACTIONS(4445),
    [sym_filter_keyword] = ACTIONS(4445),
    [sym_labels_keyword] = ACTIONS(4445),
    [sym_rendering_keyword] = ACTIONS(4445),
    [sym_requestpage_keyword] = ACTIONS(4445),
    [sym_schema_keyword] = ACTIONS(4445),
    [sym_views_keyword] = ACTIONS(4445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4445),
    [sym_preproc_open] = ACTIONS(4445),
    [sym_preproc_close] = ACTIONS(4445),
  },
  [STATE(3296)] = {
    [anon_sym_SEMI] = ACTIONS(4449),
    [aux_sym_where_condition_token1] = ACTIONS(4447),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4449),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4449),
    [anon_sym_LBRACK] = ACTIONS(4449),
    [aux_sym_basic_type_token6] = ACTIONS(4447),
    [aux_sym_basic_type_token22] = ACTIONS(4447),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4449),
    [aux_sym_addafter_modification_token1] = ACTIONS(4449),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4449),
    [aux_sym_modify_modification_token1] = ACTIONS(4449),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4449),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4449),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4449),
    [aux_sym_separator_action_token1] = ACTIONS(4449),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4449),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4449),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4449),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4449),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4449),
    [anon_sym_POUNDif] = ACTIONS(4449),
    [anon_sym_POUNDIF] = ACTIONS(4449),
    [anon_sym_POUNDIf] = ACTIONS(4449),
    [anon_sym_POUNDelif] = ACTIONS(4449),
    [anon_sym_POUNDELIF] = ACTIONS(4449),
    [anon_sym_POUNDElif] = ACTIONS(4449),
    [anon_sym_POUNDelse] = ACTIONS(4449),
    [anon_sym_POUNDELSE] = ACTIONS(4449),
    [anon_sym_POUNDElse] = ACTIONS(4449),
    [anon_sym_POUNDendif] = ACTIONS(4449),
    [anon_sym_POUNDENDIF] = ACTIONS(4449),
    [anon_sym_POUNDEndif] = ACTIONS(4449),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4449),
    [sym_trigger_keyword] = ACTIONS(4449),
    [sym_var_keyword] = ACTIONS(4449),
    [sym_local_keyword] = ACTIONS(4449),
    [sym_internal_keyword] = ACTIONS(4449),
    [sym_protected_keyword] = ACTIONS(4449),
    [sym_event_keyword] = ACTIONS(4449),
    [sym_fields_keyword] = ACTIONS(4449),
    [sym_keys_keyword] = ACTIONS(4449),
    [sym_fieldgroups_keyword] = ACTIONS(4449),
    [sym_actions_keyword] = ACTIONS(4449),
    [sym_layout_keyword] = ACTIONS(4449),
    [sym_area_keyword] = ACTIONS(4449),
    [sym_group_keyword] = ACTIONS(4449),
    [sym_repeater_keyword] = ACTIONS(4449),
    [sym_cuegroup_keyword] = ACTIONS(4449),
    [sym_fixed_keyword] = ACTIONS(4449),
    [sym_grid_keyword] = ACTIONS(4449),
    [sym_part_keyword] = ACTIONS(4449),
    [sym_systempart_keyword] = ACTIONS(4449),
    [sym_usercontrol_keyword] = ACTIONS(4449),
    [sym_dataset_keyword] = ACTIONS(4449),
    [sym_elements_keyword] = ACTIONS(4449),
    [sym_dataitem_keyword] = ACTIONS(4449),
    [sym_column_keyword] = ACTIONS(4449),
    [sym_filter_keyword] = ACTIONS(4449),
    [sym_labels_keyword] = ACTIONS(4449),
    [sym_rendering_keyword] = ACTIONS(4449),
    [sym_requestpage_keyword] = ACTIONS(4449),
    [sym_schema_keyword] = ACTIONS(4449),
    [sym_views_keyword] = ACTIONS(4449),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4449),
    [sym_preproc_open] = ACTIONS(4449),
    [sym_preproc_close] = ACTIONS(4449),
  },
  [STATE(3297)] = {
    [anon_sym_SEMI] = ACTIONS(4453),
    [aux_sym_where_condition_token1] = ACTIONS(4451),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4453),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4453),
    [anon_sym_LBRACK] = ACTIONS(4453),
    [aux_sym_basic_type_token6] = ACTIONS(4451),
    [aux_sym_basic_type_token22] = ACTIONS(4451),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4453),
    [aux_sym_addafter_modification_token1] = ACTIONS(4453),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4453),
    [aux_sym_modify_modification_token1] = ACTIONS(4453),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4453),
    [aux_sym_movelast_modification_token1] = ACTIONS(4453),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4453),
    [aux_sym_separator_action_token1] = ACTIONS(4453),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4453),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4453),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4453),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4453),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4453),
    [anon_sym_POUNDif] = ACTIONS(4453),
    [anon_sym_POUNDIF] = ACTIONS(4453),
    [anon_sym_POUNDIf] = ACTIONS(4453),
    [anon_sym_POUNDelif] = ACTIONS(4453),
    [anon_sym_POUNDELIF] = ACTIONS(4453),
    [anon_sym_POUNDElif] = ACTIONS(4453),
    [anon_sym_POUNDelse] = ACTIONS(4453),
    [anon_sym_POUNDELSE] = ACTIONS(4453),
    [anon_sym_POUNDElse] = ACTIONS(4453),
    [anon_sym_POUNDendif] = ACTIONS(4453),
    [anon_sym_POUNDENDIF] = ACTIONS(4453),
    [anon_sym_POUNDEndif] = ACTIONS(4453),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4453),
    [sym_trigger_keyword] = ACTIONS(4453),
    [sym_var_keyword] = ACTIONS(4453),
    [sym_local_keyword] = ACTIONS(4453),
    [sym_internal_keyword] = ACTIONS(4453),
    [sym_protected_keyword] = ACTIONS(4453),
    [sym_event_keyword] = ACTIONS(4453),
    [sym_fields_keyword] = ACTIONS(4453),
    [sym_keys_keyword] = ACTIONS(4453),
    [sym_fieldgroups_keyword] = ACTIONS(4453),
    [sym_actions_keyword] = ACTIONS(4453),
    [sym_layout_keyword] = ACTIONS(4453),
    [sym_area_keyword] = ACTIONS(4453),
    [sym_group_keyword] = ACTIONS(4453),
    [sym_repeater_keyword] = ACTIONS(4453),
    [sym_cuegroup_keyword] = ACTIONS(4453),
    [sym_fixed_keyword] = ACTIONS(4453),
    [sym_grid_keyword] = ACTIONS(4453),
    [sym_part_keyword] = ACTIONS(4453),
    [sym_systempart_keyword] = ACTIONS(4453),
    [sym_usercontrol_keyword] = ACTIONS(4453),
    [sym_dataset_keyword] = ACTIONS(4453),
    [sym_elements_keyword] = ACTIONS(4453),
    [sym_dataitem_keyword] = ACTIONS(4453),
    [sym_column_keyword] = ACTIONS(4453),
    [sym_filter_keyword] = ACTIONS(4453),
    [sym_labels_keyword] = ACTIONS(4453),
    [sym_rendering_keyword] = ACTIONS(4453),
    [sym_requestpage_keyword] = ACTIONS(4453),
    [sym_schema_keyword] = ACTIONS(4453),
    [sym_views_keyword] = ACTIONS(4453),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4453),
    [sym_preproc_open] = ACTIONS(4453),
    [sym_preproc_close] = ACTIONS(4453),
  },
  [STATE(3298)] = {
    [anon_sym_SEMI] = ACTIONS(8793),
    [aux_sym_where_condition_token1] = ACTIONS(8795),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8793),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8793),
    [anon_sym_LBRACK] = ACTIONS(8793),
    [aux_sym_basic_type_token6] = ACTIONS(8795),
    [aux_sym_basic_type_token22] = ACTIONS(8795),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8793),
    [aux_sym_addafter_modification_token1] = ACTIONS(8793),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8793),
    [aux_sym_modify_modification_token1] = ACTIONS(8793),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8793),
    [aux_sym_movelast_modification_token1] = ACTIONS(8793),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8793),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8793),
    [aux_sym_separator_action_token1] = ACTIONS(8793),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8793),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8793),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8793),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8793),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8793),
    [anon_sym_POUNDif] = ACTIONS(8793),
    [anon_sym_POUNDIF] = ACTIONS(8793),
    [anon_sym_POUNDIf] = ACTIONS(8793),
    [anon_sym_POUNDelif] = ACTIONS(8793),
    [anon_sym_POUNDELIF] = ACTIONS(8793),
    [anon_sym_POUNDElif] = ACTIONS(8793),
    [anon_sym_POUNDelse] = ACTIONS(8793),
    [anon_sym_POUNDELSE] = ACTIONS(8793),
    [anon_sym_POUNDElse] = ACTIONS(8793),
    [anon_sym_POUNDendif] = ACTIONS(8793),
    [anon_sym_POUNDENDIF] = ACTIONS(8793),
    [anon_sym_POUNDEndif] = ACTIONS(8793),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8793),
    [sym_trigger_keyword] = ACTIONS(8793),
    [sym_var_keyword] = ACTIONS(8793),
    [sym_local_keyword] = ACTIONS(8793),
    [sym_internal_keyword] = ACTIONS(8793),
    [sym_protected_keyword] = ACTIONS(8793),
    [sym_event_keyword] = ACTIONS(8793),
    [sym_fields_keyword] = ACTIONS(8793),
    [sym_keys_keyword] = ACTIONS(8793),
    [sym_fieldgroups_keyword] = ACTIONS(8793),
    [sym_actions_keyword] = ACTIONS(8793),
    [sym_layout_keyword] = ACTIONS(8793),
    [sym_area_keyword] = ACTIONS(8793),
    [sym_group_keyword] = ACTIONS(8793),
    [sym_repeater_keyword] = ACTIONS(8793),
    [sym_cuegroup_keyword] = ACTIONS(8793),
    [sym_fixed_keyword] = ACTIONS(8793),
    [sym_grid_keyword] = ACTIONS(8793),
    [sym_part_keyword] = ACTIONS(8793),
    [sym_systempart_keyword] = ACTIONS(8793),
    [sym_usercontrol_keyword] = ACTIONS(8793),
    [sym_dataset_keyword] = ACTIONS(8793),
    [sym_elements_keyword] = ACTIONS(8793),
    [sym_dataitem_keyword] = ACTIONS(8793),
    [sym_column_keyword] = ACTIONS(8793),
    [sym_filter_keyword] = ACTIONS(8793),
    [sym_labels_keyword] = ACTIONS(8793),
    [sym_rendering_keyword] = ACTIONS(8793),
    [sym_requestpage_keyword] = ACTIONS(8793),
    [sym_schema_keyword] = ACTIONS(8793),
    [sym_views_keyword] = ACTIONS(8793),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8793),
    [sym_preproc_open] = ACTIONS(8793),
    [sym_preproc_close] = ACTIONS(8793),
  },
  [STATE(3299)] = {
    [anon_sym_SEMI] = ACTIONS(8797),
    [aux_sym_where_condition_token1] = ACTIONS(8799),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8797),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8797),
    [anon_sym_LBRACK] = ACTIONS(8797),
    [aux_sym_basic_type_token6] = ACTIONS(8799),
    [aux_sym_basic_type_token22] = ACTIONS(8799),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8797),
    [aux_sym_addafter_modification_token1] = ACTIONS(8797),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8797),
    [aux_sym_modify_modification_token1] = ACTIONS(8797),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8797),
    [aux_sym_movelast_modification_token1] = ACTIONS(8797),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8797),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8797),
    [aux_sym_separator_action_token1] = ACTIONS(8797),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8797),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8797),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8797),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8797),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8797),
    [anon_sym_POUNDif] = ACTIONS(8797),
    [anon_sym_POUNDIF] = ACTIONS(8797),
    [anon_sym_POUNDIf] = ACTIONS(8797),
    [anon_sym_POUNDelif] = ACTIONS(8797),
    [anon_sym_POUNDELIF] = ACTIONS(8797),
    [anon_sym_POUNDElif] = ACTIONS(8797),
    [anon_sym_POUNDelse] = ACTIONS(8797),
    [anon_sym_POUNDELSE] = ACTIONS(8797),
    [anon_sym_POUNDElse] = ACTIONS(8797),
    [anon_sym_POUNDendif] = ACTIONS(8797),
    [anon_sym_POUNDENDIF] = ACTIONS(8797),
    [anon_sym_POUNDEndif] = ACTIONS(8797),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8797),
    [sym_trigger_keyword] = ACTIONS(8797),
    [sym_var_keyword] = ACTIONS(8797),
    [sym_local_keyword] = ACTIONS(8797),
    [sym_internal_keyword] = ACTIONS(8797),
    [sym_protected_keyword] = ACTIONS(8797),
    [sym_event_keyword] = ACTIONS(8797),
    [sym_fields_keyword] = ACTIONS(8797),
    [sym_keys_keyword] = ACTIONS(8797),
    [sym_fieldgroups_keyword] = ACTIONS(8797),
    [sym_actions_keyword] = ACTIONS(8797),
    [sym_layout_keyword] = ACTIONS(8797),
    [sym_area_keyword] = ACTIONS(8797),
    [sym_group_keyword] = ACTIONS(8797),
    [sym_repeater_keyword] = ACTIONS(8797),
    [sym_cuegroup_keyword] = ACTIONS(8797),
    [sym_fixed_keyword] = ACTIONS(8797),
    [sym_grid_keyword] = ACTIONS(8797),
    [sym_part_keyword] = ACTIONS(8797),
    [sym_systempart_keyword] = ACTIONS(8797),
    [sym_usercontrol_keyword] = ACTIONS(8797),
    [sym_dataset_keyword] = ACTIONS(8797),
    [sym_elements_keyword] = ACTIONS(8797),
    [sym_dataitem_keyword] = ACTIONS(8797),
    [sym_column_keyword] = ACTIONS(8797),
    [sym_filter_keyword] = ACTIONS(8797),
    [sym_labels_keyword] = ACTIONS(8797),
    [sym_rendering_keyword] = ACTIONS(8797),
    [sym_requestpage_keyword] = ACTIONS(8797),
    [sym_schema_keyword] = ACTIONS(8797),
    [sym_views_keyword] = ACTIONS(8797),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8797),
    [sym_preproc_open] = ACTIONS(8797),
    [sym_preproc_close] = ACTIONS(8797),
  },
  [STATE(3300)] = {
    [anon_sym_SEMI] = ACTIONS(8797),
    [aux_sym_where_condition_token1] = ACTIONS(8799),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8797),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8797),
    [anon_sym_LBRACK] = ACTIONS(8797),
    [aux_sym_basic_type_token6] = ACTIONS(8799),
    [aux_sym_basic_type_token22] = ACTIONS(8799),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8797),
    [aux_sym_addafter_modification_token1] = ACTIONS(8797),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8797),
    [aux_sym_modify_modification_token1] = ACTIONS(8797),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8797),
    [aux_sym_movelast_modification_token1] = ACTIONS(8797),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8797),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8797),
    [aux_sym_separator_action_token1] = ACTIONS(8797),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8797),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8797),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8797),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8797),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8797),
    [anon_sym_POUNDif] = ACTIONS(8797),
    [anon_sym_POUNDIF] = ACTIONS(8797),
    [anon_sym_POUNDIf] = ACTIONS(8797),
    [anon_sym_POUNDelif] = ACTIONS(8797),
    [anon_sym_POUNDELIF] = ACTIONS(8797),
    [anon_sym_POUNDElif] = ACTIONS(8797),
    [anon_sym_POUNDelse] = ACTIONS(8797),
    [anon_sym_POUNDELSE] = ACTIONS(8797),
    [anon_sym_POUNDElse] = ACTIONS(8797),
    [anon_sym_POUNDendif] = ACTIONS(8797),
    [anon_sym_POUNDENDIF] = ACTIONS(8797),
    [anon_sym_POUNDEndif] = ACTIONS(8797),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8797),
    [sym_trigger_keyword] = ACTIONS(8797),
    [sym_var_keyword] = ACTIONS(8797),
    [sym_local_keyword] = ACTIONS(8797),
    [sym_internal_keyword] = ACTIONS(8797),
    [sym_protected_keyword] = ACTIONS(8797),
    [sym_event_keyword] = ACTIONS(8797),
    [sym_fields_keyword] = ACTIONS(8797),
    [sym_keys_keyword] = ACTIONS(8797),
    [sym_fieldgroups_keyword] = ACTIONS(8797),
    [sym_actions_keyword] = ACTIONS(8797),
    [sym_layout_keyword] = ACTIONS(8797),
    [sym_area_keyword] = ACTIONS(8797),
    [sym_group_keyword] = ACTIONS(8797),
    [sym_repeater_keyword] = ACTIONS(8797),
    [sym_cuegroup_keyword] = ACTIONS(8797),
    [sym_fixed_keyword] = ACTIONS(8797),
    [sym_grid_keyword] = ACTIONS(8797),
    [sym_part_keyword] = ACTIONS(8797),
    [sym_systempart_keyword] = ACTIONS(8797),
    [sym_usercontrol_keyword] = ACTIONS(8797),
    [sym_dataset_keyword] = ACTIONS(8797),
    [sym_elements_keyword] = ACTIONS(8797),
    [sym_dataitem_keyword] = ACTIONS(8797),
    [sym_column_keyword] = ACTIONS(8797),
    [sym_filter_keyword] = ACTIONS(8797),
    [sym_labels_keyword] = ACTIONS(8797),
    [sym_rendering_keyword] = ACTIONS(8797),
    [sym_requestpage_keyword] = ACTIONS(8797),
    [sym_schema_keyword] = ACTIONS(8797),
    [sym_views_keyword] = ACTIONS(8797),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8797),
    [sym_preproc_open] = ACTIONS(8797),
    [sym_preproc_close] = ACTIONS(8797),
  },
  [STATE(3301)] = {
    [anon_sym_SEMI] = ACTIONS(8797),
    [aux_sym_where_condition_token1] = ACTIONS(8799),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8797),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8797),
    [anon_sym_LBRACK] = ACTIONS(8797),
    [aux_sym_basic_type_token6] = ACTIONS(8799),
    [aux_sym_basic_type_token22] = ACTIONS(8799),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8797),
    [aux_sym_addafter_modification_token1] = ACTIONS(8797),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8797),
    [aux_sym_modify_modification_token1] = ACTIONS(8797),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8797),
    [aux_sym_movelast_modification_token1] = ACTIONS(8797),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8797),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8797),
    [aux_sym_separator_action_token1] = ACTIONS(8797),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8797),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8797),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8797),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8797),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8797),
    [anon_sym_POUNDif] = ACTIONS(8797),
    [anon_sym_POUNDIF] = ACTIONS(8797),
    [anon_sym_POUNDIf] = ACTIONS(8797),
    [anon_sym_POUNDelif] = ACTIONS(8797),
    [anon_sym_POUNDELIF] = ACTIONS(8797),
    [anon_sym_POUNDElif] = ACTIONS(8797),
    [anon_sym_POUNDelse] = ACTIONS(8797),
    [anon_sym_POUNDELSE] = ACTIONS(8797),
    [anon_sym_POUNDElse] = ACTIONS(8797),
    [anon_sym_POUNDendif] = ACTIONS(8797),
    [anon_sym_POUNDENDIF] = ACTIONS(8797),
    [anon_sym_POUNDEndif] = ACTIONS(8797),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8797),
    [sym_trigger_keyword] = ACTIONS(8797),
    [sym_var_keyword] = ACTIONS(8797),
    [sym_local_keyword] = ACTIONS(8797),
    [sym_internal_keyword] = ACTIONS(8797),
    [sym_protected_keyword] = ACTIONS(8797),
    [sym_event_keyword] = ACTIONS(8797),
    [sym_fields_keyword] = ACTIONS(8797),
    [sym_keys_keyword] = ACTIONS(8797),
    [sym_fieldgroups_keyword] = ACTIONS(8797),
    [sym_actions_keyword] = ACTIONS(8797),
    [sym_layout_keyword] = ACTIONS(8797),
    [sym_area_keyword] = ACTIONS(8797),
    [sym_group_keyword] = ACTIONS(8797),
    [sym_repeater_keyword] = ACTIONS(8797),
    [sym_cuegroup_keyword] = ACTIONS(8797),
    [sym_fixed_keyword] = ACTIONS(8797),
    [sym_grid_keyword] = ACTIONS(8797),
    [sym_part_keyword] = ACTIONS(8797),
    [sym_systempart_keyword] = ACTIONS(8797),
    [sym_usercontrol_keyword] = ACTIONS(8797),
    [sym_dataset_keyword] = ACTIONS(8797),
    [sym_elements_keyword] = ACTIONS(8797),
    [sym_dataitem_keyword] = ACTIONS(8797),
    [sym_column_keyword] = ACTIONS(8797),
    [sym_filter_keyword] = ACTIONS(8797),
    [sym_labels_keyword] = ACTIONS(8797),
    [sym_rendering_keyword] = ACTIONS(8797),
    [sym_requestpage_keyword] = ACTIONS(8797),
    [sym_schema_keyword] = ACTIONS(8797),
    [sym_views_keyword] = ACTIONS(8797),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8797),
    [sym_preproc_open] = ACTIONS(8797),
    [sym_preproc_close] = ACTIONS(8797),
  },
  [STATE(3302)] = {
    [anon_sym_SEMI] = ACTIONS(8801),
    [aux_sym_where_condition_token1] = ACTIONS(8803),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8801),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8801),
    [anon_sym_LBRACK] = ACTIONS(8801),
    [aux_sym_basic_type_token6] = ACTIONS(8803),
    [aux_sym_basic_type_token22] = ACTIONS(8803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8801),
    [aux_sym_addafter_modification_token1] = ACTIONS(8801),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8801),
    [aux_sym_modify_modification_token1] = ACTIONS(8801),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8801),
    [aux_sym_movelast_modification_token1] = ACTIONS(8801),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8801),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8801),
    [aux_sym_separator_action_token1] = ACTIONS(8801),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8801),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8801),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8801),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8801),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8801),
    [anon_sym_POUNDif] = ACTIONS(8801),
    [anon_sym_POUNDIF] = ACTIONS(8801),
    [anon_sym_POUNDIf] = ACTIONS(8801),
    [anon_sym_POUNDelif] = ACTIONS(8801),
    [anon_sym_POUNDELIF] = ACTIONS(8801),
    [anon_sym_POUNDElif] = ACTIONS(8801),
    [anon_sym_POUNDelse] = ACTIONS(8801),
    [anon_sym_POUNDELSE] = ACTIONS(8801),
    [anon_sym_POUNDElse] = ACTIONS(8801),
    [anon_sym_POUNDendif] = ACTIONS(8801),
    [anon_sym_POUNDENDIF] = ACTIONS(8801),
    [anon_sym_POUNDEndif] = ACTIONS(8801),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8801),
    [sym_trigger_keyword] = ACTIONS(8801),
    [sym_var_keyword] = ACTIONS(8801),
    [sym_local_keyword] = ACTIONS(8801),
    [sym_internal_keyword] = ACTIONS(8801),
    [sym_protected_keyword] = ACTIONS(8801),
    [sym_event_keyword] = ACTIONS(8801),
    [sym_fields_keyword] = ACTIONS(8801),
    [sym_keys_keyword] = ACTIONS(8801),
    [sym_fieldgroups_keyword] = ACTIONS(8801),
    [sym_actions_keyword] = ACTIONS(8801),
    [sym_layout_keyword] = ACTIONS(8801),
    [sym_area_keyword] = ACTIONS(8801),
    [sym_group_keyword] = ACTIONS(8801),
    [sym_repeater_keyword] = ACTIONS(8801),
    [sym_cuegroup_keyword] = ACTIONS(8801),
    [sym_fixed_keyword] = ACTIONS(8801),
    [sym_grid_keyword] = ACTIONS(8801),
    [sym_part_keyword] = ACTIONS(8801),
    [sym_systempart_keyword] = ACTIONS(8801),
    [sym_usercontrol_keyword] = ACTIONS(8801),
    [sym_dataset_keyword] = ACTIONS(8801),
    [sym_elements_keyword] = ACTIONS(8801),
    [sym_dataitem_keyword] = ACTIONS(8801),
    [sym_column_keyword] = ACTIONS(8801),
    [sym_filter_keyword] = ACTIONS(8801),
    [sym_labels_keyword] = ACTIONS(8801),
    [sym_rendering_keyword] = ACTIONS(8801),
    [sym_requestpage_keyword] = ACTIONS(8801),
    [sym_schema_keyword] = ACTIONS(8801),
    [sym_views_keyword] = ACTIONS(8801),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8801),
    [sym_preproc_open] = ACTIONS(8801),
    [sym_preproc_close] = ACTIONS(8801),
  },
  [STATE(3303)] = {
    [anon_sym_SEMI] = ACTIONS(8801),
    [aux_sym_where_condition_token1] = ACTIONS(8803),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8801),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8801),
    [anon_sym_LBRACK] = ACTIONS(8801),
    [aux_sym_basic_type_token6] = ACTIONS(8803),
    [aux_sym_basic_type_token22] = ACTIONS(8803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8801),
    [aux_sym_addafter_modification_token1] = ACTIONS(8801),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8801),
    [aux_sym_modify_modification_token1] = ACTIONS(8801),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8801),
    [aux_sym_movelast_modification_token1] = ACTIONS(8801),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8801),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8801),
    [aux_sym_separator_action_token1] = ACTIONS(8801),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8801),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8801),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8801),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8801),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8801),
    [anon_sym_POUNDif] = ACTIONS(8801),
    [anon_sym_POUNDIF] = ACTIONS(8801),
    [anon_sym_POUNDIf] = ACTIONS(8801),
    [anon_sym_POUNDelif] = ACTIONS(8801),
    [anon_sym_POUNDELIF] = ACTIONS(8801),
    [anon_sym_POUNDElif] = ACTIONS(8801),
    [anon_sym_POUNDelse] = ACTIONS(8801),
    [anon_sym_POUNDELSE] = ACTIONS(8801),
    [anon_sym_POUNDElse] = ACTIONS(8801),
    [anon_sym_POUNDendif] = ACTIONS(8801),
    [anon_sym_POUNDENDIF] = ACTIONS(8801),
    [anon_sym_POUNDEndif] = ACTIONS(8801),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8801),
    [sym_trigger_keyword] = ACTIONS(8801),
    [sym_var_keyword] = ACTIONS(8801),
    [sym_local_keyword] = ACTIONS(8801),
    [sym_internal_keyword] = ACTIONS(8801),
    [sym_protected_keyword] = ACTIONS(8801),
    [sym_event_keyword] = ACTIONS(8801),
    [sym_fields_keyword] = ACTIONS(8801),
    [sym_keys_keyword] = ACTIONS(8801),
    [sym_fieldgroups_keyword] = ACTIONS(8801),
    [sym_actions_keyword] = ACTIONS(8801),
    [sym_layout_keyword] = ACTIONS(8801),
    [sym_area_keyword] = ACTIONS(8801),
    [sym_group_keyword] = ACTIONS(8801),
    [sym_repeater_keyword] = ACTIONS(8801),
    [sym_cuegroup_keyword] = ACTIONS(8801),
    [sym_fixed_keyword] = ACTIONS(8801),
    [sym_grid_keyword] = ACTIONS(8801),
    [sym_part_keyword] = ACTIONS(8801),
    [sym_systempart_keyword] = ACTIONS(8801),
    [sym_usercontrol_keyword] = ACTIONS(8801),
    [sym_dataset_keyword] = ACTIONS(8801),
    [sym_elements_keyword] = ACTIONS(8801),
    [sym_dataitem_keyword] = ACTIONS(8801),
    [sym_column_keyword] = ACTIONS(8801),
    [sym_filter_keyword] = ACTIONS(8801),
    [sym_labels_keyword] = ACTIONS(8801),
    [sym_rendering_keyword] = ACTIONS(8801),
    [sym_requestpage_keyword] = ACTIONS(8801),
    [sym_schema_keyword] = ACTIONS(8801),
    [sym_views_keyword] = ACTIONS(8801),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8801),
    [sym_preproc_open] = ACTIONS(8801),
    [sym_preproc_close] = ACTIONS(8801),
  },
  [STATE(3304)] = {
    [anon_sym_SEMI] = ACTIONS(8801),
    [aux_sym_where_condition_token1] = ACTIONS(8803),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8801),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8801),
    [anon_sym_LBRACK] = ACTIONS(8801),
    [aux_sym_basic_type_token6] = ACTIONS(8803),
    [aux_sym_basic_type_token22] = ACTIONS(8803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8801),
    [aux_sym_addafter_modification_token1] = ACTIONS(8801),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8801),
    [aux_sym_modify_modification_token1] = ACTIONS(8801),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8801),
    [aux_sym_movelast_modification_token1] = ACTIONS(8801),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8801),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8801),
    [aux_sym_separator_action_token1] = ACTIONS(8801),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8801),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8801),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8801),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8801),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8801),
    [anon_sym_POUNDif] = ACTIONS(8801),
    [anon_sym_POUNDIF] = ACTIONS(8801),
    [anon_sym_POUNDIf] = ACTIONS(8801),
    [anon_sym_POUNDelif] = ACTIONS(8801),
    [anon_sym_POUNDELIF] = ACTIONS(8801),
    [anon_sym_POUNDElif] = ACTIONS(8801),
    [anon_sym_POUNDelse] = ACTIONS(8801),
    [anon_sym_POUNDELSE] = ACTIONS(8801),
    [anon_sym_POUNDElse] = ACTIONS(8801),
    [anon_sym_POUNDendif] = ACTIONS(8801),
    [anon_sym_POUNDENDIF] = ACTIONS(8801),
    [anon_sym_POUNDEndif] = ACTIONS(8801),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8801),
    [sym_trigger_keyword] = ACTIONS(8801),
    [sym_var_keyword] = ACTIONS(8801),
    [sym_local_keyword] = ACTIONS(8801),
    [sym_internal_keyword] = ACTIONS(8801),
    [sym_protected_keyword] = ACTIONS(8801),
    [sym_event_keyword] = ACTIONS(8801),
    [sym_fields_keyword] = ACTIONS(8801),
    [sym_keys_keyword] = ACTIONS(8801),
    [sym_fieldgroups_keyword] = ACTIONS(8801),
    [sym_actions_keyword] = ACTIONS(8801),
    [sym_layout_keyword] = ACTIONS(8801),
    [sym_area_keyword] = ACTIONS(8801),
    [sym_group_keyword] = ACTIONS(8801),
    [sym_repeater_keyword] = ACTIONS(8801),
    [sym_cuegroup_keyword] = ACTIONS(8801),
    [sym_fixed_keyword] = ACTIONS(8801),
    [sym_grid_keyword] = ACTIONS(8801),
    [sym_part_keyword] = ACTIONS(8801),
    [sym_systempart_keyword] = ACTIONS(8801),
    [sym_usercontrol_keyword] = ACTIONS(8801),
    [sym_dataset_keyword] = ACTIONS(8801),
    [sym_elements_keyword] = ACTIONS(8801),
    [sym_dataitem_keyword] = ACTIONS(8801),
    [sym_column_keyword] = ACTIONS(8801),
    [sym_filter_keyword] = ACTIONS(8801),
    [sym_labels_keyword] = ACTIONS(8801),
    [sym_rendering_keyword] = ACTIONS(8801),
    [sym_requestpage_keyword] = ACTIONS(8801),
    [sym_schema_keyword] = ACTIONS(8801),
    [sym_views_keyword] = ACTIONS(8801),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8801),
    [sym_preproc_open] = ACTIONS(8801),
    [sym_preproc_close] = ACTIONS(8801),
  },
  [STATE(3305)] = {
    [anon_sym_SEMI] = ACTIONS(8805),
    [aux_sym_where_condition_token1] = ACTIONS(8807),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8805),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8805),
    [anon_sym_LBRACK] = ACTIONS(8805),
    [aux_sym_basic_type_token6] = ACTIONS(8807),
    [aux_sym_basic_type_token22] = ACTIONS(8807),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8805),
    [aux_sym_addafter_modification_token1] = ACTIONS(8805),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8805),
    [aux_sym_modify_modification_token1] = ACTIONS(8805),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8805),
    [aux_sym_movelast_modification_token1] = ACTIONS(8805),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8805),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8805),
    [aux_sym_separator_action_token1] = ACTIONS(8805),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8805),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8805),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8805),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8805),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8805),
    [anon_sym_POUNDif] = ACTIONS(8805),
    [anon_sym_POUNDIF] = ACTIONS(8805),
    [anon_sym_POUNDIf] = ACTIONS(8805),
    [anon_sym_POUNDelif] = ACTIONS(8805),
    [anon_sym_POUNDELIF] = ACTIONS(8805),
    [anon_sym_POUNDElif] = ACTIONS(8805),
    [anon_sym_POUNDelse] = ACTIONS(8805),
    [anon_sym_POUNDELSE] = ACTIONS(8805),
    [anon_sym_POUNDElse] = ACTIONS(8805),
    [anon_sym_POUNDendif] = ACTIONS(8805),
    [anon_sym_POUNDENDIF] = ACTIONS(8805),
    [anon_sym_POUNDEndif] = ACTIONS(8805),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8805),
    [sym_trigger_keyword] = ACTIONS(8805),
    [sym_var_keyword] = ACTIONS(8805),
    [sym_local_keyword] = ACTIONS(8805),
    [sym_internal_keyword] = ACTIONS(8805),
    [sym_protected_keyword] = ACTIONS(8805),
    [sym_event_keyword] = ACTIONS(8805),
    [sym_fields_keyword] = ACTIONS(8805),
    [sym_keys_keyword] = ACTIONS(8805),
    [sym_fieldgroups_keyword] = ACTIONS(8805),
    [sym_actions_keyword] = ACTIONS(8805),
    [sym_layout_keyword] = ACTIONS(8805),
    [sym_area_keyword] = ACTIONS(8805),
    [sym_group_keyword] = ACTIONS(8805),
    [sym_repeater_keyword] = ACTIONS(8805),
    [sym_cuegroup_keyword] = ACTIONS(8805),
    [sym_fixed_keyword] = ACTIONS(8805),
    [sym_grid_keyword] = ACTIONS(8805),
    [sym_part_keyword] = ACTIONS(8805),
    [sym_systempart_keyword] = ACTIONS(8805),
    [sym_usercontrol_keyword] = ACTIONS(8805),
    [sym_dataset_keyword] = ACTIONS(8805),
    [sym_elements_keyword] = ACTIONS(8805),
    [sym_dataitem_keyword] = ACTIONS(8805),
    [sym_column_keyword] = ACTIONS(8805),
    [sym_filter_keyword] = ACTIONS(8805),
    [sym_labels_keyword] = ACTIONS(8805),
    [sym_rendering_keyword] = ACTIONS(8805),
    [sym_requestpage_keyword] = ACTIONS(8805),
    [sym_schema_keyword] = ACTIONS(8805),
    [sym_views_keyword] = ACTIONS(8805),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8805),
    [sym_preproc_open] = ACTIONS(8805),
    [sym_preproc_close] = ACTIONS(8805),
  },
  [STATE(3306)] = {
    [anon_sym_SEMI] = ACTIONS(8809),
    [aux_sym_where_condition_token1] = ACTIONS(8811),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8809),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8809),
    [anon_sym_LBRACK] = ACTIONS(8809),
    [aux_sym_basic_type_token6] = ACTIONS(8811),
    [aux_sym_basic_type_token22] = ACTIONS(8811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8809),
    [aux_sym_addafter_modification_token1] = ACTIONS(8809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8809),
    [aux_sym_modify_modification_token1] = ACTIONS(8809),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8809),
    [aux_sym_movelast_modification_token1] = ACTIONS(8809),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8809),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8809),
    [aux_sym_separator_action_token1] = ACTIONS(8809),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8809),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8809),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8809),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8809),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8809),
    [anon_sym_POUNDif] = ACTIONS(8809),
    [anon_sym_POUNDIF] = ACTIONS(8809),
    [anon_sym_POUNDIf] = ACTIONS(8809),
    [anon_sym_POUNDelif] = ACTIONS(8809),
    [anon_sym_POUNDELIF] = ACTIONS(8809),
    [anon_sym_POUNDElif] = ACTIONS(8809),
    [anon_sym_POUNDelse] = ACTIONS(8809),
    [anon_sym_POUNDELSE] = ACTIONS(8809),
    [anon_sym_POUNDElse] = ACTIONS(8809),
    [anon_sym_POUNDendif] = ACTIONS(8809),
    [anon_sym_POUNDENDIF] = ACTIONS(8809),
    [anon_sym_POUNDEndif] = ACTIONS(8809),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8809),
    [sym_trigger_keyword] = ACTIONS(8809),
    [sym_var_keyword] = ACTIONS(8809),
    [sym_local_keyword] = ACTIONS(8809),
    [sym_internal_keyword] = ACTIONS(8809),
    [sym_protected_keyword] = ACTIONS(8809),
    [sym_event_keyword] = ACTIONS(8809),
    [sym_fields_keyword] = ACTIONS(8809),
    [sym_keys_keyword] = ACTIONS(8809),
    [sym_fieldgroups_keyword] = ACTIONS(8809),
    [sym_actions_keyword] = ACTIONS(8809),
    [sym_layout_keyword] = ACTIONS(8809),
    [sym_area_keyword] = ACTIONS(8809),
    [sym_group_keyword] = ACTIONS(8809),
    [sym_repeater_keyword] = ACTIONS(8809),
    [sym_cuegroup_keyword] = ACTIONS(8809),
    [sym_fixed_keyword] = ACTIONS(8809),
    [sym_grid_keyword] = ACTIONS(8809),
    [sym_part_keyword] = ACTIONS(8809),
    [sym_systempart_keyword] = ACTIONS(8809),
    [sym_usercontrol_keyword] = ACTIONS(8809),
    [sym_dataset_keyword] = ACTIONS(8809),
    [sym_elements_keyword] = ACTIONS(8809),
    [sym_dataitem_keyword] = ACTIONS(8809),
    [sym_column_keyword] = ACTIONS(8809),
    [sym_filter_keyword] = ACTIONS(8809),
    [sym_labels_keyword] = ACTIONS(8809),
    [sym_rendering_keyword] = ACTIONS(8809),
    [sym_requestpage_keyword] = ACTIONS(8809),
    [sym_schema_keyword] = ACTIONS(8809),
    [sym_views_keyword] = ACTIONS(8809),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8809),
    [sym_preproc_open] = ACTIONS(8809),
    [sym_preproc_close] = ACTIONS(8809),
  },
  [STATE(3307)] = {
    [anon_sym_SEMI] = ACTIONS(4387),
    [aux_sym_where_condition_token1] = ACTIONS(4383),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4387),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4387),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_basic_type_token6] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4387),
    [aux_sym_addafter_modification_token1] = ACTIONS(4387),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4387),
    [aux_sym_modify_modification_token1] = ACTIONS(4387),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4387),
    [aux_sym_movelast_modification_token1] = ACTIONS(4387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4387),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4387),
    [aux_sym_separator_action_token1] = ACTIONS(4387),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4387),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4387),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4387),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4387),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4387),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [anon_sym_POUNDelif] = ACTIONS(4387),
    [anon_sym_POUNDELIF] = ACTIONS(4387),
    [anon_sym_POUNDElif] = ACTIONS(4387),
    [anon_sym_POUNDelse] = ACTIONS(4387),
    [anon_sym_POUNDELSE] = ACTIONS(4387),
    [anon_sym_POUNDElse] = ACTIONS(4387),
    [anon_sym_POUNDendif] = ACTIONS(4387),
    [anon_sym_POUNDENDIF] = ACTIONS(4387),
    [anon_sym_POUNDEndif] = ACTIONS(4387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4387),
    [sym_trigger_keyword] = ACTIONS(4387),
    [sym_var_keyword] = ACTIONS(4387),
    [sym_local_keyword] = ACTIONS(4387),
    [sym_internal_keyword] = ACTIONS(4387),
    [sym_protected_keyword] = ACTIONS(4387),
    [sym_event_keyword] = ACTIONS(4387),
    [sym_fields_keyword] = ACTIONS(4387),
    [sym_keys_keyword] = ACTIONS(4387),
    [sym_fieldgroups_keyword] = ACTIONS(4387),
    [sym_actions_keyword] = ACTIONS(4387),
    [sym_layout_keyword] = ACTIONS(4387),
    [sym_area_keyword] = ACTIONS(4387),
    [sym_group_keyword] = ACTIONS(4387),
    [sym_repeater_keyword] = ACTIONS(4387),
    [sym_cuegroup_keyword] = ACTIONS(4387),
    [sym_fixed_keyword] = ACTIONS(4387),
    [sym_grid_keyword] = ACTIONS(4387),
    [sym_part_keyword] = ACTIONS(4387),
    [sym_systempart_keyword] = ACTIONS(4387),
    [sym_usercontrol_keyword] = ACTIONS(4387),
    [sym_dataset_keyword] = ACTIONS(4387),
    [sym_elements_keyword] = ACTIONS(4387),
    [sym_dataitem_keyword] = ACTIONS(4387),
    [sym_column_keyword] = ACTIONS(4387),
    [sym_filter_keyword] = ACTIONS(4387),
    [sym_labels_keyword] = ACTIONS(4387),
    [sym_rendering_keyword] = ACTIONS(4387),
    [sym_requestpage_keyword] = ACTIONS(4387),
    [sym_schema_keyword] = ACTIONS(4387),
    [sym_views_keyword] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
    [sym_preproc_close] = ACTIONS(4387),
  },
  [STATE(3308)] = {
    [anon_sym_SEMI] = ACTIONS(4457),
    [aux_sym_where_condition_token1] = ACTIONS(4455),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4457),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4457),
    [anon_sym_LBRACK] = ACTIONS(4457),
    [aux_sym_basic_type_token6] = ACTIONS(4455),
    [aux_sym_basic_type_token22] = ACTIONS(4455),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4457),
    [aux_sym_addafter_modification_token1] = ACTIONS(4457),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4457),
    [aux_sym_modify_modification_token1] = ACTIONS(4457),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4457),
    [aux_sym_movelast_modification_token1] = ACTIONS(4457),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4457),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4457),
    [aux_sym_separator_action_token1] = ACTIONS(4457),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4457),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4457),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4457),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4457),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4457),
    [anon_sym_POUNDif] = ACTIONS(4457),
    [anon_sym_POUNDIF] = ACTIONS(4457),
    [anon_sym_POUNDIf] = ACTIONS(4457),
    [anon_sym_POUNDelif] = ACTIONS(4457),
    [anon_sym_POUNDELIF] = ACTIONS(4457),
    [anon_sym_POUNDElif] = ACTIONS(4457),
    [anon_sym_POUNDelse] = ACTIONS(4457),
    [anon_sym_POUNDELSE] = ACTIONS(4457),
    [anon_sym_POUNDElse] = ACTIONS(4457),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4457),
    [sym_trigger_keyword] = ACTIONS(4457),
    [sym_var_keyword] = ACTIONS(4457),
    [sym_local_keyword] = ACTIONS(4457),
    [sym_internal_keyword] = ACTIONS(4457),
    [sym_protected_keyword] = ACTIONS(4457),
    [sym_event_keyword] = ACTIONS(4457),
    [sym_fields_keyword] = ACTIONS(4457),
    [sym_keys_keyword] = ACTIONS(4457),
    [sym_fieldgroups_keyword] = ACTIONS(4457),
    [sym_actions_keyword] = ACTIONS(4457),
    [sym_layout_keyword] = ACTIONS(4457),
    [sym_area_keyword] = ACTIONS(4457),
    [sym_group_keyword] = ACTIONS(4457),
    [sym_repeater_keyword] = ACTIONS(4457),
    [sym_cuegroup_keyword] = ACTIONS(4457),
    [sym_fixed_keyword] = ACTIONS(4457),
    [sym_grid_keyword] = ACTIONS(4457),
    [sym_part_keyword] = ACTIONS(4457),
    [sym_systempart_keyword] = ACTIONS(4457),
    [sym_usercontrol_keyword] = ACTIONS(4457),
    [sym_dataset_keyword] = ACTIONS(4457),
    [sym_elements_keyword] = ACTIONS(4457),
    [sym_dataitem_keyword] = ACTIONS(4457),
    [sym_column_keyword] = ACTIONS(4457),
    [sym_filter_keyword] = ACTIONS(4457),
    [sym_labels_keyword] = ACTIONS(4457),
    [sym_rendering_keyword] = ACTIONS(4457),
    [sym_requestpage_keyword] = ACTIONS(4457),
    [sym_schema_keyword] = ACTIONS(4457),
    [sym_views_keyword] = ACTIONS(4457),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4457),
    [sym_preproc_open] = ACTIONS(4457),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(3309)] = {
    [sym__body_element] = STATE(3325),
    [sym_empty_statement] = STATE(3325),
    [sym_property] = STATE(3325),
    [sym_fields_section] = STATE(3325),
    [sym_keys_section] = STATE(3325),
    [sym_fieldgroups_section] = STATE(3325),
    [sym_enum_value_declaration] = STATE(3325),
    [sym_labels_section] = STATE(3325),
    [sym_layout_section] = STATE(3325),
    [sym_modify_modification] = STATE(3325),
    [sym_actions_section] = STATE(3325),
    [sym_views_section] = STATE(3325),
    [sym_dataset_section] = STATE(3325),
    [sym_requestpage_section] = STATE(3325),
    [sym_rendering_section] = STATE(3325),
    [sym_elements_section] = STATE(3325),
    [sym_schema_section] = STATE(3325),
    [sym_xmlport_element] = STATE(3325),
    [sym__xmlport_body_element] = STATE(3325),
    [sym_preproc_conditional_xmlport] = STATE(3325),
    [sym_xmlport_attribute] = STATE(3325),
    [sym_assembly_declaration] = STATE(3325),
    [sym_event_declaration] = STATE(3325),
    [sym_procedure] = STATE(3325),
    [sym_preproc_split_procedure] = STATE(3325),
    [sym_procedure_modifier] = STATE(12392),
    [sym_trigger_declaration] = STATE(3325),
    [sym_var_section] = STATE(3325),
    [sym_attribute_item] = STATE(3325),
    [sym_preproc_conditional] = STATE(3325),
    [sym_preproc_if] = STATE(2456),
    [aux_sym_xmlport_element_repeat1] = STATE(3325),
    [anon_sym_SEMI] = ACTIONS(8638),
    [anon_sym_RBRACE] = ACTIONS(8813),
    [anon_sym_LBRACK] = ACTIONS(8642),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8644),
    [aux_sym_modify_modification_token1] = ACTIONS(8646),
    [aux_sym_xmlport_element_token1] = ACTIONS(8648),
    [aux_sym_xmlport_element_token2] = ACTIONS(8648),
    [aux_sym_xmlport_element_token3] = ACTIONS(8648),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8650),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8650),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8652),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8654),
    [sym_trigger_keyword] = ACTIONS(8656),
    [sym_var_keyword] = ACTIONS(8658),
    [sym_local_keyword] = ACTIONS(8660),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(8660),
    [sym_event_keyword] = ACTIONS(8662),
    [sym_fields_keyword] = ACTIONS(8664),
    [sym_keys_keyword] = ACTIONS(8666),
    [sym_fieldgroups_keyword] = ACTIONS(8668),
    [sym_actions_keyword] = ACTIONS(8670),
    [sym_layout_keyword] = ACTIONS(8672),
    [sym_dataset_keyword] = ACTIONS(8674),
    [sym_elements_keyword] = ACTIONS(8676),
    [sym_labels_keyword] = ACTIONS(8678),
    [sym_rendering_keyword] = ACTIONS(8680),
    [sym_requestpage_keyword] = ACTIONS(8682),
    [sym_schema_keyword] = ACTIONS(8684),
    [sym_views_keyword] = ACTIONS(8686),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8688),
    [sym_preproc_open] = ACTIONS(5823),
  },
  [STATE(3310)] = {
    [anon_sym_SEMI] = ACTIONS(4401),
    [aux_sym_where_condition_token1] = ACTIONS(4399),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4401),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4401),
    [anon_sym_LBRACK] = ACTIONS(4401),
    [aux_sym_basic_type_token6] = ACTIONS(4399),
    [aux_sym_basic_type_token22] = ACTIONS(4399),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4401),
    [aux_sym_addafter_modification_token1] = ACTIONS(4401),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4401),
    [aux_sym_modify_modification_token1] = ACTIONS(4401),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4401),
    [aux_sym_movelast_modification_token1] = ACTIONS(4401),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4401),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4401),
    [aux_sym_separator_action_token1] = ACTIONS(4401),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4401),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4401),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4401),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4401),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4401),
    [anon_sym_POUNDif] = ACTIONS(4401),
    [anon_sym_POUNDIF] = ACTIONS(4401),
    [anon_sym_POUNDIf] = ACTIONS(4401),
    [anon_sym_POUNDelif] = ACTIONS(4401),
    [anon_sym_POUNDELIF] = ACTIONS(4401),
    [anon_sym_POUNDElif] = ACTIONS(4401),
    [anon_sym_POUNDelse] = ACTIONS(4401),
    [anon_sym_POUNDELSE] = ACTIONS(4401),
    [anon_sym_POUNDElse] = ACTIONS(4401),
    [anon_sym_POUNDendif] = ACTIONS(4401),
    [anon_sym_POUNDENDIF] = ACTIONS(4401),
    [anon_sym_POUNDEndif] = ACTIONS(4401),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4401),
    [sym_trigger_keyword] = ACTIONS(4401),
    [sym_var_keyword] = ACTIONS(4401),
    [sym_local_keyword] = ACTIONS(4401),
    [sym_internal_keyword] = ACTIONS(4401),
    [sym_protected_keyword] = ACTIONS(4401),
    [sym_event_keyword] = ACTIONS(4401),
    [sym_fields_keyword] = ACTIONS(4401),
    [sym_keys_keyword] = ACTIONS(4401),
    [sym_fieldgroups_keyword] = ACTIONS(4401),
    [sym_actions_keyword] = ACTIONS(4401),
    [sym_layout_keyword] = ACTIONS(4401),
    [sym_area_keyword] = ACTIONS(4401),
    [sym_group_keyword] = ACTIONS(4401),
    [sym_repeater_keyword] = ACTIONS(4401),
    [sym_cuegroup_keyword] = ACTIONS(4401),
    [sym_fixed_keyword] = ACTIONS(4401),
    [sym_grid_keyword] = ACTIONS(4401),
    [sym_part_keyword] = ACTIONS(4401),
    [sym_systempart_keyword] = ACTIONS(4401),
    [sym_usercontrol_keyword] = ACTIONS(4401),
    [sym_dataset_keyword] = ACTIONS(4401),
    [sym_elements_keyword] = ACTIONS(4401),
    [sym_dataitem_keyword] = ACTIONS(4401),
    [sym_column_keyword] = ACTIONS(4401),
    [sym_filter_keyword] = ACTIONS(4401),
    [sym_labels_keyword] = ACTIONS(4401),
    [sym_rendering_keyword] = ACTIONS(4401),
    [sym_requestpage_keyword] = ACTIONS(4401),
    [sym_schema_keyword] = ACTIONS(4401),
    [sym_views_keyword] = ACTIONS(4401),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4401),
    [sym_preproc_open] = ACTIONS(4401),
    [sym_preproc_close] = ACTIONS(4401),
  },
  [STATE(3311)] = {
    [anon_sym_SEMI] = ACTIONS(8815),
    [aux_sym_where_condition_token1] = ACTIONS(8817),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8815),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8815),
    [anon_sym_LBRACK] = ACTIONS(8815),
    [aux_sym_basic_type_token6] = ACTIONS(8817),
    [aux_sym_basic_type_token22] = ACTIONS(8817),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8815),
    [aux_sym_addafter_modification_token1] = ACTIONS(8815),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8815),
    [aux_sym_modify_modification_token1] = ACTIONS(8815),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8815),
    [aux_sym_movelast_modification_token1] = ACTIONS(8815),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8815),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8815),
    [aux_sym_separator_action_token1] = ACTIONS(8815),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8815),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8815),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8815),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8815),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8815),
    [anon_sym_POUNDif] = ACTIONS(8815),
    [anon_sym_POUNDIF] = ACTIONS(8815),
    [anon_sym_POUNDIf] = ACTIONS(8815),
    [anon_sym_POUNDelif] = ACTIONS(8815),
    [anon_sym_POUNDELIF] = ACTIONS(8815),
    [anon_sym_POUNDElif] = ACTIONS(8815),
    [anon_sym_POUNDelse] = ACTIONS(8815),
    [anon_sym_POUNDELSE] = ACTIONS(8815),
    [anon_sym_POUNDElse] = ACTIONS(8815),
    [anon_sym_POUNDendif] = ACTIONS(8815),
    [anon_sym_POUNDENDIF] = ACTIONS(8815),
    [anon_sym_POUNDEndif] = ACTIONS(8815),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8815),
    [sym_trigger_keyword] = ACTIONS(8815),
    [sym_var_keyword] = ACTIONS(8815),
    [sym_local_keyword] = ACTIONS(8815),
    [sym_internal_keyword] = ACTIONS(8815),
    [sym_protected_keyword] = ACTIONS(8815),
    [sym_event_keyword] = ACTIONS(8815),
    [sym_fields_keyword] = ACTIONS(8815),
    [sym_keys_keyword] = ACTIONS(8815),
    [sym_fieldgroups_keyword] = ACTIONS(8815),
    [sym_actions_keyword] = ACTIONS(8815),
    [sym_layout_keyword] = ACTIONS(8815),
    [sym_area_keyword] = ACTIONS(8815),
    [sym_group_keyword] = ACTIONS(8815),
    [sym_repeater_keyword] = ACTIONS(8815),
    [sym_cuegroup_keyword] = ACTIONS(8815),
    [sym_fixed_keyword] = ACTIONS(8815),
    [sym_grid_keyword] = ACTIONS(8815),
    [sym_part_keyword] = ACTIONS(8815),
    [sym_systempart_keyword] = ACTIONS(8815),
    [sym_usercontrol_keyword] = ACTIONS(8815),
    [sym_dataset_keyword] = ACTIONS(8815),
    [sym_elements_keyword] = ACTIONS(8815),
    [sym_dataitem_keyword] = ACTIONS(8815),
    [sym_column_keyword] = ACTIONS(8815),
    [sym_filter_keyword] = ACTIONS(8815),
    [sym_labels_keyword] = ACTIONS(8815),
    [sym_rendering_keyword] = ACTIONS(8815),
    [sym_requestpage_keyword] = ACTIONS(8815),
    [sym_schema_keyword] = ACTIONS(8815),
    [sym_views_keyword] = ACTIONS(8815),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8815),
    [sym_preproc_open] = ACTIONS(8815),
    [sym_preproc_close] = ACTIONS(8815),
  },
  [STATE(3312)] = {
    [anon_sym_SEMI] = ACTIONS(4413),
    [aux_sym_where_condition_token1] = ACTIONS(4411),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4413),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4413),
    [anon_sym_LBRACK] = ACTIONS(4413),
    [aux_sym_basic_type_token6] = ACTIONS(4411),
    [aux_sym_basic_type_token22] = ACTIONS(4411),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4413),
    [aux_sym_addafter_modification_token1] = ACTIONS(4413),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4413),
    [aux_sym_modify_modification_token1] = ACTIONS(4413),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4413),
    [aux_sym_movelast_modification_token1] = ACTIONS(4413),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4413),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4413),
    [aux_sym_separator_action_token1] = ACTIONS(4413),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4413),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4413),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4413),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4413),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4413),
    [anon_sym_POUNDif] = ACTIONS(4413),
    [anon_sym_POUNDIF] = ACTIONS(4413),
    [anon_sym_POUNDIf] = ACTIONS(4413),
    [anon_sym_POUNDelif] = ACTIONS(4413),
    [anon_sym_POUNDELIF] = ACTIONS(4413),
    [anon_sym_POUNDElif] = ACTIONS(4413),
    [anon_sym_POUNDelse] = ACTIONS(4413),
    [anon_sym_POUNDELSE] = ACTIONS(4413),
    [anon_sym_POUNDElse] = ACTIONS(4413),
    [anon_sym_POUNDendif] = ACTIONS(4413),
    [anon_sym_POUNDENDIF] = ACTIONS(4413),
    [anon_sym_POUNDEndif] = ACTIONS(4413),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4413),
    [sym_trigger_keyword] = ACTIONS(4413),
    [sym_var_keyword] = ACTIONS(4413),
    [sym_local_keyword] = ACTIONS(4413),
    [sym_internal_keyword] = ACTIONS(4413),
    [sym_protected_keyword] = ACTIONS(4413),
    [sym_event_keyword] = ACTIONS(4413),
    [sym_fields_keyword] = ACTIONS(4413),
    [sym_keys_keyword] = ACTIONS(4413),
    [sym_fieldgroups_keyword] = ACTIONS(4413),
    [sym_actions_keyword] = ACTIONS(4413),
    [sym_layout_keyword] = ACTIONS(4413),
    [sym_area_keyword] = ACTIONS(4413),
    [sym_group_keyword] = ACTIONS(4413),
    [sym_repeater_keyword] = ACTIONS(4413),
    [sym_cuegroup_keyword] = ACTIONS(4413),
    [sym_fixed_keyword] = ACTIONS(4413),
    [sym_grid_keyword] = ACTIONS(4413),
    [sym_part_keyword] = ACTIONS(4413),
    [sym_systempart_keyword] = ACTIONS(4413),
    [sym_usercontrol_keyword] = ACTIONS(4413),
    [sym_dataset_keyword] = ACTIONS(4413),
    [sym_elements_keyword] = ACTIONS(4413),
    [sym_dataitem_keyword] = ACTIONS(4413),
    [sym_column_keyword] = ACTIONS(4413),
    [sym_filter_keyword] = ACTIONS(4413),
    [sym_labels_keyword] = ACTIONS(4413),
    [sym_rendering_keyword] = ACTIONS(4413),
    [sym_requestpage_keyword] = ACTIONS(4413),
    [sym_schema_keyword] = ACTIONS(4413),
    [sym_views_keyword] = ACTIONS(4413),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4413),
    [sym_preproc_open] = ACTIONS(4413),
    [sym_preproc_close] = ACTIONS(4413),
  },
  [STATE(3313)] = {
    [anon_sym_SEMI] = ACTIONS(4381),
    [aux_sym_where_condition_token1] = ACTIONS(4379),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4381),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4381),
    [anon_sym_LBRACK] = ACTIONS(4381),
    [aux_sym_basic_type_token6] = ACTIONS(4379),
    [aux_sym_basic_type_token22] = ACTIONS(4379),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4381),
    [aux_sym_addafter_modification_token1] = ACTIONS(4381),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4381),
    [aux_sym_modify_modification_token1] = ACTIONS(4381),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4381),
    [aux_sym_movelast_modification_token1] = ACTIONS(4381),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4381),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4381),
    [aux_sym_separator_action_token1] = ACTIONS(4381),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4381),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4381),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4381),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4381),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4381),
    [anon_sym_POUNDif] = ACTIONS(4381),
    [anon_sym_POUNDIF] = ACTIONS(4381),
    [anon_sym_POUNDIf] = ACTIONS(4381),
    [anon_sym_POUNDelif] = ACTIONS(4381),
    [anon_sym_POUNDELIF] = ACTIONS(4381),
    [anon_sym_POUNDElif] = ACTIONS(4381),
    [anon_sym_POUNDelse] = ACTIONS(4381),
    [anon_sym_POUNDELSE] = ACTIONS(4381),
    [anon_sym_POUNDElse] = ACTIONS(4381),
    [anon_sym_POUNDendif] = ACTIONS(4381),
    [anon_sym_POUNDENDIF] = ACTIONS(4381),
    [anon_sym_POUNDEndif] = ACTIONS(4381),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4381),
    [sym_trigger_keyword] = ACTIONS(4381),
    [sym_var_keyword] = ACTIONS(4381),
    [sym_local_keyword] = ACTIONS(4381),
    [sym_internal_keyword] = ACTIONS(4381),
    [sym_protected_keyword] = ACTIONS(4381),
    [sym_event_keyword] = ACTIONS(4381),
    [sym_fields_keyword] = ACTIONS(4381),
    [sym_keys_keyword] = ACTIONS(4381),
    [sym_fieldgroups_keyword] = ACTIONS(4381),
    [sym_actions_keyword] = ACTIONS(4381),
    [sym_layout_keyword] = ACTIONS(4381),
    [sym_area_keyword] = ACTIONS(4381),
    [sym_group_keyword] = ACTIONS(4381),
    [sym_repeater_keyword] = ACTIONS(4381),
    [sym_cuegroup_keyword] = ACTIONS(4381),
    [sym_fixed_keyword] = ACTIONS(4381),
    [sym_grid_keyword] = ACTIONS(4381),
    [sym_part_keyword] = ACTIONS(4381),
    [sym_systempart_keyword] = ACTIONS(4381),
    [sym_usercontrol_keyword] = ACTIONS(4381),
    [sym_dataset_keyword] = ACTIONS(4381),
    [sym_elements_keyword] = ACTIONS(4381),
    [sym_dataitem_keyword] = ACTIONS(4381),
    [sym_column_keyword] = ACTIONS(4381),
    [sym_filter_keyword] = ACTIONS(4381),
    [sym_labels_keyword] = ACTIONS(4381),
    [sym_rendering_keyword] = ACTIONS(4381),
    [sym_requestpage_keyword] = ACTIONS(4381),
    [sym_schema_keyword] = ACTIONS(4381),
    [sym_views_keyword] = ACTIONS(4381),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4381),
    [sym_preproc_open] = ACTIONS(4381),
    [sym_preproc_close] = ACTIONS(4381),
  },
  [STATE(3314)] = {
    [anon_sym_SEMI] = ACTIONS(8819),
    [aux_sym_where_condition_token1] = ACTIONS(8821),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8819),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8819),
    [anon_sym_LBRACK] = ACTIONS(8819),
    [aux_sym_basic_type_token6] = ACTIONS(8821),
    [aux_sym_basic_type_token22] = ACTIONS(8821),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8819),
    [aux_sym_addafter_modification_token1] = ACTIONS(8819),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8819),
    [aux_sym_modify_modification_token1] = ACTIONS(8819),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8819),
    [aux_sym_movelast_modification_token1] = ACTIONS(8819),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8819),
    [aux_sym_separator_action_token1] = ACTIONS(8819),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8819),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8819),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8819),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8819),
    [anon_sym_POUNDif] = ACTIONS(8819),
    [anon_sym_POUNDIF] = ACTIONS(8819),
    [anon_sym_POUNDIf] = ACTIONS(8819),
    [anon_sym_POUNDelif] = ACTIONS(8819),
    [anon_sym_POUNDELIF] = ACTIONS(8819),
    [anon_sym_POUNDElif] = ACTIONS(8819),
    [anon_sym_POUNDelse] = ACTIONS(8819),
    [anon_sym_POUNDELSE] = ACTIONS(8819),
    [anon_sym_POUNDElse] = ACTIONS(8819),
    [anon_sym_POUNDendif] = ACTIONS(8819),
    [anon_sym_POUNDENDIF] = ACTIONS(8819),
    [anon_sym_POUNDEndif] = ACTIONS(8819),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8819),
    [sym_trigger_keyword] = ACTIONS(8819),
    [sym_var_keyword] = ACTIONS(8819),
    [sym_local_keyword] = ACTIONS(8819),
    [sym_internal_keyword] = ACTIONS(8819),
    [sym_protected_keyword] = ACTIONS(8819),
    [sym_event_keyword] = ACTIONS(8819),
    [sym_fields_keyword] = ACTIONS(8819),
    [sym_keys_keyword] = ACTIONS(8819),
    [sym_fieldgroups_keyword] = ACTIONS(8819),
    [sym_actions_keyword] = ACTIONS(8819),
    [sym_layout_keyword] = ACTIONS(8819),
    [sym_area_keyword] = ACTIONS(8819),
    [sym_group_keyword] = ACTIONS(8819),
    [sym_repeater_keyword] = ACTIONS(8819),
    [sym_cuegroup_keyword] = ACTIONS(8819),
    [sym_fixed_keyword] = ACTIONS(8819),
    [sym_grid_keyword] = ACTIONS(8819),
    [sym_part_keyword] = ACTIONS(8819),
    [sym_systempart_keyword] = ACTIONS(8819),
    [sym_usercontrol_keyword] = ACTIONS(8819),
    [sym_dataset_keyword] = ACTIONS(8819),
    [sym_elements_keyword] = ACTIONS(8819),
    [sym_dataitem_keyword] = ACTIONS(8819),
    [sym_column_keyword] = ACTIONS(8819),
    [sym_filter_keyword] = ACTIONS(8819),
    [sym_labels_keyword] = ACTIONS(8819),
    [sym_rendering_keyword] = ACTIONS(8819),
    [sym_requestpage_keyword] = ACTIONS(8819),
    [sym_schema_keyword] = ACTIONS(8819),
    [sym_views_keyword] = ACTIONS(8819),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8819),
    [sym_preproc_open] = ACTIONS(8819),
    [sym_preproc_close] = ACTIONS(8819),
  },
  [STATE(3315)] = {
    [anon_sym_SEMI] = ACTIONS(8819),
    [aux_sym_where_condition_token1] = ACTIONS(8821),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8819),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8819),
    [anon_sym_LBRACK] = ACTIONS(8819),
    [aux_sym_basic_type_token6] = ACTIONS(8821),
    [aux_sym_basic_type_token22] = ACTIONS(8821),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8819),
    [aux_sym_addafter_modification_token1] = ACTIONS(8819),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8819),
    [aux_sym_modify_modification_token1] = ACTIONS(8819),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8819),
    [aux_sym_movelast_modification_token1] = ACTIONS(8819),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8819),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8819),
    [aux_sym_separator_action_token1] = ACTIONS(8819),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8819),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8819),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8819),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8819),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8819),
    [anon_sym_POUNDif] = ACTIONS(8819),
    [anon_sym_POUNDIF] = ACTIONS(8819),
    [anon_sym_POUNDIf] = ACTIONS(8819),
    [anon_sym_POUNDelif] = ACTIONS(8819),
    [anon_sym_POUNDELIF] = ACTIONS(8819),
    [anon_sym_POUNDElif] = ACTIONS(8819),
    [anon_sym_POUNDelse] = ACTIONS(8819),
    [anon_sym_POUNDELSE] = ACTIONS(8819),
    [anon_sym_POUNDElse] = ACTIONS(8819),
    [anon_sym_POUNDendif] = ACTIONS(8819),
    [anon_sym_POUNDENDIF] = ACTIONS(8819),
    [anon_sym_POUNDEndif] = ACTIONS(8819),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8819),
    [sym_trigger_keyword] = ACTIONS(8819),
    [sym_var_keyword] = ACTIONS(8819),
    [sym_local_keyword] = ACTIONS(8819),
    [sym_internal_keyword] = ACTIONS(8819),
    [sym_protected_keyword] = ACTIONS(8819),
    [sym_event_keyword] = ACTIONS(8819),
    [sym_fields_keyword] = ACTIONS(8819),
    [sym_keys_keyword] = ACTIONS(8819),
    [sym_fieldgroups_keyword] = ACTIONS(8819),
    [sym_actions_keyword] = ACTIONS(8819),
    [sym_layout_keyword] = ACTIONS(8819),
    [sym_area_keyword] = ACTIONS(8819),
    [sym_group_keyword] = ACTIONS(8819),
    [sym_repeater_keyword] = ACTIONS(8819),
    [sym_cuegroup_keyword] = ACTIONS(8819),
    [sym_fixed_keyword] = ACTIONS(8819),
    [sym_grid_keyword] = ACTIONS(8819),
    [sym_part_keyword] = ACTIONS(8819),
    [sym_systempart_keyword] = ACTIONS(8819),
    [sym_usercontrol_keyword] = ACTIONS(8819),
    [sym_dataset_keyword] = ACTIONS(8819),
    [sym_elements_keyword] = ACTIONS(8819),
    [sym_dataitem_keyword] = ACTIONS(8819),
    [sym_column_keyword] = ACTIONS(8819),
    [sym_filter_keyword] = ACTIONS(8819),
    [sym_labels_keyword] = ACTIONS(8819),
    [sym_rendering_keyword] = ACTIONS(8819),
    [sym_requestpage_keyword] = ACTIONS(8819),
    [sym_schema_keyword] = ACTIONS(8819),
    [sym_views_keyword] = ACTIONS(8819),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8819),
    [sym_preproc_open] = ACTIONS(8819),
    [sym_preproc_close] = ACTIONS(8819),
  },
  [STATE(3316)] = {
    [anon_sym_SEMI] = ACTIONS(8823),
    [aux_sym_where_condition_token1] = ACTIONS(8825),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8823),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8823),
    [anon_sym_LBRACK] = ACTIONS(8823),
    [aux_sym_basic_type_token6] = ACTIONS(8825),
    [aux_sym_basic_type_token22] = ACTIONS(8825),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8823),
    [aux_sym_addafter_modification_token1] = ACTIONS(8823),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8823),
    [aux_sym_modify_modification_token1] = ACTIONS(8823),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8823),
    [aux_sym_movelast_modification_token1] = ACTIONS(8823),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8823),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8823),
    [aux_sym_separator_action_token1] = ACTIONS(8823),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8823),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8823),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8823),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8823),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8823),
    [anon_sym_POUNDif] = ACTIONS(8823),
    [anon_sym_POUNDIF] = ACTIONS(8823),
    [anon_sym_POUNDIf] = ACTIONS(8823),
    [anon_sym_POUNDelif] = ACTIONS(8823),
    [anon_sym_POUNDELIF] = ACTIONS(8823),
    [anon_sym_POUNDElif] = ACTIONS(8823),
    [anon_sym_POUNDelse] = ACTIONS(8823),
    [anon_sym_POUNDELSE] = ACTIONS(8823),
    [anon_sym_POUNDElse] = ACTIONS(8823),
    [anon_sym_POUNDendif] = ACTIONS(8823),
    [anon_sym_POUNDENDIF] = ACTIONS(8823),
    [anon_sym_POUNDEndif] = ACTIONS(8823),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8823),
    [sym_trigger_keyword] = ACTIONS(8823),
    [sym_var_keyword] = ACTIONS(8823),
    [sym_local_keyword] = ACTIONS(8823),
    [sym_internal_keyword] = ACTIONS(8823),
    [sym_protected_keyword] = ACTIONS(8823),
    [sym_event_keyword] = ACTIONS(8823),
    [sym_fields_keyword] = ACTIONS(8823),
    [sym_keys_keyword] = ACTIONS(8823),
    [sym_fieldgroups_keyword] = ACTIONS(8823),
    [sym_actions_keyword] = ACTIONS(8823),
    [sym_layout_keyword] = ACTIONS(8823),
    [sym_area_keyword] = ACTIONS(8823),
    [sym_group_keyword] = ACTIONS(8823),
    [sym_repeater_keyword] = ACTIONS(8823),
    [sym_cuegroup_keyword] = ACTIONS(8823),
    [sym_fixed_keyword] = ACTIONS(8823),
    [sym_grid_keyword] = ACTIONS(8823),
    [sym_part_keyword] = ACTIONS(8823),
    [sym_systempart_keyword] = ACTIONS(8823),
    [sym_usercontrol_keyword] = ACTIONS(8823),
    [sym_dataset_keyword] = ACTIONS(8823),
    [sym_elements_keyword] = ACTIONS(8823),
    [sym_dataitem_keyword] = ACTIONS(8823),
    [sym_column_keyword] = ACTIONS(8823),
    [sym_filter_keyword] = ACTIONS(8823),
    [sym_labels_keyword] = ACTIONS(8823),
    [sym_rendering_keyword] = ACTIONS(8823),
    [sym_requestpage_keyword] = ACTIONS(8823),
    [sym_schema_keyword] = ACTIONS(8823),
    [sym_views_keyword] = ACTIONS(8823),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8823),
    [sym_preproc_open] = ACTIONS(8823),
    [sym_preproc_close] = ACTIONS(8823),
  },
  [STATE(3317)] = {
    [anon_sym_SEMI] = ACTIONS(8823),
    [aux_sym_where_condition_token1] = ACTIONS(8825),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8823),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8823),
    [anon_sym_LBRACK] = ACTIONS(8823),
    [aux_sym_basic_type_token6] = ACTIONS(8825),
    [aux_sym_basic_type_token22] = ACTIONS(8825),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8823),
    [aux_sym_addafter_modification_token1] = ACTIONS(8823),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8823),
    [aux_sym_modify_modification_token1] = ACTIONS(8823),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8823),
    [aux_sym_movelast_modification_token1] = ACTIONS(8823),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8823),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8823),
    [aux_sym_separator_action_token1] = ACTIONS(8823),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8823),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8823),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8823),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8823),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8823),
    [anon_sym_POUNDif] = ACTIONS(8823),
    [anon_sym_POUNDIF] = ACTIONS(8823),
    [anon_sym_POUNDIf] = ACTIONS(8823),
    [anon_sym_POUNDelif] = ACTIONS(8823),
    [anon_sym_POUNDELIF] = ACTIONS(8823),
    [anon_sym_POUNDElif] = ACTIONS(8823),
    [anon_sym_POUNDelse] = ACTIONS(8823),
    [anon_sym_POUNDELSE] = ACTIONS(8823),
    [anon_sym_POUNDElse] = ACTIONS(8823),
    [anon_sym_POUNDendif] = ACTIONS(8823),
    [anon_sym_POUNDENDIF] = ACTIONS(8823),
    [anon_sym_POUNDEndif] = ACTIONS(8823),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8823),
    [sym_trigger_keyword] = ACTIONS(8823),
    [sym_var_keyword] = ACTIONS(8823),
    [sym_local_keyword] = ACTIONS(8823),
    [sym_internal_keyword] = ACTIONS(8823),
    [sym_protected_keyword] = ACTIONS(8823),
    [sym_event_keyword] = ACTIONS(8823),
    [sym_fields_keyword] = ACTIONS(8823),
    [sym_keys_keyword] = ACTIONS(8823),
    [sym_fieldgroups_keyword] = ACTIONS(8823),
    [sym_actions_keyword] = ACTIONS(8823),
    [sym_layout_keyword] = ACTIONS(8823),
    [sym_area_keyword] = ACTIONS(8823),
    [sym_group_keyword] = ACTIONS(8823),
    [sym_repeater_keyword] = ACTIONS(8823),
    [sym_cuegroup_keyword] = ACTIONS(8823),
    [sym_fixed_keyword] = ACTIONS(8823),
    [sym_grid_keyword] = ACTIONS(8823),
    [sym_part_keyword] = ACTIONS(8823),
    [sym_systempart_keyword] = ACTIONS(8823),
    [sym_usercontrol_keyword] = ACTIONS(8823),
    [sym_dataset_keyword] = ACTIONS(8823),
    [sym_elements_keyword] = ACTIONS(8823),
    [sym_dataitem_keyword] = ACTIONS(8823),
    [sym_column_keyword] = ACTIONS(8823),
    [sym_filter_keyword] = ACTIONS(8823),
    [sym_labels_keyword] = ACTIONS(8823),
    [sym_rendering_keyword] = ACTIONS(8823),
    [sym_requestpage_keyword] = ACTIONS(8823),
    [sym_schema_keyword] = ACTIONS(8823),
    [sym_views_keyword] = ACTIONS(8823),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8823),
    [sym_preproc_open] = ACTIONS(8823),
    [sym_preproc_close] = ACTIONS(8823),
  },
  [STATE(3318)] = {
    [anon_sym_SEMI] = ACTIONS(8827),
    [aux_sym_where_condition_token1] = ACTIONS(8829),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8827),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8827),
    [anon_sym_LBRACK] = ACTIONS(8827),
    [aux_sym_basic_type_token6] = ACTIONS(8829),
    [aux_sym_basic_type_token22] = ACTIONS(8829),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8827),
    [aux_sym_addafter_modification_token1] = ACTIONS(8827),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8827),
    [aux_sym_modify_modification_token1] = ACTIONS(8827),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8827),
    [aux_sym_movelast_modification_token1] = ACTIONS(8827),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8827),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8827),
    [aux_sym_separator_action_token1] = ACTIONS(8827),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8827),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8827),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8827),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8827),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8827),
    [anon_sym_POUNDif] = ACTIONS(8827),
    [anon_sym_POUNDIF] = ACTIONS(8827),
    [anon_sym_POUNDIf] = ACTIONS(8827),
    [anon_sym_POUNDelif] = ACTIONS(8827),
    [anon_sym_POUNDELIF] = ACTIONS(8827),
    [anon_sym_POUNDElif] = ACTIONS(8827),
    [anon_sym_POUNDelse] = ACTIONS(8827),
    [anon_sym_POUNDELSE] = ACTIONS(8827),
    [anon_sym_POUNDElse] = ACTIONS(8827),
    [anon_sym_POUNDendif] = ACTIONS(8827),
    [anon_sym_POUNDENDIF] = ACTIONS(8827),
    [anon_sym_POUNDEndif] = ACTIONS(8827),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8827),
    [sym_trigger_keyword] = ACTIONS(8827),
    [sym_var_keyword] = ACTIONS(8827),
    [sym_local_keyword] = ACTIONS(8827),
    [sym_internal_keyword] = ACTIONS(8827),
    [sym_protected_keyword] = ACTIONS(8827),
    [sym_event_keyword] = ACTIONS(8827),
    [sym_fields_keyword] = ACTIONS(8827),
    [sym_keys_keyword] = ACTIONS(8827),
    [sym_fieldgroups_keyword] = ACTIONS(8827),
    [sym_actions_keyword] = ACTIONS(8827),
    [sym_layout_keyword] = ACTIONS(8827),
    [sym_area_keyword] = ACTIONS(8827),
    [sym_group_keyword] = ACTIONS(8827),
    [sym_repeater_keyword] = ACTIONS(8827),
    [sym_cuegroup_keyword] = ACTIONS(8827),
    [sym_fixed_keyword] = ACTIONS(8827),
    [sym_grid_keyword] = ACTIONS(8827),
    [sym_part_keyword] = ACTIONS(8827),
    [sym_systempart_keyword] = ACTIONS(8827),
    [sym_usercontrol_keyword] = ACTIONS(8827),
    [sym_dataset_keyword] = ACTIONS(8827),
    [sym_elements_keyword] = ACTIONS(8827),
    [sym_dataitem_keyword] = ACTIONS(8827),
    [sym_column_keyword] = ACTIONS(8827),
    [sym_filter_keyword] = ACTIONS(8827),
    [sym_labels_keyword] = ACTIONS(8827),
    [sym_rendering_keyword] = ACTIONS(8827),
    [sym_requestpage_keyword] = ACTIONS(8827),
    [sym_schema_keyword] = ACTIONS(8827),
    [sym_views_keyword] = ACTIONS(8827),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8827),
    [sym_preproc_open] = ACTIONS(8827),
    [sym_preproc_close] = ACTIONS(8827),
  },
  [STATE(3319)] = {
    [anon_sym_SEMI] = ACTIONS(8831),
    [aux_sym_where_condition_token1] = ACTIONS(8833),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8831),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8831),
    [anon_sym_LBRACK] = ACTIONS(8831),
    [aux_sym_basic_type_token6] = ACTIONS(8833),
    [aux_sym_basic_type_token22] = ACTIONS(8833),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8831),
    [aux_sym_addafter_modification_token1] = ACTIONS(8831),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8831),
    [aux_sym_modify_modification_token1] = ACTIONS(8831),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8831),
    [aux_sym_movelast_modification_token1] = ACTIONS(8831),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8831),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8831),
    [aux_sym_separator_action_token1] = ACTIONS(8831),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8831),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8831),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8831),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8831),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8831),
    [anon_sym_POUNDif] = ACTIONS(8831),
    [anon_sym_POUNDIF] = ACTIONS(8831),
    [anon_sym_POUNDIf] = ACTIONS(8831),
    [anon_sym_POUNDelif] = ACTIONS(8831),
    [anon_sym_POUNDELIF] = ACTIONS(8831),
    [anon_sym_POUNDElif] = ACTIONS(8831),
    [anon_sym_POUNDelse] = ACTIONS(8831),
    [anon_sym_POUNDELSE] = ACTIONS(8831),
    [anon_sym_POUNDElse] = ACTIONS(8831),
    [anon_sym_POUNDendif] = ACTIONS(8831),
    [anon_sym_POUNDENDIF] = ACTIONS(8831),
    [anon_sym_POUNDEndif] = ACTIONS(8831),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8831),
    [sym_trigger_keyword] = ACTIONS(8831),
    [sym_var_keyword] = ACTIONS(8831),
    [sym_local_keyword] = ACTIONS(8831),
    [sym_internal_keyword] = ACTIONS(8831),
    [sym_protected_keyword] = ACTIONS(8831),
    [sym_event_keyword] = ACTIONS(8831),
    [sym_fields_keyword] = ACTIONS(8831),
    [sym_keys_keyword] = ACTIONS(8831),
    [sym_fieldgroups_keyword] = ACTIONS(8831),
    [sym_actions_keyword] = ACTIONS(8831),
    [sym_layout_keyword] = ACTIONS(8831),
    [sym_area_keyword] = ACTIONS(8831),
    [sym_group_keyword] = ACTIONS(8831),
    [sym_repeater_keyword] = ACTIONS(8831),
    [sym_cuegroup_keyword] = ACTIONS(8831),
    [sym_fixed_keyword] = ACTIONS(8831),
    [sym_grid_keyword] = ACTIONS(8831),
    [sym_part_keyword] = ACTIONS(8831),
    [sym_systempart_keyword] = ACTIONS(8831),
    [sym_usercontrol_keyword] = ACTIONS(8831),
    [sym_dataset_keyword] = ACTIONS(8831),
    [sym_elements_keyword] = ACTIONS(8831),
    [sym_dataitem_keyword] = ACTIONS(8831),
    [sym_column_keyword] = ACTIONS(8831),
    [sym_filter_keyword] = ACTIONS(8831),
    [sym_labels_keyword] = ACTIONS(8831),
    [sym_rendering_keyword] = ACTIONS(8831),
    [sym_requestpage_keyword] = ACTIONS(8831),
    [sym_schema_keyword] = ACTIONS(8831),
    [sym_views_keyword] = ACTIONS(8831),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8831),
    [sym_preproc_open] = ACTIONS(8831),
    [sym_preproc_close] = ACTIONS(8831),
  },
  [STATE(3320)] = {
    [anon_sym_SEMI] = ACTIONS(8831),
    [aux_sym_where_condition_token1] = ACTIONS(8833),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8831),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8831),
    [anon_sym_LBRACK] = ACTIONS(8831),
    [aux_sym_basic_type_token6] = ACTIONS(8833),
    [aux_sym_basic_type_token22] = ACTIONS(8833),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8831),
    [aux_sym_addafter_modification_token1] = ACTIONS(8831),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8831),
    [aux_sym_modify_modification_token1] = ACTIONS(8831),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8831),
    [aux_sym_movelast_modification_token1] = ACTIONS(8831),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8831),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8831),
    [aux_sym_separator_action_token1] = ACTIONS(8831),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8831),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8831),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8831),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8831),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8831),
    [anon_sym_POUNDif] = ACTIONS(8831),
    [anon_sym_POUNDIF] = ACTIONS(8831),
    [anon_sym_POUNDIf] = ACTIONS(8831),
    [anon_sym_POUNDelif] = ACTIONS(8831),
    [anon_sym_POUNDELIF] = ACTIONS(8831),
    [anon_sym_POUNDElif] = ACTIONS(8831),
    [anon_sym_POUNDelse] = ACTIONS(8831),
    [anon_sym_POUNDELSE] = ACTIONS(8831),
    [anon_sym_POUNDElse] = ACTIONS(8831),
    [anon_sym_POUNDendif] = ACTIONS(8831),
    [anon_sym_POUNDENDIF] = ACTIONS(8831),
    [anon_sym_POUNDEndif] = ACTIONS(8831),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8831),
    [sym_trigger_keyword] = ACTIONS(8831),
    [sym_var_keyword] = ACTIONS(8831),
    [sym_local_keyword] = ACTIONS(8831),
    [sym_internal_keyword] = ACTIONS(8831),
    [sym_protected_keyword] = ACTIONS(8831),
    [sym_event_keyword] = ACTIONS(8831),
    [sym_fields_keyword] = ACTIONS(8831),
    [sym_keys_keyword] = ACTIONS(8831),
    [sym_fieldgroups_keyword] = ACTIONS(8831),
    [sym_actions_keyword] = ACTIONS(8831),
    [sym_layout_keyword] = ACTIONS(8831),
    [sym_area_keyword] = ACTIONS(8831),
    [sym_group_keyword] = ACTIONS(8831),
    [sym_repeater_keyword] = ACTIONS(8831),
    [sym_cuegroup_keyword] = ACTIONS(8831),
    [sym_fixed_keyword] = ACTIONS(8831),
    [sym_grid_keyword] = ACTIONS(8831),
    [sym_part_keyword] = ACTIONS(8831),
    [sym_systempart_keyword] = ACTIONS(8831),
    [sym_usercontrol_keyword] = ACTIONS(8831),
    [sym_dataset_keyword] = ACTIONS(8831),
    [sym_elements_keyword] = ACTIONS(8831),
    [sym_dataitem_keyword] = ACTIONS(8831),
    [sym_column_keyword] = ACTIONS(8831),
    [sym_filter_keyword] = ACTIONS(8831),
    [sym_labels_keyword] = ACTIONS(8831),
    [sym_rendering_keyword] = ACTIONS(8831),
    [sym_requestpage_keyword] = ACTIONS(8831),
    [sym_schema_keyword] = ACTIONS(8831),
    [sym_views_keyword] = ACTIONS(8831),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8831),
    [sym_preproc_open] = ACTIONS(8831),
    [sym_preproc_close] = ACTIONS(8831),
  },
  [STATE(3321)] = {
    [anon_sym_SEMI] = ACTIONS(8831),
    [aux_sym_where_condition_token1] = ACTIONS(8833),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8831),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8831),
    [anon_sym_LBRACK] = ACTIONS(8831),
    [aux_sym_basic_type_token6] = ACTIONS(8833),
    [aux_sym_basic_type_token22] = ACTIONS(8833),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8831),
    [aux_sym_addafter_modification_token1] = ACTIONS(8831),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8831),
    [aux_sym_modify_modification_token1] = ACTIONS(8831),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8831),
    [aux_sym_movelast_modification_token1] = ACTIONS(8831),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8831),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8831),
    [aux_sym_separator_action_token1] = ACTIONS(8831),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8831),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8831),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8831),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8831),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8831),
    [anon_sym_POUNDif] = ACTIONS(8831),
    [anon_sym_POUNDIF] = ACTIONS(8831),
    [anon_sym_POUNDIf] = ACTIONS(8831),
    [anon_sym_POUNDelif] = ACTIONS(8831),
    [anon_sym_POUNDELIF] = ACTIONS(8831),
    [anon_sym_POUNDElif] = ACTIONS(8831),
    [anon_sym_POUNDelse] = ACTIONS(8831),
    [anon_sym_POUNDELSE] = ACTIONS(8831),
    [anon_sym_POUNDElse] = ACTIONS(8831),
    [anon_sym_POUNDendif] = ACTIONS(8831),
    [anon_sym_POUNDENDIF] = ACTIONS(8831),
    [anon_sym_POUNDEndif] = ACTIONS(8831),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8831),
    [sym_trigger_keyword] = ACTIONS(8831),
    [sym_var_keyword] = ACTIONS(8831),
    [sym_local_keyword] = ACTIONS(8831),
    [sym_internal_keyword] = ACTIONS(8831),
    [sym_protected_keyword] = ACTIONS(8831),
    [sym_event_keyword] = ACTIONS(8831),
    [sym_fields_keyword] = ACTIONS(8831),
    [sym_keys_keyword] = ACTIONS(8831),
    [sym_fieldgroups_keyword] = ACTIONS(8831),
    [sym_actions_keyword] = ACTIONS(8831),
    [sym_layout_keyword] = ACTIONS(8831),
    [sym_area_keyword] = ACTIONS(8831),
    [sym_group_keyword] = ACTIONS(8831),
    [sym_repeater_keyword] = ACTIONS(8831),
    [sym_cuegroup_keyword] = ACTIONS(8831),
    [sym_fixed_keyword] = ACTIONS(8831),
    [sym_grid_keyword] = ACTIONS(8831),
    [sym_part_keyword] = ACTIONS(8831),
    [sym_systempart_keyword] = ACTIONS(8831),
    [sym_usercontrol_keyword] = ACTIONS(8831),
    [sym_dataset_keyword] = ACTIONS(8831),
    [sym_elements_keyword] = ACTIONS(8831),
    [sym_dataitem_keyword] = ACTIONS(8831),
    [sym_column_keyword] = ACTIONS(8831),
    [sym_filter_keyword] = ACTIONS(8831),
    [sym_labels_keyword] = ACTIONS(8831),
    [sym_rendering_keyword] = ACTIONS(8831),
    [sym_requestpage_keyword] = ACTIONS(8831),
    [sym_schema_keyword] = ACTIONS(8831),
    [sym_views_keyword] = ACTIONS(8831),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8831),
    [sym_preproc_open] = ACTIONS(8831),
    [sym_preproc_close] = ACTIONS(8831),
  },
  [STATE(3322)] = {
    [anon_sym_SEMI] = ACTIONS(8835),
    [aux_sym_where_condition_token1] = ACTIONS(8837),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8835),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8835),
    [anon_sym_LBRACK] = ACTIONS(8835),
    [aux_sym_basic_type_token6] = ACTIONS(8837),
    [aux_sym_basic_type_token22] = ACTIONS(8837),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8835),
    [aux_sym_addafter_modification_token1] = ACTIONS(8835),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8835),
    [aux_sym_modify_modification_token1] = ACTIONS(8835),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8835),
    [aux_sym_movelast_modification_token1] = ACTIONS(8835),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8835),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8835),
    [aux_sym_separator_action_token1] = ACTIONS(8835),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8835),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8835),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8835),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8835),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8835),
    [anon_sym_POUNDif] = ACTIONS(8835),
    [anon_sym_POUNDIF] = ACTIONS(8835),
    [anon_sym_POUNDIf] = ACTIONS(8835),
    [anon_sym_POUNDelif] = ACTIONS(8835),
    [anon_sym_POUNDELIF] = ACTIONS(8835),
    [anon_sym_POUNDElif] = ACTIONS(8835),
    [anon_sym_POUNDelse] = ACTIONS(8835),
    [anon_sym_POUNDELSE] = ACTIONS(8835),
    [anon_sym_POUNDElse] = ACTIONS(8835),
    [anon_sym_POUNDendif] = ACTIONS(8835),
    [anon_sym_POUNDENDIF] = ACTIONS(8835),
    [anon_sym_POUNDEndif] = ACTIONS(8835),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8835),
    [sym_trigger_keyword] = ACTIONS(8835),
    [sym_var_keyword] = ACTIONS(8835),
    [sym_local_keyword] = ACTIONS(8835),
    [sym_internal_keyword] = ACTIONS(8835),
    [sym_protected_keyword] = ACTIONS(8835),
    [sym_event_keyword] = ACTIONS(8835),
    [sym_fields_keyword] = ACTIONS(8835),
    [sym_keys_keyword] = ACTIONS(8835),
    [sym_fieldgroups_keyword] = ACTIONS(8835),
    [sym_actions_keyword] = ACTIONS(8835),
    [sym_layout_keyword] = ACTIONS(8835),
    [sym_area_keyword] = ACTIONS(8835),
    [sym_group_keyword] = ACTIONS(8835),
    [sym_repeater_keyword] = ACTIONS(8835),
    [sym_cuegroup_keyword] = ACTIONS(8835),
    [sym_fixed_keyword] = ACTIONS(8835),
    [sym_grid_keyword] = ACTIONS(8835),
    [sym_part_keyword] = ACTIONS(8835),
    [sym_systempart_keyword] = ACTIONS(8835),
    [sym_usercontrol_keyword] = ACTIONS(8835),
    [sym_dataset_keyword] = ACTIONS(8835),
    [sym_elements_keyword] = ACTIONS(8835),
    [sym_dataitem_keyword] = ACTIONS(8835),
    [sym_column_keyword] = ACTIONS(8835),
    [sym_filter_keyword] = ACTIONS(8835),
    [sym_labels_keyword] = ACTIONS(8835),
    [sym_rendering_keyword] = ACTIONS(8835),
    [sym_requestpage_keyword] = ACTIONS(8835),
    [sym_schema_keyword] = ACTIONS(8835),
    [sym_views_keyword] = ACTIONS(8835),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8835),
    [sym_preproc_open] = ACTIONS(8835),
    [sym_preproc_close] = ACTIONS(8835),
  },
  [STATE(3323)] = {
    [anon_sym_SEMI] = ACTIONS(8835),
    [aux_sym_where_condition_token1] = ACTIONS(8837),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8835),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8835),
    [anon_sym_LBRACK] = ACTIONS(8835),
    [aux_sym_basic_type_token6] = ACTIONS(8837),
    [aux_sym_basic_type_token22] = ACTIONS(8837),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8835),
    [aux_sym_addafter_modification_token1] = ACTIONS(8835),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8835),
    [aux_sym_modify_modification_token1] = ACTIONS(8835),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8835),
    [aux_sym_movelast_modification_token1] = ACTIONS(8835),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8835),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8835),
    [aux_sym_separator_action_token1] = ACTIONS(8835),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8835),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8835),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8835),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8835),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8835),
    [anon_sym_POUNDif] = ACTIONS(8835),
    [anon_sym_POUNDIF] = ACTIONS(8835),
    [anon_sym_POUNDIf] = ACTIONS(8835),
    [anon_sym_POUNDelif] = ACTIONS(8835),
    [anon_sym_POUNDELIF] = ACTIONS(8835),
    [anon_sym_POUNDElif] = ACTIONS(8835),
    [anon_sym_POUNDelse] = ACTIONS(8835),
    [anon_sym_POUNDELSE] = ACTIONS(8835),
    [anon_sym_POUNDElse] = ACTIONS(8835),
    [anon_sym_POUNDendif] = ACTIONS(8835),
    [anon_sym_POUNDENDIF] = ACTIONS(8835),
    [anon_sym_POUNDEndif] = ACTIONS(8835),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8835),
    [sym_trigger_keyword] = ACTIONS(8835),
    [sym_var_keyword] = ACTIONS(8835),
    [sym_local_keyword] = ACTIONS(8835),
    [sym_internal_keyword] = ACTIONS(8835),
    [sym_protected_keyword] = ACTIONS(8835),
    [sym_event_keyword] = ACTIONS(8835),
    [sym_fields_keyword] = ACTIONS(8835),
    [sym_keys_keyword] = ACTIONS(8835),
    [sym_fieldgroups_keyword] = ACTIONS(8835),
    [sym_actions_keyword] = ACTIONS(8835),
    [sym_layout_keyword] = ACTIONS(8835),
    [sym_area_keyword] = ACTIONS(8835),
    [sym_group_keyword] = ACTIONS(8835),
    [sym_repeater_keyword] = ACTIONS(8835),
    [sym_cuegroup_keyword] = ACTIONS(8835),
    [sym_fixed_keyword] = ACTIONS(8835),
    [sym_grid_keyword] = ACTIONS(8835),
    [sym_part_keyword] = ACTIONS(8835),
    [sym_systempart_keyword] = ACTIONS(8835),
    [sym_usercontrol_keyword] = ACTIONS(8835),
    [sym_dataset_keyword] = ACTIONS(8835),
    [sym_elements_keyword] = ACTIONS(8835),
    [sym_dataitem_keyword] = ACTIONS(8835),
    [sym_column_keyword] = ACTIONS(8835),
    [sym_filter_keyword] = ACTIONS(8835),
    [sym_labels_keyword] = ACTIONS(8835),
    [sym_rendering_keyword] = ACTIONS(8835),
    [sym_requestpage_keyword] = ACTIONS(8835),
    [sym_schema_keyword] = ACTIONS(8835),
    [sym_views_keyword] = ACTIONS(8835),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8835),
    [sym_preproc_open] = ACTIONS(8835),
    [sym_preproc_close] = ACTIONS(8835),
  },
  [STATE(3324)] = {
    [anon_sym_SEMI] = ACTIONS(8835),
    [aux_sym_where_condition_token1] = ACTIONS(8837),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8835),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8835),
    [anon_sym_LBRACK] = ACTIONS(8835),
    [aux_sym_basic_type_token6] = ACTIONS(8837),
    [aux_sym_basic_type_token22] = ACTIONS(8837),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8835),
    [aux_sym_addafter_modification_token1] = ACTIONS(8835),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8835),
    [aux_sym_modify_modification_token1] = ACTIONS(8835),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8835),
    [aux_sym_movelast_modification_token1] = ACTIONS(8835),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8835),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8835),
    [aux_sym_separator_action_token1] = ACTIONS(8835),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8835),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8835),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8835),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8835),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8835),
    [anon_sym_POUNDif] = ACTIONS(8835),
    [anon_sym_POUNDIF] = ACTIONS(8835),
    [anon_sym_POUNDIf] = ACTIONS(8835),
    [anon_sym_POUNDelif] = ACTIONS(8835),
    [anon_sym_POUNDELIF] = ACTIONS(8835),
    [anon_sym_POUNDElif] = ACTIONS(8835),
    [anon_sym_POUNDelse] = ACTIONS(8835),
    [anon_sym_POUNDELSE] = ACTIONS(8835),
    [anon_sym_POUNDElse] = ACTIONS(8835),
    [anon_sym_POUNDendif] = ACTIONS(8835),
    [anon_sym_POUNDENDIF] = ACTIONS(8835),
    [anon_sym_POUNDEndif] = ACTIONS(8835),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8835),
    [sym_trigger_keyword] = ACTIONS(8835),
    [sym_var_keyword] = ACTIONS(8835),
    [sym_local_keyword] = ACTIONS(8835),
    [sym_internal_keyword] = ACTIONS(8835),
    [sym_protected_keyword] = ACTIONS(8835),
    [sym_event_keyword] = ACTIONS(8835),
    [sym_fields_keyword] = ACTIONS(8835),
    [sym_keys_keyword] = ACTIONS(8835),
    [sym_fieldgroups_keyword] = ACTIONS(8835),
    [sym_actions_keyword] = ACTIONS(8835),
    [sym_layout_keyword] = ACTIONS(8835),
    [sym_area_keyword] = ACTIONS(8835),
    [sym_group_keyword] = ACTIONS(8835),
    [sym_repeater_keyword] = ACTIONS(8835),
    [sym_cuegroup_keyword] = ACTIONS(8835),
    [sym_fixed_keyword] = ACTIONS(8835),
    [sym_grid_keyword] = ACTIONS(8835),
    [sym_part_keyword] = ACTIONS(8835),
    [sym_systempart_keyword] = ACTIONS(8835),
    [sym_usercontrol_keyword] = ACTIONS(8835),
    [sym_dataset_keyword] = ACTIONS(8835),
    [sym_elements_keyword] = ACTIONS(8835),
    [sym_dataitem_keyword] = ACTIONS(8835),
    [sym_column_keyword] = ACTIONS(8835),
    [sym_filter_keyword] = ACTIONS(8835),
    [sym_labels_keyword] = ACTIONS(8835),
    [sym_rendering_keyword] = ACTIONS(8835),
    [sym_requestpage_keyword] = ACTIONS(8835),
    [sym_schema_keyword] = ACTIONS(8835),
    [sym_views_keyword] = ACTIONS(8835),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8835),
    [sym_preproc_open] = ACTIONS(8835),
    [sym_preproc_close] = ACTIONS(8835),
  },
  [STATE(3325)] = {
    [sym__body_element] = STATE(3330),
    [sym_empty_statement] = STATE(3330),
    [sym_property] = STATE(3330),
    [sym_fields_section] = STATE(3330),
    [sym_keys_section] = STATE(3330),
    [sym_fieldgroups_section] = STATE(3330),
    [sym_enum_value_declaration] = STATE(3330),
    [sym_labels_section] = STATE(3330),
    [sym_layout_section] = STATE(3330),
    [sym_modify_modification] = STATE(3330),
    [sym_actions_section] = STATE(3330),
    [sym_views_section] = STATE(3330),
    [sym_dataset_section] = STATE(3330),
    [sym_requestpage_section] = STATE(3330),
    [sym_rendering_section] = STATE(3330),
    [sym_elements_section] = STATE(3330),
    [sym_schema_section] = STATE(3330),
    [sym_xmlport_element] = STATE(3330),
    [sym__xmlport_body_element] = STATE(3330),
    [sym_preproc_conditional_xmlport] = STATE(3330),
    [sym_xmlport_attribute] = STATE(3330),
    [sym_assembly_declaration] = STATE(3330),
    [sym_event_declaration] = STATE(3330),
    [sym_procedure] = STATE(3330),
    [sym_preproc_split_procedure] = STATE(3330),
    [sym_procedure_modifier] = STATE(12392),
    [sym_trigger_declaration] = STATE(3330),
    [sym_var_section] = STATE(3330),
    [sym_attribute_item] = STATE(3330),
    [sym_preproc_conditional] = STATE(3330),
    [sym_preproc_if] = STATE(2456),
    [aux_sym_xmlport_element_repeat1] = STATE(3330),
    [anon_sym_SEMI] = ACTIONS(8638),
    [anon_sym_RBRACE] = ACTIONS(8839),
    [anon_sym_LBRACK] = ACTIONS(8642),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8644),
    [aux_sym_modify_modification_token1] = ACTIONS(8646),
    [aux_sym_xmlport_element_token1] = ACTIONS(8648),
    [aux_sym_xmlport_element_token2] = ACTIONS(8648),
    [aux_sym_xmlport_element_token3] = ACTIONS(8648),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8650),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8650),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8652),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8654),
    [sym_trigger_keyword] = ACTIONS(8656),
    [sym_var_keyword] = ACTIONS(8658),
    [sym_local_keyword] = ACTIONS(8660),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(8660),
    [sym_event_keyword] = ACTIONS(8662),
    [sym_fields_keyword] = ACTIONS(8664),
    [sym_keys_keyword] = ACTIONS(8666),
    [sym_fieldgroups_keyword] = ACTIONS(8668),
    [sym_actions_keyword] = ACTIONS(8670),
    [sym_layout_keyword] = ACTIONS(8672),
    [sym_dataset_keyword] = ACTIONS(8674),
    [sym_elements_keyword] = ACTIONS(8676),
    [sym_labels_keyword] = ACTIONS(8678),
    [sym_rendering_keyword] = ACTIONS(8680),
    [sym_requestpage_keyword] = ACTIONS(8682),
    [sym_schema_keyword] = ACTIONS(8684),
    [sym_views_keyword] = ACTIONS(8686),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8688),
    [sym_preproc_open] = ACTIONS(5823),
  },
  [STATE(3326)] = {
    [anon_sym_SEMI] = ACTIONS(8841),
    [aux_sym_where_condition_token1] = ACTIONS(8843),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8841),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8841),
    [anon_sym_LBRACK] = ACTIONS(8841),
    [aux_sym_basic_type_token6] = ACTIONS(8843),
    [aux_sym_basic_type_token22] = ACTIONS(8843),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8841),
    [aux_sym_addafter_modification_token1] = ACTIONS(8841),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8841),
    [aux_sym_modify_modification_token1] = ACTIONS(8841),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8841),
    [aux_sym_movelast_modification_token1] = ACTIONS(8841),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8841),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8841),
    [aux_sym_separator_action_token1] = ACTIONS(8841),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8841),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8841),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8841),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8841),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8841),
    [anon_sym_POUNDif] = ACTIONS(8841),
    [anon_sym_POUNDIF] = ACTIONS(8841),
    [anon_sym_POUNDIf] = ACTIONS(8841),
    [anon_sym_POUNDelif] = ACTIONS(8841),
    [anon_sym_POUNDELIF] = ACTIONS(8841),
    [anon_sym_POUNDElif] = ACTIONS(8841),
    [anon_sym_POUNDelse] = ACTIONS(8841),
    [anon_sym_POUNDELSE] = ACTIONS(8841),
    [anon_sym_POUNDElse] = ACTIONS(8841),
    [anon_sym_POUNDendif] = ACTIONS(8841),
    [anon_sym_POUNDENDIF] = ACTIONS(8841),
    [anon_sym_POUNDEndif] = ACTIONS(8841),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8841),
    [sym_trigger_keyword] = ACTIONS(8841),
    [sym_var_keyword] = ACTIONS(8841),
    [sym_local_keyword] = ACTIONS(8841),
    [sym_internal_keyword] = ACTIONS(8841),
    [sym_protected_keyword] = ACTIONS(8841),
    [sym_event_keyword] = ACTIONS(8841),
    [sym_fields_keyword] = ACTIONS(8841),
    [sym_keys_keyword] = ACTIONS(8841),
    [sym_fieldgroups_keyword] = ACTIONS(8841),
    [sym_actions_keyword] = ACTIONS(8841),
    [sym_layout_keyword] = ACTIONS(8841),
    [sym_area_keyword] = ACTIONS(8841),
    [sym_group_keyword] = ACTIONS(8841),
    [sym_repeater_keyword] = ACTIONS(8841),
    [sym_cuegroup_keyword] = ACTIONS(8841),
    [sym_fixed_keyword] = ACTIONS(8841),
    [sym_grid_keyword] = ACTIONS(8841),
    [sym_part_keyword] = ACTIONS(8841),
    [sym_systempart_keyword] = ACTIONS(8841),
    [sym_usercontrol_keyword] = ACTIONS(8841),
    [sym_dataset_keyword] = ACTIONS(8841),
    [sym_elements_keyword] = ACTIONS(8841),
    [sym_dataitem_keyword] = ACTIONS(8841),
    [sym_column_keyword] = ACTIONS(8841),
    [sym_filter_keyword] = ACTIONS(8841),
    [sym_labels_keyword] = ACTIONS(8841),
    [sym_rendering_keyword] = ACTIONS(8841),
    [sym_requestpage_keyword] = ACTIONS(8841),
    [sym_schema_keyword] = ACTIONS(8841),
    [sym_views_keyword] = ACTIONS(8841),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8841),
    [sym_preproc_open] = ACTIONS(8841),
    [sym_preproc_close] = ACTIONS(8841),
  },
  [STATE(3327)] = {
    [anon_sym_SEMI] = ACTIONS(8841),
    [aux_sym_where_condition_token1] = ACTIONS(8843),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8841),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8841),
    [anon_sym_LBRACK] = ACTIONS(8841),
    [aux_sym_basic_type_token6] = ACTIONS(8843),
    [aux_sym_basic_type_token22] = ACTIONS(8843),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8841),
    [aux_sym_addafter_modification_token1] = ACTIONS(8841),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8841),
    [aux_sym_modify_modification_token1] = ACTIONS(8841),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8841),
    [aux_sym_movelast_modification_token1] = ACTIONS(8841),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8841),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8841),
    [aux_sym_separator_action_token1] = ACTIONS(8841),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8841),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8841),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8841),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8841),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8841),
    [anon_sym_POUNDif] = ACTIONS(8841),
    [anon_sym_POUNDIF] = ACTIONS(8841),
    [anon_sym_POUNDIf] = ACTIONS(8841),
    [anon_sym_POUNDelif] = ACTIONS(8841),
    [anon_sym_POUNDELIF] = ACTIONS(8841),
    [anon_sym_POUNDElif] = ACTIONS(8841),
    [anon_sym_POUNDelse] = ACTIONS(8841),
    [anon_sym_POUNDELSE] = ACTIONS(8841),
    [anon_sym_POUNDElse] = ACTIONS(8841),
    [anon_sym_POUNDendif] = ACTIONS(8841),
    [anon_sym_POUNDENDIF] = ACTIONS(8841),
    [anon_sym_POUNDEndif] = ACTIONS(8841),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8841),
    [sym_trigger_keyword] = ACTIONS(8841),
    [sym_var_keyword] = ACTIONS(8841),
    [sym_local_keyword] = ACTIONS(8841),
    [sym_internal_keyword] = ACTIONS(8841),
    [sym_protected_keyword] = ACTIONS(8841),
    [sym_event_keyword] = ACTIONS(8841),
    [sym_fields_keyword] = ACTIONS(8841),
    [sym_keys_keyword] = ACTIONS(8841),
    [sym_fieldgroups_keyword] = ACTIONS(8841),
    [sym_actions_keyword] = ACTIONS(8841),
    [sym_layout_keyword] = ACTIONS(8841),
    [sym_area_keyword] = ACTIONS(8841),
    [sym_group_keyword] = ACTIONS(8841),
    [sym_repeater_keyword] = ACTIONS(8841),
    [sym_cuegroup_keyword] = ACTIONS(8841),
    [sym_fixed_keyword] = ACTIONS(8841),
    [sym_grid_keyword] = ACTIONS(8841),
    [sym_part_keyword] = ACTIONS(8841),
    [sym_systempart_keyword] = ACTIONS(8841),
    [sym_usercontrol_keyword] = ACTIONS(8841),
    [sym_dataset_keyword] = ACTIONS(8841),
    [sym_elements_keyword] = ACTIONS(8841),
    [sym_dataitem_keyword] = ACTIONS(8841),
    [sym_column_keyword] = ACTIONS(8841),
    [sym_filter_keyword] = ACTIONS(8841),
    [sym_labels_keyword] = ACTIONS(8841),
    [sym_rendering_keyword] = ACTIONS(8841),
    [sym_requestpage_keyword] = ACTIONS(8841),
    [sym_schema_keyword] = ACTIONS(8841),
    [sym_views_keyword] = ACTIONS(8841),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8841),
    [sym_preproc_open] = ACTIONS(8841),
    [sym_preproc_close] = ACTIONS(8841),
  },
  [STATE(3328)] = {
    [anon_sym_SEMI] = ACTIONS(8845),
    [aux_sym_where_condition_token1] = ACTIONS(8847),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8845),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8845),
    [anon_sym_LBRACK] = ACTIONS(8845),
    [aux_sym_basic_type_token6] = ACTIONS(8847),
    [aux_sym_basic_type_token22] = ACTIONS(8847),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8845),
    [aux_sym_addafter_modification_token1] = ACTIONS(8845),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8845),
    [aux_sym_modify_modification_token1] = ACTIONS(8845),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8845),
    [aux_sym_movelast_modification_token1] = ACTIONS(8845),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8845),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8845),
    [aux_sym_separator_action_token1] = ACTIONS(8845),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8845),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8845),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8845),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8845),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8845),
    [anon_sym_POUNDif] = ACTIONS(8845),
    [anon_sym_POUNDIF] = ACTIONS(8845),
    [anon_sym_POUNDIf] = ACTIONS(8845),
    [anon_sym_POUNDelif] = ACTIONS(8845),
    [anon_sym_POUNDELIF] = ACTIONS(8845),
    [anon_sym_POUNDElif] = ACTIONS(8845),
    [anon_sym_POUNDelse] = ACTIONS(8845),
    [anon_sym_POUNDELSE] = ACTIONS(8845),
    [anon_sym_POUNDElse] = ACTIONS(8845),
    [anon_sym_POUNDendif] = ACTIONS(8845),
    [anon_sym_POUNDENDIF] = ACTIONS(8845),
    [anon_sym_POUNDEndif] = ACTIONS(8845),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8845),
    [sym_trigger_keyword] = ACTIONS(8845),
    [sym_var_keyword] = ACTIONS(8845),
    [sym_local_keyword] = ACTIONS(8845),
    [sym_internal_keyword] = ACTIONS(8845),
    [sym_protected_keyword] = ACTIONS(8845),
    [sym_event_keyword] = ACTIONS(8845),
    [sym_fields_keyword] = ACTIONS(8845),
    [sym_keys_keyword] = ACTIONS(8845),
    [sym_fieldgroups_keyword] = ACTIONS(8845),
    [sym_actions_keyword] = ACTIONS(8845),
    [sym_layout_keyword] = ACTIONS(8845),
    [sym_area_keyword] = ACTIONS(8845),
    [sym_group_keyword] = ACTIONS(8845),
    [sym_repeater_keyword] = ACTIONS(8845),
    [sym_cuegroup_keyword] = ACTIONS(8845),
    [sym_fixed_keyword] = ACTIONS(8845),
    [sym_grid_keyword] = ACTIONS(8845),
    [sym_part_keyword] = ACTIONS(8845),
    [sym_systempart_keyword] = ACTIONS(8845),
    [sym_usercontrol_keyword] = ACTIONS(8845),
    [sym_dataset_keyword] = ACTIONS(8845),
    [sym_elements_keyword] = ACTIONS(8845),
    [sym_dataitem_keyword] = ACTIONS(8845),
    [sym_column_keyword] = ACTIONS(8845),
    [sym_filter_keyword] = ACTIONS(8845),
    [sym_labels_keyword] = ACTIONS(8845),
    [sym_rendering_keyword] = ACTIONS(8845),
    [sym_requestpage_keyword] = ACTIONS(8845),
    [sym_schema_keyword] = ACTIONS(8845),
    [sym_views_keyword] = ACTIONS(8845),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8845),
    [sym_preproc_open] = ACTIONS(8845),
    [sym_preproc_close] = ACTIONS(8845),
  },
  [STATE(3329)] = {
    [anon_sym_SEMI] = ACTIONS(8845),
    [aux_sym_where_condition_token1] = ACTIONS(8847),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8845),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8845),
    [anon_sym_LBRACK] = ACTIONS(8845),
    [aux_sym_basic_type_token6] = ACTIONS(8847),
    [aux_sym_basic_type_token22] = ACTIONS(8847),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8845),
    [aux_sym_addafter_modification_token1] = ACTIONS(8845),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8845),
    [aux_sym_modify_modification_token1] = ACTIONS(8845),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8845),
    [aux_sym_movelast_modification_token1] = ACTIONS(8845),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8845),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8845),
    [aux_sym_separator_action_token1] = ACTIONS(8845),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8845),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8845),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8845),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8845),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8845),
    [anon_sym_POUNDif] = ACTIONS(8845),
    [anon_sym_POUNDIF] = ACTIONS(8845),
    [anon_sym_POUNDIf] = ACTIONS(8845),
    [anon_sym_POUNDelif] = ACTIONS(8845),
    [anon_sym_POUNDELIF] = ACTIONS(8845),
    [anon_sym_POUNDElif] = ACTIONS(8845),
    [anon_sym_POUNDelse] = ACTIONS(8845),
    [anon_sym_POUNDELSE] = ACTIONS(8845),
    [anon_sym_POUNDElse] = ACTIONS(8845),
    [anon_sym_POUNDendif] = ACTIONS(8845),
    [anon_sym_POUNDENDIF] = ACTIONS(8845),
    [anon_sym_POUNDEndif] = ACTIONS(8845),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8845),
    [sym_trigger_keyword] = ACTIONS(8845),
    [sym_var_keyword] = ACTIONS(8845),
    [sym_local_keyword] = ACTIONS(8845),
    [sym_internal_keyword] = ACTIONS(8845),
    [sym_protected_keyword] = ACTIONS(8845),
    [sym_event_keyword] = ACTIONS(8845),
    [sym_fields_keyword] = ACTIONS(8845),
    [sym_keys_keyword] = ACTIONS(8845),
    [sym_fieldgroups_keyword] = ACTIONS(8845),
    [sym_actions_keyword] = ACTIONS(8845),
    [sym_layout_keyword] = ACTIONS(8845),
    [sym_area_keyword] = ACTIONS(8845),
    [sym_group_keyword] = ACTIONS(8845),
    [sym_repeater_keyword] = ACTIONS(8845),
    [sym_cuegroup_keyword] = ACTIONS(8845),
    [sym_fixed_keyword] = ACTIONS(8845),
    [sym_grid_keyword] = ACTIONS(8845),
    [sym_part_keyword] = ACTIONS(8845),
    [sym_systempart_keyword] = ACTIONS(8845),
    [sym_usercontrol_keyword] = ACTIONS(8845),
    [sym_dataset_keyword] = ACTIONS(8845),
    [sym_elements_keyword] = ACTIONS(8845),
    [sym_dataitem_keyword] = ACTIONS(8845),
    [sym_column_keyword] = ACTIONS(8845),
    [sym_filter_keyword] = ACTIONS(8845),
    [sym_labels_keyword] = ACTIONS(8845),
    [sym_rendering_keyword] = ACTIONS(8845),
    [sym_requestpage_keyword] = ACTIONS(8845),
    [sym_schema_keyword] = ACTIONS(8845),
    [sym_views_keyword] = ACTIONS(8845),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8845),
    [sym_preproc_open] = ACTIONS(8845),
    [sym_preproc_close] = ACTIONS(8845),
  },
  [STATE(3330)] = {
    [sym__body_element] = STATE(3330),
    [sym_empty_statement] = STATE(3330),
    [sym_property] = STATE(3330),
    [sym_fields_section] = STATE(3330),
    [sym_keys_section] = STATE(3330),
    [sym_fieldgroups_section] = STATE(3330),
    [sym_enum_value_declaration] = STATE(3330),
    [sym_labels_section] = STATE(3330),
    [sym_layout_section] = STATE(3330),
    [sym_modify_modification] = STATE(3330),
    [sym_actions_section] = STATE(3330),
    [sym_views_section] = STATE(3330),
    [sym_dataset_section] = STATE(3330),
    [sym_requestpage_section] = STATE(3330),
    [sym_rendering_section] = STATE(3330),
    [sym_elements_section] = STATE(3330),
    [sym_schema_section] = STATE(3330),
    [sym_xmlport_element] = STATE(3330),
    [sym__xmlport_body_element] = STATE(3330),
    [sym_preproc_conditional_xmlport] = STATE(3330),
    [sym_xmlport_attribute] = STATE(3330),
    [sym_assembly_declaration] = STATE(3330),
    [sym_event_declaration] = STATE(3330),
    [sym_procedure] = STATE(3330),
    [sym_preproc_split_procedure] = STATE(3330),
    [sym_procedure_modifier] = STATE(12392),
    [sym_trigger_declaration] = STATE(3330),
    [sym_var_section] = STATE(3330),
    [sym_attribute_item] = STATE(3330),
    [sym_preproc_conditional] = STATE(3330),
    [sym_preproc_if] = STATE(2456),
    [aux_sym_xmlport_element_repeat1] = STATE(3330),
    [anon_sym_SEMI] = ACTIONS(8849),
    [anon_sym_RBRACE] = ACTIONS(6312),
    [anon_sym_LBRACK] = ACTIONS(8852),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8855),
    [aux_sym_modify_modification_token1] = ACTIONS(8858),
    [aux_sym_xmlport_element_token1] = ACTIONS(8861),
    [aux_sym_xmlport_element_token2] = ACTIONS(8861),
    [aux_sym_xmlport_element_token3] = ACTIONS(8861),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8864),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8864),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8867),
    [anon_sym_POUNDif] = ACTIONS(6309),
    [anon_sym_POUNDIF] = ACTIONS(6309),
    [anon_sym_POUNDIf] = ACTIONS(6309),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8870),
    [sym_trigger_keyword] = ACTIONS(8873),
    [sym_var_keyword] = ACTIONS(8876),
    [sym_local_keyword] = ACTIONS(8879),
    [sym_internal_keyword] = ACTIONS(6326),
    [sym_protected_keyword] = ACTIONS(8879),
    [sym_event_keyword] = ACTIONS(8882),
    [sym_fields_keyword] = ACTIONS(8885),
    [sym_keys_keyword] = ACTIONS(8888),
    [sym_fieldgroups_keyword] = ACTIONS(8891),
    [sym_actions_keyword] = ACTIONS(8894),
    [sym_layout_keyword] = ACTIONS(8897),
    [sym_dataset_keyword] = ACTIONS(8900),
    [sym_elements_keyword] = ACTIONS(8903),
    [sym_labels_keyword] = ACTIONS(8906),
    [sym_rendering_keyword] = ACTIONS(8909),
    [sym_requestpage_keyword] = ACTIONS(8912),
    [sym_schema_keyword] = ACTIONS(8915),
    [sym_views_keyword] = ACTIONS(8918),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8921),
    [sym_preproc_open] = ACTIONS(6309),
  },
  [STATE(3331)] = {
    [anon_sym_SEMI] = ACTIONS(4469),
    [aux_sym_where_condition_token1] = ACTIONS(4467),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4469),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4469),
    [anon_sym_LBRACK] = ACTIONS(4469),
    [aux_sym_basic_type_token6] = ACTIONS(4467),
    [aux_sym_basic_type_token22] = ACTIONS(4467),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4469),
    [aux_sym_addafter_modification_token1] = ACTIONS(4469),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4469),
    [aux_sym_modify_modification_token1] = ACTIONS(4469),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4469),
    [aux_sym_movelast_modification_token1] = ACTIONS(4469),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4469),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4469),
    [aux_sym_separator_action_token1] = ACTIONS(4469),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4469),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4469),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4469),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4469),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4469),
    [anon_sym_POUNDif] = ACTIONS(4469),
    [anon_sym_POUNDIF] = ACTIONS(4469),
    [anon_sym_POUNDIf] = ACTIONS(4469),
    [anon_sym_POUNDelif] = ACTIONS(4469),
    [anon_sym_POUNDELIF] = ACTIONS(4469),
    [anon_sym_POUNDElif] = ACTIONS(4469),
    [anon_sym_POUNDelse] = ACTIONS(4469),
    [anon_sym_POUNDELSE] = ACTIONS(4469),
    [anon_sym_POUNDElse] = ACTIONS(4469),
    [anon_sym_POUNDendif] = ACTIONS(4469),
    [anon_sym_POUNDENDIF] = ACTIONS(4469),
    [anon_sym_POUNDEndif] = ACTIONS(4469),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4469),
    [sym_trigger_keyword] = ACTIONS(4469),
    [sym_var_keyword] = ACTIONS(4469),
    [sym_local_keyword] = ACTIONS(4469),
    [sym_internal_keyword] = ACTIONS(4469),
    [sym_protected_keyword] = ACTIONS(4469),
    [sym_event_keyword] = ACTIONS(4469),
    [sym_fields_keyword] = ACTIONS(4469),
    [sym_keys_keyword] = ACTIONS(4469),
    [sym_fieldgroups_keyword] = ACTIONS(4469),
    [sym_actions_keyword] = ACTIONS(4469),
    [sym_layout_keyword] = ACTIONS(4469),
    [sym_area_keyword] = ACTIONS(4469),
    [sym_group_keyword] = ACTIONS(4469),
    [sym_repeater_keyword] = ACTIONS(4469),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4469),
    [sym_grid_keyword] = ACTIONS(4469),
    [sym_part_keyword] = ACTIONS(4469),
    [sym_systempart_keyword] = ACTIONS(4469),
    [sym_usercontrol_keyword] = ACTIONS(4469),
    [sym_dataset_keyword] = ACTIONS(4469),
    [sym_elements_keyword] = ACTIONS(4469),
    [sym_dataitem_keyword] = ACTIONS(4469),
    [sym_column_keyword] = ACTIONS(4469),
    [sym_filter_keyword] = ACTIONS(4469),
    [sym_labels_keyword] = ACTIONS(4469),
    [sym_rendering_keyword] = ACTIONS(4469),
    [sym_requestpage_keyword] = ACTIONS(4469),
    [sym_schema_keyword] = ACTIONS(4469),
    [sym_views_keyword] = ACTIONS(4469),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4469),
    [sym_preproc_open] = ACTIONS(4469),
    [sym_preproc_close] = ACTIONS(4469),
  },
  [STATE(3332)] = {
    [anon_sym_SEMI] = ACTIONS(4810),
    [aux_sym_where_condition_token1] = ACTIONS(4808),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4810),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4810),
    [anon_sym_LBRACK] = ACTIONS(4810),
    [aux_sym_basic_type_token6] = ACTIONS(4808),
    [aux_sym_basic_type_token22] = ACTIONS(4808),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4810),
    [aux_sym_addafter_modification_token1] = ACTIONS(4810),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4810),
    [aux_sym_modify_modification_token1] = ACTIONS(4810),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4810),
    [aux_sym_movelast_modification_token1] = ACTIONS(4810),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4810),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4810),
    [aux_sym_separator_action_token1] = ACTIONS(4810),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4810),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4810),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4810),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4810),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4810),
    [anon_sym_POUNDif] = ACTIONS(4810),
    [anon_sym_POUNDIF] = ACTIONS(4810),
    [anon_sym_POUNDIf] = ACTIONS(4810),
    [anon_sym_POUNDelif] = ACTIONS(4810),
    [anon_sym_POUNDELIF] = ACTIONS(4810),
    [anon_sym_POUNDElif] = ACTIONS(4810),
    [anon_sym_POUNDelse] = ACTIONS(4810),
    [anon_sym_POUNDELSE] = ACTIONS(4810),
    [anon_sym_POUNDElse] = ACTIONS(4810),
    [anon_sym_POUNDendif] = ACTIONS(4810),
    [anon_sym_POUNDENDIF] = ACTIONS(4810),
    [anon_sym_POUNDEndif] = ACTIONS(4810),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4810),
    [sym_trigger_keyword] = ACTIONS(4810),
    [sym_var_keyword] = ACTIONS(4810),
    [sym_local_keyword] = ACTIONS(4810),
    [sym_internal_keyword] = ACTIONS(4810),
    [sym_protected_keyword] = ACTIONS(4810),
    [sym_event_keyword] = ACTIONS(4810),
    [sym_fields_keyword] = ACTIONS(4810),
    [sym_keys_keyword] = ACTIONS(4810),
    [sym_fieldgroups_keyword] = ACTIONS(4810),
    [sym_actions_keyword] = ACTIONS(4810),
    [sym_layout_keyword] = ACTIONS(4810),
    [sym_area_keyword] = ACTIONS(4810),
    [sym_group_keyword] = ACTIONS(4810),
    [sym_repeater_keyword] = ACTIONS(4810),
    [sym_cuegroup_keyword] = ACTIONS(4810),
    [sym_fixed_keyword] = ACTIONS(4810),
    [sym_grid_keyword] = ACTIONS(4810),
    [sym_part_keyword] = ACTIONS(4810),
    [sym_systempart_keyword] = ACTIONS(4810),
    [sym_usercontrol_keyword] = ACTIONS(4810),
    [sym_dataset_keyword] = ACTIONS(4810),
    [sym_elements_keyword] = ACTIONS(4810),
    [sym_dataitem_keyword] = ACTIONS(4810),
    [sym_column_keyword] = ACTIONS(4810),
    [sym_filter_keyword] = ACTIONS(4810),
    [sym_labels_keyword] = ACTIONS(4810),
    [sym_rendering_keyword] = ACTIONS(4810),
    [sym_requestpage_keyword] = ACTIONS(4810),
    [sym_schema_keyword] = ACTIONS(4810),
    [sym_views_keyword] = ACTIONS(4810),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4810),
    [sym_preproc_open] = ACTIONS(4810),
    [sym_preproc_close] = ACTIONS(4810),
  },
  [STATE(3333)] = {
    [sym__body_element] = STATE(3336),
    [sym_empty_statement] = STATE(3336),
    [sym_property] = STATE(3336),
    [sym_fields_section] = STATE(3336),
    [sym_keys_section] = STATE(3336),
    [sym_fieldgroups_section] = STATE(3336),
    [sym_enum_value_declaration] = STATE(3336),
    [sym_labels_section] = STATE(3336),
    [sym_layout_section] = STATE(3336),
    [sym_modify_modification] = STATE(3336),
    [sym_actions_section] = STATE(3336),
    [sym_views_section] = STATE(3336),
    [sym_dataset_section] = STATE(3336),
    [sym_requestpage_section] = STATE(3336),
    [sym_rendering_section] = STATE(3336),
    [sym_elements_section] = STATE(3336),
    [sym_schema_section] = STATE(3336),
    [sym_xmlport_element] = STATE(3336),
    [sym__xmlport_body_element] = STATE(3336),
    [sym_preproc_conditional_xmlport] = STATE(3336),
    [sym_xmlport_attribute] = STATE(3336),
    [sym_assembly_declaration] = STATE(3336),
    [sym_event_declaration] = STATE(3336),
    [sym_procedure] = STATE(3336),
    [sym_preproc_split_procedure] = STATE(3336),
    [sym_procedure_modifier] = STATE(12392),
    [sym_trigger_declaration] = STATE(3336),
    [sym_var_section] = STATE(3336),
    [sym_attribute_item] = STATE(3336),
    [sym_preproc_conditional] = STATE(3336),
    [sym_preproc_if] = STATE(2456),
    [aux_sym_xmlport_element_repeat1] = STATE(3336),
    [anon_sym_SEMI] = ACTIONS(8638),
    [anon_sym_RBRACE] = ACTIONS(8924),
    [anon_sym_LBRACK] = ACTIONS(8642),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8644),
    [aux_sym_modify_modification_token1] = ACTIONS(8646),
    [aux_sym_xmlport_element_token1] = ACTIONS(8648),
    [aux_sym_xmlport_element_token2] = ACTIONS(8648),
    [aux_sym_xmlport_element_token3] = ACTIONS(8648),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8650),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8650),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8652),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8654),
    [sym_trigger_keyword] = ACTIONS(8656),
    [sym_var_keyword] = ACTIONS(8658),
    [sym_local_keyword] = ACTIONS(8660),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(8660),
    [sym_event_keyword] = ACTIONS(8662),
    [sym_fields_keyword] = ACTIONS(8664),
    [sym_keys_keyword] = ACTIONS(8666),
    [sym_fieldgroups_keyword] = ACTIONS(8668),
    [sym_actions_keyword] = ACTIONS(8670),
    [sym_layout_keyword] = ACTIONS(8672),
    [sym_dataset_keyword] = ACTIONS(8674),
    [sym_elements_keyword] = ACTIONS(8676),
    [sym_labels_keyword] = ACTIONS(8678),
    [sym_rendering_keyword] = ACTIONS(8680),
    [sym_requestpage_keyword] = ACTIONS(8682),
    [sym_schema_keyword] = ACTIONS(8684),
    [sym_views_keyword] = ACTIONS(8686),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8688),
    [sym_preproc_open] = ACTIONS(5823),
  },
  [STATE(3334)] = {
    [anon_sym_SEMI] = ACTIONS(8926),
    [aux_sym_where_condition_token1] = ACTIONS(8928),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8926),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8926),
    [anon_sym_LBRACK] = ACTIONS(8926),
    [aux_sym_basic_type_token6] = ACTIONS(8928),
    [aux_sym_basic_type_token22] = ACTIONS(8928),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8926),
    [aux_sym_addafter_modification_token1] = ACTIONS(8926),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8926),
    [aux_sym_modify_modification_token1] = ACTIONS(8926),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8926),
    [aux_sym_movelast_modification_token1] = ACTIONS(8926),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8926),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8926),
    [aux_sym_separator_action_token1] = ACTIONS(8926),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8926),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8926),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8926),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8926),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8926),
    [anon_sym_POUNDif] = ACTIONS(8926),
    [anon_sym_POUNDIF] = ACTIONS(8926),
    [anon_sym_POUNDIf] = ACTIONS(8926),
    [anon_sym_POUNDelif] = ACTIONS(8926),
    [anon_sym_POUNDELIF] = ACTIONS(8926),
    [anon_sym_POUNDElif] = ACTIONS(8926),
    [anon_sym_POUNDelse] = ACTIONS(8926),
    [anon_sym_POUNDELSE] = ACTIONS(8926),
    [anon_sym_POUNDElse] = ACTIONS(8926),
    [anon_sym_POUNDendif] = ACTIONS(8926),
    [anon_sym_POUNDENDIF] = ACTIONS(8926),
    [anon_sym_POUNDEndif] = ACTIONS(8926),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8926),
    [sym_trigger_keyword] = ACTIONS(8926),
    [sym_var_keyword] = ACTIONS(8926),
    [sym_local_keyword] = ACTIONS(8926),
    [sym_internal_keyword] = ACTIONS(8926),
    [sym_protected_keyword] = ACTIONS(8926),
    [sym_event_keyword] = ACTIONS(8926),
    [sym_fields_keyword] = ACTIONS(8926),
    [sym_keys_keyword] = ACTIONS(8926),
    [sym_fieldgroups_keyword] = ACTIONS(8926),
    [sym_actions_keyword] = ACTIONS(8926),
    [sym_layout_keyword] = ACTIONS(8926),
    [sym_area_keyword] = ACTIONS(8926),
    [sym_group_keyword] = ACTIONS(8926),
    [sym_repeater_keyword] = ACTIONS(8926),
    [sym_cuegroup_keyword] = ACTIONS(8926),
    [sym_fixed_keyword] = ACTIONS(8926),
    [sym_grid_keyword] = ACTIONS(8926),
    [sym_part_keyword] = ACTIONS(8926),
    [sym_systempart_keyword] = ACTIONS(8926),
    [sym_usercontrol_keyword] = ACTIONS(8926),
    [sym_dataset_keyword] = ACTIONS(8926),
    [sym_elements_keyword] = ACTIONS(8926),
    [sym_dataitem_keyword] = ACTIONS(8926),
    [sym_column_keyword] = ACTIONS(8926),
    [sym_filter_keyword] = ACTIONS(8926),
    [sym_labels_keyword] = ACTIONS(8926),
    [sym_rendering_keyword] = ACTIONS(8926),
    [sym_requestpage_keyword] = ACTIONS(8926),
    [sym_schema_keyword] = ACTIONS(8926),
    [sym_views_keyword] = ACTIONS(8926),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8926),
    [sym_preproc_open] = ACTIONS(8926),
    [sym_preproc_close] = ACTIONS(8926),
  },
  [STATE(3335)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDelif] = ACTIONS(8930),
    [anon_sym_POUNDELIF] = ACTIONS(8930),
    [anon_sym_POUNDElif] = ACTIONS(8930),
    [anon_sym_POUNDelse] = ACTIONS(8930),
    [anon_sym_POUNDELSE] = ACTIONS(8930),
    [anon_sym_POUNDElse] = ACTIONS(8930),
    [anon_sym_POUNDendif] = ACTIONS(8930),
    [anon_sym_POUNDENDIF] = ACTIONS(8930),
    [anon_sym_POUNDEndif] = ACTIONS(8930),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(8930),
  },
  [STATE(3336)] = {
    [sym__body_element] = STATE(3330),
    [sym_empty_statement] = STATE(3330),
    [sym_property] = STATE(3330),
    [sym_fields_section] = STATE(3330),
    [sym_keys_section] = STATE(3330),
    [sym_fieldgroups_section] = STATE(3330),
    [sym_enum_value_declaration] = STATE(3330),
    [sym_labels_section] = STATE(3330),
    [sym_layout_section] = STATE(3330),
    [sym_modify_modification] = STATE(3330),
    [sym_actions_section] = STATE(3330),
    [sym_views_section] = STATE(3330),
    [sym_dataset_section] = STATE(3330),
    [sym_requestpage_section] = STATE(3330),
    [sym_rendering_section] = STATE(3330),
    [sym_elements_section] = STATE(3330),
    [sym_schema_section] = STATE(3330),
    [sym_xmlport_element] = STATE(3330),
    [sym__xmlport_body_element] = STATE(3330),
    [sym_preproc_conditional_xmlport] = STATE(3330),
    [sym_xmlport_attribute] = STATE(3330),
    [sym_assembly_declaration] = STATE(3330),
    [sym_event_declaration] = STATE(3330),
    [sym_procedure] = STATE(3330),
    [sym_preproc_split_procedure] = STATE(3330),
    [sym_procedure_modifier] = STATE(12392),
    [sym_trigger_declaration] = STATE(3330),
    [sym_var_section] = STATE(3330),
    [sym_attribute_item] = STATE(3330),
    [sym_preproc_conditional] = STATE(3330),
    [sym_preproc_if] = STATE(2456),
    [aux_sym_xmlport_element_repeat1] = STATE(3330),
    [anon_sym_SEMI] = ACTIONS(8638),
    [anon_sym_RBRACE] = ACTIONS(8932),
    [anon_sym_LBRACK] = ACTIONS(8642),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8644),
    [aux_sym_modify_modification_token1] = ACTIONS(8646),
    [aux_sym_xmlport_element_token1] = ACTIONS(8648),
    [aux_sym_xmlport_element_token2] = ACTIONS(8648),
    [aux_sym_xmlport_element_token3] = ACTIONS(8648),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8650),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8650),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8652),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8654),
    [sym_trigger_keyword] = ACTIONS(8656),
    [sym_var_keyword] = ACTIONS(8658),
    [sym_local_keyword] = ACTIONS(8660),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(8660),
    [sym_event_keyword] = ACTIONS(8662),
    [sym_fields_keyword] = ACTIONS(8664),
    [sym_keys_keyword] = ACTIONS(8666),
    [sym_fieldgroups_keyword] = ACTIONS(8668),
    [sym_actions_keyword] = ACTIONS(8670),
    [sym_layout_keyword] = ACTIONS(8672),
    [sym_dataset_keyword] = ACTIONS(8674),
    [sym_elements_keyword] = ACTIONS(8676),
    [sym_labels_keyword] = ACTIONS(8678),
    [sym_rendering_keyword] = ACTIONS(8680),
    [sym_requestpage_keyword] = ACTIONS(8682),
    [sym_schema_keyword] = ACTIONS(8684),
    [sym_views_keyword] = ACTIONS(8686),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8688),
    [sym_preproc_open] = ACTIONS(5823),
  },
  [STATE(3337)] = {
    [sym__body_element] = STATE(3340),
    [sym_empty_statement] = STATE(3340),
    [sym_property] = STATE(3340),
    [sym_fields_section] = STATE(3340),
    [sym_keys_section] = STATE(3340),
    [sym_fieldgroups_section] = STATE(3340),
    [sym_enum_value_declaration] = STATE(3340),
    [sym_labels_section] = STATE(3340),
    [sym_layout_section] = STATE(3340),
    [sym_modify_modification] = STATE(3340),
    [sym_actions_section] = STATE(3340),
    [sym_views_section] = STATE(3340),
    [sym_dataset_section] = STATE(3340),
    [sym_requestpage_section] = STATE(3340),
    [sym_rendering_section] = STATE(3340),
    [sym_elements_section] = STATE(3340),
    [sym_schema_section] = STATE(3340),
    [sym_xmlport_element] = STATE(3340),
    [sym__xmlport_body_element] = STATE(3340),
    [sym_preproc_conditional_xmlport] = STATE(3340),
    [sym_xmlport_attribute] = STATE(3340),
    [sym_assembly_declaration] = STATE(3340),
    [sym_event_declaration] = STATE(3340),
    [sym_procedure] = STATE(3340),
    [sym_preproc_split_procedure] = STATE(3340),
    [sym_procedure_modifier] = STATE(12392),
    [sym_trigger_declaration] = STATE(3340),
    [sym_var_section] = STATE(3340),
    [sym_attribute_item] = STATE(3340),
    [sym_preproc_conditional] = STATE(3340),
    [sym_preproc_if] = STATE(2456),
    [aux_sym_xmlport_element_repeat1] = STATE(3340),
    [anon_sym_SEMI] = ACTIONS(8638),
    [anon_sym_RBRACE] = ACTIONS(8934),
    [anon_sym_LBRACK] = ACTIONS(8642),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8644),
    [aux_sym_modify_modification_token1] = ACTIONS(8646),
    [aux_sym_xmlport_element_token1] = ACTIONS(8648),
    [aux_sym_xmlport_element_token2] = ACTIONS(8648),
    [aux_sym_xmlport_element_token3] = ACTIONS(8648),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8650),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8650),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8652),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8654),
    [sym_trigger_keyword] = ACTIONS(8656),
    [sym_var_keyword] = ACTIONS(8658),
    [sym_local_keyword] = ACTIONS(8660),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(8660),
    [sym_event_keyword] = ACTIONS(8662),
    [sym_fields_keyword] = ACTIONS(8664),
    [sym_keys_keyword] = ACTIONS(8666),
    [sym_fieldgroups_keyword] = ACTIONS(8668),
    [sym_actions_keyword] = ACTIONS(8670),
    [sym_layout_keyword] = ACTIONS(8672),
    [sym_dataset_keyword] = ACTIONS(8674),
    [sym_elements_keyword] = ACTIONS(8676),
    [sym_labels_keyword] = ACTIONS(8678),
    [sym_rendering_keyword] = ACTIONS(8680),
    [sym_requestpage_keyword] = ACTIONS(8682),
    [sym_schema_keyword] = ACTIONS(8684),
    [sym_views_keyword] = ACTIONS(8686),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8688),
    [sym_preproc_open] = ACTIONS(5823),
  },
  [STATE(3338)] = {
    [sym__body_element] = STATE(3330),
    [sym_empty_statement] = STATE(3330),
    [sym_property] = STATE(3330),
    [sym_fields_section] = STATE(3330),
    [sym_keys_section] = STATE(3330),
    [sym_fieldgroups_section] = STATE(3330),
    [sym_enum_value_declaration] = STATE(3330),
    [sym_labels_section] = STATE(3330),
    [sym_layout_section] = STATE(3330),
    [sym_modify_modification] = STATE(3330),
    [sym_actions_section] = STATE(3330),
    [sym_views_section] = STATE(3330),
    [sym_dataset_section] = STATE(3330),
    [sym_requestpage_section] = STATE(3330),
    [sym_rendering_section] = STATE(3330),
    [sym_elements_section] = STATE(3330),
    [sym_schema_section] = STATE(3330),
    [sym_xmlport_element] = STATE(3330),
    [sym__xmlport_body_element] = STATE(3330),
    [sym_preproc_conditional_xmlport] = STATE(3330),
    [sym_xmlport_attribute] = STATE(3330),
    [sym_assembly_declaration] = STATE(3330),
    [sym_event_declaration] = STATE(3330),
    [sym_procedure] = STATE(3330),
    [sym_preproc_split_procedure] = STATE(3330),
    [sym_procedure_modifier] = STATE(12392),
    [sym_trigger_declaration] = STATE(3330),
    [sym_var_section] = STATE(3330),
    [sym_attribute_item] = STATE(3330),
    [sym_preproc_conditional] = STATE(3330),
    [sym_preproc_if] = STATE(2456),
    [aux_sym_xmlport_element_repeat1] = STATE(3330),
    [anon_sym_SEMI] = ACTIONS(8638),
    [anon_sym_RBRACE] = ACTIONS(8936),
    [anon_sym_LBRACK] = ACTIONS(8642),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8644),
    [aux_sym_modify_modification_token1] = ACTIONS(8646),
    [aux_sym_xmlport_element_token1] = ACTIONS(8648),
    [aux_sym_xmlport_element_token2] = ACTIONS(8648),
    [aux_sym_xmlport_element_token3] = ACTIONS(8648),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8650),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8650),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8652),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8654),
    [sym_trigger_keyword] = ACTIONS(8656),
    [sym_var_keyword] = ACTIONS(8658),
    [sym_local_keyword] = ACTIONS(8660),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(8660),
    [sym_event_keyword] = ACTIONS(8662),
    [sym_fields_keyword] = ACTIONS(8664),
    [sym_keys_keyword] = ACTIONS(8666),
    [sym_fieldgroups_keyword] = ACTIONS(8668),
    [sym_actions_keyword] = ACTIONS(8670),
    [sym_layout_keyword] = ACTIONS(8672),
    [sym_dataset_keyword] = ACTIONS(8674),
    [sym_elements_keyword] = ACTIONS(8676),
    [sym_labels_keyword] = ACTIONS(8678),
    [sym_rendering_keyword] = ACTIONS(8680),
    [sym_requestpage_keyword] = ACTIONS(8682),
    [sym_schema_keyword] = ACTIONS(8684),
    [sym_views_keyword] = ACTIONS(8686),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8688),
    [sym_preproc_open] = ACTIONS(5823),
  },
  [STATE(3339)] = {
    [anon_sym_SEMI] = ACTIONS(8938),
    [aux_sym_where_condition_token1] = ACTIONS(4373),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4377),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4377),
    [anon_sym_LBRACK] = ACTIONS(4377),
    [aux_sym_basic_type_token6] = ACTIONS(4373),
    [aux_sym_basic_type_token22] = ACTIONS(4373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4377),
    [aux_sym_addafter_modification_token1] = ACTIONS(4377),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4377),
    [aux_sym_modify_modification_token1] = ACTIONS(4377),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4377),
    [aux_sym_movelast_modification_token1] = ACTIONS(4377),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4377),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4377),
    [aux_sym_separator_action_token1] = ACTIONS(4377),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4377),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4377),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4377),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4377),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4377),
    [anon_sym_POUNDif] = ACTIONS(4377),
    [anon_sym_POUNDIF] = ACTIONS(4377),
    [anon_sym_POUNDIf] = ACTIONS(4377),
    [anon_sym_POUNDelif] = ACTIONS(4377),
    [anon_sym_POUNDELIF] = ACTIONS(4377),
    [anon_sym_POUNDElif] = ACTIONS(4377),
    [anon_sym_POUNDelse] = ACTIONS(4377),
    [anon_sym_POUNDELSE] = ACTIONS(4377),
    [anon_sym_POUNDElse] = ACTIONS(4377),
    [anon_sym_POUNDendif] = ACTIONS(4377),
    [anon_sym_POUNDENDIF] = ACTIONS(4377),
    [anon_sym_POUNDEndif] = ACTIONS(4377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4377),
    [sym_trigger_keyword] = ACTIONS(4377),
    [sym_var_keyword] = ACTIONS(4377),
    [sym_local_keyword] = ACTIONS(4377),
    [sym_internal_keyword] = ACTIONS(4377),
    [sym_protected_keyword] = ACTIONS(4377),
    [sym_event_keyword] = ACTIONS(4377),
    [sym_fields_keyword] = ACTIONS(4377),
    [sym_keys_keyword] = ACTIONS(4377),
    [sym_fieldgroups_keyword] = ACTIONS(4377),
    [sym_actions_keyword] = ACTIONS(4377),
    [sym_layout_keyword] = ACTIONS(4377),
    [sym_area_keyword] = ACTIONS(4377),
    [sym_group_keyword] = ACTIONS(4377),
    [sym_repeater_keyword] = ACTIONS(4377),
    [sym_cuegroup_keyword] = ACTIONS(4377),
    [sym_fixed_keyword] = ACTIONS(4377),
    [sym_grid_keyword] = ACTIONS(4377),
    [sym_part_keyword] = ACTIONS(4377),
    [sym_systempart_keyword] = ACTIONS(4377),
    [sym_usercontrol_keyword] = ACTIONS(4377),
    [sym_dataset_keyword] = ACTIONS(4377),
    [sym_elements_keyword] = ACTIONS(4377),
    [sym_dataitem_keyword] = ACTIONS(4377),
    [sym_column_keyword] = ACTIONS(4377),
    [sym_filter_keyword] = ACTIONS(4377),
    [sym_labels_keyword] = ACTIONS(4377),
    [sym_rendering_keyword] = ACTIONS(4377),
    [sym_requestpage_keyword] = ACTIONS(4377),
    [sym_schema_keyword] = ACTIONS(4377),
    [sym_views_keyword] = ACTIONS(4377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4377),
    [sym_preproc_open] = ACTIONS(4377),
    [sym_preproc_close] = ACTIONS(4377),
  },
  [STATE(3340)] = {
    [sym__body_element] = STATE(3330),
    [sym_empty_statement] = STATE(3330),
    [sym_property] = STATE(3330),
    [sym_fields_section] = STATE(3330),
    [sym_keys_section] = STATE(3330),
    [sym_fieldgroups_section] = STATE(3330),
    [sym_enum_value_declaration] = STATE(3330),
    [sym_labels_section] = STATE(3330),
    [sym_layout_section] = STATE(3330),
    [sym_modify_modification] = STATE(3330),
    [sym_actions_section] = STATE(3330),
    [sym_views_section] = STATE(3330),
    [sym_dataset_section] = STATE(3330),
    [sym_requestpage_section] = STATE(3330),
    [sym_rendering_section] = STATE(3330),
    [sym_elements_section] = STATE(3330),
    [sym_schema_section] = STATE(3330),
    [sym_xmlport_element] = STATE(3330),
    [sym__xmlport_body_element] = STATE(3330),
    [sym_preproc_conditional_xmlport] = STATE(3330),
    [sym_xmlport_attribute] = STATE(3330),
    [sym_assembly_declaration] = STATE(3330),
    [sym_event_declaration] = STATE(3330),
    [sym_procedure] = STATE(3330),
    [sym_preproc_split_procedure] = STATE(3330),
    [sym_procedure_modifier] = STATE(12392),
    [sym_trigger_declaration] = STATE(3330),
    [sym_var_section] = STATE(3330),
    [sym_attribute_item] = STATE(3330),
    [sym_preproc_conditional] = STATE(3330),
    [sym_preproc_if] = STATE(2456),
    [aux_sym_xmlport_element_repeat1] = STATE(3330),
    [anon_sym_SEMI] = ACTIONS(8638),
    [anon_sym_RBRACE] = ACTIONS(8940),
    [anon_sym_LBRACK] = ACTIONS(8642),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8644),
    [aux_sym_modify_modification_token1] = ACTIONS(8646),
    [aux_sym_xmlport_element_token1] = ACTIONS(8648),
    [aux_sym_xmlport_element_token2] = ACTIONS(8648),
    [aux_sym_xmlport_element_token3] = ACTIONS(8648),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8650),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8650),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8652),
    [anon_sym_POUNDif] = ACTIONS(5823),
    [anon_sym_POUNDIF] = ACTIONS(5823),
    [anon_sym_POUNDIf] = ACTIONS(5823),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8654),
    [sym_trigger_keyword] = ACTIONS(8656),
    [sym_var_keyword] = ACTIONS(8658),
    [sym_local_keyword] = ACTIONS(8660),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(8660),
    [sym_event_keyword] = ACTIONS(8662),
    [sym_fields_keyword] = ACTIONS(8664),
    [sym_keys_keyword] = ACTIONS(8666),
    [sym_fieldgroups_keyword] = ACTIONS(8668),
    [sym_actions_keyword] = ACTIONS(8670),
    [sym_layout_keyword] = ACTIONS(8672),
    [sym_dataset_keyword] = ACTIONS(8674),
    [sym_elements_keyword] = ACTIONS(8676),
    [sym_labels_keyword] = ACTIONS(8678),
    [sym_rendering_keyword] = ACTIONS(8680),
    [sym_requestpage_keyword] = ACTIONS(8682),
    [sym_schema_keyword] = ACTIONS(8684),
    [sym_views_keyword] = ACTIONS(8686),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8688),
    [sym_preproc_open] = ACTIONS(5823),
  },
  [STATE(3341)] = {
    [anon_sym_SEMI] = ACTIONS(4377),
    [aux_sym_where_condition_token1] = ACTIONS(4373),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4377),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4377),
    [anon_sym_LBRACK] = ACTIONS(4377),
    [aux_sym_basic_type_token6] = ACTIONS(4373),
    [aux_sym_basic_type_token22] = ACTIONS(4373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4377),
    [aux_sym_addafter_modification_token1] = ACTIONS(4377),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4377),
    [aux_sym_modify_modification_token1] = ACTIONS(4377),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4377),
    [aux_sym_movelast_modification_token1] = ACTIONS(4377),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4377),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4377),
    [aux_sym_separator_action_token1] = ACTIONS(4377),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4377),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4377),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4377),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4377),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4377),
    [anon_sym_POUNDif] = ACTIONS(4377),
    [anon_sym_POUNDIF] = ACTIONS(4377),
    [anon_sym_POUNDIf] = ACTIONS(4377),
    [anon_sym_POUNDelif] = ACTIONS(4377),
    [anon_sym_POUNDELIF] = ACTIONS(4377),
    [anon_sym_POUNDElif] = ACTIONS(4377),
    [anon_sym_POUNDelse] = ACTIONS(4377),
    [anon_sym_POUNDELSE] = ACTIONS(4377),
    [anon_sym_POUNDElse] = ACTIONS(4377),
    [anon_sym_POUNDendif] = ACTIONS(4377),
    [anon_sym_POUNDENDIF] = ACTIONS(4377),
    [anon_sym_POUNDEndif] = ACTIONS(4377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4377),
    [sym_trigger_keyword] = ACTIONS(4377),
    [sym_var_keyword] = ACTIONS(4377),
    [sym_local_keyword] = ACTIONS(4377),
    [sym_internal_keyword] = ACTIONS(4377),
    [sym_protected_keyword] = ACTIONS(4377),
    [sym_event_keyword] = ACTIONS(4377),
    [sym_fields_keyword] = ACTIONS(4377),
    [sym_keys_keyword] = ACTIONS(4377),
    [sym_fieldgroups_keyword] = ACTIONS(4377),
    [sym_actions_keyword] = ACTIONS(4377),
    [sym_layout_keyword] = ACTIONS(4377),
    [sym_area_keyword] = ACTIONS(4377),
    [sym_group_keyword] = ACTIONS(4377),
    [sym_repeater_keyword] = ACTIONS(4377),
    [sym_cuegroup_keyword] = ACTIONS(4377),
    [sym_fixed_keyword] = ACTIONS(4377),
    [sym_grid_keyword] = ACTIONS(4377),
    [sym_part_keyword] = ACTIONS(4377),
    [sym_systempart_keyword] = ACTIONS(4377),
    [sym_usercontrol_keyword] = ACTIONS(4377),
    [sym_dataset_keyword] = ACTIONS(4377),
    [sym_elements_keyword] = ACTIONS(4377),
    [sym_dataitem_keyword] = ACTIONS(4377),
    [sym_column_keyword] = ACTIONS(4377),
    [sym_filter_keyword] = ACTIONS(4377),
    [sym_labels_keyword] = ACTIONS(4377),
    [sym_rendering_keyword] = ACTIONS(4377),
    [sym_requestpage_keyword] = ACTIONS(4377),
    [sym_schema_keyword] = ACTIONS(4377),
    [sym_views_keyword] = ACTIONS(4377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4377),
    [sym_preproc_open] = ACTIONS(4377),
    [sym_preproc_close] = ACTIONS(4377),
  },
  [STATE(3342)] = {
    [anon_sym_SEMI] = ACTIONS(4405),
    [aux_sym_where_condition_token1] = ACTIONS(4403),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4405),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4405),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [aux_sym_basic_type_token6] = ACTIONS(4403),
    [aux_sym_basic_type_token22] = ACTIONS(4403),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4405),
    [aux_sym_addafter_modification_token1] = ACTIONS(4405),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4405),
    [aux_sym_modify_modification_token1] = ACTIONS(4405),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4405),
    [aux_sym_movelast_modification_token1] = ACTIONS(4405),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4405),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4405),
    [aux_sym_separator_action_token1] = ACTIONS(4405),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4405),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4405),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4405),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4405),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4405),
    [anon_sym_POUNDif] = ACTIONS(4405),
    [anon_sym_POUNDIF] = ACTIONS(4405),
    [anon_sym_POUNDIf] = ACTIONS(4405),
    [anon_sym_POUNDelif] = ACTIONS(4405),
    [anon_sym_POUNDELIF] = ACTIONS(4405),
    [anon_sym_POUNDElif] = ACTIONS(4405),
    [anon_sym_POUNDelse] = ACTIONS(4405),
    [anon_sym_POUNDELSE] = ACTIONS(4405),
    [anon_sym_POUNDElse] = ACTIONS(4405),
    [anon_sym_POUNDendif] = ACTIONS(4405),
    [anon_sym_POUNDENDIF] = ACTIONS(4405),
    [anon_sym_POUNDEndif] = ACTIONS(4405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4405),
    [sym_trigger_keyword] = ACTIONS(4405),
    [sym_var_keyword] = ACTIONS(4405),
    [sym_local_keyword] = ACTIONS(4405),
    [sym_internal_keyword] = ACTIONS(4405),
    [sym_protected_keyword] = ACTIONS(4405),
    [sym_event_keyword] = ACTIONS(4405),
    [sym_fields_keyword] = ACTIONS(4405),
    [sym_keys_keyword] = ACTIONS(4405),
    [sym_fieldgroups_keyword] = ACTIONS(4405),
    [sym_actions_keyword] = ACTIONS(4405),
    [sym_layout_keyword] = ACTIONS(4405),
    [sym_area_keyword] = ACTIONS(4405),
    [sym_group_keyword] = ACTIONS(4405),
    [sym_repeater_keyword] = ACTIONS(4405),
    [sym_cuegroup_keyword] = ACTIONS(4405),
    [sym_fixed_keyword] = ACTIONS(4405),
    [sym_grid_keyword] = ACTIONS(4405),
    [sym_part_keyword] = ACTIONS(4405),
    [sym_systempart_keyword] = ACTIONS(4405),
    [sym_usercontrol_keyword] = ACTIONS(4405),
    [sym_dataset_keyword] = ACTIONS(4405),
    [sym_elements_keyword] = ACTIONS(4405),
    [sym_dataitem_keyword] = ACTIONS(4405),
    [sym_column_keyword] = ACTIONS(4405),
    [sym_filter_keyword] = ACTIONS(4405),
    [sym_labels_keyword] = ACTIONS(4405),
    [sym_rendering_keyword] = ACTIONS(4405),
    [sym_requestpage_keyword] = ACTIONS(4405),
    [sym_schema_keyword] = ACTIONS(4405),
    [sym_views_keyword] = ACTIONS(4405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4405),
    [sym_preproc_open] = ACTIONS(4405),
    [sym_preproc_close] = ACTIONS(4405),
  },
  [STATE(3343)] = {
    [anon_sym_SEMI] = ACTIONS(4409),
    [aux_sym_where_condition_token1] = ACTIONS(4407),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4409),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4409),
    [anon_sym_LBRACK] = ACTIONS(4409),
    [aux_sym_basic_type_token6] = ACTIONS(4407),
    [aux_sym_basic_type_token22] = ACTIONS(4407),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4409),
    [aux_sym_addafter_modification_token1] = ACTIONS(4409),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4409),
    [aux_sym_modify_modification_token1] = ACTIONS(4409),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4409),
    [aux_sym_movelast_modification_token1] = ACTIONS(4409),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4409),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4409),
    [aux_sym_separator_action_token1] = ACTIONS(4409),
    [aux_sym_actionref_declaration_token1] = ACTIONS(4409),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(4409),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(4409),
    [aux_sym_customaction_declaration_token1] = ACTIONS(4409),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4409),
    [anon_sym_POUNDif] = ACTIONS(4409),
    [anon_sym_POUNDIF] = ACTIONS(4409),
    [anon_sym_POUNDIf] = ACTIONS(4409),
    [anon_sym_POUNDelif] = ACTIONS(4409),
    [anon_sym_POUNDELIF] = ACTIONS(4409),
    [anon_sym_POUNDElif] = ACTIONS(4409),
    [anon_sym_POUNDelse] = ACTIONS(4409),
    [anon_sym_POUNDELSE] = ACTIONS(4409),
    [anon_sym_POUNDElse] = ACTIONS(4409),
    [anon_sym_POUNDendif] = ACTIONS(4409),
    [anon_sym_POUNDENDIF] = ACTIONS(4409),
    [anon_sym_POUNDEndif] = ACTIONS(4409),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4409),
    [sym_trigger_keyword] = ACTIONS(4409),
    [sym_var_keyword] = ACTIONS(4409),
    [sym_local_keyword] = ACTIONS(4409),
    [sym_internal_keyword] = ACTIONS(4409),
    [sym_protected_keyword] = ACTIONS(4409),
    [sym_event_keyword] = ACTIONS(4409),
    [sym_fields_keyword] = ACTIONS(4409),
    [sym_keys_keyword] = ACTIONS(4409),
    [sym_fieldgroups_keyword] = ACTIONS(4409),
    [sym_actions_keyword] = ACTIONS(4409),
    [sym_layout_keyword] = ACTIONS(4409),
    [sym_area_keyword] = ACTIONS(4409),
    [sym_group_keyword] = ACTIONS(4409),
    [sym_repeater_keyword] = ACTIONS(4409),
    [sym_cuegroup_keyword] = ACTIONS(4409),
    [sym_fixed_keyword] = ACTIONS(4409),
    [sym_grid_keyword] = ACTIONS(4409),
    [sym_part_keyword] = ACTIONS(4409),
    [sym_systempart_keyword] = ACTIONS(4409),
    [sym_usercontrol_keyword] = ACTIONS(4409),
    [sym_dataset_keyword] = ACTIONS(4409),
    [sym_elements_keyword] = ACTIONS(4409),
    [sym_dataitem_keyword] = ACTIONS(4409),
    [sym_column_keyword] = ACTIONS(4409),
    [sym_filter_keyword] = ACTIONS(4409),
    [sym_labels_keyword] = ACTIONS(4409),
    [sym_rendering_keyword] = ACTIONS(4409),
    [sym_requestpage_keyword] = ACTIONS(4409),
    [sym_schema_keyword] = ACTIONS(4409),
    [sym_views_keyword] = ACTIONS(4409),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4409),
    [sym_preproc_open] = ACTIONS(4409),
    [sym_preproc_close] = ACTIONS(4409),
  },
  [STATE(3344)] = {
    [anon_sym_SEMI] = ACTIONS(8942),
    [aux_sym_where_condition_token1] = ACTIONS(8944),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8942),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8942),
    [anon_sym_LBRACK] = ACTIONS(8942),
    [aux_sym_basic_type_token6] = ACTIONS(8944),
    [aux_sym_basic_type_token22] = ACTIONS(8944),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8942),
    [aux_sym_addafter_modification_token1] = ACTIONS(8942),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8942),
    [aux_sym_modify_modification_token1] = ACTIONS(8942),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8942),
    [aux_sym_movelast_modification_token1] = ACTIONS(8942),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8942),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8942),
    [aux_sym_separator_action_token1] = ACTIONS(8942),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8942),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8942),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8942),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8942),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8942),
    [anon_sym_POUNDif] = ACTIONS(8942),
    [anon_sym_POUNDIF] = ACTIONS(8942),
    [anon_sym_POUNDIf] = ACTIONS(8942),
    [anon_sym_POUNDelif] = ACTIONS(8942),
    [anon_sym_POUNDELIF] = ACTIONS(8942),
    [anon_sym_POUNDElif] = ACTIONS(8942),
    [anon_sym_POUNDelse] = ACTIONS(8942),
    [anon_sym_POUNDELSE] = ACTIONS(8942),
    [anon_sym_POUNDElse] = ACTIONS(8942),
    [anon_sym_POUNDendif] = ACTIONS(8942),
    [anon_sym_POUNDENDIF] = ACTIONS(8942),
    [anon_sym_POUNDEndif] = ACTIONS(8942),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8942),
    [sym_trigger_keyword] = ACTIONS(8942),
    [sym_var_keyword] = ACTIONS(8942),
    [sym_local_keyword] = ACTIONS(8942),
    [sym_internal_keyword] = ACTIONS(8942),
    [sym_protected_keyword] = ACTIONS(8942),
    [sym_event_keyword] = ACTIONS(8942),
    [sym_fields_keyword] = ACTIONS(8942),
    [sym_keys_keyword] = ACTIONS(8942),
    [sym_fieldgroups_keyword] = ACTIONS(8942),
    [sym_actions_keyword] = ACTIONS(8942),
    [sym_layout_keyword] = ACTIONS(8942),
    [sym_area_keyword] = ACTIONS(8942),
    [sym_group_keyword] = ACTIONS(8942),
    [sym_repeater_keyword] = ACTIONS(8942),
    [sym_cuegroup_keyword] = ACTIONS(8942),
    [sym_fixed_keyword] = ACTIONS(8942),
    [sym_grid_keyword] = ACTIONS(8942),
    [sym_part_keyword] = ACTIONS(8942),
    [sym_systempart_keyword] = ACTIONS(8942),
    [sym_usercontrol_keyword] = ACTIONS(8942),
    [sym_dataset_keyword] = ACTIONS(8942),
    [sym_elements_keyword] = ACTIONS(8942),
    [sym_dataitem_keyword] = ACTIONS(8942),
    [sym_column_keyword] = ACTIONS(8942),
    [sym_filter_keyword] = ACTIONS(8942),
    [sym_labels_keyword] = ACTIONS(8942),
    [sym_rendering_keyword] = ACTIONS(8942),
    [sym_requestpage_keyword] = ACTIONS(8942),
    [sym_schema_keyword] = ACTIONS(8942),
    [sym_views_keyword] = ACTIONS(8942),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8942),
    [sym_preproc_open] = ACTIONS(8942),
    [sym_preproc_close] = ACTIONS(8942),
  },
  [STATE(3345)] = {
    [sym_else_keyword] = STATE(315),
    [sym_identifier] = ACTIONS(4125),
    [anon_sym_SEMI] = ACTIONS(4127),
    [anon_sym_DASH] = ACTIONS(4127),
    [aux_sym_boolean_token1] = ACTIONS(4125),
    [aux_sym_boolean_token2] = ACTIONS(4125),
    [sym_decimal] = ACTIONS(4125),
    [anon_sym_LPAREN] = ACTIONS(4127),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4125),
    [anon_sym_LBRACK] = ACTIONS(4127),
    [aux_sym_record_type_token1] = ACTIONS(4125),
    [aux_sym_basic_type_token21] = ACTIONS(4125),
    [aux_sym_basic_type_token22] = ACTIONS(4125),
    [aux_sym_basic_type_token48] = ACTIONS(4125),
    [anon_sym_POUNDif] = ACTIONS(4127),
    [anon_sym_POUNDIF] = ACTIONS(4127),
    [anon_sym_POUNDIf] = ACTIONS(4127),
    [anon_sym_not] = ACTIONS(4125),
    [anon_sym_NOT] = ACTIONS(4125),
    [anon_sym_Not] = ACTIONS(4125),
    [anon_sym_POUNDelif] = ACTIONS(4127),
    [anon_sym_POUNDELIF] = ACTIONS(4127),
    [anon_sym_POUNDElif] = ACTIONS(4127),
    [anon_sym_POUNDelse] = ACTIONS(4127),
    [anon_sym_POUNDELSE] = ACTIONS(4127),
    [anon_sym_POUNDElse] = ACTIONS(4127),
    [anon_sym_POUNDendif] = ACTIONS(4127),
    [anon_sym_POUNDENDIF] = ACTIONS(4127),
    [anon_sym_POUNDEndif] = ACTIONS(4127),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4125),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4125),
    [anon_sym_PLUS] = ACTIONS(4127),
    [sym_datetime_literal] = ACTIONS(4127),
    [sym_date_literal] = ACTIONS(4125),
    [sym_time_literal] = ACTIONS(4125),
    [sym_biginteger_literal] = ACTIONS(4127),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(4125),
    [anon_sym_codeunit] = ACTIONS(4125),
    [anon_sym_CODEUNIT] = ACTIONS(4125),
    [anon_sym_Codeunit] = ACTIONS(4125),
    [anon_sym_CodeUnit] = ACTIONS(4125),
    [anon_sym_COdeunit] = ACTIONS(4125),
    [anon_sym_codeUnit] = ACTIONS(4125),
    [sym_report_keyword] = ACTIONS(4125),
    [sym_query_keyword] = ACTIONS(4125),
    [anon_sym_xmlport] = ACTIONS(4125),
    [anon_sym_XMLPORT] = ACTIONS(4125),
    [anon_sym_Xmlport] = ACTIONS(4125),
    [anon_sym_XMLport] = ACTIONS(4125),
    [anon_sym_XMLPort] = ACTIONS(4125),
    [anon_sym_XmlPort] = ACTIONS(4125),
    [anon_sym_enum] = ACTIONS(4125),
    [anon_sym_ENUM] = ACTIONS(4125),
    [anon_sym_Enum] = ACTIONS(4125),
    [anon_sym_eNUM] = ACTIONS(4125),
    [anon_sym_eNum] = ACTIONS(4125),
    [anon_sym_ENum] = ACTIONS(4125),
    [sym_quoted_identifier] = ACTIONS(4127),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4127),
    [sym_integer] = ACTIONS(4125),
    [sym_continue_as_identifier] = ACTIONS(4127),
    [sym_preproc_open] = ACTIONS(4127),
    [sym_preproc_close] = ACTIONS(4127),
  },
  [STATE(3346)] = {
    [sym_else_keyword] = STATE(393),
    [sym_identifier] = ACTIONS(4153),
    [anon_sym_SEMI] = ACTIONS(4155),
    [anon_sym_DASH] = ACTIONS(4155),
    [aux_sym_boolean_token1] = ACTIONS(4153),
    [aux_sym_boolean_token2] = ACTIONS(4153),
    [sym_decimal] = ACTIONS(4153),
    [anon_sym_LPAREN] = ACTIONS(4155),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4153),
    [anon_sym_LBRACK] = ACTIONS(4155),
    [aux_sym_record_type_token1] = ACTIONS(4153),
    [aux_sym_basic_type_token21] = ACTIONS(4153),
    [aux_sym_basic_type_token22] = ACTIONS(4153),
    [aux_sym_basic_type_token48] = ACTIONS(4153),
    [anon_sym_POUNDif] = ACTIONS(4155),
    [anon_sym_POUNDIF] = ACTIONS(4155),
    [anon_sym_POUNDIf] = ACTIONS(4155),
    [anon_sym_not] = ACTIONS(4153),
    [anon_sym_NOT] = ACTIONS(4153),
    [anon_sym_Not] = ACTIONS(4153),
    [anon_sym_POUNDelif] = ACTIONS(4155),
    [anon_sym_POUNDELIF] = ACTIONS(4155),
    [anon_sym_POUNDElif] = ACTIONS(4155),
    [anon_sym_POUNDelse] = ACTIONS(4155),
    [anon_sym_POUNDELSE] = ACTIONS(4155),
    [anon_sym_POUNDElse] = ACTIONS(4155),
    [anon_sym_POUNDendif] = ACTIONS(4155),
    [anon_sym_POUNDENDIF] = ACTIONS(4155),
    [anon_sym_POUNDEndif] = ACTIONS(4155),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4153),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4153),
    [anon_sym_PLUS] = ACTIONS(4155),
    [sym_datetime_literal] = ACTIONS(4155),
    [sym_date_literal] = ACTIONS(4153),
    [sym_time_literal] = ACTIONS(4153),
    [sym_biginteger_literal] = ACTIONS(4155),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(4153),
    [anon_sym_codeunit] = ACTIONS(4153),
    [anon_sym_CODEUNIT] = ACTIONS(4153),
    [anon_sym_Codeunit] = ACTIONS(4153),
    [anon_sym_CodeUnit] = ACTIONS(4153),
    [anon_sym_COdeunit] = ACTIONS(4153),
    [anon_sym_codeUnit] = ACTIONS(4153),
    [sym_report_keyword] = ACTIONS(4153),
    [sym_query_keyword] = ACTIONS(4153),
    [anon_sym_xmlport] = ACTIONS(4153),
    [anon_sym_XMLPORT] = ACTIONS(4153),
    [anon_sym_Xmlport] = ACTIONS(4153),
    [anon_sym_XMLport] = ACTIONS(4153),
    [anon_sym_XMLPort] = ACTIONS(4153),
    [anon_sym_XmlPort] = ACTIONS(4153),
    [anon_sym_enum] = ACTIONS(4153),
    [anon_sym_ENUM] = ACTIONS(4153),
    [anon_sym_Enum] = ACTIONS(4153),
    [anon_sym_eNUM] = ACTIONS(4153),
    [anon_sym_eNum] = ACTIONS(4153),
    [anon_sym_ENum] = ACTIONS(4153),
    [sym_quoted_identifier] = ACTIONS(4155),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4155),
    [sym_integer] = ACTIONS(4153),
    [sym_continue_as_identifier] = ACTIONS(4155),
    [sym_preproc_open] = ACTIONS(4155),
    [sym_preproc_close] = ACTIONS(4155),
  },
  [STATE(3347)] = {
    [sym__body_element] = STATE(3348),
    [sym_empty_statement] = STATE(3348),
    [sym_property] = STATE(3348),
    [sym_fields_section] = STATE(3348),
    [sym_keys_section] = STATE(3348),
    [sym_fieldgroups_section] = STATE(3348),
    [sym_enum_value_declaration] = STATE(3348),
    [sym_labels_section] = STATE(3348),
    [sym_layout_section] = STATE(3348),
    [sym_modify_modification] = STATE(3348),
    [sym_actions_section] = STATE(3348),
    [sym_views_section] = STATE(3348),
    [sym_dataset_section] = STATE(3348),
    [sym_requestpage_section] = STATE(3348),
    [sym_rendering_section] = STATE(3348),
    [sym_elements_section] = STATE(3348),
    [sym_query_dataitem] = STATE(3348),
    [sym__query_body_element] = STATE(3348),
    [sym_preproc_conditional_query] = STATE(3348),
    [sym_query_column] = STATE(3348),
    [sym_query_filter] = STATE(3348),
    [sym_schema_section] = STATE(3348),
    [sym_assembly_declaration] = STATE(3348),
    [sym_event_declaration] = STATE(3348),
    [sym_procedure] = STATE(3348),
    [sym_preproc_split_procedure] = STATE(3348),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3348),
    [sym_var_section] = STATE(3348),
    [sym_attribute_item] = STATE(3348),
    [sym_preproc_conditional] = STATE(3348),
    [sym_preproc_if] = STATE(2475),
    [aux_sym_query_dataitem_repeat1] = STATE(3348),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(8946),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(8948),
    [sym_column_keyword] = ACTIONS(8950),
    [sym_filter_keyword] = ACTIONS(8952),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3348)] = {
    [sym__body_element] = STATE(3352),
    [sym_empty_statement] = STATE(3352),
    [sym_property] = STATE(3352),
    [sym_fields_section] = STATE(3352),
    [sym_keys_section] = STATE(3352),
    [sym_fieldgroups_section] = STATE(3352),
    [sym_enum_value_declaration] = STATE(3352),
    [sym_labels_section] = STATE(3352),
    [sym_layout_section] = STATE(3352),
    [sym_modify_modification] = STATE(3352),
    [sym_actions_section] = STATE(3352),
    [sym_views_section] = STATE(3352),
    [sym_dataset_section] = STATE(3352),
    [sym_requestpage_section] = STATE(3352),
    [sym_rendering_section] = STATE(3352),
    [sym_elements_section] = STATE(3352),
    [sym_query_dataitem] = STATE(3352),
    [sym__query_body_element] = STATE(3352),
    [sym_preproc_conditional_query] = STATE(3352),
    [sym_query_column] = STATE(3352),
    [sym_query_filter] = STATE(3352),
    [sym_schema_section] = STATE(3352),
    [sym_assembly_declaration] = STATE(3352),
    [sym_event_declaration] = STATE(3352),
    [sym_procedure] = STATE(3352),
    [sym_preproc_split_procedure] = STATE(3352),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3352),
    [sym_var_section] = STATE(3352),
    [sym_attribute_item] = STATE(3352),
    [sym_preproc_conditional] = STATE(3352),
    [sym_preproc_if] = STATE(2475),
    [aux_sym_query_dataitem_repeat1] = STATE(3352),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(8954),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(8948),
    [sym_column_keyword] = ACTIONS(8950),
    [sym_filter_keyword] = ACTIONS(8952),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3349)] = {
    [sym_else_keyword] = STATE(315),
    [sym_identifier] = ACTIONS(8956),
    [anon_sym_SEMI] = ACTIONS(4127),
    [anon_sym_DASH] = ACTIONS(8959),
    [aux_sym_boolean_token1] = ACTIONS(8956),
    [aux_sym_boolean_token2] = ACTIONS(8956),
    [sym_decimal] = ACTIONS(8956),
    [anon_sym_LPAREN] = ACTIONS(8959),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8956),
    [anon_sym_LBRACK] = ACTIONS(8959),
    [aux_sym_record_type_token1] = ACTIONS(8956),
    [aux_sym_basic_type_token21] = ACTIONS(8956),
    [aux_sym_basic_type_token22] = ACTIONS(8956),
    [aux_sym_basic_type_token48] = ACTIONS(8956),
    [anon_sym_POUNDif] = ACTIONS(8959),
    [anon_sym_POUNDIF] = ACTIONS(8959),
    [anon_sym_POUNDIf] = ACTIONS(8959),
    [anon_sym_not] = ACTIONS(8956),
    [anon_sym_NOT] = ACTIONS(8956),
    [anon_sym_Not] = ACTIONS(8956),
    [anon_sym_POUNDelif] = ACTIONS(8959),
    [anon_sym_POUNDELIF] = ACTIONS(8959),
    [anon_sym_POUNDElif] = ACTIONS(8959),
    [anon_sym_POUNDelse] = ACTIONS(8959),
    [anon_sym_POUNDELSE] = ACTIONS(8959),
    [anon_sym_POUNDElse] = ACTIONS(8959),
    [anon_sym_POUNDendif] = ACTIONS(8959),
    [anon_sym_POUNDENDIF] = ACTIONS(8959),
    [anon_sym_POUNDEndif] = ACTIONS(8959),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8956),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8956),
    [anon_sym_PLUS] = ACTIONS(8959),
    [sym_datetime_literal] = ACTIONS(8959),
    [sym_date_literal] = ACTIONS(8956),
    [sym_time_literal] = ACTIONS(8956),
    [sym_biginteger_literal] = ACTIONS(8959),
    [anon_sym_else] = ACTIONS(8962),
    [anon_sym_ELSE] = ACTIONS(8962),
    [anon_sym_Else] = ACTIONS(8962),
    [sym_page_keyword] = ACTIONS(8956),
    [anon_sym_codeunit] = ACTIONS(8956),
    [anon_sym_CODEUNIT] = ACTIONS(8956),
    [anon_sym_Codeunit] = ACTIONS(8956),
    [anon_sym_CodeUnit] = ACTIONS(8956),
    [anon_sym_COdeunit] = ACTIONS(8956),
    [anon_sym_codeUnit] = ACTIONS(8956),
    [sym_report_keyword] = ACTIONS(8956),
    [sym_query_keyword] = ACTIONS(8956),
    [anon_sym_xmlport] = ACTIONS(8956),
    [anon_sym_XMLPORT] = ACTIONS(8956),
    [anon_sym_Xmlport] = ACTIONS(8956),
    [anon_sym_XMLport] = ACTIONS(8956),
    [anon_sym_XMLPort] = ACTIONS(8956),
    [anon_sym_XmlPort] = ACTIONS(8956),
    [anon_sym_enum] = ACTIONS(8956),
    [anon_sym_ENUM] = ACTIONS(8956),
    [anon_sym_Enum] = ACTIONS(8956),
    [anon_sym_eNUM] = ACTIONS(8956),
    [anon_sym_eNum] = ACTIONS(8956),
    [anon_sym_ENum] = ACTIONS(8956),
    [sym_quoted_identifier] = ACTIONS(8959),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8959),
    [sym_integer] = ACTIONS(8956),
    [sym_continue_as_identifier] = ACTIONS(8959),
    [sym_preproc_open] = ACTIONS(8959),
    [sym_preproc_close] = ACTIONS(8959),
  },
  [STATE(3350)] = {
    [sym_identifier] = ACTIONS(2422),
    [anon_sym_SEMI] = ACTIONS(2424),
    [anon_sym_DOT] = ACTIONS(2422),
    [anon_sym_EQ] = ACTIONS(2424),
    [anon_sym_COMMA] = ACTIONS(2424),
    [anon_sym_COLON] = ACTIONS(2422),
    [anon_sym_DASH] = ACTIONS(2422),
    [anon_sym_LPAREN] = ACTIONS(2424),
    [anon_sym_RPAREN] = ACTIONS(2424),
    [aux_sym_where_clause_token1] = ACTIONS(2424),
    [aux_sym_where_condition_token1] = ACTIONS(2422),
    [anon_sym_DOT_DOT] = ACTIONS(2424),
    [anon_sym_STAR] = ACTIONS(2422),
    [anon_sym_LBRACK] = ACTIONS(2424),
    [anon_sym_RBRACK] = ACTIONS(2424),
    [aux_sym_basic_type_token22] = ACTIONS(2422),
    [aux_sym_basic_type_token53] = ACTIONS(2422),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2422),
    [aux_sym_separator_action_token1] = ACTIONS(2422),
    [aux_sym_type_declaration_token1] = ACTIONS(2422),
    [anon_sym_COLON_COLON] = ACTIONS(2424),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2424),
    [aux_sym__expression_token1] = ACTIONS(2424),
    [aux_sym__expression_token2] = ACTIONS(2424),
    [anon_sym_SLASH] = ACTIONS(2422),
    [anon_sym_div] = ACTIONS(2422),
    [anon_sym_DIV] = ACTIONS(2422),
    [anon_sym_Div] = ACTIONS(2422),
    [anon_sym_mod] = ACTIONS(2422),
    [anon_sym_MOD] = ACTIONS(2422),
    [anon_sym_Mod] = ACTIONS(2422),
    [anon_sym_PLUS] = ACTIONS(2422),
    [anon_sym_GT_EQ] = ACTIONS(2424),
    [anon_sym_LT_EQ] = ACTIONS(2424),
    [anon_sym_GT] = ACTIONS(2422),
    [anon_sym_LT] = ACTIONS(2422),
    [anon_sym_LT_GT] = ACTIONS(2424),
    [anon_sym_and] = ACTIONS(2422),
    [anon_sym_AND] = ACTIONS(2422),
    [anon_sym_And] = ACTIONS(2422),
    [anon_sym_or] = ACTIONS(2422),
    [anon_sym_OR] = ACTIONS(2422),
    [anon_sym_Or] = ACTIONS(2422),
    [anon_sym_xor] = ACTIONS(2422),
    [anon_sym_XOR] = ACTIONS(2422),
    [anon_sym_Xor] = ACTIONS(2422),
    [anon_sym_QMARK] = ACTIONS(2424),
    [anon_sym_then] = ACTIONS(2422),
    [anon_sym_THEN] = ACTIONS(2422),
    [anon_sym_Then] = ACTIONS(2422),
    [anon_sym_else] = ACTIONS(2422),
    [anon_sym_ELSE] = ACTIONS(2422),
    [anon_sym_Else] = ACTIONS(2422),
    [anon_sym_of] = ACTIONS(2422),
    [anon_sym_OF] = ACTIONS(2422),
    [anon_sym_Of] = ACTIONS(2422),
    [anon_sym_do] = ACTIONS(2422),
    [anon_sym_DO] = ACTIONS(2422),
    [anon_sym_Do] = ACTIONS(2422),
    [anon_sym_in] = ACTIONS(2422),
    [anon_sym_IN] = ACTIONS(2422),
    [anon_sym_In] = ACTIONS(2422),
    [sym_key_keyword] = ACTIONS(2422),
    [sym_dataset_keyword] = ACTIONS(2422),
    [sym_quoted_identifier] = ACTIONS(2424),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_integer] = ACTIONS(2424),
  },
  [STATE(3351)] = {
    [sym_else_keyword] = STATE(314),
    [sym_identifier] = ACTIONS(8966),
    [anon_sym_SEMI] = ACTIONS(4121),
    [anon_sym_DASH] = ACTIONS(8969),
    [aux_sym_boolean_token1] = ACTIONS(8966),
    [aux_sym_boolean_token2] = ACTIONS(8966),
    [sym_decimal] = ACTIONS(8966),
    [anon_sym_LPAREN] = ACTIONS(8969),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8966),
    [anon_sym_LBRACK] = ACTIONS(8969),
    [aux_sym_record_type_token1] = ACTIONS(8966),
    [aux_sym_basic_type_token21] = ACTIONS(8966),
    [aux_sym_basic_type_token22] = ACTIONS(8966),
    [aux_sym_basic_type_token48] = ACTIONS(8966),
    [anon_sym_POUNDif] = ACTIONS(8969),
    [anon_sym_POUNDIF] = ACTIONS(8969),
    [anon_sym_POUNDIf] = ACTIONS(8969),
    [anon_sym_not] = ACTIONS(8966),
    [anon_sym_NOT] = ACTIONS(8966),
    [anon_sym_Not] = ACTIONS(8966),
    [anon_sym_POUNDelif] = ACTIONS(8969),
    [anon_sym_POUNDELIF] = ACTIONS(8969),
    [anon_sym_POUNDElif] = ACTIONS(8969),
    [anon_sym_POUNDelse] = ACTIONS(8969),
    [anon_sym_POUNDELSE] = ACTIONS(8969),
    [anon_sym_POUNDElse] = ACTIONS(8969),
    [anon_sym_POUNDendif] = ACTIONS(8969),
    [anon_sym_POUNDENDIF] = ACTIONS(8969),
    [anon_sym_POUNDEndif] = ACTIONS(8969),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8966),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8966),
    [anon_sym_PLUS] = ACTIONS(8969),
    [sym_datetime_literal] = ACTIONS(8969),
    [sym_date_literal] = ACTIONS(8966),
    [sym_time_literal] = ACTIONS(8966),
    [sym_biginteger_literal] = ACTIONS(8969),
    [anon_sym_else] = ACTIONS(8972),
    [anon_sym_ELSE] = ACTIONS(8972),
    [anon_sym_Else] = ACTIONS(8972),
    [sym_page_keyword] = ACTIONS(8966),
    [anon_sym_codeunit] = ACTIONS(8966),
    [anon_sym_CODEUNIT] = ACTIONS(8966),
    [anon_sym_Codeunit] = ACTIONS(8966),
    [anon_sym_CodeUnit] = ACTIONS(8966),
    [anon_sym_COdeunit] = ACTIONS(8966),
    [anon_sym_codeUnit] = ACTIONS(8966),
    [sym_report_keyword] = ACTIONS(8966),
    [sym_query_keyword] = ACTIONS(8966),
    [anon_sym_xmlport] = ACTIONS(8966),
    [anon_sym_XMLPORT] = ACTIONS(8966),
    [anon_sym_Xmlport] = ACTIONS(8966),
    [anon_sym_XMLport] = ACTIONS(8966),
    [anon_sym_XMLPort] = ACTIONS(8966),
    [anon_sym_XmlPort] = ACTIONS(8966),
    [anon_sym_enum] = ACTIONS(8966),
    [anon_sym_ENUM] = ACTIONS(8966),
    [anon_sym_Enum] = ACTIONS(8966),
    [anon_sym_eNUM] = ACTIONS(8966),
    [anon_sym_eNum] = ACTIONS(8966),
    [anon_sym_ENum] = ACTIONS(8966),
    [sym_quoted_identifier] = ACTIONS(8969),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8969),
    [sym_integer] = ACTIONS(8966),
    [sym_continue_as_identifier] = ACTIONS(8969),
    [sym_preproc_open] = ACTIONS(8969),
    [sym_preproc_close] = ACTIONS(8969),
  },
  [STATE(3352)] = {
    [sym__body_element] = STATE(3352),
    [sym_empty_statement] = STATE(3352),
    [sym_property] = STATE(3352),
    [sym_fields_section] = STATE(3352),
    [sym_keys_section] = STATE(3352),
    [sym_fieldgroups_section] = STATE(3352),
    [sym_enum_value_declaration] = STATE(3352),
    [sym_labels_section] = STATE(3352),
    [sym_layout_section] = STATE(3352),
    [sym_modify_modification] = STATE(3352),
    [sym_actions_section] = STATE(3352),
    [sym_views_section] = STATE(3352),
    [sym_dataset_section] = STATE(3352),
    [sym_requestpage_section] = STATE(3352),
    [sym_rendering_section] = STATE(3352),
    [sym_elements_section] = STATE(3352),
    [sym_query_dataitem] = STATE(3352),
    [sym__query_body_element] = STATE(3352),
    [sym_preproc_conditional_query] = STATE(3352),
    [sym_query_column] = STATE(3352),
    [sym_query_filter] = STATE(3352),
    [sym_schema_section] = STATE(3352),
    [sym_assembly_declaration] = STATE(3352),
    [sym_event_declaration] = STATE(3352),
    [sym_procedure] = STATE(3352),
    [sym_preproc_split_procedure] = STATE(3352),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3352),
    [sym_var_section] = STATE(3352),
    [sym_attribute_item] = STATE(3352),
    [sym_preproc_conditional] = STATE(3352),
    [sym_preproc_if] = STATE(2475),
    [aux_sym_query_dataitem_repeat1] = STATE(3352),
    [anon_sym_SEMI] = ACTIONS(8976),
    [anon_sym_RBRACE] = ACTIONS(6396),
    [anon_sym_LBRACK] = ACTIONS(8979),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8982),
    [aux_sym_modify_modification_token1] = ACTIONS(8985),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8988),
    [anon_sym_POUNDif] = ACTIONS(6393),
    [anon_sym_POUNDIF] = ACTIONS(6393),
    [anon_sym_POUNDIf] = ACTIONS(6393),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8991),
    [sym_trigger_keyword] = ACTIONS(8994),
    [sym_var_keyword] = ACTIONS(8997),
    [sym_local_keyword] = ACTIONS(9000),
    [sym_internal_keyword] = ACTIONS(6410),
    [sym_protected_keyword] = ACTIONS(9000),
    [sym_event_keyword] = ACTIONS(9003),
    [sym_fields_keyword] = ACTIONS(9006),
    [sym_keys_keyword] = ACTIONS(9009),
    [sym_fieldgroups_keyword] = ACTIONS(9012),
    [sym_actions_keyword] = ACTIONS(9015),
    [sym_layout_keyword] = ACTIONS(9018),
    [sym_dataset_keyword] = ACTIONS(9021),
    [sym_elements_keyword] = ACTIONS(9024),
    [sym_dataitem_keyword] = ACTIONS(9027),
    [sym_column_keyword] = ACTIONS(9030),
    [sym_filter_keyword] = ACTIONS(9033),
    [sym_labels_keyword] = ACTIONS(9036),
    [sym_rendering_keyword] = ACTIONS(9039),
    [sym_requestpage_keyword] = ACTIONS(9042),
    [sym_schema_keyword] = ACTIONS(9045),
    [sym_views_keyword] = ACTIONS(9048),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9051),
    [sym_preproc_open] = ACTIONS(6393),
  },
  [STATE(3353)] = {
    [sym_identifier] = ACTIONS(2414),
    [anon_sym_SEMI] = ACTIONS(2416),
    [anon_sym_DOT] = ACTIONS(2414),
    [anon_sym_EQ] = ACTIONS(2416),
    [anon_sym_COMMA] = ACTIONS(2416),
    [anon_sym_COLON] = ACTIONS(2414),
    [anon_sym_DASH] = ACTIONS(2414),
    [anon_sym_LPAREN] = ACTIONS(2416),
    [anon_sym_RPAREN] = ACTIONS(2416),
    [aux_sym_where_clause_token1] = ACTIONS(2416),
    [aux_sym_where_condition_token1] = ACTIONS(2414),
    [anon_sym_DOT_DOT] = ACTIONS(2416),
    [anon_sym_STAR] = ACTIONS(2414),
    [anon_sym_LBRACK] = ACTIONS(2416),
    [anon_sym_RBRACK] = ACTIONS(2416),
    [aux_sym_basic_type_token22] = ACTIONS(2414),
    [aux_sym_basic_type_token53] = ACTIONS(2414),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2414),
    [aux_sym_separator_action_token1] = ACTIONS(2414),
    [aux_sym_type_declaration_token1] = ACTIONS(2414),
    [anon_sym_COLON_COLON] = ACTIONS(2416),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2416),
    [aux_sym__expression_token1] = ACTIONS(2416),
    [aux_sym__expression_token2] = ACTIONS(2416),
    [anon_sym_SLASH] = ACTIONS(2414),
    [anon_sym_div] = ACTIONS(2414),
    [anon_sym_DIV] = ACTIONS(2414),
    [anon_sym_Div] = ACTIONS(2414),
    [anon_sym_mod] = ACTIONS(2414),
    [anon_sym_MOD] = ACTIONS(2414),
    [anon_sym_Mod] = ACTIONS(2414),
    [anon_sym_PLUS] = ACTIONS(2414),
    [anon_sym_GT_EQ] = ACTIONS(2416),
    [anon_sym_LT_EQ] = ACTIONS(2416),
    [anon_sym_GT] = ACTIONS(2414),
    [anon_sym_LT] = ACTIONS(2414),
    [anon_sym_LT_GT] = ACTIONS(2416),
    [anon_sym_and] = ACTIONS(2414),
    [anon_sym_AND] = ACTIONS(2414),
    [anon_sym_And] = ACTIONS(2414),
    [anon_sym_or] = ACTIONS(2414),
    [anon_sym_OR] = ACTIONS(2414),
    [anon_sym_Or] = ACTIONS(2414),
    [anon_sym_xor] = ACTIONS(2414),
    [anon_sym_XOR] = ACTIONS(2414),
    [anon_sym_Xor] = ACTIONS(2414),
    [anon_sym_QMARK] = ACTIONS(2416),
    [anon_sym_then] = ACTIONS(2414),
    [anon_sym_THEN] = ACTIONS(2414),
    [anon_sym_Then] = ACTIONS(2414),
    [anon_sym_else] = ACTIONS(2414),
    [anon_sym_ELSE] = ACTIONS(2414),
    [anon_sym_Else] = ACTIONS(2414),
    [anon_sym_of] = ACTIONS(2414),
    [anon_sym_OF] = ACTIONS(2414),
    [anon_sym_Of] = ACTIONS(2414),
    [anon_sym_do] = ACTIONS(2414),
    [anon_sym_DO] = ACTIONS(2414),
    [anon_sym_Do] = ACTIONS(2414),
    [anon_sym_in] = ACTIONS(2414),
    [anon_sym_IN] = ACTIONS(2414),
    [anon_sym_In] = ACTIONS(2414),
    [sym_key_keyword] = ACTIONS(2414),
    [sym_dataset_keyword] = ACTIONS(2414),
    [sym_quoted_identifier] = ACTIONS(2416),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_integer] = ACTIONS(2416),
  },
  [STATE(3354)] = {
    [sym_else_keyword] = STATE(314),
    [sym_identifier] = ACTIONS(4119),
    [anon_sym_SEMI] = ACTIONS(4121),
    [anon_sym_DASH] = ACTIONS(4121),
    [aux_sym_boolean_token1] = ACTIONS(4119),
    [aux_sym_boolean_token2] = ACTIONS(4119),
    [sym_decimal] = ACTIONS(4119),
    [anon_sym_LPAREN] = ACTIONS(4121),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4119),
    [anon_sym_LBRACK] = ACTIONS(4121),
    [aux_sym_record_type_token1] = ACTIONS(4119),
    [aux_sym_basic_type_token21] = ACTIONS(4119),
    [aux_sym_basic_type_token22] = ACTIONS(4119),
    [aux_sym_basic_type_token48] = ACTIONS(4119),
    [anon_sym_POUNDif] = ACTIONS(4121),
    [anon_sym_POUNDIF] = ACTIONS(4121),
    [anon_sym_POUNDIf] = ACTIONS(4121),
    [anon_sym_not] = ACTIONS(4119),
    [anon_sym_NOT] = ACTIONS(4119),
    [anon_sym_Not] = ACTIONS(4119),
    [anon_sym_POUNDelif] = ACTIONS(4121),
    [anon_sym_POUNDELIF] = ACTIONS(4121),
    [anon_sym_POUNDElif] = ACTIONS(4121),
    [anon_sym_POUNDelse] = ACTIONS(4121),
    [anon_sym_POUNDELSE] = ACTIONS(4121),
    [anon_sym_POUNDElse] = ACTIONS(4121),
    [anon_sym_POUNDendif] = ACTIONS(4121),
    [anon_sym_POUNDENDIF] = ACTIONS(4121),
    [anon_sym_POUNDEndif] = ACTIONS(4121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4119),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4119),
    [anon_sym_PLUS] = ACTIONS(4121),
    [sym_datetime_literal] = ACTIONS(4121),
    [sym_date_literal] = ACTIONS(4119),
    [sym_time_literal] = ACTIONS(4119),
    [sym_biginteger_literal] = ACTIONS(4121),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(4119),
    [anon_sym_codeunit] = ACTIONS(4119),
    [anon_sym_CODEUNIT] = ACTIONS(4119),
    [anon_sym_Codeunit] = ACTIONS(4119),
    [anon_sym_CodeUnit] = ACTIONS(4119),
    [anon_sym_COdeunit] = ACTIONS(4119),
    [anon_sym_codeUnit] = ACTIONS(4119),
    [sym_report_keyword] = ACTIONS(4119),
    [sym_query_keyword] = ACTIONS(4119),
    [anon_sym_xmlport] = ACTIONS(4119),
    [anon_sym_XMLPORT] = ACTIONS(4119),
    [anon_sym_Xmlport] = ACTIONS(4119),
    [anon_sym_XMLport] = ACTIONS(4119),
    [anon_sym_XMLPort] = ACTIONS(4119),
    [anon_sym_XmlPort] = ACTIONS(4119),
    [anon_sym_enum] = ACTIONS(4119),
    [anon_sym_ENUM] = ACTIONS(4119),
    [anon_sym_Enum] = ACTIONS(4119),
    [anon_sym_eNUM] = ACTIONS(4119),
    [anon_sym_eNum] = ACTIONS(4119),
    [anon_sym_ENum] = ACTIONS(4119),
    [sym_quoted_identifier] = ACTIONS(4121),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4121),
    [sym_integer] = ACTIONS(4119),
    [sym_continue_as_identifier] = ACTIONS(4121),
    [sym_preproc_open] = ACTIONS(4121),
    [sym_preproc_close] = ACTIONS(4121),
  },
  [STATE(3355)] = {
    [sym_else_keyword] = STATE(387),
    [sym_identifier] = ACTIONS(4145),
    [anon_sym_SEMI] = ACTIONS(4147),
    [anon_sym_DASH] = ACTIONS(4147),
    [aux_sym_boolean_token1] = ACTIONS(4145),
    [aux_sym_boolean_token2] = ACTIONS(4145),
    [sym_decimal] = ACTIONS(4145),
    [anon_sym_LPAREN] = ACTIONS(4147),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4145),
    [anon_sym_LBRACK] = ACTIONS(4147),
    [aux_sym_record_type_token1] = ACTIONS(4145),
    [aux_sym_basic_type_token21] = ACTIONS(4145),
    [aux_sym_basic_type_token22] = ACTIONS(4145),
    [aux_sym_basic_type_token48] = ACTIONS(4145),
    [anon_sym_POUNDif] = ACTIONS(4147),
    [anon_sym_POUNDIF] = ACTIONS(4147),
    [anon_sym_POUNDIf] = ACTIONS(4147),
    [anon_sym_not] = ACTIONS(4145),
    [anon_sym_NOT] = ACTIONS(4145),
    [anon_sym_Not] = ACTIONS(4145),
    [anon_sym_POUNDelif] = ACTIONS(4147),
    [anon_sym_POUNDELIF] = ACTIONS(4147),
    [anon_sym_POUNDElif] = ACTIONS(4147),
    [anon_sym_POUNDelse] = ACTIONS(4147),
    [anon_sym_POUNDELSE] = ACTIONS(4147),
    [anon_sym_POUNDElse] = ACTIONS(4147),
    [anon_sym_POUNDendif] = ACTIONS(4147),
    [anon_sym_POUNDENDIF] = ACTIONS(4147),
    [anon_sym_POUNDEndif] = ACTIONS(4147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4145),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4145),
    [anon_sym_PLUS] = ACTIONS(4147),
    [sym_datetime_literal] = ACTIONS(4147),
    [sym_date_literal] = ACTIONS(4145),
    [sym_time_literal] = ACTIONS(4145),
    [sym_biginteger_literal] = ACTIONS(4147),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(4145),
    [anon_sym_codeunit] = ACTIONS(4145),
    [anon_sym_CODEUNIT] = ACTIONS(4145),
    [anon_sym_Codeunit] = ACTIONS(4145),
    [anon_sym_CodeUnit] = ACTIONS(4145),
    [anon_sym_COdeunit] = ACTIONS(4145),
    [anon_sym_codeUnit] = ACTIONS(4145),
    [sym_report_keyword] = ACTIONS(4145),
    [sym_query_keyword] = ACTIONS(4145),
    [anon_sym_xmlport] = ACTIONS(4145),
    [anon_sym_XMLPORT] = ACTIONS(4145),
    [anon_sym_Xmlport] = ACTIONS(4145),
    [anon_sym_XMLport] = ACTIONS(4145),
    [anon_sym_XMLPort] = ACTIONS(4145),
    [anon_sym_XmlPort] = ACTIONS(4145),
    [anon_sym_enum] = ACTIONS(4145),
    [anon_sym_ENUM] = ACTIONS(4145),
    [anon_sym_Enum] = ACTIONS(4145),
    [anon_sym_eNUM] = ACTIONS(4145),
    [anon_sym_eNum] = ACTIONS(4145),
    [anon_sym_ENum] = ACTIONS(4145),
    [sym_quoted_identifier] = ACTIONS(4147),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4147),
    [sym_integer] = ACTIONS(4145),
    [sym_continue_as_identifier] = ACTIONS(4147),
    [sym_preproc_open] = ACTIONS(4147),
    [sym_preproc_close] = ACTIONS(4147),
  },
  [STATE(3356)] = {
    [sym_else_keyword] = STATE(388),
    [sym_identifier] = ACTIONS(4149),
    [anon_sym_SEMI] = ACTIONS(4151),
    [anon_sym_DASH] = ACTIONS(4151),
    [aux_sym_boolean_token1] = ACTIONS(4149),
    [aux_sym_boolean_token2] = ACTIONS(4149),
    [sym_decimal] = ACTIONS(4149),
    [anon_sym_LPAREN] = ACTIONS(4151),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4149),
    [anon_sym_LBRACK] = ACTIONS(4151),
    [aux_sym_record_type_token1] = ACTIONS(4149),
    [aux_sym_basic_type_token21] = ACTIONS(4149),
    [aux_sym_basic_type_token22] = ACTIONS(4149),
    [aux_sym_basic_type_token48] = ACTIONS(4149),
    [anon_sym_POUNDif] = ACTIONS(4151),
    [anon_sym_POUNDIF] = ACTIONS(4151),
    [anon_sym_POUNDIf] = ACTIONS(4151),
    [anon_sym_not] = ACTIONS(4149),
    [anon_sym_NOT] = ACTIONS(4149),
    [anon_sym_Not] = ACTIONS(4149),
    [anon_sym_POUNDelif] = ACTIONS(4151),
    [anon_sym_POUNDELIF] = ACTIONS(4151),
    [anon_sym_POUNDElif] = ACTIONS(4151),
    [anon_sym_POUNDelse] = ACTIONS(4151),
    [anon_sym_POUNDELSE] = ACTIONS(4151),
    [anon_sym_POUNDElse] = ACTIONS(4151),
    [anon_sym_POUNDendif] = ACTIONS(4151),
    [anon_sym_POUNDENDIF] = ACTIONS(4151),
    [anon_sym_POUNDEndif] = ACTIONS(4151),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4149),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4149),
    [anon_sym_PLUS] = ACTIONS(4151),
    [sym_datetime_literal] = ACTIONS(4151),
    [sym_date_literal] = ACTIONS(4149),
    [sym_time_literal] = ACTIONS(4149),
    [sym_biginteger_literal] = ACTIONS(4151),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(4149),
    [anon_sym_codeunit] = ACTIONS(4149),
    [anon_sym_CODEUNIT] = ACTIONS(4149),
    [anon_sym_Codeunit] = ACTIONS(4149),
    [anon_sym_CodeUnit] = ACTIONS(4149),
    [anon_sym_COdeunit] = ACTIONS(4149),
    [anon_sym_codeUnit] = ACTIONS(4149),
    [sym_report_keyword] = ACTIONS(4149),
    [sym_query_keyword] = ACTIONS(4149),
    [anon_sym_xmlport] = ACTIONS(4149),
    [anon_sym_XMLPORT] = ACTIONS(4149),
    [anon_sym_Xmlport] = ACTIONS(4149),
    [anon_sym_XMLport] = ACTIONS(4149),
    [anon_sym_XMLPort] = ACTIONS(4149),
    [anon_sym_XmlPort] = ACTIONS(4149),
    [anon_sym_enum] = ACTIONS(4149),
    [anon_sym_ENUM] = ACTIONS(4149),
    [anon_sym_Enum] = ACTIONS(4149),
    [anon_sym_eNUM] = ACTIONS(4149),
    [anon_sym_eNum] = ACTIONS(4149),
    [anon_sym_ENum] = ACTIONS(4149),
    [sym_quoted_identifier] = ACTIONS(4151),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4151),
    [sym_integer] = ACTIONS(4149),
    [sym_continue_as_identifier] = ACTIONS(4151),
    [sym_preproc_open] = ACTIONS(4151),
    [sym_preproc_close] = ACTIONS(4151),
  },
  [STATE(3357)] = {
    [sym_else_keyword] = STATE(394),
    [sym_identifier] = ACTIONS(4157),
    [anon_sym_SEMI] = ACTIONS(4159),
    [anon_sym_DASH] = ACTIONS(4159),
    [aux_sym_boolean_token1] = ACTIONS(4157),
    [aux_sym_boolean_token2] = ACTIONS(4157),
    [sym_decimal] = ACTIONS(4157),
    [anon_sym_LPAREN] = ACTIONS(4159),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4157),
    [anon_sym_LBRACK] = ACTIONS(4159),
    [aux_sym_record_type_token1] = ACTIONS(4157),
    [aux_sym_basic_type_token21] = ACTIONS(4157),
    [aux_sym_basic_type_token22] = ACTIONS(4157),
    [aux_sym_basic_type_token48] = ACTIONS(4157),
    [anon_sym_POUNDif] = ACTIONS(4159),
    [anon_sym_POUNDIF] = ACTIONS(4159),
    [anon_sym_POUNDIf] = ACTIONS(4159),
    [anon_sym_not] = ACTIONS(4157),
    [anon_sym_NOT] = ACTIONS(4157),
    [anon_sym_Not] = ACTIONS(4157),
    [anon_sym_POUNDelif] = ACTIONS(4159),
    [anon_sym_POUNDELIF] = ACTIONS(4159),
    [anon_sym_POUNDElif] = ACTIONS(4159),
    [anon_sym_POUNDelse] = ACTIONS(4159),
    [anon_sym_POUNDELSE] = ACTIONS(4159),
    [anon_sym_POUNDElse] = ACTIONS(4159),
    [anon_sym_POUNDendif] = ACTIONS(4159),
    [anon_sym_POUNDENDIF] = ACTIONS(4159),
    [anon_sym_POUNDEndif] = ACTIONS(4159),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4157),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4157),
    [anon_sym_PLUS] = ACTIONS(4159),
    [sym_datetime_literal] = ACTIONS(4159),
    [sym_date_literal] = ACTIONS(4157),
    [sym_time_literal] = ACTIONS(4157),
    [sym_biginteger_literal] = ACTIONS(4159),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(4157),
    [anon_sym_codeunit] = ACTIONS(4157),
    [anon_sym_CODEUNIT] = ACTIONS(4157),
    [anon_sym_Codeunit] = ACTIONS(4157),
    [anon_sym_CodeUnit] = ACTIONS(4157),
    [anon_sym_COdeunit] = ACTIONS(4157),
    [anon_sym_codeUnit] = ACTIONS(4157),
    [sym_report_keyword] = ACTIONS(4157),
    [sym_query_keyword] = ACTIONS(4157),
    [anon_sym_xmlport] = ACTIONS(4157),
    [anon_sym_XMLPORT] = ACTIONS(4157),
    [anon_sym_Xmlport] = ACTIONS(4157),
    [anon_sym_XMLport] = ACTIONS(4157),
    [anon_sym_XMLPort] = ACTIONS(4157),
    [anon_sym_XmlPort] = ACTIONS(4157),
    [anon_sym_enum] = ACTIONS(4157),
    [anon_sym_ENUM] = ACTIONS(4157),
    [anon_sym_Enum] = ACTIONS(4157),
    [anon_sym_eNUM] = ACTIONS(4157),
    [anon_sym_eNum] = ACTIONS(4157),
    [anon_sym_ENum] = ACTIONS(4157),
    [sym_quoted_identifier] = ACTIONS(4159),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4159),
    [sym_integer] = ACTIONS(4157),
    [sym_continue_as_identifier] = ACTIONS(4159),
    [sym_preproc_open] = ACTIONS(4159),
    [sym_preproc_close] = ACTIONS(4159),
  },
  [STATE(3358)] = {
    [sym_else_keyword] = STATE(395),
    [sym_identifier] = ACTIONS(4161),
    [anon_sym_SEMI] = ACTIONS(4163),
    [anon_sym_DASH] = ACTIONS(4163),
    [aux_sym_boolean_token1] = ACTIONS(4161),
    [aux_sym_boolean_token2] = ACTIONS(4161),
    [sym_decimal] = ACTIONS(4161),
    [anon_sym_LPAREN] = ACTIONS(4163),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4161),
    [anon_sym_LBRACK] = ACTIONS(4163),
    [aux_sym_record_type_token1] = ACTIONS(4161),
    [aux_sym_basic_type_token21] = ACTIONS(4161),
    [aux_sym_basic_type_token22] = ACTIONS(4161),
    [aux_sym_basic_type_token48] = ACTIONS(4161),
    [anon_sym_POUNDif] = ACTIONS(4163),
    [anon_sym_POUNDIF] = ACTIONS(4163),
    [anon_sym_POUNDIf] = ACTIONS(4163),
    [anon_sym_not] = ACTIONS(4161),
    [anon_sym_NOT] = ACTIONS(4161),
    [anon_sym_Not] = ACTIONS(4161),
    [anon_sym_POUNDelif] = ACTIONS(4163),
    [anon_sym_POUNDELIF] = ACTIONS(4163),
    [anon_sym_POUNDElif] = ACTIONS(4163),
    [anon_sym_POUNDelse] = ACTIONS(4163),
    [anon_sym_POUNDELSE] = ACTIONS(4163),
    [anon_sym_POUNDElse] = ACTIONS(4163),
    [anon_sym_POUNDendif] = ACTIONS(4163),
    [anon_sym_POUNDENDIF] = ACTIONS(4163),
    [anon_sym_POUNDEndif] = ACTIONS(4163),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4161),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4161),
    [anon_sym_PLUS] = ACTIONS(4163),
    [sym_datetime_literal] = ACTIONS(4163),
    [sym_date_literal] = ACTIONS(4161),
    [sym_time_literal] = ACTIONS(4161),
    [sym_biginteger_literal] = ACTIONS(4163),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(4161),
    [anon_sym_codeunit] = ACTIONS(4161),
    [anon_sym_CODEUNIT] = ACTIONS(4161),
    [anon_sym_Codeunit] = ACTIONS(4161),
    [anon_sym_CodeUnit] = ACTIONS(4161),
    [anon_sym_COdeunit] = ACTIONS(4161),
    [anon_sym_codeUnit] = ACTIONS(4161),
    [sym_report_keyword] = ACTIONS(4161),
    [sym_query_keyword] = ACTIONS(4161),
    [anon_sym_xmlport] = ACTIONS(4161),
    [anon_sym_XMLPORT] = ACTIONS(4161),
    [anon_sym_Xmlport] = ACTIONS(4161),
    [anon_sym_XMLport] = ACTIONS(4161),
    [anon_sym_XMLPort] = ACTIONS(4161),
    [anon_sym_XmlPort] = ACTIONS(4161),
    [anon_sym_enum] = ACTIONS(4161),
    [anon_sym_ENUM] = ACTIONS(4161),
    [anon_sym_Enum] = ACTIONS(4161),
    [anon_sym_eNUM] = ACTIONS(4161),
    [anon_sym_eNum] = ACTIONS(4161),
    [anon_sym_ENum] = ACTIONS(4161),
    [sym_quoted_identifier] = ACTIONS(4163),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4163),
    [sym_integer] = ACTIONS(4161),
    [sym_continue_as_identifier] = ACTIONS(4163),
    [sym_preproc_open] = ACTIONS(4163),
    [sym_preproc_close] = ACTIONS(4163),
  },
  [STATE(3359)] = {
    [sym_else_keyword] = STATE(396),
    [sym_identifier] = ACTIONS(4165),
    [anon_sym_SEMI] = ACTIONS(4167),
    [anon_sym_DASH] = ACTIONS(4167),
    [aux_sym_boolean_token1] = ACTIONS(4165),
    [aux_sym_boolean_token2] = ACTIONS(4165),
    [sym_decimal] = ACTIONS(4165),
    [anon_sym_LPAREN] = ACTIONS(4167),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4165),
    [anon_sym_LBRACK] = ACTIONS(4167),
    [aux_sym_record_type_token1] = ACTIONS(4165),
    [aux_sym_basic_type_token21] = ACTIONS(4165),
    [aux_sym_basic_type_token22] = ACTIONS(4165),
    [aux_sym_basic_type_token48] = ACTIONS(4165),
    [anon_sym_POUNDif] = ACTIONS(4167),
    [anon_sym_POUNDIF] = ACTIONS(4167),
    [anon_sym_POUNDIf] = ACTIONS(4167),
    [anon_sym_not] = ACTIONS(4165),
    [anon_sym_NOT] = ACTIONS(4165),
    [anon_sym_Not] = ACTIONS(4165),
    [anon_sym_POUNDelif] = ACTIONS(4167),
    [anon_sym_POUNDELIF] = ACTIONS(4167),
    [anon_sym_POUNDElif] = ACTIONS(4167),
    [anon_sym_POUNDelse] = ACTIONS(4167),
    [anon_sym_POUNDELSE] = ACTIONS(4167),
    [anon_sym_POUNDElse] = ACTIONS(4167),
    [anon_sym_POUNDendif] = ACTIONS(4167),
    [anon_sym_POUNDENDIF] = ACTIONS(4167),
    [anon_sym_POUNDEndif] = ACTIONS(4167),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4165),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4165),
    [anon_sym_PLUS] = ACTIONS(4167),
    [sym_datetime_literal] = ACTIONS(4167),
    [sym_date_literal] = ACTIONS(4165),
    [sym_time_literal] = ACTIONS(4165),
    [sym_biginteger_literal] = ACTIONS(4167),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(4165),
    [anon_sym_codeunit] = ACTIONS(4165),
    [anon_sym_CODEUNIT] = ACTIONS(4165),
    [anon_sym_Codeunit] = ACTIONS(4165),
    [anon_sym_CodeUnit] = ACTIONS(4165),
    [anon_sym_COdeunit] = ACTIONS(4165),
    [anon_sym_codeUnit] = ACTIONS(4165),
    [sym_report_keyword] = ACTIONS(4165),
    [sym_query_keyword] = ACTIONS(4165),
    [anon_sym_xmlport] = ACTIONS(4165),
    [anon_sym_XMLPORT] = ACTIONS(4165),
    [anon_sym_Xmlport] = ACTIONS(4165),
    [anon_sym_XMLport] = ACTIONS(4165),
    [anon_sym_XMLPort] = ACTIONS(4165),
    [anon_sym_XmlPort] = ACTIONS(4165),
    [anon_sym_enum] = ACTIONS(4165),
    [anon_sym_ENUM] = ACTIONS(4165),
    [anon_sym_Enum] = ACTIONS(4165),
    [anon_sym_eNUM] = ACTIONS(4165),
    [anon_sym_eNum] = ACTIONS(4165),
    [anon_sym_ENum] = ACTIONS(4165),
    [sym_quoted_identifier] = ACTIONS(4167),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4167),
    [sym_integer] = ACTIONS(4165),
    [sym_continue_as_identifier] = ACTIONS(4167),
    [sym_preproc_open] = ACTIONS(4167),
    [sym_preproc_close] = ACTIONS(4167),
  },
  [STATE(3360)] = {
    [sym_else_keyword] = STATE(401),
    [sym_identifier] = ACTIONS(4169),
    [anon_sym_SEMI] = ACTIONS(4171),
    [anon_sym_DASH] = ACTIONS(4171),
    [aux_sym_boolean_token1] = ACTIONS(4169),
    [aux_sym_boolean_token2] = ACTIONS(4169),
    [sym_decimal] = ACTIONS(4169),
    [anon_sym_LPAREN] = ACTIONS(4171),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4169),
    [anon_sym_LBRACK] = ACTIONS(4171),
    [aux_sym_record_type_token1] = ACTIONS(4169),
    [aux_sym_basic_type_token21] = ACTIONS(4169),
    [aux_sym_basic_type_token22] = ACTIONS(4169),
    [aux_sym_basic_type_token48] = ACTIONS(4169),
    [anon_sym_POUNDif] = ACTIONS(4171),
    [anon_sym_POUNDIF] = ACTIONS(4171),
    [anon_sym_POUNDIf] = ACTIONS(4171),
    [anon_sym_not] = ACTIONS(4169),
    [anon_sym_NOT] = ACTIONS(4169),
    [anon_sym_Not] = ACTIONS(4169),
    [anon_sym_POUNDelif] = ACTIONS(4171),
    [anon_sym_POUNDELIF] = ACTIONS(4171),
    [anon_sym_POUNDElif] = ACTIONS(4171),
    [anon_sym_POUNDelse] = ACTIONS(4171),
    [anon_sym_POUNDELSE] = ACTIONS(4171),
    [anon_sym_POUNDElse] = ACTIONS(4171),
    [anon_sym_POUNDendif] = ACTIONS(4171),
    [anon_sym_POUNDENDIF] = ACTIONS(4171),
    [anon_sym_POUNDEndif] = ACTIONS(4171),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4169),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4169),
    [anon_sym_PLUS] = ACTIONS(4171),
    [sym_datetime_literal] = ACTIONS(4171),
    [sym_date_literal] = ACTIONS(4169),
    [sym_time_literal] = ACTIONS(4169),
    [sym_biginteger_literal] = ACTIONS(4171),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(4169),
    [anon_sym_codeunit] = ACTIONS(4169),
    [anon_sym_CODEUNIT] = ACTIONS(4169),
    [anon_sym_Codeunit] = ACTIONS(4169),
    [anon_sym_CodeUnit] = ACTIONS(4169),
    [anon_sym_COdeunit] = ACTIONS(4169),
    [anon_sym_codeUnit] = ACTIONS(4169),
    [sym_report_keyword] = ACTIONS(4169),
    [sym_query_keyword] = ACTIONS(4169),
    [anon_sym_xmlport] = ACTIONS(4169),
    [anon_sym_XMLPORT] = ACTIONS(4169),
    [anon_sym_Xmlport] = ACTIONS(4169),
    [anon_sym_XMLport] = ACTIONS(4169),
    [anon_sym_XMLPort] = ACTIONS(4169),
    [anon_sym_XmlPort] = ACTIONS(4169),
    [anon_sym_enum] = ACTIONS(4169),
    [anon_sym_ENUM] = ACTIONS(4169),
    [anon_sym_Enum] = ACTIONS(4169),
    [anon_sym_eNUM] = ACTIONS(4169),
    [anon_sym_eNum] = ACTIONS(4169),
    [anon_sym_ENum] = ACTIONS(4169),
    [sym_quoted_identifier] = ACTIONS(4171),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4171),
    [sym_integer] = ACTIONS(4169),
    [sym_continue_as_identifier] = ACTIONS(4171),
    [sym_preproc_open] = ACTIONS(4171),
    [sym_preproc_close] = ACTIONS(4171),
  },
  [STATE(3361)] = {
    [sym_else_keyword] = STATE(402),
    [sym_identifier] = ACTIONS(4131),
    [anon_sym_SEMI] = ACTIONS(4133),
    [anon_sym_DASH] = ACTIONS(4133),
    [aux_sym_boolean_token1] = ACTIONS(4131),
    [aux_sym_boolean_token2] = ACTIONS(4131),
    [sym_decimal] = ACTIONS(4131),
    [anon_sym_LPAREN] = ACTIONS(4133),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4131),
    [anon_sym_LBRACK] = ACTIONS(4133),
    [aux_sym_record_type_token1] = ACTIONS(4131),
    [aux_sym_basic_type_token21] = ACTIONS(4131),
    [aux_sym_basic_type_token22] = ACTIONS(4131),
    [aux_sym_basic_type_token48] = ACTIONS(4131),
    [anon_sym_POUNDif] = ACTIONS(4133),
    [anon_sym_POUNDIF] = ACTIONS(4133),
    [anon_sym_POUNDIf] = ACTIONS(4133),
    [anon_sym_not] = ACTIONS(4131),
    [anon_sym_NOT] = ACTIONS(4131),
    [anon_sym_Not] = ACTIONS(4131),
    [anon_sym_POUNDelif] = ACTIONS(4133),
    [anon_sym_POUNDELIF] = ACTIONS(4133),
    [anon_sym_POUNDElif] = ACTIONS(4133),
    [anon_sym_POUNDelse] = ACTIONS(4133),
    [anon_sym_POUNDELSE] = ACTIONS(4133),
    [anon_sym_POUNDElse] = ACTIONS(4133),
    [anon_sym_POUNDendif] = ACTIONS(4133),
    [anon_sym_POUNDENDIF] = ACTIONS(4133),
    [anon_sym_POUNDEndif] = ACTIONS(4133),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4131),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4131),
    [anon_sym_PLUS] = ACTIONS(4133),
    [sym_datetime_literal] = ACTIONS(4133),
    [sym_date_literal] = ACTIONS(4131),
    [sym_time_literal] = ACTIONS(4131),
    [sym_biginteger_literal] = ACTIONS(4133),
    [anon_sym_else] = ACTIONS(4129),
    [anon_sym_ELSE] = ACTIONS(4129),
    [anon_sym_Else] = ACTIONS(4129),
    [sym_page_keyword] = ACTIONS(4131),
    [anon_sym_codeunit] = ACTIONS(4131),
    [anon_sym_CODEUNIT] = ACTIONS(4131),
    [anon_sym_Codeunit] = ACTIONS(4131),
    [anon_sym_CodeUnit] = ACTIONS(4131),
    [anon_sym_COdeunit] = ACTIONS(4131),
    [anon_sym_codeUnit] = ACTIONS(4131),
    [sym_report_keyword] = ACTIONS(4131),
    [sym_query_keyword] = ACTIONS(4131),
    [anon_sym_xmlport] = ACTIONS(4131),
    [anon_sym_XMLPORT] = ACTIONS(4131),
    [anon_sym_Xmlport] = ACTIONS(4131),
    [anon_sym_XMLport] = ACTIONS(4131),
    [anon_sym_XMLPort] = ACTIONS(4131),
    [anon_sym_XmlPort] = ACTIONS(4131),
    [anon_sym_enum] = ACTIONS(4131),
    [anon_sym_ENUM] = ACTIONS(4131),
    [anon_sym_Enum] = ACTIONS(4131),
    [anon_sym_eNUM] = ACTIONS(4131),
    [anon_sym_eNum] = ACTIONS(4131),
    [anon_sym_ENum] = ACTIONS(4131),
    [sym_quoted_identifier] = ACTIONS(4133),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4133),
    [sym_integer] = ACTIONS(4131),
    [sym_continue_as_identifier] = ACTIONS(4133),
    [sym_preproc_open] = ACTIONS(4133),
    [sym_preproc_close] = ACTIONS(4133),
  },
  [STATE(3362)] = {
    [sym_identifier] = ACTIONS(2418),
    [anon_sym_SEMI] = ACTIONS(2420),
    [anon_sym_DOT] = ACTIONS(2418),
    [anon_sym_EQ] = ACTIONS(2420),
    [anon_sym_COMMA] = ACTIONS(2420),
    [anon_sym_COLON] = ACTIONS(2418),
    [anon_sym_DASH] = ACTIONS(2418),
    [anon_sym_LPAREN] = ACTIONS(2420),
    [anon_sym_RPAREN] = ACTIONS(2420),
    [aux_sym_where_clause_token1] = ACTIONS(2420),
    [aux_sym_where_condition_token1] = ACTIONS(2418),
    [anon_sym_DOT_DOT] = ACTIONS(2420),
    [anon_sym_STAR] = ACTIONS(2418),
    [anon_sym_LBRACK] = ACTIONS(2420),
    [anon_sym_RBRACK] = ACTIONS(2420),
    [aux_sym_basic_type_token22] = ACTIONS(2418),
    [aux_sym_basic_type_token53] = ACTIONS(2418),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2418),
    [aux_sym_separator_action_token1] = ACTIONS(2418),
    [aux_sym_type_declaration_token1] = ACTIONS(2418),
    [anon_sym_COLON_COLON] = ACTIONS(2420),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2420),
    [aux_sym__expression_token1] = ACTIONS(2420),
    [aux_sym__expression_token2] = ACTIONS(2420),
    [anon_sym_SLASH] = ACTIONS(2418),
    [anon_sym_div] = ACTIONS(2418),
    [anon_sym_DIV] = ACTIONS(2418),
    [anon_sym_Div] = ACTIONS(2418),
    [anon_sym_mod] = ACTIONS(2418),
    [anon_sym_MOD] = ACTIONS(2418),
    [anon_sym_Mod] = ACTIONS(2418),
    [anon_sym_PLUS] = ACTIONS(2418),
    [anon_sym_GT_EQ] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(2420),
    [anon_sym_GT] = ACTIONS(2418),
    [anon_sym_LT] = ACTIONS(2418),
    [anon_sym_LT_GT] = ACTIONS(2420),
    [anon_sym_and] = ACTIONS(2418),
    [anon_sym_AND] = ACTIONS(2418),
    [anon_sym_And] = ACTIONS(2418),
    [anon_sym_or] = ACTIONS(2418),
    [anon_sym_OR] = ACTIONS(2418),
    [anon_sym_Or] = ACTIONS(2418),
    [anon_sym_xor] = ACTIONS(2418),
    [anon_sym_XOR] = ACTIONS(2418),
    [anon_sym_Xor] = ACTIONS(2418),
    [anon_sym_QMARK] = ACTIONS(2420),
    [anon_sym_then] = ACTIONS(2418),
    [anon_sym_THEN] = ACTIONS(2418),
    [anon_sym_Then] = ACTIONS(2418),
    [anon_sym_else] = ACTIONS(2418),
    [anon_sym_ELSE] = ACTIONS(2418),
    [anon_sym_Else] = ACTIONS(2418),
    [anon_sym_of] = ACTIONS(2418),
    [anon_sym_OF] = ACTIONS(2418),
    [anon_sym_Of] = ACTIONS(2418),
    [anon_sym_do] = ACTIONS(2418),
    [anon_sym_DO] = ACTIONS(2418),
    [anon_sym_Do] = ACTIONS(2418),
    [anon_sym_in] = ACTIONS(2418),
    [anon_sym_IN] = ACTIONS(2418),
    [anon_sym_In] = ACTIONS(2418),
    [sym_key_keyword] = ACTIONS(2418),
    [sym_dataset_keyword] = ACTIONS(2418),
    [sym_quoted_identifier] = ACTIONS(2420),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_integer] = ACTIONS(2420),
  },
  [STATE(3363)] = {
    [sym_boolean] = STATE(8393),
    [sym_option_member_list] = STATE(8835),
    [sym_option_member] = STATE(8214),
    [sym_keyword_identifier] = STATE(8393),
    [sym_codeunit_keyword] = STATE(8512),
    [sym_xmlport_keyword] = STATE(8512),
    [sym_enum_keyword] = STATE(8512),
    [sym_keyword_as_identifier] = STATE(8393),
    [aux_sym_option_member_list_repeat2] = STATE(3376),
    [sym_identifier] = ACTIONS(9054),
    [anon_sym_SEMI] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(9056),
    [anon_sym_DASH] = ACTIONS(9058),
    [aux_sym_boolean_token1] = ACTIONS(9060),
    [aux_sym_boolean_token2] = ACTIONS(9060),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9062),
    [aux_sym_record_type_token1] = ACTIONS(9062),
    [aux_sym_basic_type_token21] = ACTIONS(9062),
    [aux_sym_basic_type_token22] = ACTIONS(9064),
    [aux_sym_basic_type_token48] = ACTIONS(9062),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDelif] = ACTIONS(275),
    [anon_sym_POUNDELIF] = ACTIONS(275),
    [anon_sym_POUNDElif] = ACTIONS(275),
    [anon_sym_POUNDelse] = ACTIONS(275),
    [anon_sym_POUNDELSE] = ACTIONS(275),
    [anon_sym_POUNDElse] = ACTIONS(275),
    [anon_sym_POUNDendif] = ACTIONS(275),
    [anon_sym_POUNDENDIF] = ACTIONS(275),
    [anon_sym_POUNDEndif] = ACTIONS(275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9062),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9062),
    [sym_page_keyword] = ACTIONS(9062),
    [anon_sym_codeunit] = ACTIONS(9066),
    [anon_sym_CODEUNIT] = ACTIONS(9066),
    [anon_sym_Codeunit] = ACTIONS(9066),
    [anon_sym_CodeUnit] = ACTIONS(9066),
    [anon_sym_COdeunit] = ACTIONS(9066),
    [anon_sym_codeUnit] = ACTIONS(9066),
    [sym_report_keyword] = ACTIONS(9062),
    [sym_query_keyword] = ACTIONS(9062),
    [anon_sym_xmlport] = ACTIONS(9068),
    [anon_sym_XMLPORT] = ACTIONS(9068),
    [anon_sym_Xmlport] = ACTIONS(9068),
    [anon_sym_XMLport] = ACTIONS(9068),
    [anon_sym_XMLPort] = ACTIONS(9068),
    [anon_sym_XmlPort] = ACTIONS(9068),
    [anon_sym_enum] = ACTIONS(9070),
    [anon_sym_ENUM] = ACTIONS(9070),
    [anon_sym_Enum] = ACTIONS(9070),
    [anon_sym_eNUM] = ACTIONS(9070),
    [anon_sym_eNum] = ACTIONS(9070),
    [anon_sym_ENum] = ACTIONS(9070),
    [sym_local_keyword] = ACTIONS(9054),
    [sym_internal_keyword] = ACTIONS(9054),
    [sym_protected_keyword] = ACTIONS(9054),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(9072),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9072),
    [sym_integer] = ACTIONS(9072),
    [sym_preproc_close] = ACTIONS(275),
  },
  [STATE(3364)] = {
    [sym__body_element] = STATE(3366),
    [sym_empty_statement] = STATE(3366),
    [sym_property] = STATE(3366),
    [sym_fields_section] = STATE(3366),
    [sym_keys_section] = STATE(3366),
    [sym_fieldgroups_section] = STATE(3366),
    [sym_enum_value_declaration] = STATE(3366),
    [sym_labels_section] = STATE(3366),
    [sym_layout_section] = STATE(3366),
    [sym_modify_modification] = STATE(3366),
    [sym_actions_section] = STATE(3366),
    [sym_views_section] = STATE(3366),
    [sym_dataset_section] = STATE(3366),
    [sym_requestpage_section] = STATE(3366),
    [sym_rendering_section] = STATE(3366),
    [sym_elements_section] = STATE(3366),
    [sym_query_dataitem] = STATE(3366),
    [sym__query_body_element] = STATE(3366),
    [sym_preproc_conditional_query] = STATE(3366),
    [sym_query_column] = STATE(3366),
    [sym_query_filter] = STATE(3366),
    [sym_schema_section] = STATE(3366),
    [sym_assembly_declaration] = STATE(3366),
    [sym_event_declaration] = STATE(3366),
    [sym_procedure] = STATE(3366),
    [sym_preproc_split_procedure] = STATE(3366),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3366),
    [sym_var_section] = STATE(3366),
    [sym_attribute_item] = STATE(3366),
    [sym_preproc_conditional] = STATE(3366),
    [sym_preproc_if] = STATE(2475),
    [aux_sym_query_dataitem_repeat1] = STATE(3366),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9074),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(8948),
    [sym_column_keyword] = ACTIONS(8950),
    [sym_filter_keyword] = ACTIONS(8952),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3365)] = {
    [sym__body_element] = STATE(3352),
    [sym_empty_statement] = STATE(3352),
    [sym_property] = STATE(3352),
    [sym_fields_section] = STATE(3352),
    [sym_keys_section] = STATE(3352),
    [sym_fieldgroups_section] = STATE(3352),
    [sym_enum_value_declaration] = STATE(3352),
    [sym_labels_section] = STATE(3352),
    [sym_layout_section] = STATE(3352),
    [sym_modify_modification] = STATE(3352),
    [sym_actions_section] = STATE(3352),
    [sym_views_section] = STATE(3352),
    [sym_dataset_section] = STATE(3352),
    [sym_requestpage_section] = STATE(3352),
    [sym_rendering_section] = STATE(3352),
    [sym_elements_section] = STATE(3352),
    [sym_query_dataitem] = STATE(3352),
    [sym__query_body_element] = STATE(3352),
    [sym_preproc_conditional_query] = STATE(3352),
    [sym_query_column] = STATE(3352),
    [sym_query_filter] = STATE(3352),
    [sym_schema_section] = STATE(3352),
    [sym_assembly_declaration] = STATE(3352),
    [sym_event_declaration] = STATE(3352),
    [sym_procedure] = STATE(3352),
    [sym_preproc_split_procedure] = STATE(3352),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3352),
    [sym_var_section] = STATE(3352),
    [sym_attribute_item] = STATE(3352),
    [sym_preproc_conditional] = STATE(3352),
    [sym_preproc_if] = STATE(2475),
    [aux_sym_query_dataitem_repeat1] = STATE(3352),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9076),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(8948),
    [sym_column_keyword] = ACTIONS(8950),
    [sym_filter_keyword] = ACTIONS(8952),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3366)] = {
    [sym__body_element] = STATE(3352),
    [sym_empty_statement] = STATE(3352),
    [sym_property] = STATE(3352),
    [sym_fields_section] = STATE(3352),
    [sym_keys_section] = STATE(3352),
    [sym_fieldgroups_section] = STATE(3352),
    [sym_enum_value_declaration] = STATE(3352),
    [sym_labels_section] = STATE(3352),
    [sym_layout_section] = STATE(3352),
    [sym_modify_modification] = STATE(3352),
    [sym_actions_section] = STATE(3352),
    [sym_views_section] = STATE(3352),
    [sym_dataset_section] = STATE(3352),
    [sym_requestpage_section] = STATE(3352),
    [sym_rendering_section] = STATE(3352),
    [sym_elements_section] = STATE(3352),
    [sym_query_dataitem] = STATE(3352),
    [sym__query_body_element] = STATE(3352),
    [sym_preproc_conditional_query] = STATE(3352),
    [sym_query_column] = STATE(3352),
    [sym_query_filter] = STATE(3352),
    [sym_schema_section] = STATE(3352),
    [sym_assembly_declaration] = STATE(3352),
    [sym_event_declaration] = STATE(3352),
    [sym_procedure] = STATE(3352),
    [sym_preproc_split_procedure] = STATE(3352),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3352),
    [sym_var_section] = STATE(3352),
    [sym_attribute_item] = STATE(3352),
    [sym_preproc_conditional] = STATE(3352),
    [sym_preproc_if] = STATE(2475),
    [aux_sym_query_dataitem_repeat1] = STATE(3352),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9078),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(8948),
    [sym_column_keyword] = ACTIONS(8950),
    [sym_filter_keyword] = ACTIONS(8952),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3367)] = {
    [sym__body_element] = STATE(3365),
    [sym_empty_statement] = STATE(3365),
    [sym_property] = STATE(3365),
    [sym_fields_section] = STATE(3365),
    [sym_keys_section] = STATE(3365),
    [sym_fieldgroups_section] = STATE(3365),
    [sym_enum_value_declaration] = STATE(3365),
    [sym_labels_section] = STATE(3365),
    [sym_layout_section] = STATE(3365),
    [sym_modify_modification] = STATE(3365),
    [sym_actions_section] = STATE(3365),
    [sym_views_section] = STATE(3365),
    [sym_dataset_section] = STATE(3365),
    [sym_requestpage_section] = STATE(3365),
    [sym_rendering_section] = STATE(3365),
    [sym_elements_section] = STATE(3365),
    [sym_query_dataitem] = STATE(3365),
    [sym__query_body_element] = STATE(3365),
    [sym_preproc_conditional_query] = STATE(3365),
    [sym_query_column] = STATE(3365),
    [sym_query_filter] = STATE(3365),
    [sym_schema_section] = STATE(3365),
    [sym_assembly_declaration] = STATE(3365),
    [sym_event_declaration] = STATE(3365),
    [sym_procedure] = STATE(3365),
    [sym_preproc_split_procedure] = STATE(3365),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3365),
    [sym_var_section] = STATE(3365),
    [sym_attribute_item] = STATE(3365),
    [sym_preproc_conditional] = STATE(3365),
    [sym_preproc_if] = STATE(2475),
    [aux_sym_query_dataitem_repeat1] = STATE(3365),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9080),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(8948),
    [sym_column_keyword] = ACTIONS(8950),
    [sym_filter_keyword] = ACTIONS(8952),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3368)] = {
    [aux_sym_option_member_list_repeat2] = STATE(3368),
    [sym_identifier] = ACTIONS(565),
    [anon_sym_SEMI] = ACTIONS(567),
    [anon_sym_COMMA] = ACTIONS(9082),
    [anon_sym_DASH] = ACTIONS(567),
    [aux_sym_boolean_token1] = ACTIONS(565),
    [aux_sym_boolean_token2] = ACTIONS(565),
    [aux_sym_where_condition_token1] = ACTIONS(565),
    [aux_sym_tabledata_permission_token2] = ACTIONS(565),
    [aux_sym_record_type_token1] = ACTIONS(565),
    [aux_sym_basic_type_token21] = ACTIONS(565),
    [aux_sym_basic_type_token22] = ACTIONS(565),
    [aux_sym_basic_type_token48] = ACTIONS(565),
    [aux_sym_basic_type_token53] = ACTIONS(565),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(565),
    [aux_sym_separator_action_token1] = ACTIONS(565),
    [aux_sym_type_declaration_token1] = ACTIONS(565),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(565),
    [anon_sym_POUNDif] = ACTIONS(567),
    [anon_sym_POUNDIF] = ACTIONS(567),
    [anon_sym_POUNDIf] = ACTIONS(567),
    [anon_sym_POUNDelif] = ACTIONS(567),
    [anon_sym_POUNDELIF] = ACTIONS(567),
    [anon_sym_POUNDElif] = ACTIONS(567),
    [anon_sym_POUNDelse] = ACTIONS(567),
    [anon_sym_POUNDELSE] = ACTIONS(567),
    [anon_sym_POUNDElse] = ACTIONS(567),
    [anon_sym_POUNDendif] = ACTIONS(567),
    [anon_sym_POUNDENDIF] = ACTIONS(567),
    [anon_sym_POUNDEndif] = ACTIONS(567),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(565),
    [sym_page_keyword] = ACTIONS(565),
    [anon_sym_codeunit] = ACTIONS(565),
    [anon_sym_CODEUNIT] = ACTIONS(565),
    [anon_sym_Codeunit] = ACTIONS(565),
    [anon_sym_CodeUnit] = ACTIONS(565),
    [anon_sym_COdeunit] = ACTIONS(565),
    [anon_sym_codeUnit] = ACTIONS(565),
    [sym_report_keyword] = ACTIONS(565),
    [sym_query_keyword] = ACTIONS(565),
    [anon_sym_xmlport] = ACTIONS(565),
    [anon_sym_XMLPORT] = ACTIONS(565),
    [anon_sym_Xmlport] = ACTIONS(565),
    [anon_sym_XMLport] = ACTIONS(565),
    [anon_sym_XMLPort] = ACTIONS(565),
    [anon_sym_XmlPort] = ACTIONS(565),
    [anon_sym_enum] = ACTIONS(565),
    [anon_sym_ENUM] = ACTIONS(565),
    [anon_sym_Enum] = ACTIONS(565),
    [anon_sym_eNUM] = ACTIONS(565),
    [anon_sym_eNum] = ACTIONS(565),
    [anon_sym_ENum] = ACTIONS(565),
    [sym_var_keyword] = ACTIONS(565),
    [sym_local_keyword] = ACTIONS(565),
    [sym_internal_keyword] = ACTIONS(565),
    [sym_protected_keyword] = ACTIONS(565),
    [sym_key_keyword] = ACTIONS(565),
    [sym_dataset_keyword] = ACTIONS(565),
    [sym_quoted_identifier] = ACTIONS(567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(567),
    [sym_integer] = ACTIONS(567),
    [sym_preproc_open] = ACTIONS(567),
    [sym_preproc_close] = ACTIONS(567),
    [sym_begin_keyword] = ACTIONS(567),
  },
  [STATE(3369)] = {
    [sym_identifier] = ACTIONS(5447),
    [anon_sym_DASH] = ACTIONS(5449),
    [aux_sym_boolean_token1] = ACTIONS(5447),
    [aux_sym_boolean_token2] = ACTIONS(5447),
    [sym_decimal] = ACTIONS(5447),
    [anon_sym_LPAREN] = ACTIONS(5449),
    [aux_sym_where_condition_token1] = ACTIONS(5447),
    [aux_sym_if_table_relation_token1] = ACTIONS(5447),
    [aux_sym_tabledata_permission_token1] = ACTIONS(5447),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5447),
    [anon_sym_LBRACK] = ACTIONS(5449),
    [aux_sym_record_type_token1] = ACTIONS(5447),
    [aux_sym_basic_type_token21] = ACTIONS(5447),
    [aux_sym_basic_type_token22] = ACTIONS(5447),
    [aux_sym_basic_type_token48] = ACTIONS(5447),
    [aux_sym_basic_type_token53] = ACTIONS(5447),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5447),
    [aux_sym_separator_action_token1] = ACTIONS(5447),
    [aux_sym_type_declaration_token1] = ACTIONS(5447),
    [anon_sym_POUNDif] = ACTIONS(5449),
    [anon_sym_POUNDIF] = ACTIONS(5449),
    [anon_sym_POUNDIf] = ACTIONS(5449),
    [anon_sym_not] = ACTIONS(5447),
    [anon_sym_NOT] = ACTIONS(5447),
    [anon_sym_Not] = ACTIONS(5447),
    [anon_sym_POUNDendif] = ACTIONS(5449),
    [anon_sym_POUNDENDIF] = ACTIONS(5449),
    [anon_sym_POUNDEndif] = ACTIONS(5449),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5447),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5447),
    [anon_sym_PLUS] = ACTIONS(5449),
    [sym_datetime_literal] = ACTIONS(5449),
    [sym_date_literal] = ACTIONS(5447),
    [sym_time_literal] = ACTIONS(5447),
    [sym_biginteger_literal] = ACTIONS(5449),
    [sym_table_keyword] = ACTIONS(5447),
    [sym_page_keyword] = ACTIONS(5447),
    [anon_sym_codeunit] = ACTIONS(5447),
    [anon_sym_CODEUNIT] = ACTIONS(5447),
    [anon_sym_Codeunit] = ACTIONS(5447),
    [anon_sym_CodeUnit] = ACTIONS(5447),
    [anon_sym_COdeunit] = ACTIONS(5447),
    [anon_sym_codeUnit] = ACTIONS(5447),
    [sym_report_keyword] = ACTIONS(5447),
    [sym_query_keyword] = ACTIONS(5447),
    [anon_sym_xmlport] = ACTIONS(5447),
    [anon_sym_XMLPORT] = ACTIONS(5447),
    [anon_sym_Xmlport] = ACTIONS(5447),
    [anon_sym_XMLport] = ACTIONS(5447),
    [anon_sym_XMLPort] = ACTIONS(5447),
    [anon_sym_XmlPort] = ACTIONS(5447),
    [anon_sym_enum] = ACTIONS(5447),
    [anon_sym_ENUM] = ACTIONS(5447),
    [anon_sym_Enum] = ACTIONS(5447),
    [anon_sym_eNUM] = ACTIONS(5447),
    [anon_sym_eNum] = ACTIONS(5447),
    [anon_sym_ENum] = ACTIONS(5447),
    [sym_key_keyword] = ACTIONS(5447),
    [sym_dataset_keyword] = ACTIONS(5447),
    [sym_quoted_identifier] = ACTIONS(5449),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5449),
    [sym_integer] = ACTIONS(5447),
    [sym_continue_as_identifier] = ACTIONS(5449),
    [sym_preproc_open] = ACTIONS(5449),
    [sym_preproc_close] = ACTIONS(5449),
  },
  [STATE(3370)] = {
    [sym__layout_element] = STATE(3403),
    [sym_area_section] = STATE(3403),
    [sym_group_section] = STATE(3403),
    [sym_repeater_section] = STATE(3403),
    [sym_cuegroup_section] = STATE(3403),
    [sym_fixed_section] = STATE(3403),
    [sym_grid_section] = STATE(3403),
    [sym_page_field] = STATE(3403),
    [sym_part_section] = STATE(3403),
    [sym_systempart_section] = STATE(3403),
    [sym_usercontrol_section] = STATE(3403),
    [sym_preproc_split_field] = STATE(3403),
    [sym__field_header] = STATE(7789),
    [sym_label_section] = STATE(3403),
    [sym_addfirst_modification] = STATE(3403),
    [sym_addlast_modification] = STATE(3403),
    [sym_addafter_modification] = STATE(3403),
    [sym_addbefore_modification] = STATE(3403),
    [sym_modify_modification] = STATE(3403),
    [sym_movefirst_modification] = STATE(3403),
    [sym_movelast_modification] = STATE(3403),
    [sym_moveafter_modification] = STATE(3403),
    [sym_movebefore_modification] = STATE(3403),
    [sym_preproc_if] = STATE(3384),
    [sym_preproc_elif] = STATE(3879),
    [sym_preproc_else] = STATE(4707),
    [sym_preproc_endif] = STATE(7157),
    [sym_preproc_conditional_layout] = STATE(3403),
    [aux_sym_layout_section_repeat1] = STATE(3403),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7790),
    [anon_sym_RBRACE] = ACTIONS(9085),
    [aux_sym_where_condition_token1] = ACTIONS(9087),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [aux_sym_basic_type_token6] = ACTIONS(9089),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(9091),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [anon_sym_POUNDif] = ACTIONS(9093),
    [anon_sym_POUNDIF] = ACTIONS(9093),
    [anon_sym_POUNDIf] = ACTIONS(9093),
    [anon_sym_POUNDelif] = ACTIONS(9095),
    [anon_sym_POUNDELIF] = ACTIONS(9095),
    [anon_sym_POUNDElif] = ACTIONS(9095),
    [anon_sym_POUNDelse] = ACTIONS(9097),
    [anon_sym_POUNDELSE] = ACTIONS(9097),
    [anon_sym_POUNDElse] = ACTIONS(9097),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9093),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(3371)] = {
    [sym__layout_element] = STATE(3404),
    [sym_area_section] = STATE(3404),
    [sym_group_section] = STATE(3404),
    [sym_repeater_section] = STATE(3404),
    [sym_cuegroup_section] = STATE(3404),
    [sym_fixed_section] = STATE(3404),
    [sym_grid_section] = STATE(3404),
    [sym_page_field] = STATE(3404),
    [sym_part_section] = STATE(3404),
    [sym_systempart_section] = STATE(3404),
    [sym_usercontrol_section] = STATE(3404),
    [sym_preproc_split_field] = STATE(3404),
    [sym__field_header] = STATE(7789),
    [sym_label_section] = STATE(3404),
    [sym_addfirst_modification] = STATE(3404),
    [sym_addlast_modification] = STATE(3404),
    [sym_addafter_modification] = STATE(3404),
    [sym_addbefore_modification] = STATE(3404),
    [sym_modify_modification] = STATE(3404),
    [sym_movefirst_modification] = STATE(3404),
    [sym_movelast_modification] = STATE(3404),
    [sym_moveafter_modification] = STATE(3404),
    [sym_movebefore_modification] = STATE(3404),
    [sym_preproc_if] = STATE(3384),
    [sym_preproc_elif] = STATE(3879),
    [sym_preproc_else] = STATE(4707),
    [sym_preproc_endif] = STATE(7157),
    [sym_preproc_conditional_layout] = STATE(3404),
    [aux_sym_layout_section_repeat1] = STATE(3404),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7790),
    [anon_sym_RBRACE] = ACTIONS(9099),
    [aux_sym_where_condition_token1] = ACTIONS(9087),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [aux_sym_basic_type_token6] = ACTIONS(9089),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(9091),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [anon_sym_POUNDif] = ACTIONS(9093),
    [anon_sym_POUNDIF] = ACTIONS(9093),
    [anon_sym_POUNDIf] = ACTIONS(9093),
    [anon_sym_POUNDelif] = ACTIONS(9095),
    [anon_sym_POUNDELIF] = ACTIONS(9095),
    [anon_sym_POUNDElif] = ACTIONS(9095),
    [anon_sym_POUNDelse] = ACTIONS(9097),
    [anon_sym_POUNDELSE] = ACTIONS(9097),
    [anon_sym_POUNDElse] = ACTIONS(9097),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9093),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(3372)] = {
    [sym_identifier] = ACTIONS(2266),
    [anon_sym_SEMI] = ACTIONS(2268),
    [anon_sym_DOT] = ACTIONS(2266),
    [anon_sym_LBRACE] = ACTIONS(2268),
    [aux_sym_interface_declaration_token1] = ACTIONS(2266),
    [anon_sym_EQ] = ACTIONS(2268),
    [anon_sym_COMMA] = ACTIONS(2268),
    [anon_sym_DASH] = ACTIONS(2266),
    [anon_sym_LPAREN] = ACTIONS(2268),
    [aux_sym_where_clause_token1] = ACTIONS(2268),
    [aux_sym_where_condition_token1] = ACTIONS(2266),
    [anon_sym_DOT_DOT] = ACTIONS(2268),
    [anon_sym_STAR] = ACTIONS(2266),
    [anon_sym_LBRACK] = ACTIONS(2268),
    [aux_sym_basic_type_token22] = ACTIONS(2266),
    [aux_sym_basic_type_token53] = ACTIONS(2266),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2266),
    [aux_sym_separator_action_token1] = ACTIONS(2266),
    [aux_sym_type_declaration_token1] = ACTIONS(2266),
    [anon_sym_COLON_COLON] = ACTIONS(2268),
    [anon_sym_POUNDelif] = ACTIONS(2268),
    [anon_sym_POUNDELIF] = ACTIONS(2268),
    [anon_sym_POUNDElif] = ACTIONS(2268),
    [anon_sym_POUNDelse] = ACTIONS(2268),
    [anon_sym_POUNDELSE] = ACTIONS(2268),
    [anon_sym_POUNDElse] = ACTIONS(2268),
    [anon_sym_POUNDendif] = ACTIONS(2268),
    [anon_sym_POUNDENDIF] = ACTIONS(2268),
    [anon_sym_POUNDEndif] = ACTIONS(2268),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(2268),
    [aux_sym__expression_token1] = ACTIONS(2268),
    [aux_sym__expression_token2] = ACTIONS(2268),
    [anon_sym_SLASH] = ACTIONS(2266),
    [anon_sym_div] = ACTIONS(2266),
    [anon_sym_DIV] = ACTIONS(2266),
    [anon_sym_Div] = ACTIONS(2266),
    [anon_sym_mod] = ACTIONS(2266),
    [anon_sym_MOD] = ACTIONS(2266),
    [anon_sym_Mod] = ACTIONS(2266),
    [anon_sym_PLUS] = ACTIONS(2266),
    [anon_sym_GT_EQ] = ACTIONS(2268),
    [anon_sym_LT_EQ] = ACTIONS(2268),
    [anon_sym_GT] = ACTIONS(2266),
    [anon_sym_LT] = ACTIONS(2266),
    [anon_sym_LT_GT] = ACTIONS(2268),
    [anon_sym_and] = ACTIONS(2266),
    [anon_sym_AND] = ACTIONS(2266),
    [anon_sym_And] = ACTIONS(2266),
    [anon_sym_or] = ACTIONS(2266),
    [anon_sym_OR] = ACTIONS(2266),
    [anon_sym_Or] = ACTIONS(2266),
    [anon_sym_xor] = ACTIONS(2266),
    [anon_sym_XOR] = ACTIONS(2266),
    [anon_sym_Xor] = ACTIONS(2266),
    [anon_sym_QMARK] = ACTIONS(2268),
    [anon_sym_in] = ACTIONS(2266),
    [anon_sym_IN] = ACTIONS(2266),
    [anon_sym_In] = ACTIONS(2266),
    [sym_implements_keyword] = ACTIONS(2266),
    [sym_extends_keyword] = ACTIONS(2266),
    [sym_temporary_keyword] = ACTIONS(2266),
    [sym_key_keyword] = ACTIONS(2266),
    [sym_dataset_keyword] = ACTIONS(2266),
    [sym_quoted_identifier] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_close] = ACTIONS(2268),
  },
  [STATE(3373)] = {
    [sym_preproc_conditional_controladdin] = STATE(3409),
    [sym__body_element] = STATE(6269),
    [sym_empty_statement] = STATE(6269),
    [sym_property] = STATE(6269),
    [sym_fields_section] = STATE(6269),
    [sym_keys_section] = STATE(6269),
    [sym_fieldgroups_section] = STATE(6269),
    [sym_enum_value_declaration] = STATE(6269),
    [sym_labels_section] = STATE(6269),
    [sym_layout_section] = STATE(6269),
    [sym_modify_modification] = STATE(6269),
    [sym_actions_section] = STATE(6269),
    [sym_views_section] = STATE(6269),
    [sym_dataset_section] = STATE(6269),
    [sym_requestpage_section] = STATE(6269),
    [sym_rendering_section] = STATE(6269),
    [sym_elements_section] = STATE(6269),
    [sym_schema_section] = STATE(6269),
    [sym_assembly_declaration] = STATE(6269),
    [sym_event_declaration] = STATE(6269),
    [sym_procedure] = STATE(6269),
    [sym_preproc_split_procedure] = STATE(6269),
    [sym_interface_procedure] = STATE(3409),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(6269),
    [sym_var_section] = STATE(6269),
    [sym_attribute_item] = STATE(6269),
    [sym_preproc_conditional] = STATE(6269),
    [sym_preproc_if] = STATE(2635),
    [sym_preproc_endif] = STATE(6939),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3490),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3409),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3374)] = {
    [sym__layout_element] = STATE(3406),
    [sym_area_section] = STATE(3406),
    [sym_group_section] = STATE(3406),
    [sym_repeater_section] = STATE(3406),
    [sym_cuegroup_section] = STATE(3406),
    [sym_fixed_section] = STATE(3406),
    [sym_grid_section] = STATE(3406),
    [sym_page_field] = STATE(3406),
    [sym_part_section] = STATE(3406),
    [sym_systempart_section] = STATE(3406),
    [sym_usercontrol_section] = STATE(3406),
    [sym_preproc_split_field] = STATE(3406),
    [sym__field_header] = STATE(7789),
    [sym_label_section] = STATE(3406),
    [sym_addfirst_modification] = STATE(3406),
    [sym_addlast_modification] = STATE(3406),
    [sym_addafter_modification] = STATE(3406),
    [sym_addbefore_modification] = STATE(3406),
    [sym_modify_modification] = STATE(3406),
    [sym_movefirst_modification] = STATE(3406),
    [sym_movelast_modification] = STATE(3406),
    [sym_moveafter_modification] = STATE(3406),
    [sym_movebefore_modification] = STATE(3406),
    [sym_preproc_if] = STATE(3384),
    [sym_preproc_elif] = STATE(3879),
    [sym_preproc_else] = STATE(4707),
    [sym_preproc_endif] = STATE(7157),
    [sym_preproc_conditional_layout] = STATE(3406),
    [aux_sym_layout_section_repeat1] = STATE(3406),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7790),
    [anon_sym_RBRACE] = ACTIONS(9101),
    [aux_sym_where_condition_token1] = ACTIONS(9087),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [aux_sym_basic_type_token6] = ACTIONS(9089),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(9091),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [anon_sym_POUNDif] = ACTIONS(9093),
    [anon_sym_POUNDIF] = ACTIONS(9093),
    [anon_sym_POUNDIf] = ACTIONS(9093),
    [anon_sym_POUNDelif] = ACTIONS(9095),
    [anon_sym_POUNDELIF] = ACTIONS(9095),
    [anon_sym_POUNDElif] = ACTIONS(9095),
    [anon_sym_POUNDelse] = ACTIONS(9097),
    [anon_sym_POUNDELSE] = ACTIONS(9097),
    [anon_sym_POUNDElse] = ACTIONS(9097),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9093),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(3375)] = {
    [sym_preproc_conditional_controladdin] = STATE(3427),
    [sym__body_element] = STATE(6269),
    [sym_empty_statement] = STATE(6269),
    [sym_property] = STATE(6269),
    [sym_fields_section] = STATE(6269),
    [sym_keys_section] = STATE(6269),
    [sym_fieldgroups_section] = STATE(6269),
    [sym_enum_value_declaration] = STATE(6269),
    [sym_labels_section] = STATE(6269),
    [sym_layout_section] = STATE(6269),
    [sym_modify_modification] = STATE(6269),
    [sym_actions_section] = STATE(6269),
    [sym_views_section] = STATE(6269),
    [sym_dataset_section] = STATE(6269),
    [sym_requestpage_section] = STATE(6269),
    [sym_rendering_section] = STATE(6269),
    [sym_elements_section] = STATE(6269),
    [sym_schema_section] = STATE(6269),
    [sym_assembly_declaration] = STATE(6269),
    [sym_event_declaration] = STATE(6269),
    [sym_procedure] = STATE(6269),
    [sym_preproc_split_procedure] = STATE(6269),
    [sym_interface_procedure] = STATE(3427),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(6269),
    [sym_var_section] = STATE(6269),
    [sym_attribute_item] = STATE(6269),
    [sym_preproc_conditional] = STATE(6269),
    [sym_preproc_if] = STATE(2635),
    [sym_preproc_endif] = STATE(6263),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3482),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3427),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3376)] = {
    [sym_boolean] = STATE(8393),
    [sym_option_member] = STATE(8192),
    [sym_keyword_identifier] = STATE(8393),
    [sym_codeunit_keyword] = STATE(8512),
    [sym_xmlport_keyword] = STATE(8512),
    [sym_enum_keyword] = STATE(8512),
    [sym_keyword_as_identifier] = STATE(8393),
    [aux_sym_option_member_list_repeat2] = STATE(4100),
    [sym_identifier] = ACTIONS(9054),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(9103),
    [anon_sym_DASH] = ACTIONS(9058),
    [aux_sym_boolean_token1] = ACTIONS(9060),
    [aux_sym_boolean_token2] = ACTIONS(9060),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9062),
    [aux_sym_record_type_token1] = ACTIONS(9062),
    [aux_sym_basic_type_token21] = ACTIONS(9062),
    [aux_sym_basic_type_token22] = ACTIONS(9064),
    [aux_sym_basic_type_token48] = ACTIONS(9062),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDelif] = ACTIONS(374),
    [anon_sym_POUNDELIF] = ACTIONS(374),
    [anon_sym_POUNDElif] = ACTIONS(374),
    [anon_sym_POUNDelse] = ACTIONS(374),
    [anon_sym_POUNDELSE] = ACTIONS(374),
    [anon_sym_POUNDElse] = ACTIONS(374),
    [anon_sym_POUNDendif] = ACTIONS(374),
    [anon_sym_POUNDENDIF] = ACTIONS(374),
    [anon_sym_POUNDEndif] = ACTIONS(374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9062),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9062),
    [sym_page_keyword] = ACTIONS(9062),
    [anon_sym_codeunit] = ACTIONS(9066),
    [anon_sym_CODEUNIT] = ACTIONS(9066),
    [anon_sym_Codeunit] = ACTIONS(9066),
    [anon_sym_CodeUnit] = ACTIONS(9066),
    [anon_sym_COdeunit] = ACTIONS(9066),
    [anon_sym_codeUnit] = ACTIONS(9066),
    [sym_report_keyword] = ACTIONS(9062),
    [sym_query_keyword] = ACTIONS(9062),
    [anon_sym_xmlport] = ACTIONS(9068),
    [anon_sym_XMLPORT] = ACTIONS(9068),
    [anon_sym_Xmlport] = ACTIONS(9068),
    [anon_sym_XMLport] = ACTIONS(9068),
    [anon_sym_XMLPort] = ACTIONS(9068),
    [anon_sym_XmlPort] = ACTIONS(9068),
    [anon_sym_enum] = ACTIONS(9070),
    [anon_sym_ENUM] = ACTIONS(9070),
    [anon_sym_Enum] = ACTIONS(9070),
    [anon_sym_eNUM] = ACTIONS(9070),
    [anon_sym_eNum] = ACTIONS(9070),
    [anon_sym_ENum] = ACTIONS(9070),
    [sym_local_keyword] = ACTIONS(9054),
    [sym_internal_keyword] = ACTIONS(9054),
    [sym_protected_keyword] = ACTIONS(9054),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(9072),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9072),
    [sym_integer] = ACTIONS(9072),
    [sym_preproc_close] = ACTIONS(374),
  },
  [STATE(3377)] = {
    [sym__layout_element] = STATE(3405),
    [sym_area_section] = STATE(3405),
    [sym_group_section] = STATE(3405),
    [sym_repeater_section] = STATE(3405),
    [sym_cuegroup_section] = STATE(3405),
    [sym_fixed_section] = STATE(3405),
    [sym_grid_section] = STATE(3405),
    [sym_page_field] = STATE(3405),
    [sym_part_section] = STATE(3405),
    [sym_systempart_section] = STATE(3405),
    [sym_usercontrol_section] = STATE(3405),
    [sym_preproc_split_field] = STATE(3405),
    [sym__field_header] = STATE(7789),
    [sym_label_section] = STATE(3405),
    [sym_addfirst_modification] = STATE(3405),
    [sym_addlast_modification] = STATE(3405),
    [sym_addafter_modification] = STATE(3405),
    [sym_addbefore_modification] = STATE(3405),
    [sym_modify_modification] = STATE(3405),
    [sym_movefirst_modification] = STATE(3405),
    [sym_movelast_modification] = STATE(3405),
    [sym_moveafter_modification] = STATE(3405),
    [sym_movebefore_modification] = STATE(3405),
    [sym_preproc_if] = STATE(3384),
    [sym_preproc_elif] = STATE(3879),
    [sym_preproc_else] = STATE(4707),
    [sym_preproc_endif] = STATE(7157),
    [sym_preproc_conditional_layout] = STATE(3405),
    [aux_sym_layout_section_repeat1] = STATE(3405),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7790),
    [anon_sym_RBRACE] = ACTIONS(9105),
    [aux_sym_where_condition_token1] = ACTIONS(9087),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [aux_sym_basic_type_token6] = ACTIONS(9089),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(9091),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [anon_sym_POUNDif] = ACTIONS(9093),
    [anon_sym_POUNDIF] = ACTIONS(9093),
    [anon_sym_POUNDIf] = ACTIONS(9093),
    [anon_sym_POUNDelif] = ACTIONS(9095),
    [anon_sym_POUNDELIF] = ACTIONS(9095),
    [anon_sym_POUNDElif] = ACTIONS(9095),
    [anon_sym_POUNDelse] = ACTIONS(9097),
    [anon_sym_POUNDELSE] = ACTIONS(9097),
    [anon_sym_POUNDElse] = ACTIONS(9097),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9093),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(3378)] = {
    [sym_identifier] = ACTIONS(9107),
    [anon_sym_DASH] = ACTIONS(9109),
    [aux_sym_boolean_token1] = ACTIONS(9107),
    [aux_sym_boolean_token2] = ACTIONS(9107),
    [sym_decimal] = ACTIONS(9107),
    [anon_sym_LPAREN] = ACTIONS(9109),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9107),
    [anon_sym_LBRACK] = ACTIONS(9109),
    [aux_sym_record_type_token1] = ACTIONS(9107),
    [aux_sym_basic_type_token21] = ACTIONS(9107),
    [aux_sym_basic_type_token22] = ACTIONS(9107),
    [aux_sym_basic_type_token48] = ACTIONS(9107),
    [anon_sym_POUNDif] = ACTIONS(9109),
    [anon_sym_POUNDIF] = ACTIONS(9109),
    [anon_sym_POUNDIf] = ACTIONS(9109),
    [anon_sym_not] = ACTIONS(9107),
    [anon_sym_NOT] = ACTIONS(9107),
    [anon_sym_Not] = ACTIONS(9107),
    [anon_sym_POUNDelif] = ACTIONS(9109),
    [anon_sym_POUNDELIF] = ACTIONS(9109),
    [anon_sym_POUNDElif] = ACTIONS(9109),
    [anon_sym_POUNDelse] = ACTIONS(9109),
    [anon_sym_POUNDELSE] = ACTIONS(9109),
    [anon_sym_POUNDElse] = ACTIONS(9109),
    [anon_sym_POUNDendif] = ACTIONS(9109),
    [anon_sym_POUNDENDIF] = ACTIONS(9109),
    [anon_sym_POUNDEndif] = ACTIONS(9109),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9107),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9107),
    [anon_sym_PLUS] = ACTIONS(9109),
    [sym_datetime_literal] = ACTIONS(9109),
    [sym_date_literal] = ACTIONS(9107),
    [sym_time_literal] = ACTIONS(9107),
    [sym_biginteger_literal] = ACTIONS(9109),
    [anon_sym_else] = ACTIONS(9107),
    [anon_sym_ELSE] = ACTIONS(9107),
    [anon_sym_Else] = ACTIONS(9107),
    [sym_page_keyword] = ACTIONS(9107),
    [anon_sym_codeunit] = ACTIONS(9107),
    [anon_sym_CODEUNIT] = ACTIONS(9107),
    [anon_sym_Codeunit] = ACTIONS(9107),
    [anon_sym_CodeUnit] = ACTIONS(9107),
    [anon_sym_COdeunit] = ACTIONS(9107),
    [anon_sym_codeUnit] = ACTIONS(9107),
    [sym_report_keyword] = ACTIONS(9107),
    [sym_query_keyword] = ACTIONS(9107),
    [anon_sym_xmlport] = ACTIONS(9107),
    [anon_sym_XMLPORT] = ACTIONS(9107),
    [anon_sym_Xmlport] = ACTIONS(9107),
    [anon_sym_XMLport] = ACTIONS(9107),
    [anon_sym_XMLPort] = ACTIONS(9107),
    [anon_sym_XmlPort] = ACTIONS(9107),
    [anon_sym_enum] = ACTIONS(9107),
    [anon_sym_ENUM] = ACTIONS(9107),
    [anon_sym_Enum] = ACTIONS(9107),
    [anon_sym_eNUM] = ACTIONS(9107),
    [anon_sym_eNum] = ACTIONS(9107),
    [anon_sym_ENum] = ACTIONS(9107),
    [sym_quoted_identifier] = ACTIONS(9109),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9109),
    [sym_integer] = ACTIONS(9107),
    [sym_continue_as_identifier] = ACTIONS(9109),
    [sym_preproc_open] = ACTIONS(9109),
    [sym_preproc_close] = ACTIONS(9109),
  },
  [STATE(3379)] = {
    [sym__body_element] = STATE(3387),
    [sym_empty_statement] = STATE(3387),
    [sym_property] = STATE(3387),
    [sym_fields_section] = STATE(3387),
    [sym_keys_section] = STATE(3387),
    [sym_fieldgroups_section] = STATE(3387),
    [sym_enum_value_declaration] = STATE(3387),
    [sym_labels_section] = STATE(3387),
    [sym_layout_section] = STATE(3387),
    [sym_modify_modification] = STATE(3387),
    [sym_actions_section] = STATE(3387),
    [sym_views_section] = STATE(3387),
    [sym_dataset_section] = STATE(3387),
    [sym_report_dataitem] = STATE(3387),
    [sym__report_body_element] = STATE(3387),
    [sym_preproc_conditional_report] = STATE(3387),
    [sym_report_column] = STATE(3387),
    [sym_requestpage_section] = STATE(3387),
    [sym_rendering_section] = STATE(3387),
    [sym_elements_section] = STATE(3387),
    [sym_schema_section] = STATE(3387),
    [sym_assembly_declaration] = STATE(3387),
    [sym_event_declaration] = STATE(3387),
    [sym_procedure] = STATE(3387),
    [sym_preproc_split_procedure] = STATE(3387),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3387),
    [sym_var_section] = STATE(3387),
    [sym_attribute_item] = STATE(3387),
    [sym_preproc_conditional] = STATE(3387),
    [sym_preproc_if] = STATE(2558),
    [aux_sym_report_dataitem_repeat1] = STATE(3387),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9111),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3380)] = {
    [sym_identifier] = ACTIONS(9117),
    [anon_sym_DASH] = ACTIONS(9119),
    [aux_sym_boolean_token1] = ACTIONS(9117),
    [aux_sym_boolean_token2] = ACTIONS(9117),
    [sym_decimal] = ACTIONS(9117),
    [anon_sym_LPAREN] = ACTIONS(9119),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9117),
    [anon_sym_LBRACK] = ACTIONS(9119),
    [aux_sym_record_type_token1] = ACTIONS(9117),
    [aux_sym_basic_type_token21] = ACTIONS(9117),
    [aux_sym_basic_type_token22] = ACTIONS(9117),
    [aux_sym_basic_type_token48] = ACTIONS(9117),
    [anon_sym_POUNDif] = ACTIONS(9119),
    [anon_sym_POUNDIF] = ACTIONS(9119),
    [anon_sym_POUNDIf] = ACTIONS(9119),
    [anon_sym_not] = ACTIONS(9117),
    [anon_sym_NOT] = ACTIONS(9117),
    [anon_sym_Not] = ACTIONS(9117),
    [anon_sym_POUNDelif] = ACTIONS(9119),
    [anon_sym_POUNDELIF] = ACTIONS(9119),
    [anon_sym_POUNDElif] = ACTIONS(9119),
    [anon_sym_POUNDelse] = ACTIONS(9119),
    [anon_sym_POUNDELSE] = ACTIONS(9119),
    [anon_sym_POUNDElse] = ACTIONS(9119),
    [anon_sym_POUNDendif] = ACTIONS(9119),
    [anon_sym_POUNDENDIF] = ACTIONS(9119),
    [anon_sym_POUNDEndif] = ACTIONS(9119),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9117),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9117),
    [anon_sym_PLUS] = ACTIONS(9119),
    [sym_datetime_literal] = ACTIONS(9119),
    [sym_date_literal] = ACTIONS(9117),
    [sym_time_literal] = ACTIONS(9117),
    [sym_biginteger_literal] = ACTIONS(9119),
    [anon_sym_else] = ACTIONS(9117),
    [anon_sym_ELSE] = ACTIONS(9117),
    [anon_sym_Else] = ACTIONS(9117),
    [sym_page_keyword] = ACTIONS(9117),
    [anon_sym_codeunit] = ACTIONS(9117),
    [anon_sym_CODEUNIT] = ACTIONS(9117),
    [anon_sym_Codeunit] = ACTIONS(9117),
    [anon_sym_CodeUnit] = ACTIONS(9117),
    [anon_sym_COdeunit] = ACTIONS(9117),
    [anon_sym_codeUnit] = ACTIONS(9117),
    [sym_report_keyword] = ACTIONS(9117),
    [sym_query_keyword] = ACTIONS(9117),
    [anon_sym_xmlport] = ACTIONS(9117),
    [anon_sym_XMLPORT] = ACTIONS(9117),
    [anon_sym_Xmlport] = ACTIONS(9117),
    [anon_sym_XMLport] = ACTIONS(9117),
    [anon_sym_XMLPort] = ACTIONS(9117),
    [anon_sym_XmlPort] = ACTIONS(9117),
    [anon_sym_enum] = ACTIONS(9117),
    [anon_sym_ENUM] = ACTIONS(9117),
    [anon_sym_Enum] = ACTIONS(9117),
    [anon_sym_eNUM] = ACTIONS(9117),
    [anon_sym_eNum] = ACTIONS(9117),
    [anon_sym_ENum] = ACTIONS(9117),
    [sym_quoted_identifier] = ACTIONS(9119),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9119),
    [sym_integer] = ACTIONS(9117),
    [sym_continue_as_identifier] = ACTIONS(9119),
    [sym_preproc_open] = ACTIONS(9119),
    [sym_preproc_close] = ACTIONS(9119),
  },
  [STATE(3381)] = {
    [sym__body_element] = STATE(3383),
    [sym_empty_statement] = STATE(3383),
    [sym_property] = STATE(3383),
    [sym_fields_section] = STATE(3383),
    [sym_keys_section] = STATE(3383),
    [sym_fieldgroups_section] = STATE(3383),
    [sym_enum_value_declaration] = STATE(3383),
    [sym_labels_section] = STATE(3383),
    [sym_layout_section] = STATE(3383),
    [sym_modify_modification] = STATE(3383),
    [sym_actions_section] = STATE(3383),
    [sym_views_section] = STATE(3383),
    [sym_dataset_section] = STATE(3383),
    [sym_report_dataitem] = STATE(3383),
    [sym__report_body_element] = STATE(3383),
    [sym_preproc_conditional_report] = STATE(3383),
    [sym_report_column] = STATE(3383),
    [sym_requestpage_section] = STATE(3383),
    [sym_rendering_section] = STATE(3383),
    [sym_elements_section] = STATE(3383),
    [sym_schema_section] = STATE(3383),
    [sym_assembly_declaration] = STATE(3383),
    [sym_event_declaration] = STATE(3383),
    [sym_procedure] = STATE(3383),
    [sym_preproc_split_procedure] = STATE(3383),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3383),
    [sym_var_section] = STATE(3383),
    [sym_attribute_item] = STATE(3383),
    [sym_preproc_conditional] = STATE(3383),
    [sym_preproc_if] = STATE(2558),
    [aux_sym_report_dataitem_repeat1] = STATE(3383),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9121),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3382)] = {
    [sym_identifier] = ACTIONS(9123),
    [anon_sym_DASH] = ACTIONS(9125),
    [aux_sym_boolean_token1] = ACTIONS(9123),
    [aux_sym_boolean_token2] = ACTIONS(9123),
    [sym_decimal] = ACTIONS(9123),
    [anon_sym_LPAREN] = ACTIONS(9125),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9123),
    [anon_sym_LBRACK] = ACTIONS(9125),
    [aux_sym_record_type_token1] = ACTIONS(9123),
    [aux_sym_basic_type_token21] = ACTIONS(9123),
    [aux_sym_basic_type_token22] = ACTIONS(9123),
    [aux_sym_basic_type_token48] = ACTIONS(9123),
    [anon_sym_POUNDif] = ACTIONS(9125),
    [anon_sym_POUNDIF] = ACTIONS(9125),
    [anon_sym_POUNDIf] = ACTIONS(9125),
    [anon_sym_not] = ACTIONS(9123),
    [anon_sym_NOT] = ACTIONS(9123),
    [anon_sym_Not] = ACTIONS(9123),
    [anon_sym_POUNDelif] = ACTIONS(9125),
    [anon_sym_POUNDELIF] = ACTIONS(9125),
    [anon_sym_POUNDElif] = ACTIONS(9125),
    [anon_sym_POUNDelse] = ACTIONS(9125),
    [anon_sym_POUNDELSE] = ACTIONS(9125),
    [anon_sym_POUNDElse] = ACTIONS(9125),
    [anon_sym_POUNDendif] = ACTIONS(9125),
    [anon_sym_POUNDENDIF] = ACTIONS(9125),
    [anon_sym_POUNDEndif] = ACTIONS(9125),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9123),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9123),
    [anon_sym_PLUS] = ACTIONS(9125),
    [sym_datetime_literal] = ACTIONS(9125),
    [sym_date_literal] = ACTIONS(9123),
    [sym_time_literal] = ACTIONS(9123),
    [sym_biginteger_literal] = ACTIONS(9125),
    [anon_sym_else] = ACTIONS(9123),
    [anon_sym_ELSE] = ACTIONS(9123),
    [anon_sym_Else] = ACTIONS(9123),
    [sym_page_keyword] = ACTIONS(9123),
    [anon_sym_codeunit] = ACTIONS(9123),
    [anon_sym_CODEUNIT] = ACTIONS(9123),
    [anon_sym_Codeunit] = ACTIONS(9123),
    [anon_sym_CodeUnit] = ACTIONS(9123),
    [anon_sym_COdeunit] = ACTIONS(9123),
    [anon_sym_codeUnit] = ACTIONS(9123),
    [sym_report_keyword] = ACTIONS(9123),
    [sym_query_keyword] = ACTIONS(9123),
    [anon_sym_xmlport] = ACTIONS(9123),
    [anon_sym_XMLPORT] = ACTIONS(9123),
    [anon_sym_Xmlport] = ACTIONS(9123),
    [anon_sym_XMLport] = ACTIONS(9123),
    [anon_sym_XMLPort] = ACTIONS(9123),
    [anon_sym_XmlPort] = ACTIONS(9123),
    [anon_sym_enum] = ACTIONS(9123),
    [anon_sym_ENUM] = ACTIONS(9123),
    [anon_sym_Enum] = ACTIONS(9123),
    [anon_sym_eNUM] = ACTIONS(9123),
    [anon_sym_eNum] = ACTIONS(9123),
    [anon_sym_ENum] = ACTIONS(9123),
    [sym_quoted_identifier] = ACTIONS(9125),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9125),
    [sym_integer] = ACTIONS(9123),
    [sym_continue_as_identifier] = ACTIONS(9125),
    [sym_preproc_open] = ACTIONS(9125),
    [sym_preproc_close] = ACTIONS(9125),
  },
  [STATE(3383)] = {
    [sym__body_element] = STATE(3425),
    [sym_empty_statement] = STATE(3425),
    [sym_property] = STATE(3425),
    [sym_fields_section] = STATE(3425),
    [sym_keys_section] = STATE(3425),
    [sym_fieldgroups_section] = STATE(3425),
    [sym_enum_value_declaration] = STATE(3425),
    [sym_labels_section] = STATE(3425),
    [sym_layout_section] = STATE(3425),
    [sym_modify_modification] = STATE(3425),
    [sym_actions_section] = STATE(3425),
    [sym_views_section] = STATE(3425),
    [sym_dataset_section] = STATE(3425),
    [sym_report_dataitem] = STATE(3425),
    [sym__report_body_element] = STATE(3425),
    [sym_preproc_conditional_report] = STATE(3425),
    [sym_report_column] = STATE(3425),
    [sym_requestpage_section] = STATE(3425),
    [sym_rendering_section] = STATE(3425),
    [sym_elements_section] = STATE(3425),
    [sym_schema_section] = STATE(3425),
    [sym_assembly_declaration] = STATE(3425),
    [sym_event_declaration] = STATE(3425),
    [sym_procedure] = STATE(3425),
    [sym_preproc_split_procedure] = STATE(3425),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3425),
    [sym_var_section] = STATE(3425),
    [sym_attribute_item] = STATE(3425),
    [sym_preproc_conditional] = STATE(3425),
    [sym_preproc_if] = STATE(2558),
    [aux_sym_report_dataitem_repeat1] = STATE(3425),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9127),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3384)] = {
    [sym__layout_element] = STATE(3458),
    [sym_area_section] = STATE(3458),
    [sym_group_section] = STATE(3458),
    [sym_repeater_section] = STATE(3458),
    [sym_cuegroup_section] = STATE(3458),
    [sym_fixed_section] = STATE(3458),
    [sym_grid_section] = STATE(3458),
    [sym_page_field] = STATE(3458),
    [sym_part_section] = STATE(3458),
    [sym_systempart_section] = STATE(3458),
    [sym_usercontrol_section] = STATE(3458),
    [sym_preproc_split_field] = STATE(3458),
    [sym__field_header] = STATE(7888),
    [sym_label_section] = STATE(3458),
    [sym_addfirst_modification] = STATE(3458),
    [sym_addlast_modification] = STATE(3458),
    [sym_addafter_modification] = STATE(3458),
    [sym_addbefore_modification] = STATE(3458),
    [sym_modify_modification] = STATE(3458),
    [sym_movefirst_modification] = STATE(3458),
    [sym_movelast_modification] = STATE(3458),
    [sym_moveafter_modification] = STATE(3458),
    [sym_movebefore_modification] = STATE(3458),
    [sym_preproc_if] = STATE(3384),
    [sym_preproc_elif] = STATE(3879),
    [sym_preproc_else] = STATE(4699),
    [sym_preproc_endif] = STATE(6536),
    [sym_preproc_conditional_layout] = STATE(3458),
    [aux_sym_layout_section_repeat1] = STATE(3458),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7891),
    [aux_sym_where_condition_token1] = ACTIONS(9087),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [aux_sym_basic_type_token6] = ACTIONS(9089),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(9091),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [anon_sym_POUNDif] = ACTIONS(9093),
    [anon_sym_POUNDIF] = ACTIONS(9093),
    [anon_sym_POUNDIf] = ACTIONS(9093),
    [anon_sym_POUNDelif] = ACTIONS(9095),
    [anon_sym_POUNDELIF] = ACTIONS(9095),
    [anon_sym_POUNDElif] = ACTIONS(9095),
    [anon_sym_POUNDelse] = ACTIONS(9097),
    [anon_sym_POUNDELSE] = ACTIONS(9097),
    [anon_sym_POUNDElse] = ACTIONS(9097),
    [anon_sym_POUNDendif] = ACTIONS(9129),
    [anon_sym_POUNDENDIF] = ACTIONS(9129),
    [anon_sym_POUNDEndif] = ACTIONS(9129),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9093),
    [sym_preproc_close] = ACTIONS(9129),
  },
  [STATE(3385)] = {
    [sym_identifier] = ACTIONS(9131),
    [anon_sym_DASH] = ACTIONS(9133),
    [aux_sym_boolean_token1] = ACTIONS(9131),
    [aux_sym_boolean_token2] = ACTIONS(9131),
    [sym_decimal] = ACTIONS(9131),
    [anon_sym_LPAREN] = ACTIONS(9133),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9131),
    [anon_sym_LBRACK] = ACTIONS(9133),
    [aux_sym_record_type_token1] = ACTIONS(9131),
    [aux_sym_basic_type_token21] = ACTIONS(9131),
    [aux_sym_basic_type_token22] = ACTIONS(9131),
    [aux_sym_basic_type_token48] = ACTIONS(9131),
    [anon_sym_POUNDif] = ACTIONS(9133),
    [anon_sym_POUNDIF] = ACTIONS(9133),
    [anon_sym_POUNDIf] = ACTIONS(9133),
    [anon_sym_not] = ACTIONS(9131),
    [anon_sym_NOT] = ACTIONS(9131),
    [anon_sym_Not] = ACTIONS(9131),
    [anon_sym_POUNDelif] = ACTIONS(9133),
    [anon_sym_POUNDELIF] = ACTIONS(9133),
    [anon_sym_POUNDElif] = ACTIONS(9133),
    [anon_sym_POUNDelse] = ACTIONS(9133),
    [anon_sym_POUNDELSE] = ACTIONS(9133),
    [anon_sym_POUNDElse] = ACTIONS(9133),
    [anon_sym_POUNDendif] = ACTIONS(9133),
    [anon_sym_POUNDENDIF] = ACTIONS(9133),
    [anon_sym_POUNDEndif] = ACTIONS(9133),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9131),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9131),
    [anon_sym_PLUS] = ACTIONS(9133),
    [sym_datetime_literal] = ACTIONS(9133),
    [sym_date_literal] = ACTIONS(9131),
    [sym_time_literal] = ACTIONS(9131),
    [sym_biginteger_literal] = ACTIONS(9133),
    [anon_sym_else] = ACTIONS(9131),
    [anon_sym_ELSE] = ACTIONS(9131),
    [anon_sym_Else] = ACTIONS(9131),
    [sym_page_keyword] = ACTIONS(9131),
    [anon_sym_codeunit] = ACTIONS(9131),
    [anon_sym_CODEUNIT] = ACTIONS(9131),
    [anon_sym_Codeunit] = ACTIONS(9131),
    [anon_sym_CodeUnit] = ACTIONS(9131),
    [anon_sym_COdeunit] = ACTIONS(9131),
    [anon_sym_codeUnit] = ACTIONS(9131),
    [sym_report_keyword] = ACTIONS(9131),
    [sym_query_keyword] = ACTIONS(9131),
    [anon_sym_xmlport] = ACTIONS(9131),
    [anon_sym_XMLPORT] = ACTIONS(9131),
    [anon_sym_Xmlport] = ACTIONS(9131),
    [anon_sym_XMLport] = ACTIONS(9131),
    [anon_sym_XMLPort] = ACTIONS(9131),
    [anon_sym_XmlPort] = ACTIONS(9131),
    [anon_sym_enum] = ACTIONS(9131),
    [anon_sym_ENUM] = ACTIONS(9131),
    [anon_sym_Enum] = ACTIONS(9131),
    [anon_sym_eNUM] = ACTIONS(9131),
    [anon_sym_eNum] = ACTIONS(9131),
    [anon_sym_ENum] = ACTIONS(9131),
    [sym_quoted_identifier] = ACTIONS(9133),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9133),
    [sym_integer] = ACTIONS(9131),
    [sym_continue_as_identifier] = ACTIONS(9133),
    [sym_preproc_open] = ACTIONS(9133),
    [sym_preproc_close] = ACTIONS(9133),
  },
  [STATE(3386)] = {
    [sym_identifier] = ACTIONS(9123),
    [anon_sym_DASH] = ACTIONS(9125),
    [aux_sym_boolean_token1] = ACTIONS(9123),
    [aux_sym_boolean_token2] = ACTIONS(9123),
    [sym_decimal] = ACTIONS(9123),
    [anon_sym_LPAREN] = ACTIONS(9125),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9123),
    [anon_sym_LBRACK] = ACTIONS(9125),
    [aux_sym_record_type_token1] = ACTIONS(9123),
    [aux_sym_basic_type_token21] = ACTIONS(9123),
    [aux_sym_basic_type_token22] = ACTIONS(9123),
    [aux_sym_basic_type_token48] = ACTIONS(9123),
    [anon_sym_POUNDif] = ACTIONS(9125),
    [anon_sym_POUNDIF] = ACTIONS(9125),
    [anon_sym_POUNDIf] = ACTIONS(9125),
    [anon_sym_not] = ACTIONS(9123),
    [anon_sym_NOT] = ACTIONS(9123),
    [anon_sym_Not] = ACTIONS(9123),
    [anon_sym_POUNDelif] = ACTIONS(9125),
    [anon_sym_POUNDELIF] = ACTIONS(9125),
    [anon_sym_POUNDElif] = ACTIONS(9125),
    [anon_sym_POUNDelse] = ACTIONS(9125),
    [anon_sym_POUNDELSE] = ACTIONS(9125),
    [anon_sym_POUNDElse] = ACTIONS(9125),
    [anon_sym_POUNDendif] = ACTIONS(9125),
    [anon_sym_POUNDENDIF] = ACTIONS(9125),
    [anon_sym_POUNDEndif] = ACTIONS(9125),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9123),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9123),
    [anon_sym_PLUS] = ACTIONS(9125),
    [sym_datetime_literal] = ACTIONS(9125),
    [sym_date_literal] = ACTIONS(9123),
    [sym_time_literal] = ACTIONS(9123),
    [sym_biginteger_literal] = ACTIONS(9125),
    [anon_sym_else] = ACTIONS(9123),
    [anon_sym_ELSE] = ACTIONS(9123),
    [anon_sym_Else] = ACTIONS(9123),
    [sym_page_keyword] = ACTIONS(9123),
    [anon_sym_codeunit] = ACTIONS(9123),
    [anon_sym_CODEUNIT] = ACTIONS(9123),
    [anon_sym_Codeunit] = ACTIONS(9123),
    [anon_sym_CodeUnit] = ACTIONS(9123),
    [anon_sym_COdeunit] = ACTIONS(9123),
    [anon_sym_codeUnit] = ACTIONS(9123),
    [sym_report_keyword] = ACTIONS(9123),
    [sym_query_keyword] = ACTIONS(9123),
    [anon_sym_xmlport] = ACTIONS(9123),
    [anon_sym_XMLPORT] = ACTIONS(9123),
    [anon_sym_Xmlport] = ACTIONS(9123),
    [anon_sym_XMLport] = ACTIONS(9123),
    [anon_sym_XMLPort] = ACTIONS(9123),
    [anon_sym_XmlPort] = ACTIONS(9123),
    [anon_sym_enum] = ACTIONS(9123),
    [anon_sym_ENUM] = ACTIONS(9123),
    [anon_sym_Enum] = ACTIONS(9123),
    [anon_sym_eNUM] = ACTIONS(9123),
    [anon_sym_eNum] = ACTIONS(9123),
    [anon_sym_ENum] = ACTIONS(9123),
    [sym_quoted_identifier] = ACTIONS(9125),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9125),
    [sym_integer] = ACTIONS(9123),
    [sym_continue_as_identifier] = ACTIONS(9125),
    [sym_preproc_open] = ACTIONS(9125),
    [sym_preproc_close] = ACTIONS(9125),
  },
  [STATE(3387)] = {
    [sym__body_element] = STATE(3425),
    [sym_empty_statement] = STATE(3425),
    [sym_property] = STATE(3425),
    [sym_fields_section] = STATE(3425),
    [sym_keys_section] = STATE(3425),
    [sym_fieldgroups_section] = STATE(3425),
    [sym_enum_value_declaration] = STATE(3425),
    [sym_labels_section] = STATE(3425),
    [sym_layout_section] = STATE(3425),
    [sym_modify_modification] = STATE(3425),
    [sym_actions_section] = STATE(3425),
    [sym_views_section] = STATE(3425),
    [sym_dataset_section] = STATE(3425),
    [sym_report_dataitem] = STATE(3425),
    [sym__report_body_element] = STATE(3425),
    [sym_preproc_conditional_report] = STATE(3425),
    [sym_report_column] = STATE(3425),
    [sym_requestpage_section] = STATE(3425),
    [sym_rendering_section] = STATE(3425),
    [sym_elements_section] = STATE(3425),
    [sym_schema_section] = STATE(3425),
    [sym_assembly_declaration] = STATE(3425),
    [sym_event_declaration] = STATE(3425),
    [sym_procedure] = STATE(3425),
    [sym_preproc_split_procedure] = STATE(3425),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3425),
    [sym_var_section] = STATE(3425),
    [sym_attribute_item] = STATE(3425),
    [sym_preproc_conditional] = STATE(3425),
    [sym_preproc_if] = STATE(2558),
    [aux_sym_report_dataitem_repeat1] = STATE(3425),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9135),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3388)] = {
    [sym_preproc_conditional_controladdin] = STATE(2885),
    [sym__body_element] = STATE(2885),
    [sym_empty_statement] = STATE(2885),
    [sym_property] = STATE(2885),
    [sym_fields_section] = STATE(2885),
    [sym_keys_section] = STATE(2885),
    [sym_fieldgroups_section] = STATE(2885),
    [sym_enum_value_declaration] = STATE(2885),
    [sym_labels_section] = STATE(2885),
    [sym_layout_section] = STATE(2885),
    [sym_modify_modification] = STATE(2885),
    [sym_actions_section] = STATE(2885),
    [sym_views_section] = STATE(2885),
    [sym_dataset_section] = STATE(2885),
    [sym_requestpage_section] = STATE(2885),
    [sym_rendering_section] = STATE(2885),
    [sym_elements_section] = STATE(2885),
    [sym_schema_section] = STATE(2885),
    [sym_assembly_declaration] = STATE(2885),
    [sym_event_declaration] = STATE(2885),
    [sym_procedure] = STATE(2885),
    [sym_preproc_split_procedure] = STATE(2885),
    [sym_interface_procedure] = STATE(2885),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2885),
    [sym_var_section] = STATE(2885),
    [sym_attribute_item] = STATE(2885),
    [sym_preproc_conditional] = STATE(2885),
    [sym_preproc_if] = STATE(2635),
    [sym_preproc_endif] = STATE(6929),
    [aux_sym_controladdin_declaration_repeat1] = STATE(2885),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3389)] = {
    [sym_identifier] = ACTIONS(9137),
    [anon_sym_DASH] = ACTIONS(9139),
    [aux_sym_boolean_token1] = ACTIONS(9137),
    [aux_sym_boolean_token2] = ACTIONS(9137),
    [sym_decimal] = ACTIONS(9137),
    [anon_sym_LPAREN] = ACTIONS(9139),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9137),
    [anon_sym_LBRACK] = ACTIONS(9139),
    [aux_sym_record_type_token1] = ACTIONS(9137),
    [aux_sym_basic_type_token21] = ACTIONS(9137),
    [aux_sym_basic_type_token22] = ACTIONS(9137),
    [aux_sym_basic_type_token48] = ACTIONS(9137),
    [anon_sym_POUNDif] = ACTIONS(9139),
    [anon_sym_POUNDIF] = ACTIONS(9139),
    [anon_sym_POUNDIf] = ACTIONS(9139),
    [anon_sym_not] = ACTIONS(9137),
    [anon_sym_NOT] = ACTIONS(9137),
    [anon_sym_Not] = ACTIONS(9137),
    [anon_sym_POUNDelif] = ACTIONS(9139),
    [anon_sym_POUNDELIF] = ACTIONS(9139),
    [anon_sym_POUNDElif] = ACTIONS(9139),
    [anon_sym_POUNDelse] = ACTIONS(9139),
    [anon_sym_POUNDELSE] = ACTIONS(9139),
    [anon_sym_POUNDElse] = ACTIONS(9139),
    [anon_sym_POUNDendif] = ACTIONS(9139),
    [anon_sym_POUNDENDIF] = ACTIONS(9139),
    [anon_sym_POUNDEndif] = ACTIONS(9139),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9137),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9137),
    [anon_sym_PLUS] = ACTIONS(9139),
    [sym_datetime_literal] = ACTIONS(9139),
    [sym_date_literal] = ACTIONS(9137),
    [sym_time_literal] = ACTIONS(9137),
    [sym_biginteger_literal] = ACTIONS(9139),
    [anon_sym_else] = ACTIONS(9137),
    [anon_sym_ELSE] = ACTIONS(9137),
    [anon_sym_Else] = ACTIONS(9137),
    [sym_page_keyword] = ACTIONS(9137),
    [anon_sym_codeunit] = ACTIONS(9137),
    [anon_sym_CODEUNIT] = ACTIONS(9137),
    [anon_sym_Codeunit] = ACTIONS(9137),
    [anon_sym_CodeUnit] = ACTIONS(9137),
    [anon_sym_COdeunit] = ACTIONS(9137),
    [anon_sym_codeUnit] = ACTIONS(9137),
    [sym_report_keyword] = ACTIONS(9137),
    [sym_query_keyword] = ACTIONS(9137),
    [anon_sym_xmlport] = ACTIONS(9137),
    [anon_sym_XMLPORT] = ACTIONS(9137),
    [anon_sym_Xmlport] = ACTIONS(9137),
    [anon_sym_XMLport] = ACTIONS(9137),
    [anon_sym_XMLPort] = ACTIONS(9137),
    [anon_sym_XmlPort] = ACTIONS(9137),
    [anon_sym_enum] = ACTIONS(9137),
    [anon_sym_ENUM] = ACTIONS(9137),
    [anon_sym_Enum] = ACTIONS(9137),
    [anon_sym_eNUM] = ACTIONS(9137),
    [anon_sym_eNum] = ACTIONS(9137),
    [anon_sym_ENum] = ACTIONS(9137),
    [sym_quoted_identifier] = ACTIONS(9139),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9139),
    [sym_integer] = ACTIONS(9137),
    [sym_continue_as_identifier] = ACTIONS(9139),
    [sym_preproc_open] = ACTIONS(9139),
    [sym_preproc_close] = ACTIONS(9139),
  },
  [STATE(3390)] = {
    [sym_preproc_conditional_controladdin] = STATE(2885),
    [sym__body_element] = STATE(2885),
    [sym_empty_statement] = STATE(2885),
    [sym_property] = STATE(2885),
    [sym_fields_section] = STATE(2885),
    [sym_keys_section] = STATE(2885),
    [sym_fieldgroups_section] = STATE(2885),
    [sym_enum_value_declaration] = STATE(2885),
    [sym_labels_section] = STATE(2885),
    [sym_layout_section] = STATE(2885),
    [sym_modify_modification] = STATE(2885),
    [sym_actions_section] = STATE(2885),
    [sym_views_section] = STATE(2885),
    [sym_dataset_section] = STATE(2885),
    [sym_requestpage_section] = STATE(2885),
    [sym_rendering_section] = STATE(2885),
    [sym_elements_section] = STATE(2885),
    [sym_schema_section] = STATE(2885),
    [sym_assembly_declaration] = STATE(2885),
    [sym_event_declaration] = STATE(2885),
    [sym_procedure] = STATE(2885),
    [sym_preproc_split_procedure] = STATE(2885),
    [sym_interface_procedure] = STATE(2885),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2885),
    [sym_var_section] = STATE(2885),
    [sym_attribute_item] = STATE(2885),
    [sym_preproc_conditional] = STATE(2885),
    [sym_preproc_if] = STATE(2635),
    [sym_preproc_endif] = STATE(6257),
    [aux_sym_controladdin_declaration_repeat1] = STATE(2885),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3391)] = {
    [sym_identifier] = ACTIONS(9141),
    [anon_sym_DASH] = ACTIONS(9143),
    [aux_sym_boolean_token1] = ACTIONS(9141),
    [aux_sym_boolean_token2] = ACTIONS(9141),
    [sym_decimal] = ACTIONS(9141),
    [anon_sym_LPAREN] = ACTIONS(9143),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9141),
    [anon_sym_LBRACK] = ACTIONS(9143),
    [aux_sym_record_type_token1] = ACTIONS(9141),
    [aux_sym_basic_type_token21] = ACTIONS(9141),
    [aux_sym_basic_type_token22] = ACTIONS(9141),
    [aux_sym_basic_type_token48] = ACTIONS(9141),
    [anon_sym_POUNDif] = ACTIONS(9143),
    [anon_sym_POUNDIF] = ACTIONS(9143),
    [anon_sym_POUNDIf] = ACTIONS(9143),
    [anon_sym_not] = ACTIONS(9141),
    [anon_sym_NOT] = ACTIONS(9141),
    [anon_sym_Not] = ACTIONS(9141),
    [anon_sym_POUNDelif] = ACTIONS(9143),
    [anon_sym_POUNDELIF] = ACTIONS(9143),
    [anon_sym_POUNDElif] = ACTIONS(9143),
    [anon_sym_POUNDelse] = ACTIONS(9143),
    [anon_sym_POUNDELSE] = ACTIONS(9143),
    [anon_sym_POUNDElse] = ACTIONS(9143),
    [anon_sym_POUNDendif] = ACTIONS(9143),
    [anon_sym_POUNDENDIF] = ACTIONS(9143),
    [anon_sym_POUNDEndif] = ACTIONS(9143),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9141),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9141),
    [anon_sym_PLUS] = ACTIONS(9143),
    [sym_datetime_literal] = ACTIONS(9143),
    [sym_date_literal] = ACTIONS(9141),
    [sym_time_literal] = ACTIONS(9141),
    [sym_biginteger_literal] = ACTIONS(9143),
    [anon_sym_else] = ACTIONS(9141),
    [anon_sym_ELSE] = ACTIONS(9141),
    [anon_sym_Else] = ACTIONS(9141),
    [sym_page_keyword] = ACTIONS(9141),
    [anon_sym_codeunit] = ACTIONS(9141),
    [anon_sym_CODEUNIT] = ACTIONS(9141),
    [anon_sym_Codeunit] = ACTIONS(9141),
    [anon_sym_CodeUnit] = ACTIONS(9141),
    [anon_sym_COdeunit] = ACTIONS(9141),
    [anon_sym_codeUnit] = ACTIONS(9141),
    [sym_report_keyword] = ACTIONS(9141),
    [sym_query_keyword] = ACTIONS(9141),
    [anon_sym_xmlport] = ACTIONS(9141),
    [anon_sym_XMLPORT] = ACTIONS(9141),
    [anon_sym_Xmlport] = ACTIONS(9141),
    [anon_sym_XMLport] = ACTIONS(9141),
    [anon_sym_XMLPort] = ACTIONS(9141),
    [anon_sym_XmlPort] = ACTIONS(9141),
    [anon_sym_enum] = ACTIONS(9141),
    [anon_sym_ENUM] = ACTIONS(9141),
    [anon_sym_Enum] = ACTIONS(9141),
    [anon_sym_eNUM] = ACTIONS(9141),
    [anon_sym_eNum] = ACTIONS(9141),
    [anon_sym_ENum] = ACTIONS(9141),
    [sym_quoted_identifier] = ACTIONS(9143),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9143),
    [sym_integer] = ACTIONS(9141),
    [sym_continue_as_identifier] = ACTIONS(9143),
    [sym_preproc_open] = ACTIONS(9143),
    [sym_preproc_close] = ACTIONS(9143),
  },
  [STATE(3392)] = {
    [sym_identifier] = ACTIONS(9145),
    [anon_sym_DASH] = ACTIONS(9147),
    [aux_sym_boolean_token1] = ACTIONS(9145),
    [aux_sym_boolean_token2] = ACTIONS(9145),
    [sym_decimal] = ACTIONS(9145),
    [anon_sym_LPAREN] = ACTIONS(9147),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9145),
    [anon_sym_LBRACK] = ACTIONS(9147),
    [aux_sym_record_type_token1] = ACTIONS(9145),
    [aux_sym_basic_type_token21] = ACTIONS(9145),
    [aux_sym_basic_type_token22] = ACTIONS(9145),
    [aux_sym_basic_type_token48] = ACTIONS(9145),
    [anon_sym_POUNDif] = ACTIONS(9147),
    [anon_sym_POUNDIF] = ACTIONS(9147),
    [anon_sym_POUNDIf] = ACTIONS(9147),
    [anon_sym_not] = ACTIONS(9145),
    [anon_sym_NOT] = ACTIONS(9145),
    [anon_sym_Not] = ACTIONS(9145),
    [anon_sym_POUNDelif] = ACTIONS(9147),
    [anon_sym_POUNDELIF] = ACTIONS(9147),
    [anon_sym_POUNDElif] = ACTIONS(9147),
    [anon_sym_POUNDelse] = ACTIONS(9147),
    [anon_sym_POUNDELSE] = ACTIONS(9147),
    [anon_sym_POUNDElse] = ACTIONS(9147),
    [anon_sym_POUNDendif] = ACTIONS(9147),
    [anon_sym_POUNDENDIF] = ACTIONS(9147),
    [anon_sym_POUNDEndif] = ACTIONS(9147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9145),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9145),
    [anon_sym_PLUS] = ACTIONS(9147),
    [sym_datetime_literal] = ACTIONS(9147),
    [sym_date_literal] = ACTIONS(9145),
    [sym_time_literal] = ACTIONS(9145),
    [sym_biginteger_literal] = ACTIONS(9147),
    [anon_sym_else] = ACTIONS(9145),
    [anon_sym_ELSE] = ACTIONS(9145),
    [anon_sym_Else] = ACTIONS(9145),
    [sym_page_keyword] = ACTIONS(9145),
    [anon_sym_codeunit] = ACTIONS(9145),
    [anon_sym_CODEUNIT] = ACTIONS(9145),
    [anon_sym_Codeunit] = ACTIONS(9145),
    [anon_sym_CodeUnit] = ACTIONS(9145),
    [anon_sym_COdeunit] = ACTIONS(9145),
    [anon_sym_codeUnit] = ACTIONS(9145),
    [sym_report_keyword] = ACTIONS(9145),
    [sym_query_keyword] = ACTIONS(9145),
    [anon_sym_xmlport] = ACTIONS(9145),
    [anon_sym_XMLPORT] = ACTIONS(9145),
    [anon_sym_Xmlport] = ACTIONS(9145),
    [anon_sym_XMLport] = ACTIONS(9145),
    [anon_sym_XMLPort] = ACTIONS(9145),
    [anon_sym_XmlPort] = ACTIONS(9145),
    [anon_sym_enum] = ACTIONS(9145),
    [anon_sym_ENUM] = ACTIONS(9145),
    [anon_sym_Enum] = ACTIONS(9145),
    [anon_sym_eNUM] = ACTIONS(9145),
    [anon_sym_eNum] = ACTIONS(9145),
    [anon_sym_ENum] = ACTIONS(9145),
    [sym_quoted_identifier] = ACTIONS(9147),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9147),
    [sym_integer] = ACTIONS(9145),
    [sym_continue_as_identifier] = ACTIONS(9147),
    [sym_preproc_open] = ACTIONS(9147),
    [sym_preproc_close] = ACTIONS(9147),
  },
  [STATE(3393)] = {
    [sym_identifier] = ACTIONS(9149),
    [anon_sym_DASH] = ACTIONS(9151),
    [aux_sym_boolean_token1] = ACTIONS(9149),
    [aux_sym_boolean_token2] = ACTIONS(9149),
    [sym_decimal] = ACTIONS(9149),
    [anon_sym_LPAREN] = ACTIONS(9151),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9149),
    [anon_sym_LBRACK] = ACTIONS(9151),
    [aux_sym_record_type_token1] = ACTIONS(9149),
    [aux_sym_basic_type_token21] = ACTIONS(9149),
    [aux_sym_basic_type_token22] = ACTIONS(9149),
    [aux_sym_basic_type_token48] = ACTIONS(9149),
    [anon_sym_POUNDif] = ACTIONS(9151),
    [anon_sym_POUNDIF] = ACTIONS(9151),
    [anon_sym_POUNDIf] = ACTIONS(9151),
    [anon_sym_not] = ACTIONS(9149),
    [anon_sym_NOT] = ACTIONS(9149),
    [anon_sym_Not] = ACTIONS(9149),
    [anon_sym_POUNDelif] = ACTIONS(9151),
    [anon_sym_POUNDELIF] = ACTIONS(9151),
    [anon_sym_POUNDElif] = ACTIONS(9151),
    [anon_sym_POUNDelse] = ACTIONS(9151),
    [anon_sym_POUNDELSE] = ACTIONS(9151),
    [anon_sym_POUNDElse] = ACTIONS(9151),
    [anon_sym_POUNDendif] = ACTIONS(9151),
    [anon_sym_POUNDENDIF] = ACTIONS(9151),
    [anon_sym_POUNDEndif] = ACTIONS(9151),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9149),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9149),
    [anon_sym_PLUS] = ACTIONS(9151),
    [sym_datetime_literal] = ACTIONS(9151),
    [sym_date_literal] = ACTIONS(9149),
    [sym_time_literal] = ACTIONS(9149),
    [sym_biginteger_literal] = ACTIONS(9151),
    [anon_sym_else] = ACTIONS(9149),
    [anon_sym_ELSE] = ACTIONS(9149),
    [anon_sym_Else] = ACTIONS(9149),
    [sym_page_keyword] = ACTIONS(9149),
    [anon_sym_codeunit] = ACTIONS(9149),
    [anon_sym_CODEUNIT] = ACTIONS(9149),
    [anon_sym_Codeunit] = ACTIONS(9149),
    [anon_sym_CodeUnit] = ACTIONS(9149),
    [anon_sym_COdeunit] = ACTIONS(9149),
    [anon_sym_codeUnit] = ACTIONS(9149),
    [sym_report_keyword] = ACTIONS(9149),
    [sym_query_keyword] = ACTIONS(9149),
    [anon_sym_xmlport] = ACTIONS(9149),
    [anon_sym_XMLPORT] = ACTIONS(9149),
    [anon_sym_Xmlport] = ACTIONS(9149),
    [anon_sym_XMLport] = ACTIONS(9149),
    [anon_sym_XMLPort] = ACTIONS(9149),
    [anon_sym_XmlPort] = ACTIONS(9149),
    [anon_sym_enum] = ACTIONS(9149),
    [anon_sym_ENUM] = ACTIONS(9149),
    [anon_sym_Enum] = ACTIONS(9149),
    [anon_sym_eNUM] = ACTIONS(9149),
    [anon_sym_eNum] = ACTIONS(9149),
    [anon_sym_ENum] = ACTIONS(9149),
    [sym_quoted_identifier] = ACTIONS(9151),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9151),
    [sym_integer] = ACTIONS(9149),
    [sym_continue_as_identifier] = ACTIONS(9151),
    [sym_preproc_open] = ACTIONS(9151),
    [sym_preproc_close] = ACTIONS(9151),
  },
  [STATE(3394)] = {
    [sym_identifier] = ACTIONS(9145),
    [anon_sym_DASH] = ACTIONS(9147),
    [aux_sym_boolean_token1] = ACTIONS(9145),
    [aux_sym_boolean_token2] = ACTIONS(9145),
    [sym_decimal] = ACTIONS(9145),
    [anon_sym_LPAREN] = ACTIONS(9147),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9145),
    [anon_sym_LBRACK] = ACTIONS(9147),
    [aux_sym_record_type_token1] = ACTIONS(9145),
    [aux_sym_basic_type_token21] = ACTIONS(9145),
    [aux_sym_basic_type_token22] = ACTIONS(9145),
    [aux_sym_basic_type_token48] = ACTIONS(9145),
    [anon_sym_POUNDif] = ACTIONS(9147),
    [anon_sym_POUNDIF] = ACTIONS(9147),
    [anon_sym_POUNDIf] = ACTIONS(9147),
    [anon_sym_not] = ACTIONS(9145),
    [anon_sym_NOT] = ACTIONS(9145),
    [anon_sym_Not] = ACTIONS(9145),
    [anon_sym_POUNDelif] = ACTIONS(9147),
    [anon_sym_POUNDELIF] = ACTIONS(9147),
    [anon_sym_POUNDElif] = ACTIONS(9147),
    [anon_sym_POUNDelse] = ACTIONS(9147),
    [anon_sym_POUNDELSE] = ACTIONS(9147),
    [anon_sym_POUNDElse] = ACTIONS(9147),
    [anon_sym_POUNDendif] = ACTIONS(9147),
    [anon_sym_POUNDENDIF] = ACTIONS(9147),
    [anon_sym_POUNDEndif] = ACTIONS(9147),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9145),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9145),
    [anon_sym_PLUS] = ACTIONS(9147),
    [sym_datetime_literal] = ACTIONS(9147),
    [sym_date_literal] = ACTIONS(9145),
    [sym_time_literal] = ACTIONS(9145),
    [sym_biginteger_literal] = ACTIONS(9147),
    [anon_sym_else] = ACTIONS(9145),
    [anon_sym_ELSE] = ACTIONS(9145),
    [anon_sym_Else] = ACTIONS(9145),
    [sym_page_keyword] = ACTIONS(9145),
    [anon_sym_codeunit] = ACTIONS(9145),
    [anon_sym_CODEUNIT] = ACTIONS(9145),
    [anon_sym_Codeunit] = ACTIONS(9145),
    [anon_sym_CodeUnit] = ACTIONS(9145),
    [anon_sym_COdeunit] = ACTIONS(9145),
    [anon_sym_codeUnit] = ACTIONS(9145),
    [sym_report_keyword] = ACTIONS(9145),
    [sym_query_keyword] = ACTIONS(9145),
    [anon_sym_xmlport] = ACTIONS(9145),
    [anon_sym_XMLPORT] = ACTIONS(9145),
    [anon_sym_Xmlport] = ACTIONS(9145),
    [anon_sym_XMLport] = ACTIONS(9145),
    [anon_sym_XMLPort] = ACTIONS(9145),
    [anon_sym_XmlPort] = ACTIONS(9145),
    [anon_sym_enum] = ACTIONS(9145),
    [anon_sym_ENUM] = ACTIONS(9145),
    [anon_sym_Enum] = ACTIONS(9145),
    [anon_sym_eNUM] = ACTIONS(9145),
    [anon_sym_eNum] = ACTIONS(9145),
    [anon_sym_ENum] = ACTIONS(9145),
    [sym_quoted_identifier] = ACTIONS(9147),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9147),
    [sym_integer] = ACTIONS(9145),
    [sym_continue_as_identifier] = ACTIONS(9147),
    [sym_preproc_open] = ACTIONS(9147),
    [sym_preproc_close] = ACTIONS(9147),
  },
  [STATE(3395)] = {
    [sym_identifier] = ACTIONS(9153),
    [anon_sym_DASH] = ACTIONS(9155),
    [aux_sym_boolean_token1] = ACTIONS(9153),
    [aux_sym_boolean_token2] = ACTIONS(9153),
    [sym_decimal] = ACTIONS(9153),
    [anon_sym_LPAREN] = ACTIONS(9155),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9153),
    [anon_sym_LBRACK] = ACTIONS(9155),
    [aux_sym_record_type_token1] = ACTIONS(9153),
    [aux_sym_basic_type_token21] = ACTIONS(9153),
    [aux_sym_basic_type_token22] = ACTIONS(9153),
    [aux_sym_basic_type_token48] = ACTIONS(9153),
    [anon_sym_POUNDif] = ACTIONS(9155),
    [anon_sym_POUNDIF] = ACTIONS(9155),
    [anon_sym_POUNDIf] = ACTIONS(9155),
    [anon_sym_not] = ACTIONS(9153),
    [anon_sym_NOT] = ACTIONS(9153),
    [anon_sym_Not] = ACTIONS(9153),
    [anon_sym_POUNDelif] = ACTIONS(9155),
    [anon_sym_POUNDELIF] = ACTIONS(9155),
    [anon_sym_POUNDElif] = ACTIONS(9155),
    [anon_sym_POUNDelse] = ACTIONS(9155),
    [anon_sym_POUNDELSE] = ACTIONS(9155),
    [anon_sym_POUNDElse] = ACTIONS(9155),
    [anon_sym_POUNDendif] = ACTIONS(9155),
    [anon_sym_POUNDENDIF] = ACTIONS(9155),
    [anon_sym_POUNDEndif] = ACTIONS(9155),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9153),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9153),
    [anon_sym_PLUS] = ACTIONS(9155),
    [sym_datetime_literal] = ACTIONS(9155),
    [sym_date_literal] = ACTIONS(9153),
    [sym_time_literal] = ACTIONS(9153),
    [sym_biginteger_literal] = ACTIONS(9155),
    [anon_sym_else] = ACTIONS(9153),
    [anon_sym_ELSE] = ACTIONS(9153),
    [anon_sym_Else] = ACTIONS(9153),
    [sym_page_keyword] = ACTIONS(9153),
    [anon_sym_codeunit] = ACTIONS(9153),
    [anon_sym_CODEUNIT] = ACTIONS(9153),
    [anon_sym_Codeunit] = ACTIONS(9153),
    [anon_sym_CodeUnit] = ACTIONS(9153),
    [anon_sym_COdeunit] = ACTIONS(9153),
    [anon_sym_codeUnit] = ACTIONS(9153),
    [sym_report_keyword] = ACTIONS(9153),
    [sym_query_keyword] = ACTIONS(9153),
    [anon_sym_xmlport] = ACTIONS(9153),
    [anon_sym_XMLPORT] = ACTIONS(9153),
    [anon_sym_Xmlport] = ACTIONS(9153),
    [anon_sym_XMLport] = ACTIONS(9153),
    [anon_sym_XMLPort] = ACTIONS(9153),
    [anon_sym_XmlPort] = ACTIONS(9153),
    [anon_sym_enum] = ACTIONS(9153),
    [anon_sym_ENUM] = ACTIONS(9153),
    [anon_sym_Enum] = ACTIONS(9153),
    [anon_sym_eNUM] = ACTIONS(9153),
    [anon_sym_eNum] = ACTIONS(9153),
    [anon_sym_ENum] = ACTIONS(9153),
    [sym_quoted_identifier] = ACTIONS(9155),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9155),
    [sym_integer] = ACTIONS(9153),
    [sym_continue_as_identifier] = ACTIONS(9155),
    [sym_preproc_open] = ACTIONS(9155),
    [sym_preproc_close] = ACTIONS(9155),
  },
  [STATE(3396)] = {
    [sym_preproc_conditional_controladdin] = STATE(3430),
    [sym__body_element] = STATE(3430),
    [sym_empty_statement] = STATE(3430),
    [sym_property] = STATE(3430),
    [sym_fields_section] = STATE(3430),
    [sym_keys_section] = STATE(3430),
    [sym_fieldgroups_section] = STATE(3430),
    [sym_enum_value_declaration] = STATE(3430),
    [sym_labels_section] = STATE(3430),
    [sym_layout_section] = STATE(3430),
    [sym_modify_modification] = STATE(3430),
    [sym_actions_section] = STATE(3430),
    [sym_views_section] = STATE(3430),
    [sym_dataset_section] = STATE(3430),
    [sym_requestpage_section] = STATE(3430),
    [sym_rendering_section] = STATE(3430),
    [sym_elements_section] = STATE(3430),
    [sym_schema_section] = STATE(3430),
    [sym_assembly_declaration] = STATE(3430),
    [sym_event_declaration] = STATE(3430),
    [sym_procedure] = STATE(3430),
    [sym_preproc_split_procedure] = STATE(3430),
    [sym_interface_procedure] = STATE(3430),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3430),
    [sym_var_section] = STATE(3430),
    [sym_attribute_item] = STATE(3430),
    [sym_preproc_conditional] = STATE(3430),
    [sym_preproc_if] = STATE(2635),
    [sym_preproc_endif] = STATE(6257),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3430),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3397)] = {
    [sym_identifier] = ACTIONS(9157),
    [anon_sym_DASH] = ACTIONS(9159),
    [aux_sym_boolean_token1] = ACTIONS(9157),
    [aux_sym_boolean_token2] = ACTIONS(9157),
    [sym_decimal] = ACTIONS(9157),
    [anon_sym_LPAREN] = ACTIONS(9159),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9157),
    [anon_sym_LBRACK] = ACTIONS(9159),
    [aux_sym_record_type_token1] = ACTIONS(9157),
    [aux_sym_basic_type_token21] = ACTIONS(9157),
    [aux_sym_basic_type_token22] = ACTIONS(9157),
    [aux_sym_basic_type_token48] = ACTIONS(9157),
    [anon_sym_POUNDif] = ACTIONS(9159),
    [anon_sym_POUNDIF] = ACTIONS(9159),
    [anon_sym_POUNDIf] = ACTIONS(9159),
    [anon_sym_not] = ACTIONS(9157),
    [anon_sym_NOT] = ACTIONS(9157),
    [anon_sym_Not] = ACTIONS(9157),
    [anon_sym_POUNDelif] = ACTIONS(9159),
    [anon_sym_POUNDELIF] = ACTIONS(9159),
    [anon_sym_POUNDElif] = ACTIONS(9159),
    [anon_sym_POUNDelse] = ACTIONS(9159),
    [anon_sym_POUNDELSE] = ACTIONS(9159),
    [anon_sym_POUNDElse] = ACTIONS(9159),
    [anon_sym_POUNDendif] = ACTIONS(9159),
    [anon_sym_POUNDENDIF] = ACTIONS(9159),
    [anon_sym_POUNDEndif] = ACTIONS(9159),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9157),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9157),
    [anon_sym_PLUS] = ACTIONS(9159),
    [sym_datetime_literal] = ACTIONS(9159),
    [sym_date_literal] = ACTIONS(9157),
    [sym_time_literal] = ACTIONS(9157),
    [sym_biginteger_literal] = ACTIONS(9159),
    [anon_sym_else] = ACTIONS(9157),
    [anon_sym_ELSE] = ACTIONS(9157),
    [anon_sym_Else] = ACTIONS(9157),
    [sym_page_keyword] = ACTIONS(9157),
    [anon_sym_codeunit] = ACTIONS(9157),
    [anon_sym_CODEUNIT] = ACTIONS(9157),
    [anon_sym_Codeunit] = ACTIONS(9157),
    [anon_sym_CodeUnit] = ACTIONS(9157),
    [anon_sym_COdeunit] = ACTIONS(9157),
    [anon_sym_codeUnit] = ACTIONS(9157),
    [sym_report_keyword] = ACTIONS(9157),
    [sym_query_keyword] = ACTIONS(9157),
    [anon_sym_xmlport] = ACTIONS(9157),
    [anon_sym_XMLPORT] = ACTIONS(9157),
    [anon_sym_Xmlport] = ACTIONS(9157),
    [anon_sym_XMLport] = ACTIONS(9157),
    [anon_sym_XMLPort] = ACTIONS(9157),
    [anon_sym_XmlPort] = ACTIONS(9157),
    [anon_sym_enum] = ACTIONS(9157),
    [anon_sym_ENUM] = ACTIONS(9157),
    [anon_sym_Enum] = ACTIONS(9157),
    [anon_sym_eNUM] = ACTIONS(9157),
    [anon_sym_eNum] = ACTIONS(9157),
    [anon_sym_ENum] = ACTIONS(9157),
    [sym_quoted_identifier] = ACTIONS(9159),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9159),
    [sym_integer] = ACTIONS(9157),
    [sym_continue_as_identifier] = ACTIONS(9159),
    [sym_preproc_open] = ACTIONS(9159),
    [sym_preproc_close] = ACTIONS(9159),
  },
  [STATE(3398)] = {
    [sym_identifier] = ACTIONS(9149),
    [anon_sym_DASH] = ACTIONS(9151),
    [aux_sym_boolean_token1] = ACTIONS(9149),
    [aux_sym_boolean_token2] = ACTIONS(9149),
    [sym_decimal] = ACTIONS(9149),
    [anon_sym_LPAREN] = ACTIONS(9151),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9149),
    [anon_sym_LBRACK] = ACTIONS(9151),
    [aux_sym_record_type_token1] = ACTIONS(9149),
    [aux_sym_basic_type_token21] = ACTIONS(9149),
    [aux_sym_basic_type_token22] = ACTIONS(9149),
    [aux_sym_basic_type_token48] = ACTIONS(9149),
    [anon_sym_POUNDif] = ACTIONS(9151),
    [anon_sym_POUNDIF] = ACTIONS(9151),
    [anon_sym_POUNDIf] = ACTIONS(9151),
    [anon_sym_not] = ACTIONS(9149),
    [anon_sym_NOT] = ACTIONS(9149),
    [anon_sym_Not] = ACTIONS(9149),
    [anon_sym_POUNDelif] = ACTIONS(9151),
    [anon_sym_POUNDELIF] = ACTIONS(9151),
    [anon_sym_POUNDElif] = ACTIONS(9151),
    [anon_sym_POUNDelse] = ACTIONS(9151),
    [anon_sym_POUNDELSE] = ACTIONS(9151),
    [anon_sym_POUNDElse] = ACTIONS(9151),
    [anon_sym_POUNDendif] = ACTIONS(9151),
    [anon_sym_POUNDENDIF] = ACTIONS(9151),
    [anon_sym_POUNDEndif] = ACTIONS(9151),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9149),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9149),
    [anon_sym_PLUS] = ACTIONS(9151),
    [sym_datetime_literal] = ACTIONS(9151),
    [sym_date_literal] = ACTIONS(9149),
    [sym_time_literal] = ACTIONS(9149),
    [sym_biginteger_literal] = ACTIONS(9151),
    [anon_sym_else] = ACTIONS(9149),
    [anon_sym_ELSE] = ACTIONS(9149),
    [anon_sym_Else] = ACTIONS(9149),
    [sym_page_keyword] = ACTIONS(9149),
    [anon_sym_codeunit] = ACTIONS(9149),
    [anon_sym_CODEUNIT] = ACTIONS(9149),
    [anon_sym_Codeunit] = ACTIONS(9149),
    [anon_sym_CodeUnit] = ACTIONS(9149),
    [anon_sym_COdeunit] = ACTIONS(9149),
    [anon_sym_codeUnit] = ACTIONS(9149),
    [sym_report_keyword] = ACTIONS(9149),
    [sym_query_keyword] = ACTIONS(9149),
    [anon_sym_xmlport] = ACTIONS(9149),
    [anon_sym_XMLPORT] = ACTIONS(9149),
    [anon_sym_Xmlport] = ACTIONS(9149),
    [anon_sym_XMLport] = ACTIONS(9149),
    [anon_sym_XMLPort] = ACTIONS(9149),
    [anon_sym_XmlPort] = ACTIONS(9149),
    [anon_sym_enum] = ACTIONS(9149),
    [anon_sym_ENUM] = ACTIONS(9149),
    [anon_sym_Enum] = ACTIONS(9149),
    [anon_sym_eNUM] = ACTIONS(9149),
    [anon_sym_eNum] = ACTIONS(9149),
    [anon_sym_ENum] = ACTIONS(9149),
    [sym_quoted_identifier] = ACTIONS(9151),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9151),
    [sym_integer] = ACTIONS(9149),
    [sym_continue_as_identifier] = ACTIONS(9151),
    [sym_preproc_open] = ACTIONS(9151),
    [sym_preproc_close] = ACTIONS(9151),
  },
  [STATE(3399)] = {
    [sym_identifier] = ACTIONS(9157),
    [anon_sym_DASH] = ACTIONS(9159),
    [aux_sym_boolean_token1] = ACTIONS(9157),
    [aux_sym_boolean_token2] = ACTIONS(9157),
    [sym_decimal] = ACTIONS(9157),
    [anon_sym_LPAREN] = ACTIONS(9159),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9157),
    [anon_sym_LBRACK] = ACTIONS(9159),
    [aux_sym_record_type_token1] = ACTIONS(9157),
    [aux_sym_basic_type_token21] = ACTIONS(9157),
    [aux_sym_basic_type_token22] = ACTIONS(9157),
    [aux_sym_basic_type_token48] = ACTIONS(9157),
    [anon_sym_POUNDif] = ACTIONS(9159),
    [anon_sym_POUNDIF] = ACTIONS(9159),
    [anon_sym_POUNDIf] = ACTIONS(9159),
    [anon_sym_not] = ACTIONS(9157),
    [anon_sym_NOT] = ACTIONS(9157),
    [anon_sym_Not] = ACTIONS(9157),
    [anon_sym_POUNDelif] = ACTIONS(9159),
    [anon_sym_POUNDELIF] = ACTIONS(9159),
    [anon_sym_POUNDElif] = ACTIONS(9159),
    [anon_sym_POUNDelse] = ACTIONS(9159),
    [anon_sym_POUNDELSE] = ACTIONS(9159),
    [anon_sym_POUNDElse] = ACTIONS(9159),
    [anon_sym_POUNDendif] = ACTIONS(9159),
    [anon_sym_POUNDENDIF] = ACTIONS(9159),
    [anon_sym_POUNDEndif] = ACTIONS(9159),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9157),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9157),
    [anon_sym_PLUS] = ACTIONS(9159),
    [sym_datetime_literal] = ACTIONS(9159),
    [sym_date_literal] = ACTIONS(9157),
    [sym_time_literal] = ACTIONS(9157),
    [sym_biginteger_literal] = ACTIONS(9159),
    [anon_sym_else] = ACTIONS(9157),
    [anon_sym_ELSE] = ACTIONS(9157),
    [anon_sym_Else] = ACTIONS(9157),
    [sym_page_keyword] = ACTIONS(9157),
    [anon_sym_codeunit] = ACTIONS(9157),
    [anon_sym_CODEUNIT] = ACTIONS(9157),
    [anon_sym_Codeunit] = ACTIONS(9157),
    [anon_sym_CodeUnit] = ACTIONS(9157),
    [anon_sym_COdeunit] = ACTIONS(9157),
    [anon_sym_codeUnit] = ACTIONS(9157),
    [sym_report_keyword] = ACTIONS(9157),
    [sym_query_keyword] = ACTIONS(9157),
    [anon_sym_xmlport] = ACTIONS(9157),
    [anon_sym_XMLPORT] = ACTIONS(9157),
    [anon_sym_Xmlport] = ACTIONS(9157),
    [anon_sym_XMLport] = ACTIONS(9157),
    [anon_sym_XMLPort] = ACTIONS(9157),
    [anon_sym_XmlPort] = ACTIONS(9157),
    [anon_sym_enum] = ACTIONS(9157),
    [anon_sym_ENUM] = ACTIONS(9157),
    [anon_sym_Enum] = ACTIONS(9157),
    [anon_sym_eNUM] = ACTIONS(9157),
    [anon_sym_eNum] = ACTIONS(9157),
    [anon_sym_ENum] = ACTIONS(9157),
    [sym_quoted_identifier] = ACTIONS(9159),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9159),
    [sym_integer] = ACTIONS(9157),
    [sym_continue_as_identifier] = ACTIONS(9159),
    [sym_preproc_open] = ACTIONS(9159),
    [sym_preproc_close] = ACTIONS(9159),
  },
  [STATE(3400)] = {
    [sym_identifier] = ACTIONS(9161),
    [anon_sym_DASH] = ACTIONS(9163),
    [aux_sym_boolean_token1] = ACTIONS(9161),
    [aux_sym_boolean_token2] = ACTIONS(9161),
    [sym_decimal] = ACTIONS(9161),
    [anon_sym_LPAREN] = ACTIONS(9163),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9161),
    [anon_sym_LBRACK] = ACTIONS(9163),
    [aux_sym_record_type_token1] = ACTIONS(9161),
    [aux_sym_basic_type_token21] = ACTIONS(9161),
    [aux_sym_basic_type_token22] = ACTIONS(9161),
    [aux_sym_basic_type_token48] = ACTIONS(9161),
    [anon_sym_POUNDif] = ACTIONS(9163),
    [anon_sym_POUNDIF] = ACTIONS(9163),
    [anon_sym_POUNDIf] = ACTIONS(9163),
    [anon_sym_not] = ACTIONS(9161),
    [anon_sym_NOT] = ACTIONS(9161),
    [anon_sym_Not] = ACTIONS(9161),
    [anon_sym_POUNDelif] = ACTIONS(9163),
    [anon_sym_POUNDELIF] = ACTIONS(9163),
    [anon_sym_POUNDElif] = ACTIONS(9163),
    [anon_sym_POUNDelse] = ACTIONS(9163),
    [anon_sym_POUNDELSE] = ACTIONS(9163),
    [anon_sym_POUNDElse] = ACTIONS(9163),
    [anon_sym_POUNDendif] = ACTIONS(9163),
    [anon_sym_POUNDENDIF] = ACTIONS(9163),
    [anon_sym_POUNDEndif] = ACTIONS(9163),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9161),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9161),
    [anon_sym_PLUS] = ACTIONS(9163),
    [sym_datetime_literal] = ACTIONS(9163),
    [sym_date_literal] = ACTIONS(9161),
    [sym_time_literal] = ACTIONS(9161),
    [sym_biginteger_literal] = ACTIONS(9163),
    [anon_sym_else] = ACTIONS(9161),
    [anon_sym_ELSE] = ACTIONS(9161),
    [anon_sym_Else] = ACTIONS(9161),
    [sym_page_keyword] = ACTIONS(9161),
    [anon_sym_codeunit] = ACTIONS(9161),
    [anon_sym_CODEUNIT] = ACTIONS(9161),
    [anon_sym_Codeunit] = ACTIONS(9161),
    [anon_sym_CodeUnit] = ACTIONS(9161),
    [anon_sym_COdeunit] = ACTIONS(9161),
    [anon_sym_codeUnit] = ACTIONS(9161),
    [sym_report_keyword] = ACTIONS(9161),
    [sym_query_keyword] = ACTIONS(9161),
    [anon_sym_xmlport] = ACTIONS(9161),
    [anon_sym_XMLPORT] = ACTIONS(9161),
    [anon_sym_Xmlport] = ACTIONS(9161),
    [anon_sym_XMLport] = ACTIONS(9161),
    [anon_sym_XMLPort] = ACTIONS(9161),
    [anon_sym_XmlPort] = ACTIONS(9161),
    [anon_sym_enum] = ACTIONS(9161),
    [anon_sym_ENUM] = ACTIONS(9161),
    [anon_sym_Enum] = ACTIONS(9161),
    [anon_sym_eNUM] = ACTIONS(9161),
    [anon_sym_eNum] = ACTIONS(9161),
    [anon_sym_ENum] = ACTIONS(9161),
    [sym_quoted_identifier] = ACTIONS(9163),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9163),
    [sym_integer] = ACTIONS(9161),
    [sym_continue_as_identifier] = ACTIONS(9163),
    [sym_preproc_open] = ACTIONS(9163),
    [sym_preproc_close] = ACTIONS(9163),
  },
  [STATE(3401)] = {
    [sym_identifier] = ACTIONS(9165),
    [anon_sym_DASH] = ACTIONS(9167),
    [aux_sym_boolean_token1] = ACTIONS(9165),
    [aux_sym_boolean_token2] = ACTIONS(9165),
    [sym_decimal] = ACTIONS(9165),
    [anon_sym_LPAREN] = ACTIONS(9167),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9165),
    [anon_sym_LBRACK] = ACTIONS(9167),
    [aux_sym_record_type_token1] = ACTIONS(9165),
    [aux_sym_basic_type_token21] = ACTIONS(9165),
    [aux_sym_basic_type_token22] = ACTIONS(9165),
    [aux_sym_basic_type_token48] = ACTIONS(9165),
    [anon_sym_POUNDif] = ACTIONS(9167),
    [anon_sym_POUNDIF] = ACTIONS(9167),
    [anon_sym_POUNDIf] = ACTIONS(9167),
    [anon_sym_not] = ACTIONS(9165),
    [anon_sym_NOT] = ACTIONS(9165),
    [anon_sym_Not] = ACTIONS(9165),
    [anon_sym_POUNDelif] = ACTIONS(9167),
    [anon_sym_POUNDELIF] = ACTIONS(9167),
    [anon_sym_POUNDElif] = ACTIONS(9167),
    [anon_sym_POUNDelse] = ACTIONS(9167),
    [anon_sym_POUNDELSE] = ACTIONS(9167),
    [anon_sym_POUNDElse] = ACTIONS(9167),
    [anon_sym_POUNDendif] = ACTIONS(9167),
    [anon_sym_POUNDENDIF] = ACTIONS(9167),
    [anon_sym_POUNDEndif] = ACTIONS(9167),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9165),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9165),
    [anon_sym_PLUS] = ACTIONS(9167),
    [sym_datetime_literal] = ACTIONS(9167),
    [sym_date_literal] = ACTIONS(9165),
    [sym_time_literal] = ACTIONS(9165),
    [sym_biginteger_literal] = ACTIONS(9167),
    [anon_sym_else] = ACTIONS(9165),
    [anon_sym_ELSE] = ACTIONS(9165),
    [anon_sym_Else] = ACTIONS(9165),
    [sym_page_keyword] = ACTIONS(9165),
    [anon_sym_codeunit] = ACTIONS(9165),
    [anon_sym_CODEUNIT] = ACTIONS(9165),
    [anon_sym_Codeunit] = ACTIONS(9165),
    [anon_sym_CodeUnit] = ACTIONS(9165),
    [anon_sym_COdeunit] = ACTIONS(9165),
    [anon_sym_codeUnit] = ACTIONS(9165),
    [sym_report_keyword] = ACTIONS(9165),
    [sym_query_keyword] = ACTIONS(9165),
    [anon_sym_xmlport] = ACTIONS(9165),
    [anon_sym_XMLPORT] = ACTIONS(9165),
    [anon_sym_Xmlport] = ACTIONS(9165),
    [anon_sym_XMLport] = ACTIONS(9165),
    [anon_sym_XMLPort] = ACTIONS(9165),
    [anon_sym_XmlPort] = ACTIONS(9165),
    [anon_sym_enum] = ACTIONS(9165),
    [anon_sym_ENUM] = ACTIONS(9165),
    [anon_sym_Enum] = ACTIONS(9165),
    [anon_sym_eNUM] = ACTIONS(9165),
    [anon_sym_eNum] = ACTIONS(9165),
    [anon_sym_ENum] = ACTIONS(9165),
    [sym_quoted_identifier] = ACTIONS(9167),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9167),
    [sym_integer] = ACTIONS(9165),
    [sym_continue_as_identifier] = ACTIONS(9167),
    [sym_preproc_open] = ACTIONS(9167),
    [sym_preproc_close] = ACTIONS(9167),
  },
  [STATE(3402)] = {
    [sym_boolean] = STATE(8393),
    [sym_option_member] = STATE(8402),
    [sym_keyword_identifier] = STATE(8393),
    [sym_codeunit_keyword] = STATE(8512),
    [sym_xmlport_keyword] = STATE(8512),
    [sym_enum_keyword] = STATE(8512),
    [sym_keyword_as_identifier] = STATE(8393),
    [sym_identifier] = ACTIONS(9054),
    [anon_sym_SEMI] = ACTIONS(389),
    [anon_sym_COMMA] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(9058),
    [aux_sym_boolean_token1] = ACTIONS(9060),
    [aux_sym_boolean_token2] = ACTIONS(9060),
    [aux_sym_where_condition_token1] = ACTIONS(3060),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9062),
    [aux_sym_record_type_token1] = ACTIONS(9062),
    [aux_sym_basic_type_token21] = ACTIONS(9062),
    [aux_sym_basic_type_token22] = ACTIONS(9064),
    [aux_sym_basic_type_token48] = ACTIONS(9062),
    [aux_sym_basic_type_token53] = ACTIONS(3060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3060),
    [aux_sym_separator_action_token1] = ACTIONS(3060),
    [aux_sym_type_declaration_token1] = ACTIONS(3060),
    [anon_sym_POUNDelif] = ACTIONS(389),
    [anon_sym_POUNDELIF] = ACTIONS(389),
    [anon_sym_POUNDElif] = ACTIONS(389),
    [anon_sym_POUNDelse] = ACTIONS(389),
    [anon_sym_POUNDELSE] = ACTIONS(389),
    [anon_sym_POUNDElse] = ACTIONS(389),
    [anon_sym_POUNDendif] = ACTIONS(389),
    [anon_sym_POUNDENDIF] = ACTIONS(389),
    [anon_sym_POUNDEndif] = ACTIONS(389),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9062),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9062),
    [sym_page_keyword] = ACTIONS(9062),
    [anon_sym_codeunit] = ACTIONS(9066),
    [anon_sym_CODEUNIT] = ACTIONS(9066),
    [anon_sym_Codeunit] = ACTIONS(9066),
    [anon_sym_CodeUnit] = ACTIONS(9066),
    [anon_sym_COdeunit] = ACTIONS(9066),
    [anon_sym_codeUnit] = ACTIONS(9066),
    [sym_report_keyword] = ACTIONS(9062),
    [sym_query_keyword] = ACTIONS(9062),
    [anon_sym_xmlport] = ACTIONS(9068),
    [anon_sym_XMLPORT] = ACTIONS(9068),
    [anon_sym_Xmlport] = ACTIONS(9068),
    [anon_sym_XMLport] = ACTIONS(9068),
    [anon_sym_XMLPort] = ACTIONS(9068),
    [anon_sym_XmlPort] = ACTIONS(9068),
    [anon_sym_enum] = ACTIONS(9070),
    [anon_sym_ENUM] = ACTIONS(9070),
    [anon_sym_Enum] = ACTIONS(9070),
    [anon_sym_eNUM] = ACTIONS(9070),
    [anon_sym_eNum] = ACTIONS(9070),
    [anon_sym_ENum] = ACTIONS(9070),
    [sym_local_keyword] = ACTIONS(9054),
    [sym_internal_keyword] = ACTIONS(9054),
    [sym_protected_keyword] = ACTIONS(9054),
    [sym_key_keyword] = ACTIONS(3060),
    [sym_dataset_keyword] = ACTIONS(3060),
    [sym_quoted_identifier] = ACTIONS(9072),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9072),
    [sym_integer] = ACTIONS(9072),
    [sym_preproc_close] = ACTIONS(389),
  },
  [STATE(3403)] = {
    [sym__layout_element] = STATE(3852),
    [sym_area_section] = STATE(3852),
    [sym_group_section] = STATE(3852),
    [sym_repeater_section] = STATE(3852),
    [sym_cuegroup_section] = STATE(3852),
    [sym_fixed_section] = STATE(3852),
    [sym_grid_section] = STATE(3852),
    [sym_page_field] = STATE(3852),
    [sym_part_section] = STATE(3852),
    [sym_systempart_section] = STATE(3852),
    [sym_usercontrol_section] = STATE(3852),
    [sym_preproc_split_field] = STATE(3852),
    [sym_label_section] = STATE(3852),
    [sym_addfirst_modification] = STATE(3852),
    [sym_addlast_modification] = STATE(3852),
    [sym_addafter_modification] = STATE(3852),
    [sym_addbefore_modification] = STATE(3852),
    [sym_modify_modification] = STATE(3852),
    [sym_movefirst_modification] = STATE(3852),
    [sym_movelast_modification] = STATE(3852),
    [sym_moveafter_modification] = STATE(3852),
    [sym_movebefore_modification] = STATE(3852),
    [sym_preproc_if] = STATE(3384),
    [sym_preproc_elif] = STATE(3879),
    [sym_preproc_else] = STATE(4692),
    [sym_preproc_endif] = STATE(7125),
    [sym_preproc_conditional_layout] = STATE(3852),
    [aux_sym_layout_section_repeat1] = STATE(3852),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7933),
    [anon_sym_RBRACE] = ACTIONS(9169),
    [aux_sym_where_condition_token1] = ACTIONS(9171),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [aux_sym_basic_type_token6] = ACTIONS(9089),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(9091),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [anon_sym_POUNDif] = ACTIONS(9093),
    [anon_sym_POUNDIF] = ACTIONS(9093),
    [anon_sym_POUNDIf] = ACTIONS(9093),
    [anon_sym_POUNDelif] = ACTIONS(9095),
    [anon_sym_POUNDELIF] = ACTIONS(9095),
    [anon_sym_POUNDElif] = ACTIONS(9095),
    [anon_sym_POUNDelse] = ACTIONS(9097),
    [anon_sym_POUNDELSE] = ACTIONS(9097),
    [anon_sym_POUNDElse] = ACTIONS(9097),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9093),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(3404)] = {
    [sym__layout_element] = STATE(3852),
    [sym_area_section] = STATE(3852),
    [sym_group_section] = STATE(3852),
    [sym_repeater_section] = STATE(3852),
    [sym_cuegroup_section] = STATE(3852),
    [sym_fixed_section] = STATE(3852),
    [sym_grid_section] = STATE(3852),
    [sym_page_field] = STATE(3852),
    [sym_part_section] = STATE(3852),
    [sym_systempart_section] = STATE(3852),
    [sym_usercontrol_section] = STATE(3852),
    [sym_preproc_split_field] = STATE(3852),
    [sym_label_section] = STATE(3852),
    [sym_addfirst_modification] = STATE(3852),
    [sym_addlast_modification] = STATE(3852),
    [sym_addafter_modification] = STATE(3852),
    [sym_addbefore_modification] = STATE(3852),
    [sym_modify_modification] = STATE(3852),
    [sym_movefirst_modification] = STATE(3852),
    [sym_movelast_modification] = STATE(3852),
    [sym_moveafter_modification] = STATE(3852),
    [sym_movebefore_modification] = STATE(3852),
    [sym_preproc_if] = STATE(3384),
    [sym_preproc_elif] = STATE(3879),
    [sym_preproc_else] = STATE(4692),
    [sym_preproc_endif] = STATE(7125),
    [sym_preproc_conditional_layout] = STATE(3852),
    [aux_sym_layout_section_repeat1] = STATE(3852),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7933),
    [anon_sym_RBRACE] = ACTIONS(9173),
    [aux_sym_where_condition_token1] = ACTIONS(9171),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [aux_sym_basic_type_token6] = ACTIONS(9089),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(9091),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [anon_sym_POUNDif] = ACTIONS(9093),
    [anon_sym_POUNDIF] = ACTIONS(9093),
    [anon_sym_POUNDIf] = ACTIONS(9093),
    [anon_sym_POUNDelif] = ACTIONS(9095),
    [anon_sym_POUNDELIF] = ACTIONS(9095),
    [anon_sym_POUNDElif] = ACTIONS(9095),
    [anon_sym_POUNDelse] = ACTIONS(9097),
    [anon_sym_POUNDELSE] = ACTIONS(9097),
    [anon_sym_POUNDElse] = ACTIONS(9097),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9093),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(3405)] = {
    [sym__layout_element] = STATE(3852),
    [sym_area_section] = STATE(3852),
    [sym_group_section] = STATE(3852),
    [sym_repeater_section] = STATE(3852),
    [sym_cuegroup_section] = STATE(3852),
    [sym_fixed_section] = STATE(3852),
    [sym_grid_section] = STATE(3852),
    [sym_page_field] = STATE(3852),
    [sym_part_section] = STATE(3852),
    [sym_systempart_section] = STATE(3852),
    [sym_usercontrol_section] = STATE(3852),
    [sym_preproc_split_field] = STATE(3852),
    [sym_label_section] = STATE(3852),
    [sym_addfirst_modification] = STATE(3852),
    [sym_addlast_modification] = STATE(3852),
    [sym_addafter_modification] = STATE(3852),
    [sym_addbefore_modification] = STATE(3852),
    [sym_modify_modification] = STATE(3852),
    [sym_movefirst_modification] = STATE(3852),
    [sym_movelast_modification] = STATE(3852),
    [sym_moveafter_modification] = STATE(3852),
    [sym_movebefore_modification] = STATE(3852),
    [sym_preproc_if] = STATE(3384),
    [sym_preproc_elif] = STATE(3879),
    [sym_preproc_else] = STATE(4692),
    [sym_preproc_endif] = STATE(7125),
    [sym_preproc_conditional_layout] = STATE(3852),
    [aux_sym_layout_section_repeat1] = STATE(3852),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7933),
    [anon_sym_RBRACE] = ACTIONS(9175),
    [aux_sym_where_condition_token1] = ACTIONS(9171),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [aux_sym_basic_type_token6] = ACTIONS(9089),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(9091),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [anon_sym_POUNDif] = ACTIONS(9093),
    [anon_sym_POUNDIF] = ACTIONS(9093),
    [anon_sym_POUNDIf] = ACTIONS(9093),
    [anon_sym_POUNDelif] = ACTIONS(9095),
    [anon_sym_POUNDELIF] = ACTIONS(9095),
    [anon_sym_POUNDElif] = ACTIONS(9095),
    [anon_sym_POUNDelse] = ACTIONS(9097),
    [anon_sym_POUNDELSE] = ACTIONS(9097),
    [anon_sym_POUNDElse] = ACTIONS(9097),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9093),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(3406)] = {
    [sym__layout_element] = STATE(3852),
    [sym_area_section] = STATE(3852),
    [sym_group_section] = STATE(3852),
    [sym_repeater_section] = STATE(3852),
    [sym_cuegroup_section] = STATE(3852),
    [sym_fixed_section] = STATE(3852),
    [sym_grid_section] = STATE(3852),
    [sym_page_field] = STATE(3852),
    [sym_part_section] = STATE(3852),
    [sym_systempart_section] = STATE(3852),
    [sym_usercontrol_section] = STATE(3852),
    [sym_preproc_split_field] = STATE(3852),
    [sym_label_section] = STATE(3852),
    [sym_addfirst_modification] = STATE(3852),
    [sym_addlast_modification] = STATE(3852),
    [sym_addafter_modification] = STATE(3852),
    [sym_addbefore_modification] = STATE(3852),
    [sym_modify_modification] = STATE(3852),
    [sym_movefirst_modification] = STATE(3852),
    [sym_movelast_modification] = STATE(3852),
    [sym_moveafter_modification] = STATE(3852),
    [sym_movebefore_modification] = STATE(3852),
    [sym_preproc_if] = STATE(3384),
    [sym_preproc_elif] = STATE(3879),
    [sym_preproc_else] = STATE(4692),
    [sym_preproc_endif] = STATE(7125),
    [sym_preproc_conditional_layout] = STATE(3852),
    [aux_sym_layout_section_repeat1] = STATE(3852),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7933),
    [anon_sym_RBRACE] = ACTIONS(9177),
    [aux_sym_where_condition_token1] = ACTIONS(9171),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [aux_sym_basic_type_token6] = ACTIONS(9089),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(9091),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [anon_sym_POUNDif] = ACTIONS(9093),
    [anon_sym_POUNDIF] = ACTIONS(9093),
    [anon_sym_POUNDIf] = ACTIONS(9093),
    [anon_sym_POUNDelif] = ACTIONS(9095),
    [anon_sym_POUNDELIF] = ACTIONS(9095),
    [anon_sym_POUNDElif] = ACTIONS(9095),
    [anon_sym_POUNDelse] = ACTIONS(9097),
    [anon_sym_POUNDELSE] = ACTIONS(9097),
    [anon_sym_POUNDElse] = ACTIONS(9097),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9093),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(3407)] = {
    [sym__layout_element] = STATE(3446),
    [sym_area_section] = STATE(3446),
    [sym_group_section] = STATE(3446),
    [sym_repeater_section] = STATE(3446),
    [sym_cuegroup_section] = STATE(3446),
    [sym_fixed_section] = STATE(3446),
    [sym_grid_section] = STATE(3446),
    [sym_page_field] = STATE(3446),
    [sym_part_section] = STATE(3446),
    [sym_systempart_section] = STATE(3446),
    [sym_usercontrol_section] = STATE(3446),
    [sym_preproc_split_field] = STATE(3446),
    [sym__field_header] = STATE(7789),
    [sym_label_section] = STATE(3446),
    [sym_addfirst_modification] = STATE(3446),
    [sym_addlast_modification] = STATE(3446),
    [sym_addafter_modification] = STATE(3446),
    [sym_addbefore_modification] = STATE(3446),
    [sym_modify_modification] = STATE(3446),
    [sym_movefirst_modification] = STATE(3446),
    [sym_movelast_modification] = STATE(3446),
    [sym_moveafter_modification] = STATE(3446),
    [sym_movebefore_modification] = STATE(3446),
    [sym_preproc_if] = STATE(3384),
    [sym_preproc_elif] = STATE(3879),
    [sym_preproc_else] = STATE(4707),
    [sym_preproc_endif] = STATE(7157),
    [sym_preproc_conditional_layout] = STATE(3446),
    [aux_sym_layout_section_repeat1] = STATE(3446),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7790),
    [aux_sym_where_condition_token1] = ACTIONS(9087),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [aux_sym_basic_type_token6] = ACTIONS(9089),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(9091),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [anon_sym_POUNDif] = ACTIONS(9093),
    [anon_sym_POUNDIF] = ACTIONS(9093),
    [anon_sym_POUNDIf] = ACTIONS(9093),
    [anon_sym_POUNDelif] = ACTIONS(9095),
    [anon_sym_POUNDELIF] = ACTIONS(9095),
    [anon_sym_POUNDElif] = ACTIONS(9095),
    [anon_sym_POUNDelse] = ACTIONS(9097),
    [anon_sym_POUNDELSE] = ACTIONS(9097),
    [anon_sym_POUNDElse] = ACTIONS(9097),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9093),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(3408)] = {
    [sym_identifier] = ACTIONS(9179),
    [anon_sym_DASH] = ACTIONS(9181),
    [aux_sym_boolean_token1] = ACTIONS(9179),
    [aux_sym_boolean_token2] = ACTIONS(9179),
    [sym_decimal] = ACTIONS(9179),
    [anon_sym_LPAREN] = ACTIONS(9181),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9179),
    [anon_sym_LBRACK] = ACTIONS(9181),
    [aux_sym_record_type_token1] = ACTIONS(9179),
    [aux_sym_basic_type_token21] = ACTIONS(9179),
    [aux_sym_basic_type_token22] = ACTIONS(9179),
    [aux_sym_basic_type_token48] = ACTIONS(9179),
    [anon_sym_POUNDif] = ACTIONS(9181),
    [anon_sym_POUNDIF] = ACTIONS(9181),
    [anon_sym_POUNDIf] = ACTIONS(9181),
    [anon_sym_not] = ACTIONS(9179),
    [anon_sym_NOT] = ACTIONS(9179),
    [anon_sym_Not] = ACTIONS(9179),
    [anon_sym_POUNDelif] = ACTIONS(9181),
    [anon_sym_POUNDELIF] = ACTIONS(9181),
    [anon_sym_POUNDElif] = ACTIONS(9181),
    [anon_sym_POUNDelse] = ACTIONS(9181),
    [anon_sym_POUNDELSE] = ACTIONS(9181),
    [anon_sym_POUNDElse] = ACTIONS(9181),
    [anon_sym_POUNDendif] = ACTIONS(9181),
    [anon_sym_POUNDENDIF] = ACTIONS(9181),
    [anon_sym_POUNDEndif] = ACTIONS(9181),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9179),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9179),
    [anon_sym_PLUS] = ACTIONS(9181),
    [sym_datetime_literal] = ACTIONS(9181),
    [sym_date_literal] = ACTIONS(9179),
    [sym_time_literal] = ACTIONS(9179),
    [sym_biginteger_literal] = ACTIONS(9181),
    [anon_sym_else] = ACTIONS(9179),
    [anon_sym_ELSE] = ACTIONS(9179),
    [anon_sym_Else] = ACTIONS(9179),
    [sym_page_keyword] = ACTIONS(9179),
    [anon_sym_codeunit] = ACTIONS(9179),
    [anon_sym_CODEUNIT] = ACTIONS(9179),
    [anon_sym_Codeunit] = ACTIONS(9179),
    [anon_sym_CodeUnit] = ACTIONS(9179),
    [anon_sym_COdeunit] = ACTIONS(9179),
    [anon_sym_codeUnit] = ACTIONS(9179),
    [sym_report_keyword] = ACTIONS(9179),
    [sym_query_keyword] = ACTIONS(9179),
    [anon_sym_xmlport] = ACTIONS(9179),
    [anon_sym_XMLPORT] = ACTIONS(9179),
    [anon_sym_Xmlport] = ACTIONS(9179),
    [anon_sym_XMLport] = ACTIONS(9179),
    [anon_sym_XMLPort] = ACTIONS(9179),
    [anon_sym_XmlPort] = ACTIONS(9179),
    [anon_sym_enum] = ACTIONS(9179),
    [anon_sym_ENUM] = ACTIONS(9179),
    [anon_sym_Enum] = ACTIONS(9179),
    [anon_sym_eNUM] = ACTIONS(9179),
    [anon_sym_eNum] = ACTIONS(9179),
    [anon_sym_ENum] = ACTIONS(9179),
    [sym_quoted_identifier] = ACTIONS(9181),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9181),
    [sym_integer] = ACTIONS(9179),
    [sym_continue_as_identifier] = ACTIONS(9181),
    [sym_preproc_open] = ACTIONS(9181),
    [sym_preproc_close] = ACTIONS(9181),
  },
  [STATE(3409)] = {
    [sym_preproc_conditional_controladdin] = STATE(2885),
    [sym__body_element] = STATE(2885),
    [sym_empty_statement] = STATE(2885),
    [sym_property] = STATE(2885),
    [sym_fields_section] = STATE(2885),
    [sym_keys_section] = STATE(2885),
    [sym_fieldgroups_section] = STATE(2885),
    [sym_enum_value_declaration] = STATE(2885),
    [sym_labels_section] = STATE(2885),
    [sym_layout_section] = STATE(2885),
    [sym_modify_modification] = STATE(2885),
    [sym_actions_section] = STATE(2885),
    [sym_views_section] = STATE(2885),
    [sym_dataset_section] = STATE(2885),
    [sym_requestpage_section] = STATE(2885),
    [sym_rendering_section] = STATE(2885),
    [sym_elements_section] = STATE(2885),
    [sym_schema_section] = STATE(2885),
    [sym_assembly_declaration] = STATE(2885),
    [sym_event_declaration] = STATE(2885),
    [sym_procedure] = STATE(2885),
    [sym_preproc_split_procedure] = STATE(2885),
    [sym_interface_procedure] = STATE(2885),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2885),
    [sym_var_section] = STATE(2885),
    [sym_attribute_item] = STATE(2885),
    [sym_preproc_conditional] = STATE(2885),
    [sym_preproc_if] = STATE(2635),
    [sym_preproc_endif] = STATE(6896),
    [aux_sym_controladdin_declaration_repeat1] = STATE(2885),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3410)] = {
    [sym__body_element] = STATE(3425),
    [sym_empty_statement] = STATE(3425),
    [sym_property] = STATE(3425),
    [sym_fields_section] = STATE(3425),
    [sym_keys_section] = STATE(3425),
    [sym_fieldgroups_section] = STATE(3425),
    [sym_enum_value_declaration] = STATE(3425),
    [sym_labels_section] = STATE(3425),
    [sym_layout_section] = STATE(3425),
    [sym_modify_modification] = STATE(3425),
    [sym_actions_section] = STATE(3425),
    [sym_views_section] = STATE(3425),
    [sym_dataset_section] = STATE(3425),
    [sym_report_dataitem] = STATE(3425),
    [sym__report_body_element] = STATE(3425),
    [sym_preproc_conditional_report] = STATE(3425),
    [sym_report_column] = STATE(3425),
    [sym_requestpage_section] = STATE(3425),
    [sym_rendering_section] = STATE(3425),
    [sym_elements_section] = STATE(3425),
    [sym_schema_section] = STATE(3425),
    [sym_assembly_declaration] = STATE(3425),
    [sym_event_declaration] = STATE(3425),
    [sym_procedure] = STATE(3425),
    [sym_preproc_split_procedure] = STATE(3425),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3425),
    [sym_var_section] = STATE(3425),
    [sym_attribute_item] = STATE(3425),
    [sym_preproc_conditional] = STATE(3425),
    [sym_preproc_if] = STATE(2558),
    [aux_sym_report_dataitem_repeat1] = STATE(3425),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9183),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3411)] = {
    [sym_identifier] = ACTIONS(9185),
    [anon_sym_DASH] = ACTIONS(9187),
    [aux_sym_boolean_token1] = ACTIONS(9185),
    [aux_sym_boolean_token2] = ACTIONS(9185),
    [sym_decimal] = ACTIONS(9185),
    [anon_sym_LPAREN] = ACTIONS(9187),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9185),
    [anon_sym_LBRACK] = ACTIONS(9187),
    [aux_sym_record_type_token1] = ACTIONS(9185),
    [aux_sym_basic_type_token21] = ACTIONS(9185),
    [aux_sym_basic_type_token22] = ACTIONS(9185),
    [aux_sym_basic_type_token48] = ACTIONS(9185),
    [anon_sym_POUNDif] = ACTIONS(9187),
    [anon_sym_POUNDIF] = ACTIONS(9187),
    [anon_sym_POUNDIf] = ACTIONS(9187),
    [anon_sym_not] = ACTIONS(9185),
    [anon_sym_NOT] = ACTIONS(9185),
    [anon_sym_Not] = ACTIONS(9185),
    [anon_sym_POUNDelif] = ACTIONS(9187),
    [anon_sym_POUNDELIF] = ACTIONS(9187),
    [anon_sym_POUNDElif] = ACTIONS(9187),
    [anon_sym_POUNDelse] = ACTIONS(9187),
    [anon_sym_POUNDELSE] = ACTIONS(9187),
    [anon_sym_POUNDElse] = ACTIONS(9187),
    [anon_sym_POUNDendif] = ACTIONS(9187),
    [anon_sym_POUNDENDIF] = ACTIONS(9187),
    [anon_sym_POUNDEndif] = ACTIONS(9187),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9185),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9185),
    [anon_sym_PLUS] = ACTIONS(9187),
    [sym_datetime_literal] = ACTIONS(9187),
    [sym_date_literal] = ACTIONS(9185),
    [sym_time_literal] = ACTIONS(9185),
    [sym_biginteger_literal] = ACTIONS(9187),
    [anon_sym_else] = ACTIONS(9185),
    [anon_sym_ELSE] = ACTIONS(9185),
    [anon_sym_Else] = ACTIONS(9185),
    [sym_page_keyword] = ACTIONS(9185),
    [anon_sym_codeunit] = ACTIONS(9185),
    [anon_sym_CODEUNIT] = ACTIONS(9185),
    [anon_sym_Codeunit] = ACTIONS(9185),
    [anon_sym_CodeUnit] = ACTIONS(9185),
    [anon_sym_COdeunit] = ACTIONS(9185),
    [anon_sym_codeUnit] = ACTIONS(9185),
    [sym_report_keyword] = ACTIONS(9185),
    [sym_query_keyword] = ACTIONS(9185),
    [anon_sym_xmlport] = ACTIONS(9185),
    [anon_sym_XMLPORT] = ACTIONS(9185),
    [anon_sym_Xmlport] = ACTIONS(9185),
    [anon_sym_XMLport] = ACTIONS(9185),
    [anon_sym_XMLPort] = ACTIONS(9185),
    [anon_sym_XmlPort] = ACTIONS(9185),
    [anon_sym_enum] = ACTIONS(9185),
    [anon_sym_ENUM] = ACTIONS(9185),
    [anon_sym_Enum] = ACTIONS(9185),
    [anon_sym_eNUM] = ACTIONS(9185),
    [anon_sym_eNum] = ACTIONS(9185),
    [anon_sym_ENum] = ACTIONS(9185),
    [sym_quoted_identifier] = ACTIONS(9187),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9187),
    [sym_integer] = ACTIONS(9185),
    [sym_continue_as_identifier] = ACTIONS(9187),
    [sym_preproc_open] = ACTIONS(9187),
    [sym_preproc_close] = ACTIONS(9187),
  },
  [STATE(3412)] = {
    [sym__body_element] = STATE(3422),
    [sym_empty_statement] = STATE(3422),
    [sym_property] = STATE(3422),
    [sym_fields_section] = STATE(3422),
    [sym_keys_section] = STATE(3422),
    [sym_fieldgroups_section] = STATE(3422),
    [sym_enum_value_declaration] = STATE(3422),
    [sym_labels_section] = STATE(3422),
    [sym_layout_section] = STATE(3422),
    [sym_modify_modification] = STATE(3422),
    [sym_actions_section] = STATE(3422),
    [sym_views_section] = STATE(3422),
    [sym_dataset_section] = STATE(3422),
    [sym_report_dataitem] = STATE(3422),
    [sym__report_body_element] = STATE(3422),
    [sym_preproc_conditional_report] = STATE(3422),
    [sym_report_column] = STATE(3422),
    [sym_requestpage_section] = STATE(3422),
    [sym_rendering_section] = STATE(3422),
    [sym_elements_section] = STATE(3422),
    [sym_schema_section] = STATE(3422),
    [sym_assembly_declaration] = STATE(3422),
    [sym_event_declaration] = STATE(3422),
    [sym_procedure] = STATE(3422),
    [sym_preproc_split_procedure] = STATE(3422),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3422),
    [sym_var_section] = STATE(3422),
    [sym_attribute_item] = STATE(3422),
    [sym_preproc_conditional] = STATE(3422),
    [sym_preproc_if] = STATE(2558),
    [aux_sym_report_dataitem_repeat1] = STATE(3422),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9189),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3413)] = {
    [sym_identifier] = ACTIONS(9191),
    [anon_sym_DASH] = ACTIONS(9193),
    [aux_sym_boolean_token1] = ACTIONS(9191),
    [aux_sym_boolean_token2] = ACTIONS(9191),
    [sym_decimal] = ACTIONS(9191),
    [anon_sym_LPAREN] = ACTIONS(9193),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9191),
    [anon_sym_LBRACK] = ACTIONS(9193),
    [aux_sym_record_type_token1] = ACTIONS(9191),
    [aux_sym_basic_type_token21] = ACTIONS(9191),
    [aux_sym_basic_type_token22] = ACTIONS(9191),
    [aux_sym_basic_type_token48] = ACTIONS(9191),
    [anon_sym_POUNDif] = ACTIONS(9193),
    [anon_sym_POUNDIF] = ACTIONS(9193),
    [anon_sym_POUNDIf] = ACTIONS(9193),
    [anon_sym_not] = ACTIONS(9191),
    [anon_sym_NOT] = ACTIONS(9191),
    [anon_sym_Not] = ACTIONS(9191),
    [anon_sym_POUNDelif] = ACTIONS(9193),
    [anon_sym_POUNDELIF] = ACTIONS(9193),
    [anon_sym_POUNDElif] = ACTIONS(9193),
    [anon_sym_POUNDelse] = ACTIONS(9193),
    [anon_sym_POUNDELSE] = ACTIONS(9193),
    [anon_sym_POUNDElse] = ACTIONS(9193),
    [anon_sym_POUNDendif] = ACTIONS(9193),
    [anon_sym_POUNDENDIF] = ACTIONS(9193),
    [anon_sym_POUNDEndif] = ACTIONS(9193),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9191),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9191),
    [anon_sym_PLUS] = ACTIONS(9193),
    [sym_datetime_literal] = ACTIONS(9193),
    [sym_date_literal] = ACTIONS(9191),
    [sym_time_literal] = ACTIONS(9191),
    [sym_biginteger_literal] = ACTIONS(9193),
    [anon_sym_else] = ACTIONS(9191),
    [anon_sym_ELSE] = ACTIONS(9191),
    [anon_sym_Else] = ACTIONS(9191),
    [sym_page_keyword] = ACTIONS(9191),
    [anon_sym_codeunit] = ACTIONS(9191),
    [anon_sym_CODEUNIT] = ACTIONS(9191),
    [anon_sym_Codeunit] = ACTIONS(9191),
    [anon_sym_CodeUnit] = ACTIONS(9191),
    [anon_sym_COdeunit] = ACTIONS(9191),
    [anon_sym_codeUnit] = ACTIONS(9191),
    [sym_report_keyword] = ACTIONS(9191),
    [sym_query_keyword] = ACTIONS(9191),
    [anon_sym_xmlport] = ACTIONS(9191),
    [anon_sym_XMLPORT] = ACTIONS(9191),
    [anon_sym_Xmlport] = ACTIONS(9191),
    [anon_sym_XMLport] = ACTIONS(9191),
    [anon_sym_XMLPort] = ACTIONS(9191),
    [anon_sym_XmlPort] = ACTIONS(9191),
    [anon_sym_enum] = ACTIONS(9191),
    [anon_sym_ENUM] = ACTIONS(9191),
    [anon_sym_Enum] = ACTIONS(9191),
    [anon_sym_eNUM] = ACTIONS(9191),
    [anon_sym_eNum] = ACTIONS(9191),
    [anon_sym_ENum] = ACTIONS(9191),
    [sym_quoted_identifier] = ACTIONS(9193),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9193),
    [sym_integer] = ACTIONS(9191),
    [sym_continue_as_identifier] = ACTIONS(9193),
    [sym_preproc_open] = ACTIONS(9193),
    [sym_preproc_close] = ACTIONS(9193),
  },
  [STATE(3414)] = {
    [sym_identifier] = ACTIONS(9195),
    [anon_sym_DASH] = ACTIONS(9197),
    [aux_sym_boolean_token1] = ACTIONS(9195),
    [aux_sym_boolean_token2] = ACTIONS(9195),
    [sym_decimal] = ACTIONS(9195),
    [anon_sym_LPAREN] = ACTIONS(9197),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9195),
    [anon_sym_LBRACK] = ACTIONS(9197),
    [aux_sym_record_type_token1] = ACTIONS(9195),
    [aux_sym_basic_type_token21] = ACTIONS(9195),
    [aux_sym_basic_type_token22] = ACTIONS(9195),
    [aux_sym_basic_type_token48] = ACTIONS(9195),
    [anon_sym_POUNDif] = ACTIONS(9197),
    [anon_sym_POUNDIF] = ACTIONS(9197),
    [anon_sym_POUNDIf] = ACTIONS(9197),
    [anon_sym_not] = ACTIONS(9195),
    [anon_sym_NOT] = ACTIONS(9195),
    [anon_sym_Not] = ACTIONS(9195),
    [anon_sym_POUNDelif] = ACTIONS(9197),
    [anon_sym_POUNDELIF] = ACTIONS(9197),
    [anon_sym_POUNDElif] = ACTIONS(9197),
    [anon_sym_POUNDelse] = ACTIONS(9197),
    [anon_sym_POUNDELSE] = ACTIONS(9197),
    [anon_sym_POUNDElse] = ACTIONS(9197),
    [anon_sym_POUNDendif] = ACTIONS(9197),
    [anon_sym_POUNDENDIF] = ACTIONS(9197),
    [anon_sym_POUNDEndif] = ACTIONS(9197),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9195),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9195),
    [anon_sym_PLUS] = ACTIONS(9197),
    [sym_datetime_literal] = ACTIONS(9197),
    [sym_date_literal] = ACTIONS(9195),
    [sym_time_literal] = ACTIONS(9195),
    [sym_biginteger_literal] = ACTIONS(9197),
    [anon_sym_else] = ACTIONS(9195),
    [anon_sym_ELSE] = ACTIONS(9195),
    [anon_sym_Else] = ACTIONS(9195),
    [sym_page_keyword] = ACTIONS(9195),
    [anon_sym_codeunit] = ACTIONS(9195),
    [anon_sym_CODEUNIT] = ACTIONS(9195),
    [anon_sym_Codeunit] = ACTIONS(9195),
    [anon_sym_CodeUnit] = ACTIONS(9195),
    [anon_sym_COdeunit] = ACTIONS(9195),
    [anon_sym_codeUnit] = ACTIONS(9195),
    [sym_report_keyword] = ACTIONS(9195),
    [sym_query_keyword] = ACTIONS(9195),
    [anon_sym_xmlport] = ACTIONS(9195),
    [anon_sym_XMLPORT] = ACTIONS(9195),
    [anon_sym_Xmlport] = ACTIONS(9195),
    [anon_sym_XMLport] = ACTIONS(9195),
    [anon_sym_XMLPort] = ACTIONS(9195),
    [anon_sym_XmlPort] = ACTIONS(9195),
    [anon_sym_enum] = ACTIONS(9195),
    [anon_sym_ENUM] = ACTIONS(9195),
    [anon_sym_Enum] = ACTIONS(9195),
    [anon_sym_eNUM] = ACTIONS(9195),
    [anon_sym_eNum] = ACTIONS(9195),
    [anon_sym_ENum] = ACTIONS(9195),
    [sym_quoted_identifier] = ACTIONS(9197),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9197),
    [sym_integer] = ACTIONS(9195),
    [sym_continue_as_identifier] = ACTIONS(9197),
    [sym_preproc_open] = ACTIONS(9197),
    [sym_preproc_close] = ACTIONS(9197),
  },
  [STATE(3415)] = {
    [sym_identifier] = ACTIONS(9199),
    [anon_sym_DASH] = ACTIONS(9201),
    [aux_sym_boolean_token1] = ACTIONS(9199),
    [aux_sym_boolean_token2] = ACTIONS(9199),
    [sym_decimal] = ACTIONS(9199),
    [anon_sym_LPAREN] = ACTIONS(9201),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9199),
    [anon_sym_LBRACK] = ACTIONS(9201),
    [aux_sym_record_type_token1] = ACTIONS(9199),
    [aux_sym_basic_type_token21] = ACTIONS(9199),
    [aux_sym_basic_type_token22] = ACTIONS(9199),
    [aux_sym_basic_type_token48] = ACTIONS(9199),
    [anon_sym_POUNDif] = ACTIONS(9201),
    [anon_sym_POUNDIF] = ACTIONS(9201),
    [anon_sym_POUNDIf] = ACTIONS(9201),
    [anon_sym_not] = ACTIONS(9199),
    [anon_sym_NOT] = ACTIONS(9199),
    [anon_sym_Not] = ACTIONS(9199),
    [anon_sym_POUNDelif] = ACTIONS(9201),
    [anon_sym_POUNDELIF] = ACTIONS(9201),
    [anon_sym_POUNDElif] = ACTIONS(9201),
    [anon_sym_POUNDelse] = ACTIONS(9201),
    [anon_sym_POUNDELSE] = ACTIONS(9201),
    [anon_sym_POUNDElse] = ACTIONS(9201),
    [anon_sym_POUNDendif] = ACTIONS(9201),
    [anon_sym_POUNDENDIF] = ACTIONS(9201),
    [anon_sym_POUNDEndif] = ACTIONS(9201),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9199),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9199),
    [anon_sym_PLUS] = ACTIONS(9201),
    [sym_datetime_literal] = ACTIONS(9201),
    [sym_date_literal] = ACTIONS(9199),
    [sym_time_literal] = ACTIONS(9199),
    [sym_biginteger_literal] = ACTIONS(9201),
    [anon_sym_else] = ACTIONS(9199),
    [anon_sym_ELSE] = ACTIONS(9199),
    [anon_sym_Else] = ACTIONS(9199),
    [sym_page_keyword] = ACTIONS(9199),
    [anon_sym_codeunit] = ACTIONS(9199),
    [anon_sym_CODEUNIT] = ACTIONS(9199),
    [anon_sym_Codeunit] = ACTIONS(9199),
    [anon_sym_CodeUnit] = ACTIONS(9199),
    [anon_sym_COdeunit] = ACTIONS(9199),
    [anon_sym_codeUnit] = ACTIONS(9199),
    [sym_report_keyword] = ACTIONS(9199),
    [sym_query_keyword] = ACTIONS(9199),
    [anon_sym_xmlport] = ACTIONS(9199),
    [anon_sym_XMLPORT] = ACTIONS(9199),
    [anon_sym_Xmlport] = ACTIONS(9199),
    [anon_sym_XMLport] = ACTIONS(9199),
    [anon_sym_XMLPort] = ACTIONS(9199),
    [anon_sym_XmlPort] = ACTIONS(9199),
    [anon_sym_enum] = ACTIONS(9199),
    [anon_sym_ENUM] = ACTIONS(9199),
    [anon_sym_Enum] = ACTIONS(9199),
    [anon_sym_eNUM] = ACTIONS(9199),
    [anon_sym_eNum] = ACTIONS(9199),
    [anon_sym_ENum] = ACTIONS(9199),
    [sym_quoted_identifier] = ACTIONS(9201),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9201),
    [sym_integer] = ACTIONS(9199),
    [sym_continue_as_identifier] = ACTIONS(9201),
    [sym_preproc_open] = ACTIONS(9201),
    [sym_preproc_close] = ACTIONS(9201),
  },
  [STATE(3416)] = {
    [sym_identifier] = ACTIONS(9203),
    [anon_sym_DASH] = ACTIONS(9205),
    [aux_sym_boolean_token1] = ACTIONS(9203),
    [aux_sym_boolean_token2] = ACTIONS(9203),
    [sym_decimal] = ACTIONS(9203),
    [anon_sym_LPAREN] = ACTIONS(9205),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9203),
    [anon_sym_LBRACK] = ACTIONS(9205),
    [aux_sym_record_type_token1] = ACTIONS(9203),
    [aux_sym_basic_type_token21] = ACTIONS(9203),
    [aux_sym_basic_type_token22] = ACTIONS(9203),
    [aux_sym_basic_type_token48] = ACTIONS(9203),
    [anon_sym_POUNDif] = ACTIONS(9205),
    [anon_sym_POUNDIF] = ACTIONS(9205),
    [anon_sym_POUNDIf] = ACTIONS(9205),
    [anon_sym_not] = ACTIONS(9203),
    [anon_sym_NOT] = ACTIONS(9203),
    [anon_sym_Not] = ACTIONS(9203),
    [anon_sym_POUNDelif] = ACTIONS(9205),
    [anon_sym_POUNDELIF] = ACTIONS(9205),
    [anon_sym_POUNDElif] = ACTIONS(9205),
    [anon_sym_POUNDelse] = ACTIONS(9205),
    [anon_sym_POUNDELSE] = ACTIONS(9205),
    [anon_sym_POUNDElse] = ACTIONS(9205),
    [anon_sym_POUNDendif] = ACTIONS(9205),
    [anon_sym_POUNDENDIF] = ACTIONS(9205),
    [anon_sym_POUNDEndif] = ACTIONS(9205),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9203),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9203),
    [anon_sym_PLUS] = ACTIONS(9205),
    [sym_datetime_literal] = ACTIONS(9205),
    [sym_date_literal] = ACTIONS(9203),
    [sym_time_literal] = ACTIONS(9203),
    [sym_biginteger_literal] = ACTIONS(9205),
    [anon_sym_else] = ACTIONS(9203),
    [anon_sym_ELSE] = ACTIONS(9203),
    [anon_sym_Else] = ACTIONS(9203),
    [sym_page_keyword] = ACTIONS(9203),
    [anon_sym_codeunit] = ACTIONS(9203),
    [anon_sym_CODEUNIT] = ACTIONS(9203),
    [anon_sym_Codeunit] = ACTIONS(9203),
    [anon_sym_CodeUnit] = ACTIONS(9203),
    [anon_sym_COdeunit] = ACTIONS(9203),
    [anon_sym_codeUnit] = ACTIONS(9203),
    [sym_report_keyword] = ACTIONS(9203),
    [sym_query_keyword] = ACTIONS(9203),
    [anon_sym_xmlport] = ACTIONS(9203),
    [anon_sym_XMLPORT] = ACTIONS(9203),
    [anon_sym_Xmlport] = ACTIONS(9203),
    [anon_sym_XMLport] = ACTIONS(9203),
    [anon_sym_XMLPort] = ACTIONS(9203),
    [anon_sym_XmlPort] = ACTIONS(9203),
    [anon_sym_enum] = ACTIONS(9203),
    [anon_sym_ENUM] = ACTIONS(9203),
    [anon_sym_Enum] = ACTIONS(9203),
    [anon_sym_eNUM] = ACTIONS(9203),
    [anon_sym_eNum] = ACTIONS(9203),
    [anon_sym_ENum] = ACTIONS(9203),
    [sym_quoted_identifier] = ACTIONS(9205),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9205),
    [sym_integer] = ACTIONS(9203),
    [sym_continue_as_identifier] = ACTIONS(9205),
    [sym_preproc_open] = ACTIONS(9205),
    [sym_preproc_close] = ACTIONS(9205),
  },
  [STATE(3417)] = {
    [sym_preproc_conditional_controladdin] = STATE(2885),
    [sym__body_element] = STATE(2885),
    [sym_empty_statement] = STATE(2885),
    [sym_property] = STATE(2885),
    [sym_fields_section] = STATE(2885),
    [sym_keys_section] = STATE(2885),
    [sym_fieldgroups_section] = STATE(2885),
    [sym_enum_value_declaration] = STATE(2885),
    [sym_labels_section] = STATE(2885),
    [sym_layout_section] = STATE(2885),
    [sym_modify_modification] = STATE(2885),
    [sym_actions_section] = STATE(2885),
    [sym_views_section] = STATE(2885),
    [sym_dataset_section] = STATE(2885),
    [sym_requestpage_section] = STATE(2885),
    [sym_rendering_section] = STATE(2885),
    [sym_elements_section] = STATE(2885),
    [sym_schema_section] = STATE(2885),
    [sym_assembly_declaration] = STATE(2885),
    [sym_event_declaration] = STATE(2885),
    [sym_procedure] = STATE(2885),
    [sym_preproc_split_procedure] = STATE(2885),
    [sym_interface_procedure] = STATE(2885),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2885),
    [sym_var_section] = STATE(2885),
    [sym_attribute_item] = STATE(2885),
    [sym_preproc_conditional] = STATE(2885),
    [sym_preproc_if] = STATE(2635),
    [sym_preproc_endif] = STATE(6959),
    [aux_sym_controladdin_declaration_repeat1] = STATE(2885),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3418)] = {
    [sym_preproc_conditional_controladdin] = STATE(3417),
    [sym__body_element] = STATE(3417),
    [sym_empty_statement] = STATE(3417),
    [sym_property] = STATE(3417),
    [sym_fields_section] = STATE(3417),
    [sym_keys_section] = STATE(3417),
    [sym_fieldgroups_section] = STATE(3417),
    [sym_enum_value_declaration] = STATE(3417),
    [sym_labels_section] = STATE(3417),
    [sym_layout_section] = STATE(3417),
    [sym_modify_modification] = STATE(3417),
    [sym_actions_section] = STATE(3417),
    [sym_views_section] = STATE(3417),
    [sym_dataset_section] = STATE(3417),
    [sym_requestpage_section] = STATE(3417),
    [sym_rendering_section] = STATE(3417),
    [sym_elements_section] = STATE(3417),
    [sym_schema_section] = STATE(3417),
    [sym_assembly_declaration] = STATE(3417),
    [sym_event_declaration] = STATE(3417),
    [sym_procedure] = STATE(3417),
    [sym_preproc_split_procedure] = STATE(3417),
    [sym_interface_procedure] = STATE(3417),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3417),
    [sym_var_section] = STATE(3417),
    [sym_attribute_item] = STATE(3417),
    [sym_preproc_conditional] = STATE(3417),
    [sym_preproc_if] = STATE(2635),
    [sym_preproc_endif] = STATE(6896),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3417),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3419)] = {
    [sym_preproc_conditional_controladdin] = STATE(3388),
    [sym__body_element] = STATE(3388),
    [sym_empty_statement] = STATE(3388),
    [sym_property] = STATE(3388),
    [sym_fields_section] = STATE(3388),
    [sym_keys_section] = STATE(3388),
    [sym_fieldgroups_section] = STATE(3388),
    [sym_enum_value_declaration] = STATE(3388),
    [sym_labels_section] = STATE(3388),
    [sym_layout_section] = STATE(3388),
    [sym_modify_modification] = STATE(3388),
    [sym_actions_section] = STATE(3388),
    [sym_views_section] = STATE(3388),
    [sym_dataset_section] = STATE(3388),
    [sym_requestpage_section] = STATE(3388),
    [sym_rendering_section] = STATE(3388),
    [sym_elements_section] = STATE(3388),
    [sym_schema_section] = STATE(3388),
    [sym_assembly_declaration] = STATE(3388),
    [sym_event_declaration] = STATE(3388),
    [sym_procedure] = STATE(3388),
    [sym_preproc_split_procedure] = STATE(3388),
    [sym_interface_procedure] = STATE(3388),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3388),
    [sym_var_section] = STATE(3388),
    [sym_attribute_item] = STATE(3388),
    [sym_preproc_conditional] = STATE(3388),
    [sym_preproc_if] = STATE(2635),
    [sym_preproc_endif] = STATE(6959),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3388),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3420)] = {
    [sym_identifier] = ACTIONS(9207),
    [anon_sym_DASH] = ACTIONS(9209),
    [aux_sym_boolean_token1] = ACTIONS(9207),
    [aux_sym_boolean_token2] = ACTIONS(9207),
    [sym_decimal] = ACTIONS(9207),
    [anon_sym_LPAREN] = ACTIONS(9209),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9207),
    [anon_sym_LBRACK] = ACTIONS(9209),
    [aux_sym_record_type_token1] = ACTIONS(9207),
    [aux_sym_basic_type_token21] = ACTIONS(9207),
    [aux_sym_basic_type_token22] = ACTIONS(9207),
    [aux_sym_basic_type_token48] = ACTIONS(9207),
    [anon_sym_POUNDif] = ACTIONS(9209),
    [anon_sym_POUNDIF] = ACTIONS(9209),
    [anon_sym_POUNDIf] = ACTIONS(9209),
    [anon_sym_not] = ACTIONS(9207),
    [anon_sym_NOT] = ACTIONS(9207),
    [anon_sym_Not] = ACTIONS(9207),
    [anon_sym_POUNDelif] = ACTIONS(9209),
    [anon_sym_POUNDELIF] = ACTIONS(9209),
    [anon_sym_POUNDElif] = ACTIONS(9209),
    [anon_sym_POUNDelse] = ACTIONS(9209),
    [anon_sym_POUNDELSE] = ACTIONS(9209),
    [anon_sym_POUNDElse] = ACTIONS(9209),
    [anon_sym_POUNDendif] = ACTIONS(9209),
    [anon_sym_POUNDENDIF] = ACTIONS(9209),
    [anon_sym_POUNDEndif] = ACTIONS(9209),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9207),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9207),
    [anon_sym_PLUS] = ACTIONS(9209),
    [sym_datetime_literal] = ACTIONS(9209),
    [sym_date_literal] = ACTIONS(9207),
    [sym_time_literal] = ACTIONS(9207),
    [sym_biginteger_literal] = ACTIONS(9209),
    [anon_sym_else] = ACTIONS(9207),
    [anon_sym_ELSE] = ACTIONS(9207),
    [anon_sym_Else] = ACTIONS(9207),
    [sym_page_keyword] = ACTIONS(9207),
    [anon_sym_codeunit] = ACTIONS(9207),
    [anon_sym_CODEUNIT] = ACTIONS(9207),
    [anon_sym_Codeunit] = ACTIONS(9207),
    [anon_sym_CodeUnit] = ACTIONS(9207),
    [anon_sym_COdeunit] = ACTIONS(9207),
    [anon_sym_codeUnit] = ACTIONS(9207),
    [sym_report_keyword] = ACTIONS(9207),
    [sym_query_keyword] = ACTIONS(9207),
    [anon_sym_xmlport] = ACTIONS(9207),
    [anon_sym_XMLPORT] = ACTIONS(9207),
    [anon_sym_Xmlport] = ACTIONS(9207),
    [anon_sym_XMLport] = ACTIONS(9207),
    [anon_sym_XMLPort] = ACTIONS(9207),
    [anon_sym_XmlPort] = ACTIONS(9207),
    [anon_sym_enum] = ACTIONS(9207),
    [anon_sym_ENUM] = ACTIONS(9207),
    [anon_sym_Enum] = ACTIONS(9207),
    [anon_sym_eNUM] = ACTIONS(9207),
    [anon_sym_eNum] = ACTIONS(9207),
    [anon_sym_ENum] = ACTIONS(9207),
    [sym_quoted_identifier] = ACTIONS(9209),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9209),
    [sym_integer] = ACTIONS(9207),
    [sym_continue_as_identifier] = ACTIONS(9209),
    [sym_preproc_open] = ACTIONS(9209),
    [sym_preproc_close] = ACTIONS(9209),
  },
  [STATE(3421)] = {
    [sym_identifier] = ACTIONS(9211),
    [anon_sym_DASH] = ACTIONS(9213),
    [aux_sym_boolean_token1] = ACTIONS(9211),
    [aux_sym_boolean_token2] = ACTIONS(9211),
    [sym_decimal] = ACTIONS(9211),
    [anon_sym_LPAREN] = ACTIONS(9213),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9211),
    [anon_sym_LBRACK] = ACTIONS(9213),
    [aux_sym_record_type_token1] = ACTIONS(9211),
    [aux_sym_basic_type_token21] = ACTIONS(9211),
    [aux_sym_basic_type_token22] = ACTIONS(9211),
    [aux_sym_basic_type_token48] = ACTIONS(9211),
    [anon_sym_POUNDif] = ACTIONS(9213),
    [anon_sym_POUNDIF] = ACTIONS(9213),
    [anon_sym_POUNDIf] = ACTIONS(9213),
    [anon_sym_not] = ACTIONS(9211),
    [anon_sym_NOT] = ACTIONS(9211),
    [anon_sym_Not] = ACTIONS(9211),
    [anon_sym_POUNDelif] = ACTIONS(9213),
    [anon_sym_POUNDELIF] = ACTIONS(9213),
    [anon_sym_POUNDElif] = ACTIONS(9213),
    [anon_sym_POUNDelse] = ACTIONS(9213),
    [anon_sym_POUNDELSE] = ACTIONS(9213),
    [anon_sym_POUNDElse] = ACTIONS(9213),
    [anon_sym_POUNDendif] = ACTIONS(9213),
    [anon_sym_POUNDENDIF] = ACTIONS(9213),
    [anon_sym_POUNDEndif] = ACTIONS(9213),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9211),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9211),
    [anon_sym_PLUS] = ACTIONS(9213),
    [sym_datetime_literal] = ACTIONS(9213),
    [sym_date_literal] = ACTIONS(9211),
    [sym_time_literal] = ACTIONS(9211),
    [sym_biginteger_literal] = ACTIONS(9213),
    [anon_sym_else] = ACTIONS(9211),
    [anon_sym_ELSE] = ACTIONS(9211),
    [anon_sym_Else] = ACTIONS(9211),
    [sym_page_keyword] = ACTIONS(9211),
    [anon_sym_codeunit] = ACTIONS(9211),
    [anon_sym_CODEUNIT] = ACTIONS(9211),
    [anon_sym_Codeunit] = ACTIONS(9211),
    [anon_sym_CodeUnit] = ACTIONS(9211),
    [anon_sym_COdeunit] = ACTIONS(9211),
    [anon_sym_codeUnit] = ACTIONS(9211),
    [sym_report_keyword] = ACTIONS(9211),
    [sym_query_keyword] = ACTIONS(9211),
    [anon_sym_xmlport] = ACTIONS(9211),
    [anon_sym_XMLPORT] = ACTIONS(9211),
    [anon_sym_Xmlport] = ACTIONS(9211),
    [anon_sym_XMLport] = ACTIONS(9211),
    [anon_sym_XMLPort] = ACTIONS(9211),
    [anon_sym_XmlPort] = ACTIONS(9211),
    [anon_sym_enum] = ACTIONS(9211),
    [anon_sym_ENUM] = ACTIONS(9211),
    [anon_sym_Enum] = ACTIONS(9211),
    [anon_sym_eNUM] = ACTIONS(9211),
    [anon_sym_eNum] = ACTIONS(9211),
    [anon_sym_ENum] = ACTIONS(9211),
    [sym_quoted_identifier] = ACTIONS(9213),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9213),
    [sym_integer] = ACTIONS(9211),
    [sym_continue_as_identifier] = ACTIONS(9213),
    [sym_preproc_open] = ACTIONS(9213),
    [sym_preproc_close] = ACTIONS(9213),
  },
  [STATE(3422)] = {
    [sym__body_element] = STATE(3425),
    [sym_empty_statement] = STATE(3425),
    [sym_property] = STATE(3425),
    [sym_fields_section] = STATE(3425),
    [sym_keys_section] = STATE(3425),
    [sym_fieldgroups_section] = STATE(3425),
    [sym_enum_value_declaration] = STATE(3425),
    [sym_labels_section] = STATE(3425),
    [sym_layout_section] = STATE(3425),
    [sym_modify_modification] = STATE(3425),
    [sym_actions_section] = STATE(3425),
    [sym_views_section] = STATE(3425),
    [sym_dataset_section] = STATE(3425),
    [sym_report_dataitem] = STATE(3425),
    [sym__report_body_element] = STATE(3425),
    [sym_preproc_conditional_report] = STATE(3425),
    [sym_report_column] = STATE(3425),
    [sym_requestpage_section] = STATE(3425),
    [sym_rendering_section] = STATE(3425),
    [sym_elements_section] = STATE(3425),
    [sym_schema_section] = STATE(3425),
    [sym_assembly_declaration] = STATE(3425),
    [sym_event_declaration] = STATE(3425),
    [sym_procedure] = STATE(3425),
    [sym_preproc_split_procedure] = STATE(3425),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3425),
    [sym_var_section] = STATE(3425),
    [sym_attribute_item] = STATE(3425),
    [sym_preproc_conditional] = STATE(3425),
    [sym_preproc_if] = STATE(2558),
    [aux_sym_report_dataitem_repeat1] = STATE(3425),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9215),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3423)] = {
    [sym_identifier] = ACTIONS(9217),
    [anon_sym_DASH] = ACTIONS(9219),
    [aux_sym_boolean_token1] = ACTIONS(9217),
    [aux_sym_boolean_token2] = ACTIONS(9217),
    [sym_decimal] = ACTIONS(9217),
    [anon_sym_LPAREN] = ACTIONS(9219),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9217),
    [anon_sym_LBRACK] = ACTIONS(9219),
    [aux_sym_record_type_token1] = ACTIONS(9217),
    [aux_sym_basic_type_token21] = ACTIONS(9217),
    [aux_sym_basic_type_token22] = ACTIONS(9217),
    [aux_sym_basic_type_token48] = ACTIONS(9217),
    [anon_sym_POUNDif] = ACTIONS(9219),
    [anon_sym_POUNDIF] = ACTIONS(9219),
    [anon_sym_POUNDIf] = ACTIONS(9219),
    [anon_sym_not] = ACTIONS(9217),
    [anon_sym_NOT] = ACTIONS(9217),
    [anon_sym_Not] = ACTIONS(9217),
    [anon_sym_POUNDelif] = ACTIONS(9219),
    [anon_sym_POUNDELIF] = ACTIONS(9219),
    [anon_sym_POUNDElif] = ACTIONS(9219),
    [anon_sym_POUNDelse] = ACTIONS(9219),
    [anon_sym_POUNDELSE] = ACTIONS(9219),
    [anon_sym_POUNDElse] = ACTIONS(9219),
    [anon_sym_POUNDendif] = ACTIONS(9219),
    [anon_sym_POUNDENDIF] = ACTIONS(9219),
    [anon_sym_POUNDEndif] = ACTIONS(9219),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9217),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9217),
    [anon_sym_PLUS] = ACTIONS(9219),
    [sym_datetime_literal] = ACTIONS(9219),
    [sym_date_literal] = ACTIONS(9217),
    [sym_time_literal] = ACTIONS(9217),
    [sym_biginteger_literal] = ACTIONS(9219),
    [anon_sym_else] = ACTIONS(9217),
    [anon_sym_ELSE] = ACTIONS(9217),
    [anon_sym_Else] = ACTIONS(9217),
    [sym_page_keyword] = ACTIONS(9217),
    [anon_sym_codeunit] = ACTIONS(9217),
    [anon_sym_CODEUNIT] = ACTIONS(9217),
    [anon_sym_Codeunit] = ACTIONS(9217),
    [anon_sym_CodeUnit] = ACTIONS(9217),
    [anon_sym_COdeunit] = ACTIONS(9217),
    [anon_sym_codeUnit] = ACTIONS(9217),
    [sym_report_keyword] = ACTIONS(9217),
    [sym_query_keyword] = ACTIONS(9217),
    [anon_sym_xmlport] = ACTIONS(9217),
    [anon_sym_XMLPORT] = ACTIONS(9217),
    [anon_sym_Xmlport] = ACTIONS(9217),
    [anon_sym_XMLport] = ACTIONS(9217),
    [anon_sym_XMLPort] = ACTIONS(9217),
    [anon_sym_XmlPort] = ACTIONS(9217),
    [anon_sym_enum] = ACTIONS(9217),
    [anon_sym_ENUM] = ACTIONS(9217),
    [anon_sym_Enum] = ACTIONS(9217),
    [anon_sym_eNUM] = ACTIONS(9217),
    [anon_sym_eNum] = ACTIONS(9217),
    [anon_sym_ENum] = ACTIONS(9217),
    [sym_quoted_identifier] = ACTIONS(9219),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9219),
    [sym_integer] = ACTIONS(9217),
    [sym_continue_as_identifier] = ACTIONS(9219),
    [sym_preproc_open] = ACTIONS(9219),
    [sym_preproc_close] = ACTIONS(9219),
  },
  [STATE(3424)] = {
    [sym__body_element] = STATE(3410),
    [sym_empty_statement] = STATE(3410),
    [sym_property] = STATE(3410),
    [sym_fields_section] = STATE(3410),
    [sym_keys_section] = STATE(3410),
    [sym_fieldgroups_section] = STATE(3410),
    [sym_enum_value_declaration] = STATE(3410),
    [sym_labels_section] = STATE(3410),
    [sym_layout_section] = STATE(3410),
    [sym_modify_modification] = STATE(3410),
    [sym_actions_section] = STATE(3410),
    [sym_views_section] = STATE(3410),
    [sym_dataset_section] = STATE(3410),
    [sym_report_dataitem] = STATE(3410),
    [sym__report_body_element] = STATE(3410),
    [sym_preproc_conditional_report] = STATE(3410),
    [sym_report_column] = STATE(3410),
    [sym_requestpage_section] = STATE(3410),
    [sym_rendering_section] = STATE(3410),
    [sym_elements_section] = STATE(3410),
    [sym_schema_section] = STATE(3410),
    [sym_assembly_declaration] = STATE(3410),
    [sym_event_declaration] = STATE(3410),
    [sym_procedure] = STATE(3410),
    [sym_preproc_split_procedure] = STATE(3410),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3410),
    [sym_var_section] = STATE(3410),
    [sym_attribute_item] = STATE(3410),
    [sym_preproc_conditional] = STATE(3410),
    [sym_preproc_if] = STATE(2558),
    [aux_sym_report_dataitem_repeat1] = STATE(3410),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9221),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3425)] = {
    [sym__body_element] = STATE(3425),
    [sym_empty_statement] = STATE(3425),
    [sym_property] = STATE(3425),
    [sym_fields_section] = STATE(3425),
    [sym_keys_section] = STATE(3425),
    [sym_fieldgroups_section] = STATE(3425),
    [sym_enum_value_declaration] = STATE(3425),
    [sym_labels_section] = STATE(3425),
    [sym_layout_section] = STATE(3425),
    [sym_modify_modification] = STATE(3425),
    [sym_actions_section] = STATE(3425),
    [sym_views_section] = STATE(3425),
    [sym_dataset_section] = STATE(3425),
    [sym_report_dataitem] = STATE(3425),
    [sym__report_body_element] = STATE(3425),
    [sym_preproc_conditional_report] = STATE(3425),
    [sym_report_column] = STATE(3425),
    [sym_requestpage_section] = STATE(3425),
    [sym_rendering_section] = STATE(3425),
    [sym_elements_section] = STATE(3425),
    [sym_schema_section] = STATE(3425),
    [sym_assembly_declaration] = STATE(3425),
    [sym_event_declaration] = STATE(3425),
    [sym_procedure] = STATE(3425),
    [sym_preproc_split_procedure] = STATE(3425),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3425),
    [sym_var_section] = STATE(3425),
    [sym_attribute_item] = STATE(3425),
    [sym_preproc_conditional] = STATE(3425),
    [sym_preproc_if] = STATE(2558),
    [aux_sym_report_dataitem_repeat1] = STATE(3425),
    [anon_sym_SEMI] = ACTIONS(9223),
    [anon_sym_RBRACE] = ACTIONS(6637),
    [anon_sym_LBRACK] = ACTIONS(9226),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9229),
    [aux_sym_modify_modification_token1] = ACTIONS(9232),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9235),
    [anon_sym_POUNDif] = ACTIONS(6634),
    [anon_sym_POUNDIF] = ACTIONS(6634),
    [anon_sym_POUNDIf] = ACTIONS(6634),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9238),
    [sym_trigger_keyword] = ACTIONS(9241),
    [sym_var_keyword] = ACTIONS(9244),
    [sym_local_keyword] = ACTIONS(9247),
    [sym_internal_keyword] = ACTIONS(6651),
    [sym_protected_keyword] = ACTIONS(9247),
    [sym_event_keyword] = ACTIONS(9250),
    [sym_fields_keyword] = ACTIONS(9253),
    [sym_keys_keyword] = ACTIONS(9256),
    [sym_fieldgroups_keyword] = ACTIONS(9259),
    [sym_actions_keyword] = ACTIONS(9262),
    [sym_layout_keyword] = ACTIONS(9265),
    [sym_dataset_keyword] = ACTIONS(9268),
    [sym_elements_keyword] = ACTIONS(9271),
    [sym_dataitem_keyword] = ACTIONS(9274),
    [sym_column_keyword] = ACTIONS(9277),
    [sym_labels_keyword] = ACTIONS(9280),
    [sym_rendering_keyword] = ACTIONS(9283),
    [sym_requestpage_keyword] = ACTIONS(9286),
    [sym_schema_keyword] = ACTIONS(9289),
    [sym_views_keyword] = ACTIONS(9292),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9295),
    [sym_preproc_open] = ACTIONS(6634),
  },
  [STATE(3426)] = {
    [sym_identifier] = ACTIONS(9141),
    [anon_sym_DASH] = ACTIONS(9143),
    [aux_sym_boolean_token1] = ACTIONS(9141),
    [aux_sym_boolean_token2] = ACTIONS(9141),
    [sym_decimal] = ACTIONS(9141),
    [anon_sym_LPAREN] = ACTIONS(9143),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9141),
    [anon_sym_LBRACK] = ACTIONS(9143),
    [aux_sym_record_type_token1] = ACTIONS(9141),
    [aux_sym_basic_type_token21] = ACTIONS(9141),
    [aux_sym_basic_type_token22] = ACTIONS(9141),
    [aux_sym_basic_type_token48] = ACTIONS(9141),
    [anon_sym_POUNDif] = ACTIONS(9143),
    [anon_sym_POUNDIF] = ACTIONS(9143),
    [anon_sym_POUNDIf] = ACTIONS(9143),
    [anon_sym_not] = ACTIONS(9141),
    [anon_sym_NOT] = ACTIONS(9141),
    [anon_sym_Not] = ACTIONS(9141),
    [anon_sym_POUNDelif] = ACTIONS(9143),
    [anon_sym_POUNDELIF] = ACTIONS(9143),
    [anon_sym_POUNDElif] = ACTIONS(9143),
    [anon_sym_POUNDelse] = ACTIONS(9143),
    [anon_sym_POUNDELSE] = ACTIONS(9143),
    [anon_sym_POUNDElse] = ACTIONS(9143),
    [anon_sym_POUNDendif] = ACTIONS(9143),
    [anon_sym_POUNDENDIF] = ACTIONS(9143),
    [anon_sym_POUNDEndif] = ACTIONS(9143),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9141),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9141),
    [anon_sym_PLUS] = ACTIONS(9143),
    [sym_datetime_literal] = ACTIONS(9143),
    [sym_date_literal] = ACTIONS(9141),
    [sym_time_literal] = ACTIONS(9141),
    [sym_biginteger_literal] = ACTIONS(9143),
    [anon_sym_else] = ACTIONS(9141),
    [anon_sym_ELSE] = ACTIONS(9141),
    [anon_sym_Else] = ACTIONS(9141),
    [sym_page_keyword] = ACTIONS(9141),
    [anon_sym_codeunit] = ACTIONS(9141),
    [anon_sym_CODEUNIT] = ACTIONS(9141),
    [anon_sym_Codeunit] = ACTIONS(9141),
    [anon_sym_CodeUnit] = ACTIONS(9141),
    [anon_sym_COdeunit] = ACTIONS(9141),
    [anon_sym_codeUnit] = ACTIONS(9141),
    [sym_report_keyword] = ACTIONS(9141),
    [sym_query_keyword] = ACTIONS(9141),
    [anon_sym_xmlport] = ACTIONS(9141),
    [anon_sym_XMLPORT] = ACTIONS(9141),
    [anon_sym_Xmlport] = ACTIONS(9141),
    [anon_sym_XMLport] = ACTIONS(9141),
    [anon_sym_XMLPort] = ACTIONS(9141),
    [anon_sym_XmlPort] = ACTIONS(9141),
    [anon_sym_enum] = ACTIONS(9141),
    [anon_sym_ENUM] = ACTIONS(9141),
    [anon_sym_Enum] = ACTIONS(9141),
    [anon_sym_eNUM] = ACTIONS(9141),
    [anon_sym_eNum] = ACTIONS(9141),
    [anon_sym_ENum] = ACTIONS(9141),
    [sym_quoted_identifier] = ACTIONS(9143),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9143),
    [sym_integer] = ACTIONS(9141),
    [sym_continue_as_identifier] = ACTIONS(9143),
    [sym_preproc_open] = ACTIONS(9143),
    [sym_preproc_close] = ACTIONS(9143),
  },
  [STATE(3427)] = {
    [sym_preproc_conditional_controladdin] = STATE(2885),
    [sym__body_element] = STATE(2885),
    [sym_empty_statement] = STATE(2885),
    [sym_property] = STATE(2885),
    [sym_fields_section] = STATE(2885),
    [sym_keys_section] = STATE(2885),
    [sym_fieldgroups_section] = STATE(2885),
    [sym_enum_value_declaration] = STATE(2885),
    [sym_labels_section] = STATE(2885),
    [sym_layout_section] = STATE(2885),
    [sym_modify_modification] = STATE(2885),
    [sym_actions_section] = STATE(2885),
    [sym_views_section] = STATE(2885),
    [sym_dataset_section] = STATE(2885),
    [sym_requestpage_section] = STATE(2885),
    [sym_rendering_section] = STATE(2885),
    [sym_elements_section] = STATE(2885),
    [sym_schema_section] = STATE(2885),
    [sym_assembly_declaration] = STATE(2885),
    [sym_event_declaration] = STATE(2885),
    [sym_procedure] = STATE(2885),
    [sym_preproc_split_procedure] = STATE(2885),
    [sym_interface_procedure] = STATE(2885),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2885),
    [sym_var_section] = STATE(2885),
    [sym_attribute_item] = STATE(2885),
    [sym_preproc_conditional] = STATE(2885),
    [sym_preproc_if] = STATE(2635),
    [sym_preproc_endif] = STATE(6256),
    [aux_sym_controladdin_declaration_repeat1] = STATE(2885),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3428)] = {
    [sym_preproc_conditional_controladdin] = STATE(3390),
    [sym__body_element] = STATE(3390),
    [sym_empty_statement] = STATE(3390),
    [sym_property] = STATE(3390),
    [sym_fields_section] = STATE(3390),
    [sym_keys_section] = STATE(3390),
    [sym_fieldgroups_section] = STATE(3390),
    [sym_enum_value_declaration] = STATE(3390),
    [sym_labels_section] = STATE(3390),
    [sym_layout_section] = STATE(3390),
    [sym_modify_modification] = STATE(3390),
    [sym_actions_section] = STATE(3390),
    [sym_views_section] = STATE(3390),
    [sym_dataset_section] = STATE(3390),
    [sym_requestpage_section] = STATE(3390),
    [sym_rendering_section] = STATE(3390),
    [sym_elements_section] = STATE(3390),
    [sym_schema_section] = STATE(3390),
    [sym_assembly_declaration] = STATE(3390),
    [sym_event_declaration] = STATE(3390),
    [sym_procedure] = STATE(3390),
    [sym_preproc_split_procedure] = STATE(3390),
    [sym_interface_procedure] = STATE(3390),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3390),
    [sym_var_section] = STATE(3390),
    [sym_attribute_item] = STATE(3390),
    [sym_preproc_conditional] = STATE(3390),
    [sym_preproc_if] = STATE(2635),
    [sym_preproc_endif] = STATE(6256),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3390),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3429)] = {
    [sym_identifier] = ACTIONS(9298),
    [anon_sym_DASH] = ACTIONS(9300),
    [aux_sym_boolean_token1] = ACTIONS(9298),
    [aux_sym_boolean_token2] = ACTIONS(9298),
    [sym_decimal] = ACTIONS(9298),
    [anon_sym_LPAREN] = ACTIONS(9300),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9298),
    [anon_sym_LBRACK] = ACTIONS(9300),
    [aux_sym_record_type_token1] = ACTIONS(9298),
    [aux_sym_basic_type_token21] = ACTIONS(9298),
    [aux_sym_basic_type_token22] = ACTIONS(9298),
    [aux_sym_basic_type_token48] = ACTIONS(9298),
    [anon_sym_POUNDif] = ACTIONS(9300),
    [anon_sym_POUNDIF] = ACTIONS(9300),
    [anon_sym_POUNDIf] = ACTIONS(9300),
    [anon_sym_not] = ACTIONS(9298),
    [anon_sym_NOT] = ACTIONS(9298),
    [anon_sym_Not] = ACTIONS(9298),
    [anon_sym_POUNDelif] = ACTIONS(9300),
    [anon_sym_POUNDELIF] = ACTIONS(9300),
    [anon_sym_POUNDElif] = ACTIONS(9300),
    [anon_sym_POUNDelse] = ACTIONS(9300),
    [anon_sym_POUNDELSE] = ACTIONS(9300),
    [anon_sym_POUNDElse] = ACTIONS(9300),
    [anon_sym_POUNDendif] = ACTIONS(9300),
    [anon_sym_POUNDENDIF] = ACTIONS(9300),
    [anon_sym_POUNDEndif] = ACTIONS(9300),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9298),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9298),
    [anon_sym_PLUS] = ACTIONS(9300),
    [sym_datetime_literal] = ACTIONS(9300),
    [sym_date_literal] = ACTIONS(9298),
    [sym_time_literal] = ACTIONS(9298),
    [sym_biginteger_literal] = ACTIONS(9300),
    [anon_sym_else] = ACTIONS(9298),
    [anon_sym_ELSE] = ACTIONS(9298),
    [anon_sym_Else] = ACTIONS(9298),
    [sym_page_keyword] = ACTIONS(9298),
    [anon_sym_codeunit] = ACTIONS(9298),
    [anon_sym_CODEUNIT] = ACTIONS(9298),
    [anon_sym_Codeunit] = ACTIONS(9298),
    [anon_sym_CodeUnit] = ACTIONS(9298),
    [anon_sym_COdeunit] = ACTIONS(9298),
    [anon_sym_codeUnit] = ACTIONS(9298),
    [sym_report_keyword] = ACTIONS(9298),
    [sym_query_keyword] = ACTIONS(9298),
    [anon_sym_xmlport] = ACTIONS(9298),
    [anon_sym_XMLPORT] = ACTIONS(9298),
    [anon_sym_Xmlport] = ACTIONS(9298),
    [anon_sym_XMLport] = ACTIONS(9298),
    [anon_sym_XMLPort] = ACTIONS(9298),
    [anon_sym_XmlPort] = ACTIONS(9298),
    [anon_sym_enum] = ACTIONS(9298),
    [anon_sym_ENUM] = ACTIONS(9298),
    [anon_sym_Enum] = ACTIONS(9298),
    [anon_sym_eNUM] = ACTIONS(9298),
    [anon_sym_eNum] = ACTIONS(9298),
    [anon_sym_ENum] = ACTIONS(9298),
    [sym_quoted_identifier] = ACTIONS(9300),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9300),
    [sym_integer] = ACTIONS(9298),
    [sym_continue_as_identifier] = ACTIONS(9300),
    [sym_preproc_open] = ACTIONS(9300),
    [sym_preproc_close] = ACTIONS(9300),
  },
  [STATE(3430)] = {
    [sym_preproc_conditional_controladdin] = STATE(2885),
    [sym__body_element] = STATE(2885),
    [sym_empty_statement] = STATE(2885),
    [sym_property] = STATE(2885),
    [sym_fields_section] = STATE(2885),
    [sym_keys_section] = STATE(2885),
    [sym_fieldgroups_section] = STATE(2885),
    [sym_enum_value_declaration] = STATE(2885),
    [sym_labels_section] = STATE(2885),
    [sym_layout_section] = STATE(2885),
    [sym_modify_modification] = STATE(2885),
    [sym_actions_section] = STATE(2885),
    [sym_views_section] = STATE(2885),
    [sym_dataset_section] = STATE(2885),
    [sym_requestpage_section] = STATE(2885),
    [sym_rendering_section] = STATE(2885),
    [sym_elements_section] = STATE(2885),
    [sym_schema_section] = STATE(2885),
    [sym_assembly_declaration] = STATE(2885),
    [sym_event_declaration] = STATE(2885),
    [sym_procedure] = STATE(2885),
    [sym_preproc_split_procedure] = STATE(2885),
    [sym_interface_procedure] = STATE(2885),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(2885),
    [sym_var_section] = STATE(2885),
    [sym_attribute_item] = STATE(2885),
    [sym_preproc_conditional] = STATE(2885),
    [sym_preproc_if] = STATE(2635),
    [sym_preproc_endif] = STATE(6251),
    [aux_sym_controladdin_declaration_repeat1] = STATE(2885),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6540),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3431)] = {
    [sym_identifier] = ACTIONS(9302),
    [anon_sym_DASH] = ACTIONS(9304),
    [aux_sym_boolean_token1] = ACTIONS(9302),
    [aux_sym_boolean_token2] = ACTIONS(9302),
    [sym_decimal] = ACTIONS(9302),
    [anon_sym_LPAREN] = ACTIONS(9304),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9302),
    [anon_sym_LBRACK] = ACTIONS(9304),
    [aux_sym_record_type_token1] = ACTIONS(9302),
    [aux_sym_basic_type_token21] = ACTIONS(9302),
    [aux_sym_basic_type_token22] = ACTIONS(9302),
    [aux_sym_basic_type_token48] = ACTIONS(9302),
    [anon_sym_POUNDif] = ACTIONS(9304),
    [anon_sym_POUNDIF] = ACTIONS(9304),
    [anon_sym_POUNDIf] = ACTIONS(9304),
    [anon_sym_not] = ACTIONS(9302),
    [anon_sym_NOT] = ACTIONS(9302),
    [anon_sym_Not] = ACTIONS(9302),
    [anon_sym_POUNDelif] = ACTIONS(9304),
    [anon_sym_POUNDELIF] = ACTIONS(9304),
    [anon_sym_POUNDElif] = ACTIONS(9304),
    [anon_sym_POUNDelse] = ACTIONS(9304),
    [anon_sym_POUNDELSE] = ACTIONS(9304),
    [anon_sym_POUNDElse] = ACTIONS(9304),
    [anon_sym_POUNDendif] = ACTIONS(9304),
    [anon_sym_POUNDENDIF] = ACTIONS(9304),
    [anon_sym_POUNDEndif] = ACTIONS(9304),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9302),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9302),
    [anon_sym_PLUS] = ACTIONS(9304),
    [sym_datetime_literal] = ACTIONS(9304),
    [sym_date_literal] = ACTIONS(9302),
    [sym_time_literal] = ACTIONS(9302),
    [sym_biginteger_literal] = ACTIONS(9304),
    [anon_sym_else] = ACTIONS(9302),
    [anon_sym_ELSE] = ACTIONS(9302),
    [anon_sym_Else] = ACTIONS(9302),
    [sym_page_keyword] = ACTIONS(9302),
    [anon_sym_codeunit] = ACTIONS(9302),
    [anon_sym_CODEUNIT] = ACTIONS(9302),
    [anon_sym_Codeunit] = ACTIONS(9302),
    [anon_sym_CodeUnit] = ACTIONS(9302),
    [anon_sym_COdeunit] = ACTIONS(9302),
    [anon_sym_codeUnit] = ACTIONS(9302),
    [sym_report_keyword] = ACTIONS(9302),
    [sym_query_keyword] = ACTIONS(9302),
    [anon_sym_xmlport] = ACTIONS(9302),
    [anon_sym_XMLPORT] = ACTIONS(9302),
    [anon_sym_Xmlport] = ACTIONS(9302),
    [anon_sym_XMLport] = ACTIONS(9302),
    [anon_sym_XMLPort] = ACTIONS(9302),
    [anon_sym_XmlPort] = ACTIONS(9302),
    [anon_sym_enum] = ACTIONS(9302),
    [anon_sym_ENUM] = ACTIONS(9302),
    [anon_sym_Enum] = ACTIONS(9302),
    [anon_sym_eNUM] = ACTIONS(9302),
    [anon_sym_eNum] = ACTIONS(9302),
    [anon_sym_ENum] = ACTIONS(9302),
    [sym_quoted_identifier] = ACTIONS(9304),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9304),
    [sym_integer] = ACTIONS(9302),
    [sym_continue_as_identifier] = ACTIONS(9304),
    [sym_preproc_open] = ACTIONS(9304),
    [sym_preproc_close] = ACTIONS(9304),
  },
  [STATE(3432)] = {
    [sym_identifier] = ACTIONS(9107),
    [anon_sym_DASH] = ACTIONS(9109),
    [aux_sym_boolean_token1] = ACTIONS(9107),
    [aux_sym_boolean_token2] = ACTIONS(9107),
    [sym_decimal] = ACTIONS(9107),
    [anon_sym_LPAREN] = ACTIONS(9109),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9107),
    [anon_sym_LBRACK] = ACTIONS(9109),
    [aux_sym_record_type_token1] = ACTIONS(9107),
    [aux_sym_basic_type_token21] = ACTIONS(9107),
    [aux_sym_basic_type_token22] = ACTIONS(9107),
    [aux_sym_basic_type_token48] = ACTIONS(9107),
    [anon_sym_POUNDif] = ACTIONS(9109),
    [anon_sym_POUNDIF] = ACTIONS(9109),
    [anon_sym_POUNDIf] = ACTIONS(9109),
    [anon_sym_not] = ACTIONS(9107),
    [anon_sym_NOT] = ACTIONS(9107),
    [anon_sym_Not] = ACTIONS(9107),
    [anon_sym_POUNDelif] = ACTIONS(9109),
    [anon_sym_POUNDELIF] = ACTIONS(9109),
    [anon_sym_POUNDElif] = ACTIONS(9109),
    [anon_sym_POUNDelse] = ACTIONS(9109),
    [anon_sym_POUNDELSE] = ACTIONS(9109),
    [anon_sym_POUNDElse] = ACTIONS(9109),
    [anon_sym_POUNDendif] = ACTIONS(9109),
    [anon_sym_POUNDENDIF] = ACTIONS(9109),
    [anon_sym_POUNDEndif] = ACTIONS(9109),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9107),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9107),
    [anon_sym_PLUS] = ACTIONS(9109),
    [sym_datetime_literal] = ACTIONS(9109),
    [sym_date_literal] = ACTIONS(9107),
    [sym_time_literal] = ACTIONS(9107),
    [sym_biginteger_literal] = ACTIONS(9109),
    [anon_sym_else] = ACTIONS(9107),
    [anon_sym_ELSE] = ACTIONS(9107),
    [anon_sym_Else] = ACTIONS(9107),
    [sym_page_keyword] = ACTIONS(9107),
    [anon_sym_codeunit] = ACTIONS(9107),
    [anon_sym_CODEUNIT] = ACTIONS(9107),
    [anon_sym_Codeunit] = ACTIONS(9107),
    [anon_sym_CodeUnit] = ACTIONS(9107),
    [anon_sym_COdeunit] = ACTIONS(9107),
    [anon_sym_codeUnit] = ACTIONS(9107),
    [sym_report_keyword] = ACTIONS(9107),
    [sym_query_keyword] = ACTIONS(9107),
    [anon_sym_xmlport] = ACTIONS(9107),
    [anon_sym_XMLPORT] = ACTIONS(9107),
    [anon_sym_Xmlport] = ACTIONS(9107),
    [anon_sym_XMLport] = ACTIONS(9107),
    [anon_sym_XMLPort] = ACTIONS(9107),
    [anon_sym_XmlPort] = ACTIONS(9107),
    [anon_sym_enum] = ACTIONS(9107),
    [anon_sym_ENUM] = ACTIONS(9107),
    [anon_sym_Enum] = ACTIONS(9107),
    [anon_sym_eNUM] = ACTIONS(9107),
    [anon_sym_eNum] = ACTIONS(9107),
    [anon_sym_ENum] = ACTIONS(9107),
    [sym_quoted_identifier] = ACTIONS(9109),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9109),
    [sym_integer] = ACTIONS(9107),
    [sym_continue_as_identifier] = ACTIONS(9109),
    [sym_preproc_open] = ACTIONS(9109),
    [sym_preproc_close] = ACTIONS(9109),
  },
  [STATE(3433)] = {
    [sym_identifier] = ACTIONS(9306),
    [anon_sym_DASH] = ACTIONS(9308),
    [aux_sym_boolean_token1] = ACTIONS(9306),
    [aux_sym_boolean_token2] = ACTIONS(9306),
    [sym_decimal] = ACTIONS(9306),
    [anon_sym_LPAREN] = ACTIONS(9308),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9306),
    [anon_sym_LBRACK] = ACTIONS(9308),
    [aux_sym_record_type_token1] = ACTIONS(9306),
    [aux_sym_basic_type_token21] = ACTIONS(9306),
    [aux_sym_basic_type_token22] = ACTIONS(9306),
    [aux_sym_basic_type_token48] = ACTIONS(9306),
    [anon_sym_POUNDif] = ACTIONS(9308),
    [anon_sym_POUNDIF] = ACTIONS(9308),
    [anon_sym_POUNDIf] = ACTIONS(9308),
    [anon_sym_not] = ACTIONS(9306),
    [anon_sym_NOT] = ACTIONS(9306),
    [anon_sym_Not] = ACTIONS(9306),
    [anon_sym_POUNDelif] = ACTIONS(9308),
    [anon_sym_POUNDELIF] = ACTIONS(9308),
    [anon_sym_POUNDElif] = ACTIONS(9308),
    [anon_sym_POUNDelse] = ACTIONS(9308),
    [anon_sym_POUNDELSE] = ACTIONS(9308),
    [anon_sym_POUNDElse] = ACTIONS(9308),
    [anon_sym_POUNDendif] = ACTIONS(9308),
    [anon_sym_POUNDENDIF] = ACTIONS(9308),
    [anon_sym_POUNDEndif] = ACTIONS(9308),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9306),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9306),
    [anon_sym_PLUS] = ACTIONS(9308),
    [sym_datetime_literal] = ACTIONS(9308),
    [sym_date_literal] = ACTIONS(9306),
    [sym_time_literal] = ACTIONS(9306),
    [sym_biginteger_literal] = ACTIONS(9308),
    [anon_sym_else] = ACTIONS(9306),
    [anon_sym_ELSE] = ACTIONS(9306),
    [anon_sym_Else] = ACTIONS(9306),
    [sym_page_keyword] = ACTIONS(9306),
    [anon_sym_codeunit] = ACTIONS(9306),
    [anon_sym_CODEUNIT] = ACTIONS(9306),
    [anon_sym_Codeunit] = ACTIONS(9306),
    [anon_sym_CodeUnit] = ACTIONS(9306),
    [anon_sym_COdeunit] = ACTIONS(9306),
    [anon_sym_codeUnit] = ACTIONS(9306),
    [sym_report_keyword] = ACTIONS(9306),
    [sym_query_keyword] = ACTIONS(9306),
    [anon_sym_xmlport] = ACTIONS(9306),
    [anon_sym_XMLPORT] = ACTIONS(9306),
    [anon_sym_Xmlport] = ACTIONS(9306),
    [anon_sym_XMLport] = ACTIONS(9306),
    [anon_sym_XMLPort] = ACTIONS(9306),
    [anon_sym_XmlPort] = ACTIONS(9306),
    [anon_sym_enum] = ACTIONS(9306),
    [anon_sym_ENUM] = ACTIONS(9306),
    [anon_sym_Enum] = ACTIONS(9306),
    [anon_sym_eNUM] = ACTIONS(9306),
    [anon_sym_eNum] = ACTIONS(9306),
    [anon_sym_ENum] = ACTIONS(9306),
    [sym_quoted_identifier] = ACTIONS(9308),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9308),
    [sym_integer] = ACTIONS(9306),
    [sym_continue_as_identifier] = ACTIONS(9308),
    [sym_preproc_open] = ACTIONS(9308),
    [sym_preproc_close] = ACTIONS(9308),
  },
  [STATE(3434)] = {
    [sym_identifier] = ACTIONS(9310),
    [anon_sym_DASH] = ACTIONS(9312),
    [aux_sym_boolean_token1] = ACTIONS(9310),
    [aux_sym_boolean_token2] = ACTIONS(9310),
    [sym_decimal] = ACTIONS(9310),
    [anon_sym_LPAREN] = ACTIONS(9312),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9310),
    [anon_sym_LBRACK] = ACTIONS(9312),
    [aux_sym_record_type_token1] = ACTIONS(9310),
    [aux_sym_basic_type_token21] = ACTIONS(9310),
    [aux_sym_basic_type_token22] = ACTIONS(9310),
    [aux_sym_basic_type_token48] = ACTIONS(9310),
    [anon_sym_POUNDif] = ACTIONS(9312),
    [anon_sym_POUNDIF] = ACTIONS(9312),
    [anon_sym_POUNDIf] = ACTIONS(9312),
    [anon_sym_not] = ACTIONS(9310),
    [anon_sym_NOT] = ACTIONS(9310),
    [anon_sym_Not] = ACTIONS(9310),
    [anon_sym_POUNDelif] = ACTIONS(9312),
    [anon_sym_POUNDELIF] = ACTIONS(9312),
    [anon_sym_POUNDElif] = ACTIONS(9312),
    [anon_sym_POUNDelse] = ACTIONS(9312),
    [anon_sym_POUNDELSE] = ACTIONS(9312),
    [anon_sym_POUNDElse] = ACTIONS(9312),
    [anon_sym_POUNDendif] = ACTIONS(9312),
    [anon_sym_POUNDENDIF] = ACTIONS(9312),
    [anon_sym_POUNDEndif] = ACTIONS(9312),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9310),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9310),
    [anon_sym_PLUS] = ACTIONS(9312),
    [sym_datetime_literal] = ACTIONS(9312),
    [sym_date_literal] = ACTIONS(9310),
    [sym_time_literal] = ACTIONS(9310),
    [sym_biginteger_literal] = ACTIONS(9312),
    [anon_sym_else] = ACTIONS(9310),
    [anon_sym_ELSE] = ACTIONS(9310),
    [anon_sym_Else] = ACTIONS(9310),
    [sym_page_keyword] = ACTIONS(9310),
    [anon_sym_codeunit] = ACTIONS(9310),
    [anon_sym_CODEUNIT] = ACTIONS(9310),
    [anon_sym_Codeunit] = ACTIONS(9310),
    [anon_sym_CodeUnit] = ACTIONS(9310),
    [anon_sym_COdeunit] = ACTIONS(9310),
    [anon_sym_codeUnit] = ACTIONS(9310),
    [sym_report_keyword] = ACTIONS(9310),
    [sym_query_keyword] = ACTIONS(9310),
    [anon_sym_xmlport] = ACTIONS(9310),
    [anon_sym_XMLPORT] = ACTIONS(9310),
    [anon_sym_Xmlport] = ACTIONS(9310),
    [anon_sym_XMLport] = ACTIONS(9310),
    [anon_sym_XMLPort] = ACTIONS(9310),
    [anon_sym_XmlPort] = ACTIONS(9310),
    [anon_sym_enum] = ACTIONS(9310),
    [anon_sym_ENUM] = ACTIONS(9310),
    [anon_sym_Enum] = ACTIONS(9310),
    [anon_sym_eNUM] = ACTIONS(9310),
    [anon_sym_eNum] = ACTIONS(9310),
    [anon_sym_ENum] = ACTIONS(9310),
    [sym_quoted_identifier] = ACTIONS(9312),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9312),
    [sym_integer] = ACTIONS(9310),
    [sym_continue_as_identifier] = ACTIONS(9312),
    [sym_preproc_open] = ACTIONS(9312),
    [sym_preproc_close] = ACTIONS(9312),
  },
  [STATE(3435)] = {
    [sym_identifier] = ACTIONS(9314),
    [anon_sym_DASH] = ACTIONS(9316),
    [aux_sym_boolean_token1] = ACTIONS(9314),
    [aux_sym_boolean_token2] = ACTIONS(9314),
    [sym_decimal] = ACTIONS(9314),
    [anon_sym_LPAREN] = ACTIONS(9316),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9314),
    [anon_sym_LBRACK] = ACTIONS(9316),
    [aux_sym_record_type_token1] = ACTIONS(9314),
    [aux_sym_basic_type_token21] = ACTIONS(9314),
    [aux_sym_basic_type_token22] = ACTIONS(9314),
    [aux_sym_basic_type_token48] = ACTIONS(9314),
    [anon_sym_POUNDif] = ACTIONS(9316),
    [anon_sym_POUNDIF] = ACTIONS(9316),
    [anon_sym_POUNDIf] = ACTIONS(9316),
    [anon_sym_not] = ACTIONS(9314),
    [anon_sym_NOT] = ACTIONS(9314),
    [anon_sym_Not] = ACTIONS(9314),
    [anon_sym_POUNDelif] = ACTIONS(9316),
    [anon_sym_POUNDELIF] = ACTIONS(9316),
    [anon_sym_POUNDElif] = ACTIONS(9316),
    [anon_sym_POUNDelse] = ACTIONS(9316),
    [anon_sym_POUNDELSE] = ACTIONS(9316),
    [anon_sym_POUNDElse] = ACTIONS(9316),
    [anon_sym_POUNDendif] = ACTIONS(9316),
    [anon_sym_POUNDENDIF] = ACTIONS(9316),
    [anon_sym_POUNDEndif] = ACTIONS(9316),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9314),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9314),
    [anon_sym_PLUS] = ACTIONS(9316),
    [sym_datetime_literal] = ACTIONS(9316),
    [sym_date_literal] = ACTIONS(9314),
    [sym_time_literal] = ACTIONS(9314),
    [sym_biginteger_literal] = ACTIONS(9316),
    [anon_sym_else] = ACTIONS(9314),
    [anon_sym_ELSE] = ACTIONS(9314),
    [anon_sym_Else] = ACTIONS(9314),
    [sym_page_keyword] = ACTIONS(9314),
    [anon_sym_codeunit] = ACTIONS(9314),
    [anon_sym_CODEUNIT] = ACTIONS(9314),
    [anon_sym_Codeunit] = ACTIONS(9314),
    [anon_sym_CodeUnit] = ACTIONS(9314),
    [anon_sym_COdeunit] = ACTIONS(9314),
    [anon_sym_codeUnit] = ACTIONS(9314),
    [sym_report_keyword] = ACTIONS(9314),
    [sym_query_keyword] = ACTIONS(9314),
    [anon_sym_xmlport] = ACTIONS(9314),
    [anon_sym_XMLPORT] = ACTIONS(9314),
    [anon_sym_Xmlport] = ACTIONS(9314),
    [anon_sym_XMLport] = ACTIONS(9314),
    [anon_sym_XMLPort] = ACTIONS(9314),
    [anon_sym_XmlPort] = ACTIONS(9314),
    [anon_sym_enum] = ACTIONS(9314),
    [anon_sym_ENUM] = ACTIONS(9314),
    [anon_sym_Enum] = ACTIONS(9314),
    [anon_sym_eNUM] = ACTIONS(9314),
    [anon_sym_eNum] = ACTIONS(9314),
    [anon_sym_ENum] = ACTIONS(9314),
    [sym_quoted_identifier] = ACTIONS(9316),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9316),
    [sym_integer] = ACTIONS(9314),
    [sym_continue_as_identifier] = ACTIONS(9316),
    [sym_preproc_open] = ACTIONS(9316),
    [sym_preproc_close] = ACTIONS(9316),
  },
  [STATE(3436)] = {
    [sym_identifier] = ACTIONS(9318),
    [anon_sym_DASH] = ACTIONS(9320),
    [aux_sym_boolean_token1] = ACTIONS(9318),
    [aux_sym_boolean_token2] = ACTIONS(9318),
    [sym_decimal] = ACTIONS(9318),
    [anon_sym_LPAREN] = ACTIONS(9320),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9318),
    [anon_sym_LBRACK] = ACTIONS(9320),
    [aux_sym_record_type_token1] = ACTIONS(9318),
    [aux_sym_basic_type_token21] = ACTIONS(9318),
    [aux_sym_basic_type_token22] = ACTIONS(9318),
    [aux_sym_basic_type_token48] = ACTIONS(9318),
    [anon_sym_POUNDif] = ACTIONS(9320),
    [anon_sym_POUNDIF] = ACTIONS(9320),
    [anon_sym_POUNDIf] = ACTIONS(9320),
    [anon_sym_not] = ACTIONS(9318),
    [anon_sym_NOT] = ACTIONS(9318),
    [anon_sym_Not] = ACTIONS(9318),
    [anon_sym_POUNDelif] = ACTIONS(9320),
    [anon_sym_POUNDELIF] = ACTIONS(9320),
    [anon_sym_POUNDElif] = ACTIONS(9320),
    [anon_sym_POUNDelse] = ACTIONS(9320),
    [anon_sym_POUNDELSE] = ACTIONS(9320),
    [anon_sym_POUNDElse] = ACTIONS(9320),
    [anon_sym_POUNDendif] = ACTIONS(9320),
    [anon_sym_POUNDENDIF] = ACTIONS(9320),
    [anon_sym_POUNDEndif] = ACTIONS(9320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9318),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9318),
    [anon_sym_PLUS] = ACTIONS(9320),
    [sym_datetime_literal] = ACTIONS(9320),
    [sym_date_literal] = ACTIONS(9318),
    [sym_time_literal] = ACTIONS(9318),
    [sym_biginteger_literal] = ACTIONS(9320),
    [anon_sym_else] = ACTIONS(9318),
    [anon_sym_ELSE] = ACTIONS(9318),
    [anon_sym_Else] = ACTIONS(9318),
    [sym_page_keyword] = ACTIONS(9318),
    [anon_sym_codeunit] = ACTIONS(9318),
    [anon_sym_CODEUNIT] = ACTIONS(9318),
    [anon_sym_Codeunit] = ACTIONS(9318),
    [anon_sym_CodeUnit] = ACTIONS(9318),
    [anon_sym_COdeunit] = ACTIONS(9318),
    [anon_sym_codeUnit] = ACTIONS(9318),
    [sym_report_keyword] = ACTIONS(9318),
    [sym_query_keyword] = ACTIONS(9318),
    [anon_sym_xmlport] = ACTIONS(9318),
    [anon_sym_XMLPORT] = ACTIONS(9318),
    [anon_sym_Xmlport] = ACTIONS(9318),
    [anon_sym_XMLport] = ACTIONS(9318),
    [anon_sym_XMLPort] = ACTIONS(9318),
    [anon_sym_XmlPort] = ACTIONS(9318),
    [anon_sym_enum] = ACTIONS(9318),
    [anon_sym_ENUM] = ACTIONS(9318),
    [anon_sym_Enum] = ACTIONS(9318),
    [anon_sym_eNUM] = ACTIONS(9318),
    [anon_sym_eNum] = ACTIONS(9318),
    [anon_sym_ENum] = ACTIONS(9318),
    [sym_quoted_identifier] = ACTIONS(9320),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9320),
    [sym_integer] = ACTIONS(9318),
    [sym_continue_as_identifier] = ACTIONS(9320),
    [sym_preproc_open] = ACTIONS(9320),
    [sym_preproc_close] = ACTIONS(9320),
  },
  [STATE(3437)] = {
    [aux_sym_where_condition_token1] = ACTIONS(5449),
    [anon_sym_LBRACK] = ACTIONS(5449),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(5449),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_if] = ACTIONS(5449),
    [anon_sym_IF] = ACTIONS(5449),
    [anon_sym_If] = ACTIONS(5449),
    [sym_table_keyword] = ACTIONS(5447),
    [anon_sym_tableextension] = ACTIONS(5449),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5449),
    [anon_sym_Tableextension] = ACTIONS(5449),
    [anon_sym_TableExtension] = ACTIONS(5449),
    [anon_sym_tableExtension] = ACTIONS(5449),
    [sym_page_keyword] = ACTIONS(5447),
    [anon_sym_pageextension] = ACTIONS(5449),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5449),
    [anon_sym_Pageextension] = ACTIONS(5449),
    [anon_sym_PageExtension] = ACTIONS(5449),
    [anon_sym_pageExtension] = ACTIONS(5449),
    [anon_sym_codeunit] = ACTIONS(5449),
    [anon_sym_CODEUNIT] = ACTIONS(5449),
    [anon_sym_Codeunit] = ACTIONS(5449),
    [anon_sym_CodeUnit] = ACTIONS(5449),
    [anon_sym_COdeunit] = ACTIONS(5449),
    [anon_sym_codeUnit] = ACTIONS(5449),
    [sym_report_keyword] = ACTIONS(5447),
    [anon_sym_reportextension] = ACTIONS(5449),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5449),
    [anon_sym_Reportextension] = ACTIONS(5449),
    [anon_sym_ReportExtension] = ACTIONS(5449),
    [anon_sym_reportExtension] = ACTIONS(5449),
    [sym_query_keyword] = ACTIONS(5449),
    [anon_sym_xmlport] = ACTIONS(5449),
    [anon_sym_XMLPORT] = ACTIONS(5449),
    [anon_sym_Xmlport] = ACTIONS(5449),
    [anon_sym_XMLport] = ACTIONS(5449),
    [anon_sym_XMLPort] = ACTIONS(5449),
    [anon_sym_XmlPort] = ACTIONS(5449),
    [anon_sym_enum] = ACTIONS(5447),
    [anon_sym_ENUM] = ACTIONS(5447),
    [anon_sym_Enum] = ACTIONS(5447),
    [anon_sym_eNUM] = ACTIONS(5449),
    [anon_sym_eNum] = ACTIONS(5449),
    [anon_sym_ENum] = ACTIONS(5449),
    [anon_sym_enumextension] = ACTIONS(5449),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5449),
    [anon_sym_Enumextension] = ACTIONS(5449),
    [anon_sym_EnumExtension] = ACTIONS(5449),
    [anon_sym_enumExtension] = ACTIONS(5449),
    [sym_interface_keyword] = ACTIONS(5449),
    [anon_sym_permissionset] = ACTIONS(5447),
    [anon_sym_PERMISSIONSET] = ACTIONS(5447),
    [anon_sym_Permissionset] = ACTIONS(5447),
    [anon_sym_PermissionSet] = ACTIONS(5447),
    [anon_sym_permissionSet] = ACTIONS(5447),
    [anon_sym_permissionsetextension] = ACTIONS(5449),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5449),
    [anon_sym_Permissionsetextension] = ACTIONS(5449),
    [anon_sym_PermissionSetExtension] = ACTIONS(5449),
    [anon_sym_permissionSetExtension] = ACTIONS(5449),
    [sym_procedure_keyword] = ACTIONS(5449),
    [sym_var_keyword] = ACTIONS(5449),
    [sym_local_keyword] = ACTIONS(5449),
    [sym_internal_keyword] = ACTIONS(5449),
    [sym_protected_keyword] = ACTIONS(5449),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(3438)] = {
    [sym_identifier] = ACTIONS(9298),
    [anon_sym_DASH] = ACTIONS(9300),
    [aux_sym_boolean_token1] = ACTIONS(9298),
    [aux_sym_boolean_token2] = ACTIONS(9298),
    [sym_decimal] = ACTIONS(9298),
    [anon_sym_LPAREN] = ACTIONS(9300),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9298),
    [anon_sym_LBRACK] = ACTIONS(9300),
    [aux_sym_record_type_token1] = ACTIONS(9298),
    [aux_sym_basic_type_token21] = ACTIONS(9298),
    [aux_sym_basic_type_token22] = ACTIONS(9298),
    [aux_sym_basic_type_token48] = ACTIONS(9298),
    [anon_sym_POUNDif] = ACTIONS(9300),
    [anon_sym_POUNDIF] = ACTIONS(9300),
    [anon_sym_POUNDIf] = ACTIONS(9300),
    [anon_sym_not] = ACTIONS(9298),
    [anon_sym_NOT] = ACTIONS(9298),
    [anon_sym_Not] = ACTIONS(9298),
    [anon_sym_POUNDelif] = ACTIONS(9300),
    [anon_sym_POUNDELIF] = ACTIONS(9300),
    [anon_sym_POUNDElif] = ACTIONS(9300),
    [anon_sym_POUNDelse] = ACTIONS(9300),
    [anon_sym_POUNDELSE] = ACTIONS(9300),
    [anon_sym_POUNDElse] = ACTIONS(9300),
    [anon_sym_POUNDendif] = ACTIONS(9300),
    [anon_sym_POUNDENDIF] = ACTIONS(9300),
    [anon_sym_POUNDEndif] = ACTIONS(9300),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9298),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9298),
    [anon_sym_PLUS] = ACTIONS(9300),
    [sym_datetime_literal] = ACTIONS(9300),
    [sym_date_literal] = ACTIONS(9298),
    [sym_time_literal] = ACTIONS(9298),
    [sym_biginteger_literal] = ACTIONS(9300),
    [anon_sym_else] = ACTIONS(9298),
    [anon_sym_ELSE] = ACTIONS(9298),
    [anon_sym_Else] = ACTIONS(9298),
    [sym_page_keyword] = ACTIONS(9298),
    [anon_sym_codeunit] = ACTIONS(9298),
    [anon_sym_CODEUNIT] = ACTIONS(9298),
    [anon_sym_Codeunit] = ACTIONS(9298),
    [anon_sym_CodeUnit] = ACTIONS(9298),
    [anon_sym_COdeunit] = ACTIONS(9298),
    [anon_sym_codeUnit] = ACTIONS(9298),
    [sym_report_keyword] = ACTIONS(9298),
    [sym_query_keyword] = ACTIONS(9298),
    [anon_sym_xmlport] = ACTIONS(9298),
    [anon_sym_XMLPORT] = ACTIONS(9298),
    [anon_sym_Xmlport] = ACTIONS(9298),
    [anon_sym_XMLport] = ACTIONS(9298),
    [anon_sym_XMLPort] = ACTIONS(9298),
    [anon_sym_XmlPort] = ACTIONS(9298),
    [anon_sym_enum] = ACTIONS(9298),
    [anon_sym_ENUM] = ACTIONS(9298),
    [anon_sym_Enum] = ACTIONS(9298),
    [anon_sym_eNUM] = ACTIONS(9298),
    [anon_sym_eNum] = ACTIONS(9298),
    [anon_sym_ENum] = ACTIONS(9298),
    [sym_quoted_identifier] = ACTIONS(9300),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9300),
    [sym_integer] = ACTIONS(9298),
    [sym_continue_as_identifier] = ACTIONS(9300),
    [sym_preproc_open] = ACTIONS(9300),
    [sym_preproc_close] = ACTIONS(9300),
  },
  [STATE(3439)] = {
    [sym_identifier] = ACTIONS(9322),
    [anon_sym_DASH] = ACTIONS(9324),
    [aux_sym_boolean_token1] = ACTIONS(9322),
    [aux_sym_boolean_token2] = ACTIONS(9322),
    [sym_decimal] = ACTIONS(9322),
    [anon_sym_LPAREN] = ACTIONS(9324),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9322),
    [anon_sym_LBRACK] = ACTIONS(9324),
    [aux_sym_record_type_token1] = ACTIONS(9322),
    [aux_sym_basic_type_token21] = ACTIONS(9322),
    [aux_sym_basic_type_token22] = ACTIONS(9322),
    [aux_sym_basic_type_token48] = ACTIONS(9322),
    [anon_sym_POUNDif] = ACTIONS(9324),
    [anon_sym_POUNDIF] = ACTIONS(9324),
    [anon_sym_POUNDIf] = ACTIONS(9324),
    [anon_sym_not] = ACTIONS(9322),
    [anon_sym_NOT] = ACTIONS(9322),
    [anon_sym_Not] = ACTIONS(9322),
    [anon_sym_POUNDelif] = ACTIONS(9324),
    [anon_sym_POUNDELIF] = ACTIONS(9324),
    [anon_sym_POUNDElif] = ACTIONS(9324),
    [anon_sym_POUNDelse] = ACTIONS(9324),
    [anon_sym_POUNDELSE] = ACTIONS(9324),
    [anon_sym_POUNDElse] = ACTIONS(9324),
    [anon_sym_POUNDendif] = ACTIONS(9324),
    [anon_sym_POUNDENDIF] = ACTIONS(9324),
    [anon_sym_POUNDEndif] = ACTIONS(9324),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9322),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9322),
    [anon_sym_PLUS] = ACTIONS(9324),
    [sym_datetime_literal] = ACTIONS(9324),
    [sym_date_literal] = ACTIONS(9322),
    [sym_time_literal] = ACTIONS(9322),
    [sym_biginteger_literal] = ACTIONS(9324),
    [anon_sym_else] = ACTIONS(9322),
    [anon_sym_ELSE] = ACTIONS(9322),
    [anon_sym_Else] = ACTIONS(9322),
    [sym_page_keyword] = ACTIONS(9322),
    [anon_sym_codeunit] = ACTIONS(9322),
    [anon_sym_CODEUNIT] = ACTIONS(9322),
    [anon_sym_Codeunit] = ACTIONS(9322),
    [anon_sym_CodeUnit] = ACTIONS(9322),
    [anon_sym_COdeunit] = ACTIONS(9322),
    [anon_sym_codeUnit] = ACTIONS(9322),
    [sym_report_keyword] = ACTIONS(9322),
    [sym_query_keyword] = ACTIONS(9322),
    [anon_sym_xmlport] = ACTIONS(9322),
    [anon_sym_XMLPORT] = ACTIONS(9322),
    [anon_sym_Xmlport] = ACTIONS(9322),
    [anon_sym_XMLport] = ACTIONS(9322),
    [anon_sym_XMLPort] = ACTIONS(9322),
    [anon_sym_XmlPort] = ACTIONS(9322),
    [anon_sym_enum] = ACTIONS(9322),
    [anon_sym_ENUM] = ACTIONS(9322),
    [anon_sym_Enum] = ACTIONS(9322),
    [anon_sym_eNUM] = ACTIONS(9322),
    [anon_sym_eNum] = ACTIONS(9322),
    [anon_sym_ENum] = ACTIONS(9322),
    [sym_quoted_identifier] = ACTIONS(9324),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9324),
    [sym_integer] = ACTIONS(9322),
    [sym_continue_as_identifier] = ACTIONS(9324),
    [sym_preproc_open] = ACTIONS(9324),
    [sym_preproc_close] = ACTIONS(9324),
  },
  [STATE(3440)] = {
    [sym_identifier] = ACTIONS(9131),
    [anon_sym_DASH] = ACTIONS(9133),
    [aux_sym_boolean_token1] = ACTIONS(9131),
    [aux_sym_boolean_token2] = ACTIONS(9131),
    [sym_decimal] = ACTIONS(9131),
    [anon_sym_LPAREN] = ACTIONS(9133),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9131),
    [anon_sym_LBRACK] = ACTIONS(9133),
    [aux_sym_record_type_token1] = ACTIONS(9131),
    [aux_sym_basic_type_token21] = ACTIONS(9131),
    [aux_sym_basic_type_token22] = ACTIONS(9131),
    [aux_sym_basic_type_token48] = ACTIONS(9131),
    [anon_sym_POUNDif] = ACTIONS(9133),
    [anon_sym_POUNDIF] = ACTIONS(9133),
    [anon_sym_POUNDIf] = ACTIONS(9133),
    [anon_sym_not] = ACTIONS(9131),
    [anon_sym_NOT] = ACTIONS(9131),
    [anon_sym_Not] = ACTIONS(9131),
    [anon_sym_POUNDelif] = ACTIONS(9133),
    [anon_sym_POUNDELIF] = ACTIONS(9133),
    [anon_sym_POUNDElif] = ACTIONS(9133),
    [anon_sym_POUNDelse] = ACTIONS(9133),
    [anon_sym_POUNDELSE] = ACTIONS(9133),
    [anon_sym_POUNDElse] = ACTIONS(9133),
    [anon_sym_POUNDendif] = ACTIONS(9133),
    [anon_sym_POUNDENDIF] = ACTIONS(9133),
    [anon_sym_POUNDEndif] = ACTIONS(9133),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9131),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9131),
    [anon_sym_PLUS] = ACTIONS(9133),
    [sym_datetime_literal] = ACTIONS(9133),
    [sym_date_literal] = ACTIONS(9131),
    [sym_time_literal] = ACTIONS(9131),
    [sym_biginteger_literal] = ACTIONS(9133),
    [anon_sym_else] = ACTIONS(9131),
    [anon_sym_ELSE] = ACTIONS(9131),
    [anon_sym_Else] = ACTIONS(9131),
    [sym_page_keyword] = ACTIONS(9131),
    [anon_sym_codeunit] = ACTIONS(9131),
    [anon_sym_CODEUNIT] = ACTIONS(9131),
    [anon_sym_Codeunit] = ACTIONS(9131),
    [anon_sym_CodeUnit] = ACTIONS(9131),
    [anon_sym_COdeunit] = ACTIONS(9131),
    [anon_sym_codeUnit] = ACTIONS(9131),
    [sym_report_keyword] = ACTIONS(9131),
    [sym_query_keyword] = ACTIONS(9131),
    [anon_sym_xmlport] = ACTIONS(9131),
    [anon_sym_XMLPORT] = ACTIONS(9131),
    [anon_sym_Xmlport] = ACTIONS(9131),
    [anon_sym_XMLport] = ACTIONS(9131),
    [anon_sym_XMLPort] = ACTIONS(9131),
    [anon_sym_XmlPort] = ACTIONS(9131),
    [anon_sym_enum] = ACTIONS(9131),
    [anon_sym_ENUM] = ACTIONS(9131),
    [anon_sym_Enum] = ACTIONS(9131),
    [anon_sym_eNUM] = ACTIONS(9131),
    [anon_sym_eNum] = ACTIONS(9131),
    [anon_sym_ENum] = ACTIONS(9131),
    [sym_quoted_identifier] = ACTIONS(9133),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9133),
    [sym_integer] = ACTIONS(9131),
    [sym_continue_as_identifier] = ACTIONS(9133),
    [sym_preproc_open] = ACTIONS(9133),
    [sym_preproc_close] = ACTIONS(9133),
  },
  [STATE(3441)] = {
    [sym_identifier] = ACTIONS(9326),
    [anon_sym_DASH] = ACTIONS(9328),
    [aux_sym_boolean_token1] = ACTIONS(9326),
    [aux_sym_boolean_token2] = ACTIONS(9326),
    [sym_decimal] = ACTIONS(9326),
    [anon_sym_LPAREN] = ACTIONS(9328),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9326),
    [anon_sym_LBRACK] = ACTIONS(9328),
    [aux_sym_record_type_token1] = ACTIONS(9326),
    [aux_sym_basic_type_token21] = ACTIONS(9326),
    [aux_sym_basic_type_token22] = ACTIONS(9326),
    [aux_sym_basic_type_token48] = ACTIONS(9326),
    [anon_sym_POUNDif] = ACTIONS(9328),
    [anon_sym_POUNDIF] = ACTIONS(9328),
    [anon_sym_POUNDIf] = ACTIONS(9328),
    [anon_sym_not] = ACTIONS(9326),
    [anon_sym_NOT] = ACTIONS(9326),
    [anon_sym_Not] = ACTIONS(9326),
    [anon_sym_POUNDelif] = ACTIONS(9328),
    [anon_sym_POUNDELIF] = ACTIONS(9328),
    [anon_sym_POUNDElif] = ACTIONS(9328),
    [anon_sym_POUNDelse] = ACTIONS(9328),
    [anon_sym_POUNDELSE] = ACTIONS(9328),
    [anon_sym_POUNDElse] = ACTIONS(9328),
    [anon_sym_POUNDendif] = ACTIONS(9328),
    [anon_sym_POUNDENDIF] = ACTIONS(9328),
    [anon_sym_POUNDEndif] = ACTIONS(9328),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9326),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9326),
    [anon_sym_PLUS] = ACTIONS(9328),
    [sym_datetime_literal] = ACTIONS(9328),
    [sym_date_literal] = ACTIONS(9326),
    [sym_time_literal] = ACTIONS(9326),
    [sym_biginteger_literal] = ACTIONS(9328),
    [anon_sym_else] = ACTIONS(9326),
    [anon_sym_ELSE] = ACTIONS(9326),
    [anon_sym_Else] = ACTIONS(9326),
    [sym_page_keyword] = ACTIONS(9326),
    [anon_sym_codeunit] = ACTIONS(9326),
    [anon_sym_CODEUNIT] = ACTIONS(9326),
    [anon_sym_Codeunit] = ACTIONS(9326),
    [anon_sym_CodeUnit] = ACTIONS(9326),
    [anon_sym_COdeunit] = ACTIONS(9326),
    [anon_sym_codeUnit] = ACTIONS(9326),
    [sym_report_keyword] = ACTIONS(9326),
    [sym_query_keyword] = ACTIONS(9326),
    [anon_sym_xmlport] = ACTIONS(9326),
    [anon_sym_XMLPORT] = ACTIONS(9326),
    [anon_sym_Xmlport] = ACTIONS(9326),
    [anon_sym_XMLport] = ACTIONS(9326),
    [anon_sym_XMLPort] = ACTIONS(9326),
    [anon_sym_XmlPort] = ACTIONS(9326),
    [anon_sym_enum] = ACTIONS(9326),
    [anon_sym_ENUM] = ACTIONS(9326),
    [anon_sym_Enum] = ACTIONS(9326),
    [anon_sym_eNUM] = ACTIONS(9326),
    [anon_sym_eNum] = ACTIONS(9326),
    [anon_sym_ENum] = ACTIONS(9326),
    [sym_quoted_identifier] = ACTIONS(9328),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9328),
    [sym_integer] = ACTIONS(9326),
    [sym_continue_as_identifier] = ACTIONS(9328),
    [sym_preproc_open] = ACTIONS(9328),
    [sym_preproc_close] = ACTIONS(9328),
  },
  [STATE(3442)] = {
    [sym_identifier] = ACTIONS(9330),
    [anon_sym_DASH] = ACTIONS(9332),
    [aux_sym_boolean_token1] = ACTIONS(9330),
    [aux_sym_boolean_token2] = ACTIONS(9330),
    [sym_decimal] = ACTIONS(9330),
    [anon_sym_LPAREN] = ACTIONS(9332),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9330),
    [anon_sym_LBRACK] = ACTIONS(9332),
    [aux_sym_record_type_token1] = ACTIONS(9330),
    [aux_sym_basic_type_token21] = ACTIONS(9330),
    [aux_sym_basic_type_token22] = ACTIONS(9330),
    [aux_sym_basic_type_token48] = ACTIONS(9330),
    [anon_sym_POUNDif] = ACTIONS(9332),
    [anon_sym_POUNDIF] = ACTIONS(9332),
    [anon_sym_POUNDIf] = ACTIONS(9332),
    [anon_sym_not] = ACTIONS(9330),
    [anon_sym_NOT] = ACTIONS(9330),
    [anon_sym_Not] = ACTIONS(9330),
    [anon_sym_POUNDelif] = ACTIONS(9332),
    [anon_sym_POUNDELIF] = ACTIONS(9332),
    [anon_sym_POUNDElif] = ACTIONS(9332),
    [anon_sym_POUNDelse] = ACTIONS(9332),
    [anon_sym_POUNDELSE] = ACTIONS(9332),
    [anon_sym_POUNDElse] = ACTIONS(9332),
    [anon_sym_POUNDendif] = ACTIONS(9332),
    [anon_sym_POUNDENDIF] = ACTIONS(9332),
    [anon_sym_POUNDEndif] = ACTIONS(9332),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9330),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9330),
    [anon_sym_PLUS] = ACTIONS(9332),
    [sym_datetime_literal] = ACTIONS(9332),
    [sym_date_literal] = ACTIONS(9330),
    [sym_time_literal] = ACTIONS(9330),
    [sym_biginteger_literal] = ACTIONS(9332),
    [anon_sym_else] = ACTIONS(9330),
    [anon_sym_ELSE] = ACTIONS(9330),
    [anon_sym_Else] = ACTIONS(9330),
    [sym_page_keyword] = ACTIONS(9330),
    [anon_sym_codeunit] = ACTIONS(9330),
    [anon_sym_CODEUNIT] = ACTIONS(9330),
    [anon_sym_Codeunit] = ACTIONS(9330),
    [anon_sym_CodeUnit] = ACTIONS(9330),
    [anon_sym_COdeunit] = ACTIONS(9330),
    [anon_sym_codeUnit] = ACTIONS(9330),
    [sym_report_keyword] = ACTIONS(9330),
    [sym_query_keyword] = ACTIONS(9330),
    [anon_sym_xmlport] = ACTIONS(9330),
    [anon_sym_XMLPORT] = ACTIONS(9330),
    [anon_sym_Xmlport] = ACTIONS(9330),
    [anon_sym_XMLport] = ACTIONS(9330),
    [anon_sym_XMLPort] = ACTIONS(9330),
    [anon_sym_XmlPort] = ACTIONS(9330),
    [anon_sym_enum] = ACTIONS(9330),
    [anon_sym_ENUM] = ACTIONS(9330),
    [anon_sym_Enum] = ACTIONS(9330),
    [anon_sym_eNUM] = ACTIONS(9330),
    [anon_sym_eNum] = ACTIONS(9330),
    [anon_sym_ENum] = ACTIONS(9330),
    [sym_quoted_identifier] = ACTIONS(9332),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9332),
    [sym_integer] = ACTIONS(9330),
    [sym_continue_as_identifier] = ACTIONS(9332),
    [sym_preproc_open] = ACTIONS(9332),
    [sym_preproc_close] = ACTIONS(9332),
  },
  [STATE(3443)] = {
    [sym_identifier] = ACTIONS(9302),
    [anon_sym_DASH] = ACTIONS(9304),
    [aux_sym_boolean_token1] = ACTIONS(9302),
    [aux_sym_boolean_token2] = ACTIONS(9302),
    [sym_decimal] = ACTIONS(9302),
    [anon_sym_LPAREN] = ACTIONS(9304),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9302),
    [anon_sym_LBRACK] = ACTIONS(9304),
    [aux_sym_record_type_token1] = ACTIONS(9302),
    [aux_sym_basic_type_token21] = ACTIONS(9302),
    [aux_sym_basic_type_token22] = ACTIONS(9302),
    [aux_sym_basic_type_token48] = ACTIONS(9302),
    [anon_sym_POUNDif] = ACTIONS(9304),
    [anon_sym_POUNDIF] = ACTIONS(9304),
    [anon_sym_POUNDIf] = ACTIONS(9304),
    [anon_sym_not] = ACTIONS(9302),
    [anon_sym_NOT] = ACTIONS(9302),
    [anon_sym_Not] = ACTIONS(9302),
    [anon_sym_POUNDelif] = ACTIONS(9304),
    [anon_sym_POUNDELIF] = ACTIONS(9304),
    [anon_sym_POUNDElif] = ACTIONS(9304),
    [anon_sym_POUNDelse] = ACTIONS(9304),
    [anon_sym_POUNDELSE] = ACTIONS(9304),
    [anon_sym_POUNDElse] = ACTIONS(9304),
    [anon_sym_POUNDendif] = ACTIONS(9304),
    [anon_sym_POUNDENDIF] = ACTIONS(9304),
    [anon_sym_POUNDEndif] = ACTIONS(9304),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9302),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9302),
    [anon_sym_PLUS] = ACTIONS(9304),
    [sym_datetime_literal] = ACTIONS(9304),
    [sym_date_literal] = ACTIONS(9302),
    [sym_time_literal] = ACTIONS(9302),
    [sym_biginteger_literal] = ACTIONS(9304),
    [anon_sym_else] = ACTIONS(9302),
    [anon_sym_ELSE] = ACTIONS(9302),
    [anon_sym_Else] = ACTIONS(9302),
    [sym_page_keyword] = ACTIONS(9302),
    [anon_sym_codeunit] = ACTIONS(9302),
    [anon_sym_CODEUNIT] = ACTIONS(9302),
    [anon_sym_Codeunit] = ACTIONS(9302),
    [anon_sym_CodeUnit] = ACTIONS(9302),
    [anon_sym_COdeunit] = ACTIONS(9302),
    [anon_sym_codeUnit] = ACTIONS(9302),
    [sym_report_keyword] = ACTIONS(9302),
    [sym_query_keyword] = ACTIONS(9302),
    [anon_sym_xmlport] = ACTIONS(9302),
    [anon_sym_XMLPORT] = ACTIONS(9302),
    [anon_sym_Xmlport] = ACTIONS(9302),
    [anon_sym_XMLport] = ACTIONS(9302),
    [anon_sym_XMLPort] = ACTIONS(9302),
    [anon_sym_XmlPort] = ACTIONS(9302),
    [anon_sym_enum] = ACTIONS(9302),
    [anon_sym_ENUM] = ACTIONS(9302),
    [anon_sym_Enum] = ACTIONS(9302),
    [anon_sym_eNUM] = ACTIONS(9302),
    [anon_sym_eNum] = ACTIONS(9302),
    [anon_sym_ENum] = ACTIONS(9302),
    [sym_quoted_identifier] = ACTIONS(9304),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9304),
    [sym_integer] = ACTIONS(9302),
    [sym_continue_as_identifier] = ACTIONS(9304),
    [sym_preproc_open] = ACTIONS(9304),
    [sym_preproc_close] = ACTIONS(9304),
  },
  [STATE(3444)] = {
    [sym_identifier] = ACTIONS(9334),
    [anon_sym_DASH] = ACTIONS(9336),
    [aux_sym_boolean_token1] = ACTIONS(9334),
    [aux_sym_boolean_token2] = ACTIONS(9334),
    [sym_decimal] = ACTIONS(9334),
    [anon_sym_LPAREN] = ACTIONS(9336),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9334),
    [anon_sym_LBRACK] = ACTIONS(9336),
    [aux_sym_record_type_token1] = ACTIONS(9334),
    [aux_sym_basic_type_token21] = ACTIONS(9334),
    [aux_sym_basic_type_token22] = ACTIONS(9334),
    [aux_sym_basic_type_token48] = ACTIONS(9334),
    [anon_sym_POUNDif] = ACTIONS(9336),
    [anon_sym_POUNDIF] = ACTIONS(9336),
    [anon_sym_POUNDIf] = ACTIONS(9336),
    [anon_sym_not] = ACTIONS(9334),
    [anon_sym_NOT] = ACTIONS(9334),
    [anon_sym_Not] = ACTIONS(9334),
    [anon_sym_POUNDelif] = ACTIONS(9336),
    [anon_sym_POUNDELIF] = ACTIONS(9336),
    [anon_sym_POUNDElif] = ACTIONS(9336),
    [anon_sym_POUNDelse] = ACTIONS(9336),
    [anon_sym_POUNDELSE] = ACTIONS(9336),
    [anon_sym_POUNDElse] = ACTIONS(9336),
    [anon_sym_POUNDendif] = ACTIONS(9336),
    [anon_sym_POUNDENDIF] = ACTIONS(9336),
    [anon_sym_POUNDEndif] = ACTIONS(9336),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9334),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9334),
    [anon_sym_PLUS] = ACTIONS(9336),
    [sym_datetime_literal] = ACTIONS(9336),
    [sym_date_literal] = ACTIONS(9334),
    [sym_time_literal] = ACTIONS(9334),
    [sym_biginteger_literal] = ACTIONS(9336),
    [anon_sym_else] = ACTIONS(9334),
    [anon_sym_ELSE] = ACTIONS(9334),
    [anon_sym_Else] = ACTIONS(9334),
    [sym_page_keyword] = ACTIONS(9334),
    [anon_sym_codeunit] = ACTIONS(9334),
    [anon_sym_CODEUNIT] = ACTIONS(9334),
    [anon_sym_Codeunit] = ACTIONS(9334),
    [anon_sym_CodeUnit] = ACTIONS(9334),
    [anon_sym_COdeunit] = ACTIONS(9334),
    [anon_sym_codeUnit] = ACTIONS(9334),
    [sym_report_keyword] = ACTIONS(9334),
    [sym_query_keyword] = ACTIONS(9334),
    [anon_sym_xmlport] = ACTIONS(9334),
    [anon_sym_XMLPORT] = ACTIONS(9334),
    [anon_sym_Xmlport] = ACTIONS(9334),
    [anon_sym_XMLport] = ACTIONS(9334),
    [anon_sym_XMLPort] = ACTIONS(9334),
    [anon_sym_XmlPort] = ACTIONS(9334),
    [anon_sym_enum] = ACTIONS(9334),
    [anon_sym_ENUM] = ACTIONS(9334),
    [anon_sym_Enum] = ACTIONS(9334),
    [anon_sym_eNUM] = ACTIONS(9334),
    [anon_sym_eNum] = ACTIONS(9334),
    [anon_sym_ENum] = ACTIONS(9334),
    [sym_quoted_identifier] = ACTIONS(9336),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9336),
    [sym_integer] = ACTIONS(9334),
    [sym_continue_as_identifier] = ACTIONS(9336),
    [sym_preproc_open] = ACTIONS(9336),
    [sym_preproc_close] = ACTIONS(9336),
  },
  [STATE(3445)] = {
    [sym__layout_element] = STATE(3852),
    [sym_area_section] = STATE(3852),
    [sym_group_section] = STATE(3852),
    [sym_repeater_section] = STATE(3852),
    [sym_cuegroup_section] = STATE(3852),
    [sym_fixed_section] = STATE(3852),
    [sym_grid_section] = STATE(3852),
    [sym_page_field] = STATE(3852),
    [sym_part_section] = STATE(3852),
    [sym_systempart_section] = STATE(3852),
    [sym_usercontrol_section] = STATE(3852),
    [sym_preproc_split_field] = STATE(3852),
    [sym_label_section] = STATE(3852),
    [sym_addfirst_modification] = STATE(3852),
    [sym_addlast_modification] = STATE(3852),
    [sym_addafter_modification] = STATE(3852),
    [sym_addbefore_modification] = STATE(3852),
    [sym_modify_modification] = STATE(3852),
    [sym_movefirst_modification] = STATE(3852),
    [sym_movelast_modification] = STATE(3852),
    [sym_moveafter_modification] = STATE(3852),
    [sym_movebefore_modification] = STATE(3852),
    [sym_preproc_if] = STATE(3384),
    [sym_preproc_elif] = STATE(3879),
    [sym_preproc_else] = STATE(4701),
    [sym_preproc_endif] = STATE(4979),
    [sym_preproc_conditional_layout] = STATE(3852),
    [aux_sym_layout_section_repeat1] = STATE(3852),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7843),
    [aux_sym_where_condition_token1] = ACTIONS(9171),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [aux_sym_basic_type_token6] = ACTIONS(9089),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(9091),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [anon_sym_POUNDif] = ACTIONS(9093),
    [anon_sym_POUNDIF] = ACTIONS(9093),
    [anon_sym_POUNDIf] = ACTIONS(9093),
    [anon_sym_POUNDelif] = ACTIONS(9095),
    [anon_sym_POUNDELIF] = ACTIONS(9095),
    [anon_sym_POUNDElif] = ACTIONS(9095),
    [anon_sym_POUNDelse] = ACTIONS(9097),
    [anon_sym_POUNDELSE] = ACTIONS(9097),
    [anon_sym_POUNDElse] = ACTIONS(9097),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9093),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3446)] = {
    [sym__layout_element] = STATE(3852),
    [sym_area_section] = STATE(3852),
    [sym_group_section] = STATE(3852),
    [sym_repeater_section] = STATE(3852),
    [sym_cuegroup_section] = STATE(3852),
    [sym_fixed_section] = STATE(3852),
    [sym_grid_section] = STATE(3852),
    [sym_page_field] = STATE(3852),
    [sym_part_section] = STATE(3852),
    [sym_systempart_section] = STATE(3852),
    [sym_usercontrol_section] = STATE(3852),
    [sym_preproc_split_field] = STATE(3852),
    [sym_label_section] = STATE(3852),
    [sym_addfirst_modification] = STATE(3852),
    [sym_addlast_modification] = STATE(3852),
    [sym_addafter_modification] = STATE(3852),
    [sym_addbefore_modification] = STATE(3852),
    [sym_modify_modification] = STATE(3852),
    [sym_movefirst_modification] = STATE(3852),
    [sym_movelast_modification] = STATE(3852),
    [sym_moveafter_modification] = STATE(3852),
    [sym_movebefore_modification] = STATE(3852),
    [sym_preproc_if] = STATE(3384),
    [sym_preproc_elif] = STATE(3879),
    [sym_preproc_else] = STATE(4692),
    [sym_preproc_endif] = STATE(7125),
    [sym_preproc_conditional_layout] = STATE(3852),
    [aux_sym_layout_section_repeat1] = STATE(3852),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7933),
    [aux_sym_where_condition_token1] = ACTIONS(9171),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [aux_sym_basic_type_token6] = ACTIONS(9089),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(9091),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [anon_sym_POUNDif] = ACTIONS(9093),
    [anon_sym_POUNDIF] = ACTIONS(9093),
    [anon_sym_POUNDIf] = ACTIONS(9093),
    [anon_sym_POUNDelif] = ACTIONS(9095),
    [anon_sym_POUNDELIF] = ACTIONS(9095),
    [anon_sym_POUNDElif] = ACTIONS(9095),
    [anon_sym_POUNDelse] = ACTIONS(9097),
    [anon_sym_POUNDELSE] = ACTIONS(9097),
    [anon_sym_POUNDElse] = ACTIONS(9097),
    [anon_sym_POUNDendif] = ACTIONS(1577),
    [anon_sym_POUNDENDIF] = ACTIONS(1577),
    [anon_sym_POUNDEndif] = ACTIONS(1577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9093),
    [sym_preproc_close] = ACTIONS(1577),
  },
  [STATE(3447)] = {
    [sym__object_header] = STATE(9706),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(3448)] = {
    [sym__object_header] = STATE(9916),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(3449)] = {
    [sym__object_header] = STATE(9657),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(3450)] = {
    [sym_identifier] = ACTIONS(9338),
    [anon_sym_COMMA] = ACTIONS(9341),
    [anon_sym_COLON] = ACTIONS(9343),
    [anon_sym_DASH] = ACTIONS(9345),
    [aux_sym_boolean_token1] = ACTIONS(9338),
    [aux_sym_boolean_token2] = ACTIONS(9338),
    [sym_decimal] = ACTIONS(9338),
    [anon_sym_LPAREN] = ACTIONS(9345),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9338),
    [anon_sym_LBRACK] = ACTIONS(9345),
    [aux_sym_record_type_token1] = ACTIONS(9338),
    [aux_sym_basic_type_token21] = ACTIONS(9338),
    [aux_sym_basic_type_token22] = ACTIONS(9338),
    [aux_sym_basic_type_token48] = ACTIONS(9338),
    [anon_sym_POUNDif] = ACTIONS(9343),
    [anon_sym_POUNDIF] = ACTIONS(9343),
    [anon_sym_POUNDIf] = ACTIONS(9343),
    [anon_sym_not] = ACTIONS(9338),
    [anon_sym_NOT] = ACTIONS(9338),
    [anon_sym_Not] = ACTIONS(9338),
    [anon_sym_POUNDelif] = ACTIONS(9348),
    [anon_sym_POUNDELIF] = ACTIONS(9348),
    [anon_sym_POUNDElif] = ACTIONS(9348),
    [anon_sym_POUNDelse] = ACTIONS(9348),
    [anon_sym_POUNDELSE] = ACTIONS(9348),
    [anon_sym_POUNDElse] = ACTIONS(9348),
    [anon_sym_POUNDendif] = ACTIONS(9348),
    [anon_sym_POUNDENDIF] = ACTIONS(9348),
    [anon_sym_POUNDEndif] = ACTIONS(9348),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9338),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9338),
    [anon_sym_PLUS] = ACTIONS(9345),
    [sym_datetime_literal] = ACTIONS(9345),
    [sym_date_literal] = ACTIONS(9338),
    [sym_time_literal] = ACTIONS(9338),
    [sym_biginteger_literal] = ACTIONS(9345),
    [sym_page_keyword] = ACTIONS(9338),
    [anon_sym_codeunit] = ACTIONS(9338),
    [anon_sym_CODEUNIT] = ACTIONS(9338),
    [anon_sym_Codeunit] = ACTIONS(9338),
    [anon_sym_CodeUnit] = ACTIONS(9338),
    [anon_sym_COdeunit] = ACTIONS(9338),
    [anon_sym_codeUnit] = ACTIONS(9338),
    [sym_report_keyword] = ACTIONS(9338),
    [sym_query_keyword] = ACTIONS(9338),
    [anon_sym_xmlport] = ACTIONS(9338),
    [anon_sym_XMLPORT] = ACTIONS(9338),
    [anon_sym_Xmlport] = ACTIONS(9338),
    [anon_sym_XMLport] = ACTIONS(9338),
    [anon_sym_XMLPort] = ACTIONS(9338),
    [anon_sym_XmlPort] = ACTIONS(9338),
    [anon_sym_enum] = ACTIONS(9338),
    [anon_sym_ENUM] = ACTIONS(9338),
    [anon_sym_Enum] = ACTIONS(9338),
    [anon_sym_eNUM] = ACTIONS(9338),
    [anon_sym_eNum] = ACTIONS(9338),
    [anon_sym_ENum] = ACTIONS(9338),
    [sym_quoted_identifier] = ACTIONS(9345),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9345),
    [sym_integer] = ACTIONS(9338),
    [sym_continue_as_identifier] = ACTIONS(9345),
    [sym_preproc_open] = ACTIONS(9343),
    [sym_preproc_close] = ACTIONS(9348),
  },
  [STATE(3451)] = {
    [sym__object_header] = STATE(8137),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(3452)] = {
    [sym__object_header] = STATE(8139),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(3453)] = {
    [sym__object_header] = STATE(9718),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(3454)] = {
    [sym__object_header] = STATE(9721),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(3455)] = {
    [sym__object_header] = STATE(9722),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(3456)] = {
    [sym__object_header] = STATE(9729),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(3457)] = {
    [sym__object_header] = STATE(9693),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(3458)] = {
    [sym__layout_element] = STATE(3852),
    [sym_area_section] = STATE(3852),
    [sym_group_section] = STATE(3852),
    [sym_repeater_section] = STATE(3852),
    [sym_cuegroup_section] = STATE(3852),
    [sym_fixed_section] = STATE(3852),
    [sym_grid_section] = STATE(3852),
    [sym_page_field] = STATE(3852),
    [sym_part_section] = STATE(3852),
    [sym_systempart_section] = STATE(3852),
    [sym_usercontrol_section] = STATE(3852),
    [sym_preproc_split_field] = STATE(3852),
    [sym_label_section] = STATE(3852),
    [sym_addfirst_modification] = STATE(3852),
    [sym_addlast_modification] = STATE(3852),
    [sym_addafter_modification] = STATE(3852),
    [sym_addbefore_modification] = STATE(3852),
    [sym_modify_modification] = STATE(3852),
    [sym_movefirst_modification] = STATE(3852),
    [sym_movelast_modification] = STATE(3852),
    [sym_moveafter_modification] = STATE(3852),
    [sym_movebefore_modification] = STATE(3852),
    [sym_preproc_if] = STATE(3384),
    [sym_preproc_elif] = STATE(3879),
    [sym_preproc_else] = STATE(4693),
    [sym_preproc_endif] = STATE(6382),
    [sym_preproc_conditional_layout] = STATE(3852),
    [aux_sym_layout_section_repeat1] = STATE(3852),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7915),
    [aux_sym_where_condition_token1] = ACTIONS(9171),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [aux_sym_basic_type_token6] = ACTIONS(9089),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(9091),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [anon_sym_POUNDif] = ACTIONS(9093),
    [anon_sym_POUNDIF] = ACTIONS(9093),
    [anon_sym_POUNDIf] = ACTIONS(9093),
    [anon_sym_POUNDelif] = ACTIONS(9095),
    [anon_sym_POUNDELIF] = ACTIONS(9095),
    [anon_sym_POUNDElif] = ACTIONS(9095),
    [anon_sym_POUNDelse] = ACTIONS(9097),
    [anon_sym_POUNDELSE] = ACTIONS(9097),
    [anon_sym_POUNDElse] = ACTIONS(9097),
    [anon_sym_POUNDendif] = ACTIONS(9129),
    [anon_sym_POUNDENDIF] = ACTIONS(9129),
    [anon_sym_POUNDEndif] = ACTIONS(9129),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9093),
    [sym_preproc_close] = ACTIONS(9129),
  },
  [STATE(3459)] = {
    [sym__object_header] = STATE(7955),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(3460)] = {
    [sym__object_header] = STATE(8120),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(3461)] = {
    [sym__object_header] = STATE(8847),
    [sym_tableextension_keyword] = STATE(12499),
    [sym_pageextension_keyword] = STATE(12499),
    [sym_codeunit_keyword] = STATE(12538),
    [sym_reportextension_keyword] = STATE(12499),
    [sym_xmlport_keyword] = STATE(11946),
    [sym_enum_keyword] = STATE(12538),
    [sym_enumextension_keyword] = STATE(12499),
    [sym_permissionset_keyword] = STATE(11946),
    [sym_permissionsetextension_keyword] = STATE(12499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8619),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(8619),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(8619),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(8621),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(8623),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(3462)] = {
    [sym__layout_element] = STATE(3852),
    [sym_area_section] = STATE(3852),
    [sym_group_section] = STATE(3852),
    [sym_repeater_section] = STATE(3852),
    [sym_cuegroup_section] = STATE(3852),
    [sym_fixed_section] = STATE(3852),
    [sym_grid_section] = STATE(3852),
    [sym_page_field] = STATE(3852),
    [sym_part_section] = STATE(3852),
    [sym_systempart_section] = STATE(3852),
    [sym_usercontrol_section] = STATE(3852),
    [sym_preproc_split_field] = STATE(3852),
    [sym_label_section] = STATE(3852),
    [sym_addfirst_modification] = STATE(3852),
    [sym_addlast_modification] = STATE(3852),
    [sym_addafter_modification] = STATE(3852),
    [sym_addbefore_modification] = STATE(3852),
    [sym_modify_modification] = STATE(3852),
    [sym_movefirst_modification] = STATE(3852),
    [sym_movelast_modification] = STATE(3852),
    [sym_moveafter_modification] = STATE(3852),
    [sym_movebefore_modification] = STATE(3852),
    [sym_preproc_if] = STATE(3384),
    [sym_preproc_elif] = STATE(3879),
    [sym_preproc_else] = STATE(4711),
    [sym_preproc_endif] = STATE(4605),
    [sym_preproc_conditional_layout] = STATE(3852),
    [aux_sym_layout_section_repeat1] = STATE(3852),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(7922),
    [aux_sym_where_condition_token1] = ACTIONS(9171),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2961),
    [aux_sym_basic_type_token6] = ACTIONS(9089),
    [aux_sym_addafter_modification_token1] = ACTIONS(2965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2967),
    [aux_sym_modify_modification_token1] = ACTIONS(9091),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2969),
    [aux_sym_movelast_modification_token1] = ACTIONS(2971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2973),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2975),
    [anon_sym_POUNDif] = ACTIONS(9093),
    [anon_sym_POUNDIF] = ACTIONS(9093),
    [anon_sym_POUNDIf] = ACTIONS(9093),
    [anon_sym_POUNDelif] = ACTIONS(9095),
    [anon_sym_POUNDELIF] = ACTIONS(9095),
    [anon_sym_POUNDElif] = ACTIONS(9095),
    [anon_sym_POUNDelse] = ACTIONS(9097),
    [anon_sym_POUNDELSE] = ACTIONS(9097),
    [anon_sym_POUNDElse] = ACTIONS(9097),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(2979),
    [sym_group_keyword] = ACTIONS(2981),
    [sym_repeater_keyword] = ACTIONS(2983),
    [sym_cuegroup_keyword] = ACTIONS(2985),
    [sym_fixed_keyword] = ACTIONS(2987),
    [sym_grid_keyword] = ACTIONS(2989),
    [sym_part_keyword] = ACTIONS(2991),
    [sym_systempart_keyword] = ACTIONS(2993),
    [sym_usercontrol_keyword] = ACTIONS(2995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9093),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3463)] = {
    [sym_boolean] = STATE(8843),
    [sym_option_member_list] = STATE(8885),
    [sym_option_member] = STATE(8565),
    [sym_keyword_identifier] = STATE(8843),
    [sym_codeunit_keyword] = STATE(8787),
    [sym_xmlport_keyword] = STATE(8787),
    [sym_enum_keyword] = STATE(8787),
    [sym_keyword_as_identifier] = STATE(8843),
    [aux_sym_option_member_list_repeat2] = STATE(3500),
    [sym_identifier] = ACTIONS(9350),
    [anon_sym_SEMI] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(9352),
    [anon_sym_DASH] = ACTIONS(9354),
    [aux_sym_boolean_token1] = ACTIONS(9356),
    [aux_sym_boolean_token2] = ACTIONS(9356),
    [aux_sym_where_condition_token1] = ACTIONS(9358),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9360),
    [aux_sym_record_type_token1] = ACTIONS(9360),
    [aux_sym_basic_type_token21] = ACTIONS(9360),
    [aux_sym_basic_type_token22] = ACTIONS(9362),
    [aux_sym_basic_type_token48] = ACTIONS(9360),
    [aux_sym_basic_type_token53] = ACTIONS(9358),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9358),
    [aux_sym_separator_action_token1] = ACTIONS(9358),
    [aux_sym_type_declaration_token1] = ACTIONS(9358),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(277),
    [anon_sym_POUNDif] = ACTIONS(275),
    [anon_sym_POUNDIF] = ACTIONS(275),
    [anon_sym_POUNDIf] = ACTIONS(275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9360),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9360),
    [sym_page_keyword] = ACTIONS(9360),
    [anon_sym_codeunit] = ACTIONS(9364),
    [anon_sym_CODEUNIT] = ACTIONS(9364),
    [anon_sym_Codeunit] = ACTIONS(9364),
    [anon_sym_CodeUnit] = ACTIONS(9364),
    [anon_sym_COdeunit] = ACTIONS(9364),
    [anon_sym_codeUnit] = ACTIONS(9364),
    [sym_report_keyword] = ACTIONS(9360),
    [sym_query_keyword] = ACTIONS(9360),
    [anon_sym_xmlport] = ACTIONS(9366),
    [anon_sym_XMLPORT] = ACTIONS(9366),
    [anon_sym_Xmlport] = ACTIONS(9366),
    [anon_sym_XMLport] = ACTIONS(9366),
    [anon_sym_XMLPort] = ACTIONS(9366),
    [anon_sym_XmlPort] = ACTIONS(9366),
    [anon_sym_enum] = ACTIONS(9368),
    [anon_sym_ENUM] = ACTIONS(9368),
    [anon_sym_Enum] = ACTIONS(9368),
    [anon_sym_eNUM] = ACTIONS(9368),
    [anon_sym_eNum] = ACTIONS(9368),
    [anon_sym_ENum] = ACTIONS(9368),
    [sym_var_keyword] = ACTIONS(277),
    [sym_local_keyword] = ACTIONS(9350),
    [sym_internal_keyword] = ACTIONS(9350),
    [sym_protected_keyword] = ACTIONS(9350),
    [sym_key_keyword] = ACTIONS(9358),
    [sym_dataset_keyword] = ACTIONS(9358),
    [sym_quoted_identifier] = ACTIONS(9370),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9370),
    [sym_integer] = ACTIONS(9370),
    [sym_preproc_open] = ACTIONS(275),
    [sym_begin_keyword] = ACTIONS(275),
  },
  [STATE(3464)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(5212),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5568),
    [anon_sym_POUNDENDIF] = ACTIONS(5568),
    [anon_sym_POUNDEndif] = ACTIONS(5568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5568),
  },
  [STATE(3465)] = {
    [sym__body_element] = STATE(3491),
    [sym_empty_statement] = STATE(3491),
    [sym_property] = STATE(3491),
    [sym_fields_section] = STATE(3491),
    [sym_keys_section] = STATE(3491),
    [sym_fieldgroups_section] = STATE(3491),
    [sym_enum_value_declaration] = STATE(3491),
    [sym_labels_section] = STATE(3491),
    [sym_layout_section] = STATE(3491),
    [sym_modify_modification] = STATE(3491),
    [sym_actions_section] = STATE(3491),
    [sym_views_section] = STATE(3491),
    [sym_dataset_section] = STATE(3491),
    [sym_report_dataitem] = STATE(3491),
    [sym_report_column] = STATE(3491),
    [sym_requestpage_section] = STATE(3491),
    [sym_rendering_section] = STATE(3491),
    [sym_elements_section] = STATE(3491),
    [sym_schema_section] = STATE(3491),
    [sym_assembly_declaration] = STATE(3491),
    [sym_event_declaration] = STATE(3491),
    [sym_procedure] = STATE(3491),
    [sym_preproc_split_procedure] = STATE(3491),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3491),
    [sym_var_section] = STATE(3491),
    [sym_attribute_item] = STATE(3491),
    [sym_preproc_conditional] = STATE(3491),
    [sym_preproc_if] = STATE(2724),
    [aux_sym_add_dataset_modification_repeat1] = STATE(3491),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9372),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3466)] = {
    [sym__body_element] = STATE(3490),
    [sym_empty_statement] = STATE(3490),
    [sym_property] = STATE(3490),
    [sym_fields_section] = STATE(3490),
    [sym_keys_section] = STATE(3490),
    [sym_fieldgroups_section] = STATE(3490),
    [sym_enum_value_declaration] = STATE(3490),
    [sym_labels_section] = STATE(3490),
    [sym_layout_section] = STATE(3490),
    [sym_modify_modification] = STATE(3490),
    [sym_actions_section] = STATE(3490),
    [sym_views_section] = STATE(3490),
    [sym_dataset_section] = STATE(3490),
    [sym_requestpage_section] = STATE(3490),
    [sym_rendering_section] = STATE(3490),
    [sym_elements_section] = STATE(3490),
    [sym_schema_section] = STATE(3490),
    [sym_assembly_declaration] = STATE(3490),
    [sym_event_declaration] = STATE(3490),
    [sym_procedure] = STATE(3490),
    [sym_preproc_split_procedure] = STATE(3490),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3490),
    [sym_var_section] = STATE(3490),
    [sym_attribute_item] = STATE(3490),
    [sym_preproc_conditional] = STATE(3490),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(4130),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3490),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3467)] = {
    [sym__body_element] = STATE(3491),
    [sym_empty_statement] = STATE(3491),
    [sym_property] = STATE(3491),
    [sym_fields_section] = STATE(3491),
    [sym_keys_section] = STATE(3491),
    [sym_fieldgroups_section] = STATE(3491),
    [sym_enum_value_declaration] = STATE(3491),
    [sym_labels_section] = STATE(3491),
    [sym_layout_section] = STATE(3491),
    [sym_modify_modification] = STATE(3491),
    [sym_actions_section] = STATE(3491),
    [sym_views_section] = STATE(3491),
    [sym_dataset_section] = STATE(3491),
    [sym_report_dataitem] = STATE(3491),
    [sym_report_column] = STATE(3491),
    [sym_requestpage_section] = STATE(3491),
    [sym_rendering_section] = STATE(3491),
    [sym_elements_section] = STATE(3491),
    [sym_schema_section] = STATE(3491),
    [sym_assembly_declaration] = STATE(3491),
    [sym_event_declaration] = STATE(3491),
    [sym_procedure] = STATE(3491),
    [sym_preproc_split_procedure] = STATE(3491),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3491),
    [sym_var_section] = STATE(3491),
    [sym_attribute_item] = STATE(3491),
    [sym_preproc_conditional] = STATE(3491),
    [sym_preproc_if] = STATE(2724),
    [aux_sym_add_dataset_modification_repeat1] = STATE(3491),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9374),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3468)] = {
    [sym__body_element] = STATE(3473),
    [sym_empty_statement] = STATE(3473),
    [sym_property] = STATE(3473),
    [sym_fields_section] = STATE(3473),
    [sym_keys_section] = STATE(3473),
    [sym_fieldgroups_section] = STATE(3473),
    [sym_enum_value_declaration] = STATE(3473),
    [sym_labels_section] = STATE(3473),
    [sym_layout_section] = STATE(3473),
    [sym_modify_modification] = STATE(3473),
    [sym_actions_section] = STATE(3473),
    [sym_views_section] = STATE(3473),
    [sym_dataset_section] = STATE(3473),
    [sym_requestpage_section] = STATE(3473),
    [sym_rendering_section] = STATE(3473),
    [sym_elements_section] = STATE(3473),
    [sym_schema_section] = STATE(3473),
    [sym_assembly_declaration] = STATE(3473),
    [sym_event_declaration] = STATE(3473),
    [sym_procedure] = STATE(3473),
    [sym_preproc_split_procedure] = STATE(3473),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3473),
    [sym_var_section] = STATE(3473),
    [sym_attribute_item] = STATE(3473),
    [sym_preproc_conditional] = STATE(3473),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(6748),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3473),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5869),
    [anon_sym_POUNDENDIF] = ACTIONS(5869),
    [anon_sym_POUNDEndif] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5869),
  },
  [STATE(3469)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(4227),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3470)] = {
    [sym__body_element] = STATE(3491),
    [sym_empty_statement] = STATE(3491),
    [sym_property] = STATE(3491),
    [sym_fields_section] = STATE(3491),
    [sym_keys_section] = STATE(3491),
    [sym_fieldgroups_section] = STATE(3491),
    [sym_enum_value_declaration] = STATE(3491),
    [sym_labels_section] = STATE(3491),
    [sym_layout_section] = STATE(3491),
    [sym_modify_modification] = STATE(3491),
    [sym_actions_section] = STATE(3491),
    [sym_views_section] = STATE(3491),
    [sym_dataset_section] = STATE(3491),
    [sym_report_dataitem] = STATE(3491),
    [sym_report_column] = STATE(3491),
    [sym_requestpage_section] = STATE(3491),
    [sym_rendering_section] = STATE(3491),
    [sym_elements_section] = STATE(3491),
    [sym_schema_section] = STATE(3491),
    [sym_assembly_declaration] = STATE(3491),
    [sym_event_declaration] = STATE(3491),
    [sym_procedure] = STATE(3491),
    [sym_preproc_split_procedure] = STATE(3491),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3491),
    [sym_var_section] = STATE(3491),
    [sym_attribute_item] = STATE(3491),
    [sym_preproc_conditional] = STATE(3491),
    [sym_preproc_if] = STATE(2724),
    [aux_sym_add_dataset_modification_repeat1] = STATE(3491),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9376),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3471)] = {
    [sym__body_element] = STATE(3470),
    [sym_empty_statement] = STATE(3470),
    [sym_property] = STATE(3470),
    [sym_fields_section] = STATE(3470),
    [sym_keys_section] = STATE(3470),
    [sym_fieldgroups_section] = STATE(3470),
    [sym_enum_value_declaration] = STATE(3470),
    [sym_labels_section] = STATE(3470),
    [sym_layout_section] = STATE(3470),
    [sym_modify_modification] = STATE(3470),
    [sym_actions_section] = STATE(3470),
    [sym_views_section] = STATE(3470),
    [sym_dataset_section] = STATE(3470),
    [sym_report_dataitem] = STATE(3470),
    [sym_report_column] = STATE(3470),
    [sym_requestpage_section] = STATE(3470),
    [sym_rendering_section] = STATE(3470),
    [sym_elements_section] = STATE(3470),
    [sym_schema_section] = STATE(3470),
    [sym_assembly_declaration] = STATE(3470),
    [sym_event_declaration] = STATE(3470),
    [sym_procedure] = STATE(3470),
    [sym_preproc_split_procedure] = STATE(3470),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3470),
    [sym_var_section] = STATE(3470),
    [sym_attribute_item] = STATE(3470),
    [sym_preproc_conditional] = STATE(3470),
    [sym_preproc_if] = STATE(2724),
    [aux_sym_add_dataset_modification_repeat1] = STATE(3470),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9378),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3472)] = {
    [sym__body_element] = STATE(3494),
    [sym_empty_statement] = STATE(3494),
    [sym_property] = STATE(3494),
    [sym_fields_section] = STATE(3494),
    [sym_keys_section] = STATE(3494),
    [sym_fieldgroups_section] = STATE(3494),
    [sym_enum_value_declaration] = STATE(3494),
    [sym_labels_section] = STATE(3494),
    [sym_layout_section] = STATE(3494),
    [sym_modify_modification] = STATE(3494),
    [sym_actions_section] = STATE(3494),
    [sym_views_section] = STATE(3494),
    [sym_dataset_section] = STATE(3494),
    [sym_requestpage_section] = STATE(3494),
    [sym_rendering_section] = STATE(3494),
    [sym_elements_section] = STATE(3494),
    [sym_schema_section] = STATE(3494),
    [sym_assembly_declaration] = STATE(3494),
    [sym_event_declaration] = STATE(3494),
    [sym_procedure] = STATE(3494),
    [sym_preproc_split_procedure] = STATE(3494),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3494),
    [sym_var_section] = STATE(3494),
    [sym_attribute_item] = STATE(3494),
    [sym_preproc_conditional] = STATE(3494),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(5212),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3494),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5568),
    [anon_sym_POUNDENDIF] = ACTIONS(5568),
    [anon_sym_POUNDEndif] = ACTIONS(5568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5568),
  },
  [STATE(3473)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(6760),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5869),
    [anon_sym_POUNDENDIF] = ACTIONS(5869),
    [anon_sym_POUNDEndif] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5869),
  },
  [STATE(3474)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(3704),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3475)] = {
    [sym__body_element] = STATE(3499),
    [sym_empty_statement] = STATE(3499),
    [sym_property] = STATE(3499),
    [sym_fields_section] = STATE(3499),
    [sym_keys_section] = STATE(3499),
    [sym_fieldgroups_section] = STATE(3499),
    [sym_enum_value_declaration] = STATE(3499),
    [sym_labels_section] = STATE(3499),
    [sym_layout_section] = STATE(3499),
    [sym_modify_modification] = STATE(3499),
    [sym_actions_section] = STATE(3499),
    [sym_views_section] = STATE(3499),
    [sym_dataset_section] = STATE(3499),
    [sym_requestpage_section] = STATE(3499),
    [sym_rendering_section] = STATE(3499),
    [sym_elements_section] = STATE(3499),
    [sym_schema_section] = STATE(3499),
    [sym_assembly_declaration] = STATE(3499),
    [sym_event_declaration] = STATE(3499),
    [sym_procedure] = STATE(3499),
    [sym_preproc_split_procedure] = STATE(3499),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3499),
    [sym_var_section] = STATE(3499),
    [sym_attribute_item] = STATE(3499),
    [sym_preproc_conditional] = STATE(3499),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(3704),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3499),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3476)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(5371),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5568),
    [anon_sym_POUNDENDIF] = ACTIONS(5568),
    [anon_sym_POUNDEndif] = ACTIONS(5568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5568),
  },
  [STATE(3477)] = {
    [sym__body_element] = STATE(3464),
    [sym_empty_statement] = STATE(3464),
    [sym_property] = STATE(3464),
    [sym_fields_section] = STATE(3464),
    [sym_keys_section] = STATE(3464),
    [sym_fieldgroups_section] = STATE(3464),
    [sym_enum_value_declaration] = STATE(3464),
    [sym_labels_section] = STATE(3464),
    [sym_layout_section] = STATE(3464),
    [sym_modify_modification] = STATE(3464),
    [sym_actions_section] = STATE(3464),
    [sym_views_section] = STATE(3464),
    [sym_dataset_section] = STATE(3464),
    [sym_requestpage_section] = STATE(3464),
    [sym_rendering_section] = STATE(3464),
    [sym_elements_section] = STATE(3464),
    [sym_schema_section] = STATE(3464),
    [sym_assembly_declaration] = STATE(3464),
    [sym_event_declaration] = STATE(3464),
    [sym_procedure] = STATE(3464),
    [sym_preproc_split_procedure] = STATE(3464),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3464),
    [sym_var_section] = STATE(3464),
    [sym_attribute_item] = STATE(3464),
    [sym_preproc_conditional] = STATE(3464),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(5371),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3464),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5568),
    [anon_sym_POUNDENDIF] = ACTIONS(5568),
    [anon_sym_POUNDEndif] = ACTIONS(5568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5568),
  },
  [STATE(3478)] = {
    [sym__body_element] = STATE(3467),
    [sym_empty_statement] = STATE(3467),
    [sym_property] = STATE(3467),
    [sym_fields_section] = STATE(3467),
    [sym_keys_section] = STATE(3467),
    [sym_fieldgroups_section] = STATE(3467),
    [sym_enum_value_declaration] = STATE(3467),
    [sym_labels_section] = STATE(3467),
    [sym_layout_section] = STATE(3467),
    [sym_modify_modification] = STATE(3467),
    [sym_actions_section] = STATE(3467),
    [sym_views_section] = STATE(3467),
    [sym_dataset_section] = STATE(3467),
    [sym_report_dataitem] = STATE(3467),
    [sym_report_column] = STATE(3467),
    [sym_requestpage_section] = STATE(3467),
    [sym_rendering_section] = STATE(3467),
    [sym_elements_section] = STATE(3467),
    [sym_schema_section] = STATE(3467),
    [sym_assembly_declaration] = STATE(3467),
    [sym_event_declaration] = STATE(3467),
    [sym_procedure] = STATE(3467),
    [sym_preproc_split_procedure] = STATE(3467),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3467),
    [sym_var_section] = STATE(3467),
    [sym_attribute_item] = STATE(3467),
    [sym_preproc_conditional] = STATE(3467),
    [sym_preproc_if] = STATE(2724),
    [aux_sym_add_dataset_modification_repeat1] = STATE(3467),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9380),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3479)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(6770),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5869),
    [anon_sym_POUNDENDIF] = ACTIONS(5869),
    [anon_sym_POUNDEndif] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5869),
  },
  [STATE(3480)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(4522),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3481)] = {
    [sym__body_element] = STATE(3483),
    [sym_empty_statement] = STATE(3483),
    [sym_property] = STATE(3483),
    [sym_fields_section] = STATE(3483),
    [sym_keys_section] = STATE(3483),
    [sym_fieldgroups_section] = STATE(3483),
    [sym_enum_value_declaration] = STATE(3483),
    [sym_labels_section] = STATE(3483),
    [sym_layout_section] = STATE(3483),
    [sym_modify_modification] = STATE(3483),
    [sym_actions_section] = STATE(3483),
    [sym_views_section] = STATE(3483),
    [sym_dataset_section] = STATE(3483),
    [sym_report_dataitem] = STATE(3483),
    [sym_report_column] = STATE(3483),
    [sym_requestpage_section] = STATE(3483),
    [sym_rendering_section] = STATE(3483),
    [sym_elements_section] = STATE(3483),
    [sym_schema_section] = STATE(3483),
    [sym_assembly_declaration] = STATE(3483),
    [sym_event_declaration] = STATE(3483),
    [sym_procedure] = STATE(3483),
    [sym_preproc_split_procedure] = STATE(3483),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3483),
    [sym_var_section] = STATE(3483),
    [sym_attribute_item] = STATE(3483),
    [sym_preproc_conditional] = STATE(3483),
    [sym_preproc_if] = STATE(2724),
    [aux_sym_add_dataset_modification_repeat1] = STATE(3483),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9382),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3482)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(3729),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3483)] = {
    [sym__body_element] = STATE(3491),
    [sym_empty_statement] = STATE(3491),
    [sym_property] = STATE(3491),
    [sym_fields_section] = STATE(3491),
    [sym_keys_section] = STATE(3491),
    [sym_fieldgroups_section] = STATE(3491),
    [sym_enum_value_declaration] = STATE(3491),
    [sym_labels_section] = STATE(3491),
    [sym_layout_section] = STATE(3491),
    [sym_modify_modification] = STATE(3491),
    [sym_actions_section] = STATE(3491),
    [sym_views_section] = STATE(3491),
    [sym_dataset_section] = STATE(3491),
    [sym_report_dataitem] = STATE(3491),
    [sym_report_column] = STATE(3491),
    [sym_requestpage_section] = STATE(3491),
    [sym_rendering_section] = STATE(3491),
    [sym_elements_section] = STATE(3491),
    [sym_schema_section] = STATE(3491),
    [sym_assembly_declaration] = STATE(3491),
    [sym_event_declaration] = STATE(3491),
    [sym_procedure] = STATE(3491),
    [sym_preproc_split_procedure] = STATE(3491),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3491),
    [sym_var_section] = STATE(3491),
    [sym_attribute_item] = STATE(3491),
    [sym_preproc_conditional] = STATE(3491),
    [sym_preproc_if] = STATE(2724),
    [aux_sym_add_dataset_modification_repeat1] = STATE(3491),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9384),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3484)] = {
    [sym__body_element] = STATE(3476),
    [sym_empty_statement] = STATE(3476),
    [sym_property] = STATE(3476),
    [sym_fields_section] = STATE(3476),
    [sym_keys_section] = STATE(3476),
    [sym_fieldgroups_section] = STATE(3476),
    [sym_enum_value_declaration] = STATE(3476),
    [sym_labels_section] = STATE(3476),
    [sym_layout_section] = STATE(3476),
    [sym_modify_modification] = STATE(3476),
    [sym_actions_section] = STATE(3476),
    [sym_views_section] = STATE(3476),
    [sym_dataset_section] = STATE(3476),
    [sym_requestpage_section] = STATE(3476),
    [sym_rendering_section] = STATE(3476),
    [sym_elements_section] = STATE(3476),
    [sym_schema_section] = STATE(3476),
    [sym_assembly_declaration] = STATE(3476),
    [sym_event_declaration] = STATE(3476),
    [sym_procedure] = STATE(3476),
    [sym_preproc_split_procedure] = STATE(3476),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3476),
    [sym_var_section] = STATE(3476),
    [sym_attribute_item] = STATE(3476),
    [sym_preproc_conditional] = STATE(3476),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(5117),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3476),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5568),
    [anon_sym_POUNDENDIF] = ACTIONS(5568),
    [anon_sym_POUNDEndif] = ACTIONS(5568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5568),
  },
  [STATE(3485)] = {
    [sym__body_element] = STATE(3482),
    [sym_empty_statement] = STATE(3482),
    [sym_property] = STATE(3482),
    [sym_fields_section] = STATE(3482),
    [sym_keys_section] = STATE(3482),
    [sym_fieldgroups_section] = STATE(3482),
    [sym_enum_value_declaration] = STATE(3482),
    [sym_labels_section] = STATE(3482),
    [sym_layout_section] = STATE(3482),
    [sym_modify_modification] = STATE(3482),
    [sym_actions_section] = STATE(3482),
    [sym_views_section] = STATE(3482),
    [sym_dataset_section] = STATE(3482),
    [sym_requestpage_section] = STATE(3482),
    [sym_rendering_section] = STATE(3482),
    [sym_elements_section] = STATE(3482),
    [sym_schema_section] = STATE(3482),
    [sym_assembly_declaration] = STATE(3482),
    [sym_event_declaration] = STATE(3482),
    [sym_procedure] = STATE(3482),
    [sym_preproc_split_procedure] = STATE(3482),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3482),
    [sym_var_section] = STATE(3482),
    [sym_attribute_item] = STATE(3482),
    [sym_preproc_conditional] = STATE(3482),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(3571),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3482),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3486)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(5781),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5829),
    [anon_sym_POUNDENDIF] = ACTIONS(5829),
    [anon_sym_POUNDEndif] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5829),
  },
  [STATE(3487)] = {
    [sym__body_element] = STATE(3492),
    [sym_empty_statement] = STATE(3492),
    [sym_property] = STATE(3492),
    [sym_fields_section] = STATE(3492),
    [sym_keys_section] = STATE(3492),
    [sym_fieldgroups_section] = STATE(3492),
    [sym_enum_value_declaration] = STATE(3492),
    [sym_labels_section] = STATE(3492),
    [sym_layout_section] = STATE(3492),
    [sym_modify_modification] = STATE(3492),
    [sym_actions_section] = STATE(3492),
    [sym_views_section] = STATE(3492),
    [sym_dataset_section] = STATE(3492),
    [sym_requestpage_section] = STATE(3492),
    [sym_rendering_section] = STATE(3492),
    [sym_elements_section] = STATE(3492),
    [sym_schema_section] = STATE(3492),
    [sym_assembly_declaration] = STATE(3492),
    [sym_event_declaration] = STATE(3492),
    [sym_procedure] = STATE(3492),
    [sym_preproc_split_procedure] = STATE(3492),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3492),
    [sym_var_section] = STATE(3492),
    [sym_attribute_item] = STATE(3492),
    [sym_preproc_conditional] = STATE(3492),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(5781),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3492),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5829),
    [anon_sym_POUNDENDIF] = ACTIONS(5829),
    [anon_sym_POUNDEndif] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5829),
  },
  [STATE(3488)] = {
    [sym__body_element] = STATE(3501),
    [sym_empty_statement] = STATE(3501),
    [sym_property] = STATE(3501),
    [sym_fields_section] = STATE(3501),
    [sym_keys_section] = STATE(3501),
    [sym_fieldgroups_section] = STATE(3501),
    [sym_enum_value_declaration] = STATE(3501),
    [sym_labels_section] = STATE(3501),
    [sym_layout_section] = STATE(3501),
    [sym_modify_modification] = STATE(3501),
    [sym_actions_section] = STATE(3501),
    [sym_views_section] = STATE(3501),
    [sym_dataset_section] = STATE(3501),
    [sym_report_dataitem] = STATE(3501),
    [sym_report_column] = STATE(3501),
    [sym_requestpage_section] = STATE(3501),
    [sym_rendering_section] = STATE(3501),
    [sym_elements_section] = STATE(3501),
    [sym_schema_section] = STATE(3501),
    [sym_assembly_declaration] = STATE(3501),
    [sym_event_declaration] = STATE(3501),
    [sym_procedure] = STATE(3501),
    [sym_preproc_split_procedure] = STATE(3501),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3501),
    [sym_var_section] = STATE(3501),
    [sym_attribute_item] = STATE(3501),
    [sym_preproc_conditional] = STATE(3501),
    [sym_preproc_if] = STATE(2724),
    [aux_sym_add_dataset_modification_repeat1] = STATE(3501),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9386),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3489)] = {
    [sym__body_element] = STATE(3503),
    [sym_empty_statement] = STATE(3503),
    [sym_property] = STATE(3503),
    [sym_fields_section] = STATE(3503),
    [sym_keys_section] = STATE(3503),
    [sym_fieldgroups_section] = STATE(3503),
    [sym_enum_value_declaration] = STATE(3503),
    [sym_labels_section] = STATE(3503),
    [sym_layout_section] = STATE(3503),
    [sym_modify_modification] = STATE(3503),
    [sym_actions_section] = STATE(3503),
    [sym_views_section] = STATE(3503),
    [sym_dataset_section] = STATE(3503),
    [sym_report_dataitem] = STATE(3503),
    [sym_report_column] = STATE(3503),
    [sym_requestpage_section] = STATE(3503),
    [sym_rendering_section] = STATE(3503),
    [sym_elements_section] = STATE(3503),
    [sym_schema_section] = STATE(3503),
    [sym_assembly_declaration] = STATE(3503),
    [sym_event_declaration] = STATE(3503),
    [sym_procedure] = STATE(3503),
    [sym_preproc_split_procedure] = STATE(3503),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3503),
    [sym_var_section] = STATE(3503),
    [sym_attribute_item] = STATE(3503),
    [sym_preproc_conditional] = STATE(3503),
    [sym_preproc_if] = STATE(2724),
    [aux_sym_add_dataset_modification_repeat1] = STATE(3503),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9388),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3490)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(4011),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3491)] = {
    [sym__body_element] = STATE(3491),
    [sym_empty_statement] = STATE(3491),
    [sym_property] = STATE(3491),
    [sym_fields_section] = STATE(3491),
    [sym_keys_section] = STATE(3491),
    [sym_fieldgroups_section] = STATE(3491),
    [sym_enum_value_declaration] = STATE(3491),
    [sym_labels_section] = STATE(3491),
    [sym_layout_section] = STATE(3491),
    [sym_modify_modification] = STATE(3491),
    [sym_actions_section] = STATE(3491),
    [sym_views_section] = STATE(3491),
    [sym_dataset_section] = STATE(3491),
    [sym_report_dataitem] = STATE(3491),
    [sym_report_column] = STATE(3491),
    [sym_requestpage_section] = STATE(3491),
    [sym_rendering_section] = STATE(3491),
    [sym_elements_section] = STATE(3491),
    [sym_schema_section] = STATE(3491),
    [sym_assembly_declaration] = STATE(3491),
    [sym_event_declaration] = STATE(3491),
    [sym_procedure] = STATE(3491),
    [sym_preproc_split_procedure] = STATE(3491),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3491),
    [sym_var_section] = STATE(3491),
    [sym_attribute_item] = STATE(3491),
    [sym_preproc_conditional] = STATE(3491),
    [sym_preproc_if] = STATE(2724),
    [aux_sym_add_dataset_modification_repeat1] = STATE(3491),
    [anon_sym_SEMI] = ACTIONS(9390),
    [anon_sym_RBRACE] = ACTIONS(9393),
    [anon_sym_LBRACK] = ACTIONS(9395),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9398),
    [aux_sym_modify_modification_token1] = ACTIONS(9401),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9404),
    [anon_sym_POUNDif] = ACTIONS(9407),
    [anon_sym_POUNDIF] = ACTIONS(9407),
    [anon_sym_POUNDIf] = ACTIONS(9407),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9410),
    [sym_trigger_keyword] = ACTIONS(9413),
    [sym_var_keyword] = ACTIONS(9416),
    [sym_local_keyword] = ACTIONS(9419),
    [sym_internal_keyword] = ACTIONS(9422),
    [sym_protected_keyword] = ACTIONS(9419),
    [sym_event_keyword] = ACTIONS(9425),
    [sym_fields_keyword] = ACTIONS(9428),
    [sym_keys_keyword] = ACTIONS(9431),
    [sym_fieldgroups_keyword] = ACTIONS(9434),
    [sym_actions_keyword] = ACTIONS(9437),
    [sym_layout_keyword] = ACTIONS(9440),
    [sym_dataset_keyword] = ACTIONS(9443),
    [sym_elements_keyword] = ACTIONS(9446),
    [sym_dataitem_keyword] = ACTIONS(9449),
    [sym_column_keyword] = ACTIONS(9452),
    [sym_labels_keyword] = ACTIONS(9455),
    [sym_rendering_keyword] = ACTIONS(9458),
    [sym_requestpage_keyword] = ACTIONS(9461),
    [sym_schema_keyword] = ACTIONS(9464),
    [sym_views_keyword] = ACTIONS(9467),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9470),
    [sym_preproc_open] = ACTIONS(9407),
  },
  [STATE(3492)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(5457),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5829),
    [anon_sym_POUNDENDIF] = ACTIONS(5829),
    [anon_sym_POUNDEndif] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5829),
  },
  [STATE(3493)] = {
    [sym__body_element] = STATE(3496),
    [sym_empty_statement] = STATE(3496),
    [sym_property] = STATE(3496),
    [sym_fields_section] = STATE(3496),
    [sym_keys_section] = STATE(3496),
    [sym_fieldgroups_section] = STATE(3496),
    [sym_enum_value_declaration] = STATE(3496),
    [sym_labels_section] = STATE(3496),
    [sym_layout_section] = STATE(3496),
    [sym_modify_modification] = STATE(3496),
    [sym_actions_section] = STATE(3496),
    [sym_views_section] = STATE(3496),
    [sym_dataset_section] = STATE(3496),
    [sym_requestpage_section] = STATE(3496),
    [sym_rendering_section] = STATE(3496),
    [sym_elements_section] = STATE(3496),
    [sym_schema_section] = STATE(3496),
    [sym_assembly_declaration] = STATE(3496),
    [sym_event_declaration] = STATE(3496),
    [sym_procedure] = STATE(3496),
    [sym_preproc_split_procedure] = STATE(3496),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3496),
    [sym_var_section] = STATE(3496),
    [sym_attribute_item] = STATE(3496),
    [sym_preproc_conditional] = STATE(3496),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(5457),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3496),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5829),
    [anon_sym_POUNDENDIF] = ACTIONS(5829),
    [anon_sym_POUNDEndif] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5829),
  },
  [STATE(3494)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(5109),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5568),
    [anon_sym_POUNDENDIF] = ACTIONS(5568),
    [anon_sym_POUNDEndif] = ACTIONS(5568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5568),
  },
  [STATE(3495)] = {
    [aux_sym_where_condition_token1] = ACTIONS(4469),
    [anon_sym_LBRACK] = ACTIONS(4469),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_if] = ACTIONS(4469),
    [anon_sym_IF] = ACTIONS(4469),
    [anon_sym_If] = ACTIONS(4469),
    [sym_table_keyword] = ACTIONS(4467),
    [anon_sym_tableextension] = ACTIONS(4469),
    [anon_sym_TABLEEXTENSION] = ACTIONS(4469),
    [anon_sym_Tableextension] = ACTIONS(4469),
    [anon_sym_TableExtension] = ACTIONS(4469),
    [anon_sym_tableExtension] = ACTIONS(4469),
    [sym_page_keyword] = ACTIONS(4467),
    [anon_sym_pageextension] = ACTIONS(4469),
    [anon_sym_PAGEEXTENSION] = ACTIONS(4469),
    [anon_sym_Pageextension] = ACTIONS(4469),
    [anon_sym_PageExtension] = ACTIONS(4469),
    [anon_sym_pageExtension] = ACTIONS(4469),
    [anon_sym_codeunit] = ACTIONS(4469),
    [anon_sym_CODEUNIT] = ACTIONS(4469),
    [anon_sym_Codeunit] = ACTIONS(4469),
    [anon_sym_CodeUnit] = ACTIONS(4469),
    [anon_sym_COdeunit] = ACTIONS(4469),
    [anon_sym_codeUnit] = ACTIONS(4469),
    [sym_report_keyword] = ACTIONS(4467),
    [anon_sym_reportextension] = ACTIONS(4469),
    [anon_sym_REPORTEXTENSION] = ACTIONS(4469),
    [anon_sym_Reportextension] = ACTIONS(4469),
    [anon_sym_ReportExtension] = ACTIONS(4469),
    [anon_sym_reportExtension] = ACTIONS(4469),
    [sym_query_keyword] = ACTIONS(4469),
    [anon_sym_xmlport] = ACTIONS(4469),
    [anon_sym_XMLPORT] = ACTIONS(4469),
    [anon_sym_Xmlport] = ACTIONS(4469),
    [anon_sym_XMLport] = ACTIONS(4469),
    [anon_sym_XMLPort] = ACTIONS(4469),
    [anon_sym_XmlPort] = ACTIONS(4469),
    [anon_sym_enum] = ACTIONS(4467),
    [anon_sym_ENUM] = ACTIONS(4467),
    [anon_sym_Enum] = ACTIONS(4467),
    [anon_sym_eNUM] = ACTIONS(4469),
    [anon_sym_eNum] = ACTIONS(4469),
    [anon_sym_ENum] = ACTIONS(4469),
    [anon_sym_enumextension] = ACTIONS(4469),
    [anon_sym_ENUMEXTENSION] = ACTIONS(4469),
    [anon_sym_Enumextension] = ACTIONS(4469),
    [anon_sym_EnumExtension] = ACTIONS(4469),
    [anon_sym_enumExtension] = ACTIONS(4469),
    [sym_interface_keyword] = ACTIONS(4469),
    [anon_sym_permissionset] = ACTIONS(4467),
    [anon_sym_PERMISSIONSET] = ACTIONS(4467),
    [anon_sym_Permissionset] = ACTIONS(4467),
    [anon_sym_PermissionSet] = ACTIONS(4467),
    [anon_sym_permissionSet] = ACTIONS(4467),
    [anon_sym_permissionsetextension] = ACTIONS(4469),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(4469),
    [anon_sym_Permissionsetextension] = ACTIONS(4469),
    [anon_sym_PermissionSetExtension] = ACTIONS(4469),
    [anon_sym_permissionSetExtension] = ACTIONS(4469),
    [sym_procedure_keyword] = ACTIONS(4469),
    [sym_local_keyword] = ACTIONS(4469),
    [sym_internal_keyword] = ACTIONS(4469),
    [sym_protected_keyword] = ACTIONS(4469),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(3496)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(5509),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5829),
    [anon_sym_POUNDENDIF] = ACTIONS(5829),
    [anon_sym_POUNDEndif] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5829),
  },
  [STATE(3497)] = {
    [sym_identifier] = ACTIONS(9473),
    [anon_sym_COLON] = ACTIONS(9476),
    [anon_sym_DASH] = ACTIONS(9478),
    [aux_sym_boolean_token1] = ACTIONS(9473),
    [aux_sym_boolean_token2] = ACTIONS(9473),
    [sym_decimal] = ACTIONS(9473),
    [anon_sym_LPAREN] = ACTIONS(9478),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9473),
    [anon_sym_LBRACK] = ACTIONS(9478),
    [aux_sym_record_type_token1] = ACTIONS(9473),
    [aux_sym_basic_type_token21] = ACTIONS(9473),
    [aux_sym_basic_type_token22] = ACTIONS(9473),
    [aux_sym_basic_type_token48] = ACTIONS(9473),
    [anon_sym_POUNDif] = ACTIONS(9476),
    [anon_sym_POUNDIF] = ACTIONS(9476),
    [anon_sym_POUNDIf] = ACTIONS(9476),
    [anon_sym_not] = ACTIONS(9473),
    [anon_sym_NOT] = ACTIONS(9473),
    [anon_sym_Not] = ACTIONS(9473),
    [anon_sym_POUNDelif] = ACTIONS(9481),
    [anon_sym_POUNDELIF] = ACTIONS(9481),
    [anon_sym_POUNDElif] = ACTIONS(9481),
    [anon_sym_POUNDelse] = ACTIONS(9481),
    [anon_sym_POUNDELSE] = ACTIONS(9481),
    [anon_sym_POUNDElse] = ACTIONS(9481),
    [anon_sym_POUNDendif] = ACTIONS(9481),
    [anon_sym_POUNDENDIF] = ACTIONS(9481),
    [anon_sym_POUNDEndif] = ACTIONS(9481),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9473),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9473),
    [anon_sym_PLUS] = ACTIONS(9478),
    [sym_datetime_literal] = ACTIONS(9478),
    [sym_date_literal] = ACTIONS(9473),
    [sym_time_literal] = ACTIONS(9473),
    [sym_biginteger_literal] = ACTIONS(9478),
    [sym_page_keyword] = ACTIONS(9473),
    [anon_sym_codeunit] = ACTIONS(9473),
    [anon_sym_CODEUNIT] = ACTIONS(9473),
    [anon_sym_Codeunit] = ACTIONS(9473),
    [anon_sym_CodeUnit] = ACTIONS(9473),
    [anon_sym_COdeunit] = ACTIONS(9473),
    [anon_sym_codeUnit] = ACTIONS(9473),
    [sym_report_keyword] = ACTIONS(9473),
    [sym_query_keyword] = ACTIONS(9473),
    [anon_sym_xmlport] = ACTIONS(9473),
    [anon_sym_XMLPORT] = ACTIONS(9473),
    [anon_sym_Xmlport] = ACTIONS(9473),
    [anon_sym_XMLport] = ACTIONS(9473),
    [anon_sym_XMLPort] = ACTIONS(9473),
    [anon_sym_XmlPort] = ACTIONS(9473),
    [anon_sym_enum] = ACTIONS(9473),
    [anon_sym_ENUM] = ACTIONS(9473),
    [anon_sym_Enum] = ACTIONS(9473),
    [anon_sym_eNUM] = ACTIONS(9473),
    [anon_sym_eNum] = ACTIONS(9473),
    [anon_sym_ENum] = ACTIONS(9473),
    [sym_quoted_identifier] = ACTIONS(9478),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9478),
    [sym_integer] = ACTIONS(9473),
    [sym_continue_as_identifier] = ACTIONS(9478),
    [sym_preproc_open] = ACTIONS(9476),
    [sym_preproc_close] = ACTIONS(9481),
  },
  [STATE(3498)] = {
    [sym__body_element] = STATE(3479),
    [sym_empty_statement] = STATE(3479),
    [sym_property] = STATE(3479),
    [sym_fields_section] = STATE(3479),
    [sym_keys_section] = STATE(3479),
    [sym_fieldgroups_section] = STATE(3479),
    [sym_enum_value_declaration] = STATE(3479),
    [sym_labels_section] = STATE(3479),
    [sym_layout_section] = STATE(3479),
    [sym_modify_modification] = STATE(3479),
    [sym_actions_section] = STATE(3479),
    [sym_views_section] = STATE(3479),
    [sym_dataset_section] = STATE(3479),
    [sym_requestpage_section] = STATE(3479),
    [sym_rendering_section] = STATE(3479),
    [sym_elements_section] = STATE(3479),
    [sym_schema_section] = STATE(3479),
    [sym_assembly_declaration] = STATE(3479),
    [sym_event_declaration] = STATE(3479),
    [sym_procedure] = STATE(3479),
    [sym_preproc_split_procedure] = STATE(3479),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3479),
    [sym_var_section] = STATE(3479),
    [sym_attribute_item] = STATE(3479),
    [sym_preproc_conditional] = STATE(3479),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(6760),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3479),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5869),
    [anon_sym_POUNDENDIF] = ACTIONS(5869),
    [anon_sym_POUNDEndif] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5869),
  },
  [STATE(3499)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(3644),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3500)] = {
    [sym_boolean] = STATE(8843),
    [sym_option_member] = STATE(8366),
    [sym_keyword_identifier] = STATE(8843),
    [sym_codeunit_keyword] = STATE(8787),
    [sym_xmlport_keyword] = STATE(8787),
    [sym_enum_keyword] = STATE(8787),
    [sym_keyword_as_identifier] = STATE(8843),
    [aux_sym_option_member_list_repeat2] = STATE(4669),
    [sym_identifier] = ACTIONS(9350),
    [anon_sym_SEMI] = ACTIONS(374),
    [anon_sym_COMMA] = ACTIONS(9483),
    [anon_sym_DASH] = ACTIONS(9354),
    [aux_sym_boolean_token1] = ACTIONS(9356),
    [aux_sym_boolean_token2] = ACTIONS(9356),
    [aux_sym_where_condition_token1] = ACTIONS(9358),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9360),
    [aux_sym_record_type_token1] = ACTIONS(9360),
    [aux_sym_basic_type_token21] = ACTIONS(9360),
    [aux_sym_basic_type_token22] = ACTIONS(9362),
    [aux_sym_basic_type_token48] = ACTIONS(9360),
    [aux_sym_basic_type_token53] = ACTIONS(9358),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9358),
    [aux_sym_separator_action_token1] = ACTIONS(9358),
    [aux_sym_type_declaration_token1] = ACTIONS(9358),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(376),
    [anon_sym_POUNDif] = ACTIONS(374),
    [anon_sym_POUNDIF] = ACTIONS(374),
    [anon_sym_POUNDIf] = ACTIONS(374),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9360),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9360),
    [sym_page_keyword] = ACTIONS(9360),
    [anon_sym_codeunit] = ACTIONS(9364),
    [anon_sym_CODEUNIT] = ACTIONS(9364),
    [anon_sym_Codeunit] = ACTIONS(9364),
    [anon_sym_CodeUnit] = ACTIONS(9364),
    [anon_sym_COdeunit] = ACTIONS(9364),
    [anon_sym_codeUnit] = ACTIONS(9364),
    [sym_report_keyword] = ACTIONS(9360),
    [sym_query_keyword] = ACTIONS(9360),
    [anon_sym_xmlport] = ACTIONS(9366),
    [anon_sym_XMLPORT] = ACTIONS(9366),
    [anon_sym_Xmlport] = ACTIONS(9366),
    [anon_sym_XMLport] = ACTIONS(9366),
    [anon_sym_XMLPort] = ACTIONS(9366),
    [anon_sym_XmlPort] = ACTIONS(9366),
    [anon_sym_enum] = ACTIONS(9368),
    [anon_sym_ENUM] = ACTIONS(9368),
    [anon_sym_Enum] = ACTIONS(9368),
    [anon_sym_eNUM] = ACTIONS(9368),
    [anon_sym_eNum] = ACTIONS(9368),
    [anon_sym_ENum] = ACTIONS(9368),
    [sym_var_keyword] = ACTIONS(376),
    [sym_local_keyword] = ACTIONS(9350),
    [sym_internal_keyword] = ACTIONS(9350),
    [sym_protected_keyword] = ACTIONS(9350),
    [sym_key_keyword] = ACTIONS(9358),
    [sym_dataset_keyword] = ACTIONS(9358),
    [sym_quoted_identifier] = ACTIONS(9370),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9370),
    [sym_integer] = ACTIONS(9370),
    [sym_preproc_open] = ACTIONS(374),
    [sym_begin_keyword] = ACTIONS(374),
  },
  [STATE(3501)] = {
    [sym__body_element] = STATE(3491),
    [sym_empty_statement] = STATE(3491),
    [sym_property] = STATE(3491),
    [sym_fields_section] = STATE(3491),
    [sym_keys_section] = STATE(3491),
    [sym_fieldgroups_section] = STATE(3491),
    [sym_enum_value_declaration] = STATE(3491),
    [sym_labels_section] = STATE(3491),
    [sym_layout_section] = STATE(3491),
    [sym_modify_modification] = STATE(3491),
    [sym_actions_section] = STATE(3491),
    [sym_views_section] = STATE(3491),
    [sym_dataset_section] = STATE(3491),
    [sym_report_dataitem] = STATE(3491),
    [sym_report_column] = STATE(3491),
    [sym_requestpage_section] = STATE(3491),
    [sym_rendering_section] = STATE(3491),
    [sym_elements_section] = STATE(3491),
    [sym_schema_section] = STATE(3491),
    [sym_assembly_declaration] = STATE(3491),
    [sym_event_declaration] = STATE(3491),
    [sym_procedure] = STATE(3491),
    [sym_preproc_split_procedure] = STATE(3491),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3491),
    [sym_var_section] = STATE(3491),
    [sym_attribute_item] = STATE(3491),
    [sym_preproc_conditional] = STATE(3491),
    [sym_preproc_if] = STATE(2724),
    [aux_sym_add_dataset_modification_repeat1] = STATE(3491),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9485),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3502)] = {
    [sym__body_element] = STATE(3465),
    [sym_empty_statement] = STATE(3465),
    [sym_property] = STATE(3465),
    [sym_fields_section] = STATE(3465),
    [sym_keys_section] = STATE(3465),
    [sym_fieldgroups_section] = STATE(3465),
    [sym_enum_value_declaration] = STATE(3465),
    [sym_labels_section] = STATE(3465),
    [sym_layout_section] = STATE(3465),
    [sym_modify_modification] = STATE(3465),
    [sym_actions_section] = STATE(3465),
    [sym_views_section] = STATE(3465),
    [sym_dataset_section] = STATE(3465),
    [sym_report_dataitem] = STATE(3465),
    [sym_report_column] = STATE(3465),
    [sym_requestpage_section] = STATE(3465),
    [sym_rendering_section] = STATE(3465),
    [sym_elements_section] = STATE(3465),
    [sym_schema_section] = STATE(3465),
    [sym_assembly_declaration] = STATE(3465),
    [sym_event_declaration] = STATE(3465),
    [sym_procedure] = STATE(3465),
    [sym_preproc_split_procedure] = STATE(3465),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3465),
    [sym_var_section] = STATE(3465),
    [sym_attribute_item] = STATE(3465),
    [sym_preproc_conditional] = STATE(3465),
    [sym_preproc_if] = STATE(2724),
    [aux_sym_add_dataset_modification_repeat1] = STATE(3465),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9487),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3503)] = {
    [sym__body_element] = STATE(3491),
    [sym_empty_statement] = STATE(3491),
    [sym_property] = STATE(3491),
    [sym_fields_section] = STATE(3491),
    [sym_keys_section] = STATE(3491),
    [sym_fieldgroups_section] = STATE(3491),
    [sym_enum_value_declaration] = STATE(3491),
    [sym_labels_section] = STATE(3491),
    [sym_layout_section] = STATE(3491),
    [sym_modify_modification] = STATE(3491),
    [sym_actions_section] = STATE(3491),
    [sym_views_section] = STATE(3491),
    [sym_dataset_section] = STATE(3491),
    [sym_report_dataitem] = STATE(3491),
    [sym_report_column] = STATE(3491),
    [sym_requestpage_section] = STATE(3491),
    [sym_rendering_section] = STATE(3491),
    [sym_elements_section] = STATE(3491),
    [sym_schema_section] = STATE(3491),
    [sym_assembly_declaration] = STATE(3491),
    [sym_event_declaration] = STATE(3491),
    [sym_procedure] = STATE(3491),
    [sym_preproc_split_procedure] = STATE(3491),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3491),
    [sym_var_section] = STATE(3491),
    [sym_attribute_item] = STATE(3491),
    [sym_preproc_conditional] = STATE(3491),
    [sym_preproc_if] = STATE(2724),
    [aux_sym_add_dataset_modification_repeat1] = STATE(3491),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(9489),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3825),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_dataitem_keyword] = ACTIONS(9113),
    [sym_column_keyword] = ACTIONS(9115),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3504)] = {
    [aux_sym_where_condition_token1] = ACTIONS(4810),
    [anon_sym_LBRACK] = ACTIONS(4810),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_if] = ACTIONS(4810),
    [anon_sym_IF] = ACTIONS(4810),
    [anon_sym_If] = ACTIONS(4810),
    [sym_table_keyword] = ACTIONS(4808),
    [anon_sym_tableextension] = ACTIONS(4810),
    [anon_sym_TABLEEXTENSION] = ACTIONS(4810),
    [anon_sym_Tableextension] = ACTIONS(4810),
    [anon_sym_TableExtension] = ACTIONS(4810),
    [anon_sym_tableExtension] = ACTIONS(4810),
    [sym_page_keyword] = ACTIONS(4808),
    [anon_sym_pageextension] = ACTIONS(4810),
    [anon_sym_PAGEEXTENSION] = ACTIONS(4810),
    [anon_sym_Pageextension] = ACTIONS(4810),
    [anon_sym_PageExtension] = ACTIONS(4810),
    [anon_sym_pageExtension] = ACTIONS(4810),
    [anon_sym_codeunit] = ACTIONS(4810),
    [anon_sym_CODEUNIT] = ACTIONS(4810),
    [anon_sym_Codeunit] = ACTIONS(4810),
    [anon_sym_CodeUnit] = ACTIONS(4810),
    [anon_sym_COdeunit] = ACTIONS(4810),
    [anon_sym_codeUnit] = ACTIONS(4810),
    [sym_report_keyword] = ACTIONS(4808),
    [anon_sym_reportextension] = ACTIONS(4810),
    [anon_sym_REPORTEXTENSION] = ACTIONS(4810),
    [anon_sym_Reportextension] = ACTIONS(4810),
    [anon_sym_ReportExtension] = ACTIONS(4810),
    [anon_sym_reportExtension] = ACTIONS(4810),
    [sym_query_keyword] = ACTIONS(4810),
    [anon_sym_xmlport] = ACTIONS(4810),
    [anon_sym_XMLPORT] = ACTIONS(4810),
    [anon_sym_Xmlport] = ACTIONS(4810),
    [anon_sym_XMLport] = ACTIONS(4810),
    [anon_sym_XMLPort] = ACTIONS(4810),
    [anon_sym_XmlPort] = ACTIONS(4810),
    [anon_sym_enum] = ACTIONS(4808),
    [anon_sym_ENUM] = ACTIONS(4808),
    [anon_sym_Enum] = ACTIONS(4808),
    [anon_sym_eNUM] = ACTIONS(4810),
    [anon_sym_eNum] = ACTIONS(4810),
    [anon_sym_ENum] = ACTIONS(4810),
    [anon_sym_enumextension] = ACTIONS(4810),
    [anon_sym_ENUMEXTENSION] = ACTIONS(4810),
    [anon_sym_Enumextension] = ACTIONS(4810),
    [anon_sym_EnumExtension] = ACTIONS(4810),
    [anon_sym_enumExtension] = ACTIONS(4810),
    [sym_interface_keyword] = ACTIONS(4810),
    [anon_sym_permissionset] = ACTIONS(4808),
    [anon_sym_PERMISSIONSET] = ACTIONS(4808),
    [anon_sym_Permissionset] = ACTIONS(4808),
    [anon_sym_PermissionSet] = ACTIONS(4808),
    [anon_sym_permissionSet] = ACTIONS(4808),
    [anon_sym_permissionsetextension] = ACTIONS(4810),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(4810),
    [anon_sym_Permissionsetextension] = ACTIONS(4810),
    [anon_sym_PermissionSetExtension] = ACTIONS(4810),
    [anon_sym_permissionSetExtension] = ACTIONS(4810),
    [sym_procedure_keyword] = ACTIONS(4810),
    [sym_local_keyword] = ACTIONS(4810),
    [sym_internal_keyword] = ACTIONS(4810),
    [sym_protected_keyword] = ACTIONS(4810),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(3505)] = {
    [sym__body_element] = STATE(3284),
    [sym_empty_statement] = STATE(3284),
    [sym_property] = STATE(3284),
    [sym_fields_section] = STATE(3284),
    [sym_keys_section] = STATE(3284),
    [sym_fieldgroups_section] = STATE(3284),
    [sym_enum_value_declaration] = STATE(3284),
    [sym_labels_section] = STATE(3284),
    [sym_layout_section] = STATE(3284),
    [sym_modify_modification] = STATE(3284),
    [sym_actions_section] = STATE(3284),
    [sym_views_section] = STATE(3284),
    [sym_dataset_section] = STATE(3284),
    [sym_requestpage_section] = STATE(3284),
    [sym_rendering_section] = STATE(3284),
    [sym_elements_section] = STATE(3284),
    [sym_schema_section] = STATE(3284),
    [sym_assembly_declaration] = STATE(3284),
    [sym_event_declaration] = STATE(3284),
    [sym_procedure] = STATE(3284),
    [sym_preproc_split_procedure] = STATE(3284),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3284),
    [sym_var_section] = STATE(3284),
    [sym_attribute_item] = STATE(3284),
    [sym_preproc_conditional] = STATE(3284),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(6748),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3284),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(5869),
    [anon_sym_POUNDENDIF] = ACTIONS(5869),
    [anon_sym_POUNDEndif] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(5869),
  },
  [STATE(3506)] = {
    [sym__body_element] = STATE(3469),
    [sym_empty_statement] = STATE(3469),
    [sym_property] = STATE(3469),
    [sym_fields_section] = STATE(3469),
    [sym_keys_section] = STATE(3469),
    [sym_fieldgroups_section] = STATE(3469),
    [sym_enum_value_declaration] = STATE(3469),
    [sym_labels_section] = STATE(3469),
    [sym_layout_section] = STATE(3469),
    [sym_modify_modification] = STATE(3469),
    [sym_actions_section] = STATE(3469),
    [sym_views_section] = STATE(3469),
    [sym_dataset_section] = STATE(3469),
    [sym_requestpage_section] = STATE(3469),
    [sym_rendering_section] = STATE(3469),
    [sym_elements_section] = STATE(3469),
    [sym_schema_section] = STATE(3469),
    [sym_assembly_declaration] = STATE(3469),
    [sym_event_declaration] = STATE(3469),
    [sym_procedure] = STATE(3469),
    [sym_preproc_split_procedure] = STATE(3469),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3469),
    [sym_var_section] = STATE(3469),
    [sym_attribute_item] = STATE(3469),
    [sym_preproc_conditional] = STATE(3469),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(4011),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3469),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3507)] = {
    [sym__body_element] = STATE(3480),
    [sym_empty_statement] = STATE(3480),
    [sym_property] = STATE(3480),
    [sym_fields_section] = STATE(3480),
    [sym_keys_section] = STATE(3480),
    [sym_fieldgroups_section] = STATE(3480),
    [sym_enum_value_declaration] = STATE(3480),
    [sym_labels_section] = STATE(3480),
    [sym_layout_section] = STATE(3480),
    [sym_modify_modification] = STATE(3480),
    [sym_actions_section] = STATE(3480),
    [sym_views_section] = STATE(3480),
    [sym_dataset_section] = STATE(3480),
    [sym_requestpage_section] = STATE(3480),
    [sym_rendering_section] = STATE(3480),
    [sym_elements_section] = STATE(3480),
    [sym_schema_section] = STATE(3480),
    [sym_assembly_declaration] = STATE(3480),
    [sym_event_declaration] = STATE(3480),
    [sym_procedure] = STATE(3480),
    [sym_preproc_split_procedure] = STATE(3480),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3480),
    [sym_var_section] = STATE(3480),
    [sym_attribute_item] = STATE(3480),
    [sym_preproc_conditional] = STATE(3480),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(4227),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3480),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2881),
    [anon_sym_POUNDENDIF] = ACTIONS(2881),
    [anon_sym_POUNDEndif] = ACTIONS(2881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2881),
  },
  [STATE(3508)] = {
    [sym__body_element] = STATE(3474),
    [sym_empty_statement] = STATE(3474),
    [sym_property] = STATE(3474),
    [sym_fields_section] = STATE(3474),
    [sym_keys_section] = STATE(3474),
    [sym_fieldgroups_section] = STATE(3474),
    [sym_enum_value_declaration] = STATE(3474),
    [sym_labels_section] = STATE(3474),
    [sym_layout_section] = STATE(3474),
    [sym_modify_modification] = STATE(3474),
    [sym_actions_section] = STATE(3474),
    [sym_views_section] = STATE(3474),
    [sym_dataset_section] = STATE(3474),
    [sym_requestpage_section] = STATE(3474),
    [sym_rendering_section] = STATE(3474),
    [sym_elements_section] = STATE(3474),
    [sym_schema_section] = STATE(3474),
    [sym_assembly_declaration] = STATE(3474),
    [sym_event_declaration] = STATE(3474),
    [sym_procedure] = STATE(3474),
    [sym_preproc_split_procedure] = STATE(3474),
    [sym_procedure_modifier] = STATE(12268),
    [sym_trigger_declaration] = STATE(3474),
    [sym_var_section] = STATE(3474),
    [sym_attribute_item] = STATE(3474),
    [sym_preproc_conditional] = STATE(3474),
    [sym_preproc_if] = STATE(2733),
    [sym_preproc_endif] = STATE(3729),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3474),
    [anon_sym_SEMI] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2857),
    [aux_sym_modify_modification_token1] = ACTIONS(2863),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [anon_sym_POUNDendif] = ACTIONS(2977),
    [anon_sym_POUNDENDIF] = ACTIONS(2977),
    [anon_sym_POUNDEndif] = ACTIONS(2977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3416),
    [sym_trigger_keyword] = ACTIONS(2885),
    [sym_var_keyword] = ACTIONS(2887),
    [sym_local_keyword] = ACTIONS(2889),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(2889),
    [sym_event_keyword] = ACTIONS(2893),
    [sym_fields_keyword] = ACTIONS(2895),
    [sym_keys_keyword] = ACTIONS(2897),
    [sym_fieldgroups_keyword] = ACTIONS(2899),
    [sym_actions_keyword] = ACTIONS(2901),
    [sym_layout_keyword] = ACTIONS(2903),
    [sym_dataset_keyword] = ACTIONS(2923),
    [sym_elements_keyword] = ACTIONS(2925),
    [sym_labels_keyword] = ACTIONS(2927),
    [sym_rendering_keyword] = ACTIONS(2929),
    [sym_requestpage_keyword] = ACTIONS(2931),
    [sym_schema_keyword] = ACTIONS(2933),
    [sym_views_keyword] = ACTIONS(2935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2937),
    [sym_preproc_open] = ACTIONS(2875),
    [sym_preproc_close] = ACTIONS(2977),
  },
  [STATE(3509)] = {
    [anon_sym_SEMI] = ACTIONS(9491),
    [aux_sym_where_condition_token1] = ACTIONS(9493),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9495),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9495),
    [anon_sym_LBRACK] = ACTIONS(9495),
    [aux_sym_basic_type_token6] = ACTIONS(9493),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9495),
    [aux_sym_addafter_modification_token1] = ACTIONS(9495),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9495),
    [aux_sym_modify_modification_token1] = ACTIONS(9495),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9495),
    [aux_sym_movelast_modification_token1] = ACTIONS(9495),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9495),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9495),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9495),
    [anon_sym_POUNDif] = ACTIONS(9495),
    [anon_sym_POUNDIF] = ACTIONS(9495),
    [anon_sym_POUNDIf] = ACTIONS(9495),
    [anon_sym_POUNDelif] = ACTIONS(9495),
    [anon_sym_POUNDELIF] = ACTIONS(9495),
    [anon_sym_POUNDElif] = ACTIONS(9495),
    [anon_sym_POUNDelse] = ACTIONS(9495),
    [anon_sym_POUNDELSE] = ACTIONS(9495),
    [anon_sym_POUNDElse] = ACTIONS(9495),
    [anon_sym_POUNDendif] = ACTIONS(9495),
    [anon_sym_POUNDENDIF] = ACTIONS(9495),
    [anon_sym_POUNDEndif] = ACTIONS(9495),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9495),
    [sym_trigger_keyword] = ACTIONS(9495),
    [sym_var_keyword] = ACTIONS(9495),
    [sym_local_keyword] = ACTIONS(9495),
    [sym_internal_keyword] = ACTIONS(9495),
    [sym_protected_keyword] = ACTIONS(9495),
    [sym_event_keyword] = ACTIONS(9495),
    [sym_fields_keyword] = ACTIONS(9495),
    [sym_keys_keyword] = ACTIONS(9495),
    [sym_fieldgroups_keyword] = ACTIONS(9495),
    [sym_actions_keyword] = ACTIONS(9495),
    [sym_layout_keyword] = ACTIONS(9495),
    [sym_area_keyword] = ACTIONS(9495),
    [sym_group_keyword] = ACTIONS(9495),
    [sym_repeater_keyword] = ACTIONS(9495),
    [sym_cuegroup_keyword] = ACTIONS(9495),
    [sym_fixed_keyword] = ACTIONS(9495),
    [sym_grid_keyword] = ACTIONS(9495),
    [sym_part_keyword] = ACTIONS(9495),
    [sym_systempart_keyword] = ACTIONS(9495),
    [sym_usercontrol_keyword] = ACTIONS(9495),
    [sym_dataset_keyword] = ACTIONS(9495),
    [sym_elements_keyword] = ACTIONS(9495),
    [sym_dataitem_keyword] = ACTIONS(9495),
    [sym_column_keyword] = ACTIONS(9495),
    [sym_filter_keyword] = ACTIONS(9495),
    [sym_labels_keyword] = ACTIONS(9495),
    [sym_rendering_keyword] = ACTIONS(9495),
    [sym_requestpage_keyword] = ACTIONS(9495),
    [sym_schema_keyword] = ACTIONS(9495),
    [sym_views_keyword] = ACTIONS(9495),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9495),
    [sym_preproc_open] = ACTIONS(9495),
    [sym_preproc_close] = ACTIONS(9495),
  },
  [STATE(3510)] = {
    [anon_sym_SEMI] = ACTIONS(9497),
    [aux_sym_where_condition_token1] = ACTIONS(9499),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9497),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9497),
    [anon_sym_LBRACK] = ACTIONS(9497),
    [aux_sym_basic_type_token6] = ACTIONS(9499),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9497),
    [aux_sym_addafter_modification_token1] = ACTIONS(9497),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9497),
    [aux_sym_modify_modification_token1] = ACTIONS(9497),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9497),
    [aux_sym_movelast_modification_token1] = ACTIONS(9497),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9497),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9497),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9497),
    [anon_sym_POUNDif] = ACTIONS(9497),
    [anon_sym_POUNDIF] = ACTIONS(9497),
    [anon_sym_POUNDIf] = ACTIONS(9497),
    [anon_sym_POUNDelif] = ACTIONS(9497),
    [anon_sym_POUNDELIF] = ACTIONS(9497),
    [anon_sym_POUNDElif] = ACTIONS(9497),
    [anon_sym_POUNDelse] = ACTIONS(9497),
    [anon_sym_POUNDELSE] = ACTIONS(9497),
    [anon_sym_POUNDElse] = ACTIONS(9497),
    [anon_sym_POUNDendif] = ACTIONS(9497),
    [anon_sym_POUNDENDIF] = ACTIONS(9497),
    [anon_sym_POUNDEndif] = ACTIONS(9497),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9497),
    [sym_trigger_keyword] = ACTIONS(9497),
    [sym_var_keyword] = ACTIONS(9497),
    [sym_local_keyword] = ACTIONS(9497),
    [sym_internal_keyword] = ACTIONS(9497),
    [sym_protected_keyword] = ACTIONS(9497),
    [sym_event_keyword] = ACTIONS(9497),
    [sym_fields_keyword] = ACTIONS(9497),
    [sym_keys_keyword] = ACTIONS(9497),
    [sym_fieldgroups_keyword] = ACTIONS(9497),
    [sym_actions_keyword] = ACTIONS(9497),
    [sym_layout_keyword] = ACTIONS(9497),
    [sym_area_keyword] = ACTIONS(9497),
    [sym_group_keyword] = ACTIONS(9497),
    [sym_repeater_keyword] = ACTIONS(9497),
    [sym_cuegroup_keyword] = ACTIONS(9497),
    [sym_fixed_keyword] = ACTIONS(9497),
    [sym_grid_keyword] = ACTIONS(9497),
    [sym_part_keyword] = ACTIONS(9497),
    [sym_systempart_keyword] = ACTIONS(9497),
    [sym_usercontrol_keyword] = ACTIONS(9497),
    [sym_dataset_keyword] = ACTIONS(9497),
    [sym_elements_keyword] = ACTIONS(9497),
    [sym_dataitem_keyword] = ACTIONS(9497),
    [sym_column_keyword] = ACTIONS(9497),
    [sym_filter_keyword] = ACTIONS(9497),
    [sym_labels_keyword] = ACTIONS(9497),
    [sym_rendering_keyword] = ACTIONS(9497),
    [sym_requestpage_keyword] = ACTIONS(9497),
    [sym_schema_keyword] = ACTIONS(9497),
    [sym_views_keyword] = ACTIONS(9497),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9497),
    [sym_preproc_open] = ACTIONS(9497),
    [sym_preproc_close] = ACTIONS(9497),
  },
  [STATE(3511)] = {
    [anon_sym_SEMI] = ACTIONS(9501),
    [aux_sym_where_condition_token1] = ACTIONS(9503),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9501),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9501),
    [anon_sym_LBRACK] = ACTIONS(9501),
    [aux_sym_basic_type_token6] = ACTIONS(9503),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9501),
    [aux_sym_addafter_modification_token1] = ACTIONS(9501),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9501),
    [aux_sym_modify_modification_token1] = ACTIONS(9501),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9501),
    [aux_sym_movelast_modification_token1] = ACTIONS(9501),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9501),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9501),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9501),
    [anon_sym_POUNDif] = ACTIONS(9501),
    [anon_sym_POUNDIF] = ACTIONS(9501),
    [anon_sym_POUNDIf] = ACTIONS(9501),
    [anon_sym_POUNDelif] = ACTIONS(9501),
    [anon_sym_POUNDELIF] = ACTIONS(9501),
    [anon_sym_POUNDElif] = ACTIONS(9501),
    [anon_sym_POUNDelse] = ACTIONS(9501),
    [anon_sym_POUNDELSE] = ACTIONS(9501),
    [anon_sym_POUNDElse] = ACTIONS(9501),
    [anon_sym_POUNDendif] = ACTIONS(9501),
    [anon_sym_POUNDENDIF] = ACTIONS(9501),
    [anon_sym_POUNDEndif] = ACTIONS(9501),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9501),
    [sym_trigger_keyword] = ACTIONS(9501),
    [sym_var_keyword] = ACTIONS(9501),
    [sym_local_keyword] = ACTIONS(9501),
    [sym_internal_keyword] = ACTIONS(9501),
    [sym_protected_keyword] = ACTIONS(9501),
    [sym_event_keyword] = ACTIONS(9501),
    [sym_fields_keyword] = ACTIONS(9501),
    [sym_keys_keyword] = ACTIONS(9501),
    [sym_fieldgroups_keyword] = ACTIONS(9501),
    [sym_actions_keyword] = ACTIONS(9501),
    [sym_layout_keyword] = ACTIONS(9501),
    [sym_area_keyword] = ACTIONS(9501),
    [sym_group_keyword] = ACTIONS(9501),
    [sym_repeater_keyword] = ACTIONS(9501),
    [sym_cuegroup_keyword] = ACTIONS(9501),
    [sym_fixed_keyword] = ACTIONS(9501),
    [sym_grid_keyword] = ACTIONS(9501),
    [sym_part_keyword] = ACTIONS(9501),
    [sym_systempart_keyword] = ACTIONS(9501),
    [sym_usercontrol_keyword] = ACTIONS(9501),
    [sym_dataset_keyword] = ACTIONS(9501),
    [sym_elements_keyword] = ACTIONS(9501),
    [sym_dataitem_keyword] = ACTIONS(9501),
    [sym_column_keyword] = ACTIONS(9501),
    [sym_filter_keyword] = ACTIONS(9501),
    [sym_labels_keyword] = ACTIONS(9501),
    [sym_rendering_keyword] = ACTIONS(9501),
    [sym_requestpage_keyword] = ACTIONS(9501),
    [sym_schema_keyword] = ACTIONS(9501),
    [sym_views_keyword] = ACTIONS(9501),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9501),
    [sym_preproc_open] = ACTIONS(9501),
    [sym_preproc_close] = ACTIONS(9501),
  },
  [STATE(3512)] = {
    [anon_sym_SEMI] = ACTIONS(7377),
    [aux_sym_where_condition_token1] = ACTIONS(7375),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7377),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7377),
    [anon_sym_LBRACK] = ACTIONS(7377),
    [aux_sym_basic_type_token6] = ACTIONS(7375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7377),
    [aux_sym_addafter_modification_token1] = ACTIONS(7377),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7377),
    [aux_sym_modify_modification_token1] = ACTIONS(7377),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7377),
    [aux_sym_movelast_modification_token1] = ACTIONS(7377),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7377),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7377),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7377),
    [anon_sym_POUNDif] = ACTIONS(7377),
    [anon_sym_POUNDIF] = ACTIONS(7377),
    [anon_sym_POUNDIf] = ACTIONS(7377),
    [anon_sym_POUNDelif] = ACTIONS(7377),
    [anon_sym_POUNDELIF] = ACTIONS(7377),
    [anon_sym_POUNDElif] = ACTIONS(7377),
    [anon_sym_POUNDelse] = ACTIONS(7377),
    [anon_sym_POUNDELSE] = ACTIONS(7377),
    [anon_sym_POUNDElse] = ACTIONS(7377),
    [anon_sym_POUNDendif] = ACTIONS(7377),
    [anon_sym_POUNDENDIF] = ACTIONS(7377),
    [anon_sym_POUNDEndif] = ACTIONS(7377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7377),
    [sym_trigger_keyword] = ACTIONS(7377),
    [sym_var_keyword] = ACTIONS(7377),
    [sym_local_keyword] = ACTIONS(7377),
    [sym_internal_keyword] = ACTIONS(7377),
    [sym_protected_keyword] = ACTIONS(7377),
    [sym_event_keyword] = ACTIONS(7377),
    [sym_fields_keyword] = ACTIONS(7377),
    [sym_keys_keyword] = ACTIONS(7377),
    [sym_fieldgroups_keyword] = ACTIONS(7377),
    [sym_actions_keyword] = ACTIONS(7377),
    [sym_layout_keyword] = ACTIONS(7377),
    [sym_area_keyword] = ACTIONS(7377),
    [sym_group_keyword] = ACTIONS(7377),
    [sym_repeater_keyword] = ACTIONS(7377),
    [sym_cuegroup_keyword] = ACTIONS(7377),
    [sym_fixed_keyword] = ACTIONS(7377),
    [sym_grid_keyword] = ACTIONS(7377),
    [sym_part_keyword] = ACTIONS(7377),
    [sym_systempart_keyword] = ACTIONS(7377),
    [sym_usercontrol_keyword] = ACTIONS(7377),
    [sym_dataset_keyword] = ACTIONS(7377),
    [sym_elements_keyword] = ACTIONS(7377),
    [sym_dataitem_keyword] = ACTIONS(7377),
    [sym_column_keyword] = ACTIONS(7377),
    [sym_filter_keyword] = ACTIONS(7377),
    [sym_labels_keyword] = ACTIONS(7377),
    [sym_rendering_keyword] = ACTIONS(7377),
    [sym_requestpage_keyword] = ACTIONS(7377),
    [sym_schema_keyword] = ACTIONS(7377),
    [sym_views_keyword] = ACTIONS(7377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7377),
    [sym_preproc_open] = ACTIONS(7377),
    [sym_preproc_close] = ACTIONS(7377),
  },
  [STATE(3513)] = {
    [anon_sym_SEMI] = ACTIONS(7377),
    [aux_sym_where_condition_token1] = ACTIONS(7375),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7377),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7377),
    [anon_sym_LBRACK] = ACTIONS(7377),
    [aux_sym_basic_type_token6] = ACTIONS(7375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7377),
    [aux_sym_addafter_modification_token1] = ACTIONS(7377),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7377),
    [aux_sym_modify_modification_token1] = ACTIONS(7377),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7377),
    [aux_sym_movelast_modification_token1] = ACTIONS(7377),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7377),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7377),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7377),
    [anon_sym_POUNDif] = ACTIONS(7377),
    [anon_sym_POUNDIF] = ACTIONS(7377),
    [anon_sym_POUNDIf] = ACTIONS(7377),
    [anon_sym_POUNDelif] = ACTIONS(7377),
    [anon_sym_POUNDELIF] = ACTIONS(7377),
    [anon_sym_POUNDElif] = ACTIONS(7377),
    [anon_sym_POUNDelse] = ACTIONS(7377),
    [anon_sym_POUNDELSE] = ACTIONS(7377),
    [anon_sym_POUNDElse] = ACTIONS(7377),
    [anon_sym_POUNDendif] = ACTIONS(7377),
    [anon_sym_POUNDENDIF] = ACTIONS(7377),
    [anon_sym_POUNDEndif] = ACTIONS(7377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7377),
    [sym_trigger_keyword] = ACTIONS(7377),
    [sym_var_keyword] = ACTIONS(7377),
    [sym_local_keyword] = ACTIONS(7377),
    [sym_internal_keyword] = ACTIONS(7377),
    [sym_protected_keyword] = ACTIONS(7377),
    [sym_event_keyword] = ACTIONS(7377),
    [sym_fields_keyword] = ACTIONS(7377),
    [sym_keys_keyword] = ACTIONS(7377),
    [sym_fieldgroups_keyword] = ACTIONS(7377),
    [sym_actions_keyword] = ACTIONS(7377),
    [sym_layout_keyword] = ACTIONS(7377),
    [sym_area_keyword] = ACTIONS(7377),
    [sym_group_keyword] = ACTIONS(7377),
    [sym_repeater_keyword] = ACTIONS(7377),
    [sym_cuegroup_keyword] = ACTIONS(7377),
    [sym_fixed_keyword] = ACTIONS(7377),
    [sym_grid_keyword] = ACTIONS(7377),
    [sym_part_keyword] = ACTIONS(7377),
    [sym_systempart_keyword] = ACTIONS(7377),
    [sym_usercontrol_keyword] = ACTIONS(7377),
    [sym_dataset_keyword] = ACTIONS(7377),
    [sym_elements_keyword] = ACTIONS(7377),
    [sym_dataitem_keyword] = ACTIONS(7377),
    [sym_column_keyword] = ACTIONS(7377),
    [sym_filter_keyword] = ACTIONS(7377),
    [sym_labels_keyword] = ACTIONS(7377),
    [sym_rendering_keyword] = ACTIONS(7377),
    [sym_requestpage_keyword] = ACTIONS(7377),
    [sym_schema_keyword] = ACTIONS(7377),
    [sym_views_keyword] = ACTIONS(7377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7377),
    [sym_preproc_open] = ACTIONS(7377),
    [sym_preproc_close] = ACTIONS(7377),
  },
  [STATE(3514)] = {
    [anon_sym_SEMI] = ACTIONS(8473),
    [aux_sym_where_condition_token1] = ACTIONS(8471),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8473),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8473),
    [anon_sym_LBRACK] = ACTIONS(8473),
    [aux_sym_basic_type_token6] = ACTIONS(8471),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8473),
    [aux_sym_addafter_modification_token1] = ACTIONS(8473),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8473),
    [aux_sym_modify_modification_token1] = ACTIONS(8473),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8473),
    [aux_sym_movelast_modification_token1] = ACTIONS(8473),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8473),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8473),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8473),
    [anon_sym_POUNDif] = ACTIONS(8473),
    [anon_sym_POUNDIF] = ACTIONS(8473),
    [anon_sym_POUNDIf] = ACTIONS(8473),
    [anon_sym_POUNDelif] = ACTIONS(8473),
    [anon_sym_POUNDELIF] = ACTIONS(8473),
    [anon_sym_POUNDElif] = ACTIONS(8473),
    [anon_sym_POUNDelse] = ACTIONS(8473),
    [anon_sym_POUNDELSE] = ACTIONS(8473),
    [anon_sym_POUNDElse] = ACTIONS(8473),
    [anon_sym_POUNDendif] = ACTIONS(8473),
    [anon_sym_POUNDENDIF] = ACTIONS(8473),
    [anon_sym_POUNDEndif] = ACTIONS(8473),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8473),
    [sym_trigger_keyword] = ACTIONS(8473),
    [sym_var_keyword] = ACTIONS(8473),
    [sym_local_keyword] = ACTIONS(8473),
    [sym_internal_keyword] = ACTIONS(8473),
    [sym_protected_keyword] = ACTIONS(8473),
    [sym_event_keyword] = ACTIONS(8473),
    [sym_fields_keyword] = ACTIONS(8473),
    [sym_keys_keyword] = ACTIONS(8473),
    [sym_fieldgroups_keyword] = ACTIONS(8473),
    [sym_actions_keyword] = ACTIONS(8473),
    [sym_layout_keyword] = ACTIONS(8473),
    [sym_area_keyword] = ACTIONS(8473),
    [sym_group_keyword] = ACTIONS(8473),
    [sym_repeater_keyword] = ACTIONS(8473),
    [sym_cuegroup_keyword] = ACTIONS(8473),
    [sym_fixed_keyword] = ACTIONS(8473),
    [sym_grid_keyword] = ACTIONS(8473),
    [sym_part_keyword] = ACTIONS(8473),
    [sym_systempart_keyword] = ACTIONS(8473),
    [sym_usercontrol_keyword] = ACTIONS(8473),
    [sym_dataset_keyword] = ACTIONS(8473),
    [sym_elements_keyword] = ACTIONS(8473),
    [sym_dataitem_keyword] = ACTIONS(8473),
    [sym_column_keyword] = ACTIONS(8473),
    [sym_filter_keyword] = ACTIONS(8473),
    [sym_labels_keyword] = ACTIONS(8473),
    [sym_rendering_keyword] = ACTIONS(8473),
    [sym_requestpage_keyword] = ACTIONS(8473),
    [sym_schema_keyword] = ACTIONS(8473),
    [sym_views_keyword] = ACTIONS(8473),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8473),
    [sym_preproc_open] = ACTIONS(8473),
    [sym_preproc_close] = ACTIONS(8473),
  },
  [STATE(3515)] = {
    [anon_sym_SEMI] = ACTIONS(9505),
    [aux_sym_where_condition_token1] = ACTIONS(9507),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9505),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9505),
    [anon_sym_LBRACK] = ACTIONS(9505),
    [aux_sym_basic_type_token6] = ACTIONS(9507),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9505),
    [aux_sym_addafter_modification_token1] = ACTIONS(9505),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9505),
    [aux_sym_modify_modification_token1] = ACTIONS(9505),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9505),
    [aux_sym_movelast_modification_token1] = ACTIONS(9505),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9505),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9505),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9505),
    [anon_sym_POUNDif] = ACTIONS(9505),
    [anon_sym_POUNDIF] = ACTIONS(9505),
    [anon_sym_POUNDIf] = ACTIONS(9505),
    [anon_sym_POUNDelif] = ACTIONS(9505),
    [anon_sym_POUNDELIF] = ACTIONS(9505),
    [anon_sym_POUNDElif] = ACTIONS(9505),
    [anon_sym_POUNDelse] = ACTIONS(9505),
    [anon_sym_POUNDELSE] = ACTIONS(9505),
    [anon_sym_POUNDElse] = ACTIONS(9505),
    [anon_sym_POUNDendif] = ACTIONS(9505),
    [anon_sym_POUNDENDIF] = ACTIONS(9505),
    [anon_sym_POUNDEndif] = ACTIONS(9505),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9505),
    [sym_trigger_keyword] = ACTIONS(9505),
    [sym_var_keyword] = ACTIONS(9505),
    [sym_local_keyword] = ACTIONS(9505),
    [sym_internal_keyword] = ACTIONS(9505),
    [sym_protected_keyword] = ACTIONS(9505),
    [sym_event_keyword] = ACTIONS(9505),
    [sym_fields_keyword] = ACTIONS(9505),
    [sym_keys_keyword] = ACTIONS(9505),
    [sym_fieldgroups_keyword] = ACTIONS(9505),
    [sym_actions_keyword] = ACTIONS(9505),
    [sym_layout_keyword] = ACTIONS(9505),
    [sym_area_keyword] = ACTIONS(9505),
    [sym_group_keyword] = ACTIONS(9505),
    [sym_repeater_keyword] = ACTIONS(9505),
    [sym_cuegroup_keyword] = ACTIONS(9505),
    [sym_fixed_keyword] = ACTIONS(9505),
    [sym_grid_keyword] = ACTIONS(9505),
    [sym_part_keyword] = ACTIONS(9505),
    [sym_systempart_keyword] = ACTIONS(9505),
    [sym_usercontrol_keyword] = ACTIONS(9505),
    [sym_dataset_keyword] = ACTIONS(9505),
    [sym_elements_keyword] = ACTIONS(9505),
    [sym_dataitem_keyword] = ACTIONS(9505),
    [sym_column_keyword] = ACTIONS(9505),
    [sym_filter_keyword] = ACTIONS(9505),
    [sym_labels_keyword] = ACTIONS(9505),
    [sym_rendering_keyword] = ACTIONS(9505),
    [sym_requestpage_keyword] = ACTIONS(9505),
    [sym_schema_keyword] = ACTIONS(9505),
    [sym_views_keyword] = ACTIONS(9505),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9505),
    [sym_preproc_open] = ACTIONS(9505),
    [sym_preproc_close] = ACTIONS(9505),
  },
  [STATE(3516)] = {
    [anon_sym_SEMI] = ACTIONS(9509),
    [aux_sym_where_condition_token1] = ACTIONS(9511),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9509),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9509),
    [anon_sym_LBRACK] = ACTIONS(9509),
    [aux_sym_basic_type_token6] = ACTIONS(9511),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9509),
    [aux_sym_addafter_modification_token1] = ACTIONS(9509),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9509),
    [aux_sym_modify_modification_token1] = ACTIONS(9509),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9509),
    [aux_sym_movelast_modification_token1] = ACTIONS(9509),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9509),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9509),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9509),
    [anon_sym_POUNDif] = ACTIONS(9509),
    [anon_sym_POUNDIF] = ACTIONS(9509),
    [anon_sym_POUNDIf] = ACTIONS(9509),
    [anon_sym_POUNDelif] = ACTIONS(9509),
    [anon_sym_POUNDELIF] = ACTIONS(9509),
    [anon_sym_POUNDElif] = ACTIONS(9509),
    [anon_sym_POUNDelse] = ACTIONS(9509),
    [anon_sym_POUNDELSE] = ACTIONS(9509),
    [anon_sym_POUNDElse] = ACTIONS(9509),
    [anon_sym_POUNDendif] = ACTIONS(9509),
    [anon_sym_POUNDENDIF] = ACTIONS(9509),
    [anon_sym_POUNDEndif] = ACTIONS(9509),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9509),
    [sym_trigger_keyword] = ACTIONS(9509),
    [sym_var_keyword] = ACTIONS(9509),
    [sym_local_keyword] = ACTIONS(9509),
    [sym_internal_keyword] = ACTIONS(9509),
    [sym_protected_keyword] = ACTIONS(9509),
    [sym_event_keyword] = ACTIONS(9509),
    [sym_fields_keyword] = ACTIONS(9509),
    [sym_keys_keyword] = ACTIONS(9509),
    [sym_fieldgroups_keyword] = ACTIONS(9509),
    [sym_actions_keyword] = ACTIONS(9509),
    [sym_layout_keyword] = ACTIONS(9509),
    [sym_area_keyword] = ACTIONS(9509),
    [sym_group_keyword] = ACTIONS(9509),
    [sym_repeater_keyword] = ACTIONS(9509),
    [sym_cuegroup_keyword] = ACTIONS(9509),
    [sym_fixed_keyword] = ACTIONS(9509),
    [sym_grid_keyword] = ACTIONS(9509),
    [sym_part_keyword] = ACTIONS(9509),
    [sym_systempart_keyword] = ACTIONS(9509),
    [sym_usercontrol_keyword] = ACTIONS(9509),
    [sym_dataset_keyword] = ACTIONS(9509),
    [sym_elements_keyword] = ACTIONS(9509),
    [sym_dataitem_keyword] = ACTIONS(9509),
    [sym_column_keyword] = ACTIONS(9509),
    [sym_filter_keyword] = ACTIONS(9509),
    [sym_labels_keyword] = ACTIONS(9509),
    [sym_rendering_keyword] = ACTIONS(9509),
    [sym_requestpage_keyword] = ACTIONS(9509),
    [sym_schema_keyword] = ACTIONS(9509),
    [sym_views_keyword] = ACTIONS(9509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9509),
    [sym_preproc_open] = ACTIONS(9509),
    [sym_preproc_close] = ACTIONS(9509),
  },
  [STATE(3517)] = {
    [anon_sym_SEMI] = ACTIONS(9513),
    [aux_sym_where_condition_token1] = ACTIONS(9515),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9513),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9513),
    [anon_sym_LBRACK] = ACTIONS(9513),
    [aux_sym_basic_type_token6] = ACTIONS(9515),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9513),
    [aux_sym_addafter_modification_token1] = ACTIONS(9513),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9513),
    [aux_sym_modify_modification_token1] = ACTIONS(9513),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9513),
    [aux_sym_movelast_modification_token1] = ACTIONS(9513),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9513),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9513),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9513),
    [anon_sym_POUNDif] = ACTIONS(9513),
    [anon_sym_POUNDIF] = ACTIONS(9513),
    [anon_sym_POUNDIf] = ACTIONS(9513),
    [anon_sym_POUNDelif] = ACTIONS(9513),
    [anon_sym_POUNDELIF] = ACTIONS(9513),
    [anon_sym_POUNDElif] = ACTIONS(9513),
    [anon_sym_POUNDelse] = ACTIONS(9513),
    [anon_sym_POUNDELSE] = ACTIONS(9513),
    [anon_sym_POUNDElse] = ACTIONS(9513),
    [anon_sym_POUNDendif] = ACTIONS(9513),
    [anon_sym_POUNDENDIF] = ACTIONS(9513),
    [anon_sym_POUNDEndif] = ACTIONS(9513),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9513),
    [sym_trigger_keyword] = ACTIONS(9513),
    [sym_var_keyword] = ACTIONS(9513),
    [sym_local_keyword] = ACTIONS(9513),
    [sym_internal_keyword] = ACTIONS(9513),
    [sym_protected_keyword] = ACTIONS(9513),
    [sym_event_keyword] = ACTIONS(9513),
    [sym_fields_keyword] = ACTIONS(9513),
    [sym_keys_keyword] = ACTIONS(9513),
    [sym_fieldgroups_keyword] = ACTIONS(9513),
    [sym_actions_keyword] = ACTIONS(9513),
    [sym_layout_keyword] = ACTIONS(9513),
    [sym_area_keyword] = ACTIONS(9513),
    [sym_group_keyword] = ACTIONS(9513),
    [sym_repeater_keyword] = ACTIONS(9513),
    [sym_cuegroup_keyword] = ACTIONS(9513),
    [sym_fixed_keyword] = ACTIONS(9513),
    [sym_grid_keyword] = ACTIONS(9513),
    [sym_part_keyword] = ACTIONS(9513),
    [sym_systempart_keyword] = ACTIONS(9513),
    [sym_usercontrol_keyword] = ACTIONS(9513),
    [sym_dataset_keyword] = ACTIONS(9513),
    [sym_elements_keyword] = ACTIONS(9513),
    [sym_dataitem_keyword] = ACTIONS(9513),
    [sym_column_keyword] = ACTIONS(9513),
    [sym_filter_keyword] = ACTIONS(9513),
    [sym_labels_keyword] = ACTIONS(9513),
    [sym_rendering_keyword] = ACTIONS(9513),
    [sym_requestpage_keyword] = ACTIONS(9513),
    [sym_schema_keyword] = ACTIONS(9513),
    [sym_views_keyword] = ACTIONS(9513),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9513),
    [sym_preproc_open] = ACTIONS(9513),
    [sym_preproc_close] = ACTIONS(9513),
  },
  [STATE(3518)] = {
    [anon_sym_SEMI] = ACTIONS(9517),
    [aux_sym_where_condition_token1] = ACTIONS(9519),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9517),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9517),
    [anon_sym_LBRACK] = ACTIONS(9517),
    [aux_sym_basic_type_token6] = ACTIONS(9519),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9517),
    [aux_sym_addafter_modification_token1] = ACTIONS(9517),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9517),
    [aux_sym_modify_modification_token1] = ACTIONS(9517),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9517),
    [aux_sym_movelast_modification_token1] = ACTIONS(9517),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9517),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9517),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9517),
    [anon_sym_POUNDif] = ACTIONS(9517),
    [anon_sym_POUNDIF] = ACTIONS(9517),
    [anon_sym_POUNDIf] = ACTIONS(9517),
    [anon_sym_POUNDelif] = ACTIONS(9517),
    [anon_sym_POUNDELIF] = ACTIONS(9517),
    [anon_sym_POUNDElif] = ACTIONS(9517),
    [anon_sym_POUNDelse] = ACTIONS(9517),
    [anon_sym_POUNDELSE] = ACTIONS(9517),
    [anon_sym_POUNDElse] = ACTIONS(9517),
    [anon_sym_POUNDendif] = ACTIONS(9517),
    [anon_sym_POUNDENDIF] = ACTIONS(9517),
    [anon_sym_POUNDEndif] = ACTIONS(9517),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9517),
    [sym_trigger_keyword] = ACTIONS(9517),
    [sym_var_keyword] = ACTIONS(9517),
    [sym_local_keyword] = ACTIONS(9517),
    [sym_internal_keyword] = ACTIONS(9517),
    [sym_protected_keyword] = ACTIONS(9517),
    [sym_event_keyword] = ACTIONS(9517),
    [sym_fields_keyword] = ACTIONS(9517),
    [sym_keys_keyword] = ACTIONS(9517),
    [sym_fieldgroups_keyword] = ACTIONS(9517),
    [sym_actions_keyword] = ACTIONS(9517),
    [sym_layout_keyword] = ACTIONS(9517),
    [sym_area_keyword] = ACTIONS(9517),
    [sym_group_keyword] = ACTIONS(9517),
    [sym_repeater_keyword] = ACTIONS(9517),
    [sym_cuegroup_keyword] = ACTIONS(9517),
    [sym_fixed_keyword] = ACTIONS(9517),
    [sym_grid_keyword] = ACTIONS(9517),
    [sym_part_keyword] = ACTIONS(9517),
    [sym_systempart_keyword] = ACTIONS(9517),
    [sym_usercontrol_keyword] = ACTIONS(9517),
    [sym_dataset_keyword] = ACTIONS(9517),
    [sym_elements_keyword] = ACTIONS(9517),
    [sym_dataitem_keyword] = ACTIONS(9517),
    [sym_column_keyword] = ACTIONS(9517),
    [sym_filter_keyword] = ACTIONS(9517),
    [sym_labels_keyword] = ACTIONS(9517),
    [sym_rendering_keyword] = ACTIONS(9517),
    [sym_requestpage_keyword] = ACTIONS(9517),
    [sym_schema_keyword] = ACTIONS(9517),
    [sym_views_keyword] = ACTIONS(9517),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9517),
    [sym_preproc_open] = ACTIONS(9517),
    [sym_preproc_close] = ACTIONS(9517),
  },
  [STATE(3519)] = {
    [anon_sym_SEMI] = ACTIONS(8265),
    [aux_sym_where_condition_token1] = ACTIONS(8263),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8265),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8265),
    [anon_sym_LBRACK] = ACTIONS(8265),
    [aux_sym_basic_type_token6] = ACTIONS(8263),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8265),
    [aux_sym_addafter_modification_token1] = ACTIONS(8265),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8265),
    [aux_sym_modify_modification_token1] = ACTIONS(8265),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8265),
    [aux_sym_movelast_modification_token1] = ACTIONS(8265),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8265),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8265),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8265),
    [anon_sym_POUNDif] = ACTIONS(8265),
    [anon_sym_POUNDIF] = ACTIONS(8265),
    [anon_sym_POUNDIf] = ACTIONS(8265),
    [anon_sym_POUNDelif] = ACTIONS(8265),
    [anon_sym_POUNDELIF] = ACTIONS(8265),
    [anon_sym_POUNDElif] = ACTIONS(8265),
    [anon_sym_POUNDelse] = ACTIONS(8265),
    [anon_sym_POUNDELSE] = ACTIONS(8265),
    [anon_sym_POUNDElse] = ACTIONS(8265),
    [anon_sym_POUNDendif] = ACTIONS(8265),
    [anon_sym_POUNDENDIF] = ACTIONS(8265),
    [anon_sym_POUNDEndif] = ACTIONS(8265),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8265),
    [sym_trigger_keyword] = ACTIONS(8265),
    [sym_var_keyword] = ACTIONS(8265),
    [sym_local_keyword] = ACTIONS(8265),
    [sym_internal_keyword] = ACTIONS(8265),
    [sym_protected_keyword] = ACTIONS(8265),
    [sym_event_keyword] = ACTIONS(8265),
    [sym_fields_keyword] = ACTIONS(8265),
    [sym_keys_keyword] = ACTIONS(8265),
    [sym_fieldgroups_keyword] = ACTIONS(8265),
    [sym_actions_keyword] = ACTIONS(8265),
    [sym_layout_keyword] = ACTIONS(8265),
    [sym_area_keyword] = ACTIONS(8265),
    [sym_group_keyword] = ACTIONS(8265),
    [sym_repeater_keyword] = ACTIONS(8265),
    [sym_cuegroup_keyword] = ACTIONS(8265),
    [sym_fixed_keyword] = ACTIONS(8265),
    [sym_grid_keyword] = ACTIONS(8265),
    [sym_part_keyword] = ACTIONS(8265),
    [sym_systempart_keyword] = ACTIONS(8265),
    [sym_usercontrol_keyword] = ACTIONS(8265),
    [sym_dataset_keyword] = ACTIONS(8265),
    [sym_elements_keyword] = ACTIONS(8265),
    [sym_dataitem_keyword] = ACTIONS(8265),
    [sym_column_keyword] = ACTIONS(8265),
    [sym_filter_keyword] = ACTIONS(8265),
    [sym_labels_keyword] = ACTIONS(8265),
    [sym_rendering_keyword] = ACTIONS(8265),
    [sym_requestpage_keyword] = ACTIONS(8265),
    [sym_schema_keyword] = ACTIONS(8265),
    [sym_views_keyword] = ACTIONS(8265),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8265),
    [sym_preproc_open] = ACTIONS(8265),
    [sym_preproc_close] = ACTIONS(8265),
  },
  [STATE(3520)] = {
    [anon_sym_SEMI] = ACTIONS(9521),
    [aux_sym_where_condition_token1] = ACTIONS(9523),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9521),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9521),
    [anon_sym_LBRACK] = ACTIONS(9521),
    [aux_sym_basic_type_token6] = ACTIONS(9523),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9521),
    [aux_sym_addafter_modification_token1] = ACTIONS(9521),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9521),
    [aux_sym_modify_modification_token1] = ACTIONS(9521),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9521),
    [aux_sym_movelast_modification_token1] = ACTIONS(9521),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9521),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9521),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9521),
    [anon_sym_POUNDif] = ACTIONS(9521),
    [anon_sym_POUNDIF] = ACTIONS(9521),
    [anon_sym_POUNDIf] = ACTIONS(9521),
    [anon_sym_POUNDelif] = ACTIONS(9521),
    [anon_sym_POUNDELIF] = ACTIONS(9521),
    [anon_sym_POUNDElif] = ACTIONS(9521),
    [anon_sym_POUNDelse] = ACTIONS(9521),
    [anon_sym_POUNDELSE] = ACTIONS(9521),
    [anon_sym_POUNDElse] = ACTIONS(9521),
    [anon_sym_POUNDendif] = ACTIONS(9521),
    [anon_sym_POUNDENDIF] = ACTIONS(9521),
    [anon_sym_POUNDEndif] = ACTIONS(9521),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9521),
    [sym_trigger_keyword] = ACTIONS(9521),
    [sym_var_keyword] = ACTIONS(9521),
    [sym_local_keyword] = ACTIONS(9521),
    [sym_internal_keyword] = ACTIONS(9521),
    [sym_protected_keyword] = ACTIONS(9521),
    [sym_event_keyword] = ACTIONS(9521),
    [sym_fields_keyword] = ACTIONS(9521),
    [sym_keys_keyword] = ACTIONS(9521),
    [sym_fieldgroups_keyword] = ACTIONS(9521),
    [sym_actions_keyword] = ACTIONS(9521),
    [sym_layout_keyword] = ACTIONS(9521),
    [sym_area_keyword] = ACTIONS(9521),
    [sym_group_keyword] = ACTIONS(9521),
    [sym_repeater_keyword] = ACTIONS(9521),
    [sym_cuegroup_keyword] = ACTIONS(9521),
    [sym_fixed_keyword] = ACTIONS(9521),
    [sym_grid_keyword] = ACTIONS(9521),
    [sym_part_keyword] = ACTIONS(9521),
    [sym_systempart_keyword] = ACTIONS(9521),
    [sym_usercontrol_keyword] = ACTIONS(9521),
    [sym_dataset_keyword] = ACTIONS(9521),
    [sym_elements_keyword] = ACTIONS(9521),
    [sym_dataitem_keyword] = ACTIONS(9521),
    [sym_column_keyword] = ACTIONS(9521),
    [sym_filter_keyword] = ACTIONS(9521),
    [sym_labels_keyword] = ACTIONS(9521),
    [sym_rendering_keyword] = ACTIONS(9521),
    [sym_requestpage_keyword] = ACTIONS(9521),
    [sym_schema_keyword] = ACTIONS(9521),
    [sym_views_keyword] = ACTIONS(9521),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9521),
    [sym_preproc_open] = ACTIONS(9521),
    [sym_preproc_close] = ACTIONS(9521),
  },
  [STATE(3521)] = {
    [anon_sym_SEMI] = ACTIONS(9525),
    [aux_sym_where_condition_token1] = ACTIONS(9527),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9525),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9525),
    [anon_sym_LBRACK] = ACTIONS(9525),
    [aux_sym_basic_type_token6] = ACTIONS(9527),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9525),
    [aux_sym_addafter_modification_token1] = ACTIONS(9525),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9525),
    [aux_sym_modify_modification_token1] = ACTIONS(9525),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9525),
    [aux_sym_movelast_modification_token1] = ACTIONS(9525),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9525),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9525),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9525),
    [anon_sym_POUNDif] = ACTIONS(9525),
    [anon_sym_POUNDIF] = ACTIONS(9525),
    [anon_sym_POUNDIf] = ACTIONS(9525),
    [anon_sym_POUNDelif] = ACTIONS(9525),
    [anon_sym_POUNDELIF] = ACTIONS(9525),
    [anon_sym_POUNDElif] = ACTIONS(9525),
    [anon_sym_POUNDelse] = ACTIONS(9525),
    [anon_sym_POUNDELSE] = ACTIONS(9525),
    [anon_sym_POUNDElse] = ACTIONS(9525),
    [anon_sym_POUNDendif] = ACTIONS(9525),
    [anon_sym_POUNDENDIF] = ACTIONS(9525),
    [anon_sym_POUNDEndif] = ACTIONS(9525),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9525),
    [sym_trigger_keyword] = ACTIONS(9525),
    [sym_var_keyword] = ACTIONS(9525),
    [sym_local_keyword] = ACTIONS(9525),
    [sym_internal_keyword] = ACTIONS(9525),
    [sym_protected_keyword] = ACTIONS(9525),
    [sym_event_keyword] = ACTIONS(9525),
    [sym_fields_keyword] = ACTIONS(9525),
    [sym_keys_keyword] = ACTIONS(9525),
    [sym_fieldgroups_keyword] = ACTIONS(9525),
    [sym_actions_keyword] = ACTIONS(9525),
    [sym_layout_keyword] = ACTIONS(9525),
    [sym_area_keyword] = ACTIONS(9525),
    [sym_group_keyword] = ACTIONS(9525),
    [sym_repeater_keyword] = ACTIONS(9525),
    [sym_cuegroup_keyword] = ACTIONS(9525),
    [sym_fixed_keyword] = ACTIONS(9525),
    [sym_grid_keyword] = ACTIONS(9525),
    [sym_part_keyword] = ACTIONS(9525),
    [sym_systempart_keyword] = ACTIONS(9525),
    [sym_usercontrol_keyword] = ACTIONS(9525),
    [sym_dataset_keyword] = ACTIONS(9525),
    [sym_elements_keyword] = ACTIONS(9525),
    [sym_dataitem_keyword] = ACTIONS(9525),
    [sym_column_keyword] = ACTIONS(9525),
    [sym_filter_keyword] = ACTIONS(9525),
    [sym_labels_keyword] = ACTIONS(9525),
    [sym_rendering_keyword] = ACTIONS(9525),
    [sym_requestpage_keyword] = ACTIONS(9525),
    [sym_schema_keyword] = ACTIONS(9525),
    [sym_views_keyword] = ACTIONS(9525),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9525),
    [sym_preproc_open] = ACTIONS(9525),
    [sym_preproc_close] = ACTIONS(9525),
  },
  [STATE(3522)] = {
    [anon_sym_SEMI] = ACTIONS(9529),
    [aux_sym_where_condition_token1] = ACTIONS(9531),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9529),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9529),
    [anon_sym_LBRACK] = ACTIONS(9529),
    [aux_sym_basic_type_token6] = ACTIONS(9531),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9529),
    [aux_sym_addafter_modification_token1] = ACTIONS(9529),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9529),
    [aux_sym_modify_modification_token1] = ACTIONS(9529),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9529),
    [aux_sym_movelast_modification_token1] = ACTIONS(9529),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9529),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9529),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9529),
    [anon_sym_POUNDif] = ACTIONS(9529),
    [anon_sym_POUNDIF] = ACTIONS(9529),
    [anon_sym_POUNDIf] = ACTIONS(9529),
    [anon_sym_POUNDelif] = ACTIONS(9529),
    [anon_sym_POUNDELIF] = ACTIONS(9529),
    [anon_sym_POUNDElif] = ACTIONS(9529),
    [anon_sym_POUNDelse] = ACTIONS(9529),
    [anon_sym_POUNDELSE] = ACTIONS(9529),
    [anon_sym_POUNDElse] = ACTIONS(9529),
    [anon_sym_POUNDendif] = ACTIONS(9529),
    [anon_sym_POUNDENDIF] = ACTIONS(9529),
    [anon_sym_POUNDEndif] = ACTIONS(9529),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9529),
    [sym_trigger_keyword] = ACTIONS(9529),
    [sym_var_keyword] = ACTIONS(9529),
    [sym_local_keyword] = ACTIONS(9529),
    [sym_internal_keyword] = ACTIONS(9529),
    [sym_protected_keyword] = ACTIONS(9529),
    [sym_event_keyword] = ACTIONS(9529),
    [sym_fields_keyword] = ACTIONS(9529),
    [sym_keys_keyword] = ACTIONS(9529),
    [sym_fieldgroups_keyword] = ACTIONS(9529),
    [sym_actions_keyword] = ACTIONS(9529),
    [sym_layout_keyword] = ACTIONS(9529),
    [sym_area_keyword] = ACTIONS(9529),
    [sym_group_keyword] = ACTIONS(9529),
    [sym_repeater_keyword] = ACTIONS(9529),
    [sym_cuegroup_keyword] = ACTIONS(9529),
    [sym_fixed_keyword] = ACTIONS(9529),
    [sym_grid_keyword] = ACTIONS(9529),
    [sym_part_keyword] = ACTIONS(9529),
    [sym_systempart_keyword] = ACTIONS(9529),
    [sym_usercontrol_keyword] = ACTIONS(9529),
    [sym_dataset_keyword] = ACTIONS(9529),
    [sym_elements_keyword] = ACTIONS(9529),
    [sym_dataitem_keyword] = ACTIONS(9529),
    [sym_column_keyword] = ACTIONS(9529),
    [sym_filter_keyword] = ACTIONS(9529),
    [sym_labels_keyword] = ACTIONS(9529),
    [sym_rendering_keyword] = ACTIONS(9529),
    [sym_requestpage_keyword] = ACTIONS(9529),
    [sym_schema_keyword] = ACTIONS(9529),
    [sym_views_keyword] = ACTIONS(9529),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9529),
    [sym_preproc_open] = ACTIONS(9529),
    [sym_preproc_close] = ACTIONS(9529),
  },
  [STATE(3523)] = {
    [anon_sym_SEMI] = ACTIONS(9529),
    [aux_sym_where_condition_token1] = ACTIONS(9531),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9529),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9529),
    [anon_sym_LBRACK] = ACTIONS(9529),
    [aux_sym_basic_type_token6] = ACTIONS(9531),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9529),
    [aux_sym_addafter_modification_token1] = ACTIONS(9529),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9529),
    [aux_sym_modify_modification_token1] = ACTIONS(9529),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9529),
    [aux_sym_movelast_modification_token1] = ACTIONS(9529),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9529),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9529),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9529),
    [anon_sym_POUNDif] = ACTIONS(9529),
    [anon_sym_POUNDIF] = ACTIONS(9529),
    [anon_sym_POUNDIf] = ACTIONS(9529),
    [anon_sym_POUNDelif] = ACTIONS(9529),
    [anon_sym_POUNDELIF] = ACTIONS(9529),
    [anon_sym_POUNDElif] = ACTIONS(9529),
    [anon_sym_POUNDelse] = ACTIONS(9529),
    [anon_sym_POUNDELSE] = ACTIONS(9529),
    [anon_sym_POUNDElse] = ACTIONS(9529),
    [anon_sym_POUNDendif] = ACTIONS(9529),
    [anon_sym_POUNDENDIF] = ACTIONS(9529),
    [anon_sym_POUNDEndif] = ACTIONS(9529),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9529),
    [sym_trigger_keyword] = ACTIONS(9529),
    [sym_var_keyword] = ACTIONS(9529),
    [sym_local_keyword] = ACTIONS(9529),
    [sym_internal_keyword] = ACTIONS(9529),
    [sym_protected_keyword] = ACTIONS(9529),
    [sym_event_keyword] = ACTIONS(9529),
    [sym_fields_keyword] = ACTIONS(9529),
    [sym_keys_keyword] = ACTIONS(9529),
    [sym_fieldgroups_keyword] = ACTIONS(9529),
    [sym_actions_keyword] = ACTIONS(9529),
    [sym_layout_keyword] = ACTIONS(9529),
    [sym_area_keyword] = ACTIONS(9529),
    [sym_group_keyword] = ACTIONS(9529),
    [sym_repeater_keyword] = ACTIONS(9529),
    [sym_cuegroup_keyword] = ACTIONS(9529),
    [sym_fixed_keyword] = ACTIONS(9529),
    [sym_grid_keyword] = ACTIONS(9529),
    [sym_part_keyword] = ACTIONS(9529),
    [sym_systempart_keyword] = ACTIONS(9529),
    [sym_usercontrol_keyword] = ACTIONS(9529),
    [sym_dataset_keyword] = ACTIONS(9529),
    [sym_elements_keyword] = ACTIONS(9529),
    [sym_dataitem_keyword] = ACTIONS(9529),
    [sym_column_keyword] = ACTIONS(9529),
    [sym_filter_keyword] = ACTIONS(9529),
    [sym_labels_keyword] = ACTIONS(9529),
    [sym_rendering_keyword] = ACTIONS(9529),
    [sym_requestpage_keyword] = ACTIONS(9529),
    [sym_schema_keyword] = ACTIONS(9529),
    [sym_views_keyword] = ACTIONS(9529),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9529),
    [sym_preproc_open] = ACTIONS(9529),
    [sym_preproc_close] = ACTIONS(9529),
  },
  [STATE(3524)] = {
    [anon_sym_SEMI] = ACTIONS(9529),
    [aux_sym_where_condition_token1] = ACTIONS(9531),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9529),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9529),
    [anon_sym_LBRACK] = ACTIONS(9529),
    [aux_sym_basic_type_token6] = ACTIONS(9531),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9529),
    [aux_sym_addafter_modification_token1] = ACTIONS(9529),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9529),
    [aux_sym_modify_modification_token1] = ACTIONS(9529),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9529),
    [aux_sym_movelast_modification_token1] = ACTIONS(9529),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9529),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9529),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9529),
    [anon_sym_POUNDif] = ACTIONS(9529),
    [anon_sym_POUNDIF] = ACTIONS(9529),
    [anon_sym_POUNDIf] = ACTIONS(9529),
    [anon_sym_POUNDelif] = ACTIONS(9529),
    [anon_sym_POUNDELIF] = ACTIONS(9529),
    [anon_sym_POUNDElif] = ACTIONS(9529),
    [anon_sym_POUNDelse] = ACTIONS(9529),
    [anon_sym_POUNDELSE] = ACTIONS(9529),
    [anon_sym_POUNDElse] = ACTIONS(9529),
    [anon_sym_POUNDendif] = ACTIONS(9529),
    [anon_sym_POUNDENDIF] = ACTIONS(9529),
    [anon_sym_POUNDEndif] = ACTIONS(9529),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9529),
    [sym_trigger_keyword] = ACTIONS(9529),
    [sym_var_keyword] = ACTIONS(9529),
    [sym_local_keyword] = ACTIONS(9529),
    [sym_internal_keyword] = ACTIONS(9529),
    [sym_protected_keyword] = ACTIONS(9529),
    [sym_event_keyword] = ACTIONS(9529),
    [sym_fields_keyword] = ACTIONS(9529),
    [sym_keys_keyword] = ACTIONS(9529),
    [sym_fieldgroups_keyword] = ACTIONS(9529),
    [sym_actions_keyword] = ACTIONS(9529),
    [sym_layout_keyword] = ACTIONS(9529),
    [sym_area_keyword] = ACTIONS(9529),
    [sym_group_keyword] = ACTIONS(9529),
    [sym_repeater_keyword] = ACTIONS(9529),
    [sym_cuegroup_keyword] = ACTIONS(9529),
    [sym_fixed_keyword] = ACTIONS(9529),
    [sym_grid_keyword] = ACTIONS(9529),
    [sym_part_keyword] = ACTIONS(9529),
    [sym_systempart_keyword] = ACTIONS(9529),
    [sym_usercontrol_keyword] = ACTIONS(9529),
    [sym_dataset_keyword] = ACTIONS(9529),
    [sym_elements_keyword] = ACTIONS(9529),
    [sym_dataitem_keyword] = ACTIONS(9529),
    [sym_column_keyword] = ACTIONS(9529),
    [sym_filter_keyword] = ACTIONS(9529),
    [sym_labels_keyword] = ACTIONS(9529),
    [sym_rendering_keyword] = ACTIONS(9529),
    [sym_requestpage_keyword] = ACTIONS(9529),
    [sym_schema_keyword] = ACTIONS(9529),
    [sym_views_keyword] = ACTIONS(9529),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9529),
    [sym_preproc_open] = ACTIONS(9529),
    [sym_preproc_close] = ACTIONS(9529),
  },
  [STATE(3525)] = {
    [anon_sym_SEMI] = ACTIONS(9529),
    [aux_sym_where_condition_token1] = ACTIONS(9531),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9529),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9529),
    [anon_sym_LBRACK] = ACTIONS(9529),
    [aux_sym_basic_type_token6] = ACTIONS(9531),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9529),
    [aux_sym_addafter_modification_token1] = ACTIONS(9529),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9529),
    [aux_sym_modify_modification_token1] = ACTIONS(9529),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9529),
    [aux_sym_movelast_modification_token1] = ACTIONS(9529),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9529),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9529),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9529),
    [anon_sym_POUNDif] = ACTIONS(9529),
    [anon_sym_POUNDIF] = ACTIONS(9529),
    [anon_sym_POUNDIf] = ACTIONS(9529),
    [anon_sym_POUNDelif] = ACTIONS(9529),
    [anon_sym_POUNDELIF] = ACTIONS(9529),
    [anon_sym_POUNDElif] = ACTIONS(9529),
    [anon_sym_POUNDelse] = ACTIONS(9529),
    [anon_sym_POUNDELSE] = ACTIONS(9529),
    [anon_sym_POUNDElse] = ACTIONS(9529),
    [anon_sym_POUNDendif] = ACTIONS(9529),
    [anon_sym_POUNDENDIF] = ACTIONS(9529),
    [anon_sym_POUNDEndif] = ACTIONS(9529),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9529),
    [sym_trigger_keyword] = ACTIONS(9529),
    [sym_var_keyword] = ACTIONS(9529),
    [sym_local_keyword] = ACTIONS(9529),
    [sym_internal_keyword] = ACTIONS(9529),
    [sym_protected_keyword] = ACTIONS(9529),
    [sym_event_keyword] = ACTIONS(9529),
    [sym_fields_keyword] = ACTIONS(9529),
    [sym_keys_keyword] = ACTIONS(9529),
    [sym_fieldgroups_keyword] = ACTIONS(9529),
    [sym_actions_keyword] = ACTIONS(9529),
    [sym_layout_keyword] = ACTIONS(9529),
    [sym_area_keyword] = ACTIONS(9529),
    [sym_group_keyword] = ACTIONS(9529),
    [sym_repeater_keyword] = ACTIONS(9529),
    [sym_cuegroup_keyword] = ACTIONS(9529),
    [sym_fixed_keyword] = ACTIONS(9529),
    [sym_grid_keyword] = ACTIONS(9529),
    [sym_part_keyword] = ACTIONS(9529),
    [sym_systempart_keyword] = ACTIONS(9529),
    [sym_usercontrol_keyword] = ACTIONS(9529),
    [sym_dataset_keyword] = ACTIONS(9529),
    [sym_elements_keyword] = ACTIONS(9529),
    [sym_dataitem_keyword] = ACTIONS(9529),
    [sym_column_keyword] = ACTIONS(9529),
    [sym_filter_keyword] = ACTIONS(9529),
    [sym_labels_keyword] = ACTIONS(9529),
    [sym_rendering_keyword] = ACTIONS(9529),
    [sym_requestpage_keyword] = ACTIONS(9529),
    [sym_schema_keyword] = ACTIONS(9529),
    [sym_views_keyword] = ACTIONS(9529),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9529),
    [sym_preproc_open] = ACTIONS(9529),
    [sym_preproc_close] = ACTIONS(9529),
  },
  [STATE(3526)] = {
    [anon_sym_SEMI] = ACTIONS(9533),
    [aux_sym_where_condition_token1] = ACTIONS(9535),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9533),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9533),
    [anon_sym_LBRACK] = ACTIONS(9533),
    [aux_sym_basic_type_token6] = ACTIONS(9535),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9533),
    [aux_sym_addafter_modification_token1] = ACTIONS(9533),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9533),
    [aux_sym_modify_modification_token1] = ACTIONS(9533),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9533),
    [aux_sym_movelast_modification_token1] = ACTIONS(9533),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9533),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9533),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9533),
    [anon_sym_POUNDif] = ACTIONS(9533),
    [anon_sym_POUNDIF] = ACTIONS(9533),
    [anon_sym_POUNDIf] = ACTIONS(9533),
    [anon_sym_POUNDelif] = ACTIONS(9533),
    [anon_sym_POUNDELIF] = ACTIONS(9533),
    [anon_sym_POUNDElif] = ACTIONS(9533),
    [anon_sym_POUNDelse] = ACTIONS(9533),
    [anon_sym_POUNDELSE] = ACTIONS(9533),
    [anon_sym_POUNDElse] = ACTIONS(9533),
    [anon_sym_POUNDendif] = ACTIONS(9533),
    [anon_sym_POUNDENDIF] = ACTIONS(9533),
    [anon_sym_POUNDEndif] = ACTIONS(9533),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9533),
    [sym_trigger_keyword] = ACTIONS(9533),
    [sym_var_keyword] = ACTIONS(9533),
    [sym_local_keyword] = ACTIONS(9533),
    [sym_internal_keyword] = ACTIONS(9533),
    [sym_protected_keyword] = ACTIONS(9533),
    [sym_event_keyword] = ACTIONS(9533),
    [sym_fields_keyword] = ACTIONS(9533),
    [sym_keys_keyword] = ACTIONS(9533),
    [sym_fieldgroups_keyword] = ACTIONS(9533),
    [sym_actions_keyword] = ACTIONS(9533),
    [sym_layout_keyword] = ACTIONS(9533),
    [sym_area_keyword] = ACTIONS(9533),
    [sym_group_keyword] = ACTIONS(9533),
    [sym_repeater_keyword] = ACTIONS(9533),
    [sym_cuegroup_keyword] = ACTIONS(9533),
    [sym_fixed_keyword] = ACTIONS(9533),
    [sym_grid_keyword] = ACTIONS(9533),
    [sym_part_keyword] = ACTIONS(9533),
    [sym_systempart_keyword] = ACTIONS(9533),
    [sym_usercontrol_keyword] = ACTIONS(9533),
    [sym_dataset_keyword] = ACTIONS(9533),
    [sym_elements_keyword] = ACTIONS(9533),
    [sym_dataitem_keyword] = ACTIONS(9533),
    [sym_column_keyword] = ACTIONS(9533),
    [sym_filter_keyword] = ACTIONS(9533),
    [sym_labels_keyword] = ACTIONS(9533),
    [sym_rendering_keyword] = ACTIONS(9533),
    [sym_requestpage_keyword] = ACTIONS(9533),
    [sym_schema_keyword] = ACTIONS(9533),
    [sym_views_keyword] = ACTIONS(9533),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9533),
    [sym_preproc_open] = ACTIONS(9533),
    [sym_preproc_close] = ACTIONS(9533),
  },
  [STATE(3527)] = {
    [anon_sym_SEMI] = ACTIONS(9533),
    [aux_sym_where_condition_token1] = ACTIONS(9535),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9533),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9533),
    [anon_sym_LBRACK] = ACTIONS(9533),
    [aux_sym_basic_type_token6] = ACTIONS(9535),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9533),
    [aux_sym_addafter_modification_token1] = ACTIONS(9533),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9533),
    [aux_sym_modify_modification_token1] = ACTIONS(9533),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9533),
    [aux_sym_movelast_modification_token1] = ACTIONS(9533),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9533),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9533),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9533),
    [anon_sym_POUNDif] = ACTIONS(9533),
    [anon_sym_POUNDIF] = ACTIONS(9533),
    [anon_sym_POUNDIf] = ACTIONS(9533),
    [anon_sym_POUNDelif] = ACTIONS(9533),
    [anon_sym_POUNDELIF] = ACTIONS(9533),
    [anon_sym_POUNDElif] = ACTIONS(9533),
    [anon_sym_POUNDelse] = ACTIONS(9533),
    [anon_sym_POUNDELSE] = ACTIONS(9533),
    [anon_sym_POUNDElse] = ACTIONS(9533),
    [anon_sym_POUNDendif] = ACTIONS(9533),
    [anon_sym_POUNDENDIF] = ACTIONS(9533),
    [anon_sym_POUNDEndif] = ACTIONS(9533),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9533),
    [sym_trigger_keyword] = ACTIONS(9533),
    [sym_var_keyword] = ACTIONS(9533),
    [sym_local_keyword] = ACTIONS(9533),
    [sym_internal_keyword] = ACTIONS(9533),
    [sym_protected_keyword] = ACTIONS(9533),
    [sym_event_keyword] = ACTIONS(9533),
    [sym_fields_keyword] = ACTIONS(9533),
    [sym_keys_keyword] = ACTIONS(9533),
    [sym_fieldgroups_keyword] = ACTIONS(9533),
    [sym_actions_keyword] = ACTIONS(9533),
    [sym_layout_keyword] = ACTIONS(9533),
    [sym_area_keyword] = ACTIONS(9533),
    [sym_group_keyword] = ACTIONS(9533),
    [sym_repeater_keyword] = ACTIONS(9533),
    [sym_cuegroup_keyword] = ACTIONS(9533),
    [sym_fixed_keyword] = ACTIONS(9533),
    [sym_grid_keyword] = ACTIONS(9533),
    [sym_part_keyword] = ACTIONS(9533),
    [sym_systempart_keyword] = ACTIONS(9533),
    [sym_usercontrol_keyword] = ACTIONS(9533),
    [sym_dataset_keyword] = ACTIONS(9533),
    [sym_elements_keyword] = ACTIONS(9533),
    [sym_dataitem_keyword] = ACTIONS(9533),
    [sym_column_keyword] = ACTIONS(9533),
    [sym_filter_keyword] = ACTIONS(9533),
    [sym_labels_keyword] = ACTIONS(9533),
    [sym_rendering_keyword] = ACTIONS(9533),
    [sym_requestpage_keyword] = ACTIONS(9533),
    [sym_schema_keyword] = ACTIONS(9533),
    [sym_views_keyword] = ACTIONS(9533),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9533),
    [sym_preproc_open] = ACTIONS(9533),
    [sym_preproc_close] = ACTIONS(9533),
  },
  [STATE(3528)] = {
    [anon_sym_SEMI] = ACTIONS(9533),
    [aux_sym_where_condition_token1] = ACTIONS(9535),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9533),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9533),
    [anon_sym_LBRACK] = ACTIONS(9533),
    [aux_sym_basic_type_token6] = ACTIONS(9535),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9533),
    [aux_sym_addafter_modification_token1] = ACTIONS(9533),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9533),
    [aux_sym_modify_modification_token1] = ACTIONS(9533),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9533),
    [aux_sym_movelast_modification_token1] = ACTIONS(9533),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9533),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9533),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9533),
    [anon_sym_POUNDif] = ACTIONS(9533),
    [anon_sym_POUNDIF] = ACTIONS(9533),
    [anon_sym_POUNDIf] = ACTIONS(9533),
    [anon_sym_POUNDelif] = ACTIONS(9533),
    [anon_sym_POUNDELIF] = ACTIONS(9533),
    [anon_sym_POUNDElif] = ACTIONS(9533),
    [anon_sym_POUNDelse] = ACTIONS(9533),
    [anon_sym_POUNDELSE] = ACTIONS(9533),
    [anon_sym_POUNDElse] = ACTIONS(9533),
    [anon_sym_POUNDendif] = ACTIONS(9533),
    [anon_sym_POUNDENDIF] = ACTIONS(9533),
    [anon_sym_POUNDEndif] = ACTIONS(9533),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9533),
    [sym_trigger_keyword] = ACTIONS(9533),
    [sym_var_keyword] = ACTIONS(9533),
    [sym_local_keyword] = ACTIONS(9533),
    [sym_internal_keyword] = ACTIONS(9533),
    [sym_protected_keyword] = ACTIONS(9533),
    [sym_event_keyword] = ACTIONS(9533),
    [sym_fields_keyword] = ACTIONS(9533),
    [sym_keys_keyword] = ACTIONS(9533),
    [sym_fieldgroups_keyword] = ACTIONS(9533),
    [sym_actions_keyword] = ACTIONS(9533),
    [sym_layout_keyword] = ACTIONS(9533),
    [sym_area_keyword] = ACTIONS(9533),
    [sym_group_keyword] = ACTIONS(9533),
    [sym_repeater_keyword] = ACTIONS(9533),
    [sym_cuegroup_keyword] = ACTIONS(9533),
    [sym_fixed_keyword] = ACTIONS(9533),
    [sym_grid_keyword] = ACTIONS(9533),
    [sym_part_keyword] = ACTIONS(9533),
    [sym_systempart_keyword] = ACTIONS(9533),
    [sym_usercontrol_keyword] = ACTIONS(9533),
    [sym_dataset_keyword] = ACTIONS(9533),
    [sym_elements_keyword] = ACTIONS(9533),
    [sym_dataitem_keyword] = ACTIONS(9533),
    [sym_column_keyword] = ACTIONS(9533),
    [sym_filter_keyword] = ACTIONS(9533),
    [sym_labels_keyword] = ACTIONS(9533),
    [sym_rendering_keyword] = ACTIONS(9533),
    [sym_requestpage_keyword] = ACTIONS(9533),
    [sym_schema_keyword] = ACTIONS(9533),
    [sym_views_keyword] = ACTIONS(9533),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9533),
    [sym_preproc_open] = ACTIONS(9533),
    [sym_preproc_close] = ACTIONS(9533),
  },
  [STATE(3529)] = {
    [anon_sym_SEMI] = ACTIONS(9537),
    [aux_sym_where_condition_token1] = ACTIONS(9539),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9537),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9537),
    [anon_sym_LBRACK] = ACTIONS(9537),
    [aux_sym_basic_type_token6] = ACTIONS(9539),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9537),
    [aux_sym_addafter_modification_token1] = ACTIONS(9537),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9537),
    [aux_sym_modify_modification_token1] = ACTIONS(9537),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9537),
    [aux_sym_movelast_modification_token1] = ACTIONS(9537),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9537),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9537),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9537),
    [anon_sym_POUNDif] = ACTIONS(9537),
    [anon_sym_POUNDIF] = ACTIONS(9537),
    [anon_sym_POUNDIf] = ACTIONS(9537),
    [anon_sym_POUNDelif] = ACTIONS(9537),
    [anon_sym_POUNDELIF] = ACTIONS(9537),
    [anon_sym_POUNDElif] = ACTIONS(9537),
    [anon_sym_POUNDelse] = ACTIONS(9537),
    [anon_sym_POUNDELSE] = ACTIONS(9537),
    [anon_sym_POUNDElse] = ACTIONS(9537),
    [anon_sym_POUNDendif] = ACTIONS(9537),
    [anon_sym_POUNDENDIF] = ACTIONS(9537),
    [anon_sym_POUNDEndif] = ACTIONS(9537),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9537),
    [sym_trigger_keyword] = ACTIONS(9537),
    [sym_var_keyword] = ACTIONS(9537),
    [sym_local_keyword] = ACTIONS(9537),
    [sym_internal_keyword] = ACTIONS(9537),
    [sym_protected_keyword] = ACTIONS(9537),
    [sym_event_keyword] = ACTIONS(9537),
    [sym_fields_keyword] = ACTIONS(9537),
    [sym_keys_keyword] = ACTIONS(9537),
    [sym_fieldgroups_keyword] = ACTIONS(9537),
    [sym_actions_keyword] = ACTIONS(9537),
    [sym_layout_keyword] = ACTIONS(9537),
    [sym_area_keyword] = ACTIONS(9537),
    [sym_group_keyword] = ACTIONS(9537),
    [sym_repeater_keyword] = ACTIONS(9537),
    [sym_cuegroup_keyword] = ACTIONS(9537),
    [sym_fixed_keyword] = ACTIONS(9537),
    [sym_grid_keyword] = ACTIONS(9537),
    [sym_part_keyword] = ACTIONS(9537),
    [sym_systempart_keyword] = ACTIONS(9537),
    [sym_usercontrol_keyword] = ACTIONS(9537),
    [sym_dataset_keyword] = ACTIONS(9537),
    [sym_elements_keyword] = ACTIONS(9537),
    [sym_dataitem_keyword] = ACTIONS(9537),
    [sym_column_keyword] = ACTIONS(9537),
    [sym_filter_keyword] = ACTIONS(9537),
    [sym_labels_keyword] = ACTIONS(9537),
    [sym_rendering_keyword] = ACTIONS(9537),
    [sym_requestpage_keyword] = ACTIONS(9537),
    [sym_schema_keyword] = ACTIONS(9537),
    [sym_views_keyword] = ACTIONS(9537),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9537),
    [sym_preproc_open] = ACTIONS(9537),
    [sym_preproc_close] = ACTIONS(9537),
  },
  [STATE(3530)] = {
    [anon_sym_SEMI] = ACTIONS(9533),
    [aux_sym_where_condition_token1] = ACTIONS(9535),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9533),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9533),
    [anon_sym_LBRACK] = ACTIONS(9533),
    [aux_sym_basic_type_token6] = ACTIONS(9535),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9533),
    [aux_sym_addafter_modification_token1] = ACTIONS(9533),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9533),
    [aux_sym_modify_modification_token1] = ACTIONS(9533),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9533),
    [aux_sym_movelast_modification_token1] = ACTIONS(9533),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9533),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9533),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9533),
    [anon_sym_POUNDif] = ACTIONS(9533),
    [anon_sym_POUNDIF] = ACTIONS(9533),
    [anon_sym_POUNDIf] = ACTIONS(9533),
    [anon_sym_POUNDelif] = ACTIONS(9533),
    [anon_sym_POUNDELIF] = ACTIONS(9533),
    [anon_sym_POUNDElif] = ACTIONS(9533),
    [anon_sym_POUNDelse] = ACTIONS(9533),
    [anon_sym_POUNDELSE] = ACTIONS(9533),
    [anon_sym_POUNDElse] = ACTIONS(9533),
    [anon_sym_POUNDendif] = ACTIONS(9533),
    [anon_sym_POUNDENDIF] = ACTIONS(9533),
    [anon_sym_POUNDEndif] = ACTIONS(9533),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9533),
    [sym_trigger_keyword] = ACTIONS(9533),
    [sym_var_keyword] = ACTIONS(9533),
    [sym_local_keyword] = ACTIONS(9533),
    [sym_internal_keyword] = ACTIONS(9533),
    [sym_protected_keyword] = ACTIONS(9533),
    [sym_event_keyword] = ACTIONS(9533),
    [sym_fields_keyword] = ACTIONS(9533),
    [sym_keys_keyword] = ACTIONS(9533),
    [sym_fieldgroups_keyword] = ACTIONS(9533),
    [sym_actions_keyword] = ACTIONS(9533),
    [sym_layout_keyword] = ACTIONS(9533),
    [sym_area_keyword] = ACTIONS(9533),
    [sym_group_keyword] = ACTIONS(9533),
    [sym_repeater_keyword] = ACTIONS(9533),
    [sym_cuegroup_keyword] = ACTIONS(9533),
    [sym_fixed_keyword] = ACTIONS(9533),
    [sym_grid_keyword] = ACTIONS(9533),
    [sym_part_keyword] = ACTIONS(9533),
    [sym_systempart_keyword] = ACTIONS(9533),
    [sym_usercontrol_keyword] = ACTIONS(9533),
    [sym_dataset_keyword] = ACTIONS(9533),
    [sym_elements_keyword] = ACTIONS(9533),
    [sym_dataitem_keyword] = ACTIONS(9533),
    [sym_column_keyword] = ACTIONS(9533),
    [sym_filter_keyword] = ACTIONS(9533),
    [sym_labels_keyword] = ACTIONS(9533),
    [sym_rendering_keyword] = ACTIONS(9533),
    [sym_requestpage_keyword] = ACTIONS(9533),
    [sym_schema_keyword] = ACTIONS(9533),
    [sym_views_keyword] = ACTIONS(9533),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9533),
    [sym_preproc_open] = ACTIONS(9533),
    [sym_preproc_close] = ACTIONS(9533),
  },
  [STATE(3531)] = {
    [anon_sym_SEMI] = ACTIONS(9541),
    [aux_sym_where_condition_token1] = ACTIONS(9543),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9541),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9541),
    [anon_sym_LBRACK] = ACTIONS(9541),
    [aux_sym_basic_type_token6] = ACTIONS(9543),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9541),
    [aux_sym_addafter_modification_token1] = ACTIONS(9541),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9541),
    [aux_sym_modify_modification_token1] = ACTIONS(9541),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9541),
    [aux_sym_movelast_modification_token1] = ACTIONS(9541),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9541),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9541),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9541),
    [anon_sym_POUNDif] = ACTIONS(9541),
    [anon_sym_POUNDIF] = ACTIONS(9541),
    [anon_sym_POUNDIf] = ACTIONS(9541),
    [anon_sym_POUNDelif] = ACTIONS(9541),
    [anon_sym_POUNDELIF] = ACTIONS(9541),
    [anon_sym_POUNDElif] = ACTIONS(9541),
    [anon_sym_POUNDelse] = ACTIONS(9541),
    [anon_sym_POUNDELSE] = ACTIONS(9541),
    [anon_sym_POUNDElse] = ACTIONS(9541),
    [anon_sym_POUNDendif] = ACTIONS(9541),
    [anon_sym_POUNDENDIF] = ACTIONS(9541),
    [anon_sym_POUNDEndif] = ACTIONS(9541),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9541),
    [sym_trigger_keyword] = ACTIONS(9541),
    [sym_var_keyword] = ACTIONS(9541),
    [sym_local_keyword] = ACTIONS(9541),
    [sym_internal_keyword] = ACTIONS(9541),
    [sym_protected_keyword] = ACTIONS(9541),
    [sym_event_keyword] = ACTIONS(9541),
    [sym_fields_keyword] = ACTIONS(9541),
    [sym_keys_keyword] = ACTIONS(9541),
    [sym_fieldgroups_keyword] = ACTIONS(9541),
    [sym_actions_keyword] = ACTIONS(9541),
    [sym_layout_keyword] = ACTIONS(9541),
    [sym_area_keyword] = ACTIONS(9541),
    [sym_group_keyword] = ACTIONS(9541),
    [sym_repeater_keyword] = ACTIONS(9541),
    [sym_cuegroup_keyword] = ACTIONS(9541),
    [sym_fixed_keyword] = ACTIONS(9541),
    [sym_grid_keyword] = ACTIONS(9541),
    [sym_part_keyword] = ACTIONS(9541),
    [sym_systempart_keyword] = ACTIONS(9541),
    [sym_usercontrol_keyword] = ACTIONS(9541),
    [sym_dataset_keyword] = ACTIONS(9541),
    [sym_elements_keyword] = ACTIONS(9541),
    [sym_dataitem_keyword] = ACTIONS(9541),
    [sym_column_keyword] = ACTIONS(9541),
    [sym_filter_keyword] = ACTIONS(9541),
    [sym_labels_keyword] = ACTIONS(9541),
    [sym_rendering_keyword] = ACTIONS(9541),
    [sym_requestpage_keyword] = ACTIONS(9541),
    [sym_schema_keyword] = ACTIONS(9541),
    [sym_views_keyword] = ACTIONS(9541),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9541),
    [sym_preproc_open] = ACTIONS(9541),
    [sym_preproc_close] = ACTIONS(9541),
  },
  [STATE(3532)] = {
    [anon_sym_SEMI] = ACTIONS(9545),
    [aux_sym_where_condition_token1] = ACTIONS(9547),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9545),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9545),
    [anon_sym_LBRACK] = ACTIONS(9545),
    [aux_sym_basic_type_token6] = ACTIONS(9547),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9545),
    [aux_sym_addafter_modification_token1] = ACTIONS(9545),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9545),
    [aux_sym_modify_modification_token1] = ACTIONS(9545),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9545),
    [aux_sym_movelast_modification_token1] = ACTIONS(9545),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9545),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9545),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9545),
    [anon_sym_POUNDif] = ACTIONS(9545),
    [anon_sym_POUNDIF] = ACTIONS(9545),
    [anon_sym_POUNDIf] = ACTIONS(9545),
    [anon_sym_POUNDelif] = ACTIONS(9545),
    [anon_sym_POUNDELIF] = ACTIONS(9545),
    [anon_sym_POUNDElif] = ACTIONS(9545),
    [anon_sym_POUNDelse] = ACTIONS(9545),
    [anon_sym_POUNDELSE] = ACTIONS(9545),
    [anon_sym_POUNDElse] = ACTIONS(9545),
    [anon_sym_POUNDendif] = ACTIONS(9545),
    [anon_sym_POUNDENDIF] = ACTIONS(9545),
    [anon_sym_POUNDEndif] = ACTIONS(9545),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9545),
    [sym_trigger_keyword] = ACTIONS(9545),
    [sym_var_keyword] = ACTIONS(9545),
    [sym_local_keyword] = ACTIONS(9545),
    [sym_internal_keyword] = ACTIONS(9545),
    [sym_protected_keyword] = ACTIONS(9545),
    [sym_event_keyword] = ACTIONS(9545),
    [sym_fields_keyword] = ACTIONS(9545),
    [sym_keys_keyword] = ACTIONS(9545),
    [sym_fieldgroups_keyword] = ACTIONS(9545),
    [sym_actions_keyword] = ACTIONS(9545),
    [sym_layout_keyword] = ACTIONS(9545),
    [sym_area_keyword] = ACTIONS(9545),
    [sym_group_keyword] = ACTIONS(9545),
    [sym_repeater_keyword] = ACTIONS(9545),
    [sym_cuegroup_keyword] = ACTIONS(9545),
    [sym_fixed_keyword] = ACTIONS(9545),
    [sym_grid_keyword] = ACTIONS(9545),
    [sym_part_keyword] = ACTIONS(9545),
    [sym_systempart_keyword] = ACTIONS(9545),
    [sym_usercontrol_keyword] = ACTIONS(9545),
    [sym_dataset_keyword] = ACTIONS(9545),
    [sym_elements_keyword] = ACTIONS(9545),
    [sym_dataitem_keyword] = ACTIONS(9545),
    [sym_column_keyword] = ACTIONS(9545),
    [sym_filter_keyword] = ACTIONS(9545),
    [sym_labels_keyword] = ACTIONS(9545),
    [sym_rendering_keyword] = ACTIONS(9545),
    [sym_requestpage_keyword] = ACTIONS(9545),
    [sym_schema_keyword] = ACTIONS(9545),
    [sym_views_keyword] = ACTIONS(9545),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9545),
    [sym_preproc_open] = ACTIONS(9545),
    [sym_preproc_close] = ACTIONS(9545),
  },
  [STATE(3533)] = {
    [anon_sym_SEMI] = ACTIONS(9549),
    [aux_sym_where_condition_token1] = ACTIONS(9551),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9549),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9549),
    [anon_sym_LBRACK] = ACTIONS(9549),
    [aux_sym_basic_type_token6] = ACTIONS(9551),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9549),
    [aux_sym_addafter_modification_token1] = ACTIONS(9549),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9549),
    [aux_sym_modify_modification_token1] = ACTIONS(9549),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9549),
    [aux_sym_movelast_modification_token1] = ACTIONS(9549),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9549),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9549),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9549),
    [anon_sym_POUNDif] = ACTIONS(9549),
    [anon_sym_POUNDIF] = ACTIONS(9549),
    [anon_sym_POUNDIf] = ACTIONS(9549),
    [anon_sym_POUNDelif] = ACTIONS(9549),
    [anon_sym_POUNDELIF] = ACTIONS(9549),
    [anon_sym_POUNDElif] = ACTIONS(9549),
    [anon_sym_POUNDelse] = ACTIONS(9549),
    [anon_sym_POUNDELSE] = ACTIONS(9549),
    [anon_sym_POUNDElse] = ACTIONS(9549),
    [anon_sym_POUNDendif] = ACTIONS(9549),
    [anon_sym_POUNDENDIF] = ACTIONS(9549),
    [anon_sym_POUNDEndif] = ACTIONS(9549),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9549),
    [sym_trigger_keyword] = ACTIONS(9549),
    [sym_var_keyword] = ACTIONS(9549),
    [sym_local_keyword] = ACTIONS(9549),
    [sym_internal_keyword] = ACTIONS(9549),
    [sym_protected_keyword] = ACTIONS(9549),
    [sym_event_keyword] = ACTIONS(9549),
    [sym_fields_keyword] = ACTIONS(9549),
    [sym_keys_keyword] = ACTIONS(9549),
    [sym_fieldgroups_keyword] = ACTIONS(9549),
    [sym_actions_keyword] = ACTIONS(9549),
    [sym_layout_keyword] = ACTIONS(9549),
    [sym_area_keyword] = ACTIONS(9549),
    [sym_group_keyword] = ACTIONS(9549),
    [sym_repeater_keyword] = ACTIONS(9549),
    [sym_cuegroup_keyword] = ACTIONS(9549),
    [sym_fixed_keyword] = ACTIONS(9549),
    [sym_grid_keyword] = ACTIONS(9549),
    [sym_part_keyword] = ACTIONS(9549),
    [sym_systempart_keyword] = ACTIONS(9549),
    [sym_usercontrol_keyword] = ACTIONS(9549),
    [sym_dataset_keyword] = ACTIONS(9549),
    [sym_elements_keyword] = ACTIONS(9549),
    [sym_dataitem_keyword] = ACTIONS(9549),
    [sym_column_keyword] = ACTIONS(9549),
    [sym_filter_keyword] = ACTIONS(9549),
    [sym_labels_keyword] = ACTIONS(9549),
    [sym_rendering_keyword] = ACTIONS(9549),
    [sym_requestpage_keyword] = ACTIONS(9549),
    [sym_schema_keyword] = ACTIONS(9549),
    [sym_views_keyword] = ACTIONS(9549),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9549),
    [sym_preproc_open] = ACTIONS(9549),
    [sym_preproc_close] = ACTIONS(9549),
  },
  [STATE(3534)] = {
    [anon_sym_SEMI] = ACTIONS(9553),
    [aux_sym_where_condition_token1] = ACTIONS(9555),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9553),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9553),
    [anon_sym_LBRACK] = ACTIONS(9553),
    [aux_sym_basic_type_token6] = ACTIONS(9555),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9553),
    [aux_sym_addafter_modification_token1] = ACTIONS(9553),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9553),
    [aux_sym_modify_modification_token1] = ACTIONS(9553),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9553),
    [aux_sym_movelast_modification_token1] = ACTIONS(9553),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9553),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9553),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9553),
    [anon_sym_POUNDif] = ACTIONS(9553),
    [anon_sym_POUNDIF] = ACTIONS(9553),
    [anon_sym_POUNDIf] = ACTIONS(9553),
    [anon_sym_POUNDelif] = ACTIONS(9553),
    [anon_sym_POUNDELIF] = ACTIONS(9553),
    [anon_sym_POUNDElif] = ACTIONS(9553),
    [anon_sym_POUNDelse] = ACTIONS(9553),
    [anon_sym_POUNDELSE] = ACTIONS(9553),
    [anon_sym_POUNDElse] = ACTIONS(9553),
    [anon_sym_POUNDendif] = ACTIONS(9553),
    [anon_sym_POUNDENDIF] = ACTIONS(9553),
    [anon_sym_POUNDEndif] = ACTIONS(9553),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9553),
    [sym_trigger_keyword] = ACTIONS(9553),
    [sym_var_keyword] = ACTIONS(9553),
    [sym_local_keyword] = ACTIONS(9553),
    [sym_internal_keyword] = ACTIONS(9553),
    [sym_protected_keyword] = ACTIONS(9553),
    [sym_event_keyword] = ACTIONS(9553),
    [sym_fields_keyword] = ACTIONS(9553),
    [sym_keys_keyword] = ACTIONS(9553),
    [sym_fieldgroups_keyword] = ACTIONS(9553),
    [sym_actions_keyword] = ACTIONS(9553),
    [sym_layout_keyword] = ACTIONS(9553),
    [sym_area_keyword] = ACTIONS(9553),
    [sym_group_keyword] = ACTIONS(9553),
    [sym_repeater_keyword] = ACTIONS(9553),
    [sym_cuegroup_keyword] = ACTIONS(9553),
    [sym_fixed_keyword] = ACTIONS(9553),
    [sym_grid_keyword] = ACTIONS(9553),
    [sym_part_keyword] = ACTIONS(9553),
    [sym_systempart_keyword] = ACTIONS(9553),
    [sym_usercontrol_keyword] = ACTIONS(9553),
    [sym_dataset_keyword] = ACTIONS(9553),
    [sym_elements_keyword] = ACTIONS(9553),
    [sym_dataitem_keyword] = ACTIONS(9553),
    [sym_column_keyword] = ACTIONS(9553),
    [sym_filter_keyword] = ACTIONS(9553),
    [sym_labels_keyword] = ACTIONS(9553),
    [sym_rendering_keyword] = ACTIONS(9553),
    [sym_requestpage_keyword] = ACTIONS(9553),
    [sym_schema_keyword] = ACTIONS(9553),
    [sym_views_keyword] = ACTIONS(9553),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9553),
    [sym_preproc_open] = ACTIONS(9553),
    [sym_preproc_close] = ACTIONS(9553),
  },
  [STATE(3535)] = {
    [anon_sym_SEMI] = ACTIONS(9553),
    [aux_sym_where_condition_token1] = ACTIONS(9555),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9553),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9553),
    [anon_sym_LBRACK] = ACTIONS(9553),
    [aux_sym_basic_type_token6] = ACTIONS(9555),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9553),
    [aux_sym_addafter_modification_token1] = ACTIONS(9553),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9553),
    [aux_sym_modify_modification_token1] = ACTIONS(9553),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9553),
    [aux_sym_movelast_modification_token1] = ACTIONS(9553),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9553),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9553),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9553),
    [anon_sym_POUNDif] = ACTIONS(9553),
    [anon_sym_POUNDIF] = ACTIONS(9553),
    [anon_sym_POUNDIf] = ACTIONS(9553),
    [anon_sym_POUNDelif] = ACTIONS(9553),
    [anon_sym_POUNDELIF] = ACTIONS(9553),
    [anon_sym_POUNDElif] = ACTIONS(9553),
    [anon_sym_POUNDelse] = ACTIONS(9553),
    [anon_sym_POUNDELSE] = ACTIONS(9553),
    [anon_sym_POUNDElse] = ACTIONS(9553),
    [anon_sym_POUNDendif] = ACTIONS(9553),
    [anon_sym_POUNDENDIF] = ACTIONS(9553),
    [anon_sym_POUNDEndif] = ACTIONS(9553),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9553),
    [sym_trigger_keyword] = ACTIONS(9553),
    [sym_var_keyword] = ACTIONS(9553),
    [sym_local_keyword] = ACTIONS(9553),
    [sym_internal_keyword] = ACTIONS(9553),
    [sym_protected_keyword] = ACTIONS(9553),
    [sym_event_keyword] = ACTIONS(9553),
    [sym_fields_keyword] = ACTIONS(9553),
    [sym_keys_keyword] = ACTIONS(9553),
    [sym_fieldgroups_keyword] = ACTIONS(9553),
    [sym_actions_keyword] = ACTIONS(9553),
    [sym_layout_keyword] = ACTIONS(9553),
    [sym_area_keyword] = ACTIONS(9553),
    [sym_group_keyword] = ACTIONS(9553),
    [sym_repeater_keyword] = ACTIONS(9553),
    [sym_cuegroup_keyword] = ACTIONS(9553),
    [sym_fixed_keyword] = ACTIONS(9553),
    [sym_grid_keyword] = ACTIONS(9553),
    [sym_part_keyword] = ACTIONS(9553),
    [sym_systempart_keyword] = ACTIONS(9553),
    [sym_usercontrol_keyword] = ACTIONS(9553),
    [sym_dataset_keyword] = ACTIONS(9553),
    [sym_elements_keyword] = ACTIONS(9553),
    [sym_dataitem_keyword] = ACTIONS(9553),
    [sym_column_keyword] = ACTIONS(9553),
    [sym_filter_keyword] = ACTIONS(9553),
    [sym_labels_keyword] = ACTIONS(9553),
    [sym_rendering_keyword] = ACTIONS(9553),
    [sym_requestpage_keyword] = ACTIONS(9553),
    [sym_schema_keyword] = ACTIONS(9553),
    [sym_views_keyword] = ACTIONS(9553),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9553),
    [sym_preproc_open] = ACTIONS(9553),
    [sym_preproc_close] = ACTIONS(9553),
  },
  [STATE(3536)] = {
    [anon_sym_SEMI] = ACTIONS(9553),
    [aux_sym_where_condition_token1] = ACTIONS(9555),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9553),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9553),
    [anon_sym_LBRACK] = ACTIONS(9553),
    [aux_sym_basic_type_token6] = ACTIONS(9555),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9553),
    [aux_sym_addafter_modification_token1] = ACTIONS(9553),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9553),
    [aux_sym_modify_modification_token1] = ACTIONS(9553),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9553),
    [aux_sym_movelast_modification_token1] = ACTIONS(9553),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9553),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9553),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9553),
    [anon_sym_POUNDif] = ACTIONS(9553),
    [anon_sym_POUNDIF] = ACTIONS(9553),
    [anon_sym_POUNDIf] = ACTIONS(9553),
    [anon_sym_POUNDelif] = ACTIONS(9553),
    [anon_sym_POUNDELIF] = ACTIONS(9553),
    [anon_sym_POUNDElif] = ACTIONS(9553),
    [anon_sym_POUNDelse] = ACTIONS(9553),
    [anon_sym_POUNDELSE] = ACTIONS(9553),
    [anon_sym_POUNDElse] = ACTIONS(9553),
    [anon_sym_POUNDendif] = ACTIONS(9553),
    [anon_sym_POUNDENDIF] = ACTIONS(9553),
    [anon_sym_POUNDEndif] = ACTIONS(9553),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9553),
    [sym_trigger_keyword] = ACTIONS(9553),
    [sym_var_keyword] = ACTIONS(9553),
    [sym_local_keyword] = ACTIONS(9553),
    [sym_internal_keyword] = ACTIONS(9553),
    [sym_protected_keyword] = ACTIONS(9553),
    [sym_event_keyword] = ACTIONS(9553),
    [sym_fields_keyword] = ACTIONS(9553),
    [sym_keys_keyword] = ACTIONS(9553),
    [sym_fieldgroups_keyword] = ACTIONS(9553),
    [sym_actions_keyword] = ACTIONS(9553),
    [sym_layout_keyword] = ACTIONS(9553),
    [sym_area_keyword] = ACTIONS(9553),
    [sym_group_keyword] = ACTIONS(9553),
    [sym_repeater_keyword] = ACTIONS(9553),
    [sym_cuegroup_keyword] = ACTIONS(9553),
    [sym_fixed_keyword] = ACTIONS(9553),
    [sym_grid_keyword] = ACTIONS(9553),
    [sym_part_keyword] = ACTIONS(9553),
    [sym_systempart_keyword] = ACTIONS(9553),
    [sym_usercontrol_keyword] = ACTIONS(9553),
    [sym_dataset_keyword] = ACTIONS(9553),
    [sym_elements_keyword] = ACTIONS(9553),
    [sym_dataitem_keyword] = ACTIONS(9553),
    [sym_column_keyword] = ACTIONS(9553),
    [sym_filter_keyword] = ACTIONS(9553),
    [sym_labels_keyword] = ACTIONS(9553),
    [sym_rendering_keyword] = ACTIONS(9553),
    [sym_requestpage_keyword] = ACTIONS(9553),
    [sym_schema_keyword] = ACTIONS(9553),
    [sym_views_keyword] = ACTIONS(9553),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9553),
    [sym_preproc_open] = ACTIONS(9553),
    [sym_preproc_close] = ACTIONS(9553),
  },
  [STATE(3537)] = {
    [anon_sym_SEMI] = ACTIONS(9553),
    [aux_sym_where_condition_token1] = ACTIONS(9555),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9553),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9553),
    [anon_sym_LBRACK] = ACTIONS(9553),
    [aux_sym_basic_type_token6] = ACTIONS(9555),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9553),
    [aux_sym_addafter_modification_token1] = ACTIONS(9553),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9553),
    [aux_sym_modify_modification_token1] = ACTIONS(9553),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9553),
    [aux_sym_movelast_modification_token1] = ACTIONS(9553),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9553),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9553),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9553),
    [anon_sym_POUNDif] = ACTIONS(9553),
    [anon_sym_POUNDIF] = ACTIONS(9553),
    [anon_sym_POUNDIf] = ACTIONS(9553),
    [anon_sym_POUNDelif] = ACTIONS(9553),
    [anon_sym_POUNDELIF] = ACTIONS(9553),
    [anon_sym_POUNDElif] = ACTIONS(9553),
    [anon_sym_POUNDelse] = ACTIONS(9553),
    [anon_sym_POUNDELSE] = ACTIONS(9553),
    [anon_sym_POUNDElse] = ACTIONS(9553),
    [anon_sym_POUNDendif] = ACTIONS(9553),
    [anon_sym_POUNDENDIF] = ACTIONS(9553),
    [anon_sym_POUNDEndif] = ACTIONS(9553),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9553),
    [sym_trigger_keyword] = ACTIONS(9553),
    [sym_var_keyword] = ACTIONS(9553),
    [sym_local_keyword] = ACTIONS(9553),
    [sym_internal_keyword] = ACTIONS(9553),
    [sym_protected_keyword] = ACTIONS(9553),
    [sym_event_keyword] = ACTIONS(9553),
    [sym_fields_keyword] = ACTIONS(9553),
    [sym_keys_keyword] = ACTIONS(9553),
    [sym_fieldgroups_keyword] = ACTIONS(9553),
    [sym_actions_keyword] = ACTIONS(9553),
    [sym_layout_keyword] = ACTIONS(9553),
    [sym_area_keyword] = ACTIONS(9553),
    [sym_group_keyword] = ACTIONS(9553),
    [sym_repeater_keyword] = ACTIONS(9553),
    [sym_cuegroup_keyword] = ACTIONS(9553),
    [sym_fixed_keyword] = ACTIONS(9553),
    [sym_grid_keyword] = ACTIONS(9553),
    [sym_part_keyword] = ACTIONS(9553),
    [sym_systempart_keyword] = ACTIONS(9553),
    [sym_usercontrol_keyword] = ACTIONS(9553),
    [sym_dataset_keyword] = ACTIONS(9553),
    [sym_elements_keyword] = ACTIONS(9553),
    [sym_dataitem_keyword] = ACTIONS(9553),
    [sym_column_keyword] = ACTIONS(9553),
    [sym_filter_keyword] = ACTIONS(9553),
    [sym_labels_keyword] = ACTIONS(9553),
    [sym_rendering_keyword] = ACTIONS(9553),
    [sym_requestpage_keyword] = ACTIONS(9553),
    [sym_schema_keyword] = ACTIONS(9553),
    [sym_views_keyword] = ACTIONS(9553),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9553),
    [sym_preproc_open] = ACTIONS(9553),
    [sym_preproc_close] = ACTIONS(9553),
  },
  [STATE(3538)] = {
    [anon_sym_SEMI] = ACTIONS(9557),
    [aux_sym_where_condition_token1] = ACTIONS(9559),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9557),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9557),
    [anon_sym_LBRACK] = ACTIONS(9557),
    [aux_sym_basic_type_token6] = ACTIONS(9559),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9557),
    [aux_sym_addafter_modification_token1] = ACTIONS(9557),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9557),
    [aux_sym_modify_modification_token1] = ACTIONS(9557),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9557),
    [aux_sym_movelast_modification_token1] = ACTIONS(9557),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9557),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9557),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9557),
    [anon_sym_POUNDif] = ACTIONS(9557),
    [anon_sym_POUNDIF] = ACTIONS(9557),
    [anon_sym_POUNDIf] = ACTIONS(9557),
    [anon_sym_POUNDelif] = ACTIONS(9557),
    [anon_sym_POUNDELIF] = ACTIONS(9557),
    [anon_sym_POUNDElif] = ACTIONS(9557),
    [anon_sym_POUNDelse] = ACTIONS(9557),
    [anon_sym_POUNDELSE] = ACTIONS(9557),
    [anon_sym_POUNDElse] = ACTIONS(9557),
    [anon_sym_POUNDendif] = ACTIONS(9557),
    [anon_sym_POUNDENDIF] = ACTIONS(9557),
    [anon_sym_POUNDEndif] = ACTIONS(9557),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9557),
    [sym_trigger_keyword] = ACTIONS(9557),
    [sym_var_keyword] = ACTIONS(9557),
    [sym_local_keyword] = ACTIONS(9557),
    [sym_internal_keyword] = ACTIONS(9557),
    [sym_protected_keyword] = ACTIONS(9557),
    [sym_event_keyword] = ACTIONS(9557),
    [sym_fields_keyword] = ACTIONS(9557),
    [sym_keys_keyword] = ACTIONS(9557),
    [sym_fieldgroups_keyword] = ACTIONS(9557),
    [sym_actions_keyword] = ACTIONS(9557),
    [sym_layout_keyword] = ACTIONS(9557),
    [sym_area_keyword] = ACTIONS(9557),
    [sym_group_keyword] = ACTIONS(9557),
    [sym_repeater_keyword] = ACTIONS(9557),
    [sym_cuegroup_keyword] = ACTIONS(9557),
    [sym_fixed_keyword] = ACTIONS(9557),
    [sym_grid_keyword] = ACTIONS(9557),
    [sym_part_keyword] = ACTIONS(9557),
    [sym_systempart_keyword] = ACTIONS(9557),
    [sym_usercontrol_keyword] = ACTIONS(9557),
    [sym_dataset_keyword] = ACTIONS(9557),
    [sym_elements_keyword] = ACTIONS(9557),
    [sym_dataitem_keyword] = ACTIONS(9557),
    [sym_column_keyword] = ACTIONS(9557),
    [sym_filter_keyword] = ACTIONS(9557),
    [sym_labels_keyword] = ACTIONS(9557),
    [sym_rendering_keyword] = ACTIONS(9557),
    [sym_requestpage_keyword] = ACTIONS(9557),
    [sym_schema_keyword] = ACTIONS(9557),
    [sym_views_keyword] = ACTIONS(9557),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9557),
    [sym_preproc_open] = ACTIONS(9557),
    [sym_preproc_close] = ACTIONS(9557),
  },
  [STATE(3539)] = {
    [anon_sym_SEMI] = ACTIONS(9557),
    [aux_sym_where_condition_token1] = ACTIONS(9559),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9557),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9557),
    [anon_sym_LBRACK] = ACTIONS(9557),
    [aux_sym_basic_type_token6] = ACTIONS(9559),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9557),
    [aux_sym_addafter_modification_token1] = ACTIONS(9557),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9557),
    [aux_sym_modify_modification_token1] = ACTIONS(9557),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9557),
    [aux_sym_movelast_modification_token1] = ACTIONS(9557),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9557),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9557),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9557),
    [anon_sym_POUNDif] = ACTIONS(9557),
    [anon_sym_POUNDIF] = ACTIONS(9557),
    [anon_sym_POUNDIf] = ACTIONS(9557),
    [anon_sym_POUNDelif] = ACTIONS(9557),
    [anon_sym_POUNDELIF] = ACTIONS(9557),
    [anon_sym_POUNDElif] = ACTIONS(9557),
    [anon_sym_POUNDelse] = ACTIONS(9557),
    [anon_sym_POUNDELSE] = ACTIONS(9557),
    [anon_sym_POUNDElse] = ACTIONS(9557),
    [anon_sym_POUNDendif] = ACTIONS(9557),
    [anon_sym_POUNDENDIF] = ACTIONS(9557),
    [anon_sym_POUNDEndif] = ACTIONS(9557),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9557),
    [sym_trigger_keyword] = ACTIONS(9557),
    [sym_var_keyword] = ACTIONS(9557),
    [sym_local_keyword] = ACTIONS(9557),
    [sym_internal_keyword] = ACTIONS(9557),
    [sym_protected_keyword] = ACTIONS(9557),
    [sym_event_keyword] = ACTIONS(9557),
    [sym_fields_keyword] = ACTIONS(9557),
    [sym_keys_keyword] = ACTIONS(9557),
    [sym_fieldgroups_keyword] = ACTIONS(9557),
    [sym_actions_keyword] = ACTIONS(9557),
    [sym_layout_keyword] = ACTIONS(9557),
    [sym_area_keyword] = ACTIONS(9557),
    [sym_group_keyword] = ACTIONS(9557),
    [sym_repeater_keyword] = ACTIONS(9557),
    [sym_cuegroup_keyword] = ACTIONS(9557),
    [sym_fixed_keyword] = ACTIONS(9557),
    [sym_grid_keyword] = ACTIONS(9557),
    [sym_part_keyword] = ACTIONS(9557),
    [sym_systempart_keyword] = ACTIONS(9557),
    [sym_usercontrol_keyword] = ACTIONS(9557),
    [sym_dataset_keyword] = ACTIONS(9557),
    [sym_elements_keyword] = ACTIONS(9557),
    [sym_dataitem_keyword] = ACTIONS(9557),
    [sym_column_keyword] = ACTIONS(9557),
    [sym_filter_keyword] = ACTIONS(9557),
    [sym_labels_keyword] = ACTIONS(9557),
    [sym_rendering_keyword] = ACTIONS(9557),
    [sym_requestpage_keyword] = ACTIONS(9557),
    [sym_schema_keyword] = ACTIONS(9557),
    [sym_views_keyword] = ACTIONS(9557),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9557),
    [sym_preproc_open] = ACTIONS(9557),
    [sym_preproc_close] = ACTIONS(9557),
  },
  [STATE(3540)] = {
    [anon_sym_SEMI] = ACTIONS(9557),
    [aux_sym_where_condition_token1] = ACTIONS(9559),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9557),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9557),
    [anon_sym_LBRACK] = ACTIONS(9557),
    [aux_sym_basic_type_token6] = ACTIONS(9559),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9557),
    [aux_sym_addafter_modification_token1] = ACTIONS(9557),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9557),
    [aux_sym_modify_modification_token1] = ACTIONS(9557),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9557),
    [aux_sym_movelast_modification_token1] = ACTIONS(9557),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9557),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9557),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9557),
    [anon_sym_POUNDif] = ACTIONS(9557),
    [anon_sym_POUNDIF] = ACTIONS(9557),
    [anon_sym_POUNDIf] = ACTIONS(9557),
    [anon_sym_POUNDelif] = ACTIONS(9557),
    [anon_sym_POUNDELIF] = ACTIONS(9557),
    [anon_sym_POUNDElif] = ACTIONS(9557),
    [anon_sym_POUNDelse] = ACTIONS(9557),
    [anon_sym_POUNDELSE] = ACTIONS(9557),
    [anon_sym_POUNDElse] = ACTIONS(9557),
    [anon_sym_POUNDendif] = ACTIONS(9557),
    [anon_sym_POUNDENDIF] = ACTIONS(9557),
    [anon_sym_POUNDEndif] = ACTIONS(9557),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9557),
    [sym_trigger_keyword] = ACTIONS(9557),
    [sym_var_keyword] = ACTIONS(9557),
    [sym_local_keyword] = ACTIONS(9557),
    [sym_internal_keyword] = ACTIONS(9557),
    [sym_protected_keyword] = ACTIONS(9557),
    [sym_event_keyword] = ACTIONS(9557),
    [sym_fields_keyword] = ACTIONS(9557),
    [sym_keys_keyword] = ACTIONS(9557),
    [sym_fieldgroups_keyword] = ACTIONS(9557),
    [sym_actions_keyword] = ACTIONS(9557),
    [sym_layout_keyword] = ACTIONS(9557),
    [sym_area_keyword] = ACTIONS(9557),
    [sym_group_keyword] = ACTIONS(9557),
    [sym_repeater_keyword] = ACTIONS(9557),
    [sym_cuegroup_keyword] = ACTIONS(9557),
    [sym_fixed_keyword] = ACTIONS(9557),
    [sym_grid_keyword] = ACTIONS(9557),
    [sym_part_keyword] = ACTIONS(9557),
    [sym_systempart_keyword] = ACTIONS(9557),
    [sym_usercontrol_keyword] = ACTIONS(9557),
    [sym_dataset_keyword] = ACTIONS(9557),
    [sym_elements_keyword] = ACTIONS(9557),
    [sym_dataitem_keyword] = ACTIONS(9557),
    [sym_column_keyword] = ACTIONS(9557),
    [sym_filter_keyword] = ACTIONS(9557),
    [sym_labels_keyword] = ACTIONS(9557),
    [sym_rendering_keyword] = ACTIONS(9557),
    [sym_requestpage_keyword] = ACTIONS(9557),
    [sym_schema_keyword] = ACTIONS(9557),
    [sym_views_keyword] = ACTIONS(9557),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9557),
    [sym_preproc_open] = ACTIONS(9557),
    [sym_preproc_close] = ACTIONS(9557),
  },
  [STATE(3541)] = {
    [anon_sym_SEMI] = ACTIONS(9557),
    [aux_sym_where_condition_token1] = ACTIONS(9559),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9557),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9557),
    [anon_sym_LBRACK] = ACTIONS(9557),
    [aux_sym_basic_type_token6] = ACTIONS(9559),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9557),
    [aux_sym_addafter_modification_token1] = ACTIONS(9557),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9557),
    [aux_sym_modify_modification_token1] = ACTIONS(9557),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9557),
    [aux_sym_movelast_modification_token1] = ACTIONS(9557),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9557),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9557),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9557),
    [anon_sym_POUNDif] = ACTIONS(9557),
    [anon_sym_POUNDIF] = ACTIONS(9557),
    [anon_sym_POUNDIf] = ACTIONS(9557),
    [anon_sym_POUNDelif] = ACTIONS(9557),
    [anon_sym_POUNDELIF] = ACTIONS(9557),
    [anon_sym_POUNDElif] = ACTIONS(9557),
    [anon_sym_POUNDelse] = ACTIONS(9557),
    [anon_sym_POUNDELSE] = ACTIONS(9557),
    [anon_sym_POUNDElse] = ACTIONS(9557),
    [anon_sym_POUNDendif] = ACTIONS(9557),
    [anon_sym_POUNDENDIF] = ACTIONS(9557),
    [anon_sym_POUNDEndif] = ACTIONS(9557),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9557),
    [sym_trigger_keyword] = ACTIONS(9557),
    [sym_var_keyword] = ACTIONS(9557),
    [sym_local_keyword] = ACTIONS(9557),
    [sym_internal_keyword] = ACTIONS(9557),
    [sym_protected_keyword] = ACTIONS(9557),
    [sym_event_keyword] = ACTIONS(9557),
    [sym_fields_keyword] = ACTIONS(9557),
    [sym_keys_keyword] = ACTIONS(9557),
    [sym_fieldgroups_keyword] = ACTIONS(9557),
    [sym_actions_keyword] = ACTIONS(9557),
    [sym_layout_keyword] = ACTIONS(9557),
    [sym_area_keyword] = ACTIONS(9557),
    [sym_group_keyword] = ACTIONS(9557),
    [sym_repeater_keyword] = ACTIONS(9557),
    [sym_cuegroup_keyword] = ACTIONS(9557),
    [sym_fixed_keyword] = ACTIONS(9557),
    [sym_grid_keyword] = ACTIONS(9557),
    [sym_part_keyword] = ACTIONS(9557),
    [sym_systempart_keyword] = ACTIONS(9557),
    [sym_usercontrol_keyword] = ACTIONS(9557),
    [sym_dataset_keyword] = ACTIONS(9557),
    [sym_elements_keyword] = ACTIONS(9557),
    [sym_dataitem_keyword] = ACTIONS(9557),
    [sym_column_keyword] = ACTIONS(9557),
    [sym_filter_keyword] = ACTIONS(9557),
    [sym_labels_keyword] = ACTIONS(9557),
    [sym_rendering_keyword] = ACTIONS(9557),
    [sym_requestpage_keyword] = ACTIONS(9557),
    [sym_schema_keyword] = ACTIONS(9557),
    [sym_views_keyword] = ACTIONS(9557),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9557),
    [sym_preproc_open] = ACTIONS(9557),
    [sym_preproc_close] = ACTIONS(9557),
  },
  [STATE(3542)] = {
    [anon_sym_SEMI] = ACTIONS(9561),
    [aux_sym_where_condition_token1] = ACTIONS(9563),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9561),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9561),
    [anon_sym_LBRACK] = ACTIONS(9561),
    [aux_sym_basic_type_token6] = ACTIONS(9563),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9561),
    [aux_sym_addafter_modification_token1] = ACTIONS(9561),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9561),
    [aux_sym_modify_modification_token1] = ACTIONS(9561),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9561),
    [aux_sym_movelast_modification_token1] = ACTIONS(9561),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9561),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9561),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9561),
    [anon_sym_POUNDif] = ACTIONS(9561),
    [anon_sym_POUNDIF] = ACTIONS(9561),
    [anon_sym_POUNDIf] = ACTIONS(9561),
    [anon_sym_POUNDelif] = ACTIONS(9561),
    [anon_sym_POUNDELIF] = ACTIONS(9561),
    [anon_sym_POUNDElif] = ACTIONS(9561),
    [anon_sym_POUNDelse] = ACTIONS(9561),
    [anon_sym_POUNDELSE] = ACTIONS(9561),
    [anon_sym_POUNDElse] = ACTIONS(9561),
    [anon_sym_POUNDendif] = ACTIONS(9561),
    [anon_sym_POUNDENDIF] = ACTIONS(9561),
    [anon_sym_POUNDEndif] = ACTIONS(9561),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9561),
    [sym_trigger_keyword] = ACTIONS(9561),
    [sym_var_keyword] = ACTIONS(9561),
    [sym_local_keyword] = ACTIONS(9561),
    [sym_internal_keyword] = ACTIONS(9561),
    [sym_protected_keyword] = ACTIONS(9561),
    [sym_event_keyword] = ACTIONS(9561),
    [sym_fields_keyword] = ACTIONS(9561),
    [sym_keys_keyword] = ACTIONS(9561),
    [sym_fieldgroups_keyword] = ACTIONS(9561),
    [sym_actions_keyword] = ACTIONS(9561),
    [sym_layout_keyword] = ACTIONS(9561),
    [sym_area_keyword] = ACTIONS(9561),
    [sym_group_keyword] = ACTIONS(9561),
    [sym_repeater_keyword] = ACTIONS(9561),
    [sym_cuegroup_keyword] = ACTIONS(9561),
    [sym_fixed_keyword] = ACTIONS(9561),
    [sym_grid_keyword] = ACTIONS(9561),
    [sym_part_keyword] = ACTIONS(9561),
    [sym_systempart_keyword] = ACTIONS(9561),
    [sym_usercontrol_keyword] = ACTIONS(9561),
    [sym_dataset_keyword] = ACTIONS(9561),
    [sym_elements_keyword] = ACTIONS(9561),
    [sym_dataitem_keyword] = ACTIONS(9561),
    [sym_column_keyword] = ACTIONS(9561),
    [sym_filter_keyword] = ACTIONS(9561),
    [sym_labels_keyword] = ACTIONS(9561),
    [sym_rendering_keyword] = ACTIONS(9561),
    [sym_requestpage_keyword] = ACTIONS(9561),
    [sym_schema_keyword] = ACTIONS(9561),
    [sym_views_keyword] = ACTIONS(9561),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9561),
    [sym_preproc_open] = ACTIONS(9561),
    [sym_preproc_close] = ACTIONS(9561),
  },
  [STATE(3543)] = {
    [anon_sym_SEMI] = ACTIONS(9565),
    [aux_sym_where_condition_token1] = ACTIONS(9567),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9565),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9565),
    [anon_sym_LBRACK] = ACTIONS(9565),
    [aux_sym_basic_type_token6] = ACTIONS(9567),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9565),
    [aux_sym_addafter_modification_token1] = ACTIONS(9565),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9565),
    [aux_sym_modify_modification_token1] = ACTIONS(9565),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9565),
    [aux_sym_movelast_modification_token1] = ACTIONS(9565),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9565),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9565),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9565),
    [anon_sym_POUNDif] = ACTIONS(9565),
    [anon_sym_POUNDIF] = ACTIONS(9565),
    [anon_sym_POUNDIf] = ACTIONS(9565),
    [anon_sym_POUNDelif] = ACTIONS(9565),
    [anon_sym_POUNDELIF] = ACTIONS(9565),
    [anon_sym_POUNDElif] = ACTIONS(9565),
    [anon_sym_POUNDelse] = ACTIONS(9565),
    [anon_sym_POUNDELSE] = ACTIONS(9565),
    [anon_sym_POUNDElse] = ACTIONS(9565),
    [anon_sym_POUNDendif] = ACTIONS(9565),
    [anon_sym_POUNDENDIF] = ACTIONS(9565),
    [anon_sym_POUNDEndif] = ACTIONS(9565),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9565),
    [sym_trigger_keyword] = ACTIONS(9565),
    [sym_var_keyword] = ACTIONS(9565),
    [sym_local_keyword] = ACTIONS(9565),
    [sym_internal_keyword] = ACTIONS(9565),
    [sym_protected_keyword] = ACTIONS(9565),
    [sym_event_keyword] = ACTIONS(9565),
    [sym_fields_keyword] = ACTIONS(9565),
    [sym_keys_keyword] = ACTIONS(9565),
    [sym_fieldgroups_keyword] = ACTIONS(9565),
    [sym_actions_keyword] = ACTIONS(9565),
    [sym_layout_keyword] = ACTIONS(9565),
    [sym_area_keyword] = ACTIONS(9565),
    [sym_group_keyword] = ACTIONS(9565),
    [sym_repeater_keyword] = ACTIONS(9565),
    [sym_cuegroup_keyword] = ACTIONS(9565),
    [sym_fixed_keyword] = ACTIONS(9565),
    [sym_grid_keyword] = ACTIONS(9565),
    [sym_part_keyword] = ACTIONS(9565),
    [sym_systempart_keyword] = ACTIONS(9565),
    [sym_usercontrol_keyword] = ACTIONS(9565),
    [sym_dataset_keyword] = ACTIONS(9565),
    [sym_elements_keyword] = ACTIONS(9565),
    [sym_dataitem_keyword] = ACTIONS(9565),
    [sym_column_keyword] = ACTIONS(9565),
    [sym_filter_keyword] = ACTIONS(9565),
    [sym_labels_keyword] = ACTIONS(9565),
    [sym_rendering_keyword] = ACTIONS(9565),
    [sym_requestpage_keyword] = ACTIONS(9565),
    [sym_schema_keyword] = ACTIONS(9565),
    [sym_views_keyword] = ACTIONS(9565),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9565),
    [sym_preproc_open] = ACTIONS(9565),
    [sym_preproc_close] = ACTIONS(9565),
  },
  [STATE(3544)] = {
    [anon_sym_SEMI] = ACTIONS(9569),
    [aux_sym_where_condition_token1] = ACTIONS(9567),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9565),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9565),
    [anon_sym_LBRACK] = ACTIONS(9565),
    [aux_sym_basic_type_token6] = ACTIONS(9567),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9565),
    [aux_sym_addafter_modification_token1] = ACTIONS(9565),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9565),
    [aux_sym_modify_modification_token1] = ACTIONS(9565),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9565),
    [aux_sym_movelast_modification_token1] = ACTIONS(9565),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9565),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9565),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9565),
    [anon_sym_POUNDif] = ACTIONS(9565),
    [anon_sym_POUNDIF] = ACTIONS(9565),
    [anon_sym_POUNDIf] = ACTIONS(9565),
    [anon_sym_POUNDelif] = ACTIONS(9565),
    [anon_sym_POUNDELIF] = ACTIONS(9565),
    [anon_sym_POUNDElif] = ACTIONS(9565),
    [anon_sym_POUNDelse] = ACTIONS(9565),
    [anon_sym_POUNDELSE] = ACTIONS(9565),
    [anon_sym_POUNDElse] = ACTIONS(9565),
    [anon_sym_POUNDendif] = ACTIONS(9565),
    [anon_sym_POUNDENDIF] = ACTIONS(9565),
    [anon_sym_POUNDEndif] = ACTIONS(9565),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9565),
    [sym_trigger_keyword] = ACTIONS(9565),
    [sym_var_keyword] = ACTIONS(9565),
    [sym_local_keyword] = ACTIONS(9565),
    [sym_internal_keyword] = ACTIONS(9565),
    [sym_protected_keyword] = ACTIONS(9565),
    [sym_event_keyword] = ACTIONS(9565),
    [sym_fields_keyword] = ACTIONS(9565),
    [sym_keys_keyword] = ACTIONS(9565),
    [sym_fieldgroups_keyword] = ACTIONS(9565),
    [sym_actions_keyword] = ACTIONS(9565),
    [sym_layout_keyword] = ACTIONS(9565),
    [sym_area_keyword] = ACTIONS(9565),
    [sym_group_keyword] = ACTIONS(9565),
    [sym_repeater_keyword] = ACTIONS(9565),
    [sym_cuegroup_keyword] = ACTIONS(9565),
    [sym_fixed_keyword] = ACTIONS(9565),
    [sym_grid_keyword] = ACTIONS(9565),
    [sym_part_keyword] = ACTIONS(9565),
    [sym_systempart_keyword] = ACTIONS(9565),
    [sym_usercontrol_keyword] = ACTIONS(9565),
    [sym_dataset_keyword] = ACTIONS(9565),
    [sym_elements_keyword] = ACTIONS(9565),
    [sym_dataitem_keyword] = ACTIONS(9565),
    [sym_column_keyword] = ACTIONS(9565),
    [sym_filter_keyword] = ACTIONS(9565),
    [sym_labels_keyword] = ACTIONS(9565),
    [sym_rendering_keyword] = ACTIONS(9565),
    [sym_requestpage_keyword] = ACTIONS(9565),
    [sym_schema_keyword] = ACTIONS(9565),
    [sym_views_keyword] = ACTIONS(9565),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9565),
    [sym_preproc_open] = ACTIONS(9565),
    [sym_preproc_close] = ACTIONS(9565),
  },
  [STATE(3545)] = {
    [anon_sym_SEMI] = ACTIONS(9571),
    [aux_sym_where_condition_token1] = ACTIONS(9573),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9571),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9571),
    [anon_sym_LBRACK] = ACTIONS(9571),
    [aux_sym_basic_type_token6] = ACTIONS(9573),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9571),
    [aux_sym_addafter_modification_token1] = ACTIONS(9571),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9571),
    [aux_sym_modify_modification_token1] = ACTIONS(9571),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9571),
    [aux_sym_movelast_modification_token1] = ACTIONS(9571),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9571),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9571),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9571),
    [anon_sym_POUNDif] = ACTIONS(9571),
    [anon_sym_POUNDIF] = ACTIONS(9571),
    [anon_sym_POUNDIf] = ACTIONS(9571),
    [anon_sym_POUNDelif] = ACTIONS(9571),
    [anon_sym_POUNDELIF] = ACTIONS(9571),
    [anon_sym_POUNDElif] = ACTIONS(9571),
    [anon_sym_POUNDelse] = ACTIONS(9571),
    [anon_sym_POUNDELSE] = ACTIONS(9571),
    [anon_sym_POUNDElse] = ACTIONS(9571),
    [anon_sym_POUNDendif] = ACTIONS(9571),
    [anon_sym_POUNDENDIF] = ACTIONS(9571),
    [anon_sym_POUNDEndif] = ACTIONS(9571),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9571),
    [sym_trigger_keyword] = ACTIONS(9571),
    [sym_var_keyword] = ACTIONS(9571),
    [sym_local_keyword] = ACTIONS(9571),
    [sym_internal_keyword] = ACTIONS(9571),
    [sym_protected_keyword] = ACTIONS(9571),
    [sym_event_keyword] = ACTIONS(9571),
    [sym_fields_keyword] = ACTIONS(9571),
    [sym_keys_keyword] = ACTIONS(9571),
    [sym_fieldgroups_keyword] = ACTIONS(9571),
    [sym_actions_keyword] = ACTIONS(9571),
    [sym_layout_keyword] = ACTIONS(9571),
    [sym_area_keyword] = ACTIONS(9571),
    [sym_group_keyword] = ACTIONS(9571),
    [sym_repeater_keyword] = ACTIONS(9571),
    [sym_cuegroup_keyword] = ACTIONS(9571),
    [sym_fixed_keyword] = ACTIONS(9571),
    [sym_grid_keyword] = ACTIONS(9571),
    [sym_part_keyword] = ACTIONS(9571),
    [sym_systempart_keyword] = ACTIONS(9571),
    [sym_usercontrol_keyword] = ACTIONS(9571),
    [sym_dataset_keyword] = ACTIONS(9571),
    [sym_elements_keyword] = ACTIONS(9571),
    [sym_dataitem_keyword] = ACTIONS(9571),
    [sym_column_keyword] = ACTIONS(9571),
    [sym_filter_keyword] = ACTIONS(9571),
    [sym_labels_keyword] = ACTIONS(9571),
    [sym_rendering_keyword] = ACTIONS(9571),
    [sym_requestpage_keyword] = ACTIONS(9571),
    [sym_schema_keyword] = ACTIONS(9571),
    [sym_views_keyword] = ACTIONS(9571),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9571),
    [sym_preproc_open] = ACTIONS(9571),
    [sym_preproc_close] = ACTIONS(9571),
  },
  [STATE(3546)] = {
    [anon_sym_SEMI] = ACTIONS(9575),
    [aux_sym_where_condition_token1] = ACTIONS(9577),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9575),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9575),
    [anon_sym_LBRACK] = ACTIONS(9575),
    [aux_sym_basic_type_token6] = ACTIONS(9577),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9575),
    [aux_sym_addafter_modification_token1] = ACTIONS(9575),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9575),
    [aux_sym_modify_modification_token1] = ACTIONS(9575),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9575),
    [aux_sym_movelast_modification_token1] = ACTIONS(9575),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9575),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9575),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9575),
    [anon_sym_POUNDif] = ACTIONS(9575),
    [anon_sym_POUNDIF] = ACTIONS(9575),
    [anon_sym_POUNDIf] = ACTIONS(9575),
    [anon_sym_POUNDelif] = ACTIONS(9575),
    [anon_sym_POUNDELIF] = ACTIONS(9575),
    [anon_sym_POUNDElif] = ACTIONS(9575),
    [anon_sym_POUNDelse] = ACTIONS(9575),
    [anon_sym_POUNDELSE] = ACTIONS(9575),
    [anon_sym_POUNDElse] = ACTIONS(9575),
    [anon_sym_POUNDendif] = ACTIONS(9575),
    [anon_sym_POUNDENDIF] = ACTIONS(9575),
    [anon_sym_POUNDEndif] = ACTIONS(9575),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9575),
    [sym_trigger_keyword] = ACTIONS(9575),
    [sym_var_keyword] = ACTIONS(9575),
    [sym_local_keyword] = ACTIONS(9575),
    [sym_internal_keyword] = ACTIONS(9575),
    [sym_protected_keyword] = ACTIONS(9575),
    [sym_event_keyword] = ACTIONS(9575),
    [sym_fields_keyword] = ACTIONS(9575),
    [sym_keys_keyword] = ACTIONS(9575),
    [sym_fieldgroups_keyword] = ACTIONS(9575),
    [sym_actions_keyword] = ACTIONS(9575),
    [sym_layout_keyword] = ACTIONS(9575),
    [sym_area_keyword] = ACTIONS(9575),
    [sym_group_keyword] = ACTIONS(9575),
    [sym_repeater_keyword] = ACTIONS(9575),
    [sym_cuegroup_keyword] = ACTIONS(9575),
    [sym_fixed_keyword] = ACTIONS(9575),
    [sym_grid_keyword] = ACTIONS(9575),
    [sym_part_keyword] = ACTIONS(9575),
    [sym_systempart_keyword] = ACTIONS(9575),
    [sym_usercontrol_keyword] = ACTIONS(9575),
    [sym_dataset_keyword] = ACTIONS(9575),
    [sym_elements_keyword] = ACTIONS(9575),
    [sym_dataitem_keyword] = ACTIONS(9575),
    [sym_column_keyword] = ACTIONS(9575),
    [sym_filter_keyword] = ACTIONS(9575),
    [sym_labels_keyword] = ACTIONS(9575),
    [sym_rendering_keyword] = ACTIONS(9575),
    [sym_requestpage_keyword] = ACTIONS(9575),
    [sym_schema_keyword] = ACTIONS(9575),
    [sym_views_keyword] = ACTIONS(9575),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9575),
    [sym_preproc_open] = ACTIONS(9575),
    [sym_preproc_close] = ACTIONS(9575),
  },
  [STATE(3547)] = {
    [anon_sym_SEMI] = ACTIONS(9579),
    [aux_sym_where_condition_token1] = ACTIONS(9581),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9579),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9579),
    [anon_sym_LBRACK] = ACTIONS(9579),
    [aux_sym_basic_type_token6] = ACTIONS(9581),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9579),
    [aux_sym_addafter_modification_token1] = ACTIONS(9579),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9579),
    [aux_sym_modify_modification_token1] = ACTIONS(9579),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9579),
    [aux_sym_movelast_modification_token1] = ACTIONS(9579),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9579),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9579),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9579),
    [anon_sym_POUNDif] = ACTIONS(9579),
    [anon_sym_POUNDIF] = ACTIONS(9579),
    [anon_sym_POUNDIf] = ACTIONS(9579),
    [anon_sym_POUNDelif] = ACTIONS(9579),
    [anon_sym_POUNDELIF] = ACTIONS(9579),
    [anon_sym_POUNDElif] = ACTIONS(9579),
    [anon_sym_POUNDelse] = ACTIONS(9579),
    [anon_sym_POUNDELSE] = ACTIONS(9579),
    [anon_sym_POUNDElse] = ACTIONS(9579),
    [anon_sym_POUNDendif] = ACTIONS(9579),
    [anon_sym_POUNDENDIF] = ACTIONS(9579),
    [anon_sym_POUNDEndif] = ACTIONS(9579),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9579),
    [sym_trigger_keyword] = ACTIONS(9579),
    [sym_var_keyword] = ACTIONS(9579),
    [sym_local_keyword] = ACTIONS(9579),
    [sym_internal_keyword] = ACTIONS(9579),
    [sym_protected_keyword] = ACTIONS(9579),
    [sym_event_keyword] = ACTIONS(9579),
    [sym_fields_keyword] = ACTIONS(9579),
    [sym_keys_keyword] = ACTIONS(9579),
    [sym_fieldgroups_keyword] = ACTIONS(9579),
    [sym_actions_keyword] = ACTIONS(9579),
    [sym_layout_keyword] = ACTIONS(9579),
    [sym_area_keyword] = ACTIONS(9579),
    [sym_group_keyword] = ACTIONS(9579),
    [sym_repeater_keyword] = ACTIONS(9579),
    [sym_cuegroup_keyword] = ACTIONS(9579),
    [sym_fixed_keyword] = ACTIONS(9579),
    [sym_grid_keyword] = ACTIONS(9579),
    [sym_part_keyword] = ACTIONS(9579),
    [sym_systempart_keyword] = ACTIONS(9579),
    [sym_usercontrol_keyword] = ACTIONS(9579),
    [sym_dataset_keyword] = ACTIONS(9579),
    [sym_elements_keyword] = ACTIONS(9579),
    [sym_dataitem_keyword] = ACTIONS(9579),
    [sym_column_keyword] = ACTIONS(9579),
    [sym_filter_keyword] = ACTIONS(9579),
    [sym_labels_keyword] = ACTIONS(9579),
    [sym_rendering_keyword] = ACTIONS(9579),
    [sym_requestpage_keyword] = ACTIONS(9579),
    [sym_schema_keyword] = ACTIONS(9579),
    [sym_views_keyword] = ACTIONS(9579),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9579),
    [sym_preproc_open] = ACTIONS(9579),
    [sym_preproc_close] = ACTIONS(9579),
  },
  [STATE(3548)] = {
    [anon_sym_SEMI] = ACTIONS(9579),
    [aux_sym_where_condition_token1] = ACTIONS(9581),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9579),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9579),
    [anon_sym_LBRACK] = ACTIONS(9579),
    [aux_sym_basic_type_token6] = ACTIONS(9581),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9579),
    [aux_sym_addafter_modification_token1] = ACTIONS(9579),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9579),
    [aux_sym_modify_modification_token1] = ACTIONS(9579),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9579),
    [aux_sym_movelast_modification_token1] = ACTIONS(9579),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9579),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9579),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9579),
    [anon_sym_POUNDif] = ACTIONS(9579),
    [anon_sym_POUNDIF] = ACTIONS(9579),
    [anon_sym_POUNDIf] = ACTIONS(9579),
    [anon_sym_POUNDelif] = ACTIONS(9579),
    [anon_sym_POUNDELIF] = ACTIONS(9579),
    [anon_sym_POUNDElif] = ACTIONS(9579),
    [anon_sym_POUNDelse] = ACTIONS(9579),
    [anon_sym_POUNDELSE] = ACTIONS(9579),
    [anon_sym_POUNDElse] = ACTIONS(9579),
    [anon_sym_POUNDendif] = ACTIONS(9579),
    [anon_sym_POUNDENDIF] = ACTIONS(9579),
    [anon_sym_POUNDEndif] = ACTIONS(9579),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9579),
    [sym_trigger_keyword] = ACTIONS(9579),
    [sym_var_keyword] = ACTIONS(9579),
    [sym_local_keyword] = ACTIONS(9579),
    [sym_internal_keyword] = ACTIONS(9579),
    [sym_protected_keyword] = ACTIONS(9579),
    [sym_event_keyword] = ACTIONS(9579),
    [sym_fields_keyword] = ACTIONS(9579),
    [sym_keys_keyword] = ACTIONS(9579),
    [sym_fieldgroups_keyword] = ACTIONS(9579),
    [sym_actions_keyword] = ACTIONS(9579),
    [sym_layout_keyword] = ACTIONS(9579),
    [sym_area_keyword] = ACTIONS(9579),
    [sym_group_keyword] = ACTIONS(9579),
    [sym_repeater_keyword] = ACTIONS(9579),
    [sym_cuegroup_keyword] = ACTIONS(9579),
    [sym_fixed_keyword] = ACTIONS(9579),
    [sym_grid_keyword] = ACTIONS(9579),
    [sym_part_keyword] = ACTIONS(9579),
    [sym_systempart_keyword] = ACTIONS(9579),
    [sym_usercontrol_keyword] = ACTIONS(9579),
    [sym_dataset_keyword] = ACTIONS(9579),
    [sym_elements_keyword] = ACTIONS(9579),
    [sym_dataitem_keyword] = ACTIONS(9579),
    [sym_column_keyword] = ACTIONS(9579),
    [sym_filter_keyword] = ACTIONS(9579),
    [sym_labels_keyword] = ACTIONS(9579),
    [sym_rendering_keyword] = ACTIONS(9579),
    [sym_requestpage_keyword] = ACTIONS(9579),
    [sym_schema_keyword] = ACTIONS(9579),
    [sym_views_keyword] = ACTIONS(9579),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9579),
    [sym_preproc_open] = ACTIONS(9579),
    [sym_preproc_close] = ACTIONS(9579),
  },
  [STATE(3549)] = {
    [anon_sym_SEMI] = ACTIONS(9583),
    [aux_sym_where_condition_token1] = ACTIONS(9585),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9583),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9583),
    [anon_sym_LBRACK] = ACTIONS(9583),
    [aux_sym_basic_type_token6] = ACTIONS(9585),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9583),
    [aux_sym_addafter_modification_token1] = ACTIONS(9583),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9583),
    [aux_sym_modify_modification_token1] = ACTIONS(9583),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9583),
    [aux_sym_movelast_modification_token1] = ACTIONS(9583),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9583),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9583),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9583),
    [anon_sym_POUNDif] = ACTIONS(9583),
    [anon_sym_POUNDIF] = ACTIONS(9583),
    [anon_sym_POUNDIf] = ACTIONS(9583),
    [anon_sym_POUNDelif] = ACTIONS(9583),
    [anon_sym_POUNDELIF] = ACTIONS(9583),
    [anon_sym_POUNDElif] = ACTIONS(9583),
    [anon_sym_POUNDelse] = ACTIONS(9583),
    [anon_sym_POUNDELSE] = ACTIONS(9583),
    [anon_sym_POUNDElse] = ACTIONS(9583),
    [anon_sym_POUNDendif] = ACTIONS(9583),
    [anon_sym_POUNDENDIF] = ACTIONS(9583),
    [anon_sym_POUNDEndif] = ACTIONS(9583),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9583),
    [sym_trigger_keyword] = ACTIONS(9583),
    [sym_var_keyword] = ACTIONS(9583),
    [sym_local_keyword] = ACTIONS(9583),
    [sym_internal_keyword] = ACTIONS(9583),
    [sym_protected_keyword] = ACTIONS(9583),
    [sym_event_keyword] = ACTIONS(9583),
    [sym_fields_keyword] = ACTIONS(9583),
    [sym_keys_keyword] = ACTIONS(9583),
    [sym_fieldgroups_keyword] = ACTIONS(9583),
    [sym_actions_keyword] = ACTIONS(9583),
    [sym_layout_keyword] = ACTIONS(9583),
    [sym_area_keyword] = ACTIONS(9583),
    [sym_group_keyword] = ACTIONS(9583),
    [sym_repeater_keyword] = ACTIONS(9583),
    [sym_cuegroup_keyword] = ACTIONS(9583),
    [sym_fixed_keyword] = ACTIONS(9583),
    [sym_grid_keyword] = ACTIONS(9583),
    [sym_part_keyword] = ACTIONS(9583),
    [sym_systempart_keyword] = ACTIONS(9583),
    [sym_usercontrol_keyword] = ACTIONS(9583),
    [sym_dataset_keyword] = ACTIONS(9583),
    [sym_elements_keyword] = ACTIONS(9583),
    [sym_dataitem_keyword] = ACTIONS(9583),
    [sym_column_keyword] = ACTIONS(9583),
    [sym_filter_keyword] = ACTIONS(9583),
    [sym_labels_keyword] = ACTIONS(9583),
    [sym_rendering_keyword] = ACTIONS(9583),
    [sym_requestpage_keyword] = ACTIONS(9583),
    [sym_schema_keyword] = ACTIONS(9583),
    [sym_views_keyword] = ACTIONS(9583),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9583),
    [sym_preproc_open] = ACTIONS(9583),
    [sym_preproc_close] = ACTIONS(9583),
  },
  [STATE(3550)] = {
    [anon_sym_SEMI] = ACTIONS(9583),
    [aux_sym_where_condition_token1] = ACTIONS(9585),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9583),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9583),
    [anon_sym_LBRACK] = ACTIONS(9583),
    [aux_sym_basic_type_token6] = ACTIONS(9585),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9583),
    [aux_sym_addafter_modification_token1] = ACTIONS(9583),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9583),
    [aux_sym_modify_modification_token1] = ACTIONS(9583),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9583),
    [aux_sym_movelast_modification_token1] = ACTIONS(9583),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9583),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9583),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9583),
    [anon_sym_POUNDif] = ACTIONS(9583),
    [anon_sym_POUNDIF] = ACTIONS(9583),
    [anon_sym_POUNDIf] = ACTIONS(9583),
    [anon_sym_POUNDelif] = ACTIONS(9583),
    [anon_sym_POUNDELIF] = ACTIONS(9583),
    [anon_sym_POUNDElif] = ACTIONS(9583),
    [anon_sym_POUNDelse] = ACTIONS(9583),
    [anon_sym_POUNDELSE] = ACTIONS(9583),
    [anon_sym_POUNDElse] = ACTIONS(9583),
    [anon_sym_POUNDendif] = ACTIONS(9583),
    [anon_sym_POUNDENDIF] = ACTIONS(9583),
    [anon_sym_POUNDEndif] = ACTIONS(9583),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9583),
    [sym_trigger_keyword] = ACTIONS(9583),
    [sym_var_keyword] = ACTIONS(9583),
    [sym_local_keyword] = ACTIONS(9583),
    [sym_internal_keyword] = ACTIONS(9583),
    [sym_protected_keyword] = ACTIONS(9583),
    [sym_event_keyword] = ACTIONS(9583),
    [sym_fields_keyword] = ACTIONS(9583),
    [sym_keys_keyword] = ACTIONS(9583),
    [sym_fieldgroups_keyword] = ACTIONS(9583),
    [sym_actions_keyword] = ACTIONS(9583),
    [sym_layout_keyword] = ACTIONS(9583),
    [sym_area_keyword] = ACTIONS(9583),
    [sym_group_keyword] = ACTIONS(9583),
    [sym_repeater_keyword] = ACTIONS(9583),
    [sym_cuegroup_keyword] = ACTIONS(9583),
    [sym_fixed_keyword] = ACTIONS(9583),
    [sym_grid_keyword] = ACTIONS(9583),
    [sym_part_keyword] = ACTIONS(9583),
    [sym_systempart_keyword] = ACTIONS(9583),
    [sym_usercontrol_keyword] = ACTIONS(9583),
    [sym_dataset_keyword] = ACTIONS(9583),
    [sym_elements_keyword] = ACTIONS(9583),
    [sym_dataitem_keyword] = ACTIONS(9583),
    [sym_column_keyword] = ACTIONS(9583),
    [sym_filter_keyword] = ACTIONS(9583),
    [sym_labels_keyword] = ACTIONS(9583),
    [sym_rendering_keyword] = ACTIONS(9583),
    [sym_requestpage_keyword] = ACTIONS(9583),
    [sym_schema_keyword] = ACTIONS(9583),
    [sym_views_keyword] = ACTIONS(9583),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9583),
    [sym_preproc_open] = ACTIONS(9583),
    [sym_preproc_close] = ACTIONS(9583),
  },
  [STATE(3551)] = {
    [anon_sym_SEMI] = ACTIONS(9587),
    [aux_sym_where_condition_token1] = ACTIONS(9589),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9587),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9587),
    [anon_sym_LBRACK] = ACTIONS(9587),
    [aux_sym_basic_type_token6] = ACTIONS(9589),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9587),
    [aux_sym_addafter_modification_token1] = ACTIONS(9587),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9587),
    [aux_sym_modify_modification_token1] = ACTIONS(9587),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9587),
    [aux_sym_movelast_modification_token1] = ACTIONS(9587),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9587),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9587),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9587),
    [anon_sym_POUNDif] = ACTIONS(9587),
    [anon_sym_POUNDIF] = ACTIONS(9587),
    [anon_sym_POUNDIf] = ACTIONS(9587),
    [anon_sym_POUNDelif] = ACTIONS(9587),
    [anon_sym_POUNDELIF] = ACTIONS(9587),
    [anon_sym_POUNDElif] = ACTIONS(9587),
    [anon_sym_POUNDelse] = ACTIONS(9587),
    [anon_sym_POUNDELSE] = ACTIONS(9587),
    [anon_sym_POUNDElse] = ACTIONS(9587),
    [anon_sym_POUNDendif] = ACTIONS(9587),
    [anon_sym_POUNDENDIF] = ACTIONS(9587),
    [anon_sym_POUNDEndif] = ACTIONS(9587),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9587),
    [sym_trigger_keyword] = ACTIONS(9587),
    [sym_var_keyword] = ACTIONS(9587),
    [sym_local_keyword] = ACTIONS(9587),
    [sym_internal_keyword] = ACTIONS(9587),
    [sym_protected_keyword] = ACTIONS(9587),
    [sym_event_keyword] = ACTIONS(9587),
    [sym_fields_keyword] = ACTIONS(9587),
    [sym_keys_keyword] = ACTIONS(9587),
    [sym_fieldgroups_keyword] = ACTIONS(9587),
    [sym_actions_keyword] = ACTIONS(9587),
    [sym_layout_keyword] = ACTIONS(9587),
    [sym_area_keyword] = ACTIONS(9587),
    [sym_group_keyword] = ACTIONS(9587),
    [sym_repeater_keyword] = ACTIONS(9587),
    [sym_cuegroup_keyword] = ACTIONS(9587),
    [sym_fixed_keyword] = ACTIONS(9587),
    [sym_grid_keyword] = ACTIONS(9587),
    [sym_part_keyword] = ACTIONS(9587),
    [sym_systempart_keyword] = ACTIONS(9587),
    [sym_usercontrol_keyword] = ACTIONS(9587),
    [sym_dataset_keyword] = ACTIONS(9587),
    [sym_elements_keyword] = ACTIONS(9587),
    [sym_dataitem_keyword] = ACTIONS(9587),
    [sym_column_keyword] = ACTIONS(9587),
    [sym_filter_keyword] = ACTIONS(9587),
    [sym_labels_keyword] = ACTIONS(9587),
    [sym_rendering_keyword] = ACTIONS(9587),
    [sym_requestpage_keyword] = ACTIONS(9587),
    [sym_schema_keyword] = ACTIONS(9587),
    [sym_views_keyword] = ACTIONS(9587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9587),
    [sym_preproc_open] = ACTIONS(9587),
    [sym_preproc_close] = ACTIONS(9587),
  },
  [STATE(3552)] = {
    [anon_sym_SEMI] = ACTIONS(9591),
    [aux_sym_where_condition_token1] = ACTIONS(9593),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9591),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9591),
    [anon_sym_LBRACK] = ACTIONS(9591),
    [aux_sym_basic_type_token6] = ACTIONS(9593),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9591),
    [aux_sym_addafter_modification_token1] = ACTIONS(9591),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9591),
    [aux_sym_modify_modification_token1] = ACTIONS(9591),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9591),
    [aux_sym_movelast_modification_token1] = ACTIONS(9591),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9591),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9591),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9591),
    [anon_sym_POUNDif] = ACTIONS(9591),
    [anon_sym_POUNDIF] = ACTIONS(9591),
    [anon_sym_POUNDIf] = ACTIONS(9591),
    [anon_sym_POUNDelif] = ACTIONS(9591),
    [anon_sym_POUNDELIF] = ACTIONS(9591),
    [anon_sym_POUNDElif] = ACTIONS(9591),
    [anon_sym_POUNDelse] = ACTIONS(9591),
    [anon_sym_POUNDELSE] = ACTIONS(9591),
    [anon_sym_POUNDElse] = ACTIONS(9591),
    [anon_sym_POUNDendif] = ACTIONS(9591),
    [anon_sym_POUNDENDIF] = ACTIONS(9591),
    [anon_sym_POUNDEndif] = ACTIONS(9591),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9591),
    [sym_trigger_keyword] = ACTIONS(9591),
    [sym_var_keyword] = ACTIONS(9591),
    [sym_local_keyword] = ACTIONS(9591),
    [sym_internal_keyword] = ACTIONS(9591),
    [sym_protected_keyword] = ACTIONS(9591),
    [sym_event_keyword] = ACTIONS(9591),
    [sym_fields_keyword] = ACTIONS(9591),
    [sym_keys_keyword] = ACTIONS(9591),
    [sym_fieldgroups_keyword] = ACTIONS(9591),
    [sym_actions_keyword] = ACTIONS(9591),
    [sym_layout_keyword] = ACTIONS(9591),
    [sym_area_keyword] = ACTIONS(9591),
    [sym_group_keyword] = ACTIONS(9591),
    [sym_repeater_keyword] = ACTIONS(9591),
    [sym_cuegroup_keyword] = ACTIONS(9591),
    [sym_fixed_keyword] = ACTIONS(9591),
    [sym_grid_keyword] = ACTIONS(9591),
    [sym_part_keyword] = ACTIONS(9591),
    [sym_systempart_keyword] = ACTIONS(9591),
    [sym_usercontrol_keyword] = ACTIONS(9591),
    [sym_dataset_keyword] = ACTIONS(9591),
    [sym_elements_keyword] = ACTIONS(9591),
    [sym_dataitem_keyword] = ACTIONS(9591),
    [sym_column_keyword] = ACTIONS(9591),
    [sym_filter_keyword] = ACTIONS(9591),
    [sym_labels_keyword] = ACTIONS(9591),
    [sym_rendering_keyword] = ACTIONS(9591),
    [sym_requestpage_keyword] = ACTIONS(9591),
    [sym_schema_keyword] = ACTIONS(9591),
    [sym_views_keyword] = ACTIONS(9591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9591),
    [sym_preproc_open] = ACTIONS(9591),
    [sym_preproc_close] = ACTIONS(9591),
  },
  [STATE(3553)] = {
    [anon_sym_SEMI] = ACTIONS(9595),
    [aux_sym_where_condition_token1] = ACTIONS(9597),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9595),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9595),
    [anon_sym_LBRACK] = ACTIONS(9595),
    [aux_sym_basic_type_token6] = ACTIONS(9597),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9595),
    [aux_sym_addafter_modification_token1] = ACTIONS(9595),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9595),
    [aux_sym_modify_modification_token1] = ACTIONS(9595),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9595),
    [aux_sym_movelast_modification_token1] = ACTIONS(9595),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9595),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9595),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9595),
    [anon_sym_POUNDif] = ACTIONS(9595),
    [anon_sym_POUNDIF] = ACTIONS(9595),
    [anon_sym_POUNDIf] = ACTIONS(9595),
    [anon_sym_POUNDelif] = ACTIONS(9595),
    [anon_sym_POUNDELIF] = ACTIONS(9595),
    [anon_sym_POUNDElif] = ACTIONS(9595),
    [anon_sym_POUNDelse] = ACTIONS(9595),
    [anon_sym_POUNDELSE] = ACTIONS(9595),
    [anon_sym_POUNDElse] = ACTIONS(9595),
    [anon_sym_POUNDendif] = ACTIONS(9595),
    [anon_sym_POUNDENDIF] = ACTIONS(9595),
    [anon_sym_POUNDEndif] = ACTIONS(9595),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9595),
    [sym_trigger_keyword] = ACTIONS(9595),
    [sym_var_keyword] = ACTIONS(9595),
    [sym_local_keyword] = ACTIONS(9595),
    [sym_internal_keyword] = ACTIONS(9595),
    [sym_protected_keyword] = ACTIONS(9595),
    [sym_event_keyword] = ACTIONS(9595),
    [sym_fields_keyword] = ACTIONS(9595),
    [sym_keys_keyword] = ACTIONS(9595),
    [sym_fieldgroups_keyword] = ACTIONS(9595),
    [sym_actions_keyword] = ACTIONS(9595),
    [sym_layout_keyword] = ACTIONS(9595),
    [sym_area_keyword] = ACTIONS(9595),
    [sym_group_keyword] = ACTIONS(9595),
    [sym_repeater_keyword] = ACTIONS(9595),
    [sym_cuegroup_keyword] = ACTIONS(9595),
    [sym_fixed_keyword] = ACTIONS(9595),
    [sym_grid_keyword] = ACTIONS(9595),
    [sym_part_keyword] = ACTIONS(9595),
    [sym_systempart_keyword] = ACTIONS(9595),
    [sym_usercontrol_keyword] = ACTIONS(9595),
    [sym_dataset_keyword] = ACTIONS(9595),
    [sym_elements_keyword] = ACTIONS(9595),
    [sym_dataitem_keyword] = ACTIONS(9595),
    [sym_column_keyword] = ACTIONS(9595),
    [sym_filter_keyword] = ACTIONS(9595),
    [sym_labels_keyword] = ACTIONS(9595),
    [sym_rendering_keyword] = ACTIONS(9595),
    [sym_requestpage_keyword] = ACTIONS(9595),
    [sym_schema_keyword] = ACTIONS(9595),
    [sym_views_keyword] = ACTIONS(9595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9595),
    [sym_preproc_open] = ACTIONS(9595),
    [sym_preproc_close] = ACTIONS(9595),
  },
  [STATE(3554)] = {
    [anon_sym_SEMI] = ACTIONS(9599),
    [aux_sym_where_condition_token1] = ACTIONS(9601),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9599),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9599),
    [anon_sym_LBRACK] = ACTIONS(9599),
    [aux_sym_basic_type_token6] = ACTIONS(9601),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9599),
    [aux_sym_addafter_modification_token1] = ACTIONS(9599),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9599),
    [aux_sym_modify_modification_token1] = ACTIONS(9599),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9599),
    [aux_sym_movelast_modification_token1] = ACTIONS(9599),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9599),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9599),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9599),
    [anon_sym_POUNDif] = ACTIONS(9599),
    [anon_sym_POUNDIF] = ACTIONS(9599),
    [anon_sym_POUNDIf] = ACTIONS(9599),
    [anon_sym_POUNDelif] = ACTIONS(9599),
    [anon_sym_POUNDELIF] = ACTIONS(9599),
    [anon_sym_POUNDElif] = ACTIONS(9599),
    [anon_sym_POUNDelse] = ACTIONS(9599),
    [anon_sym_POUNDELSE] = ACTIONS(9599),
    [anon_sym_POUNDElse] = ACTIONS(9599),
    [anon_sym_POUNDendif] = ACTIONS(9599),
    [anon_sym_POUNDENDIF] = ACTIONS(9599),
    [anon_sym_POUNDEndif] = ACTIONS(9599),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9599),
    [sym_trigger_keyword] = ACTIONS(9599),
    [sym_var_keyword] = ACTIONS(9599),
    [sym_local_keyword] = ACTIONS(9599),
    [sym_internal_keyword] = ACTIONS(9599),
    [sym_protected_keyword] = ACTIONS(9599),
    [sym_event_keyword] = ACTIONS(9599),
    [sym_fields_keyword] = ACTIONS(9599),
    [sym_keys_keyword] = ACTIONS(9599),
    [sym_fieldgroups_keyword] = ACTIONS(9599),
    [sym_actions_keyword] = ACTIONS(9599),
    [sym_layout_keyword] = ACTIONS(9599),
    [sym_area_keyword] = ACTIONS(9599),
    [sym_group_keyword] = ACTIONS(9599),
    [sym_repeater_keyword] = ACTIONS(9599),
    [sym_cuegroup_keyword] = ACTIONS(9599),
    [sym_fixed_keyword] = ACTIONS(9599),
    [sym_grid_keyword] = ACTIONS(9599),
    [sym_part_keyword] = ACTIONS(9599),
    [sym_systempart_keyword] = ACTIONS(9599),
    [sym_usercontrol_keyword] = ACTIONS(9599),
    [sym_dataset_keyword] = ACTIONS(9599),
    [sym_elements_keyword] = ACTIONS(9599),
    [sym_dataitem_keyword] = ACTIONS(9599),
    [sym_column_keyword] = ACTIONS(9599),
    [sym_filter_keyword] = ACTIONS(9599),
    [sym_labels_keyword] = ACTIONS(9599),
    [sym_rendering_keyword] = ACTIONS(9599),
    [sym_requestpage_keyword] = ACTIONS(9599),
    [sym_schema_keyword] = ACTIONS(9599),
    [sym_views_keyword] = ACTIONS(9599),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9599),
    [sym_preproc_open] = ACTIONS(9599),
    [sym_preproc_close] = ACTIONS(9599),
  },
  [STATE(3555)] = {
    [anon_sym_SEMI] = ACTIONS(9599),
    [aux_sym_where_condition_token1] = ACTIONS(9601),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9599),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9599),
    [anon_sym_LBRACK] = ACTIONS(9599),
    [aux_sym_basic_type_token6] = ACTIONS(9601),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9599),
    [aux_sym_addafter_modification_token1] = ACTIONS(9599),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9599),
    [aux_sym_modify_modification_token1] = ACTIONS(9599),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9599),
    [aux_sym_movelast_modification_token1] = ACTIONS(9599),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9599),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9599),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9599),
    [anon_sym_POUNDif] = ACTIONS(9599),
    [anon_sym_POUNDIF] = ACTIONS(9599),
    [anon_sym_POUNDIf] = ACTIONS(9599),
    [anon_sym_POUNDelif] = ACTIONS(9599),
    [anon_sym_POUNDELIF] = ACTIONS(9599),
    [anon_sym_POUNDElif] = ACTIONS(9599),
    [anon_sym_POUNDelse] = ACTIONS(9599),
    [anon_sym_POUNDELSE] = ACTIONS(9599),
    [anon_sym_POUNDElse] = ACTIONS(9599),
    [anon_sym_POUNDendif] = ACTIONS(9599),
    [anon_sym_POUNDENDIF] = ACTIONS(9599),
    [anon_sym_POUNDEndif] = ACTIONS(9599),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9599),
    [sym_trigger_keyword] = ACTIONS(9599),
    [sym_var_keyword] = ACTIONS(9599),
    [sym_local_keyword] = ACTIONS(9599),
    [sym_internal_keyword] = ACTIONS(9599),
    [sym_protected_keyword] = ACTIONS(9599),
    [sym_event_keyword] = ACTIONS(9599),
    [sym_fields_keyword] = ACTIONS(9599),
    [sym_keys_keyword] = ACTIONS(9599),
    [sym_fieldgroups_keyword] = ACTIONS(9599),
    [sym_actions_keyword] = ACTIONS(9599),
    [sym_layout_keyword] = ACTIONS(9599),
    [sym_area_keyword] = ACTIONS(9599),
    [sym_group_keyword] = ACTIONS(9599),
    [sym_repeater_keyword] = ACTIONS(9599),
    [sym_cuegroup_keyword] = ACTIONS(9599),
    [sym_fixed_keyword] = ACTIONS(9599),
    [sym_grid_keyword] = ACTIONS(9599),
    [sym_part_keyword] = ACTIONS(9599),
    [sym_systempart_keyword] = ACTIONS(9599),
    [sym_usercontrol_keyword] = ACTIONS(9599),
    [sym_dataset_keyword] = ACTIONS(9599),
    [sym_elements_keyword] = ACTIONS(9599),
    [sym_dataitem_keyword] = ACTIONS(9599),
    [sym_column_keyword] = ACTIONS(9599),
    [sym_filter_keyword] = ACTIONS(9599),
    [sym_labels_keyword] = ACTIONS(9599),
    [sym_rendering_keyword] = ACTIONS(9599),
    [sym_requestpage_keyword] = ACTIONS(9599),
    [sym_schema_keyword] = ACTIONS(9599),
    [sym_views_keyword] = ACTIONS(9599),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9599),
    [sym_preproc_open] = ACTIONS(9599),
    [sym_preproc_close] = ACTIONS(9599),
  },
  [STATE(3556)] = {
    [anon_sym_SEMI] = ACTIONS(9599),
    [aux_sym_where_condition_token1] = ACTIONS(9601),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9599),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9599),
    [anon_sym_LBRACK] = ACTIONS(9599),
    [aux_sym_basic_type_token6] = ACTIONS(9601),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9599),
    [aux_sym_addafter_modification_token1] = ACTIONS(9599),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9599),
    [aux_sym_modify_modification_token1] = ACTIONS(9599),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9599),
    [aux_sym_movelast_modification_token1] = ACTIONS(9599),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9599),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9599),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9599),
    [anon_sym_POUNDif] = ACTIONS(9599),
    [anon_sym_POUNDIF] = ACTIONS(9599),
    [anon_sym_POUNDIf] = ACTIONS(9599),
    [anon_sym_POUNDelif] = ACTIONS(9599),
    [anon_sym_POUNDELIF] = ACTIONS(9599),
    [anon_sym_POUNDElif] = ACTIONS(9599),
    [anon_sym_POUNDelse] = ACTIONS(9599),
    [anon_sym_POUNDELSE] = ACTIONS(9599),
    [anon_sym_POUNDElse] = ACTIONS(9599),
    [anon_sym_POUNDendif] = ACTIONS(9599),
    [anon_sym_POUNDENDIF] = ACTIONS(9599),
    [anon_sym_POUNDEndif] = ACTIONS(9599),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9599),
    [sym_trigger_keyword] = ACTIONS(9599),
    [sym_var_keyword] = ACTIONS(9599),
    [sym_local_keyword] = ACTIONS(9599),
    [sym_internal_keyword] = ACTIONS(9599),
    [sym_protected_keyword] = ACTIONS(9599),
    [sym_event_keyword] = ACTIONS(9599),
    [sym_fields_keyword] = ACTIONS(9599),
    [sym_keys_keyword] = ACTIONS(9599),
    [sym_fieldgroups_keyword] = ACTIONS(9599),
    [sym_actions_keyword] = ACTIONS(9599),
    [sym_layout_keyword] = ACTIONS(9599),
    [sym_area_keyword] = ACTIONS(9599),
    [sym_group_keyword] = ACTIONS(9599),
    [sym_repeater_keyword] = ACTIONS(9599),
    [sym_cuegroup_keyword] = ACTIONS(9599),
    [sym_fixed_keyword] = ACTIONS(9599),
    [sym_grid_keyword] = ACTIONS(9599),
    [sym_part_keyword] = ACTIONS(9599),
    [sym_systempart_keyword] = ACTIONS(9599),
    [sym_usercontrol_keyword] = ACTIONS(9599),
    [sym_dataset_keyword] = ACTIONS(9599),
    [sym_elements_keyword] = ACTIONS(9599),
    [sym_dataitem_keyword] = ACTIONS(9599),
    [sym_column_keyword] = ACTIONS(9599),
    [sym_filter_keyword] = ACTIONS(9599),
    [sym_labels_keyword] = ACTIONS(9599),
    [sym_rendering_keyword] = ACTIONS(9599),
    [sym_requestpage_keyword] = ACTIONS(9599),
    [sym_schema_keyword] = ACTIONS(9599),
    [sym_views_keyword] = ACTIONS(9599),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9599),
    [sym_preproc_open] = ACTIONS(9599),
    [sym_preproc_close] = ACTIONS(9599),
  },
  [STATE(3557)] = {
    [anon_sym_SEMI] = ACTIONS(9599),
    [aux_sym_where_condition_token1] = ACTIONS(9601),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9599),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9599),
    [anon_sym_LBRACK] = ACTIONS(9599),
    [aux_sym_basic_type_token6] = ACTIONS(9601),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9599),
    [aux_sym_addafter_modification_token1] = ACTIONS(9599),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9599),
    [aux_sym_modify_modification_token1] = ACTIONS(9599),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9599),
    [aux_sym_movelast_modification_token1] = ACTIONS(9599),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9599),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9599),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9599),
    [anon_sym_POUNDif] = ACTIONS(9599),
    [anon_sym_POUNDIF] = ACTIONS(9599),
    [anon_sym_POUNDIf] = ACTIONS(9599),
    [anon_sym_POUNDelif] = ACTIONS(9599),
    [anon_sym_POUNDELIF] = ACTIONS(9599),
    [anon_sym_POUNDElif] = ACTIONS(9599),
    [anon_sym_POUNDelse] = ACTIONS(9599),
    [anon_sym_POUNDELSE] = ACTIONS(9599),
    [anon_sym_POUNDElse] = ACTIONS(9599),
    [anon_sym_POUNDendif] = ACTIONS(9599),
    [anon_sym_POUNDENDIF] = ACTIONS(9599),
    [anon_sym_POUNDEndif] = ACTIONS(9599),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9599),
    [sym_trigger_keyword] = ACTIONS(9599),
    [sym_var_keyword] = ACTIONS(9599),
    [sym_local_keyword] = ACTIONS(9599),
    [sym_internal_keyword] = ACTIONS(9599),
    [sym_protected_keyword] = ACTIONS(9599),
    [sym_event_keyword] = ACTIONS(9599),
    [sym_fields_keyword] = ACTIONS(9599),
    [sym_keys_keyword] = ACTIONS(9599),
    [sym_fieldgroups_keyword] = ACTIONS(9599),
    [sym_actions_keyword] = ACTIONS(9599),
    [sym_layout_keyword] = ACTIONS(9599),
    [sym_area_keyword] = ACTIONS(9599),
    [sym_group_keyword] = ACTIONS(9599),
    [sym_repeater_keyword] = ACTIONS(9599),
    [sym_cuegroup_keyword] = ACTIONS(9599),
    [sym_fixed_keyword] = ACTIONS(9599),
    [sym_grid_keyword] = ACTIONS(9599),
    [sym_part_keyword] = ACTIONS(9599),
    [sym_systempart_keyword] = ACTIONS(9599),
    [sym_usercontrol_keyword] = ACTIONS(9599),
    [sym_dataset_keyword] = ACTIONS(9599),
    [sym_elements_keyword] = ACTIONS(9599),
    [sym_dataitem_keyword] = ACTIONS(9599),
    [sym_column_keyword] = ACTIONS(9599),
    [sym_filter_keyword] = ACTIONS(9599),
    [sym_labels_keyword] = ACTIONS(9599),
    [sym_rendering_keyword] = ACTIONS(9599),
    [sym_requestpage_keyword] = ACTIONS(9599),
    [sym_schema_keyword] = ACTIONS(9599),
    [sym_views_keyword] = ACTIONS(9599),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9599),
    [sym_preproc_open] = ACTIONS(9599),
    [sym_preproc_close] = ACTIONS(9599),
  },
  [STATE(3558)] = {
    [anon_sym_SEMI] = ACTIONS(9603),
    [aux_sym_where_condition_token1] = ACTIONS(9605),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9603),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9603),
    [anon_sym_LBRACK] = ACTIONS(9603),
    [aux_sym_basic_type_token6] = ACTIONS(9605),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9603),
    [aux_sym_addafter_modification_token1] = ACTIONS(9603),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9603),
    [aux_sym_modify_modification_token1] = ACTIONS(9603),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9603),
    [aux_sym_movelast_modification_token1] = ACTIONS(9603),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9603),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9603),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9603),
    [anon_sym_POUNDif] = ACTIONS(9603),
    [anon_sym_POUNDIF] = ACTIONS(9603),
    [anon_sym_POUNDIf] = ACTIONS(9603),
    [anon_sym_POUNDelif] = ACTIONS(9603),
    [anon_sym_POUNDELIF] = ACTIONS(9603),
    [anon_sym_POUNDElif] = ACTIONS(9603),
    [anon_sym_POUNDelse] = ACTIONS(9603),
    [anon_sym_POUNDELSE] = ACTIONS(9603),
    [anon_sym_POUNDElse] = ACTIONS(9603),
    [anon_sym_POUNDendif] = ACTIONS(9603),
    [anon_sym_POUNDENDIF] = ACTIONS(9603),
    [anon_sym_POUNDEndif] = ACTIONS(9603),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9603),
    [sym_trigger_keyword] = ACTIONS(9603),
    [sym_var_keyword] = ACTIONS(9603),
    [sym_local_keyword] = ACTIONS(9603),
    [sym_internal_keyword] = ACTIONS(9603),
    [sym_protected_keyword] = ACTIONS(9603),
    [sym_event_keyword] = ACTIONS(9603),
    [sym_fields_keyword] = ACTIONS(9603),
    [sym_keys_keyword] = ACTIONS(9603),
    [sym_fieldgroups_keyword] = ACTIONS(9603),
    [sym_actions_keyword] = ACTIONS(9603),
    [sym_layout_keyword] = ACTIONS(9603),
    [sym_area_keyword] = ACTIONS(9603),
    [sym_group_keyword] = ACTIONS(9603),
    [sym_repeater_keyword] = ACTIONS(9603),
    [sym_cuegroup_keyword] = ACTIONS(9603),
    [sym_fixed_keyword] = ACTIONS(9603),
    [sym_grid_keyword] = ACTIONS(9603),
    [sym_part_keyword] = ACTIONS(9603),
    [sym_systempart_keyword] = ACTIONS(9603),
    [sym_usercontrol_keyword] = ACTIONS(9603),
    [sym_dataset_keyword] = ACTIONS(9603),
    [sym_elements_keyword] = ACTIONS(9603),
    [sym_dataitem_keyword] = ACTIONS(9603),
    [sym_column_keyword] = ACTIONS(9603),
    [sym_filter_keyword] = ACTIONS(9603),
    [sym_labels_keyword] = ACTIONS(9603),
    [sym_rendering_keyword] = ACTIONS(9603),
    [sym_requestpage_keyword] = ACTIONS(9603),
    [sym_schema_keyword] = ACTIONS(9603),
    [sym_views_keyword] = ACTIONS(9603),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9603),
    [sym_preproc_open] = ACTIONS(9603),
    [sym_preproc_close] = ACTIONS(9603),
  },
  [STATE(3559)] = {
    [anon_sym_SEMI] = ACTIONS(9603),
    [aux_sym_where_condition_token1] = ACTIONS(9605),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9603),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9603),
    [anon_sym_LBRACK] = ACTIONS(9603),
    [aux_sym_basic_type_token6] = ACTIONS(9605),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9603),
    [aux_sym_addafter_modification_token1] = ACTIONS(9603),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9603),
    [aux_sym_modify_modification_token1] = ACTIONS(9603),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9603),
    [aux_sym_movelast_modification_token1] = ACTIONS(9603),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9603),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9603),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9603),
    [anon_sym_POUNDif] = ACTIONS(9603),
    [anon_sym_POUNDIF] = ACTIONS(9603),
    [anon_sym_POUNDIf] = ACTIONS(9603),
    [anon_sym_POUNDelif] = ACTIONS(9603),
    [anon_sym_POUNDELIF] = ACTIONS(9603),
    [anon_sym_POUNDElif] = ACTIONS(9603),
    [anon_sym_POUNDelse] = ACTIONS(9603),
    [anon_sym_POUNDELSE] = ACTIONS(9603),
    [anon_sym_POUNDElse] = ACTIONS(9603),
    [anon_sym_POUNDendif] = ACTIONS(9603),
    [anon_sym_POUNDENDIF] = ACTIONS(9603),
    [anon_sym_POUNDEndif] = ACTIONS(9603),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9603),
    [sym_trigger_keyword] = ACTIONS(9603),
    [sym_var_keyword] = ACTIONS(9603),
    [sym_local_keyword] = ACTIONS(9603),
    [sym_internal_keyword] = ACTIONS(9603),
    [sym_protected_keyword] = ACTIONS(9603),
    [sym_event_keyword] = ACTIONS(9603),
    [sym_fields_keyword] = ACTIONS(9603),
    [sym_keys_keyword] = ACTIONS(9603),
    [sym_fieldgroups_keyword] = ACTIONS(9603),
    [sym_actions_keyword] = ACTIONS(9603),
    [sym_layout_keyword] = ACTIONS(9603),
    [sym_area_keyword] = ACTIONS(9603),
    [sym_group_keyword] = ACTIONS(9603),
    [sym_repeater_keyword] = ACTIONS(9603),
    [sym_cuegroup_keyword] = ACTIONS(9603),
    [sym_fixed_keyword] = ACTIONS(9603),
    [sym_grid_keyword] = ACTIONS(9603),
    [sym_part_keyword] = ACTIONS(9603),
    [sym_systempart_keyword] = ACTIONS(9603),
    [sym_usercontrol_keyword] = ACTIONS(9603),
    [sym_dataset_keyword] = ACTIONS(9603),
    [sym_elements_keyword] = ACTIONS(9603),
    [sym_dataitem_keyword] = ACTIONS(9603),
    [sym_column_keyword] = ACTIONS(9603),
    [sym_filter_keyword] = ACTIONS(9603),
    [sym_labels_keyword] = ACTIONS(9603),
    [sym_rendering_keyword] = ACTIONS(9603),
    [sym_requestpage_keyword] = ACTIONS(9603),
    [sym_schema_keyword] = ACTIONS(9603),
    [sym_views_keyword] = ACTIONS(9603),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9603),
    [sym_preproc_open] = ACTIONS(9603),
    [sym_preproc_close] = ACTIONS(9603),
  },
  [STATE(3560)] = {
    [anon_sym_SEMI] = ACTIONS(9603),
    [aux_sym_where_condition_token1] = ACTIONS(9605),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9603),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9603),
    [anon_sym_LBRACK] = ACTIONS(9603),
    [aux_sym_basic_type_token6] = ACTIONS(9605),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9603),
    [aux_sym_addafter_modification_token1] = ACTIONS(9603),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9603),
    [aux_sym_modify_modification_token1] = ACTIONS(9603),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9603),
    [aux_sym_movelast_modification_token1] = ACTIONS(9603),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9603),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9603),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9603),
    [anon_sym_POUNDif] = ACTIONS(9603),
    [anon_sym_POUNDIF] = ACTIONS(9603),
    [anon_sym_POUNDIf] = ACTIONS(9603),
    [anon_sym_POUNDelif] = ACTIONS(9603),
    [anon_sym_POUNDELIF] = ACTIONS(9603),
    [anon_sym_POUNDElif] = ACTIONS(9603),
    [anon_sym_POUNDelse] = ACTIONS(9603),
    [anon_sym_POUNDELSE] = ACTIONS(9603),
    [anon_sym_POUNDElse] = ACTIONS(9603),
    [anon_sym_POUNDendif] = ACTIONS(9603),
    [anon_sym_POUNDENDIF] = ACTIONS(9603),
    [anon_sym_POUNDEndif] = ACTIONS(9603),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9603),
    [sym_trigger_keyword] = ACTIONS(9603),
    [sym_var_keyword] = ACTIONS(9603),
    [sym_local_keyword] = ACTIONS(9603),
    [sym_internal_keyword] = ACTIONS(9603),
    [sym_protected_keyword] = ACTIONS(9603),
    [sym_event_keyword] = ACTIONS(9603),
    [sym_fields_keyword] = ACTIONS(9603),
    [sym_keys_keyword] = ACTIONS(9603),
    [sym_fieldgroups_keyword] = ACTIONS(9603),
    [sym_actions_keyword] = ACTIONS(9603),
    [sym_layout_keyword] = ACTIONS(9603),
    [sym_area_keyword] = ACTIONS(9603),
    [sym_group_keyword] = ACTIONS(9603),
    [sym_repeater_keyword] = ACTIONS(9603),
    [sym_cuegroup_keyword] = ACTIONS(9603),
    [sym_fixed_keyword] = ACTIONS(9603),
    [sym_grid_keyword] = ACTIONS(9603),
    [sym_part_keyword] = ACTIONS(9603),
    [sym_systempart_keyword] = ACTIONS(9603),
    [sym_usercontrol_keyword] = ACTIONS(9603),
    [sym_dataset_keyword] = ACTIONS(9603),
    [sym_elements_keyword] = ACTIONS(9603),
    [sym_dataitem_keyword] = ACTIONS(9603),
    [sym_column_keyword] = ACTIONS(9603),
    [sym_filter_keyword] = ACTIONS(9603),
    [sym_labels_keyword] = ACTIONS(9603),
    [sym_rendering_keyword] = ACTIONS(9603),
    [sym_requestpage_keyword] = ACTIONS(9603),
    [sym_schema_keyword] = ACTIONS(9603),
    [sym_views_keyword] = ACTIONS(9603),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9603),
    [sym_preproc_open] = ACTIONS(9603),
    [sym_preproc_close] = ACTIONS(9603),
  },
  [STATE(3561)] = {
    [anon_sym_SEMI] = ACTIONS(9603),
    [aux_sym_where_condition_token1] = ACTIONS(9605),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9603),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9603),
    [anon_sym_LBRACK] = ACTIONS(9603),
    [aux_sym_basic_type_token6] = ACTIONS(9605),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9603),
    [aux_sym_addafter_modification_token1] = ACTIONS(9603),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9603),
    [aux_sym_modify_modification_token1] = ACTIONS(9603),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9603),
    [aux_sym_movelast_modification_token1] = ACTIONS(9603),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9603),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9603),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9603),
    [anon_sym_POUNDif] = ACTIONS(9603),
    [anon_sym_POUNDIF] = ACTIONS(9603),
    [anon_sym_POUNDIf] = ACTIONS(9603),
    [anon_sym_POUNDelif] = ACTIONS(9603),
    [anon_sym_POUNDELIF] = ACTIONS(9603),
    [anon_sym_POUNDElif] = ACTIONS(9603),
    [anon_sym_POUNDelse] = ACTIONS(9603),
    [anon_sym_POUNDELSE] = ACTIONS(9603),
    [anon_sym_POUNDElse] = ACTIONS(9603),
    [anon_sym_POUNDendif] = ACTIONS(9603),
    [anon_sym_POUNDENDIF] = ACTIONS(9603),
    [anon_sym_POUNDEndif] = ACTIONS(9603),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9603),
    [sym_trigger_keyword] = ACTIONS(9603),
    [sym_var_keyword] = ACTIONS(9603),
    [sym_local_keyword] = ACTIONS(9603),
    [sym_internal_keyword] = ACTIONS(9603),
    [sym_protected_keyword] = ACTIONS(9603),
    [sym_event_keyword] = ACTIONS(9603),
    [sym_fields_keyword] = ACTIONS(9603),
    [sym_keys_keyword] = ACTIONS(9603),
    [sym_fieldgroups_keyword] = ACTIONS(9603),
    [sym_actions_keyword] = ACTIONS(9603),
    [sym_layout_keyword] = ACTIONS(9603),
    [sym_area_keyword] = ACTIONS(9603),
    [sym_group_keyword] = ACTIONS(9603),
    [sym_repeater_keyword] = ACTIONS(9603),
    [sym_cuegroup_keyword] = ACTIONS(9603),
    [sym_fixed_keyword] = ACTIONS(9603),
    [sym_grid_keyword] = ACTIONS(9603),
    [sym_part_keyword] = ACTIONS(9603),
    [sym_systempart_keyword] = ACTIONS(9603),
    [sym_usercontrol_keyword] = ACTIONS(9603),
    [sym_dataset_keyword] = ACTIONS(9603),
    [sym_elements_keyword] = ACTIONS(9603),
    [sym_dataitem_keyword] = ACTIONS(9603),
    [sym_column_keyword] = ACTIONS(9603),
    [sym_filter_keyword] = ACTIONS(9603),
    [sym_labels_keyword] = ACTIONS(9603),
    [sym_rendering_keyword] = ACTIONS(9603),
    [sym_requestpage_keyword] = ACTIONS(9603),
    [sym_schema_keyword] = ACTIONS(9603),
    [sym_views_keyword] = ACTIONS(9603),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9603),
    [sym_preproc_open] = ACTIONS(9603),
    [sym_preproc_close] = ACTIONS(9603),
  },
  [STATE(3562)] = {
    [anon_sym_SEMI] = ACTIONS(9607),
    [aux_sym_where_condition_token1] = ACTIONS(9609),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9607),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9607),
    [anon_sym_LBRACK] = ACTIONS(9607),
    [aux_sym_basic_type_token6] = ACTIONS(9609),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9607),
    [aux_sym_addafter_modification_token1] = ACTIONS(9607),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9607),
    [aux_sym_modify_modification_token1] = ACTIONS(9607),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9607),
    [aux_sym_movelast_modification_token1] = ACTIONS(9607),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9607),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9607),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9607),
    [anon_sym_POUNDif] = ACTIONS(9607),
    [anon_sym_POUNDIF] = ACTIONS(9607),
    [anon_sym_POUNDIf] = ACTIONS(9607),
    [anon_sym_POUNDelif] = ACTIONS(9607),
    [anon_sym_POUNDELIF] = ACTIONS(9607),
    [anon_sym_POUNDElif] = ACTIONS(9607),
    [anon_sym_POUNDelse] = ACTIONS(9607),
    [anon_sym_POUNDELSE] = ACTIONS(9607),
    [anon_sym_POUNDElse] = ACTIONS(9607),
    [anon_sym_POUNDendif] = ACTIONS(9607),
    [anon_sym_POUNDENDIF] = ACTIONS(9607),
    [anon_sym_POUNDEndif] = ACTIONS(9607),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9607),
    [sym_trigger_keyword] = ACTIONS(9607),
    [sym_var_keyword] = ACTIONS(9607),
    [sym_local_keyword] = ACTIONS(9607),
    [sym_internal_keyword] = ACTIONS(9607),
    [sym_protected_keyword] = ACTIONS(9607),
    [sym_event_keyword] = ACTIONS(9607),
    [sym_fields_keyword] = ACTIONS(9607),
    [sym_keys_keyword] = ACTIONS(9607),
    [sym_fieldgroups_keyword] = ACTIONS(9607),
    [sym_actions_keyword] = ACTIONS(9607),
    [sym_layout_keyword] = ACTIONS(9607),
    [sym_area_keyword] = ACTIONS(9607),
    [sym_group_keyword] = ACTIONS(9607),
    [sym_repeater_keyword] = ACTIONS(9607),
    [sym_cuegroup_keyword] = ACTIONS(9607),
    [sym_fixed_keyword] = ACTIONS(9607),
    [sym_grid_keyword] = ACTIONS(9607),
    [sym_part_keyword] = ACTIONS(9607),
    [sym_systempart_keyword] = ACTIONS(9607),
    [sym_usercontrol_keyword] = ACTIONS(9607),
    [sym_dataset_keyword] = ACTIONS(9607),
    [sym_elements_keyword] = ACTIONS(9607),
    [sym_dataitem_keyword] = ACTIONS(9607),
    [sym_column_keyword] = ACTIONS(9607),
    [sym_filter_keyword] = ACTIONS(9607),
    [sym_labels_keyword] = ACTIONS(9607),
    [sym_rendering_keyword] = ACTIONS(9607),
    [sym_requestpage_keyword] = ACTIONS(9607),
    [sym_schema_keyword] = ACTIONS(9607),
    [sym_views_keyword] = ACTIONS(9607),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9607),
    [sym_preproc_open] = ACTIONS(9607),
    [sym_preproc_close] = ACTIONS(9607),
  },
  [STATE(3563)] = {
    [anon_sym_SEMI] = ACTIONS(9607),
    [aux_sym_where_condition_token1] = ACTIONS(9609),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9607),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9607),
    [anon_sym_LBRACK] = ACTIONS(9607),
    [aux_sym_basic_type_token6] = ACTIONS(9609),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9607),
    [aux_sym_addafter_modification_token1] = ACTIONS(9607),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9607),
    [aux_sym_modify_modification_token1] = ACTIONS(9607),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9607),
    [aux_sym_movelast_modification_token1] = ACTIONS(9607),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9607),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9607),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9607),
    [anon_sym_POUNDif] = ACTIONS(9607),
    [anon_sym_POUNDIF] = ACTIONS(9607),
    [anon_sym_POUNDIf] = ACTIONS(9607),
    [anon_sym_POUNDelif] = ACTIONS(9607),
    [anon_sym_POUNDELIF] = ACTIONS(9607),
    [anon_sym_POUNDElif] = ACTIONS(9607),
    [anon_sym_POUNDelse] = ACTIONS(9607),
    [anon_sym_POUNDELSE] = ACTIONS(9607),
    [anon_sym_POUNDElse] = ACTIONS(9607),
    [anon_sym_POUNDendif] = ACTIONS(9607),
    [anon_sym_POUNDENDIF] = ACTIONS(9607),
    [anon_sym_POUNDEndif] = ACTIONS(9607),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9607),
    [sym_trigger_keyword] = ACTIONS(9607),
    [sym_var_keyword] = ACTIONS(9607),
    [sym_local_keyword] = ACTIONS(9607),
    [sym_internal_keyword] = ACTIONS(9607),
    [sym_protected_keyword] = ACTIONS(9607),
    [sym_event_keyword] = ACTIONS(9607),
    [sym_fields_keyword] = ACTIONS(9607),
    [sym_keys_keyword] = ACTIONS(9607),
    [sym_fieldgroups_keyword] = ACTIONS(9607),
    [sym_actions_keyword] = ACTIONS(9607),
    [sym_layout_keyword] = ACTIONS(9607),
    [sym_area_keyword] = ACTIONS(9607),
    [sym_group_keyword] = ACTIONS(9607),
    [sym_repeater_keyword] = ACTIONS(9607),
    [sym_cuegroup_keyword] = ACTIONS(9607),
    [sym_fixed_keyword] = ACTIONS(9607),
    [sym_grid_keyword] = ACTIONS(9607),
    [sym_part_keyword] = ACTIONS(9607),
    [sym_systempart_keyword] = ACTIONS(9607),
    [sym_usercontrol_keyword] = ACTIONS(9607),
    [sym_dataset_keyword] = ACTIONS(9607),
    [sym_elements_keyword] = ACTIONS(9607),
    [sym_dataitem_keyword] = ACTIONS(9607),
    [sym_column_keyword] = ACTIONS(9607),
    [sym_filter_keyword] = ACTIONS(9607),
    [sym_labels_keyword] = ACTIONS(9607),
    [sym_rendering_keyword] = ACTIONS(9607),
    [sym_requestpage_keyword] = ACTIONS(9607),
    [sym_schema_keyword] = ACTIONS(9607),
    [sym_views_keyword] = ACTIONS(9607),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9607),
    [sym_preproc_open] = ACTIONS(9607),
    [sym_preproc_close] = ACTIONS(9607),
  },
  [STATE(3564)] = {
    [anon_sym_SEMI] = ACTIONS(9611),
    [aux_sym_where_condition_token1] = ACTIONS(9613),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9611),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9611),
    [anon_sym_LBRACK] = ACTIONS(9611),
    [aux_sym_basic_type_token6] = ACTIONS(9613),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9611),
    [aux_sym_addafter_modification_token1] = ACTIONS(9611),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9611),
    [aux_sym_modify_modification_token1] = ACTIONS(9611),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9611),
    [aux_sym_movelast_modification_token1] = ACTIONS(9611),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9611),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9611),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9611),
    [anon_sym_POUNDif] = ACTIONS(9611),
    [anon_sym_POUNDIF] = ACTIONS(9611),
    [anon_sym_POUNDIf] = ACTIONS(9611),
    [anon_sym_POUNDelif] = ACTIONS(9611),
    [anon_sym_POUNDELIF] = ACTIONS(9611),
    [anon_sym_POUNDElif] = ACTIONS(9611),
    [anon_sym_POUNDelse] = ACTIONS(9611),
    [anon_sym_POUNDELSE] = ACTIONS(9611),
    [anon_sym_POUNDElse] = ACTIONS(9611),
    [anon_sym_POUNDendif] = ACTIONS(9611),
    [anon_sym_POUNDENDIF] = ACTIONS(9611),
    [anon_sym_POUNDEndif] = ACTIONS(9611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9611),
    [sym_trigger_keyword] = ACTIONS(9611),
    [sym_var_keyword] = ACTIONS(9611),
    [sym_local_keyword] = ACTIONS(9611),
    [sym_internal_keyword] = ACTIONS(9611),
    [sym_protected_keyword] = ACTIONS(9611),
    [sym_event_keyword] = ACTIONS(9611),
    [sym_fields_keyword] = ACTIONS(9611),
    [sym_keys_keyword] = ACTIONS(9611),
    [sym_fieldgroups_keyword] = ACTIONS(9611),
    [sym_actions_keyword] = ACTIONS(9611),
    [sym_layout_keyword] = ACTIONS(9611),
    [sym_area_keyword] = ACTIONS(9611),
    [sym_group_keyword] = ACTIONS(9611),
    [sym_repeater_keyword] = ACTIONS(9611),
    [sym_cuegroup_keyword] = ACTIONS(9611),
    [sym_fixed_keyword] = ACTIONS(9611),
    [sym_grid_keyword] = ACTIONS(9611),
    [sym_part_keyword] = ACTIONS(9611),
    [sym_systempart_keyword] = ACTIONS(9611),
    [sym_usercontrol_keyword] = ACTIONS(9611),
    [sym_dataset_keyword] = ACTIONS(9611),
    [sym_elements_keyword] = ACTIONS(9611),
    [sym_dataitem_keyword] = ACTIONS(9611),
    [sym_column_keyword] = ACTIONS(9611),
    [sym_filter_keyword] = ACTIONS(9611),
    [sym_labels_keyword] = ACTIONS(9611),
    [sym_rendering_keyword] = ACTIONS(9611),
    [sym_requestpage_keyword] = ACTIONS(9611),
    [sym_schema_keyword] = ACTIONS(9611),
    [sym_views_keyword] = ACTIONS(9611),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9611),
    [sym_preproc_open] = ACTIONS(9611),
    [sym_preproc_close] = ACTIONS(9611),
  },
  [STATE(3565)] = {
    [anon_sym_SEMI] = ACTIONS(9611),
    [aux_sym_where_condition_token1] = ACTIONS(9613),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9611),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9611),
    [anon_sym_LBRACK] = ACTIONS(9611),
    [aux_sym_basic_type_token6] = ACTIONS(9613),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9611),
    [aux_sym_addafter_modification_token1] = ACTIONS(9611),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9611),
    [aux_sym_modify_modification_token1] = ACTIONS(9611),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9611),
    [aux_sym_movelast_modification_token1] = ACTIONS(9611),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9611),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9611),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9611),
    [anon_sym_POUNDif] = ACTIONS(9611),
    [anon_sym_POUNDIF] = ACTIONS(9611),
    [anon_sym_POUNDIf] = ACTIONS(9611),
    [anon_sym_POUNDelif] = ACTIONS(9611),
    [anon_sym_POUNDELIF] = ACTIONS(9611),
    [anon_sym_POUNDElif] = ACTIONS(9611),
    [anon_sym_POUNDelse] = ACTIONS(9611),
    [anon_sym_POUNDELSE] = ACTIONS(9611),
    [anon_sym_POUNDElse] = ACTIONS(9611),
    [anon_sym_POUNDendif] = ACTIONS(9611),
    [anon_sym_POUNDENDIF] = ACTIONS(9611),
    [anon_sym_POUNDEndif] = ACTIONS(9611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9611),
    [sym_trigger_keyword] = ACTIONS(9611),
    [sym_var_keyword] = ACTIONS(9611),
    [sym_local_keyword] = ACTIONS(9611),
    [sym_internal_keyword] = ACTIONS(9611),
    [sym_protected_keyword] = ACTIONS(9611),
    [sym_event_keyword] = ACTIONS(9611),
    [sym_fields_keyword] = ACTIONS(9611),
    [sym_keys_keyword] = ACTIONS(9611),
    [sym_fieldgroups_keyword] = ACTIONS(9611),
    [sym_actions_keyword] = ACTIONS(9611),
    [sym_layout_keyword] = ACTIONS(9611),
    [sym_area_keyword] = ACTIONS(9611),
    [sym_group_keyword] = ACTIONS(9611),
    [sym_repeater_keyword] = ACTIONS(9611),
    [sym_cuegroup_keyword] = ACTIONS(9611),
    [sym_fixed_keyword] = ACTIONS(9611),
    [sym_grid_keyword] = ACTIONS(9611),
    [sym_part_keyword] = ACTIONS(9611),
    [sym_systempart_keyword] = ACTIONS(9611),
    [sym_usercontrol_keyword] = ACTIONS(9611),
    [sym_dataset_keyword] = ACTIONS(9611),
    [sym_elements_keyword] = ACTIONS(9611),
    [sym_dataitem_keyword] = ACTIONS(9611),
    [sym_column_keyword] = ACTIONS(9611),
    [sym_filter_keyword] = ACTIONS(9611),
    [sym_labels_keyword] = ACTIONS(9611),
    [sym_rendering_keyword] = ACTIONS(9611),
    [sym_requestpage_keyword] = ACTIONS(9611),
    [sym_schema_keyword] = ACTIONS(9611),
    [sym_views_keyword] = ACTIONS(9611),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9611),
    [sym_preproc_open] = ACTIONS(9611),
    [sym_preproc_close] = ACTIONS(9611),
  },
  [STATE(3566)] = {
    [anon_sym_SEMI] = ACTIONS(9615),
    [aux_sym_where_condition_token1] = ACTIONS(9617),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9615),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9615),
    [anon_sym_LBRACK] = ACTIONS(9615),
    [aux_sym_basic_type_token6] = ACTIONS(9617),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9615),
    [aux_sym_addafter_modification_token1] = ACTIONS(9615),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9615),
    [aux_sym_modify_modification_token1] = ACTIONS(9615),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9615),
    [aux_sym_movelast_modification_token1] = ACTIONS(9615),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9615),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9615),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9615),
    [anon_sym_POUNDif] = ACTIONS(9615),
    [anon_sym_POUNDIF] = ACTIONS(9615),
    [anon_sym_POUNDIf] = ACTIONS(9615),
    [anon_sym_POUNDelif] = ACTIONS(9615),
    [anon_sym_POUNDELIF] = ACTIONS(9615),
    [anon_sym_POUNDElif] = ACTIONS(9615),
    [anon_sym_POUNDelse] = ACTIONS(9615),
    [anon_sym_POUNDELSE] = ACTIONS(9615),
    [anon_sym_POUNDElse] = ACTIONS(9615),
    [anon_sym_POUNDendif] = ACTIONS(9615),
    [anon_sym_POUNDENDIF] = ACTIONS(9615),
    [anon_sym_POUNDEndif] = ACTIONS(9615),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9615),
    [sym_trigger_keyword] = ACTIONS(9615),
    [sym_var_keyword] = ACTIONS(9615),
    [sym_local_keyword] = ACTIONS(9615),
    [sym_internal_keyword] = ACTIONS(9615),
    [sym_protected_keyword] = ACTIONS(9615),
    [sym_event_keyword] = ACTIONS(9615),
    [sym_fields_keyword] = ACTIONS(9615),
    [sym_keys_keyword] = ACTIONS(9615),
    [sym_fieldgroups_keyword] = ACTIONS(9615),
    [sym_actions_keyword] = ACTIONS(9615),
    [sym_layout_keyword] = ACTIONS(9615),
    [sym_area_keyword] = ACTIONS(9615),
    [sym_group_keyword] = ACTIONS(9615),
    [sym_repeater_keyword] = ACTIONS(9615),
    [sym_cuegroup_keyword] = ACTIONS(9615),
    [sym_fixed_keyword] = ACTIONS(9615),
    [sym_grid_keyword] = ACTIONS(9615),
    [sym_part_keyword] = ACTIONS(9615),
    [sym_systempart_keyword] = ACTIONS(9615),
    [sym_usercontrol_keyword] = ACTIONS(9615),
    [sym_dataset_keyword] = ACTIONS(9615),
    [sym_elements_keyword] = ACTIONS(9615),
    [sym_dataitem_keyword] = ACTIONS(9615),
    [sym_column_keyword] = ACTIONS(9615),
    [sym_filter_keyword] = ACTIONS(9615),
    [sym_labels_keyword] = ACTIONS(9615),
    [sym_rendering_keyword] = ACTIONS(9615),
    [sym_requestpage_keyword] = ACTIONS(9615),
    [sym_schema_keyword] = ACTIONS(9615),
    [sym_views_keyword] = ACTIONS(9615),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9615),
    [sym_preproc_open] = ACTIONS(9615),
    [sym_preproc_close] = ACTIONS(9615),
  },
  [STATE(3567)] = {
    [anon_sym_SEMI] = ACTIONS(9619),
    [aux_sym_where_condition_token1] = ACTIONS(9621),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9619),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9619),
    [anon_sym_LBRACK] = ACTIONS(9619),
    [aux_sym_basic_type_token6] = ACTIONS(9621),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9619),
    [aux_sym_addafter_modification_token1] = ACTIONS(9619),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9619),
    [aux_sym_modify_modification_token1] = ACTIONS(9619),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9619),
    [aux_sym_movelast_modification_token1] = ACTIONS(9619),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9619),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9619),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9619),
    [anon_sym_POUNDif] = ACTIONS(9619),
    [anon_sym_POUNDIF] = ACTIONS(9619),
    [anon_sym_POUNDIf] = ACTIONS(9619),
    [anon_sym_POUNDelif] = ACTIONS(9619),
    [anon_sym_POUNDELIF] = ACTIONS(9619),
    [anon_sym_POUNDElif] = ACTIONS(9619),
    [anon_sym_POUNDelse] = ACTIONS(9619),
    [anon_sym_POUNDELSE] = ACTIONS(9619),
    [anon_sym_POUNDElse] = ACTIONS(9619),
    [anon_sym_POUNDendif] = ACTIONS(9619),
    [anon_sym_POUNDENDIF] = ACTIONS(9619),
    [anon_sym_POUNDEndif] = ACTIONS(9619),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9619),
    [sym_trigger_keyword] = ACTIONS(9619),
    [sym_var_keyword] = ACTIONS(9619),
    [sym_local_keyword] = ACTIONS(9619),
    [sym_internal_keyword] = ACTIONS(9619),
    [sym_protected_keyword] = ACTIONS(9619),
    [sym_event_keyword] = ACTIONS(9619),
    [sym_fields_keyword] = ACTIONS(9619),
    [sym_keys_keyword] = ACTIONS(9619),
    [sym_fieldgroups_keyword] = ACTIONS(9619),
    [sym_actions_keyword] = ACTIONS(9619),
    [sym_layout_keyword] = ACTIONS(9619),
    [sym_area_keyword] = ACTIONS(9619),
    [sym_group_keyword] = ACTIONS(9619),
    [sym_repeater_keyword] = ACTIONS(9619),
    [sym_cuegroup_keyword] = ACTIONS(9619),
    [sym_fixed_keyword] = ACTIONS(9619),
    [sym_grid_keyword] = ACTIONS(9619),
    [sym_part_keyword] = ACTIONS(9619),
    [sym_systempart_keyword] = ACTIONS(9619),
    [sym_usercontrol_keyword] = ACTIONS(9619),
    [sym_dataset_keyword] = ACTIONS(9619),
    [sym_elements_keyword] = ACTIONS(9619),
    [sym_dataitem_keyword] = ACTIONS(9619),
    [sym_column_keyword] = ACTIONS(9619),
    [sym_filter_keyword] = ACTIONS(9619),
    [sym_labels_keyword] = ACTIONS(9619),
    [sym_rendering_keyword] = ACTIONS(9619),
    [sym_requestpage_keyword] = ACTIONS(9619),
    [sym_schema_keyword] = ACTIONS(9619),
    [sym_views_keyword] = ACTIONS(9619),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9619),
    [sym_preproc_open] = ACTIONS(9619),
    [sym_preproc_close] = ACTIONS(9619),
  },
  [STATE(3568)] = {
    [anon_sym_SEMI] = ACTIONS(9501),
    [aux_sym_where_condition_token1] = ACTIONS(9503),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9501),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9501),
    [anon_sym_LBRACK] = ACTIONS(9501),
    [aux_sym_basic_type_token6] = ACTIONS(9503),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9501),
    [aux_sym_addafter_modification_token1] = ACTIONS(9501),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9501),
    [aux_sym_modify_modification_token1] = ACTIONS(9501),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9501),
    [aux_sym_movelast_modification_token1] = ACTIONS(9501),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9501),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9501),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9501),
    [anon_sym_POUNDif] = ACTIONS(9501),
    [anon_sym_POUNDIF] = ACTIONS(9501),
    [anon_sym_POUNDIf] = ACTIONS(9501),
    [anon_sym_POUNDelif] = ACTIONS(9501),
    [anon_sym_POUNDELIF] = ACTIONS(9501),
    [anon_sym_POUNDElif] = ACTIONS(9501),
    [anon_sym_POUNDelse] = ACTIONS(9501),
    [anon_sym_POUNDELSE] = ACTIONS(9501),
    [anon_sym_POUNDElse] = ACTIONS(9501),
    [anon_sym_POUNDendif] = ACTIONS(9501),
    [anon_sym_POUNDENDIF] = ACTIONS(9501),
    [anon_sym_POUNDEndif] = ACTIONS(9501),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9501),
    [sym_trigger_keyword] = ACTIONS(9501),
    [sym_var_keyword] = ACTIONS(9501),
    [sym_local_keyword] = ACTIONS(9501),
    [sym_internal_keyword] = ACTIONS(9501),
    [sym_protected_keyword] = ACTIONS(9501),
    [sym_event_keyword] = ACTIONS(9501),
    [sym_fields_keyword] = ACTIONS(9501),
    [sym_keys_keyword] = ACTIONS(9501),
    [sym_fieldgroups_keyword] = ACTIONS(9501),
    [sym_actions_keyword] = ACTIONS(9501),
    [sym_layout_keyword] = ACTIONS(9501),
    [sym_area_keyword] = ACTIONS(9501),
    [sym_group_keyword] = ACTIONS(9501),
    [sym_repeater_keyword] = ACTIONS(9501),
    [sym_cuegroup_keyword] = ACTIONS(9501),
    [sym_fixed_keyword] = ACTIONS(9501),
    [sym_grid_keyword] = ACTIONS(9501),
    [sym_part_keyword] = ACTIONS(9501),
    [sym_systempart_keyword] = ACTIONS(9501),
    [sym_usercontrol_keyword] = ACTIONS(9501),
    [sym_dataset_keyword] = ACTIONS(9501),
    [sym_elements_keyword] = ACTIONS(9501),
    [sym_dataitem_keyword] = ACTIONS(9501),
    [sym_column_keyword] = ACTIONS(9501),
    [sym_filter_keyword] = ACTIONS(9501),
    [sym_labels_keyword] = ACTIONS(9501),
    [sym_rendering_keyword] = ACTIONS(9501),
    [sym_requestpage_keyword] = ACTIONS(9501),
    [sym_schema_keyword] = ACTIONS(9501),
    [sym_views_keyword] = ACTIONS(9501),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9501),
    [sym_preproc_open] = ACTIONS(9501),
    [sym_preproc_close] = ACTIONS(9501),
  },
  [STATE(3569)] = {
    [anon_sym_SEMI] = ACTIONS(4215),
    [aux_sym_where_condition_token1] = ACTIONS(4213),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4215),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4215),
    [anon_sym_LBRACK] = ACTIONS(4215),
    [aux_sym_basic_type_token6] = ACTIONS(4213),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4215),
    [aux_sym_addafter_modification_token1] = ACTIONS(4215),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4215),
    [aux_sym_modify_modification_token1] = ACTIONS(4215),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4215),
    [aux_sym_movelast_modification_token1] = ACTIONS(4215),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4215),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4215),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4215),
    [anon_sym_POUNDif] = ACTIONS(4215),
    [anon_sym_POUNDIF] = ACTIONS(4215),
    [anon_sym_POUNDIf] = ACTIONS(4215),
    [anon_sym_POUNDelif] = ACTIONS(4215),
    [anon_sym_POUNDELIF] = ACTIONS(4215),
    [anon_sym_POUNDElif] = ACTIONS(4215),
    [anon_sym_POUNDelse] = ACTIONS(4215),
    [anon_sym_POUNDELSE] = ACTIONS(4215),
    [anon_sym_POUNDElse] = ACTIONS(4215),
    [anon_sym_POUNDendif] = ACTIONS(4215),
    [anon_sym_POUNDENDIF] = ACTIONS(4215),
    [anon_sym_POUNDEndif] = ACTIONS(4215),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4215),
    [sym_trigger_keyword] = ACTIONS(4215),
    [sym_var_keyword] = ACTIONS(4215),
    [sym_local_keyword] = ACTIONS(4215),
    [sym_internal_keyword] = ACTIONS(4215),
    [sym_protected_keyword] = ACTIONS(4215),
    [sym_event_keyword] = ACTIONS(4215),
    [sym_fields_keyword] = ACTIONS(4215),
    [sym_keys_keyword] = ACTIONS(4215),
    [sym_fieldgroups_keyword] = ACTIONS(4215),
    [sym_actions_keyword] = ACTIONS(4215),
    [sym_layout_keyword] = ACTIONS(4215),
    [sym_area_keyword] = ACTIONS(4215),
    [sym_group_keyword] = ACTIONS(4215),
    [sym_repeater_keyword] = ACTIONS(4215),
    [sym_cuegroup_keyword] = ACTIONS(4215),
    [sym_fixed_keyword] = ACTIONS(4215),
    [sym_grid_keyword] = ACTIONS(4215),
    [sym_part_keyword] = ACTIONS(4215),
    [sym_systempart_keyword] = ACTIONS(4215),
    [sym_usercontrol_keyword] = ACTIONS(4215),
    [sym_dataset_keyword] = ACTIONS(4215),
    [sym_elements_keyword] = ACTIONS(4215),
    [sym_dataitem_keyword] = ACTIONS(4215),
    [sym_column_keyword] = ACTIONS(4215),
    [sym_filter_keyword] = ACTIONS(4215),
    [sym_labels_keyword] = ACTIONS(4215),
    [sym_rendering_keyword] = ACTIONS(4215),
    [sym_requestpage_keyword] = ACTIONS(4215),
    [sym_schema_keyword] = ACTIONS(4215),
    [sym_views_keyword] = ACTIONS(4215),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4215),
    [sym_preproc_open] = ACTIONS(4215),
    [sym_preproc_close] = ACTIONS(4215),
  },
  [STATE(3570)] = {
    [anon_sym_SEMI] = ACTIONS(9561),
    [aux_sym_where_condition_token1] = ACTIONS(9563),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9561),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9561),
    [anon_sym_LBRACK] = ACTIONS(9561),
    [aux_sym_basic_type_token6] = ACTIONS(9563),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9561),
    [aux_sym_addafter_modification_token1] = ACTIONS(9561),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9561),
    [aux_sym_modify_modification_token1] = ACTIONS(9561),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9561),
    [aux_sym_movelast_modification_token1] = ACTIONS(9561),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9561),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9561),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9561),
    [anon_sym_POUNDif] = ACTIONS(9561),
    [anon_sym_POUNDIF] = ACTIONS(9561),
    [anon_sym_POUNDIf] = ACTIONS(9561),
    [anon_sym_POUNDelif] = ACTIONS(9561),
    [anon_sym_POUNDELIF] = ACTIONS(9561),
    [anon_sym_POUNDElif] = ACTIONS(9561),
    [anon_sym_POUNDelse] = ACTIONS(9561),
    [anon_sym_POUNDELSE] = ACTIONS(9561),
    [anon_sym_POUNDElse] = ACTIONS(9561),
    [anon_sym_POUNDendif] = ACTIONS(9561),
    [anon_sym_POUNDENDIF] = ACTIONS(9561),
    [anon_sym_POUNDEndif] = ACTIONS(9561),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9561),
    [sym_trigger_keyword] = ACTIONS(9561),
    [sym_var_keyword] = ACTIONS(9561),
    [sym_local_keyword] = ACTIONS(9561),
    [sym_internal_keyword] = ACTIONS(9561),
    [sym_protected_keyword] = ACTIONS(9561),
    [sym_event_keyword] = ACTIONS(9561),
    [sym_fields_keyword] = ACTIONS(9561),
    [sym_keys_keyword] = ACTIONS(9561),
    [sym_fieldgroups_keyword] = ACTIONS(9561),
    [sym_actions_keyword] = ACTIONS(9561),
    [sym_layout_keyword] = ACTIONS(9561),
    [sym_area_keyword] = ACTIONS(9561),
    [sym_group_keyword] = ACTIONS(9561),
    [sym_repeater_keyword] = ACTIONS(9561),
    [sym_cuegroup_keyword] = ACTIONS(9561),
    [sym_fixed_keyword] = ACTIONS(9561),
    [sym_grid_keyword] = ACTIONS(9561),
    [sym_part_keyword] = ACTIONS(9561),
    [sym_systempart_keyword] = ACTIONS(9561),
    [sym_usercontrol_keyword] = ACTIONS(9561),
    [sym_dataset_keyword] = ACTIONS(9561),
    [sym_elements_keyword] = ACTIONS(9561),
    [sym_dataitem_keyword] = ACTIONS(9561),
    [sym_column_keyword] = ACTIONS(9561),
    [sym_filter_keyword] = ACTIONS(9561),
    [sym_labels_keyword] = ACTIONS(9561),
    [sym_rendering_keyword] = ACTIONS(9561),
    [sym_requestpage_keyword] = ACTIONS(9561),
    [sym_schema_keyword] = ACTIONS(9561),
    [sym_views_keyword] = ACTIONS(9561),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9561),
    [sym_preproc_open] = ACTIONS(9561),
    [sym_preproc_close] = ACTIONS(9561),
  },
  [STATE(3571)] = {
    [anon_sym_SEMI] = ACTIONS(9623),
    [aux_sym_where_condition_token1] = ACTIONS(9625),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9623),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9623),
    [anon_sym_LBRACK] = ACTIONS(9623),
    [aux_sym_basic_type_token6] = ACTIONS(9625),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9623),
    [aux_sym_addafter_modification_token1] = ACTIONS(9623),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9623),
    [aux_sym_modify_modification_token1] = ACTIONS(9623),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9623),
    [aux_sym_movelast_modification_token1] = ACTIONS(9623),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9623),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9623),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9623),
    [anon_sym_POUNDif] = ACTIONS(9623),
    [anon_sym_POUNDIF] = ACTIONS(9623),
    [anon_sym_POUNDIf] = ACTIONS(9623),
    [anon_sym_POUNDelif] = ACTIONS(9623),
    [anon_sym_POUNDELIF] = ACTIONS(9623),
    [anon_sym_POUNDElif] = ACTIONS(9623),
    [anon_sym_POUNDelse] = ACTIONS(9623),
    [anon_sym_POUNDELSE] = ACTIONS(9623),
    [anon_sym_POUNDElse] = ACTIONS(9623),
    [anon_sym_POUNDendif] = ACTIONS(9623),
    [anon_sym_POUNDENDIF] = ACTIONS(9623),
    [anon_sym_POUNDEndif] = ACTIONS(9623),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9623),
    [sym_trigger_keyword] = ACTIONS(9623),
    [sym_var_keyword] = ACTIONS(9623),
    [sym_local_keyword] = ACTIONS(9623),
    [sym_internal_keyword] = ACTIONS(9623),
    [sym_protected_keyword] = ACTIONS(9623),
    [sym_event_keyword] = ACTIONS(9623),
    [sym_fields_keyword] = ACTIONS(9623),
    [sym_keys_keyword] = ACTIONS(9623),
    [sym_fieldgroups_keyword] = ACTIONS(9623),
    [sym_actions_keyword] = ACTIONS(9623),
    [sym_layout_keyword] = ACTIONS(9623),
    [sym_area_keyword] = ACTIONS(9623),
    [sym_group_keyword] = ACTIONS(9623),
    [sym_repeater_keyword] = ACTIONS(9623),
    [sym_cuegroup_keyword] = ACTIONS(9623),
    [sym_fixed_keyword] = ACTIONS(9623),
    [sym_grid_keyword] = ACTIONS(9623),
    [sym_part_keyword] = ACTIONS(9623),
    [sym_systempart_keyword] = ACTIONS(9623),
    [sym_usercontrol_keyword] = ACTIONS(9623),
    [sym_dataset_keyword] = ACTIONS(9623),
    [sym_elements_keyword] = ACTIONS(9623),
    [sym_dataitem_keyword] = ACTIONS(9623),
    [sym_column_keyword] = ACTIONS(9623),
    [sym_filter_keyword] = ACTIONS(9623),
    [sym_labels_keyword] = ACTIONS(9623),
    [sym_rendering_keyword] = ACTIONS(9623),
    [sym_requestpage_keyword] = ACTIONS(9623),
    [sym_schema_keyword] = ACTIONS(9623),
    [sym_views_keyword] = ACTIONS(9623),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9623),
    [sym_preproc_open] = ACTIONS(9623),
    [sym_preproc_close] = ACTIONS(9623),
  },
  [STATE(3572)] = {
    [anon_sym_SEMI] = ACTIONS(9627),
    [aux_sym_where_condition_token1] = ACTIONS(9629),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9627),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9627),
    [anon_sym_LBRACK] = ACTIONS(9627),
    [aux_sym_basic_type_token6] = ACTIONS(9629),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9627),
    [aux_sym_addafter_modification_token1] = ACTIONS(9627),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9627),
    [aux_sym_modify_modification_token1] = ACTIONS(9627),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9627),
    [aux_sym_movelast_modification_token1] = ACTIONS(9627),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9627),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9627),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9627),
    [anon_sym_POUNDif] = ACTIONS(9627),
    [anon_sym_POUNDIF] = ACTIONS(9627),
    [anon_sym_POUNDIf] = ACTIONS(9627),
    [anon_sym_POUNDelif] = ACTIONS(9627),
    [anon_sym_POUNDELIF] = ACTIONS(9627),
    [anon_sym_POUNDElif] = ACTIONS(9627),
    [anon_sym_POUNDelse] = ACTIONS(9627),
    [anon_sym_POUNDELSE] = ACTIONS(9627),
    [anon_sym_POUNDElse] = ACTIONS(9627),
    [anon_sym_POUNDendif] = ACTIONS(9627),
    [anon_sym_POUNDENDIF] = ACTIONS(9627),
    [anon_sym_POUNDEndif] = ACTIONS(9627),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9627),
    [sym_trigger_keyword] = ACTIONS(9627),
    [sym_var_keyword] = ACTIONS(9627),
    [sym_local_keyword] = ACTIONS(9627),
    [sym_internal_keyword] = ACTIONS(9627),
    [sym_protected_keyword] = ACTIONS(9627),
    [sym_event_keyword] = ACTIONS(9627),
    [sym_fields_keyword] = ACTIONS(9627),
    [sym_keys_keyword] = ACTIONS(9627),
    [sym_fieldgroups_keyword] = ACTIONS(9627),
    [sym_actions_keyword] = ACTIONS(9627),
    [sym_layout_keyword] = ACTIONS(9627),
    [sym_area_keyword] = ACTIONS(9627),
    [sym_group_keyword] = ACTIONS(9627),
    [sym_repeater_keyword] = ACTIONS(9627),
    [sym_cuegroup_keyword] = ACTIONS(9627),
    [sym_fixed_keyword] = ACTIONS(9627),
    [sym_grid_keyword] = ACTIONS(9627),
    [sym_part_keyword] = ACTIONS(9627),
    [sym_systempart_keyword] = ACTIONS(9627),
    [sym_usercontrol_keyword] = ACTIONS(9627),
    [sym_dataset_keyword] = ACTIONS(9627),
    [sym_elements_keyword] = ACTIONS(9627),
    [sym_dataitem_keyword] = ACTIONS(9627),
    [sym_column_keyword] = ACTIONS(9627),
    [sym_filter_keyword] = ACTIONS(9627),
    [sym_labels_keyword] = ACTIONS(9627),
    [sym_rendering_keyword] = ACTIONS(9627),
    [sym_requestpage_keyword] = ACTIONS(9627),
    [sym_schema_keyword] = ACTIONS(9627),
    [sym_views_keyword] = ACTIONS(9627),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9627),
    [sym_preproc_open] = ACTIONS(9627),
    [sym_preproc_close] = ACTIONS(9627),
  },
  [STATE(3573)] = {
    [anon_sym_SEMI] = ACTIONS(7617),
    [aux_sym_where_condition_token1] = ACTIONS(7615),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7617),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7617),
    [anon_sym_LBRACK] = ACTIONS(7617),
    [aux_sym_basic_type_token6] = ACTIONS(7615),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7617),
    [aux_sym_addafter_modification_token1] = ACTIONS(7617),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7617),
    [aux_sym_modify_modification_token1] = ACTIONS(7617),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7617),
    [aux_sym_movelast_modification_token1] = ACTIONS(7617),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7617),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7617),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7617),
    [anon_sym_POUNDif] = ACTIONS(7617),
    [anon_sym_POUNDIF] = ACTIONS(7617),
    [anon_sym_POUNDIf] = ACTIONS(7617),
    [anon_sym_POUNDelif] = ACTIONS(7617),
    [anon_sym_POUNDELIF] = ACTIONS(7617),
    [anon_sym_POUNDElif] = ACTIONS(7617),
    [anon_sym_POUNDelse] = ACTIONS(7617),
    [anon_sym_POUNDELSE] = ACTIONS(7617),
    [anon_sym_POUNDElse] = ACTIONS(7617),
    [anon_sym_POUNDendif] = ACTIONS(7617),
    [anon_sym_POUNDENDIF] = ACTIONS(7617),
    [anon_sym_POUNDEndif] = ACTIONS(7617),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7617),
    [sym_trigger_keyword] = ACTIONS(7617),
    [sym_var_keyword] = ACTIONS(7617),
    [sym_local_keyword] = ACTIONS(7617),
    [sym_internal_keyword] = ACTIONS(7617),
    [sym_protected_keyword] = ACTIONS(7617),
    [sym_event_keyword] = ACTIONS(7617),
    [sym_fields_keyword] = ACTIONS(7617),
    [sym_keys_keyword] = ACTIONS(7617),
    [sym_fieldgroups_keyword] = ACTIONS(7617),
    [sym_actions_keyword] = ACTIONS(7617),
    [sym_layout_keyword] = ACTIONS(7617),
    [sym_area_keyword] = ACTIONS(7617),
    [sym_group_keyword] = ACTIONS(7617),
    [sym_repeater_keyword] = ACTIONS(7617),
    [sym_cuegroup_keyword] = ACTIONS(7617),
    [sym_fixed_keyword] = ACTIONS(7617),
    [sym_grid_keyword] = ACTIONS(7617),
    [sym_part_keyword] = ACTIONS(7617),
    [sym_systempart_keyword] = ACTIONS(7617),
    [sym_usercontrol_keyword] = ACTIONS(7617),
    [sym_dataset_keyword] = ACTIONS(7617),
    [sym_elements_keyword] = ACTIONS(7617),
    [sym_dataitem_keyword] = ACTIONS(7617),
    [sym_column_keyword] = ACTIONS(7617),
    [sym_filter_keyword] = ACTIONS(7617),
    [sym_labels_keyword] = ACTIONS(7617),
    [sym_rendering_keyword] = ACTIONS(7617),
    [sym_requestpage_keyword] = ACTIONS(7617),
    [sym_schema_keyword] = ACTIONS(7617),
    [sym_views_keyword] = ACTIONS(7617),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7617),
    [sym_preproc_open] = ACTIONS(7617),
    [sym_preproc_close] = ACTIONS(7617),
  },
  [STATE(3574)] = {
    [anon_sym_SEMI] = ACTIONS(9631),
    [aux_sym_where_condition_token1] = ACTIONS(9633),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9631),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9631),
    [anon_sym_LBRACK] = ACTIONS(9631),
    [aux_sym_basic_type_token6] = ACTIONS(9633),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9631),
    [aux_sym_addafter_modification_token1] = ACTIONS(9631),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9631),
    [aux_sym_modify_modification_token1] = ACTIONS(9631),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9631),
    [aux_sym_movelast_modification_token1] = ACTIONS(9631),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9631),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9631),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9631),
    [anon_sym_POUNDif] = ACTIONS(9631),
    [anon_sym_POUNDIF] = ACTIONS(9631),
    [anon_sym_POUNDIf] = ACTIONS(9631),
    [anon_sym_POUNDelif] = ACTIONS(9631),
    [anon_sym_POUNDELIF] = ACTIONS(9631),
    [anon_sym_POUNDElif] = ACTIONS(9631),
    [anon_sym_POUNDelse] = ACTIONS(9631),
    [anon_sym_POUNDELSE] = ACTIONS(9631),
    [anon_sym_POUNDElse] = ACTIONS(9631),
    [anon_sym_POUNDendif] = ACTIONS(9631),
    [anon_sym_POUNDENDIF] = ACTIONS(9631),
    [anon_sym_POUNDEndif] = ACTIONS(9631),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9631),
    [sym_trigger_keyword] = ACTIONS(9631),
    [sym_var_keyword] = ACTIONS(9631),
    [sym_local_keyword] = ACTIONS(9631),
    [sym_internal_keyword] = ACTIONS(9631),
    [sym_protected_keyword] = ACTIONS(9631),
    [sym_event_keyword] = ACTIONS(9631),
    [sym_fields_keyword] = ACTIONS(9631),
    [sym_keys_keyword] = ACTIONS(9631),
    [sym_fieldgroups_keyword] = ACTIONS(9631),
    [sym_actions_keyword] = ACTIONS(9631),
    [sym_layout_keyword] = ACTIONS(9631),
    [sym_area_keyword] = ACTIONS(9631),
    [sym_group_keyword] = ACTIONS(9631),
    [sym_repeater_keyword] = ACTIONS(9631),
    [sym_cuegroup_keyword] = ACTIONS(9631),
    [sym_fixed_keyword] = ACTIONS(9631),
    [sym_grid_keyword] = ACTIONS(9631),
    [sym_part_keyword] = ACTIONS(9631),
    [sym_systempart_keyword] = ACTIONS(9631),
    [sym_usercontrol_keyword] = ACTIONS(9631),
    [sym_dataset_keyword] = ACTIONS(9631),
    [sym_elements_keyword] = ACTIONS(9631),
    [sym_dataitem_keyword] = ACTIONS(9631),
    [sym_column_keyword] = ACTIONS(9631),
    [sym_filter_keyword] = ACTIONS(9631),
    [sym_labels_keyword] = ACTIONS(9631),
    [sym_rendering_keyword] = ACTIONS(9631),
    [sym_requestpage_keyword] = ACTIONS(9631),
    [sym_schema_keyword] = ACTIONS(9631),
    [sym_views_keyword] = ACTIONS(9631),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9631),
    [sym_preproc_open] = ACTIONS(9631),
    [sym_preproc_close] = ACTIONS(9631),
  },
  [STATE(3575)] = {
    [anon_sym_SEMI] = ACTIONS(9635),
    [aux_sym_where_condition_token1] = ACTIONS(9637),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9635),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9635),
    [anon_sym_LBRACK] = ACTIONS(9635),
    [aux_sym_basic_type_token6] = ACTIONS(9637),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9635),
    [aux_sym_addafter_modification_token1] = ACTIONS(9635),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9635),
    [aux_sym_modify_modification_token1] = ACTIONS(9635),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9635),
    [aux_sym_movelast_modification_token1] = ACTIONS(9635),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9635),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9635),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9635),
    [anon_sym_POUNDif] = ACTIONS(9635),
    [anon_sym_POUNDIF] = ACTIONS(9635),
    [anon_sym_POUNDIf] = ACTIONS(9635),
    [anon_sym_POUNDelif] = ACTIONS(9635),
    [anon_sym_POUNDELIF] = ACTIONS(9635),
    [anon_sym_POUNDElif] = ACTIONS(9635),
    [anon_sym_POUNDelse] = ACTIONS(9635),
    [anon_sym_POUNDELSE] = ACTIONS(9635),
    [anon_sym_POUNDElse] = ACTIONS(9635),
    [anon_sym_POUNDendif] = ACTIONS(9635),
    [anon_sym_POUNDENDIF] = ACTIONS(9635),
    [anon_sym_POUNDEndif] = ACTIONS(9635),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9635),
    [sym_trigger_keyword] = ACTIONS(9635),
    [sym_var_keyword] = ACTIONS(9635),
    [sym_local_keyword] = ACTIONS(9635),
    [sym_internal_keyword] = ACTIONS(9635),
    [sym_protected_keyword] = ACTIONS(9635),
    [sym_event_keyword] = ACTIONS(9635),
    [sym_fields_keyword] = ACTIONS(9635),
    [sym_keys_keyword] = ACTIONS(9635),
    [sym_fieldgroups_keyword] = ACTIONS(9635),
    [sym_actions_keyword] = ACTIONS(9635),
    [sym_layout_keyword] = ACTIONS(9635),
    [sym_area_keyword] = ACTIONS(9635),
    [sym_group_keyword] = ACTIONS(9635),
    [sym_repeater_keyword] = ACTIONS(9635),
    [sym_cuegroup_keyword] = ACTIONS(9635),
    [sym_fixed_keyword] = ACTIONS(9635),
    [sym_grid_keyword] = ACTIONS(9635),
    [sym_part_keyword] = ACTIONS(9635),
    [sym_systempart_keyword] = ACTIONS(9635),
    [sym_usercontrol_keyword] = ACTIONS(9635),
    [sym_dataset_keyword] = ACTIONS(9635),
    [sym_elements_keyword] = ACTIONS(9635),
    [sym_dataitem_keyword] = ACTIONS(9635),
    [sym_column_keyword] = ACTIONS(9635),
    [sym_filter_keyword] = ACTIONS(9635),
    [sym_labels_keyword] = ACTIONS(9635),
    [sym_rendering_keyword] = ACTIONS(9635),
    [sym_requestpage_keyword] = ACTIONS(9635),
    [sym_schema_keyword] = ACTIONS(9635),
    [sym_views_keyword] = ACTIONS(9635),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9635),
    [sym_preproc_open] = ACTIONS(9635),
    [sym_preproc_close] = ACTIONS(9635),
  },
  [STATE(3576)] = {
    [anon_sym_SEMI] = ACTIONS(7617),
    [aux_sym_where_condition_token1] = ACTIONS(7615),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7617),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7617),
    [anon_sym_LBRACK] = ACTIONS(7617),
    [aux_sym_basic_type_token6] = ACTIONS(7615),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7617),
    [aux_sym_addafter_modification_token1] = ACTIONS(7617),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7617),
    [aux_sym_modify_modification_token1] = ACTIONS(7617),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7617),
    [aux_sym_movelast_modification_token1] = ACTIONS(7617),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7617),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7617),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7617),
    [anon_sym_POUNDif] = ACTIONS(7617),
    [anon_sym_POUNDIF] = ACTIONS(7617),
    [anon_sym_POUNDIf] = ACTIONS(7617),
    [anon_sym_POUNDelif] = ACTIONS(7617),
    [anon_sym_POUNDELIF] = ACTIONS(7617),
    [anon_sym_POUNDElif] = ACTIONS(7617),
    [anon_sym_POUNDelse] = ACTIONS(7617),
    [anon_sym_POUNDELSE] = ACTIONS(7617),
    [anon_sym_POUNDElse] = ACTIONS(7617),
    [anon_sym_POUNDendif] = ACTIONS(7617),
    [anon_sym_POUNDENDIF] = ACTIONS(7617),
    [anon_sym_POUNDEndif] = ACTIONS(7617),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7617),
    [sym_trigger_keyword] = ACTIONS(7617),
    [sym_var_keyword] = ACTIONS(7617),
    [sym_local_keyword] = ACTIONS(7617),
    [sym_internal_keyword] = ACTIONS(7617),
    [sym_protected_keyword] = ACTIONS(7617),
    [sym_event_keyword] = ACTIONS(7617),
    [sym_fields_keyword] = ACTIONS(7617),
    [sym_keys_keyword] = ACTIONS(7617),
    [sym_fieldgroups_keyword] = ACTIONS(7617),
    [sym_actions_keyword] = ACTIONS(7617),
    [sym_layout_keyword] = ACTIONS(7617),
    [sym_area_keyword] = ACTIONS(7617),
    [sym_group_keyword] = ACTIONS(7617),
    [sym_repeater_keyword] = ACTIONS(7617),
    [sym_cuegroup_keyword] = ACTIONS(7617),
    [sym_fixed_keyword] = ACTIONS(7617),
    [sym_grid_keyword] = ACTIONS(7617),
    [sym_part_keyword] = ACTIONS(7617),
    [sym_systempart_keyword] = ACTIONS(7617),
    [sym_usercontrol_keyword] = ACTIONS(7617),
    [sym_dataset_keyword] = ACTIONS(7617),
    [sym_elements_keyword] = ACTIONS(7617),
    [sym_dataitem_keyword] = ACTIONS(7617),
    [sym_column_keyword] = ACTIONS(7617),
    [sym_filter_keyword] = ACTIONS(7617),
    [sym_labels_keyword] = ACTIONS(7617),
    [sym_rendering_keyword] = ACTIONS(7617),
    [sym_requestpage_keyword] = ACTIONS(7617),
    [sym_schema_keyword] = ACTIONS(7617),
    [sym_views_keyword] = ACTIONS(7617),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7617),
    [sym_preproc_open] = ACTIONS(7617),
    [sym_preproc_close] = ACTIONS(7617),
  },
  [STATE(3577)] = {
    [anon_sym_SEMI] = ACTIONS(9635),
    [aux_sym_where_condition_token1] = ACTIONS(9637),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9635),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9635),
    [anon_sym_LBRACK] = ACTIONS(9635),
    [aux_sym_basic_type_token6] = ACTIONS(9637),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9635),
    [aux_sym_addafter_modification_token1] = ACTIONS(9635),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9635),
    [aux_sym_modify_modification_token1] = ACTIONS(9635),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9635),
    [aux_sym_movelast_modification_token1] = ACTIONS(9635),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9635),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9635),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9635),
    [anon_sym_POUNDif] = ACTIONS(9635),
    [anon_sym_POUNDIF] = ACTIONS(9635),
    [anon_sym_POUNDIf] = ACTIONS(9635),
    [anon_sym_POUNDelif] = ACTIONS(9635),
    [anon_sym_POUNDELIF] = ACTIONS(9635),
    [anon_sym_POUNDElif] = ACTIONS(9635),
    [anon_sym_POUNDelse] = ACTIONS(9635),
    [anon_sym_POUNDELSE] = ACTIONS(9635),
    [anon_sym_POUNDElse] = ACTIONS(9635),
    [anon_sym_POUNDendif] = ACTIONS(9635),
    [anon_sym_POUNDENDIF] = ACTIONS(9635),
    [anon_sym_POUNDEndif] = ACTIONS(9635),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9635),
    [sym_trigger_keyword] = ACTIONS(9635),
    [sym_var_keyword] = ACTIONS(9635),
    [sym_local_keyword] = ACTIONS(9635),
    [sym_internal_keyword] = ACTIONS(9635),
    [sym_protected_keyword] = ACTIONS(9635),
    [sym_event_keyword] = ACTIONS(9635),
    [sym_fields_keyword] = ACTIONS(9635),
    [sym_keys_keyword] = ACTIONS(9635),
    [sym_fieldgroups_keyword] = ACTIONS(9635),
    [sym_actions_keyword] = ACTIONS(9635),
    [sym_layout_keyword] = ACTIONS(9635),
    [sym_area_keyword] = ACTIONS(9635),
    [sym_group_keyword] = ACTIONS(9635),
    [sym_repeater_keyword] = ACTIONS(9635),
    [sym_cuegroup_keyword] = ACTIONS(9635),
    [sym_fixed_keyword] = ACTIONS(9635),
    [sym_grid_keyword] = ACTIONS(9635),
    [sym_part_keyword] = ACTIONS(9635),
    [sym_systempart_keyword] = ACTIONS(9635),
    [sym_usercontrol_keyword] = ACTIONS(9635),
    [sym_dataset_keyword] = ACTIONS(9635),
    [sym_elements_keyword] = ACTIONS(9635),
    [sym_dataitem_keyword] = ACTIONS(9635),
    [sym_column_keyword] = ACTIONS(9635),
    [sym_filter_keyword] = ACTIONS(9635),
    [sym_labels_keyword] = ACTIONS(9635),
    [sym_rendering_keyword] = ACTIONS(9635),
    [sym_requestpage_keyword] = ACTIONS(9635),
    [sym_schema_keyword] = ACTIONS(9635),
    [sym_views_keyword] = ACTIONS(9635),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9635),
    [sym_preproc_open] = ACTIONS(9635),
    [sym_preproc_close] = ACTIONS(9635),
  },
  [STATE(3578)] = {
    [anon_sym_SEMI] = ACTIONS(9639),
    [aux_sym_where_condition_token1] = ACTIONS(9641),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9639),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9639),
    [anon_sym_LBRACK] = ACTIONS(9639),
    [aux_sym_basic_type_token6] = ACTIONS(9641),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9639),
    [aux_sym_addafter_modification_token1] = ACTIONS(9639),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9639),
    [aux_sym_modify_modification_token1] = ACTIONS(9639),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9639),
    [aux_sym_movelast_modification_token1] = ACTIONS(9639),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9639),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9639),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9639),
    [anon_sym_POUNDif] = ACTIONS(9639),
    [anon_sym_POUNDIF] = ACTIONS(9639),
    [anon_sym_POUNDIf] = ACTIONS(9639),
    [anon_sym_POUNDelif] = ACTIONS(9639),
    [anon_sym_POUNDELIF] = ACTIONS(9639),
    [anon_sym_POUNDElif] = ACTIONS(9639),
    [anon_sym_POUNDelse] = ACTIONS(9639),
    [anon_sym_POUNDELSE] = ACTIONS(9639),
    [anon_sym_POUNDElse] = ACTIONS(9639),
    [anon_sym_POUNDendif] = ACTIONS(9639),
    [anon_sym_POUNDENDIF] = ACTIONS(9639),
    [anon_sym_POUNDEndif] = ACTIONS(9639),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9639),
    [sym_trigger_keyword] = ACTIONS(9639),
    [sym_var_keyword] = ACTIONS(9639),
    [sym_local_keyword] = ACTIONS(9639),
    [sym_internal_keyword] = ACTIONS(9639),
    [sym_protected_keyword] = ACTIONS(9639),
    [sym_event_keyword] = ACTIONS(9639),
    [sym_fields_keyword] = ACTIONS(9639),
    [sym_keys_keyword] = ACTIONS(9639),
    [sym_fieldgroups_keyword] = ACTIONS(9639),
    [sym_actions_keyword] = ACTIONS(9639),
    [sym_layout_keyword] = ACTIONS(9639),
    [sym_area_keyword] = ACTIONS(9639),
    [sym_group_keyword] = ACTIONS(9639),
    [sym_repeater_keyword] = ACTIONS(9639),
    [sym_cuegroup_keyword] = ACTIONS(9639),
    [sym_fixed_keyword] = ACTIONS(9639),
    [sym_grid_keyword] = ACTIONS(9639),
    [sym_part_keyword] = ACTIONS(9639),
    [sym_systempart_keyword] = ACTIONS(9639),
    [sym_usercontrol_keyword] = ACTIONS(9639),
    [sym_dataset_keyword] = ACTIONS(9639),
    [sym_elements_keyword] = ACTIONS(9639),
    [sym_dataitem_keyword] = ACTIONS(9639),
    [sym_column_keyword] = ACTIONS(9639),
    [sym_filter_keyword] = ACTIONS(9639),
    [sym_labels_keyword] = ACTIONS(9639),
    [sym_rendering_keyword] = ACTIONS(9639),
    [sym_requestpage_keyword] = ACTIONS(9639),
    [sym_schema_keyword] = ACTIONS(9639),
    [sym_views_keyword] = ACTIONS(9639),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9639),
    [sym_preproc_open] = ACTIONS(9639),
    [sym_preproc_close] = ACTIONS(9639),
  },
  [STATE(3579)] = {
    [anon_sym_SEMI] = ACTIONS(9643),
    [aux_sym_where_condition_token1] = ACTIONS(9645),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9643),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9643),
    [anon_sym_LBRACK] = ACTIONS(9643),
    [aux_sym_basic_type_token6] = ACTIONS(9645),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9643),
    [aux_sym_addafter_modification_token1] = ACTIONS(9643),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9643),
    [aux_sym_modify_modification_token1] = ACTIONS(9643),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9643),
    [aux_sym_movelast_modification_token1] = ACTIONS(9643),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9643),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9643),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9643),
    [anon_sym_POUNDif] = ACTIONS(9643),
    [anon_sym_POUNDIF] = ACTIONS(9643),
    [anon_sym_POUNDIf] = ACTIONS(9643),
    [anon_sym_POUNDelif] = ACTIONS(9643),
    [anon_sym_POUNDELIF] = ACTIONS(9643),
    [anon_sym_POUNDElif] = ACTIONS(9643),
    [anon_sym_POUNDelse] = ACTIONS(9643),
    [anon_sym_POUNDELSE] = ACTIONS(9643),
    [anon_sym_POUNDElse] = ACTIONS(9643),
    [anon_sym_POUNDendif] = ACTIONS(9643),
    [anon_sym_POUNDENDIF] = ACTIONS(9643),
    [anon_sym_POUNDEndif] = ACTIONS(9643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9643),
    [sym_trigger_keyword] = ACTIONS(9643),
    [sym_var_keyword] = ACTIONS(9643),
    [sym_local_keyword] = ACTIONS(9643),
    [sym_internal_keyword] = ACTIONS(9643),
    [sym_protected_keyword] = ACTIONS(9643),
    [sym_event_keyword] = ACTIONS(9643),
    [sym_fields_keyword] = ACTIONS(9643),
    [sym_keys_keyword] = ACTIONS(9643),
    [sym_fieldgroups_keyword] = ACTIONS(9643),
    [sym_actions_keyword] = ACTIONS(9643),
    [sym_layout_keyword] = ACTIONS(9643),
    [sym_area_keyword] = ACTIONS(9643),
    [sym_group_keyword] = ACTIONS(9643),
    [sym_repeater_keyword] = ACTIONS(9643),
    [sym_cuegroup_keyword] = ACTIONS(9643),
    [sym_fixed_keyword] = ACTIONS(9643),
    [sym_grid_keyword] = ACTIONS(9643),
    [sym_part_keyword] = ACTIONS(9643),
    [sym_systempart_keyword] = ACTIONS(9643),
    [sym_usercontrol_keyword] = ACTIONS(9643),
    [sym_dataset_keyword] = ACTIONS(9643),
    [sym_elements_keyword] = ACTIONS(9643),
    [sym_dataitem_keyword] = ACTIONS(9643),
    [sym_column_keyword] = ACTIONS(9643),
    [sym_filter_keyword] = ACTIONS(9643),
    [sym_labels_keyword] = ACTIONS(9643),
    [sym_rendering_keyword] = ACTIONS(9643),
    [sym_requestpage_keyword] = ACTIONS(9643),
    [sym_schema_keyword] = ACTIONS(9643),
    [sym_views_keyword] = ACTIONS(9643),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9643),
    [sym_preproc_open] = ACTIONS(9643),
    [sym_preproc_close] = ACTIONS(9643),
  },
  [STATE(3580)] = {
    [anon_sym_SEMI] = ACTIONS(9647),
    [aux_sym_where_condition_token1] = ACTIONS(9649),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9647),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9647),
    [anon_sym_LBRACK] = ACTIONS(9647),
    [aux_sym_basic_type_token6] = ACTIONS(9649),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9647),
    [aux_sym_addafter_modification_token1] = ACTIONS(9647),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9647),
    [aux_sym_modify_modification_token1] = ACTIONS(9647),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9647),
    [aux_sym_movelast_modification_token1] = ACTIONS(9647),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9647),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9647),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9647),
    [anon_sym_POUNDif] = ACTIONS(9647),
    [anon_sym_POUNDIF] = ACTIONS(9647),
    [anon_sym_POUNDIf] = ACTIONS(9647),
    [anon_sym_POUNDelif] = ACTIONS(9647),
    [anon_sym_POUNDELIF] = ACTIONS(9647),
    [anon_sym_POUNDElif] = ACTIONS(9647),
    [anon_sym_POUNDelse] = ACTIONS(9647),
    [anon_sym_POUNDELSE] = ACTIONS(9647),
    [anon_sym_POUNDElse] = ACTIONS(9647),
    [anon_sym_POUNDendif] = ACTIONS(9647),
    [anon_sym_POUNDENDIF] = ACTIONS(9647),
    [anon_sym_POUNDEndif] = ACTIONS(9647),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9647),
    [sym_trigger_keyword] = ACTIONS(9647),
    [sym_var_keyword] = ACTIONS(9647),
    [sym_local_keyword] = ACTIONS(9647),
    [sym_internal_keyword] = ACTIONS(9647),
    [sym_protected_keyword] = ACTIONS(9647),
    [sym_event_keyword] = ACTIONS(9647),
    [sym_fields_keyword] = ACTIONS(9647),
    [sym_keys_keyword] = ACTIONS(9647),
    [sym_fieldgroups_keyword] = ACTIONS(9647),
    [sym_actions_keyword] = ACTIONS(9647),
    [sym_layout_keyword] = ACTIONS(9647),
    [sym_area_keyword] = ACTIONS(9647),
    [sym_group_keyword] = ACTIONS(9647),
    [sym_repeater_keyword] = ACTIONS(9647),
    [sym_cuegroup_keyword] = ACTIONS(9647),
    [sym_fixed_keyword] = ACTIONS(9647),
    [sym_grid_keyword] = ACTIONS(9647),
    [sym_part_keyword] = ACTIONS(9647),
    [sym_systempart_keyword] = ACTIONS(9647),
    [sym_usercontrol_keyword] = ACTIONS(9647),
    [sym_dataset_keyword] = ACTIONS(9647),
    [sym_elements_keyword] = ACTIONS(9647),
    [sym_dataitem_keyword] = ACTIONS(9647),
    [sym_column_keyword] = ACTIONS(9647),
    [sym_filter_keyword] = ACTIONS(9647),
    [sym_labels_keyword] = ACTIONS(9647),
    [sym_rendering_keyword] = ACTIONS(9647),
    [sym_requestpage_keyword] = ACTIONS(9647),
    [sym_schema_keyword] = ACTIONS(9647),
    [sym_views_keyword] = ACTIONS(9647),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9647),
    [sym_preproc_open] = ACTIONS(9647),
    [sym_preproc_close] = ACTIONS(9647),
  },
  [STATE(3581)] = {
    [anon_sym_SEMI] = ACTIONS(9647),
    [aux_sym_where_condition_token1] = ACTIONS(9649),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9647),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9647),
    [anon_sym_LBRACK] = ACTIONS(9647),
    [aux_sym_basic_type_token6] = ACTIONS(9649),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9647),
    [aux_sym_addafter_modification_token1] = ACTIONS(9647),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9647),
    [aux_sym_modify_modification_token1] = ACTIONS(9647),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9647),
    [aux_sym_movelast_modification_token1] = ACTIONS(9647),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9647),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9647),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9647),
    [anon_sym_POUNDif] = ACTIONS(9647),
    [anon_sym_POUNDIF] = ACTIONS(9647),
    [anon_sym_POUNDIf] = ACTIONS(9647),
    [anon_sym_POUNDelif] = ACTIONS(9647),
    [anon_sym_POUNDELIF] = ACTIONS(9647),
    [anon_sym_POUNDElif] = ACTIONS(9647),
    [anon_sym_POUNDelse] = ACTIONS(9647),
    [anon_sym_POUNDELSE] = ACTIONS(9647),
    [anon_sym_POUNDElse] = ACTIONS(9647),
    [anon_sym_POUNDendif] = ACTIONS(9647),
    [anon_sym_POUNDENDIF] = ACTIONS(9647),
    [anon_sym_POUNDEndif] = ACTIONS(9647),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9647),
    [sym_trigger_keyword] = ACTIONS(9647),
    [sym_var_keyword] = ACTIONS(9647),
    [sym_local_keyword] = ACTIONS(9647),
    [sym_internal_keyword] = ACTIONS(9647),
    [sym_protected_keyword] = ACTIONS(9647),
    [sym_event_keyword] = ACTIONS(9647),
    [sym_fields_keyword] = ACTIONS(9647),
    [sym_keys_keyword] = ACTIONS(9647),
    [sym_fieldgroups_keyword] = ACTIONS(9647),
    [sym_actions_keyword] = ACTIONS(9647),
    [sym_layout_keyword] = ACTIONS(9647),
    [sym_area_keyword] = ACTIONS(9647),
    [sym_group_keyword] = ACTIONS(9647),
    [sym_repeater_keyword] = ACTIONS(9647),
    [sym_cuegroup_keyword] = ACTIONS(9647),
    [sym_fixed_keyword] = ACTIONS(9647),
    [sym_grid_keyword] = ACTIONS(9647),
    [sym_part_keyword] = ACTIONS(9647),
    [sym_systempart_keyword] = ACTIONS(9647),
    [sym_usercontrol_keyword] = ACTIONS(9647),
    [sym_dataset_keyword] = ACTIONS(9647),
    [sym_elements_keyword] = ACTIONS(9647),
    [sym_dataitem_keyword] = ACTIONS(9647),
    [sym_column_keyword] = ACTIONS(9647),
    [sym_filter_keyword] = ACTIONS(9647),
    [sym_labels_keyword] = ACTIONS(9647),
    [sym_rendering_keyword] = ACTIONS(9647),
    [sym_requestpage_keyword] = ACTIONS(9647),
    [sym_schema_keyword] = ACTIONS(9647),
    [sym_views_keyword] = ACTIONS(9647),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9647),
    [sym_preproc_open] = ACTIONS(9647),
    [sym_preproc_close] = ACTIONS(9647),
  },
  [STATE(3582)] = {
    [anon_sym_SEMI] = ACTIONS(9651),
    [aux_sym_where_condition_token1] = ACTIONS(9653),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9651),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9651),
    [anon_sym_LBRACK] = ACTIONS(9651),
    [aux_sym_basic_type_token6] = ACTIONS(9653),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9651),
    [aux_sym_addafter_modification_token1] = ACTIONS(9651),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9651),
    [aux_sym_modify_modification_token1] = ACTIONS(9651),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9651),
    [aux_sym_movelast_modification_token1] = ACTIONS(9651),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9651),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9651),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9651),
    [anon_sym_POUNDif] = ACTIONS(9651),
    [anon_sym_POUNDIF] = ACTIONS(9651),
    [anon_sym_POUNDIf] = ACTIONS(9651),
    [anon_sym_POUNDelif] = ACTIONS(9651),
    [anon_sym_POUNDELIF] = ACTIONS(9651),
    [anon_sym_POUNDElif] = ACTIONS(9651),
    [anon_sym_POUNDelse] = ACTIONS(9651),
    [anon_sym_POUNDELSE] = ACTIONS(9651),
    [anon_sym_POUNDElse] = ACTIONS(9651),
    [anon_sym_POUNDendif] = ACTIONS(9651),
    [anon_sym_POUNDENDIF] = ACTIONS(9651),
    [anon_sym_POUNDEndif] = ACTIONS(9651),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9651),
    [sym_trigger_keyword] = ACTIONS(9651),
    [sym_var_keyword] = ACTIONS(9651),
    [sym_local_keyword] = ACTIONS(9651),
    [sym_internal_keyword] = ACTIONS(9651),
    [sym_protected_keyword] = ACTIONS(9651),
    [sym_event_keyword] = ACTIONS(9651),
    [sym_fields_keyword] = ACTIONS(9651),
    [sym_keys_keyword] = ACTIONS(9651),
    [sym_fieldgroups_keyword] = ACTIONS(9651),
    [sym_actions_keyword] = ACTIONS(9651),
    [sym_layout_keyword] = ACTIONS(9651),
    [sym_area_keyword] = ACTIONS(9651),
    [sym_group_keyword] = ACTIONS(9651),
    [sym_repeater_keyword] = ACTIONS(9651),
    [sym_cuegroup_keyword] = ACTIONS(9651),
    [sym_fixed_keyword] = ACTIONS(9651),
    [sym_grid_keyword] = ACTIONS(9651),
    [sym_part_keyword] = ACTIONS(9651),
    [sym_systempart_keyword] = ACTIONS(9651),
    [sym_usercontrol_keyword] = ACTIONS(9651),
    [sym_dataset_keyword] = ACTIONS(9651),
    [sym_elements_keyword] = ACTIONS(9651),
    [sym_dataitem_keyword] = ACTIONS(9651),
    [sym_column_keyword] = ACTIONS(9651),
    [sym_filter_keyword] = ACTIONS(9651),
    [sym_labels_keyword] = ACTIONS(9651),
    [sym_rendering_keyword] = ACTIONS(9651),
    [sym_requestpage_keyword] = ACTIONS(9651),
    [sym_schema_keyword] = ACTIONS(9651),
    [sym_views_keyword] = ACTIONS(9651),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9651),
    [sym_preproc_open] = ACTIONS(9651),
    [sym_preproc_close] = ACTIONS(9651),
  },
  [STATE(3583)] = {
    [anon_sym_SEMI] = ACTIONS(9651),
    [aux_sym_where_condition_token1] = ACTIONS(9653),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9651),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9651),
    [anon_sym_LBRACK] = ACTIONS(9651),
    [aux_sym_basic_type_token6] = ACTIONS(9653),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9651),
    [aux_sym_addafter_modification_token1] = ACTIONS(9651),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9651),
    [aux_sym_modify_modification_token1] = ACTIONS(9651),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9651),
    [aux_sym_movelast_modification_token1] = ACTIONS(9651),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9651),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9651),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9651),
    [anon_sym_POUNDif] = ACTIONS(9651),
    [anon_sym_POUNDIF] = ACTIONS(9651),
    [anon_sym_POUNDIf] = ACTIONS(9651),
    [anon_sym_POUNDelif] = ACTIONS(9651),
    [anon_sym_POUNDELIF] = ACTIONS(9651),
    [anon_sym_POUNDElif] = ACTIONS(9651),
    [anon_sym_POUNDelse] = ACTIONS(9651),
    [anon_sym_POUNDELSE] = ACTIONS(9651),
    [anon_sym_POUNDElse] = ACTIONS(9651),
    [anon_sym_POUNDendif] = ACTIONS(9651),
    [anon_sym_POUNDENDIF] = ACTIONS(9651),
    [anon_sym_POUNDEndif] = ACTIONS(9651),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9651),
    [sym_trigger_keyword] = ACTIONS(9651),
    [sym_var_keyword] = ACTIONS(9651),
    [sym_local_keyword] = ACTIONS(9651),
    [sym_internal_keyword] = ACTIONS(9651),
    [sym_protected_keyword] = ACTIONS(9651),
    [sym_event_keyword] = ACTIONS(9651),
    [sym_fields_keyword] = ACTIONS(9651),
    [sym_keys_keyword] = ACTIONS(9651),
    [sym_fieldgroups_keyword] = ACTIONS(9651),
    [sym_actions_keyword] = ACTIONS(9651),
    [sym_layout_keyword] = ACTIONS(9651),
    [sym_area_keyword] = ACTIONS(9651),
    [sym_group_keyword] = ACTIONS(9651),
    [sym_repeater_keyword] = ACTIONS(9651),
    [sym_cuegroup_keyword] = ACTIONS(9651),
    [sym_fixed_keyword] = ACTIONS(9651),
    [sym_grid_keyword] = ACTIONS(9651),
    [sym_part_keyword] = ACTIONS(9651),
    [sym_systempart_keyword] = ACTIONS(9651),
    [sym_usercontrol_keyword] = ACTIONS(9651),
    [sym_dataset_keyword] = ACTIONS(9651),
    [sym_elements_keyword] = ACTIONS(9651),
    [sym_dataitem_keyword] = ACTIONS(9651),
    [sym_column_keyword] = ACTIONS(9651),
    [sym_filter_keyword] = ACTIONS(9651),
    [sym_labels_keyword] = ACTIONS(9651),
    [sym_rendering_keyword] = ACTIONS(9651),
    [sym_requestpage_keyword] = ACTIONS(9651),
    [sym_schema_keyword] = ACTIONS(9651),
    [sym_views_keyword] = ACTIONS(9651),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9651),
    [sym_preproc_open] = ACTIONS(9651),
    [sym_preproc_close] = ACTIONS(9651),
  },
  [STATE(3584)] = {
    [anon_sym_SEMI] = ACTIONS(9655),
    [aux_sym_where_condition_token1] = ACTIONS(9657),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9655),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9655),
    [anon_sym_LBRACK] = ACTIONS(9655),
    [aux_sym_basic_type_token6] = ACTIONS(9657),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9655),
    [aux_sym_addafter_modification_token1] = ACTIONS(9655),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9655),
    [aux_sym_modify_modification_token1] = ACTIONS(9655),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9655),
    [aux_sym_movelast_modification_token1] = ACTIONS(9655),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9655),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9655),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9655),
    [anon_sym_POUNDif] = ACTIONS(9655),
    [anon_sym_POUNDIF] = ACTIONS(9655),
    [anon_sym_POUNDIf] = ACTIONS(9655),
    [anon_sym_POUNDelif] = ACTIONS(9655),
    [anon_sym_POUNDELIF] = ACTIONS(9655),
    [anon_sym_POUNDElif] = ACTIONS(9655),
    [anon_sym_POUNDelse] = ACTIONS(9655),
    [anon_sym_POUNDELSE] = ACTIONS(9655),
    [anon_sym_POUNDElse] = ACTIONS(9655),
    [anon_sym_POUNDendif] = ACTIONS(9655),
    [anon_sym_POUNDENDIF] = ACTIONS(9655),
    [anon_sym_POUNDEndif] = ACTIONS(9655),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9655),
    [sym_trigger_keyword] = ACTIONS(9655),
    [sym_var_keyword] = ACTIONS(9655),
    [sym_local_keyword] = ACTIONS(9655),
    [sym_internal_keyword] = ACTIONS(9655),
    [sym_protected_keyword] = ACTIONS(9655),
    [sym_event_keyword] = ACTIONS(9655),
    [sym_fields_keyword] = ACTIONS(9655),
    [sym_keys_keyword] = ACTIONS(9655),
    [sym_fieldgroups_keyword] = ACTIONS(9655),
    [sym_actions_keyword] = ACTIONS(9655),
    [sym_layout_keyword] = ACTIONS(9655),
    [sym_area_keyword] = ACTIONS(9655),
    [sym_group_keyword] = ACTIONS(9655),
    [sym_repeater_keyword] = ACTIONS(9655),
    [sym_cuegroup_keyword] = ACTIONS(9655),
    [sym_fixed_keyword] = ACTIONS(9655),
    [sym_grid_keyword] = ACTIONS(9655),
    [sym_part_keyword] = ACTIONS(9655),
    [sym_systempart_keyword] = ACTIONS(9655),
    [sym_usercontrol_keyword] = ACTIONS(9655),
    [sym_dataset_keyword] = ACTIONS(9655),
    [sym_elements_keyword] = ACTIONS(9655),
    [sym_dataitem_keyword] = ACTIONS(9655),
    [sym_column_keyword] = ACTIONS(9655),
    [sym_filter_keyword] = ACTIONS(9655),
    [sym_labels_keyword] = ACTIONS(9655),
    [sym_rendering_keyword] = ACTIONS(9655),
    [sym_requestpage_keyword] = ACTIONS(9655),
    [sym_schema_keyword] = ACTIONS(9655),
    [sym_views_keyword] = ACTIONS(9655),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9655),
    [sym_preproc_open] = ACTIONS(9655),
    [sym_preproc_close] = ACTIONS(9655),
  },
  [STATE(3585)] = {
    [anon_sym_SEMI] = ACTIONS(9655),
    [aux_sym_where_condition_token1] = ACTIONS(9657),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9655),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9655),
    [anon_sym_LBRACK] = ACTIONS(9655),
    [aux_sym_basic_type_token6] = ACTIONS(9657),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9655),
    [aux_sym_addafter_modification_token1] = ACTIONS(9655),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9655),
    [aux_sym_modify_modification_token1] = ACTIONS(9655),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9655),
    [aux_sym_movelast_modification_token1] = ACTIONS(9655),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9655),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9655),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9655),
    [anon_sym_POUNDif] = ACTIONS(9655),
    [anon_sym_POUNDIF] = ACTIONS(9655),
    [anon_sym_POUNDIf] = ACTIONS(9655),
    [anon_sym_POUNDelif] = ACTIONS(9655),
    [anon_sym_POUNDELIF] = ACTIONS(9655),
    [anon_sym_POUNDElif] = ACTIONS(9655),
    [anon_sym_POUNDelse] = ACTIONS(9655),
    [anon_sym_POUNDELSE] = ACTIONS(9655),
    [anon_sym_POUNDElse] = ACTIONS(9655),
    [anon_sym_POUNDendif] = ACTIONS(9655),
    [anon_sym_POUNDENDIF] = ACTIONS(9655),
    [anon_sym_POUNDEndif] = ACTIONS(9655),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9655),
    [sym_trigger_keyword] = ACTIONS(9655),
    [sym_var_keyword] = ACTIONS(9655),
    [sym_local_keyword] = ACTIONS(9655),
    [sym_internal_keyword] = ACTIONS(9655),
    [sym_protected_keyword] = ACTIONS(9655),
    [sym_event_keyword] = ACTIONS(9655),
    [sym_fields_keyword] = ACTIONS(9655),
    [sym_keys_keyword] = ACTIONS(9655),
    [sym_fieldgroups_keyword] = ACTIONS(9655),
    [sym_actions_keyword] = ACTIONS(9655),
    [sym_layout_keyword] = ACTIONS(9655),
    [sym_area_keyword] = ACTIONS(9655),
    [sym_group_keyword] = ACTIONS(9655),
    [sym_repeater_keyword] = ACTIONS(9655),
    [sym_cuegroup_keyword] = ACTIONS(9655),
    [sym_fixed_keyword] = ACTIONS(9655),
    [sym_grid_keyword] = ACTIONS(9655),
    [sym_part_keyword] = ACTIONS(9655),
    [sym_systempart_keyword] = ACTIONS(9655),
    [sym_usercontrol_keyword] = ACTIONS(9655),
    [sym_dataset_keyword] = ACTIONS(9655),
    [sym_elements_keyword] = ACTIONS(9655),
    [sym_dataitem_keyword] = ACTIONS(9655),
    [sym_column_keyword] = ACTIONS(9655),
    [sym_filter_keyword] = ACTIONS(9655),
    [sym_labels_keyword] = ACTIONS(9655),
    [sym_rendering_keyword] = ACTIONS(9655),
    [sym_requestpage_keyword] = ACTIONS(9655),
    [sym_schema_keyword] = ACTIONS(9655),
    [sym_views_keyword] = ACTIONS(9655),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9655),
    [sym_preproc_open] = ACTIONS(9655),
    [sym_preproc_close] = ACTIONS(9655),
  },
  [STATE(3586)] = {
    [anon_sym_SEMI] = ACTIONS(9655),
    [aux_sym_where_condition_token1] = ACTIONS(9657),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9655),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9655),
    [anon_sym_LBRACK] = ACTIONS(9655),
    [aux_sym_basic_type_token6] = ACTIONS(9657),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9655),
    [aux_sym_addafter_modification_token1] = ACTIONS(9655),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9655),
    [aux_sym_modify_modification_token1] = ACTIONS(9655),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9655),
    [aux_sym_movelast_modification_token1] = ACTIONS(9655),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9655),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9655),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9655),
    [anon_sym_POUNDif] = ACTIONS(9655),
    [anon_sym_POUNDIF] = ACTIONS(9655),
    [anon_sym_POUNDIf] = ACTIONS(9655),
    [anon_sym_POUNDelif] = ACTIONS(9655),
    [anon_sym_POUNDELIF] = ACTIONS(9655),
    [anon_sym_POUNDElif] = ACTIONS(9655),
    [anon_sym_POUNDelse] = ACTIONS(9655),
    [anon_sym_POUNDELSE] = ACTIONS(9655),
    [anon_sym_POUNDElse] = ACTIONS(9655),
    [anon_sym_POUNDendif] = ACTIONS(9655),
    [anon_sym_POUNDENDIF] = ACTIONS(9655),
    [anon_sym_POUNDEndif] = ACTIONS(9655),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9655),
    [sym_trigger_keyword] = ACTIONS(9655),
    [sym_var_keyword] = ACTIONS(9655),
    [sym_local_keyword] = ACTIONS(9655),
    [sym_internal_keyword] = ACTIONS(9655),
    [sym_protected_keyword] = ACTIONS(9655),
    [sym_event_keyword] = ACTIONS(9655),
    [sym_fields_keyword] = ACTIONS(9655),
    [sym_keys_keyword] = ACTIONS(9655),
    [sym_fieldgroups_keyword] = ACTIONS(9655),
    [sym_actions_keyword] = ACTIONS(9655),
    [sym_layout_keyword] = ACTIONS(9655),
    [sym_area_keyword] = ACTIONS(9655),
    [sym_group_keyword] = ACTIONS(9655),
    [sym_repeater_keyword] = ACTIONS(9655),
    [sym_cuegroup_keyword] = ACTIONS(9655),
    [sym_fixed_keyword] = ACTIONS(9655),
    [sym_grid_keyword] = ACTIONS(9655),
    [sym_part_keyword] = ACTIONS(9655),
    [sym_systempart_keyword] = ACTIONS(9655),
    [sym_usercontrol_keyword] = ACTIONS(9655),
    [sym_dataset_keyword] = ACTIONS(9655),
    [sym_elements_keyword] = ACTIONS(9655),
    [sym_dataitem_keyword] = ACTIONS(9655),
    [sym_column_keyword] = ACTIONS(9655),
    [sym_filter_keyword] = ACTIONS(9655),
    [sym_labels_keyword] = ACTIONS(9655),
    [sym_rendering_keyword] = ACTIONS(9655),
    [sym_requestpage_keyword] = ACTIONS(9655),
    [sym_schema_keyword] = ACTIONS(9655),
    [sym_views_keyword] = ACTIONS(9655),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9655),
    [sym_preproc_open] = ACTIONS(9655),
    [sym_preproc_close] = ACTIONS(9655),
  },
  [STATE(3587)] = {
    [anon_sym_SEMI] = ACTIONS(9655),
    [aux_sym_where_condition_token1] = ACTIONS(9657),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9655),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9655),
    [anon_sym_LBRACK] = ACTIONS(9655),
    [aux_sym_basic_type_token6] = ACTIONS(9657),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9655),
    [aux_sym_addafter_modification_token1] = ACTIONS(9655),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9655),
    [aux_sym_modify_modification_token1] = ACTIONS(9655),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9655),
    [aux_sym_movelast_modification_token1] = ACTIONS(9655),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9655),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9655),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9655),
    [anon_sym_POUNDif] = ACTIONS(9655),
    [anon_sym_POUNDIF] = ACTIONS(9655),
    [anon_sym_POUNDIf] = ACTIONS(9655),
    [anon_sym_POUNDelif] = ACTIONS(9655),
    [anon_sym_POUNDELIF] = ACTIONS(9655),
    [anon_sym_POUNDElif] = ACTIONS(9655),
    [anon_sym_POUNDelse] = ACTIONS(9655),
    [anon_sym_POUNDELSE] = ACTIONS(9655),
    [anon_sym_POUNDElse] = ACTIONS(9655),
    [anon_sym_POUNDendif] = ACTIONS(9655),
    [anon_sym_POUNDENDIF] = ACTIONS(9655),
    [anon_sym_POUNDEndif] = ACTIONS(9655),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9655),
    [sym_trigger_keyword] = ACTIONS(9655),
    [sym_var_keyword] = ACTIONS(9655),
    [sym_local_keyword] = ACTIONS(9655),
    [sym_internal_keyword] = ACTIONS(9655),
    [sym_protected_keyword] = ACTIONS(9655),
    [sym_event_keyword] = ACTIONS(9655),
    [sym_fields_keyword] = ACTIONS(9655),
    [sym_keys_keyword] = ACTIONS(9655),
    [sym_fieldgroups_keyword] = ACTIONS(9655),
    [sym_actions_keyword] = ACTIONS(9655),
    [sym_layout_keyword] = ACTIONS(9655),
    [sym_area_keyword] = ACTIONS(9655),
    [sym_group_keyword] = ACTIONS(9655),
    [sym_repeater_keyword] = ACTIONS(9655),
    [sym_cuegroup_keyword] = ACTIONS(9655),
    [sym_fixed_keyword] = ACTIONS(9655),
    [sym_grid_keyword] = ACTIONS(9655),
    [sym_part_keyword] = ACTIONS(9655),
    [sym_systempart_keyword] = ACTIONS(9655),
    [sym_usercontrol_keyword] = ACTIONS(9655),
    [sym_dataset_keyword] = ACTIONS(9655),
    [sym_elements_keyword] = ACTIONS(9655),
    [sym_dataitem_keyword] = ACTIONS(9655),
    [sym_column_keyword] = ACTIONS(9655),
    [sym_filter_keyword] = ACTIONS(9655),
    [sym_labels_keyword] = ACTIONS(9655),
    [sym_rendering_keyword] = ACTIONS(9655),
    [sym_requestpage_keyword] = ACTIONS(9655),
    [sym_schema_keyword] = ACTIONS(9655),
    [sym_views_keyword] = ACTIONS(9655),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9655),
    [sym_preproc_open] = ACTIONS(9655),
    [sym_preproc_close] = ACTIONS(9655),
  },
  [STATE(3588)] = {
    [anon_sym_SEMI] = ACTIONS(9659),
    [aux_sym_where_condition_token1] = ACTIONS(9661),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9659),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9659),
    [anon_sym_LBRACK] = ACTIONS(9659),
    [aux_sym_basic_type_token6] = ACTIONS(9661),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9659),
    [aux_sym_addafter_modification_token1] = ACTIONS(9659),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9659),
    [aux_sym_modify_modification_token1] = ACTIONS(9659),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9659),
    [aux_sym_movelast_modification_token1] = ACTIONS(9659),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9659),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9659),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9659),
    [anon_sym_POUNDif] = ACTIONS(9659),
    [anon_sym_POUNDIF] = ACTIONS(9659),
    [anon_sym_POUNDIf] = ACTIONS(9659),
    [anon_sym_POUNDelif] = ACTIONS(9659),
    [anon_sym_POUNDELIF] = ACTIONS(9659),
    [anon_sym_POUNDElif] = ACTIONS(9659),
    [anon_sym_POUNDelse] = ACTIONS(9659),
    [anon_sym_POUNDELSE] = ACTIONS(9659),
    [anon_sym_POUNDElse] = ACTIONS(9659),
    [anon_sym_POUNDendif] = ACTIONS(9659),
    [anon_sym_POUNDENDIF] = ACTIONS(9659),
    [anon_sym_POUNDEndif] = ACTIONS(9659),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9659),
    [sym_trigger_keyword] = ACTIONS(9659),
    [sym_var_keyword] = ACTIONS(9659),
    [sym_local_keyword] = ACTIONS(9659),
    [sym_internal_keyword] = ACTIONS(9659),
    [sym_protected_keyword] = ACTIONS(9659),
    [sym_event_keyword] = ACTIONS(9659),
    [sym_fields_keyword] = ACTIONS(9659),
    [sym_keys_keyword] = ACTIONS(9659),
    [sym_fieldgroups_keyword] = ACTIONS(9659),
    [sym_actions_keyword] = ACTIONS(9659),
    [sym_layout_keyword] = ACTIONS(9659),
    [sym_area_keyword] = ACTIONS(9659),
    [sym_group_keyword] = ACTIONS(9659),
    [sym_repeater_keyword] = ACTIONS(9659),
    [sym_cuegroup_keyword] = ACTIONS(9659),
    [sym_fixed_keyword] = ACTIONS(9659),
    [sym_grid_keyword] = ACTIONS(9659),
    [sym_part_keyword] = ACTIONS(9659),
    [sym_systempart_keyword] = ACTIONS(9659),
    [sym_usercontrol_keyword] = ACTIONS(9659),
    [sym_dataset_keyword] = ACTIONS(9659),
    [sym_elements_keyword] = ACTIONS(9659),
    [sym_dataitem_keyword] = ACTIONS(9659),
    [sym_column_keyword] = ACTIONS(9659),
    [sym_filter_keyword] = ACTIONS(9659),
    [sym_labels_keyword] = ACTIONS(9659),
    [sym_rendering_keyword] = ACTIONS(9659),
    [sym_requestpage_keyword] = ACTIONS(9659),
    [sym_schema_keyword] = ACTIONS(9659),
    [sym_views_keyword] = ACTIONS(9659),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9659),
    [sym_preproc_open] = ACTIONS(9659),
    [sym_preproc_close] = ACTIONS(9659),
  },
  [STATE(3589)] = {
    [anon_sym_SEMI] = ACTIONS(9659),
    [aux_sym_where_condition_token1] = ACTIONS(9661),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9659),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9659),
    [anon_sym_LBRACK] = ACTIONS(9659),
    [aux_sym_basic_type_token6] = ACTIONS(9661),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9659),
    [aux_sym_addafter_modification_token1] = ACTIONS(9659),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9659),
    [aux_sym_modify_modification_token1] = ACTIONS(9659),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9659),
    [aux_sym_movelast_modification_token1] = ACTIONS(9659),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9659),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9659),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9659),
    [anon_sym_POUNDif] = ACTIONS(9659),
    [anon_sym_POUNDIF] = ACTIONS(9659),
    [anon_sym_POUNDIf] = ACTIONS(9659),
    [anon_sym_POUNDelif] = ACTIONS(9659),
    [anon_sym_POUNDELIF] = ACTIONS(9659),
    [anon_sym_POUNDElif] = ACTIONS(9659),
    [anon_sym_POUNDelse] = ACTIONS(9659),
    [anon_sym_POUNDELSE] = ACTIONS(9659),
    [anon_sym_POUNDElse] = ACTIONS(9659),
    [anon_sym_POUNDendif] = ACTIONS(9659),
    [anon_sym_POUNDENDIF] = ACTIONS(9659),
    [anon_sym_POUNDEndif] = ACTIONS(9659),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9659),
    [sym_trigger_keyword] = ACTIONS(9659),
    [sym_var_keyword] = ACTIONS(9659),
    [sym_local_keyword] = ACTIONS(9659),
    [sym_internal_keyword] = ACTIONS(9659),
    [sym_protected_keyword] = ACTIONS(9659),
    [sym_event_keyword] = ACTIONS(9659),
    [sym_fields_keyword] = ACTIONS(9659),
    [sym_keys_keyword] = ACTIONS(9659),
    [sym_fieldgroups_keyword] = ACTIONS(9659),
    [sym_actions_keyword] = ACTIONS(9659),
    [sym_layout_keyword] = ACTIONS(9659),
    [sym_area_keyword] = ACTIONS(9659),
    [sym_group_keyword] = ACTIONS(9659),
    [sym_repeater_keyword] = ACTIONS(9659),
    [sym_cuegroup_keyword] = ACTIONS(9659),
    [sym_fixed_keyword] = ACTIONS(9659),
    [sym_grid_keyword] = ACTIONS(9659),
    [sym_part_keyword] = ACTIONS(9659),
    [sym_systempart_keyword] = ACTIONS(9659),
    [sym_usercontrol_keyword] = ACTIONS(9659),
    [sym_dataset_keyword] = ACTIONS(9659),
    [sym_elements_keyword] = ACTIONS(9659),
    [sym_dataitem_keyword] = ACTIONS(9659),
    [sym_column_keyword] = ACTIONS(9659),
    [sym_filter_keyword] = ACTIONS(9659),
    [sym_labels_keyword] = ACTIONS(9659),
    [sym_rendering_keyword] = ACTIONS(9659),
    [sym_requestpage_keyword] = ACTIONS(9659),
    [sym_schema_keyword] = ACTIONS(9659),
    [sym_views_keyword] = ACTIONS(9659),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9659),
    [sym_preproc_open] = ACTIONS(9659),
    [sym_preproc_close] = ACTIONS(9659),
  },
  [STATE(3590)] = {
    [anon_sym_SEMI] = ACTIONS(9659),
    [aux_sym_where_condition_token1] = ACTIONS(9661),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9659),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9659),
    [anon_sym_LBRACK] = ACTIONS(9659),
    [aux_sym_basic_type_token6] = ACTIONS(9661),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9659),
    [aux_sym_addafter_modification_token1] = ACTIONS(9659),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9659),
    [aux_sym_modify_modification_token1] = ACTIONS(9659),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9659),
    [aux_sym_movelast_modification_token1] = ACTIONS(9659),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9659),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9659),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9659),
    [anon_sym_POUNDif] = ACTIONS(9659),
    [anon_sym_POUNDIF] = ACTIONS(9659),
    [anon_sym_POUNDIf] = ACTIONS(9659),
    [anon_sym_POUNDelif] = ACTIONS(9659),
    [anon_sym_POUNDELIF] = ACTIONS(9659),
    [anon_sym_POUNDElif] = ACTIONS(9659),
    [anon_sym_POUNDelse] = ACTIONS(9659),
    [anon_sym_POUNDELSE] = ACTIONS(9659),
    [anon_sym_POUNDElse] = ACTIONS(9659),
    [anon_sym_POUNDendif] = ACTIONS(9659),
    [anon_sym_POUNDENDIF] = ACTIONS(9659),
    [anon_sym_POUNDEndif] = ACTIONS(9659),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9659),
    [sym_trigger_keyword] = ACTIONS(9659),
    [sym_var_keyword] = ACTIONS(9659),
    [sym_local_keyword] = ACTIONS(9659),
    [sym_internal_keyword] = ACTIONS(9659),
    [sym_protected_keyword] = ACTIONS(9659),
    [sym_event_keyword] = ACTIONS(9659),
    [sym_fields_keyword] = ACTIONS(9659),
    [sym_keys_keyword] = ACTIONS(9659),
    [sym_fieldgroups_keyword] = ACTIONS(9659),
    [sym_actions_keyword] = ACTIONS(9659),
    [sym_layout_keyword] = ACTIONS(9659),
    [sym_area_keyword] = ACTIONS(9659),
    [sym_group_keyword] = ACTIONS(9659),
    [sym_repeater_keyword] = ACTIONS(9659),
    [sym_cuegroup_keyword] = ACTIONS(9659),
    [sym_fixed_keyword] = ACTIONS(9659),
    [sym_grid_keyword] = ACTIONS(9659),
    [sym_part_keyword] = ACTIONS(9659),
    [sym_systempart_keyword] = ACTIONS(9659),
    [sym_usercontrol_keyword] = ACTIONS(9659),
    [sym_dataset_keyword] = ACTIONS(9659),
    [sym_elements_keyword] = ACTIONS(9659),
    [sym_dataitem_keyword] = ACTIONS(9659),
    [sym_column_keyword] = ACTIONS(9659),
    [sym_filter_keyword] = ACTIONS(9659),
    [sym_labels_keyword] = ACTIONS(9659),
    [sym_rendering_keyword] = ACTIONS(9659),
    [sym_requestpage_keyword] = ACTIONS(9659),
    [sym_schema_keyword] = ACTIONS(9659),
    [sym_views_keyword] = ACTIONS(9659),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9659),
    [sym_preproc_open] = ACTIONS(9659),
    [sym_preproc_close] = ACTIONS(9659),
  },
  [STATE(3591)] = {
    [anon_sym_SEMI] = ACTIONS(9659),
    [aux_sym_where_condition_token1] = ACTIONS(9661),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9659),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9659),
    [anon_sym_LBRACK] = ACTIONS(9659),
    [aux_sym_basic_type_token6] = ACTIONS(9661),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9659),
    [aux_sym_addafter_modification_token1] = ACTIONS(9659),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9659),
    [aux_sym_modify_modification_token1] = ACTIONS(9659),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9659),
    [aux_sym_movelast_modification_token1] = ACTIONS(9659),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9659),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9659),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9659),
    [anon_sym_POUNDif] = ACTIONS(9659),
    [anon_sym_POUNDIF] = ACTIONS(9659),
    [anon_sym_POUNDIf] = ACTIONS(9659),
    [anon_sym_POUNDelif] = ACTIONS(9659),
    [anon_sym_POUNDELIF] = ACTIONS(9659),
    [anon_sym_POUNDElif] = ACTIONS(9659),
    [anon_sym_POUNDelse] = ACTIONS(9659),
    [anon_sym_POUNDELSE] = ACTIONS(9659),
    [anon_sym_POUNDElse] = ACTIONS(9659),
    [anon_sym_POUNDendif] = ACTIONS(9659),
    [anon_sym_POUNDENDIF] = ACTIONS(9659),
    [anon_sym_POUNDEndif] = ACTIONS(9659),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9659),
    [sym_trigger_keyword] = ACTIONS(9659),
    [sym_var_keyword] = ACTIONS(9659),
    [sym_local_keyword] = ACTIONS(9659),
    [sym_internal_keyword] = ACTIONS(9659),
    [sym_protected_keyword] = ACTIONS(9659),
    [sym_event_keyword] = ACTIONS(9659),
    [sym_fields_keyword] = ACTIONS(9659),
    [sym_keys_keyword] = ACTIONS(9659),
    [sym_fieldgroups_keyword] = ACTIONS(9659),
    [sym_actions_keyword] = ACTIONS(9659),
    [sym_layout_keyword] = ACTIONS(9659),
    [sym_area_keyword] = ACTIONS(9659),
    [sym_group_keyword] = ACTIONS(9659),
    [sym_repeater_keyword] = ACTIONS(9659),
    [sym_cuegroup_keyword] = ACTIONS(9659),
    [sym_fixed_keyword] = ACTIONS(9659),
    [sym_grid_keyword] = ACTIONS(9659),
    [sym_part_keyword] = ACTIONS(9659),
    [sym_systempart_keyword] = ACTIONS(9659),
    [sym_usercontrol_keyword] = ACTIONS(9659),
    [sym_dataset_keyword] = ACTIONS(9659),
    [sym_elements_keyword] = ACTIONS(9659),
    [sym_dataitem_keyword] = ACTIONS(9659),
    [sym_column_keyword] = ACTIONS(9659),
    [sym_filter_keyword] = ACTIONS(9659),
    [sym_labels_keyword] = ACTIONS(9659),
    [sym_rendering_keyword] = ACTIONS(9659),
    [sym_requestpage_keyword] = ACTIONS(9659),
    [sym_schema_keyword] = ACTIONS(9659),
    [sym_views_keyword] = ACTIONS(9659),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9659),
    [sym_preproc_open] = ACTIONS(9659),
    [sym_preproc_close] = ACTIONS(9659),
  },
  [STATE(3592)] = {
    [anon_sym_SEMI] = ACTIONS(9663),
    [aux_sym_where_condition_token1] = ACTIONS(9665),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9663),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9663),
    [anon_sym_LBRACK] = ACTIONS(9663),
    [aux_sym_basic_type_token6] = ACTIONS(9665),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9663),
    [aux_sym_addafter_modification_token1] = ACTIONS(9663),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9663),
    [aux_sym_modify_modification_token1] = ACTIONS(9663),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9663),
    [aux_sym_movelast_modification_token1] = ACTIONS(9663),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9663),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9663),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9663),
    [anon_sym_POUNDif] = ACTIONS(9663),
    [anon_sym_POUNDIF] = ACTIONS(9663),
    [anon_sym_POUNDIf] = ACTIONS(9663),
    [anon_sym_POUNDelif] = ACTIONS(9663),
    [anon_sym_POUNDELIF] = ACTIONS(9663),
    [anon_sym_POUNDElif] = ACTIONS(9663),
    [anon_sym_POUNDelse] = ACTIONS(9663),
    [anon_sym_POUNDELSE] = ACTIONS(9663),
    [anon_sym_POUNDElse] = ACTIONS(9663),
    [anon_sym_POUNDendif] = ACTIONS(9663),
    [anon_sym_POUNDENDIF] = ACTIONS(9663),
    [anon_sym_POUNDEndif] = ACTIONS(9663),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9663),
    [sym_trigger_keyword] = ACTIONS(9663),
    [sym_var_keyword] = ACTIONS(9663),
    [sym_local_keyword] = ACTIONS(9663),
    [sym_internal_keyword] = ACTIONS(9663),
    [sym_protected_keyword] = ACTIONS(9663),
    [sym_event_keyword] = ACTIONS(9663),
    [sym_fields_keyword] = ACTIONS(9663),
    [sym_keys_keyword] = ACTIONS(9663),
    [sym_fieldgroups_keyword] = ACTIONS(9663),
    [sym_actions_keyword] = ACTIONS(9663),
    [sym_layout_keyword] = ACTIONS(9663),
    [sym_area_keyword] = ACTIONS(9663),
    [sym_group_keyword] = ACTIONS(9663),
    [sym_repeater_keyword] = ACTIONS(9663),
    [sym_cuegroup_keyword] = ACTIONS(9663),
    [sym_fixed_keyword] = ACTIONS(9663),
    [sym_grid_keyword] = ACTIONS(9663),
    [sym_part_keyword] = ACTIONS(9663),
    [sym_systempart_keyword] = ACTIONS(9663),
    [sym_usercontrol_keyword] = ACTIONS(9663),
    [sym_dataset_keyword] = ACTIONS(9663),
    [sym_elements_keyword] = ACTIONS(9663),
    [sym_dataitem_keyword] = ACTIONS(9663),
    [sym_column_keyword] = ACTIONS(9663),
    [sym_filter_keyword] = ACTIONS(9663),
    [sym_labels_keyword] = ACTIONS(9663),
    [sym_rendering_keyword] = ACTIONS(9663),
    [sym_requestpage_keyword] = ACTIONS(9663),
    [sym_schema_keyword] = ACTIONS(9663),
    [sym_views_keyword] = ACTIONS(9663),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9663),
    [sym_preproc_open] = ACTIONS(9663),
    [sym_preproc_close] = ACTIONS(9663),
  },
  [STATE(3593)] = {
    [anon_sym_SEMI] = ACTIONS(9663),
    [aux_sym_where_condition_token1] = ACTIONS(9665),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9663),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9663),
    [anon_sym_LBRACK] = ACTIONS(9663),
    [aux_sym_basic_type_token6] = ACTIONS(9665),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9663),
    [aux_sym_addafter_modification_token1] = ACTIONS(9663),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9663),
    [aux_sym_modify_modification_token1] = ACTIONS(9663),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9663),
    [aux_sym_movelast_modification_token1] = ACTIONS(9663),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9663),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9663),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9663),
    [anon_sym_POUNDif] = ACTIONS(9663),
    [anon_sym_POUNDIF] = ACTIONS(9663),
    [anon_sym_POUNDIf] = ACTIONS(9663),
    [anon_sym_POUNDelif] = ACTIONS(9663),
    [anon_sym_POUNDELIF] = ACTIONS(9663),
    [anon_sym_POUNDElif] = ACTIONS(9663),
    [anon_sym_POUNDelse] = ACTIONS(9663),
    [anon_sym_POUNDELSE] = ACTIONS(9663),
    [anon_sym_POUNDElse] = ACTIONS(9663),
    [anon_sym_POUNDendif] = ACTIONS(9663),
    [anon_sym_POUNDENDIF] = ACTIONS(9663),
    [anon_sym_POUNDEndif] = ACTIONS(9663),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9663),
    [sym_trigger_keyword] = ACTIONS(9663),
    [sym_var_keyword] = ACTIONS(9663),
    [sym_local_keyword] = ACTIONS(9663),
    [sym_internal_keyword] = ACTIONS(9663),
    [sym_protected_keyword] = ACTIONS(9663),
    [sym_event_keyword] = ACTIONS(9663),
    [sym_fields_keyword] = ACTIONS(9663),
    [sym_keys_keyword] = ACTIONS(9663),
    [sym_fieldgroups_keyword] = ACTIONS(9663),
    [sym_actions_keyword] = ACTIONS(9663),
    [sym_layout_keyword] = ACTIONS(9663),
    [sym_area_keyword] = ACTIONS(9663),
    [sym_group_keyword] = ACTIONS(9663),
    [sym_repeater_keyword] = ACTIONS(9663),
    [sym_cuegroup_keyword] = ACTIONS(9663),
    [sym_fixed_keyword] = ACTIONS(9663),
    [sym_grid_keyword] = ACTIONS(9663),
    [sym_part_keyword] = ACTIONS(9663),
    [sym_systempart_keyword] = ACTIONS(9663),
    [sym_usercontrol_keyword] = ACTIONS(9663),
    [sym_dataset_keyword] = ACTIONS(9663),
    [sym_elements_keyword] = ACTIONS(9663),
    [sym_dataitem_keyword] = ACTIONS(9663),
    [sym_column_keyword] = ACTIONS(9663),
    [sym_filter_keyword] = ACTIONS(9663),
    [sym_labels_keyword] = ACTIONS(9663),
    [sym_rendering_keyword] = ACTIONS(9663),
    [sym_requestpage_keyword] = ACTIONS(9663),
    [sym_schema_keyword] = ACTIONS(9663),
    [sym_views_keyword] = ACTIONS(9663),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9663),
    [sym_preproc_open] = ACTIONS(9663),
    [sym_preproc_close] = ACTIONS(9663),
  },
  [STATE(3594)] = {
    [anon_sym_SEMI] = ACTIONS(5449),
    [aux_sym_where_condition_token1] = ACTIONS(5447),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5449),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5449),
    [anon_sym_LBRACK] = ACTIONS(5449),
    [aux_sym_basic_type_token6] = ACTIONS(5447),
    [aux_sym_basic_type_token22] = ACTIONS(5447),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5449),
    [aux_sym_addafter_modification_token1] = ACTIONS(5449),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5449),
    [aux_sym_modify_modification_token1] = ACTIONS(5449),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5449),
    [aux_sym_movelast_modification_token1] = ACTIONS(5449),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5449),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5449),
    [aux_sym_separator_action_token1] = ACTIONS(5449),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5449),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5449),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5449),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5449),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5449),
    [anon_sym_POUNDif] = ACTIONS(5449),
    [anon_sym_POUNDIF] = ACTIONS(5449),
    [anon_sym_POUNDIf] = ACTIONS(5449),
    [anon_sym_POUNDendif] = ACTIONS(5449),
    [anon_sym_POUNDENDIF] = ACTIONS(5449),
    [anon_sym_POUNDEndif] = ACTIONS(5449),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5449),
    [sym_trigger_keyword] = ACTIONS(5449),
    [sym_var_keyword] = ACTIONS(5449),
    [sym_local_keyword] = ACTIONS(5449),
    [sym_internal_keyword] = ACTIONS(5449),
    [sym_protected_keyword] = ACTIONS(5449),
    [sym_event_keyword] = ACTIONS(5449),
    [sym_fields_keyword] = ACTIONS(5449),
    [sym_keys_keyword] = ACTIONS(5449),
    [sym_fieldgroups_keyword] = ACTIONS(5449),
    [sym_actions_keyword] = ACTIONS(5449),
    [sym_layout_keyword] = ACTIONS(5449),
    [sym_area_keyword] = ACTIONS(5449),
    [sym_group_keyword] = ACTIONS(5449),
    [sym_repeater_keyword] = ACTIONS(5449),
    [sym_cuegroup_keyword] = ACTIONS(5449),
    [sym_fixed_keyword] = ACTIONS(5449),
    [sym_grid_keyword] = ACTIONS(5449),
    [sym_part_keyword] = ACTIONS(5449),
    [sym_systempart_keyword] = ACTIONS(5449),
    [sym_usercontrol_keyword] = ACTIONS(5449),
    [sym_dataset_keyword] = ACTIONS(5449),
    [sym_elements_keyword] = ACTIONS(5449),
    [sym_dataitem_keyword] = ACTIONS(5449),
    [sym_column_keyword] = ACTIONS(5449),
    [sym_filter_keyword] = ACTIONS(5449),
    [sym_labels_keyword] = ACTIONS(5449),
    [sym_rendering_keyword] = ACTIONS(5449),
    [sym_requestpage_keyword] = ACTIONS(5449),
    [sym_schema_keyword] = ACTIONS(5449),
    [sym_views_keyword] = ACTIONS(5449),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5449),
    [sym_preproc_open] = ACTIONS(5449),
    [sym_preproc_close] = ACTIONS(5449),
  },
  [STATE(3595)] = {
    [anon_sym_SEMI] = ACTIONS(9667),
    [aux_sym_where_condition_token1] = ACTIONS(9669),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9667),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9667),
    [anon_sym_LBRACK] = ACTIONS(9667),
    [aux_sym_basic_type_token6] = ACTIONS(9669),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9667),
    [aux_sym_addafter_modification_token1] = ACTIONS(9667),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9667),
    [aux_sym_modify_modification_token1] = ACTIONS(9667),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9667),
    [aux_sym_movelast_modification_token1] = ACTIONS(9667),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9667),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9667),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9667),
    [anon_sym_POUNDif] = ACTIONS(9667),
    [anon_sym_POUNDIF] = ACTIONS(9667),
    [anon_sym_POUNDIf] = ACTIONS(9667),
    [anon_sym_POUNDelif] = ACTIONS(9667),
    [anon_sym_POUNDELIF] = ACTIONS(9667),
    [anon_sym_POUNDElif] = ACTIONS(9667),
    [anon_sym_POUNDelse] = ACTIONS(9667),
    [anon_sym_POUNDELSE] = ACTIONS(9667),
    [anon_sym_POUNDElse] = ACTIONS(9667),
    [anon_sym_POUNDendif] = ACTIONS(9667),
    [anon_sym_POUNDENDIF] = ACTIONS(9667),
    [anon_sym_POUNDEndif] = ACTIONS(9667),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9667),
    [sym_trigger_keyword] = ACTIONS(9667),
    [sym_var_keyword] = ACTIONS(9667),
    [sym_local_keyword] = ACTIONS(9667),
    [sym_internal_keyword] = ACTIONS(9667),
    [sym_protected_keyword] = ACTIONS(9667),
    [sym_event_keyword] = ACTIONS(9667),
    [sym_fields_keyword] = ACTIONS(9667),
    [sym_keys_keyword] = ACTIONS(9667),
    [sym_fieldgroups_keyword] = ACTIONS(9667),
    [sym_actions_keyword] = ACTIONS(9667),
    [sym_layout_keyword] = ACTIONS(9667),
    [sym_area_keyword] = ACTIONS(9667),
    [sym_group_keyword] = ACTIONS(9667),
    [sym_repeater_keyword] = ACTIONS(9667),
    [sym_cuegroup_keyword] = ACTIONS(9667),
    [sym_fixed_keyword] = ACTIONS(9667),
    [sym_grid_keyword] = ACTIONS(9667),
    [sym_part_keyword] = ACTIONS(9667),
    [sym_systempart_keyword] = ACTIONS(9667),
    [sym_usercontrol_keyword] = ACTIONS(9667),
    [sym_dataset_keyword] = ACTIONS(9667),
    [sym_elements_keyword] = ACTIONS(9667),
    [sym_dataitem_keyword] = ACTIONS(9667),
    [sym_column_keyword] = ACTIONS(9667),
    [sym_filter_keyword] = ACTIONS(9667),
    [sym_labels_keyword] = ACTIONS(9667),
    [sym_rendering_keyword] = ACTIONS(9667),
    [sym_requestpage_keyword] = ACTIONS(9667),
    [sym_schema_keyword] = ACTIONS(9667),
    [sym_views_keyword] = ACTIONS(9667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9667),
    [sym_preproc_open] = ACTIONS(9667),
    [sym_preproc_close] = ACTIONS(9667),
  },
  [STATE(3596)] = {
    [anon_sym_SEMI] = ACTIONS(9667),
    [aux_sym_where_condition_token1] = ACTIONS(9669),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9667),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9667),
    [anon_sym_LBRACK] = ACTIONS(9667),
    [aux_sym_basic_type_token6] = ACTIONS(9669),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9667),
    [aux_sym_addafter_modification_token1] = ACTIONS(9667),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9667),
    [aux_sym_modify_modification_token1] = ACTIONS(9667),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9667),
    [aux_sym_movelast_modification_token1] = ACTIONS(9667),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9667),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9667),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9667),
    [anon_sym_POUNDif] = ACTIONS(9667),
    [anon_sym_POUNDIF] = ACTIONS(9667),
    [anon_sym_POUNDIf] = ACTIONS(9667),
    [anon_sym_POUNDelif] = ACTIONS(9667),
    [anon_sym_POUNDELIF] = ACTIONS(9667),
    [anon_sym_POUNDElif] = ACTIONS(9667),
    [anon_sym_POUNDelse] = ACTIONS(9667),
    [anon_sym_POUNDELSE] = ACTIONS(9667),
    [anon_sym_POUNDElse] = ACTIONS(9667),
    [anon_sym_POUNDendif] = ACTIONS(9667),
    [anon_sym_POUNDENDIF] = ACTIONS(9667),
    [anon_sym_POUNDEndif] = ACTIONS(9667),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9667),
    [sym_trigger_keyword] = ACTIONS(9667),
    [sym_var_keyword] = ACTIONS(9667),
    [sym_local_keyword] = ACTIONS(9667),
    [sym_internal_keyword] = ACTIONS(9667),
    [sym_protected_keyword] = ACTIONS(9667),
    [sym_event_keyword] = ACTIONS(9667),
    [sym_fields_keyword] = ACTIONS(9667),
    [sym_keys_keyword] = ACTIONS(9667),
    [sym_fieldgroups_keyword] = ACTIONS(9667),
    [sym_actions_keyword] = ACTIONS(9667),
    [sym_layout_keyword] = ACTIONS(9667),
    [sym_area_keyword] = ACTIONS(9667),
    [sym_group_keyword] = ACTIONS(9667),
    [sym_repeater_keyword] = ACTIONS(9667),
    [sym_cuegroup_keyword] = ACTIONS(9667),
    [sym_fixed_keyword] = ACTIONS(9667),
    [sym_grid_keyword] = ACTIONS(9667),
    [sym_part_keyword] = ACTIONS(9667),
    [sym_systempart_keyword] = ACTIONS(9667),
    [sym_usercontrol_keyword] = ACTIONS(9667),
    [sym_dataset_keyword] = ACTIONS(9667),
    [sym_elements_keyword] = ACTIONS(9667),
    [sym_dataitem_keyword] = ACTIONS(9667),
    [sym_column_keyword] = ACTIONS(9667),
    [sym_filter_keyword] = ACTIONS(9667),
    [sym_labels_keyword] = ACTIONS(9667),
    [sym_rendering_keyword] = ACTIONS(9667),
    [sym_requestpage_keyword] = ACTIONS(9667),
    [sym_schema_keyword] = ACTIONS(9667),
    [sym_views_keyword] = ACTIONS(9667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9667),
    [sym_preproc_open] = ACTIONS(9667),
    [sym_preproc_close] = ACTIONS(9667),
  },
  [STATE(3597)] = {
    [anon_sym_SEMI] = ACTIONS(9667),
    [aux_sym_where_condition_token1] = ACTIONS(9669),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9667),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9667),
    [anon_sym_LBRACK] = ACTIONS(9667),
    [aux_sym_basic_type_token6] = ACTIONS(9669),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9667),
    [aux_sym_addafter_modification_token1] = ACTIONS(9667),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9667),
    [aux_sym_modify_modification_token1] = ACTIONS(9667),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9667),
    [aux_sym_movelast_modification_token1] = ACTIONS(9667),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9667),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9667),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9667),
    [anon_sym_POUNDif] = ACTIONS(9667),
    [anon_sym_POUNDIF] = ACTIONS(9667),
    [anon_sym_POUNDIf] = ACTIONS(9667),
    [anon_sym_POUNDelif] = ACTIONS(9667),
    [anon_sym_POUNDELIF] = ACTIONS(9667),
    [anon_sym_POUNDElif] = ACTIONS(9667),
    [anon_sym_POUNDelse] = ACTIONS(9667),
    [anon_sym_POUNDELSE] = ACTIONS(9667),
    [anon_sym_POUNDElse] = ACTIONS(9667),
    [anon_sym_POUNDendif] = ACTIONS(9667),
    [anon_sym_POUNDENDIF] = ACTIONS(9667),
    [anon_sym_POUNDEndif] = ACTIONS(9667),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9667),
    [sym_trigger_keyword] = ACTIONS(9667),
    [sym_var_keyword] = ACTIONS(9667),
    [sym_local_keyword] = ACTIONS(9667),
    [sym_internal_keyword] = ACTIONS(9667),
    [sym_protected_keyword] = ACTIONS(9667),
    [sym_event_keyword] = ACTIONS(9667),
    [sym_fields_keyword] = ACTIONS(9667),
    [sym_keys_keyword] = ACTIONS(9667),
    [sym_fieldgroups_keyword] = ACTIONS(9667),
    [sym_actions_keyword] = ACTIONS(9667),
    [sym_layout_keyword] = ACTIONS(9667),
    [sym_area_keyword] = ACTIONS(9667),
    [sym_group_keyword] = ACTIONS(9667),
    [sym_repeater_keyword] = ACTIONS(9667),
    [sym_cuegroup_keyword] = ACTIONS(9667),
    [sym_fixed_keyword] = ACTIONS(9667),
    [sym_grid_keyword] = ACTIONS(9667),
    [sym_part_keyword] = ACTIONS(9667),
    [sym_systempart_keyword] = ACTIONS(9667),
    [sym_usercontrol_keyword] = ACTIONS(9667),
    [sym_dataset_keyword] = ACTIONS(9667),
    [sym_elements_keyword] = ACTIONS(9667),
    [sym_dataitem_keyword] = ACTIONS(9667),
    [sym_column_keyword] = ACTIONS(9667),
    [sym_filter_keyword] = ACTIONS(9667),
    [sym_labels_keyword] = ACTIONS(9667),
    [sym_rendering_keyword] = ACTIONS(9667),
    [sym_requestpage_keyword] = ACTIONS(9667),
    [sym_schema_keyword] = ACTIONS(9667),
    [sym_views_keyword] = ACTIONS(9667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9667),
    [sym_preproc_open] = ACTIONS(9667),
    [sym_preproc_close] = ACTIONS(9667),
  },
  [STATE(3598)] = {
    [anon_sym_SEMI] = ACTIONS(9667),
    [aux_sym_where_condition_token1] = ACTIONS(9669),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9667),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9667),
    [anon_sym_LBRACK] = ACTIONS(9667),
    [aux_sym_basic_type_token6] = ACTIONS(9669),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9667),
    [aux_sym_addafter_modification_token1] = ACTIONS(9667),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9667),
    [aux_sym_modify_modification_token1] = ACTIONS(9667),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9667),
    [aux_sym_movelast_modification_token1] = ACTIONS(9667),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9667),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9667),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9667),
    [anon_sym_POUNDif] = ACTIONS(9667),
    [anon_sym_POUNDIF] = ACTIONS(9667),
    [anon_sym_POUNDIf] = ACTIONS(9667),
    [anon_sym_POUNDelif] = ACTIONS(9667),
    [anon_sym_POUNDELIF] = ACTIONS(9667),
    [anon_sym_POUNDElif] = ACTIONS(9667),
    [anon_sym_POUNDelse] = ACTIONS(9667),
    [anon_sym_POUNDELSE] = ACTIONS(9667),
    [anon_sym_POUNDElse] = ACTIONS(9667),
    [anon_sym_POUNDendif] = ACTIONS(9667),
    [anon_sym_POUNDENDIF] = ACTIONS(9667),
    [anon_sym_POUNDEndif] = ACTIONS(9667),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9667),
    [sym_trigger_keyword] = ACTIONS(9667),
    [sym_var_keyword] = ACTIONS(9667),
    [sym_local_keyword] = ACTIONS(9667),
    [sym_internal_keyword] = ACTIONS(9667),
    [sym_protected_keyword] = ACTIONS(9667),
    [sym_event_keyword] = ACTIONS(9667),
    [sym_fields_keyword] = ACTIONS(9667),
    [sym_keys_keyword] = ACTIONS(9667),
    [sym_fieldgroups_keyword] = ACTIONS(9667),
    [sym_actions_keyword] = ACTIONS(9667),
    [sym_layout_keyword] = ACTIONS(9667),
    [sym_area_keyword] = ACTIONS(9667),
    [sym_group_keyword] = ACTIONS(9667),
    [sym_repeater_keyword] = ACTIONS(9667),
    [sym_cuegroup_keyword] = ACTIONS(9667),
    [sym_fixed_keyword] = ACTIONS(9667),
    [sym_grid_keyword] = ACTIONS(9667),
    [sym_part_keyword] = ACTIONS(9667),
    [sym_systempart_keyword] = ACTIONS(9667),
    [sym_usercontrol_keyword] = ACTIONS(9667),
    [sym_dataset_keyword] = ACTIONS(9667),
    [sym_elements_keyword] = ACTIONS(9667),
    [sym_dataitem_keyword] = ACTIONS(9667),
    [sym_column_keyword] = ACTIONS(9667),
    [sym_filter_keyword] = ACTIONS(9667),
    [sym_labels_keyword] = ACTIONS(9667),
    [sym_rendering_keyword] = ACTIONS(9667),
    [sym_requestpage_keyword] = ACTIONS(9667),
    [sym_schema_keyword] = ACTIONS(9667),
    [sym_views_keyword] = ACTIONS(9667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9667),
    [sym_preproc_open] = ACTIONS(9667),
    [sym_preproc_close] = ACTIONS(9667),
  },
  [STATE(3599)] = {
    [anon_sym_SEMI] = ACTIONS(9671),
    [aux_sym_where_condition_token1] = ACTIONS(9673),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9671),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9671),
    [anon_sym_LBRACK] = ACTIONS(9671),
    [aux_sym_basic_type_token6] = ACTIONS(9673),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9671),
    [aux_sym_addafter_modification_token1] = ACTIONS(9671),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9671),
    [aux_sym_modify_modification_token1] = ACTIONS(9671),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9671),
    [aux_sym_movelast_modification_token1] = ACTIONS(9671),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9671),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9671),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9671),
    [anon_sym_POUNDif] = ACTIONS(9671),
    [anon_sym_POUNDIF] = ACTIONS(9671),
    [anon_sym_POUNDIf] = ACTIONS(9671),
    [anon_sym_POUNDelif] = ACTIONS(9671),
    [anon_sym_POUNDELIF] = ACTIONS(9671),
    [anon_sym_POUNDElif] = ACTIONS(9671),
    [anon_sym_POUNDelse] = ACTIONS(9671),
    [anon_sym_POUNDELSE] = ACTIONS(9671),
    [anon_sym_POUNDElse] = ACTIONS(9671),
    [anon_sym_POUNDendif] = ACTIONS(9671),
    [anon_sym_POUNDENDIF] = ACTIONS(9671),
    [anon_sym_POUNDEndif] = ACTIONS(9671),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9671),
    [sym_trigger_keyword] = ACTIONS(9671),
    [sym_var_keyword] = ACTIONS(9671),
    [sym_local_keyword] = ACTIONS(9671),
    [sym_internal_keyword] = ACTIONS(9671),
    [sym_protected_keyword] = ACTIONS(9671),
    [sym_event_keyword] = ACTIONS(9671),
    [sym_fields_keyword] = ACTIONS(9671),
    [sym_keys_keyword] = ACTIONS(9671),
    [sym_fieldgroups_keyword] = ACTIONS(9671),
    [sym_actions_keyword] = ACTIONS(9671),
    [sym_layout_keyword] = ACTIONS(9671),
    [sym_area_keyword] = ACTIONS(9671),
    [sym_group_keyword] = ACTIONS(9671),
    [sym_repeater_keyword] = ACTIONS(9671),
    [sym_cuegroup_keyword] = ACTIONS(9671),
    [sym_fixed_keyword] = ACTIONS(9671),
    [sym_grid_keyword] = ACTIONS(9671),
    [sym_part_keyword] = ACTIONS(9671),
    [sym_systempart_keyword] = ACTIONS(9671),
    [sym_usercontrol_keyword] = ACTIONS(9671),
    [sym_dataset_keyword] = ACTIONS(9671),
    [sym_elements_keyword] = ACTIONS(9671),
    [sym_dataitem_keyword] = ACTIONS(9671),
    [sym_column_keyword] = ACTIONS(9671),
    [sym_filter_keyword] = ACTIONS(9671),
    [sym_labels_keyword] = ACTIONS(9671),
    [sym_rendering_keyword] = ACTIONS(9671),
    [sym_requestpage_keyword] = ACTIONS(9671),
    [sym_schema_keyword] = ACTIONS(9671),
    [sym_views_keyword] = ACTIONS(9671),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9671),
    [sym_preproc_open] = ACTIONS(9671),
    [sym_preproc_close] = ACTIONS(9671),
  },
  [STATE(3600)] = {
    [anon_sym_SEMI] = ACTIONS(9671),
    [aux_sym_where_condition_token1] = ACTIONS(9673),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9671),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9671),
    [anon_sym_LBRACK] = ACTIONS(9671),
    [aux_sym_basic_type_token6] = ACTIONS(9673),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9671),
    [aux_sym_addafter_modification_token1] = ACTIONS(9671),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9671),
    [aux_sym_modify_modification_token1] = ACTIONS(9671),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9671),
    [aux_sym_movelast_modification_token1] = ACTIONS(9671),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9671),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9671),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9671),
    [anon_sym_POUNDif] = ACTIONS(9671),
    [anon_sym_POUNDIF] = ACTIONS(9671),
    [anon_sym_POUNDIf] = ACTIONS(9671),
    [anon_sym_POUNDelif] = ACTIONS(9671),
    [anon_sym_POUNDELIF] = ACTIONS(9671),
    [anon_sym_POUNDElif] = ACTIONS(9671),
    [anon_sym_POUNDelse] = ACTIONS(9671),
    [anon_sym_POUNDELSE] = ACTIONS(9671),
    [anon_sym_POUNDElse] = ACTIONS(9671),
    [anon_sym_POUNDendif] = ACTIONS(9671),
    [anon_sym_POUNDENDIF] = ACTIONS(9671),
    [anon_sym_POUNDEndif] = ACTIONS(9671),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9671),
    [sym_trigger_keyword] = ACTIONS(9671),
    [sym_var_keyword] = ACTIONS(9671),
    [sym_local_keyword] = ACTIONS(9671),
    [sym_internal_keyword] = ACTIONS(9671),
    [sym_protected_keyword] = ACTIONS(9671),
    [sym_event_keyword] = ACTIONS(9671),
    [sym_fields_keyword] = ACTIONS(9671),
    [sym_keys_keyword] = ACTIONS(9671),
    [sym_fieldgroups_keyword] = ACTIONS(9671),
    [sym_actions_keyword] = ACTIONS(9671),
    [sym_layout_keyword] = ACTIONS(9671),
    [sym_area_keyword] = ACTIONS(9671),
    [sym_group_keyword] = ACTIONS(9671),
    [sym_repeater_keyword] = ACTIONS(9671),
    [sym_cuegroup_keyword] = ACTIONS(9671),
    [sym_fixed_keyword] = ACTIONS(9671),
    [sym_grid_keyword] = ACTIONS(9671),
    [sym_part_keyword] = ACTIONS(9671),
    [sym_systempart_keyword] = ACTIONS(9671),
    [sym_usercontrol_keyword] = ACTIONS(9671),
    [sym_dataset_keyword] = ACTIONS(9671),
    [sym_elements_keyword] = ACTIONS(9671),
    [sym_dataitem_keyword] = ACTIONS(9671),
    [sym_column_keyword] = ACTIONS(9671),
    [sym_filter_keyword] = ACTIONS(9671),
    [sym_labels_keyword] = ACTIONS(9671),
    [sym_rendering_keyword] = ACTIONS(9671),
    [sym_requestpage_keyword] = ACTIONS(9671),
    [sym_schema_keyword] = ACTIONS(9671),
    [sym_views_keyword] = ACTIONS(9671),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9671),
    [sym_preproc_open] = ACTIONS(9671),
    [sym_preproc_close] = ACTIONS(9671),
  },
  [STATE(3601)] = {
    [anon_sym_SEMI] = ACTIONS(9671),
    [aux_sym_where_condition_token1] = ACTIONS(9673),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9671),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9671),
    [anon_sym_LBRACK] = ACTIONS(9671),
    [aux_sym_basic_type_token6] = ACTIONS(9673),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9671),
    [aux_sym_addafter_modification_token1] = ACTIONS(9671),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9671),
    [aux_sym_modify_modification_token1] = ACTIONS(9671),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9671),
    [aux_sym_movelast_modification_token1] = ACTIONS(9671),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9671),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9671),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9671),
    [anon_sym_POUNDif] = ACTIONS(9671),
    [anon_sym_POUNDIF] = ACTIONS(9671),
    [anon_sym_POUNDIf] = ACTIONS(9671),
    [anon_sym_POUNDelif] = ACTIONS(9671),
    [anon_sym_POUNDELIF] = ACTIONS(9671),
    [anon_sym_POUNDElif] = ACTIONS(9671),
    [anon_sym_POUNDelse] = ACTIONS(9671),
    [anon_sym_POUNDELSE] = ACTIONS(9671),
    [anon_sym_POUNDElse] = ACTIONS(9671),
    [anon_sym_POUNDendif] = ACTIONS(9671),
    [anon_sym_POUNDENDIF] = ACTIONS(9671),
    [anon_sym_POUNDEndif] = ACTIONS(9671),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9671),
    [sym_trigger_keyword] = ACTIONS(9671),
    [sym_var_keyword] = ACTIONS(9671),
    [sym_local_keyword] = ACTIONS(9671),
    [sym_internal_keyword] = ACTIONS(9671),
    [sym_protected_keyword] = ACTIONS(9671),
    [sym_event_keyword] = ACTIONS(9671),
    [sym_fields_keyword] = ACTIONS(9671),
    [sym_keys_keyword] = ACTIONS(9671),
    [sym_fieldgroups_keyword] = ACTIONS(9671),
    [sym_actions_keyword] = ACTIONS(9671),
    [sym_layout_keyword] = ACTIONS(9671),
    [sym_area_keyword] = ACTIONS(9671),
    [sym_group_keyword] = ACTIONS(9671),
    [sym_repeater_keyword] = ACTIONS(9671),
    [sym_cuegroup_keyword] = ACTIONS(9671),
    [sym_fixed_keyword] = ACTIONS(9671),
    [sym_grid_keyword] = ACTIONS(9671),
    [sym_part_keyword] = ACTIONS(9671),
    [sym_systempart_keyword] = ACTIONS(9671),
    [sym_usercontrol_keyword] = ACTIONS(9671),
    [sym_dataset_keyword] = ACTIONS(9671),
    [sym_elements_keyword] = ACTIONS(9671),
    [sym_dataitem_keyword] = ACTIONS(9671),
    [sym_column_keyword] = ACTIONS(9671),
    [sym_filter_keyword] = ACTIONS(9671),
    [sym_labels_keyword] = ACTIONS(9671),
    [sym_rendering_keyword] = ACTIONS(9671),
    [sym_requestpage_keyword] = ACTIONS(9671),
    [sym_schema_keyword] = ACTIONS(9671),
    [sym_views_keyword] = ACTIONS(9671),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9671),
    [sym_preproc_open] = ACTIONS(9671),
    [sym_preproc_close] = ACTIONS(9671),
  },
  [STATE(3602)] = {
    [anon_sym_SEMI] = ACTIONS(9671),
    [aux_sym_where_condition_token1] = ACTIONS(9673),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9671),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9671),
    [anon_sym_LBRACK] = ACTIONS(9671),
    [aux_sym_basic_type_token6] = ACTIONS(9673),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9671),
    [aux_sym_addafter_modification_token1] = ACTIONS(9671),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9671),
    [aux_sym_modify_modification_token1] = ACTIONS(9671),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9671),
    [aux_sym_movelast_modification_token1] = ACTIONS(9671),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9671),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9671),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9671),
    [anon_sym_POUNDif] = ACTIONS(9671),
    [anon_sym_POUNDIF] = ACTIONS(9671),
    [anon_sym_POUNDIf] = ACTIONS(9671),
    [anon_sym_POUNDelif] = ACTIONS(9671),
    [anon_sym_POUNDELIF] = ACTIONS(9671),
    [anon_sym_POUNDElif] = ACTIONS(9671),
    [anon_sym_POUNDelse] = ACTIONS(9671),
    [anon_sym_POUNDELSE] = ACTIONS(9671),
    [anon_sym_POUNDElse] = ACTIONS(9671),
    [anon_sym_POUNDendif] = ACTIONS(9671),
    [anon_sym_POUNDENDIF] = ACTIONS(9671),
    [anon_sym_POUNDEndif] = ACTIONS(9671),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9671),
    [sym_trigger_keyword] = ACTIONS(9671),
    [sym_var_keyword] = ACTIONS(9671),
    [sym_local_keyword] = ACTIONS(9671),
    [sym_internal_keyword] = ACTIONS(9671),
    [sym_protected_keyword] = ACTIONS(9671),
    [sym_event_keyword] = ACTIONS(9671),
    [sym_fields_keyword] = ACTIONS(9671),
    [sym_keys_keyword] = ACTIONS(9671),
    [sym_fieldgroups_keyword] = ACTIONS(9671),
    [sym_actions_keyword] = ACTIONS(9671),
    [sym_layout_keyword] = ACTIONS(9671),
    [sym_area_keyword] = ACTIONS(9671),
    [sym_group_keyword] = ACTIONS(9671),
    [sym_repeater_keyword] = ACTIONS(9671),
    [sym_cuegroup_keyword] = ACTIONS(9671),
    [sym_fixed_keyword] = ACTIONS(9671),
    [sym_grid_keyword] = ACTIONS(9671),
    [sym_part_keyword] = ACTIONS(9671),
    [sym_systempart_keyword] = ACTIONS(9671),
    [sym_usercontrol_keyword] = ACTIONS(9671),
    [sym_dataset_keyword] = ACTIONS(9671),
    [sym_elements_keyword] = ACTIONS(9671),
    [sym_dataitem_keyword] = ACTIONS(9671),
    [sym_column_keyword] = ACTIONS(9671),
    [sym_filter_keyword] = ACTIONS(9671),
    [sym_labels_keyword] = ACTIONS(9671),
    [sym_rendering_keyword] = ACTIONS(9671),
    [sym_requestpage_keyword] = ACTIONS(9671),
    [sym_schema_keyword] = ACTIONS(9671),
    [sym_views_keyword] = ACTIONS(9671),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9671),
    [sym_preproc_open] = ACTIONS(9671),
    [sym_preproc_close] = ACTIONS(9671),
  },
  [STATE(3603)] = {
    [anon_sym_SEMI] = ACTIONS(9675),
    [aux_sym_where_condition_token1] = ACTIONS(9677),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9675),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9675),
    [anon_sym_LBRACK] = ACTIONS(9675),
    [aux_sym_basic_type_token6] = ACTIONS(9677),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9675),
    [aux_sym_addafter_modification_token1] = ACTIONS(9675),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9675),
    [aux_sym_modify_modification_token1] = ACTIONS(9675),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9675),
    [aux_sym_movelast_modification_token1] = ACTIONS(9675),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9675),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9675),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9675),
    [anon_sym_POUNDif] = ACTIONS(9675),
    [anon_sym_POUNDIF] = ACTIONS(9675),
    [anon_sym_POUNDIf] = ACTIONS(9675),
    [anon_sym_POUNDelif] = ACTIONS(9675),
    [anon_sym_POUNDELIF] = ACTIONS(9675),
    [anon_sym_POUNDElif] = ACTIONS(9675),
    [anon_sym_POUNDelse] = ACTIONS(9675),
    [anon_sym_POUNDELSE] = ACTIONS(9675),
    [anon_sym_POUNDElse] = ACTIONS(9675),
    [anon_sym_POUNDendif] = ACTIONS(9675),
    [anon_sym_POUNDENDIF] = ACTIONS(9675),
    [anon_sym_POUNDEndif] = ACTIONS(9675),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9675),
    [sym_trigger_keyword] = ACTIONS(9675),
    [sym_var_keyword] = ACTIONS(9675),
    [sym_local_keyword] = ACTIONS(9675),
    [sym_internal_keyword] = ACTIONS(9675),
    [sym_protected_keyword] = ACTIONS(9675),
    [sym_event_keyword] = ACTIONS(9675),
    [sym_fields_keyword] = ACTIONS(9675),
    [sym_keys_keyword] = ACTIONS(9675),
    [sym_fieldgroups_keyword] = ACTIONS(9675),
    [sym_actions_keyword] = ACTIONS(9675),
    [sym_layout_keyword] = ACTIONS(9675),
    [sym_area_keyword] = ACTIONS(9675),
    [sym_group_keyword] = ACTIONS(9675),
    [sym_repeater_keyword] = ACTIONS(9675),
    [sym_cuegroup_keyword] = ACTIONS(9675),
    [sym_fixed_keyword] = ACTIONS(9675),
    [sym_grid_keyword] = ACTIONS(9675),
    [sym_part_keyword] = ACTIONS(9675),
    [sym_systempart_keyword] = ACTIONS(9675),
    [sym_usercontrol_keyword] = ACTIONS(9675),
    [sym_dataset_keyword] = ACTIONS(9675),
    [sym_elements_keyword] = ACTIONS(9675),
    [sym_dataitem_keyword] = ACTIONS(9675),
    [sym_column_keyword] = ACTIONS(9675),
    [sym_filter_keyword] = ACTIONS(9675),
    [sym_labels_keyword] = ACTIONS(9675),
    [sym_rendering_keyword] = ACTIONS(9675),
    [sym_requestpage_keyword] = ACTIONS(9675),
    [sym_schema_keyword] = ACTIONS(9675),
    [sym_views_keyword] = ACTIONS(9675),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9675),
    [sym_preproc_open] = ACTIONS(9675),
    [sym_preproc_close] = ACTIONS(9675),
  },
  [STATE(3604)] = {
    [anon_sym_SEMI] = ACTIONS(9679),
    [aux_sym_where_condition_token1] = ACTIONS(9681),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9679),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9679),
    [anon_sym_LBRACK] = ACTIONS(9679),
    [aux_sym_basic_type_token6] = ACTIONS(9681),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9679),
    [aux_sym_addafter_modification_token1] = ACTIONS(9679),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9679),
    [aux_sym_modify_modification_token1] = ACTIONS(9679),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9679),
    [aux_sym_movelast_modification_token1] = ACTIONS(9679),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9679),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9679),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9679),
    [anon_sym_POUNDif] = ACTIONS(9679),
    [anon_sym_POUNDIF] = ACTIONS(9679),
    [anon_sym_POUNDIf] = ACTIONS(9679),
    [anon_sym_POUNDelif] = ACTIONS(9679),
    [anon_sym_POUNDELIF] = ACTIONS(9679),
    [anon_sym_POUNDElif] = ACTIONS(9679),
    [anon_sym_POUNDelse] = ACTIONS(9679),
    [anon_sym_POUNDELSE] = ACTIONS(9679),
    [anon_sym_POUNDElse] = ACTIONS(9679),
    [anon_sym_POUNDendif] = ACTIONS(9679),
    [anon_sym_POUNDENDIF] = ACTIONS(9679),
    [anon_sym_POUNDEndif] = ACTIONS(9679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9679),
    [sym_trigger_keyword] = ACTIONS(9679),
    [sym_var_keyword] = ACTIONS(9679),
    [sym_local_keyword] = ACTIONS(9679),
    [sym_internal_keyword] = ACTIONS(9679),
    [sym_protected_keyword] = ACTIONS(9679),
    [sym_event_keyword] = ACTIONS(9679),
    [sym_fields_keyword] = ACTIONS(9679),
    [sym_keys_keyword] = ACTIONS(9679),
    [sym_fieldgroups_keyword] = ACTIONS(9679),
    [sym_actions_keyword] = ACTIONS(9679),
    [sym_layout_keyword] = ACTIONS(9679),
    [sym_area_keyword] = ACTIONS(9679),
    [sym_group_keyword] = ACTIONS(9679),
    [sym_repeater_keyword] = ACTIONS(9679),
    [sym_cuegroup_keyword] = ACTIONS(9679),
    [sym_fixed_keyword] = ACTIONS(9679),
    [sym_grid_keyword] = ACTIONS(9679),
    [sym_part_keyword] = ACTIONS(9679),
    [sym_systempart_keyword] = ACTIONS(9679),
    [sym_usercontrol_keyword] = ACTIONS(9679),
    [sym_dataset_keyword] = ACTIONS(9679),
    [sym_elements_keyword] = ACTIONS(9679),
    [sym_dataitem_keyword] = ACTIONS(9679),
    [sym_column_keyword] = ACTIONS(9679),
    [sym_filter_keyword] = ACTIONS(9679),
    [sym_labels_keyword] = ACTIONS(9679),
    [sym_rendering_keyword] = ACTIONS(9679),
    [sym_requestpage_keyword] = ACTIONS(9679),
    [sym_schema_keyword] = ACTIONS(9679),
    [sym_views_keyword] = ACTIONS(9679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9679),
    [sym_preproc_open] = ACTIONS(9679),
    [sym_preproc_close] = ACTIONS(9679),
  },
  [STATE(3605)] = {
    [anon_sym_SEMI] = ACTIONS(9679),
    [aux_sym_where_condition_token1] = ACTIONS(9681),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9679),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9679),
    [anon_sym_LBRACK] = ACTIONS(9679),
    [aux_sym_basic_type_token6] = ACTIONS(9681),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9679),
    [aux_sym_addafter_modification_token1] = ACTIONS(9679),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9679),
    [aux_sym_modify_modification_token1] = ACTIONS(9679),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9679),
    [aux_sym_movelast_modification_token1] = ACTIONS(9679),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9679),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9679),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9679),
    [anon_sym_POUNDif] = ACTIONS(9679),
    [anon_sym_POUNDIF] = ACTIONS(9679),
    [anon_sym_POUNDIf] = ACTIONS(9679),
    [anon_sym_POUNDelif] = ACTIONS(9679),
    [anon_sym_POUNDELIF] = ACTIONS(9679),
    [anon_sym_POUNDElif] = ACTIONS(9679),
    [anon_sym_POUNDelse] = ACTIONS(9679),
    [anon_sym_POUNDELSE] = ACTIONS(9679),
    [anon_sym_POUNDElse] = ACTIONS(9679),
    [anon_sym_POUNDendif] = ACTIONS(9679),
    [anon_sym_POUNDENDIF] = ACTIONS(9679),
    [anon_sym_POUNDEndif] = ACTIONS(9679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9679),
    [sym_trigger_keyword] = ACTIONS(9679),
    [sym_var_keyword] = ACTIONS(9679),
    [sym_local_keyword] = ACTIONS(9679),
    [sym_internal_keyword] = ACTIONS(9679),
    [sym_protected_keyword] = ACTIONS(9679),
    [sym_event_keyword] = ACTIONS(9679),
    [sym_fields_keyword] = ACTIONS(9679),
    [sym_keys_keyword] = ACTIONS(9679),
    [sym_fieldgroups_keyword] = ACTIONS(9679),
    [sym_actions_keyword] = ACTIONS(9679),
    [sym_layout_keyword] = ACTIONS(9679),
    [sym_area_keyword] = ACTIONS(9679),
    [sym_group_keyword] = ACTIONS(9679),
    [sym_repeater_keyword] = ACTIONS(9679),
    [sym_cuegroup_keyword] = ACTIONS(9679),
    [sym_fixed_keyword] = ACTIONS(9679),
    [sym_grid_keyword] = ACTIONS(9679),
    [sym_part_keyword] = ACTIONS(9679),
    [sym_systempart_keyword] = ACTIONS(9679),
    [sym_usercontrol_keyword] = ACTIONS(9679),
    [sym_dataset_keyword] = ACTIONS(9679),
    [sym_elements_keyword] = ACTIONS(9679),
    [sym_dataitem_keyword] = ACTIONS(9679),
    [sym_column_keyword] = ACTIONS(9679),
    [sym_filter_keyword] = ACTIONS(9679),
    [sym_labels_keyword] = ACTIONS(9679),
    [sym_rendering_keyword] = ACTIONS(9679),
    [sym_requestpage_keyword] = ACTIONS(9679),
    [sym_schema_keyword] = ACTIONS(9679),
    [sym_views_keyword] = ACTIONS(9679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9679),
    [sym_preproc_open] = ACTIONS(9679),
    [sym_preproc_close] = ACTIONS(9679),
  },
  [STATE(3606)] = {
    [anon_sym_SEMI] = ACTIONS(9679),
    [aux_sym_where_condition_token1] = ACTIONS(9681),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9679),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9679),
    [anon_sym_LBRACK] = ACTIONS(9679),
    [aux_sym_basic_type_token6] = ACTIONS(9681),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9679),
    [aux_sym_addafter_modification_token1] = ACTIONS(9679),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9679),
    [aux_sym_modify_modification_token1] = ACTIONS(9679),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9679),
    [aux_sym_movelast_modification_token1] = ACTIONS(9679),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9679),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9679),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9679),
    [anon_sym_POUNDif] = ACTIONS(9679),
    [anon_sym_POUNDIF] = ACTIONS(9679),
    [anon_sym_POUNDIf] = ACTIONS(9679),
    [anon_sym_POUNDelif] = ACTIONS(9679),
    [anon_sym_POUNDELIF] = ACTIONS(9679),
    [anon_sym_POUNDElif] = ACTIONS(9679),
    [anon_sym_POUNDelse] = ACTIONS(9679),
    [anon_sym_POUNDELSE] = ACTIONS(9679),
    [anon_sym_POUNDElse] = ACTIONS(9679),
    [anon_sym_POUNDendif] = ACTIONS(9679),
    [anon_sym_POUNDENDIF] = ACTIONS(9679),
    [anon_sym_POUNDEndif] = ACTIONS(9679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9679),
    [sym_trigger_keyword] = ACTIONS(9679),
    [sym_var_keyword] = ACTIONS(9679),
    [sym_local_keyword] = ACTIONS(9679),
    [sym_internal_keyword] = ACTIONS(9679),
    [sym_protected_keyword] = ACTIONS(9679),
    [sym_event_keyword] = ACTIONS(9679),
    [sym_fields_keyword] = ACTIONS(9679),
    [sym_keys_keyword] = ACTIONS(9679),
    [sym_fieldgroups_keyword] = ACTIONS(9679),
    [sym_actions_keyword] = ACTIONS(9679),
    [sym_layout_keyword] = ACTIONS(9679),
    [sym_area_keyword] = ACTIONS(9679),
    [sym_group_keyword] = ACTIONS(9679),
    [sym_repeater_keyword] = ACTIONS(9679),
    [sym_cuegroup_keyword] = ACTIONS(9679),
    [sym_fixed_keyword] = ACTIONS(9679),
    [sym_grid_keyword] = ACTIONS(9679),
    [sym_part_keyword] = ACTIONS(9679),
    [sym_systempart_keyword] = ACTIONS(9679),
    [sym_usercontrol_keyword] = ACTIONS(9679),
    [sym_dataset_keyword] = ACTIONS(9679),
    [sym_elements_keyword] = ACTIONS(9679),
    [sym_dataitem_keyword] = ACTIONS(9679),
    [sym_column_keyword] = ACTIONS(9679),
    [sym_filter_keyword] = ACTIONS(9679),
    [sym_labels_keyword] = ACTIONS(9679),
    [sym_rendering_keyword] = ACTIONS(9679),
    [sym_requestpage_keyword] = ACTIONS(9679),
    [sym_schema_keyword] = ACTIONS(9679),
    [sym_views_keyword] = ACTIONS(9679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9679),
    [sym_preproc_open] = ACTIONS(9679),
    [sym_preproc_close] = ACTIONS(9679),
  },
  [STATE(3607)] = {
    [anon_sym_SEMI] = ACTIONS(9679),
    [aux_sym_where_condition_token1] = ACTIONS(9681),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9679),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9679),
    [anon_sym_LBRACK] = ACTIONS(9679),
    [aux_sym_basic_type_token6] = ACTIONS(9681),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9679),
    [aux_sym_addafter_modification_token1] = ACTIONS(9679),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9679),
    [aux_sym_modify_modification_token1] = ACTIONS(9679),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9679),
    [aux_sym_movelast_modification_token1] = ACTIONS(9679),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9679),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9679),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9679),
    [anon_sym_POUNDif] = ACTIONS(9679),
    [anon_sym_POUNDIF] = ACTIONS(9679),
    [anon_sym_POUNDIf] = ACTIONS(9679),
    [anon_sym_POUNDelif] = ACTIONS(9679),
    [anon_sym_POUNDELIF] = ACTIONS(9679),
    [anon_sym_POUNDElif] = ACTIONS(9679),
    [anon_sym_POUNDelse] = ACTIONS(9679),
    [anon_sym_POUNDELSE] = ACTIONS(9679),
    [anon_sym_POUNDElse] = ACTIONS(9679),
    [anon_sym_POUNDendif] = ACTIONS(9679),
    [anon_sym_POUNDENDIF] = ACTIONS(9679),
    [anon_sym_POUNDEndif] = ACTIONS(9679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9679),
    [sym_trigger_keyword] = ACTIONS(9679),
    [sym_var_keyword] = ACTIONS(9679),
    [sym_local_keyword] = ACTIONS(9679),
    [sym_internal_keyword] = ACTIONS(9679),
    [sym_protected_keyword] = ACTIONS(9679),
    [sym_event_keyword] = ACTIONS(9679),
    [sym_fields_keyword] = ACTIONS(9679),
    [sym_keys_keyword] = ACTIONS(9679),
    [sym_fieldgroups_keyword] = ACTIONS(9679),
    [sym_actions_keyword] = ACTIONS(9679),
    [sym_layout_keyword] = ACTIONS(9679),
    [sym_area_keyword] = ACTIONS(9679),
    [sym_group_keyword] = ACTIONS(9679),
    [sym_repeater_keyword] = ACTIONS(9679),
    [sym_cuegroup_keyword] = ACTIONS(9679),
    [sym_fixed_keyword] = ACTIONS(9679),
    [sym_grid_keyword] = ACTIONS(9679),
    [sym_part_keyword] = ACTIONS(9679),
    [sym_systempart_keyword] = ACTIONS(9679),
    [sym_usercontrol_keyword] = ACTIONS(9679),
    [sym_dataset_keyword] = ACTIONS(9679),
    [sym_elements_keyword] = ACTIONS(9679),
    [sym_dataitem_keyword] = ACTIONS(9679),
    [sym_column_keyword] = ACTIONS(9679),
    [sym_filter_keyword] = ACTIONS(9679),
    [sym_labels_keyword] = ACTIONS(9679),
    [sym_rendering_keyword] = ACTIONS(9679),
    [sym_requestpage_keyword] = ACTIONS(9679),
    [sym_schema_keyword] = ACTIONS(9679),
    [sym_views_keyword] = ACTIONS(9679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9679),
    [sym_preproc_open] = ACTIONS(9679),
    [sym_preproc_close] = ACTIONS(9679),
  },
  [STATE(3608)] = {
    [anon_sym_SEMI] = ACTIONS(9683),
    [aux_sym_where_condition_token1] = ACTIONS(9685),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9683),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9683),
    [anon_sym_LBRACK] = ACTIONS(9683),
    [aux_sym_basic_type_token6] = ACTIONS(9685),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9683),
    [aux_sym_addafter_modification_token1] = ACTIONS(9683),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9683),
    [aux_sym_modify_modification_token1] = ACTIONS(9683),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9683),
    [aux_sym_movelast_modification_token1] = ACTIONS(9683),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9683),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9683),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9683),
    [anon_sym_POUNDif] = ACTIONS(9683),
    [anon_sym_POUNDIF] = ACTIONS(9683),
    [anon_sym_POUNDIf] = ACTIONS(9683),
    [anon_sym_POUNDelif] = ACTIONS(9683),
    [anon_sym_POUNDELIF] = ACTIONS(9683),
    [anon_sym_POUNDElif] = ACTIONS(9683),
    [anon_sym_POUNDelse] = ACTIONS(9683),
    [anon_sym_POUNDELSE] = ACTIONS(9683),
    [anon_sym_POUNDElse] = ACTIONS(9683),
    [anon_sym_POUNDendif] = ACTIONS(9683),
    [anon_sym_POUNDENDIF] = ACTIONS(9683),
    [anon_sym_POUNDEndif] = ACTIONS(9683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9683),
    [sym_trigger_keyword] = ACTIONS(9683),
    [sym_var_keyword] = ACTIONS(9683),
    [sym_local_keyword] = ACTIONS(9683),
    [sym_internal_keyword] = ACTIONS(9683),
    [sym_protected_keyword] = ACTIONS(9683),
    [sym_event_keyword] = ACTIONS(9683),
    [sym_fields_keyword] = ACTIONS(9683),
    [sym_keys_keyword] = ACTIONS(9683),
    [sym_fieldgroups_keyword] = ACTIONS(9683),
    [sym_actions_keyword] = ACTIONS(9683),
    [sym_layout_keyword] = ACTIONS(9683),
    [sym_area_keyword] = ACTIONS(9683),
    [sym_group_keyword] = ACTIONS(9683),
    [sym_repeater_keyword] = ACTIONS(9683),
    [sym_cuegroup_keyword] = ACTIONS(9683),
    [sym_fixed_keyword] = ACTIONS(9683),
    [sym_grid_keyword] = ACTIONS(9683),
    [sym_part_keyword] = ACTIONS(9683),
    [sym_systempart_keyword] = ACTIONS(9683),
    [sym_usercontrol_keyword] = ACTIONS(9683),
    [sym_dataset_keyword] = ACTIONS(9683),
    [sym_elements_keyword] = ACTIONS(9683),
    [sym_dataitem_keyword] = ACTIONS(9683),
    [sym_column_keyword] = ACTIONS(9683),
    [sym_filter_keyword] = ACTIONS(9683),
    [sym_labels_keyword] = ACTIONS(9683),
    [sym_rendering_keyword] = ACTIONS(9683),
    [sym_requestpage_keyword] = ACTIONS(9683),
    [sym_schema_keyword] = ACTIONS(9683),
    [sym_views_keyword] = ACTIONS(9683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9683),
    [sym_preproc_open] = ACTIONS(9683),
    [sym_preproc_close] = ACTIONS(9683),
  },
  [STATE(3609)] = {
    [anon_sym_SEMI] = ACTIONS(9683),
    [aux_sym_where_condition_token1] = ACTIONS(9685),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9683),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9683),
    [anon_sym_LBRACK] = ACTIONS(9683),
    [aux_sym_basic_type_token6] = ACTIONS(9685),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9683),
    [aux_sym_addafter_modification_token1] = ACTIONS(9683),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9683),
    [aux_sym_modify_modification_token1] = ACTIONS(9683),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9683),
    [aux_sym_movelast_modification_token1] = ACTIONS(9683),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9683),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9683),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9683),
    [anon_sym_POUNDif] = ACTIONS(9683),
    [anon_sym_POUNDIF] = ACTIONS(9683),
    [anon_sym_POUNDIf] = ACTIONS(9683),
    [anon_sym_POUNDelif] = ACTIONS(9683),
    [anon_sym_POUNDELIF] = ACTIONS(9683),
    [anon_sym_POUNDElif] = ACTIONS(9683),
    [anon_sym_POUNDelse] = ACTIONS(9683),
    [anon_sym_POUNDELSE] = ACTIONS(9683),
    [anon_sym_POUNDElse] = ACTIONS(9683),
    [anon_sym_POUNDendif] = ACTIONS(9683),
    [anon_sym_POUNDENDIF] = ACTIONS(9683),
    [anon_sym_POUNDEndif] = ACTIONS(9683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9683),
    [sym_trigger_keyword] = ACTIONS(9683),
    [sym_var_keyword] = ACTIONS(9683),
    [sym_local_keyword] = ACTIONS(9683),
    [sym_internal_keyword] = ACTIONS(9683),
    [sym_protected_keyword] = ACTIONS(9683),
    [sym_event_keyword] = ACTIONS(9683),
    [sym_fields_keyword] = ACTIONS(9683),
    [sym_keys_keyword] = ACTIONS(9683),
    [sym_fieldgroups_keyword] = ACTIONS(9683),
    [sym_actions_keyword] = ACTIONS(9683),
    [sym_layout_keyword] = ACTIONS(9683),
    [sym_area_keyword] = ACTIONS(9683),
    [sym_group_keyword] = ACTIONS(9683),
    [sym_repeater_keyword] = ACTIONS(9683),
    [sym_cuegroup_keyword] = ACTIONS(9683),
    [sym_fixed_keyword] = ACTIONS(9683),
    [sym_grid_keyword] = ACTIONS(9683),
    [sym_part_keyword] = ACTIONS(9683),
    [sym_systempart_keyword] = ACTIONS(9683),
    [sym_usercontrol_keyword] = ACTIONS(9683),
    [sym_dataset_keyword] = ACTIONS(9683),
    [sym_elements_keyword] = ACTIONS(9683),
    [sym_dataitem_keyword] = ACTIONS(9683),
    [sym_column_keyword] = ACTIONS(9683),
    [sym_filter_keyword] = ACTIONS(9683),
    [sym_labels_keyword] = ACTIONS(9683),
    [sym_rendering_keyword] = ACTIONS(9683),
    [sym_requestpage_keyword] = ACTIONS(9683),
    [sym_schema_keyword] = ACTIONS(9683),
    [sym_views_keyword] = ACTIONS(9683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9683),
    [sym_preproc_open] = ACTIONS(9683),
    [sym_preproc_close] = ACTIONS(9683),
  },
  [STATE(3610)] = {
    [anon_sym_SEMI] = ACTIONS(9683),
    [aux_sym_where_condition_token1] = ACTIONS(9685),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9683),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9683),
    [anon_sym_LBRACK] = ACTIONS(9683),
    [aux_sym_basic_type_token6] = ACTIONS(9685),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9683),
    [aux_sym_addafter_modification_token1] = ACTIONS(9683),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9683),
    [aux_sym_modify_modification_token1] = ACTIONS(9683),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9683),
    [aux_sym_movelast_modification_token1] = ACTIONS(9683),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9683),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9683),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9683),
    [anon_sym_POUNDif] = ACTIONS(9683),
    [anon_sym_POUNDIF] = ACTIONS(9683),
    [anon_sym_POUNDIf] = ACTIONS(9683),
    [anon_sym_POUNDelif] = ACTIONS(9683),
    [anon_sym_POUNDELIF] = ACTIONS(9683),
    [anon_sym_POUNDElif] = ACTIONS(9683),
    [anon_sym_POUNDelse] = ACTIONS(9683),
    [anon_sym_POUNDELSE] = ACTIONS(9683),
    [anon_sym_POUNDElse] = ACTIONS(9683),
    [anon_sym_POUNDendif] = ACTIONS(9683),
    [anon_sym_POUNDENDIF] = ACTIONS(9683),
    [anon_sym_POUNDEndif] = ACTIONS(9683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9683),
    [sym_trigger_keyword] = ACTIONS(9683),
    [sym_var_keyword] = ACTIONS(9683),
    [sym_local_keyword] = ACTIONS(9683),
    [sym_internal_keyword] = ACTIONS(9683),
    [sym_protected_keyword] = ACTIONS(9683),
    [sym_event_keyword] = ACTIONS(9683),
    [sym_fields_keyword] = ACTIONS(9683),
    [sym_keys_keyword] = ACTIONS(9683),
    [sym_fieldgroups_keyword] = ACTIONS(9683),
    [sym_actions_keyword] = ACTIONS(9683),
    [sym_layout_keyword] = ACTIONS(9683),
    [sym_area_keyword] = ACTIONS(9683),
    [sym_group_keyword] = ACTIONS(9683),
    [sym_repeater_keyword] = ACTIONS(9683),
    [sym_cuegroup_keyword] = ACTIONS(9683),
    [sym_fixed_keyword] = ACTIONS(9683),
    [sym_grid_keyword] = ACTIONS(9683),
    [sym_part_keyword] = ACTIONS(9683),
    [sym_systempart_keyword] = ACTIONS(9683),
    [sym_usercontrol_keyword] = ACTIONS(9683),
    [sym_dataset_keyword] = ACTIONS(9683),
    [sym_elements_keyword] = ACTIONS(9683),
    [sym_dataitem_keyword] = ACTIONS(9683),
    [sym_column_keyword] = ACTIONS(9683),
    [sym_filter_keyword] = ACTIONS(9683),
    [sym_labels_keyword] = ACTIONS(9683),
    [sym_rendering_keyword] = ACTIONS(9683),
    [sym_requestpage_keyword] = ACTIONS(9683),
    [sym_schema_keyword] = ACTIONS(9683),
    [sym_views_keyword] = ACTIONS(9683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9683),
    [sym_preproc_open] = ACTIONS(9683),
    [sym_preproc_close] = ACTIONS(9683),
  },
  [STATE(3611)] = {
    [anon_sym_SEMI] = ACTIONS(9683),
    [aux_sym_where_condition_token1] = ACTIONS(9685),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9683),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9683),
    [anon_sym_LBRACK] = ACTIONS(9683),
    [aux_sym_basic_type_token6] = ACTIONS(9685),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9683),
    [aux_sym_addafter_modification_token1] = ACTIONS(9683),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9683),
    [aux_sym_modify_modification_token1] = ACTIONS(9683),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9683),
    [aux_sym_movelast_modification_token1] = ACTIONS(9683),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9683),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9683),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9683),
    [anon_sym_POUNDif] = ACTIONS(9683),
    [anon_sym_POUNDIF] = ACTIONS(9683),
    [anon_sym_POUNDIf] = ACTIONS(9683),
    [anon_sym_POUNDelif] = ACTIONS(9683),
    [anon_sym_POUNDELIF] = ACTIONS(9683),
    [anon_sym_POUNDElif] = ACTIONS(9683),
    [anon_sym_POUNDelse] = ACTIONS(9683),
    [anon_sym_POUNDELSE] = ACTIONS(9683),
    [anon_sym_POUNDElse] = ACTIONS(9683),
    [anon_sym_POUNDendif] = ACTIONS(9683),
    [anon_sym_POUNDENDIF] = ACTIONS(9683),
    [anon_sym_POUNDEndif] = ACTIONS(9683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9683),
    [sym_trigger_keyword] = ACTIONS(9683),
    [sym_var_keyword] = ACTIONS(9683),
    [sym_local_keyword] = ACTIONS(9683),
    [sym_internal_keyword] = ACTIONS(9683),
    [sym_protected_keyword] = ACTIONS(9683),
    [sym_event_keyword] = ACTIONS(9683),
    [sym_fields_keyword] = ACTIONS(9683),
    [sym_keys_keyword] = ACTIONS(9683),
    [sym_fieldgroups_keyword] = ACTIONS(9683),
    [sym_actions_keyword] = ACTIONS(9683),
    [sym_layout_keyword] = ACTIONS(9683),
    [sym_area_keyword] = ACTIONS(9683),
    [sym_group_keyword] = ACTIONS(9683),
    [sym_repeater_keyword] = ACTIONS(9683),
    [sym_cuegroup_keyword] = ACTIONS(9683),
    [sym_fixed_keyword] = ACTIONS(9683),
    [sym_grid_keyword] = ACTIONS(9683),
    [sym_part_keyword] = ACTIONS(9683),
    [sym_systempart_keyword] = ACTIONS(9683),
    [sym_usercontrol_keyword] = ACTIONS(9683),
    [sym_dataset_keyword] = ACTIONS(9683),
    [sym_elements_keyword] = ACTIONS(9683),
    [sym_dataitem_keyword] = ACTIONS(9683),
    [sym_column_keyword] = ACTIONS(9683),
    [sym_filter_keyword] = ACTIONS(9683),
    [sym_labels_keyword] = ACTIONS(9683),
    [sym_rendering_keyword] = ACTIONS(9683),
    [sym_requestpage_keyword] = ACTIONS(9683),
    [sym_schema_keyword] = ACTIONS(9683),
    [sym_views_keyword] = ACTIONS(9683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9683),
    [sym_preproc_open] = ACTIONS(9683),
    [sym_preproc_close] = ACTIONS(9683),
  },
  [STATE(3612)] = {
    [anon_sym_SEMI] = ACTIONS(9687),
    [aux_sym_where_condition_token1] = ACTIONS(9689),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9691),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9691),
    [anon_sym_LBRACK] = ACTIONS(9691),
    [aux_sym_basic_type_token6] = ACTIONS(9689),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9691),
    [aux_sym_addafter_modification_token1] = ACTIONS(9691),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9691),
    [aux_sym_modify_modification_token1] = ACTIONS(9691),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9691),
    [aux_sym_movelast_modification_token1] = ACTIONS(9691),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9691),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9691),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9691),
    [anon_sym_POUNDif] = ACTIONS(9691),
    [anon_sym_POUNDIF] = ACTIONS(9691),
    [anon_sym_POUNDIf] = ACTIONS(9691),
    [anon_sym_POUNDelif] = ACTIONS(9691),
    [anon_sym_POUNDELIF] = ACTIONS(9691),
    [anon_sym_POUNDElif] = ACTIONS(9691),
    [anon_sym_POUNDelse] = ACTIONS(9691),
    [anon_sym_POUNDELSE] = ACTIONS(9691),
    [anon_sym_POUNDElse] = ACTIONS(9691),
    [anon_sym_POUNDendif] = ACTIONS(9691),
    [anon_sym_POUNDENDIF] = ACTIONS(9691),
    [anon_sym_POUNDEndif] = ACTIONS(9691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9691),
    [sym_trigger_keyword] = ACTIONS(9691),
    [sym_var_keyword] = ACTIONS(9691),
    [sym_local_keyword] = ACTIONS(9691),
    [sym_internal_keyword] = ACTIONS(9691),
    [sym_protected_keyword] = ACTIONS(9691),
    [sym_event_keyword] = ACTIONS(9691),
    [sym_fields_keyword] = ACTIONS(9691),
    [sym_keys_keyword] = ACTIONS(9691),
    [sym_fieldgroups_keyword] = ACTIONS(9691),
    [sym_actions_keyword] = ACTIONS(9691),
    [sym_layout_keyword] = ACTIONS(9691),
    [sym_area_keyword] = ACTIONS(9691),
    [sym_group_keyword] = ACTIONS(9691),
    [sym_repeater_keyword] = ACTIONS(9691),
    [sym_cuegroup_keyword] = ACTIONS(9691),
    [sym_fixed_keyword] = ACTIONS(9691),
    [sym_grid_keyword] = ACTIONS(9691),
    [sym_part_keyword] = ACTIONS(9691),
    [sym_systempart_keyword] = ACTIONS(9691),
    [sym_usercontrol_keyword] = ACTIONS(9691),
    [sym_dataset_keyword] = ACTIONS(9691),
    [sym_elements_keyword] = ACTIONS(9691),
    [sym_dataitem_keyword] = ACTIONS(9691),
    [sym_column_keyword] = ACTIONS(9691),
    [sym_filter_keyword] = ACTIONS(9691),
    [sym_labels_keyword] = ACTIONS(9691),
    [sym_rendering_keyword] = ACTIONS(9691),
    [sym_requestpage_keyword] = ACTIONS(9691),
    [sym_schema_keyword] = ACTIONS(9691),
    [sym_views_keyword] = ACTIONS(9691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9691),
    [sym_preproc_open] = ACTIONS(9691),
    [sym_preproc_close] = ACTIONS(9691),
  },
  [STATE(3613)] = {
    [anon_sym_SEMI] = ACTIONS(9693),
    [aux_sym_where_condition_token1] = ACTIONS(9695),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9693),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9693),
    [anon_sym_LBRACK] = ACTIONS(9693),
    [aux_sym_basic_type_token6] = ACTIONS(9695),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9693),
    [aux_sym_addafter_modification_token1] = ACTIONS(9693),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9693),
    [aux_sym_modify_modification_token1] = ACTIONS(9693),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9693),
    [aux_sym_movelast_modification_token1] = ACTIONS(9693),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9693),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9693),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9693),
    [anon_sym_POUNDif] = ACTIONS(9693),
    [anon_sym_POUNDIF] = ACTIONS(9693),
    [anon_sym_POUNDIf] = ACTIONS(9693),
    [anon_sym_POUNDelif] = ACTIONS(9693),
    [anon_sym_POUNDELIF] = ACTIONS(9693),
    [anon_sym_POUNDElif] = ACTIONS(9693),
    [anon_sym_POUNDelse] = ACTIONS(9693),
    [anon_sym_POUNDELSE] = ACTIONS(9693),
    [anon_sym_POUNDElse] = ACTIONS(9693),
    [anon_sym_POUNDendif] = ACTIONS(9693),
    [anon_sym_POUNDENDIF] = ACTIONS(9693),
    [anon_sym_POUNDEndif] = ACTIONS(9693),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9693),
    [sym_trigger_keyword] = ACTIONS(9693),
    [sym_var_keyword] = ACTIONS(9693),
    [sym_local_keyword] = ACTIONS(9693),
    [sym_internal_keyword] = ACTIONS(9693),
    [sym_protected_keyword] = ACTIONS(9693),
    [sym_event_keyword] = ACTIONS(9693),
    [sym_fields_keyword] = ACTIONS(9693),
    [sym_keys_keyword] = ACTIONS(9693),
    [sym_fieldgroups_keyword] = ACTIONS(9693),
    [sym_actions_keyword] = ACTIONS(9693),
    [sym_layout_keyword] = ACTIONS(9693),
    [sym_area_keyword] = ACTIONS(9693),
    [sym_group_keyword] = ACTIONS(9693),
    [sym_repeater_keyword] = ACTIONS(9693),
    [sym_cuegroup_keyword] = ACTIONS(9693),
    [sym_fixed_keyword] = ACTIONS(9693),
    [sym_grid_keyword] = ACTIONS(9693),
    [sym_part_keyword] = ACTIONS(9693),
    [sym_systempart_keyword] = ACTIONS(9693),
    [sym_usercontrol_keyword] = ACTIONS(9693),
    [sym_dataset_keyword] = ACTIONS(9693),
    [sym_elements_keyword] = ACTIONS(9693),
    [sym_dataitem_keyword] = ACTIONS(9693),
    [sym_column_keyword] = ACTIONS(9693),
    [sym_filter_keyword] = ACTIONS(9693),
    [sym_labels_keyword] = ACTIONS(9693),
    [sym_rendering_keyword] = ACTIONS(9693),
    [sym_requestpage_keyword] = ACTIONS(9693),
    [sym_schema_keyword] = ACTIONS(9693),
    [sym_views_keyword] = ACTIONS(9693),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9693),
    [sym_preproc_open] = ACTIONS(9693),
    [sym_preproc_close] = ACTIONS(9693),
  },
  [STATE(3614)] = {
    [anon_sym_SEMI] = ACTIONS(7577),
    [aux_sym_where_condition_token1] = ACTIONS(7575),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7577),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7577),
    [anon_sym_LBRACK] = ACTIONS(7577),
    [aux_sym_basic_type_token6] = ACTIONS(7575),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7577),
    [aux_sym_addafter_modification_token1] = ACTIONS(7577),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7577),
    [aux_sym_modify_modification_token1] = ACTIONS(7577),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7577),
    [aux_sym_movelast_modification_token1] = ACTIONS(7577),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7577),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7577),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7577),
    [anon_sym_POUNDif] = ACTIONS(7577),
    [anon_sym_POUNDIF] = ACTIONS(7577),
    [anon_sym_POUNDIf] = ACTIONS(7577),
    [anon_sym_POUNDelif] = ACTIONS(7577),
    [anon_sym_POUNDELIF] = ACTIONS(7577),
    [anon_sym_POUNDElif] = ACTIONS(7577),
    [anon_sym_POUNDelse] = ACTIONS(7577),
    [anon_sym_POUNDELSE] = ACTIONS(7577),
    [anon_sym_POUNDElse] = ACTIONS(7577),
    [anon_sym_POUNDendif] = ACTIONS(7577),
    [anon_sym_POUNDENDIF] = ACTIONS(7577),
    [anon_sym_POUNDEndif] = ACTIONS(7577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7577),
    [sym_trigger_keyword] = ACTIONS(7577),
    [sym_var_keyword] = ACTIONS(7577),
    [sym_local_keyword] = ACTIONS(7577),
    [sym_internal_keyword] = ACTIONS(7577),
    [sym_protected_keyword] = ACTIONS(7577),
    [sym_event_keyword] = ACTIONS(7577),
    [sym_fields_keyword] = ACTIONS(7577),
    [sym_keys_keyword] = ACTIONS(7577),
    [sym_fieldgroups_keyword] = ACTIONS(7577),
    [sym_actions_keyword] = ACTIONS(7577),
    [sym_layout_keyword] = ACTIONS(7577),
    [sym_area_keyword] = ACTIONS(7577),
    [sym_group_keyword] = ACTIONS(7577),
    [sym_repeater_keyword] = ACTIONS(7577),
    [sym_cuegroup_keyword] = ACTIONS(7577),
    [sym_fixed_keyword] = ACTIONS(7577),
    [sym_grid_keyword] = ACTIONS(7577),
    [sym_part_keyword] = ACTIONS(7577),
    [sym_systempart_keyword] = ACTIONS(7577),
    [sym_usercontrol_keyword] = ACTIONS(7577),
    [sym_dataset_keyword] = ACTIONS(7577),
    [sym_elements_keyword] = ACTIONS(7577),
    [sym_dataitem_keyword] = ACTIONS(7577),
    [sym_column_keyword] = ACTIONS(7577),
    [sym_filter_keyword] = ACTIONS(7577),
    [sym_labels_keyword] = ACTIONS(7577),
    [sym_rendering_keyword] = ACTIONS(7577),
    [sym_requestpage_keyword] = ACTIONS(7577),
    [sym_schema_keyword] = ACTIONS(7577),
    [sym_views_keyword] = ACTIONS(7577),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7577),
    [sym_preproc_open] = ACTIONS(7577),
    [sym_preproc_close] = ACTIONS(7577),
  },
  [STATE(3615)] = {
    [anon_sym_SEMI] = ACTIONS(9697),
    [aux_sym_where_condition_token1] = ACTIONS(9699),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9697),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9697),
    [anon_sym_LBRACK] = ACTIONS(9697),
    [aux_sym_basic_type_token6] = ACTIONS(9699),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9697),
    [aux_sym_addafter_modification_token1] = ACTIONS(9697),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9697),
    [aux_sym_modify_modification_token1] = ACTIONS(9697),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9697),
    [aux_sym_movelast_modification_token1] = ACTIONS(9697),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9697),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9697),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9697),
    [anon_sym_POUNDif] = ACTIONS(9697),
    [anon_sym_POUNDIF] = ACTIONS(9697),
    [anon_sym_POUNDIf] = ACTIONS(9697),
    [anon_sym_POUNDelif] = ACTIONS(9697),
    [anon_sym_POUNDELIF] = ACTIONS(9697),
    [anon_sym_POUNDElif] = ACTIONS(9697),
    [anon_sym_POUNDelse] = ACTIONS(9697),
    [anon_sym_POUNDELSE] = ACTIONS(9697),
    [anon_sym_POUNDElse] = ACTIONS(9697),
    [anon_sym_POUNDendif] = ACTIONS(9697),
    [anon_sym_POUNDENDIF] = ACTIONS(9697),
    [anon_sym_POUNDEndif] = ACTIONS(9697),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9697),
    [sym_trigger_keyword] = ACTIONS(9697),
    [sym_var_keyword] = ACTIONS(9697),
    [sym_local_keyword] = ACTIONS(9697),
    [sym_internal_keyword] = ACTIONS(9697),
    [sym_protected_keyword] = ACTIONS(9697),
    [sym_event_keyword] = ACTIONS(9697),
    [sym_fields_keyword] = ACTIONS(9697),
    [sym_keys_keyword] = ACTIONS(9697),
    [sym_fieldgroups_keyword] = ACTIONS(9697),
    [sym_actions_keyword] = ACTIONS(9697),
    [sym_layout_keyword] = ACTIONS(9697),
    [sym_area_keyword] = ACTIONS(9697),
    [sym_group_keyword] = ACTIONS(9697),
    [sym_repeater_keyword] = ACTIONS(9697),
    [sym_cuegroup_keyword] = ACTIONS(9697),
    [sym_fixed_keyword] = ACTIONS(9697),
    [sym_grid_keyword] = ACTIONS(9697),
    [sym_part_keyword] = ACTIONS(9697),
    [sym_systempart_keyword] = ACTIONS(9697),
    [sym_usercontrol_keyword] = ACTIONS(9697),
    [sym_dataset_keyword] = ACTIONS(9697),
    [sym_elements_keyword] = ACTIONS(9697),
    [sym_dataitem_keyword] = ACTIONS(9697),
    [sym_column_keyword] = ACTIONS(9697),
    [sym_filter_keyword] = ACTIONS(9697),
    [sym_labels_keyword] = ACTIONS(9697),
    [sym_rendering_keyword] = ACTIONS(9697),
    [sym_requestpage_keyword] = ACTIONS(9697),
    [sym_schema_keyword] = ACTIONS(9697),
    [sym_views_keyword] = ACTIONS(9697),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9697),
    [sym_preproc_open] = ACTIONS(9697),
    [sym_preproc_close] = ACTIONS(9697),
  },
  [STATE(3616)] = {
    [anon_sym_SEMI] = ACTIONS(7577),
    [aux_sym_where_condition_token1] = ACTIONS(7575),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7577),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7577),
    [anon_sym_LBRACK] = ACTIONS(7577),
    [aux_sym_basic_type_token6] = ACTIONS(7575),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7577),
    [aux_sym_addafter_modification_token1] = ACTIONS(7577),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7577),
    [aux_sym_modify_modification_token1] = ACTIONS(7577),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7577),
    [aux_sym_movelast_modification_token1] = ACTIONS(7577),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7577),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7577),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7577),
    [anon_sym_POUNDif] = ACTIONS(7577),
    [anon_sym_POUNDIF] = ACTIONS(7577),
    [anon_sym_POUNDIf] = ACTIONS(7577),
    [anon_sym_POUNDelif] = ACTIONS(7577),
    [anon_sym_POUNDELIF] = ACTIONS(7577),
    [anon_sym_POUNDElif] = ACTIONS(7577),
    [anon_sym_POUNDelse] = ACTIONS(7577),
    [anon_sym_POUNDELSE] = ACTIONS(7577),
    [anon_sym_POUNDElse] = ACTIONS(7577),
    [anon_sym_POUNDendif] = ACTIONS(7577),
    [anon_sym_POUNDENDIF] = ACTIONS(7577),
    [anon_sym_POUNDEndif] = ACTIONS(7577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7577),
    [sym_trigger_keyword] = ACTIONS(7577),
    [sym_var_keyword] = ACTIONS(7577),
    [sym_local_keyword] = ACTIONS(7577),
    [sym_internal_keyword] = ACTIONS(7577),
    [sym_protected_keyword] = ACTIONS(7577),
    [sym_event_keyword] = ACTIONS(7577),
    [sym_fields_keyword] = ACTIONS(7577),
    [sym_keys_keyword] = ACTIONS(7577),
    [sym_fieldgroups_keyword] = ACTIONS(7577),
    [sym_actions_keyword] = ACTIONS(7577),
    [sym_layout_keyword] = ACTIONS(7577),
    [sym_area_keyword] = ACTIONS(7577),
    [sym_group_keyword] = ACTIONS(7577),
    [sym_repeater_keyword] = ACTIONS(7577),
    [sym_cuegroup_keyword] = ACTIONS(7577),
    [sym_fixed_keyword] = ACTIONS(7577),
    [sym_grid_keyword] = ACTIONS(7577),
    [sym_part_keyword] = ACTIONS(7577),
    [sym_systempart_keyword] = ACTIONS(7577),
    [sym_usercontrol_keyword] = ACTIONS(7577),
    [sym_dataset_keyword] = ACTIONS(7577),
    [sym_elements_keyword] = ACTIONS(7577),
    [sym_dataitem_keyword] = ACTIONS(7577),
    [sym_column_keyword] = ACTIONS(7577),
    [sym_filter_keyword] = ACTIONS(7577),
    [sym_labels_keyword] = ACTIONS(7577),
    [sym_rendering_keyword] = ACTIONS(7577),
    [sym_requestpage_keyword] = ACTIONS(7577),
    [sym_schema_keyword] = ACTIONS(7577),
    [sym_views_keyword] = ACTIONS(7577),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7577),
    [sym_preproc_open] = ACTIONS(7577),
    [sym_preproc_close] = ACTIONS(7577),
  },
  [STATE(3617)] = {
    [anon_sym_SEMI] = ACTIONS(9639),
    [aux_sym_where_condition_token1] = ACTIONS(9641),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9639),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9639),
    [anon_sym_LBRACK] = ACTIONS(9639),
    [aux_sym_basic_type_token6] = ACTIONS(9641),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9639),
    [aux_sym_addafter_modification_token1] = ACTIONS(9639),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9639),
    [aux_sym_modify_modification_token1] = ACTIONS(9639),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9639),
    [aux_sym_movelast_modification_token1] = ACTIONS(9639),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9639),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9639),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9639),
    [anon_sym_POUNDif] = ACTIONS(9639),
    [anon_sym_POUNDIF] = ACTIONS(9639),
    [anon_sym_POUNDIf] = ACTIONS(9639),
    [anon_sym_POUNDelif] = ACTIONS(9639),
    [anon_sym_POUNDELIF] = ACTIONS(9639),
    [anon_sym_POUNDElif] = ACTIONS(9639),
    [anon_sym_POUNDelse] = ACTIONS(9639),
    [anon_sym_POUNDELSE] = ACTIONS(9639),
    [anon_sym_POUNDElse] = ACTIONS(9639),
    [anon_sym_POUNDendif] = ACTIONS(9639),
    [anon_sym_POUNDENDIF] = ACTIONS(9639),
    [anon_sym_POUNDEndif] = ACTIONS(9639),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9639),
    [sym_trigger_keyword] = ACTIONS(9639),
    [sym_var_keyword] = ACTIONS(9639),
    [sym_local_keyword] = ACTIONS(9639),
    [sym_internal_keyword] = ACTIONS(9639),
    [sym_protected_keyword] = ACTIONS(9639),
    [sym_event_keyword] = ACTIONS(9639),
    [sym_fields_keyword] = ACTIONS(9639),
    [sym_keys_keyword] = ACTIONS(9639),
    [sym_fieldgroups_keyword] = ACTIONS(9639),
    [sym_actions_keyword] = ACTIONS(9639),
    [sym_layout_keyword] = ACTIONS(9639),
    [sym_area_keyword] = ACTIONS(9639),
    [sym_group_keyword] = ACTIONS(9639),
    [sym_repeater_keyword] = ACTIONS(9639),
    [sym_cuegroup_keyword] = ACTIONS(9639),
    [sym_fixed_keyword] = ACTIONS(9639),
    [sym_grid_keyword] = ACTIONS(9639),
    [sym_part_keyword] = ACTIONS(9639),
    [sym_systempart_keyword] = ACTIONS(9639),
    [sym_usercontrol_keyword] = ACTIONS(9639),
    [sym_dataset_keyword] = ACTIONS(9639),
    [sym_elements_keyword] = ACTIONS(9639),
    [sym_dataitem_keyword] = ACTIONS(9639),
    [sym_column_keyword] = ACTIONS(9639),
    [sym_filter_keyword] = ACTIONS(9639),
    [sym_labels_keyword] = ACTIONS(9639),
    [sym_rendering_keyword] = ACTIONS(9639),
    [sym_requestpage_keyword] = ACTIONS(9639),
    [sym_schema_keyword] = ACTIONS(9639),
    [sym_views_keyword] = ACTIONS(9639),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9639),
    [sym_preproc_open] = ACTIONS(9639),
    [sym_preproc_close] = ACTIONS(9639),
  },
  [STATE(3618)] = {
    [anon_sym_SEMI] = ACTIONS(9701),
    [aux_sym_where_condition_token1] = ACTIONS(9689),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9691),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9691),
    [anon_sym_LBRACK] = ACTIONS(9691),
    [aux_sym_basic_type_token6] = ACTIONS(9689),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9691),
    [aux_sym_addafter_modification_token1] = ACTIONS(9691),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9691),
    [aux_sym_modify_modification_token1] = ACTIONS(9691),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9691),
    [aux_sym_movelast_modification_token1] = ACTIONS(9691),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9691),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9691),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9691),
    [anon_sym_POUNDif] = ACTIONS(9691),
    [anon_sym_POUNDIF] = ACTIONS(9691),
    [anon_sym_POUNDIf] = ACTIONS(9691),
    [anon_sym_POUNDelif] = ACTIONS(9691),
    [anon_sym_POUNDELIF] = ACTIONS(9691),
    [anon_sym_POUNDElif] = ACTIONS(9691),
    [anon_sym_POUNDelse] = ACTIONS(9691),
    [anon_sym_POUNDELSE] = ACTIONS(9691),
    [anon_sym_POUNDElse] = ACTIONS(9691),
    [anon_sym_POUNDendif] = ACTIONS(9691),
    [anon_sym_POUNDENDIF] = ACTIONS(9691),
    [anon_sym_POUNDEndif] = ACTIONS(9691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9691),
    [sym_trigger_keyword] = ACTIONS(9691),
    [sym_var_keyword] = ACTIONS(9691),
    [sym_local_keyword] = ACTIONS(9691),
    [sym_internal_keyword] = ACTIONS(9691),
    [sym_protected_keyword] = ACTIONS(9691),
    [sym_event_keyword] = ACTIONS(9691),
    [sym_fields_keyword] = ACTIONS(9691),
    [sym_keys_keyword] = ACTIONS(9691),
    [sym_fieldgroups_keyword] = ACTIONS(9691),
    [sym_actions_keyword] = ACTIONS(9691),
    [sym_layout_keyword] = ACTIONS(9691),
    [sym_area_keyword] = ACTIONS(9691),
    [sym_group_keyword] = ACTIONS(9691),
    [sym_repeater_keyword] = ACTIONS(9691),
    [sym_cuegroup_keyword] = ACTIONS(9691),
    [sym_fixed_keyword] = ACTIONS(9691),
    [sym_grid_keyword] = ACTIONS(9691),
    [sym_part_keyword] = ACTIONS(9691),
    [sym_systempart_keyword] = ACTIONS(9691),
    [sym_usercontrol_keyword] = ACTIONS(9691),
    [sym_dataset_keyword] = ACTIONS(9691),
    [sym_elements_keyword] = ACTIONS(9691),
    [sym_dataitem_keyword] = ACTIONS(9691),
    [sym_column_keyword] = ACTIONS(9691),
    [sym_filter_keyword] = ACTIONS(9691),
    [sym_labels_keyword] = ACTIONS(9691),
    [sym_rendering_keyword] = ACTIONS(9691),
    [sym_requestpage_keyword] = ACTIONS(9691),
    [sym_schema_keyword] = ACTIONS(9691),
    [sym_views_keyword] = ACTIONS(9691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9691),
    [sym_preproc_open] = ACTIONS(9691),
    [sym_preproc_close] = ACTIONS(9691),
  },
  [STATE(3619)] = {
    [anon_sym_SEMI] = ACTIONS(9703),
    [aux_sym_where_condition_token1] = ACTIONS(9705),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9703),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9703),
    [anon_sym_LBRACK] = ACTIONS(9703),
    [aux_sym_basic_type_token6] = ACTIONS(9705),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9703),
    [aux_sym_addafter_modification_token1] = ACTIONS(9703),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9703),
    [aux_sym_modify_modification_token1] = ACTIONS(9703),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9703),
    [aux_sym_movelast_modification_token1] = ACTIONS(9703),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9703),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9703),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9703),
    [anon_sym_POUNDif] = ACTIONS(9703),
    [anon_sym_POUNDIF] = ACTIONS(9703),
    [anon_sym_POUNDIf] = ACTIONS(9703),
    [anon_sym_POUNDelif] = ACTIONS(9703),
    [anon_sym_POUNDELIF] = ACTIONS(9703),
    [anon_sym_POUNDElif] = ACTIONS(9703),
    [anon_sym_POUNDelse] = ACTIONS(9703),
    [anon_sym_POUNDELSE] = ACTIONS(9703),
    [anon_sym_POUNDElse] = ACTIONS(9703),
    [anon_sym_POUNDendif] = ACTIONS(9703),
    [anon_sym_POUNDENDIF] = ACTIONS(9703),
    [anon_sym_POUNDEndif] = ACTIONS(9703),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9703),
    [sym_trigger_keyword] = ACTIONS(9703),
    [sym_var_keyword] = ACTIONS(9703),
    [sym_local_keyword] = ACTIONS(9703),
    [sym_internal_keyword] = ACTIONS(9703),
    [sym_protected_keyword] = ACTIONS(9703),
    [sym_event_keyword] = ACTIONS(9703),
    [sym_fields_keyword] = ACTIONS(9703),
    [sym_keys_keyword] = ACTIONS(9703),
    [sym_fieldgroups_keyword] = ACTIONS(9703),
    [sym_actions_keyword] = ACTIONS(9703),
    [sym_layout_keyword] = ACTIONS(9703),
    [sym_area_keyword] = ACTIONS(9703),
    [sym_group_keyword] = ACTIONS(9703),
    [sym_repeater_keyword] = ACTIONS(9703),
    [sym_cuegroup_keyword] = ACTIONS(9703),
    [sym_fixed_keyword] = ACTIONS(9703),
    [sym_grid_keyword] = ACTIONS(9703),
    [sym_part_keyword] = ACTIONS(9703),
    [sym_systempart_keyword] = ACTIONS(9703),
    [sym_usercontrol_keyword] = ACTIONS(9703),
    [sym_dataset_keyword] = ACTIONS(9703),
    [sym_elements_keyword] = ACTIONS(9703),
    [sym_dataitem_keyword] = ACTIONS(9703),
    [sym_column_keyword] = ACTIONS(9703),
    [sym_filter_keyword] = ACTIONS(9703),
    [sym_labels_keyword] = ACTIONS(9703),
    [sym_rendering_keyword] = ACTIONS(9703),
    [sym_requestpage_keyword] = ACTIONS(9703),
    [sym_schema_keyword] = ACTIONS(9703),
    [sym_views_keyword] = ACTIONS(9703),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9703),
    [sym_preproc_open] = ACTIONS(9703),
    [sym_preproc_close] = ACTIONS(9703),
  },
  [STATE(3620)] = {
    [anon_sym_SEMI] = ACTIONS(9703),
    [aux_sym_where_condition_token1] = ACTIONS(9705),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9703),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9703),
    [anon_sym_LBRACK] = ACTIONS(9703),
    [aux_sym_basic_type_token6] = ACTIONS(9705),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9703),
    [aux_sym_addafter_modification_token1] = ACTIONS(9703),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9703),
    [aux_sym_modify_modification_token1] = ACTIONS(9703),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9703),
    [aux_sym_movelast_modification_token1] = ACTIONS(9703),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9703),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9703),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9703),
    [anon_sym_POUNDif] = ACTIONS(9703),
    [anon_sym_POUNDIF] = ACTIONS(9703),
    [anon_sym_POUNDIf] = ACTIONS(9703),
    [anon_sym_POUNDelif] = ACTIONS(9703),
    [anon_sym_POUNDELIF] = ACTIONS(9703),
    [anon_sym_POUNDElif] = ACTIONS(9703),
    [anon_sym_POUNDelse] = ACTIONS(9703),
    [anon_sym_POUNDELSE] = ACTIONS(9703),
    [anon_sym_POUNDElse] = ACTIONS(9703),
    [anon_sym_POUNDendif] = ACTIONS(9703),
    [anon_sym_POUNDENDIF] = ACTIONS(9703),
    [anon_sym_POUNDEndif] = ACTIONS(9703),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9703),
    [sym_trigger_keyword] = ACTIONS(9703),
    [sym_var_keyword] = ACTIONS(9703),
    [sym_local_keyword] = ACTIONS(9703),
    [sym_internal_keyword] = ACTIONS(9703),
    [sym_protected_keyword] = ACTIONS(9703),
    [sym_event_keyword] = ACTIONS(9703),
    [sym_fields_keyword] = ACTIONS(9703),
    [sym_keys_keyword] = ACTIONS(9703),
    [sym_fieldgroups_keyword] = ACTIONS(9703),
    [sym_actions_keyword] = ACTIONS(9703),
    [sym_layout_keyword] = ACTIONS(9703),
    [sym_area_keyword] = ACTIONS(9703),
    [sym_group_keyword] = ACTIONS(9703),
    [sym_repeater_keyword] = ACTIONS(9703),
    [sym_cuegroup_keyword] = ACTIONS(9703),
    [sym_fixed_keyword] = ACTIONS(9703),
    [sym_grid_keyword] = ACTIONS(9703),
    [sym_part_keyword] = ACTIONS(9703),
    [sym_systempart_keyword] = ACTIONS(9703),
    [sym_usercontrol_keyword] = ACTIONS(9703),
    [sym_dataset_keyword] = ACTIONS(9703),
    [sym_elements_keyword] = ACTIONS(9703),
    [sym_dataitem_keyword] = ACTIONS(9703),
    [sym_column_keyword] = ACTIONS(9703),
    [sym_filter_keyword] = ACTIONS(9703),
    [sym_labels_keyword] = ACTIONS(9703),
    [sym_rendering_keyword] = ACTIONS(9703),
    [sym_requestpage_keyword] = ACTIONS(9703),
    [sym_schema_keyword] = ACTIONS(9703),
    [sym_views_keyword] = ACTIONS(9703),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9703),
    [sym_preproc_open] = ACTIONS(9703),
    [sym_preproc_close] = ACTIONS(9703),
  },
  [STATE(3621)] = {
    [anon_sym_SEMI] = ACTIONS(9707),
    [aux_sym_where_condition_token1] = ACTIONS(9709),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9707),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9707),
    [anon_sym_LBRACK] = ACTIONS(9707),
    [aux_sym_basic_type_token6] = ACTIONS(9709),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9707),
    [aux_sym_addafter_modification_token1] = ACTIONS(9707),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9707),
    [aux_sym_modify_modification_token1] = ACTIONS(9707),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9707),
    [aux_sym_movelast_modification_token1] = ACTIONS(9707),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9707),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9707),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9707),
    [anon_sym_POUNDif] = ACTIONS(9707),
    [anon_sym_POUNDIF] = ACTIONS(9707),
    [anon_sym_POUNDIf] = ACTIONS(9707),
    [anon_sym_POUNDelif] = ACTIONS(9707),
    [anon_sym_POUNDELIF] = ACTIONS(9707),
    [anon_sym_POUNDElif] = ACTIONS(9707),
    [anon_sym_POUNDelse] = ACTIONS(9707),
    [anon_sym_POUNDELSE] = ACTIONS(9707),
    [anon_sym_POUNDElse] = ACTIONS(9707),
    [anon_sym_POUNDendif] = ACTIONS(9707),
    [anon_sym_POUNDENDIF] = ACTIONS(9707),
    [anon_sym_POUNDEndif] = ACTIONS(9707),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9707),
    [sym_trigger_keyword] = ACTIONS(9707),
    [sym_var_keyword] = ACTIONS(9707),
    [sym_local_keyword] = ACTIONS(9707),
    [sym_internal_keyword] = ACTIONS(9707),
    [sym_protected_keyword] = ACTIONS(9707),
    [sym_event_keyword] = ACTIONS(9707),
    [sym_fields_keyword] = ACTIONS(9707),
    [sym_keys_keyword] = ACTIONS(9707),
    [sym_fieldgroups_keyword] = ACTIONS(9707),
    [sym_actions_keyword] = ACTIONS(9707),
    [sym_layout_keyword] = ACTIONS(9707),
    [sym_area_keyword] = ACTIONS(9707),
    [sym_group_keyword] = ACTIONS(9707),
    [sym_repeater_keyword] = ACTIONS(9707),
    [sym_cuegroup_keyword] = ACTIONS(9707),
    [sym_fixed_keyword] = ACTIONS(9707),
    [sym_grid_keyword] = ACTIONS(9707),
    [sym_part_keyword] = ACTIONS(9707),
    [sym_systempart_keyword] = ACTIONS(9707),
    [sym_usercontrol_keyword] = ACTIONS(9707),
    [sym_dataset_keyword] = ACTIONS(9707),
    [sym_elements_keyword] = ACTIONS(9707),
    [sym_dataitem_keyword] = ACTIONS(9707),
    [sym_column_keyword] = ACTIONS(9707),
    [sym_filter_keyword] = ACTIONS(9707),
    [sym_labels_keyword] = ACTIONS(9707),
    [sym_rendering_keyword] = ACTIONS(9707),
    [sym_requestpage_keyword] = ACTIONS(9707),
    [sym_schema_keyword] = ACTIONS(9707),
    [sym_views_keyword] = ACTIONS(9707),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9707),
    [sym_preproc_open] = ACTIONS(9707),
    [sym_preproc_close] = ACTIONS(9707),
  },
  [STATE(3622)] = {
    [anon_sym_SEMI] = ACTIONS(9711),
    [aux_sym_where_condition_token1] = ACTIONS(9713),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9711),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9711),
    [anon_sym_LBRACK] = ACTIONS(9711),
    [aux_sym_basic_type_token6] = ACTIONS(9713),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9711),
    [aux_sym_addafter_modification_token1] = ACTIONS(9711),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9711),
    [aux_sym_modify_modification_token1] = ACTIONS(9711),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9711),
    [aux_sym_movelast_modification_token1] = ACTIONS(9711),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9711),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9711),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9711),
    [anon_sym_POUNDif] = ACTIONS(9711),
    [anon_sym_POUNDIF] = ACTIONS(9711),
    [anon_sym_POUNDIf] = ACTIONS(9711),
    [anon_sym_POUNDelif] = ACTIONS(9711),
    [anon_sym_POUNDELIF] = ACTIONS(9711),
    [anon_sym_POUNDElif] = ACTIONS(9711),
    [anon_sym_POUNDelse] = ACTIONS(9711),
    [anon_sym_POUNDELSE] = ACTIONS(9711),
    [anon_sym_POUNDElse] = ACTIONS(9711),
    [anon_sym_POUNDendif] = ACTIONS(9711),
    [anon_sym_POUNDENDIF] = ACTIONS(9711),
    [anon_sym_POUNDEndif] = ACTIONS(9711),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9711),
    [sym_trigger_keyword] = ACTIONS(9711),
    [sym_var_keyword] = ACTIONS(9711),
    [sym_local_keyword] = ACTIONS(9711),
    [sym_internal_keyword] = ACTIONS(9711),
    [sym_protected_keyword] = ACTIONS(9711),
    [sym_event_keyword] = ACTIONS(9711),
    [sym_fields_keyword] = ACTIONS(9711),
    [sym_keys_keyword] = ACTIONS(9711),
    [sym_fieldgroups_keyword] = ACTIONS(9711),
    [sym_actions_keyword] = ACTIONS(9711),
    [sym_layout_keyword] = ACTIONS(9711),
    [sym_area_keyword] = ACTIONS(9711),
    [sym_group_keyword] = ACTIONS(9711),
    [sym_repeater_keyword] = ACTIONS(9711),
    [sym_cuegroup_keyword] = ACTIONS(9711),
    [sym_fixed_keyword] = ACTIONS(9711),
    [sym_grid_keyword] = ACTIONS(9711),
    [sym_part_keyword] = ACTIONS(9711),
    [sym_systempart_keyword] = ACTIONS(9711),
    [sym_usercontrol_keyword] = ACTIONS(9711),
    [sym_dataset_keyword] = ACTIONS(9711),
    [sym_elements_keyword] = ACTIONS(9711),
    [sym_dataitem_keyword] = ACTIONS(9711),
    [sym_column_keyword] = ACTIONS(9711),
    [sym_filter_keyword] = ACTIONS(9711),
    [sym_labels_keyword] = ACTIONS(9711),
    [sym_rendering_keyword] = ACTIONS(9711),
    [sym_requestpage_keyword] = ACTIONS(9711),
    [sym_schema_keyword] = ACTIONS(9711),
    [sym_views_keyword] = ACTIONS(9711),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9711),
    [sym_preproc_open] = ACTIONS(9711),
    [sym_preproc_close] = ACTIONS(9711),
  },
  [STATE(3623)] = {
    [anon_sym_SEMI] = ACTIONS(7154),
    [aux_sym_where_condition_token1] = ACTIONS(7152),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7154),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7154),
    [anon_sym_LBRACK] = ACTIONS(7154),
    [aux_sym_basic_type_token6] = ACTIONS(7152),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7154),
    [aux_sym_addafter_modification_token1] = ACTIONS(7154),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7154),
    [aux_sym_modify_modification_token1] = ACTIONS(7154),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7154),
    [aux_sym_movelast_modification_token1] = ACTIONS(7154),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7154),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7154),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7154),
    [anon_sym_POUNDif] = ACTIONS(7154),
    [anon_sym_POUNDIF] = ACTIONS(7154),
    [anon_sym_POUNDIf] = ACTIONS(7154),
    [anon_sym_POUNDelif] = ACTIONS(7154),
    [anon_sym_POUNDELIF] = ACTIONS(7154),
    [anon_sym_POUNDElif] = ACTIONS(7154),
    [anon_sym_POUNDelse] = ACTIONS(7154),
    [anon_sym_POUNDELSE] = ACTIONS(7154),
    [anon_sym_POUNDElse] = ACTIONS(7154),
    [anon_sym_POUNDendif] = ACTIONS(7154),
    [anon_sym_POUNDENDIF] = ACTIONS(7154),
    [anon_sym_POUNDEndif] = ACTIONS(7154),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7154),
    [sym_trigger_keyword] = ACTIONS(7154),
    [sym_var_keyword] = ACTIONS(7154),
    [sym_local_keyword] = ACTIONS(7154),
    [sym_internal_keyword] = ACTIONS(7154),
    [sym_protected_keyword] = ACTIONS(7154),
    [sym_event_keyword] = ACTIONS(7154),
    [sym_fields_keyword] = ACTIONS(7154),
    [sym_keys_keyword] = ACTIONS(7154),
    [sym_fieldgroups_keyword] = ACTIONS(7154),
    [sym_actions_keyword] = ACTIONS(7154),
    [sym_layout_keyword] = ACTIONS(7154),
    [sym_area_keyword] = ACTIONS(7154),
    [sym_group_keyword] = ACTIONS(7154),
    [sym_repeater_keyword] = ACTIONS(7154),
    [sym_cuegroup_keyword] = ACTIONS(7154),
    [sym_fixed_keyword] = ACTIONS(7154),
    [sym_grid_keyword] = ACTIONS(7154),
    [sym_part_keyword] = ACTIONS(7154),
    [sym_systempart_keyword] = ACTIONS(7154),
    [sym_usercontrol_keyword] = ACTIONS(7154),
    [sym_dataset_keyword] = ACTIONS(7154),
    [sym_elements_keyword] = ACTIONS(7154),
    [sym_dataitem_keyword] = ACTIONS(7154),
    [sym_column_keyword] = ACTIONS(7154),
    [sym_filter_keyword] = ACTIONS(7154),
    [sym_labels_keyword] = ACTIONS(7154),
    [sym_rendering_keyword] = ACTIONS(7154),
    [sym_requestpage_keyword] = ACTIONS(7154),
    [sym_schema_keyword] = ACTIONS(7154),
    [sym_views_keyword] = ACTIONS(7154),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7154),
    [sym_preproc_open] = ACTIONS(7154),
    [sym_preproc_close] = ACTIONS(7154),
  },
  [STATE(3624)] = {
    [anon_sym_SEMI] = ACTIONS(7168),
    [aux_sym_where_condition_token1] = ACTIONS(7166),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7168),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7168),
    [anon_sym_LBRACK] = ACTIONS(7168),
    [aux_sym_basic_type_token6] = ACTIONS(7166),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7168),
    [aux_sym_addafter_modification_token1] = ACTIONS(7168),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7168),
    [aux_sym_modify_modification_token1] = ACTIONS(7168),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7168),
    [aux_sym_movelast_modification_token1] = ACTIONS(7168),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7168),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7168),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7168),
    [anon_sym_POUNDif] = ACTIONS(7168),
    [anon_sym_POUNDIF] = ACTIONS(7168),
    [anon_sym_POUNDIf] = ACTIONS(7168),
    [anon_sym_POUNDelif] = ACTIONS(7168),
    [anon_sym_POUNDELIF] = ACTIONS(7168),
    [anon_sym_POUNDElif] = ACTIONS(7168),
    [anon_sym_POUNDelse] = ACTIONS(7168),
    [anon_sym_POUNDELSE] = ACTIONS(7168),
    [anon_sym_POUNDElse] = ACTIONS(7168),
    [anon_sym_POUNDendif] = ACTIONS(7168),
    [anon_sym_POUNDENDIF] = ACTIONS(7168),
    [anon_sym_POUNDEndif] = ACTIONS(7168),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7168),
    [sym_trigger_keyword] = ACTIONS(7168),
    [sym_var_keyword] = ACTIONS(7168),
    [sym_local_keyword] = ACTIONS(7168),
    [sym_internal_keyword] = ACTIONS(7168),
    [sym_protected_keyword] = ACTIONS(7168),
    [sym_event_keyword] = ACTIONS(7168),
    [sym_fields_keyword] = ACTIONS(7168),
    [sym_keys_keyword] = ACTIONS(7168),
    [sym_fieldgroups_keyword] = ACTIONS(7168),
    [sym_actions_keyword] = ACTIONS(7168),
    [sym_layout_keyword] = ACTIONS(7168),
    [sym_area_keyword] = ACTIONS(7168),
    [sym_group_keyword] = ACTIONS(7168),
    [sym_repeater_keyword] = ACTIONS(7168),
    [sym_cuegroup_keyword] = ACTIONS(7168),
    [sym_fixed_keyword] = ACTIONS(7168),
    [sym_grid_keyword] = ACTIONS(7168),
    [sym_part_keyword] = ACTIONS(7168),
    [sym_systempart_keyword] = ACTIONS(7168),
    [sym_usercontrol_keyword] = ACTIONS(7168),
    [sym_dataset_keyword] = ACTIONS(7168),
    [sym_elements_keyword] = ACTIONS(7168),
    [sym_dataitem_keyword] = ACTIONS(7168),
    [sym_column_keyword] = ACTIONS(7168),
    [sym_filter_keyword] = ACTIONS(7168),
    [sym_labels_keyword] = ACTIONS(7168),
    [sym_rendering_keyword] = ACTIONS(7168),
    [sym_requestpage_keyword] = ACTIONS(7168),
    [sym_schema_keyword] = ACTIONS(7168),
    [sym_views_keyword] = ACTIONS(7168),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7168),
    [sym_preproc_open] = ACTIONS(7168),
    [sym_preproc_close] = ACTIONS(7168),
  },
  [STATE(3625)] = {
    [anon_sym_SEMI] = ACTIONS(7168),
    [aux_sym_where_condition_token1] = ACTIONS(7166),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7168),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7168),
    [anon_sym_LBRACK] = ACTIONS(7168),
    [aux_sym_basic_type_token6] = ACTIONS(7166),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7168),
    [aux_sym_addafter_modification_token1] = ACTIONS(7168),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7168),
    [aux_sym_modify_modification_token1] = ACTIONS(7168),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7168),
    [aux_sym_movelast_modification_token1] = ACTIONS(7168),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7168),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7168),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7168),
    [anon_sym_POUNDif] = ACTIONS(7168),
    [anon_sym_POUNDIF] = ACTIONS(7168),
    [anon_sym_POUNDIf] = ACTIONS(7168),
    [anon_sym_POUNDelif] = ACTIONS(7168),
    [anon_sym_POUNDELIF] = ACTIONS(7168),
    [anon_sym_POUNDElif] = ACTIONS(7168),
    [anon_sym_POUNDelse] = ACTIONS(7168),
    [anon_sym_POUNDELSE] = ACTIONS(7168),
    [anon_sym_POUNDElse] = ACTIONS(7168),
    [anon_sym_POUNDendif] = ACTIONS(7168),
    [anon_sym_POUNDENDIF] = ACTIONS(7168),
    [anon_sym_POUNDEndif] = ACTIONS(7168),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7168),
    [sym_trigger_keyword] = ACTIONS(7168),
    [sym_var_keyword] = ACTIONS(7168),
    [sym_local_keyword] = ACTIONS(7168),
    [sym_internal_keyword] = ACTIONS(7168),
    [sym_protected_keyword] = ACTIONS(7168),
    [sym_event_keyword] = ACTIONS(7168),
    [sym_fields_keyword] = ACTIONS(7168),
    [sym_keys_keyword] = ACTIONS(7168),
    [sym_fieldgroups_keyword] = ACTIONS(7168),
    [sym_actions_keyword] = ACTIONS(7168),
    [sym_layout_keyword] = ACTIONS(7168),
    [sym_area_keyword] = ACTIONS(7168),
    [sym_group_keyword] = ACTIONS(7168),
    [sym_repeater_keyword] = ACTIONS(7168),
    [sym_cuegroup_keyword] = ACTIONS(7168),
    [sym_fixed_keyword] = ACTIONS(7168),
    [sym_grid_keyword] = ACTIONS(7168),
    [sym_part_keyword] = ACTIONS(7168),
    [sym_systempart_keyword] = ACTIONS(7168),
    [sym_usercontrol_keyword] = ACTIONS(7168),
    [sym_dataset_keyword] = ACTIONS(7168),
    [sym_elements_keyword] = ACTIONS(7168),
    [sym_dataitem_keyword] = ACTIONS(7168),
    [sym_column_keyword] = ACTIONS(7168),
    [sym_filter_keyword] = ACTIONS(7168),
    [sym_labels_keyword] = ACTIONS(7168),
    [sym_rendering_keyword] = ACTIONS(7168),
    [sym_requestpage_keyword] = ACTIONS(7168),
    [sym_schema_keyword] = ACTIONS(7168),
    [sym_views_keyword] = ACTIONS(7168),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7168),
    [sym_preproc_open] = ACTIONS(7168),
    [sym_preproc_close] = ACTIONS(7168),
  },
  [STATE(3626)] = {
    [anon_sym_SEMI] = ACTIONS(9707),
    [aux_sym_where_condition_token1] = ACTIONS(9709),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9707),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9707),
    [anon_sym_LBRACK] = ACTIONS(9707),
    [aux_sym_basic_type_token6] = ACTIONS(9709),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9707),
    [aux_sym_addafter_modification_token1] = ACTIONS(9707),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9707),
    [aux_sym_modify_modification_token1] = ACTIONS(9707),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9707),
    [aux_sym_movelast_modification_token1] = ACTIONS(9707),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9707),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9707),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9707),
    [anon_sym_POUNDif] = ACTIONS(9707),
    [anon_sym_POUNDIF] = ACTIONS(9707),
    [anon_sym_POUNDIf] = ACTIONS(9707),
    [anon_sym_POUNDelif] = ACTIONS(9707),
    [anon_sym_POUNDELIF] = ACTIONS(9707),
    [anon_sym_POUNDElif] = ACTIONS(9707),
    [anon_sym_POUNDelse] = ACTIONS(9707),
    [anon_sym_POUNDELSE] = ACTIONS(9707),
    [anon_sym_POUNDElse] = ACTIONS(9707),
    [anon_sym_POUNDendif] = ACTIONS(9707),
    [anon_sym_POUNDENDIF] = ACTIONS(9707),
    [anon_sym_POUNDEndif] = ACTIONS(9707),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9707),
    [sym_trigger_keyword] = ACTIONS(9707),
    [sym_var_keyword] = ACTIONS(9707),
    [sym_local_keyword] = ACTIONS(9707),
    [sym_internal_keyword] = ACTIONS(9707),
    [sym_protected_keyword] = ACTIONS(9707),
    [sym_event_keyword] = ACTIONS(9707),
    [sym_fields_keyword] = ACTIONS(9707),
    [sym_keys_keyword] = ACTIONS(9707),
    [sym_fieldgroups_keyword] = ACTIONS(9707),
    [sym_actions_keyword] = ACTIONS(9707),
    [sym_layout_keyword] = ACTIONS(9707),
    [sym_area_keyword] = ACTIONS(9707),
    [sym_group_keyword] = ACTIONS(9707),
    [sym_repeater_keyword] = ACTIONS(9707),
    [sym_cuegroup_keyword] = ACTIONS(9707),
    [sym_fixed_keyword] = ACTIONS(9707),
    [sym_grid_keyword] = ACTIONS(9707),
    [sym_part_keyword] = ACTIONS(9707),
    [sym_systempart_keyword] = ACTIONS(9707),
    [sym_usercontrol_keyword] = ACTIONS(9707),
    [sym_dataset_keyword] = ACTIONS(9707),
    [sym_elements_keyword] = ACTIONS(9707),
    [sym_dataitem_keyword] = ACTIONS(9707),
    [sym_column_keyword] = ACTIONS(9707),
    [sym_filter_keyword] = ACTIONS(9707),
    [sym_labels_keyword] = ACTIONS(9707),
    [sym_rendering_keyword] = ACTIONS(9707),
    [sym_requestpage_keyword] = ACTIONS(9707),
    [sym_schema_keyword] = ACTIONS(9707),
    [sym_views_keyword] = ACTIONS(9707),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9707),
    [sym_preproc_open] = ACTIONS(9707),
    [sym_preproc_close] = ACTIONS(9707),
  },
  [STATE(3627)] = {
    [anon_sym_SEMI] = ACTIONS(9711),
    [aux_sym_where_condition_token1] = ACTIONS(9713),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9711),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9711),
    [anon_sym_LBRACK] = ACTIONS(9711),
    [aux_sym_basic_type_token6] = ACTIONS(9713),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9711),
    [aux_sym_addafter_modification_token1] = ACTIONS(9711),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9711),
    [aux_sym_modify_modification_token1] = ACTIONS(9711),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9711),
    [aux_sym_movelast_modification_token1] = ACTIONS(9711),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9711),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9711),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9711),
    [anon_sym_POUNDif] = ACTIONS(9711),
    [anon_sym_POUNDIF] = ACTIONS(9711),
    [anon_sym_POUNDIf] = ACTIONS(9711),
    [anon_sym_POUNDelif] = ACTIONS(9711),
    [anon_sym_POUNDELIF] = ACTIONS(9711),
    [anon_sym_POUNDElif] = ACTIONS(9711),
    [anon_sym_POUNDelse] = ACTIONS(9711),
    [anon_sym_POUNDELSE] = ACTIONS(9711),
    [anon_sym_POUNDElse] = ACTIONS(9711),
    [anon_sym_POUNDendif] = ACTIONS(9711),
    [anon_sym_POUNDENDIF] = ACTIONS(9711),
    [anon_sym_POUNDEndif] = ACTIONS(9711),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9711),
    [sym_trigger_keyword] = ACTIONS(9711),
    [sym_var_keyword] = ACTIONS(9711),
    [sym_local_keyword] = ACTIONS(9711),
    [sym_internal_keyword] = ACTIONS(9711),
    [sym_protected_keyword] = ACTIONS(9711),
    [sym_event_keyword] = ACTIONS(9711),
    [sym_fields_keyword] = ACTIONS(9711),
    [sym_keys_keyword] = ACTIONS(9711),
    [sym_fieldgroups_keyword] = ACTIONS(9711),
    [sym_actions_keyword] = ACTIONS(9711),
    [sym_layout_keyword] = ACTIONS(9711),
    [sym_area_keyword] = ACTIONS(9711),
    [sym_group_keyword] = ACTIONS(9711),
    [sym_repeater_keyword] = ACTIONS(9711),
    [sym_cuegroup_keyword] = ACTIONS(9711),
    [sym_fixed_keyword] = ACTIONS(9711),
    [sym_grid_keyword] = ACTIONS(9711),
    [sym_part_keyword] = ACTIONS(9711),
    [sym_systempart_keyword] = ACTIONS(9711),
    [sym_usercontrol_keyword] = ACTIONS(9711),
    [sym_dataset_keyword] = ACTIONS(9711),
    [sym_elements_keyword] = ACTIONS(9711),
    [sym_dataitem_keyword] = ACTIONS(9711),
    [sym_column_keyword] = ACTIONS(9711),
    [sym_filter_keyword] = ACTIONS(9711),
    [sym_labels_keyword] = ACTIONS(9711),
    [sym_rendering_keyword] = ACTIONS(9711),
    [sym_requestpage_keyword] = ACTIONS(9711),
    [sym_schema_keyword] = ACTIONS(9711),
    [sym_views_keyword] = ACTIONS(9711),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9711),
    [sym_preproc_open] = ACTIONS(9711),
    [sym_preproc_close] = ACTIONS(9711),
  },
  [STATE(3628)] = {
    [anon_sym_SEMI] = ACTIONS(9715),
    [aux_sym_where_condition_token1] = ACTIONS(9717),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9719),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9719),
    [anon_sym_LBRACK] = ACTIONS(9719),
    [aux_sym_basic_type_token6] = ACTIONS(9717),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9719),
    [aux_sym_addafter_modification_token1] = ACTIONS(9719),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9719),
    [aux_sym_modify_modification_token1] = ACTIONS(9719),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9719),
    [aux_sym_movelast_modification_token1] = ACTIONS(9719),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9719),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9719),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9719),
    [anon_sym_POUNDif] = ACTIONS(9719),
    [anon_sym_POUNDIF] = ACTIONS(9719),
    [anon_sym_POUNDIf] = ACTIONS(9719),
    [anon_sym_POUNDelif] = ACTIONS(9719),
    [anon_sym_POUNDELIF] = ACTIONS(9719),
    [anon_sym_POUNDElif] = ACTIONS(9719),
    [anon_sym_POUNDelse] = ACTIONS(9719),
    [anon_sym_POUNDELSE] = ACTIONS(9719),
    [anon_sym_POUNDElse] = ACTIONS(9719),
    [anon_sym_POUNDendif] = ACTIONS(9719),
    [anon_sym_POUNDENDIF] = ACTIONS(9719),
    [anon_sym_POUNDEndif] = ACTIONS(9719),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9719),
    [sym_trigger_keyword] = ACTIONS(9719),
    [sym_var_keyword] = ACTIONS(9719),
    [sym_local_keyword] = ACTIONS(9719),
    [sym_internal_keyword] = ACTIONS(9719),
    [sym_protected_keyword] = ACTIONS(9719),
    [sym_event_keyword] = ACTIONS(9719),
    [sym_fields_keyword] = ACTIONS(9719),
    [sym_keys_keyword] = ACTIONS(9719),
    [sym_fieldgroups_keyword] = ACTIONS(9719),
    [sym_actions_keyword] = ACTIONS(9719),
    [sym_layout_keyword] = ACTIONS(9719),
    [sym_area_keyword] = ACTIONS(9719),
    [sym_group_keyword] = ACTIONS(9719),
    [sym_repeater_keyword] = ACTIONS(9719),
    [sym_cuegroup_keyword] = ACTIONS(9719),
    [sym_fixed_keyword] = ACTIONS(9719),
    [sym_grid_keyword] = ACTIONS(9719),
    [sym_part_keyword] = ACTIONS(9719),
    [sym_systempart_keyword] = ACTIONS(9719),
    [sym_usercontrol_keyword] = ACTIONS(9719),
    [sym_dataset_keyword] = ACTIONS(9719),
    [sym_elements_keyword] = ACTIONS(9719),
    [sym_dataitem_keyword] = ACTIONS(9719),
    [sym_column_keyword] = ACTIONS(9719),
    [sym_filter_keyword] = ACTIONS(9719),
    [sym_labels_keyword] = ACTIONS(9719),
    [sym_rendering_keyword] = ACTIONS(9719),
    [sym_requestpage_keyword] = ACTIONS(9719),
    [sym_schema_keyword] = ACTIONS(9719),
    [sym_views_keyword] = ACTIONS(9719),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9719),
    [sym_preproc_open] = ACTIONS(9719),
    [sym_preproc_close] = ACTIONS(9719),
  },
  [STATE(3629)] = {
    [anon_sym_SEMI] = ACTIONS(9721),
    [aux_sym_where_condition_token1] = ACTIONS(9723),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9721),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9721),
    [anon_sym_LBRACK] = ACTIONS(9721),
    [aux_sym_basic_type_token6] = ACTIONS(9723),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9721),
    [aux_sym_addafter_modification_token1] = ACTIONS(9721),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9721),
    [aux_sym_modify_modification_token1] = ACTIONS(9721),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9721),
    [aux_sym_movelast_modification_token1] = ACTIONS(9721),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9721),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9721),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9721),
    [anon_sym_POUNDif] = ACTIONS(9721),
    [anon_sym_POUNDIF] = ACTIONS(9721),
    [anon_sym_POUNDIf] = ACTIONS(9721),
    [anon_sym_POUNDelif] = ACTIONS(9721),
    [anon_sym_POUNDELIF] = ACTIONS(9721),
    [anon_sym_POUNDElif] = ACTIONS(9721),
    [anon_sym_POUNDelse] = ACTIONS(9721),
    [anon_sym_POUNDELSE] = ACTIONS(9721),
    [anon_sym_POUNDElse] = ACTIONS(9721),
    [anon_sym_POUNDendif] = ACTIONS(9721),
    [anon_sym_POUNDENDIF] = ACTIONS(9721),
    [anon_sym_POUNDEndif] = ACTIONS(9721),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9721),
    [sym_trigger_keyword] = ACTIONS(9721),
    [sym_var_keyword] = ACTIONS(9721),
    [sym_local_keyword] = ACTIONS(9721),
    [sym_internal_keyword] = ACTIONS(9721),
    [sym_protected_keyword] = ACTIONS(9721),
    [sym_event_keyword] = ACTIONS(9721),
    [sym_fields_keyword] = ACTIONS(9721),
    [sym_keys_keyword] = ACTIONS(9721),
    [sym_fieldgroups_keyword] = ACTIONS(9721),
    [sym_actions_keyword] = ACTIONS(9721),
    [sym_layout_keyword] = ACTIONS(9721),
    [sym_area_keyword] = ACTIONS(9721),
    [sym_group_keyword] = ACTIONS(9721),
    [sym_repeater_keyword] = ACTIONS(9721),
    [sym_cuegroup_keyword] = ACTIONS(9721),
    [sym_fixed_keyword] = ACTIONS(9721),
    [sym_grid_keyword] = ACTIONS(9721),
    [sym_part_keyword] = ACTIONS(9721),
    [sym_systempart_keyword] = ACTIONS(9721),
    [sym_usercontrol_keyword] = ACTIONS(9721),
    [sym_dataset_keyword] = ACTIONS(9721),
    [sym_elements_keyword] = ACTIONS(9721),
    [sym_dataitem_keyword] = ACTIONS(9721),
    [sym_column_keyword] = ACTIONS(9721),
    [sym_filter_keyword] = ACTIONS(9721),
    [sym_labels_keyword] = ACTIONS(9721),
    [sym_rendering_keyword] = ACTIONS(9721),
    [sym_requestpage_keyword] = ACTIONS(9721),
    [sym_schema_keyword] = ACTIONS(9721),
    [sym_views_keyword] = ACTIONS(9721),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9721),
    [sym_preproc_open] = ACTIONS(9721),
    [sym_preproc_close] = ACTIONS(9721),
  },
  [STATE(3630)] = {
    [anon_sym_SEMI] = ACTIONS(7369),
    [aux_sym_where_condition_token1] = ACTIONS(7367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7369),
    [anon_sym_LBRACK] = ACTIONS(7369),
    [aux_sym_basic_type_token6] = ACTIONS(7367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7369),
    [aux_sym_addafter_modification_token1] = ACTIONS(7369),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7369),
    [aux_sym_modify_modification_token1] = ACTIONS(7369),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7369),
    [aux_sym_movelast_modification_token1] = ACTIONS(7369),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7369),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7369),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7369),
    [anon_sym_POUNDif] = ACTIONS(7369),
    [anon_sym_POUNDIF] = ACTIONS(7369),
    [anon_sym_POUNDIf] = ACTIONS(7369),
    [anon_sym_POUNDelif] = ACTIONS(7369),
    [anon_sym_POUNDELIF] = ACTIONS(7369),
    [anon_sym_POUNDElif] = ACTIONS(7369),
    [anon_sym_POUNDelse] = ACTIONS(7369),
    [anon_sym_POUNDELSE] = ACTIONS(7369),
    [anon_sym_POUNDElse] = ACTIONS(7369),
    [anon_sym_POUNDendif] = ACTIONS(7369),
    [anon_sym_POUNDENDIF] = ACTIONS(7369),
    [anon_sym_POUNDEndif] = ACTIONS(7369),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7369),
    [sym_trigger_keyword] = ACTIONS(7369),
    [sym_var_keyword] = ACTIONS(7369),
    [sym_local_keyword] = ACTIONS(7369),
    [sym_internal_keyword] = ACTIONS(7369),
    [sym_protected_keyword] = ACTIONS(7369),
    [sym_event_keyword] = ACTIONS(7369),
    [sym_fields_keyword] = ACTIONS(7369),
    [sym_keys_keyword] = ACTIONS(7369),
    [sym_fieldgroups_keyword] = ACTIONS(7369),
    [sym_actions_keyword] = ACTIONS(7369),
    [sym_layout_keyword] = ACTIONS(7369),
    [sym_area_keyword] = ACTIONS(7369),
    [sym_group_keyword] = ACTIONS(7369),
    [sym_repeater_keyword] = ACTIONS(7369),
    [sym_cuegroup_keyword] = ACTIONS(7369),
    [sym_fixed_keyword] = ACTIONS(7369),
    [sym_grid_keyword] = ACTIONS(7369),
    [sym_part_keyword] = ACTIONS(7369),
    [sym_systempart_keyword] = ACTIONS(7369),
    [sym_usercontrol_keyword] = ACTIONS(7369),
    [sym_dataset_keyword] = ACTIONS(7369),
    [sym_elements_keyword] = ACTIONS(7369),
    [sym_dataitem_keyword] = ACTIONS(7369),
    [sym_column_keyword] = ACTIONS(7369),
    [sym_filter_keyword] = ACTIONS(7369),
    [sym_labels_keyword] = ACTIONS(7369),
    [sym_rendering_keyword] = ACTIONS(7369),
    [sym_requestpage_keyword] = ACTIONS(7369),
    [sym_schema_keyword] = ACTIONS(7369),
    [sym_views_keyword] = ACTIONS(7369),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7369),
    [sym_preproc_open] = ACTIONS(7369),
    [sym_preproc_close] = ACTIONS(7369),
  },
  [STATE(3631)] = {
    [anon_sym_SEMI] = ACTIONS(7373),
    [aux_sym_where_condition_token1] = ACTIONS(7371),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7373),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7373),
    [anon_sym_LBRACK] = ACTIONS(7373),
    [aux_sym_basic_type_token6] = ACTIONS(7371),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7373),
    [aux_sym_addafter_modification_token1] = ACTIONS(7373),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7373),
    [aux_sym_modify_modification_token1] = ACTIONS(7373),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7373),
    [aux_sym_movelast_modification_token1] = ACTIONS(7373),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7373),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7373),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7373),
    [anon_sym_POUNDif] = ACTIONS(7373),
    [anon_sym_POUNDIF] = ACTIONS(7373),
    [anon_sym_POUNDIf] = ACTIONS(7373),
    [anon_sym_POUNDelif] = ACTIONS(7373),
    [anon_sym_POUNDELIF] = ACTIONS(7373),
    [anon_sym_POUNDElif] = ACTIONS(7373),
    [anon_sym_POUNDelse] = ACTIONS(7373),
    [anon_sym_POUNDELSE] = ACTIONS(7373),
    [anon_sym_POUNDElse] = ACTIONS(7373),
    [anon_sym_POUNDendif] = ACTIONS(7373),
    [anon_sym_POUNDENDIF] = ACTIONS(7373),
    [anon_sym_POUNDEndif] = ACTIONS(7373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7373),
    [sym_trigger_keyword] = ACTIONS(7373),
    [sym_var_keyword] = ACTIONS(7373),
    [sym_local_keyword] = ACTIONS(7373),
    [sym_internal_keyword] = ACTIONS(7373),
    [sym_protected_keyword] = ACTIONS(7373),
    [sym_event_keyword] = ACTIONS(7373),
    [sym_fields_keyword] = ACTIONS(7373),
    [sym_keys_keyword] = ACTIONS(7373),
    [sym_fieldgroups_keyword] = ACTIONS(7373),
    [sym_actions_keyword] = ACTIONS(7373),
    [sym_layout_keyword] = ACTIONS(7373),
    [sym_area_keyword] = ACTIONS(7373),
    [sym_group_keyword] = ACTIONS(7373),
    [sym_repeater_keyword] = ACTIONS(7373),
    [sym_cuegroup_keyword] = ACTIONS(7373),
    [sym_fixed_keyword] = ACTIONS(7373),
    [sym_grid_keyword] = ACTIONS(7373),
    [sym_part_keyword] = ACTIONS(7373),
    [sym_systempart_keyword] = ACTIONS(7373),
    [sym_usercontrol_keyword] = ACTIONS(7373),
    [sym_dataset_keyword] = ACTIONS(7373),
    [sym_elements_keyword] = ACTIONS(7373),
    [sym_dataitem_keyword] = ACTIONS(7373),
    [sym_column_keyword] = ACTIONS(7373),
    [sym_filter_keyword] = ACTIONS(7373),
    [sym_labels_keyword] = ACTIONS(7373),
    [sym_rendering_keyword] = ACTIONS(7373),
    [sym_requestpage_keyword] = ACTIONS(7373),
    [sym_schema_keyword] = ACTIONS(7373),
    [sym_views_keyword] = ACTIONS(7373),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7373),
    [sym_preproc_open] = ACTIONS(7373),
    [sym_preproc_close] = ACTIONS(7373),
  },
  [STATE(3632)] = {
    [anon_sym_SEMI] = ACTIONS(7577),
    [aux_sym_where_condition_token1] = ACTIONS(7575),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7577),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7577),
    [anon_sym_LBRACK] = ACTIONS(7577),
    [aux_sym_basic_type_token6] = ACTIONS(7575),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7577),
    [aux_sym_addafter_modification_token1] = ACTIONS(7577),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7577),
    [aux_sym_modify_modification_token1] = ACTIONS(7577),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7577),
    [aux_sym_movelast_modification_token1] = ACTIONS(7577),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7577),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7577),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7577),
    [anon_sym_POUNDif] = ACTIONS(7577),
    [anon_sym_POUNDIF] = ACTIONS(7577),
    [anon_sym_POUNDIf] = ACTIONS(7577),
    [anon_sym_POUNDelif] = ACTIONS(7577),
    [anon_sym_POUNDELIF] = ACTIONS(7577),
    [anon_sym_POUNDElif] = ACTIONS(7577),
    [anon_sym_POUNDelse] = ACTIONS(7577),
    [anon_sym_POUNDELSE] = ACTIONS(7577),
    [anon_sym_POUNDElse] = ACTIONS(7577),
    [anon_sym_POUNDendif] = ACTIONS(7577),
    [anon_sym_POUNDENDIF] = ACTIONS(7577),
    [anon_sym_POUNDEndif] = ACTIONS(7577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7577),
    [sym_trigger_keyword] = ACTIONS(7577),
    [sym_var_keyword] = ACTIONS(7577),
    [sym_local_keyword] = ACTIONS(7577),
    [sym_internal_keyword] = ACTIONS(7577),
    [sym_protected_keyword] = ACTIONS(7577),
    [sym_event_keyword] = ACTIONS(7577),
    [sym_fields_keyword] = ACTIONS(7577),
    [sym_keys_keyword] = ACTIONS(7577),
    [sym_fieldgroups_keyword] = ACTIONS(7577),
    [sym_actions_keyword] = ACTIONS(7577),
    [sym_layout_keyword] = ACTIONS(7577),
    [sym_area_keyword] = ACTIONS(7577),
    [sym_group_keyword] = ACTIONS(7577),
    [sym_repeater_keyword] = ACTIONS(7577),
    [sym_cuegroup_keyword] = ACTIONS(7577),
    [sym_fixed_keyword] = ACTIONS(7577),
    [sym_grid_keyword] = ACTIONS(7577),
    [sym_part_keyword] = ACTIONS(7577),
    [sym_systempart_keyword] = ACTIONS(7577),
    [sym_usercontrol_keyword] = ACTIONS(7577),
    [sym_dataset_keyword] = ACTIONS(7577),
    [sym_elements_keyword] = ACTIONS(7577),
    [sym_dataitem_keyword] = ACTIONS(7577),
    [sym_column_keyword] = ACTIONS(7577),
    [sym_filter_keyword] = ACTIONS(7577),
    [sym_labels_keyword] = ACTIONS(7577),
    [sym_rendering_keyword] = ACTIONS(7577),
    [sym_requestpage_keyword] = ACTIONS(7577),
    [sym_schema_keyword] = ACTIONS(7577),
    [sym_views_keyword] = ACTIONS(7577),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7577),
    [sym_preproc_open] = ACTIONS(7577),
    [sym_preproc_close] = ACTIONS(7577),
  },
  [STATE(3633)] = {
    [anon_sym_SEMI] = ACTIONS(9693),
    [aux_sym_where_condition_token1] = ACTIONS(9695),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9693),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9693),
    [anon_sym_LBRACK] = ACTIONS(9693),
    [aux_sym_basic_type_token6] = ACTIONS(9695),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9693),
    [aux_sym_addafter_modification_token1] = ACTIONS(9693),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9693),
    [aux_sym_modify_modification_token1] = ACTIONS(9693),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9693),
    [aux_sym_movelast_modification_token1] = ACTIONS(9693),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9693),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9693),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9693),
    [anon_sym_POUNDif] = ACTIONS(9693),
    [anon_sym_POUNDIF] = ACTIONS(9693),
    [anon_sym_POUNDIf] = ACTIONS(9693),
    [anon_sym_POUNDelif] = ACTIONS(9693),
    [anon_sym_POUNDELIF] = ACTIONS(9693),
    [anon_sym_POUNDElif] = ACTIONS(9693),
    [anon_sym_POUNDelse] = ACTIONS(9693),
    [anon_sym_POUNDELSE] = ACTIONS(9693),
    [anon_sym_POUNDElse] = ACTIONS(9693),
    [anon_sym_POUNDendif] = ACTIONS(9693),
    [anon_sym_POUNDENDIF] = ACTIONS(9693),
    [anon_sym_POUNDEndif] = ACTIONS(9693),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9693),
    [sym_trigger_keyword] = ACTIONS(9693),
    [sym_var_keyword] = ACTIONS(9693),
    [sym_local_keyword] = ACTIONS(9693),
    [sym_internal_keyword] = ACTIONS(9693),
    [sym_protected_keyword] = ACTIONS(9693),
    [sym_event_keyword] = ACTIONS(9693),
    [sym_fields_keyword] = ACTIONS(9693),
    [sym_keys_keyword] = ACTIONS(9693),
    [sym_fieldgroups_keyword] = ACTIONS(9693),
    [sym_actions_keyword] = ACTIONS(9693),
    [sym_layout_keyword] = ACTIONS(9693),
    [sym_area_keyword] = ACTIONS(9693),
    [sym_group_keyword] = ACTIONS(9693),
    [sym_repeater_keyword] = ACTIONS(9693),
    [sym_cuegroup_keyword] = ACTIONS(9693),
    [sym_fixed_keyword] = ACTIONS(9693),
    [sym_grid_keyword] = ACTIONS(9693),
    [sym_part_keyword] = ACTIONS(9693),
    [sym_systempart_keyword] = ACTIONS(9693),
    [sym_usercontrol_keyword] = ACTIONS(9693),
    [sym_dataset_keyword] = ACTIONS(9693),
    [sym_elements_keyword] = ACTIONS(9693),
    [sym_dataitem_keyword] = ACTIONS(9693),
    [sym_column_keyword] = ACTIONS(9693),
    [sym_filter_keyword] = ACTIONS(9693),
    [sym_labels_keyword] = ACTIONS(9693),
    [sym_rendering_keyword] = ACTIONS(9693),
    [sym_requestpage_keyword] = ACTIONS(9693),
    [sym_schema_keyword] = ACTIONS(9693),
    [sym_views_keyword] = ACTIONS(9693),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9693),
    [sym_preproc_open] = ACTIONS(9693),
    [sym_preproc_close] = ACTIONS(9693),
  },
  [STATE(3634)] = {
    [anon_sym_SEMI] = ACTIONS(9725),
    [aux_sym_where_condition_token1] = ACTIONS(9717),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9719),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9719),
    [anon_sym_LBRACK] = ACTIONS(9719),
    [aux_sym_basic_type_token6] = ACTIONS(9717),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9719),
    [aux_sym_addafter_modification_token1] = ACTIONS(9719),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9719),
    [aux_sym_modify_modification_token1] = ACTIONS(9719),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9719),
    [aux_sym_movelast_modification_token1] = ACTIONS(9719),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9719),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9719),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9719),
    [anon_sym_POUNDif] = ACTIONS(9719),
    [anon_sym_POUNDIF] = ACTIONS(9719),
    [anon_sym_POUNDIf] = ACTIONS(9719),
    [anon_sym_POUNDelif] = ACTIONS(9719),
    [anon_sym_POUNDELIF] = ACTIONS(9719),
    [anon_sym_POUNDElif] = ACTIONS(9719),
    [anon_sym_POUNDelse] = ACTIONS(9719),
    [anon_sym_POUNDELSE] = ACTIONS(9719),
    [anon_sym_POUNDElse] = ACTIONS(9719),
    [anon_sym_POUNDendif] = ACTIONS(9719),
    [anon_sym_POUNDENDIF] = ACTIONS(9719),
    [anon_sym_POUNDEndif] = ACTIONS(9719),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9719),
    [sym_trigger_keyword] = ACTIONS(9719),
    [sym_var_keyword] = ACTIONS(9719),
    [sym_local_keyword] = ACTIONS(9719),
    [sym_internal_keyword] = ACTIONS(9719),
    [sym_protected_keyword] = ACTIONS(9719),
    [sym_event_keyword] = ACTIONS(9719),
    [sym_fields_keyword] = ACTIONS(9719),
    [sym_keys_keyword] = ACTIONS(9719),
    [sym_fieldgroups_keyword] = ACTIONS(9719),
    [sym_actions_keyword] = ACTIONS(9719),
    [sym_layout_keyword] = ACTIONS(9719),
    [sym_area_keyword] = ACTIONS(9719),
    [sym_group_keyword] = ACTIONS(9719),
    [sym_repeater_keyword] = ACTIONS(9719),
    [sym_cuegroup_keyword] = ACTIONS(9719),
    [sym_fixed_keyword] = ACTIONS(9719),
    [sym_grid_keyword] = ACTIONS(9719),
    [sym_part_keyword] = ACTIONS(9719),
    [sym_systempart_keyword] = ACTIONS(9719),
    [sym_usercontrol_keyword] = ACTIONS(9719),
    [sym_dataset_keyword] = ACTIONS(9719),
    [sym_elements_keyword] = ACTIONS(9719),
    [sym_dataitem_keyword] = ACTIONS(9719),
    [sym_column_keyword] = ACTIONS(9719),
    [sym_filter_keyword] = ACTIONS(9719),
    [sym_labels_keyword] = ACTIONS(9719),
    [sym_rendering_keyword] = ACTIONS(9719),
    [sym_requestpage_keyword] = ACTIONS(9719),
    [sym_schema_keyword] = ACTIONS(9719),
    [sym_views_keyword] = ACTIONS(9719),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9719),
    [sym_preproc_open] = ACTIONS(9719),
    [sym_preproc_close] = ACTIONS(9719),
  },
  [STATE(3635)] = {
    [anon_sym_SEMI] = ACTIONS(9721),
    [aux_sym_where_condition_token1] = ACTIONS(9723),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9721),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9721),
    [anon_sym_LBRACK] = ACTIONS(9721),
    [aux_sym_basic_type_token6] = ACTIONS(9723),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9721),
    [aux_sym_addafter_modification_token1] = ACTIONS(9721),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9721),
    [aux_sym_modify_modification_token1] = ACTIONS(9721),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9721),
    [aux_sym_movelast_modification_token1] = ACTIONS(9721),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9721),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9721),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9721),
    [anon_sym_POUNDif] = ACTIONS(9721),
    [anon_sym_POUNDIF] = ACTIONS(9721),
    [anon_sym_POUNDIf] = ACTIONS(9721),
    [anon_sym_POUNDelif] = ACTIONS(9721),
    [anon_sym_POUNDELIF] = ACTIONS(9721),
    [anon_sym_POUNDElif] = ACTIONS(9721),
    [anon_sym_POUNDelse] = ACTIONS(9721),
    [anon_sym_POUNDELSE] = ACTIONS(9721),
    [anon_sym_POUNDElse] = ACTIONS(9721),
    [anon_sym_POUNDendif] = ACTIONS(9721),
    [anon_sym_POUNDENDIF] = ACTIONS(9721),
    [anon_sym_POUNDEndif] = ACTIONS(9721),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9721),
    [sym_trigger_keyword] = ACTIONS(9721),
    [sym_var_keyword] = ACTIONS(9721),
    [sym_local_keyword] = ACTIONS(9721),
    [sym_internal_keyword] = ACTIONS(9721),
    [sym_protected_keyword] = ACTIONS(9721),
    [sym_event_keyword] = ACTIONS(9721),
    [sym_fields_keyword] = ACTIONS(9721),
    [sym_keys_keyword] = ACTIONS(9721),
    [sym_fieldgroups_keyword] = ACTIONS(9721),
    [sym_actions_keyword] = ACTIONS(9721),
    [sym_layout_keyword] = ACTIONS(9721),
    [sym_area_keyword] = ACTIONS(9721),
    [sym_group_keyword] = ACTIONS(9721),
    [sym_repeater_keyword] = ACTIONS(9721),
    [sym_cuegroup_keyword] = ACTIONS(9721),
    [sym_fixed_keyword] = ACTIONS(9721),
    [sym_grid_keyword] = ACTIONS(9721),
    [sym_part_keyword] = ACTIONS(9721),
    [sym_systempart_keyword] = ACTIONS(9721),
    [sym_usercontrol_keyword] = ACTIONS(9721),
    [sym_dataset_keyword] = ACTIONS(9721),
    [sym_elements_keyword] = ACTIONS(9721),
    [sym_dataitem_keyword] = ACTIONS(9721),
    [sym_column_keyword] = ACTIONS(9721),
    [sym_filter_keyword] = ACTIONS(9721),
    [sym_labels_keyword] = ACTIONS(9721),
    [sym_rendering_keyword] = ACTIONS(9721),
    [sym_requestpage_keyword] = ACTIONS(9721),
    [sym_schema_keyword] = ACTIONS(9721),
    [sym_views_keyword] = ACTIONS(9721),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9721),
    [sym_preproc_open] = ACTIONS(9721),
    [sym_preproc_close] = ACTIONS(9721),
  },
  [STATE(3636)] = {
    [anon_sym_SEMI] = ACTIONS(9727),
    [aux_sym_where_condition_token1] = ACTIONS(9729),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9727),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9727),
    [anon_sym_LBRACK] = ACTIONS(9727),
    [aux_sym_basic_type_token6] = ACTIONS(9729),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9727),
    [aux_sym_addafter_modification_token1] = ACTIONS(9727),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9727),
    [aux_sym_modify_modification_token1] = ACTIONS(9727),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9727),
    [aux_sym_movelast_modification_token1] = ACTIONS(9727),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9727),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9727),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9727),
    [anon_sym_POUNDif] = ACTIONS(9727),
    [anon_sym_POUNDIF] = ACTIONS(9727),
    [anon_sym_POUNDIf] = ACTIONS(9727),
    [anon_sym_POUNDelif] = ACTIONS(9727),
    [anon_sym_POUNDELIF] = ACTIONS(9727),
    [anon_sym_POUNDElif] = ACTIONS(9727),
    [anon_sym_POUNDelse] = ACTIONS(9727),
    [anon_sym_POUNDELSE] = ACTIONS(9727),
    [anon_sym_POUNDElse] = ACTIONS(9727),
    [anon_sym_POUNDendif] = ACTIONS(9727),
    [anon_sym_POUNDENDIF] = ACTIONS(9727),
    [anon_sym_POUNDEndif] = ACTIONS(9727),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9727),
    [sym_trigger_keyword] = ACTIONS(9727),
    [sym_var_keyword] = ACTIONS(9727),
    [sym_local_keyword] = ACTIONS(9727),
    [sym_internal_keyword] = ACTIONS(9727),
    [sym_protected_keyword] = ACTIONS(9727),
    [sym_event_keyword] = ACTIONS(9727),
    [sym_fields_keyword] = ACTIONS(9727),
    [sym_keys_keyword] = ACTIONS(9727),
    [sym_fieldgroups_keyword] = ACTIONS(9727),
    [sym_actions_keyword] = ACTIONS(9727),
    [sym_layout_keyword] = ACTIONS(9727),
    [sym_area_keyword] = ACTIONS(9727),
    [sym_group_keyword] = ACTIONS(9727),
    [sym_repeater_keyword] = ACTIONS(9727),
    [sym_cuegroup_keyword] = ACTIONS(9727),
    [sym_fixed_keyword] = ACTIONS(9727),
    [sym_grid_keyword] = ACTIONS(9727),
    [sym_part_keyword] = ACTIONS(9727),
    [sym_systempart_keyword] = ACTIONS(9727),
    [sym_usercontrol_keyword] = ACTIONS(9727),
    [sym_dataset_keyword] = ACTIONS(9727),
    [sym_elements_keyword] = ACTIONS(9727),
    [sym_dataitem_keyword] = ACTIONS(9727),
    [sym_column_keyword] = ACTIONS(9727),
    [sym_filter_keyword] = ACTIONS(9727),
    [sym_labels_keyword] = ACTIONS(9727),
    [sym_rendering_keyword] = ACTIONS(9727),
    [sym_requestpage_keyword] = ACTIONS(9727),
    [sym_schema_keyword] = ACTIONS(9727),
    [sym_views_keyword] = ACTIONS(9727),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9727),
    [sym_preproc_open] = ACTIONS(9727),
    [sym_preproc_close] = ACTIONS(9727),
  },
  [STATE(3637)] = {
    [anon_sym_SEMI] = ACTIONS(9731),
    [aux_sym_where_condition_token1] = ACTIONS(9733),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9735),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9735),
    [anon_sym_LBRACK] = ACTIONS(9735),
    [aux_sym_basic_type_token6] = ACTIONS(9733),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9735),
    [aux_sym_addafter_modification_token1] = ACTIONS(9735),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9735),
    [aux_sym_modify_modification_token1] = ACTIONS(9735),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9735),
    [aux_sym_movelast_modification_token1] = ACTIONS(9735),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9735),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9735),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9735),
    [anon_sym_POUNDif] = ACTIONS(9735),
    [anon_sym_POUNDIF] = ACTIONS(9735),
    [anon_sym_POUNDIf] = ACTIONS(9735),
    [anon_sym_POUNDelif] = ACTIONS(9735),
    [anon_sym_POUNDELIF] = ACTIONS(9735),
    [anon_sym_POUNDElif] = ACTIONS(9735),
    [anon_sym_POUNDelse] = ACTIONS(9735),
    [anon_sym_POUNDELSE] = ACTIONS(9735),
    [anon_sym_POUNDElse] = ACTIONS(9735),
    [anon_sym_POUNDendif] = ACTIONS(9735),
    [anon_sym_POUNDENDIF] = ACTIONS(9735),
    [anon_sym_POUNDEndif] = ACTIONS(9735),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9735),
    [sym_trigger_keyword] = ACTIONS(9735),
    [sym_var_keyword] = ACTIONS(9735),
    [sym_local_keyword] = ACTIONS(9735),
    [sym_internal_keyword] = ACTIONS(9735),
    [sym_protected_keyword] = ACTIONS(9735),
    [sym_event_keyword] = ACTIONS(9735),
    [sym_fields_keyword] = ACTIONS(9735),
    [sym_keys_keyword] = ACTIONS(9735),
    [sym_fieldgroups_keyword] = ACTIONS(9735),
    [sym_actions_keyword] = ACTIONS(9735),
    [sym_layout_keyword] = ACTIONS(9735),
    [sym_area_keyword] = ACTIONS(9735),
    [sym_group_keyword] = ACTIONS(9735),
    [sym_repeater_keyword] = ACTIONS(9735),
    [sym_cuegroup_keyword] = ACTIONS(9735),
    [sym_fixed_keyword] = ACTIONS(9735),
    [sym_grid_keyword] = ACTIONS(9735),
    [sym_part_keyword] = ACTIONS(9735),
    [sym_systempart_keyword] = ACTIONS(9735),
    [sym_usercontrol_keyword] = ACTIONS(9735),
    [sym_dataset_keyword] = ACTIONS(9735),
    [sym_elements_keyword] = ACTIONS(9735),
    [sym_dataitem_keyword] = ACTIONS(9735),
    [sym_column_keyword] = ACTIONS(9735),
    [sym_filter_keyword] = ACTIONS(9735),
    [sym_labels_keyword] = ACTIONS(9735),
    [sym_rendering_keyword] = ACTIONS(9735),
    [sym_requestpage_keyword] = ACTIONS(9735),
    [sym_schema_keyword] = ACTIONS(9735),
    [sym_views_keyword] = ACTIONS(9735),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9735),
    [sym_preproc_open] = ACTIONS(9735),
    [sym_preproc_close] = ACTIONS(9735),
  },
  [STATE(3638)] = {
    [anon_sym_SEMI] = ACTIONS(9737),
    [aux_sym_where_condition_token1] = ACTIONS(9739),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9737),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9737),
    [anon_sym_LBRACK] = ACTIONS(9737),
    [aux_sym_basic_type_token6] = ACTIONS(9739),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9737),
    [aux_sym_addafter_modification_token1] = ACTIONS(9737),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9737),
    [aux_sym_modify_modification_token1] = ACTIONS(9737),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9737),
    [aux_sym_movelast_modification_token1] = ACTIONS(9737),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9737),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9737),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9737),
    [anon_sym_POUNDif] = ACTIONS(9737),
    [anon_sym_POUNDIF] = ACTIONS(9737),
    [anon_sym_POUNDIf] = ACTIONS(9737),
    [anon_sym_POUNDelif] = ACTIONS(9737),
    [anon_sym_POUNDELIF] = ACTIONS(9737),
    [anon_sym_POUNDElif] = ACTIONS(9737),
    [anon_sym_POUNDelse] = ACTIONS(9737),
    [anon_sym_POUNDELSE] = ACTIONS(9737),
    [anon_sym_POUNDElse] = ACTIONS(9737),
    [anon_sym_POUNDendif] = ACTIONS(9737),
    [anon_sym_POUNDENDIF] = ACTIONS(9737),
    [anon_sym_POUNDEndif] = ACTIONS(9737),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9737),
    [sym_trigger_keyword] = ACTIONS(9737),
    [sym_var_keyword] = ACTIONS(9737),
    [sym_local_keyword] = ACTIONS(9737),
    [sym_internal_keyword] = ACTIONS(9737),
    [sym_protected_keyword] = ACTIONS(9737),
    [sym_event_keyword] = ACTIONS(9737),
    [sym_fields_keyword] = ACTIONS(9737),
    [sym_keys_keyword] = ACTIONS(9737),
    [sym_fieldgroups_keyword] = ACTIONS(9737),
    [sym_actions_keyword] = ACTIONS(9737),
    [sym_layout_keyword] = ACTIONS(9737),
    [sym_area_keyword] = ACTIONS(9737),
    [sym_group_keyword] = ACTIONS(9737),
    [sym_repeater_keyword] = ACTIONS(9737),
    [sym_cuegroup_keyword] = ACTIONS(9737),
    [sym_fixed_keyword] = ACTIONS(9737),
    [sym_grid_keyword] = ACTIONS(9737),
    [sym_part_keyword] = ACTIONS(9737),
    [sym_systempart_keyword] = ACTIONS(9737),
    [sym_usercontrol_keyword] = ACTIONS(9737),
    [sym_dataset_keyword] = ACTIONS(9737),
    [sym_elements_keyword] = ACTIONS(9737),
    [sym_dataitem_keyword] = ACTIONS(9737),
    [sym_column_keyword] = ACTIONS(9737),
    [sym_filter_keyword] = ACTIONS(9737),
    [sym_labels_keyword] = ACTIONS(9737),
    [sym_rendering_keyword] = ACTIONS(9737),
    [sym_requestpage_keyword] = ACTIONS(9737),
    [sym_schema_keyword] = ACTIONS(9737),
    [sym_views_keyword] = ACTIONS(9737),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9737),
    [sym_preproc_open] = ACTIONS(9737),
    [sym_preproc_close] = ACTIONS(9737),
  },
  [STATE(3639)] = {
    [anon_sym_SEMI] = ACTIONS(9737),
    [aux_sym_where_condition_token1] = ACTIONS(9739),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9737),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9737),
    [anon_sym_LBRACK] = ACTIONS(9737),
    [aux_sym_basic_type_token6] = ACTIONS(9739),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9737),
    [aux_sym_addafter_modification_token1] = ACTIONS(9737),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9737),
    [aux_sym_modify_modification_token1] = ACTIONS(9737),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9737),
    [aux_sym_movelast_modification_token1] = ACTIONS(9737),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9737),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9737),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9737),
    [anon_sym_POUNDif] = ACTIONS(9737),
    [anon_sym_POUNDIF] = ACTIONS(9737),
    [anon_sym_POUNDIf] = ACTIONS(9737),
    [anon_sym_POUNDelif] = ACTIONS(9737),
    [anon_sym_POUNDELIF] = ACTIONS(9737),
    [anon_sym_POUNDElif] = ACTIONS(9737),
    [anon_sym_POUNDelse] = ACTIONS(9737),
    [anon_sym_POUNDELSE] = ACTIONS(9737),
    [anon_sym_POUNDElse] = ACTIONS(9737),
    [anon_sym_POUNDendif] = ACTIONS(9737),
    [anon_sym_POUNDENDIF] = ACTIONS(9737),
    [anon_sym_POUNDEndif] = ACTIONS(9737),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9737),
    [sym_trigger_keyword] = ACTIONS(9737),
    [sym_var_keyword] = ACTIONS(9737),
    [sym_local_keyword] = ACTIONS(9737),
    [sym_internal_keyword] = ACTIONS(9737),
    [sym_protected_keyword] = ACTIONS(9737),
    [sym_event_keyword] = ACTIONS(9737),
    [sym_fields_keyword] = ACTIONS(9737),
    [sym_keys_keyword] = ACTIONS(9737),
    [sym_fieldgroups_keyword] = ACTIONS(9737),
    [sym_actions_keyword] = ACTIONS(9737),
    [sym_layout_keyword] = ACTIONS(9737),
    [sym_area_keyword] = ACTIONS(9737),
    [sym_group_keyword] = ACTIONS(9737),
    [sym_repeater_keyword] = ACTIONS(9737),
    [sym_cuegroup_keyword] = ACTIONS(9737),
    [sym_fixed_keyword] = ACTIONS(9737),
    [sym_grid_keyword] = ACTIONS(9737),
    [sym_part_keyword] = ACTIONS(9737),
    [sym_systempart_keyword] = ACTIONS(9737),
    [sym_usercontrol_keyword] = ACTIONS(9737),
    [sym_dataset_keyword] = ACTIONS(9737),
    [sym_elements_keyword] = ACTIONS(9737),
    [sym_dataitem_keyword] = ACTIONS(9737),
    [sym_column_keyword] = ACTIONS(9737),
    [sym_filter_keyword] = ACTIONS(9737),
    [sym_labels_keyword] = ACTIONS(9737),
    [sym_rendering_keyword] = ACTIONS(9737),
    [sym_requestpage_keyword] = ACTIONS(9737),
    [sym_schema_keyword] = ACTIONS(9737),
    [sym_views_keyword] = ACTIONS(9737),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9737),
    [sym_preproc_open] = ACTIONS(9737),
    [sym_preproc_close] = ACTIONS(9737),
  },
  [STATE(3640)] = {
    [anon_sym_SEMI] = ACTIONS(9741),
    [aux_sym_where_condition_token1] = ACTIONS(9743),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9741),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9741),
    [anon_sym_LBRACK] = ACTIONS(9741),
    [aux_sym_basic_type_token6] = ACTIONS(9743),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9741),
    [aux_sym_addafter_modification_token1] = ACTIONS(9741),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9741),
    [aux_sym_modify_modification_token1] = ACTIONS(9741),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9741),
    [aux_sym_movelast_modification_token1] = ACTIONS(9741),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9741),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9741),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9741),
    [anon_sym_POUNDif] = ACTIONS(9741),
    [anon_sym_POUNDIF] = ACTIONS(9741),
    [anon_sym_POUNDIf] = ACTIONS(9741),
    [anon_sym_POUNDelif] = ACTIONS(9741),
    [anon_sym_POUNDELIF] = ACTIONS(9741),
    [anon_sym_POUNDElif] = ACTIONS(9741),
    [anon_sym_POUNDelse] = ACTIONS(9741),
    [anon_sym_POUNDELSE] = ACTIONS(9741),
    [anon_sym_POUNDElse] = ACTIONS(9741),
    [anon_sym_POUNDendif] = ACTIONS(9741),
    [anon_sym_POUNDENDIF] = ACTIONS(9741),
    [anon_sym_POUNDEndif] = ACTIONS(9741),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9741),
    [sym_trigger_keyword] = ACTIONS(9741),
    [sym_var_keyword] = ACTIONS(9741),
    [sym_local_keyword] = ACTIONS(9741),
    [sym_internal_keyword] = ACTIONS(9741),
    [sym_protected_keyword] = ACTIONS(9741),
    [sym_event_keyword] = ACTIONS(9741),
    [sym_fields_keyword] = ACTIONS(9741),
    [sym_keys_keyword] = ACTIONS(9741),
    [sym_fieldgroups_keyword] = ACTIONS(9741),
    [sym_actions_keyword] = ACTIONS(9741),
    [sym_layout_keyword] = ACTIONS(9741),
    [sym_area_keyword] = ACTIONS(9741),
    [sym_group_keyword] = ACTIONS(9741),
    [sym_repeater_keyword] = ACTIONS(9741),
    [sym_cuegroup_keyword] = ACTIONS(9741),
    [sym_fixed_keyword] = ACTIONS(9741),
    [sym_grid_keyword] = ACTIONS(9741),
    [sym_part_keyword] = ACTIONS(9741),
    [sym_systempart_keyword] = ACTIONS(9741),
    [sym_usercontrol_keyword] = ACTIONS(9741),
    [sym_dataset_keyword] = ACTIONS(9741),
    [sym_elements_keyword] = ACTIONS(9741),
    [sym_dataitem_keyword] = ACTIONS(9741),
    [sym_column_keyword] = ACTIONS(9741),
    [sym_filter_keyword] = ACTIONS(9741),
    [sym_labels_keyword] = ACTIONS(9741),
    [sym_rendering_keyword] = ACTIONS(9741),
    [sym_requestpage_keyword] = ACTIONS(9741),
    [sym_schema_keyword] = ACTIONS(9741),
    [sym_views_keyword] = ACTIONS(9741),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9741),
    [sym_preproc_open] = ACTIONS(9741),
    [sym_preproc_close] = ACTIONS(9741),
  },
  [STATE(3641)] = {
    [anon_sym_SEMI] = ACTIONS(9741),
    [aux_sym_where_condition_token1] = ACTIONS(9743),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9741),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9741),
    [anon_sym_LBRACK] = ACTIONS(9741),
    [aux_sym_basic_type_token6] = ACTIONS(9743),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9741),
    [aux_sym_addafter_modification_token1] = ACTIONS(9741),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9741),
    [aux_sym_modify_modification_token1] = ACTIONS(9741),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9741),
    [aux_sym_movelast_modification_token1] = ACTIONS(9741),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9741),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9741),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9741),
    [anon_sym_POUNDif] = ACTIONS(9741),
    [anon_sym_POUNDIF] = ACTIONS(9741),
    [anon_sym_POUNDIf] = ACTIONS(9741),
    [anon_sym_POUNDelif] = ACTIONS(9741),
    [anon_sym_POUNDELIF] = ACTIONS(9741),
    [anon_sym_POUNDElif] = ACTIONS(9741),
    [anon_sym_POUNDelse] = ACTIONS(9741),
    [anon_sym_POUNDELSE] = ACTIONS(9741),
    [anon_sym_POUNDElse] = ACTIONS(9741),
    [anon_sym_POUNDendif] = ACTIONS(9741),
    [anon_sym_POUNDENDIF] = ACTIONS(9741),
    [anon_sym_POUNDEndif] = ACTIONS(9741),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9741),
    [sym_trigger_keyword] = ACTIONS(9741),
    [sym_var_keyword] = ACTIONS(9741),
    [sym_local_keyword] = ACTIONS(9741),
    [sym_internal_keyword] = ACTIONS(9741),
    [sym_protected_keyword] = ACTIONS(9741),
    [sym_event_keyword] = ACTIONS(9741),
    [sym_fields_keyword] = ACTIONS(9741),
    [sym_keys_keyword] = ACTIONS(9741),
    [sym_fieldgroups_keyword] = ACTIONS(9741),
    [sym_actions_keyword] = ACTIONS(9741),
    [sym_layout_keyword] = ACTIONS(9741),
    [sym_area_keyword] = ACTIONS(9741),
    [sym_group_keyword] = ACTIONS(9741),
    [sym_repeater_keyword] = ACTIONS(9741),
    [sym_cuegroup_keyword] = ACTIONS(9741),
    [sym_fixed_keyword] = ACTIONS(9741),
    [sym_grid_keyword] = ACTIONS(9741),
    [sym_part_keyword] = ACTIONS(9741),
    [sym_systempart_keyword] = ACTIONS(9741),
    [sym_usercontrol_keyword] = ACTIONS(9741),
    [sym_dataset_keyword] = ACTIONS(9741),
    [sym_elements_keyword] = ACTIONS(9741),
    [sym_dataitem_keyword] = ACTIONS(9741),
    [sym_column_keyword] = ACTIONS(9741),
    [sym_filter_keyword] = ACTIONS(9741),
    [sym_labels_keyword] = ACTIONS(9741),
    [sym_rendering_keyword] = ACTIONS(9741),
    [sym_requestpage_keyword] = ACTIONS(9741),
    [sym_schema_keyword] = ACTIONS(9741),
    [sym_views_keyword] = ACTIONS(9741),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9741),
    [sym_preproc_open] = ACTIONS(9741),
    [sym_preproc_close] = ACTIONS(9741),
  },
  [STATE(3642)] = {
    [anon_sym_SEMI] = ACTIONS(9745),
    [aux_sym_where_condition_token1] = ACTIONS(9747),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9745),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9745),
    [anon_sym_LBRACK] = ACTIONS(9745),
    [aux_sym_basic_type_token6] = ACTIONS(9747),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9745),
    [aux_sym_addafter_modification_token1] = ACTIONS(9745),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9745),
    [aux_sym_modify_modification_token1] = ACTIONS(9745),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9745),
    [aux_sym_movelast_modification_token1] = ACTIONS(9745),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9745),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9745),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9745),
    [anon_sym_POUNDif] = ACTIONS(9745),
    [anon_sym_POUNDIF] = ACTIONS(9745),
    [anon_sym_POUNDIf] = ACTIONS(9745),
    [anon_sym_POUNDelif] = ACTIONS(9745),
    [anon_sym_POUNDELIF] = ACTIONS(9745),
    [anon_sym_POUNDElif] = ACTIONS(9745),
    [anon_sym_POUNDelse] = ACTIONS(9745),
    [anon_sym_POUNDELSE] = ACTIONS(9745),
    [anon_sym_POUNDElse] = ACTIONS(9745),
    [anon_sym_POUNDendif] = ACTIONS(9745),
    [anon_sym_POUNDENDIF] = ACTIONS(9745),
    [anon_sym_POUNDEndif] = ACTIONS(9745),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9745),
    [sym_trigger_keyword] = ACTIONS(9745),
    [sym_var_keyword] = ACTIONS(9745),
    [sym_local_keyword] = ACTIONS(9745),
    [sym_internal_keyword] = ACTIONS(9745),
    [sym_protected_keyword] = ACTIONS(9745),
    [sym_event_keyword] = ACTIONS(9745),
    [sym_fields_keyword] = ACTIONS(9745),
    [sym_keys_keyword] = ACTIONS(9745),
    [sym_fieldgroups_keyword] = ACTIONS(9745),
    [sym_actions_keyword] = ACTIONS(9745),
    [sym_layout_keyword] = ACTIONS(9745),
    [sym_area_keyword] = ACTIONS(9745),
    [sym_group_keyword] = ACTIONS(9745),
    [sym_repeater_keyword] = ACTIONS(9745),
    [sym_cuegroup_keyword] = ACTIONS(9745),
    [sym_fixed_keyword] = ACTIONS(9745),
    [sym_grid_keyword] = ACTIONS(9745),
    [sym_part_keyword] = ACTIONS(9745),
    [sym_systempart_keyword] = ACTIONS(9745),
    [sym_usercontrol_keyword] = ACTIONS(9745),
    [sym_dataset_keyword] = ACTIONS(9745),
    [sym_elements_keyword] = ACTIONS(9745),
    [sym_dataitem_keyword] = ACTIONS(9745),
    [sym_column_keyword] = ACTIONS(9745),
    [sym_filter_keyword] = ACTIONS(9745),
    [sym_labels_keyword] = ACTIONS(9745),
    [sym_rendering_keyword] = ACTIONS(9745),
    [sym_requestpage_keyword] = ACTIONS(9745),
    [sym_schema_keyword] = ACTIONS(9745),
    [sym_views_keyword] = ACTIONS(9745),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9745),
    [sym_preproc_open] = ACTIONS(9745),
    [sym_preproc_close] = ACTIONS(9745),
  },
  [STATE(3643)] = {
    [anon_sym_SEMI] = ACTIONS(9745),
    [aux_sym_where_condition_token1] = ACTIONS(9747),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9745),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9745),
    [anon_sym_LBRACK] = ACTIONS(9745),
    [aux_sym_basic_type_token6] = ACTIONS(9747),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9745),
    [aux_sym_addafter_modification_token1] = ACTIONS(9745),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9745),
    [aux_sym_modify_modification_token1] = ACTIONS(9745),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9745),
    [aux_sym_movelast_modification_token1] = ACTIONS(9745),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9745),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9745),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9745),
    [anon_sym_POUNDif] = ACTIONS(9745),
    [anon_sym_POUNDIF] = ACTIONS(9745),
    [anon_sym_POUNDIf] = ACTIONS(9745),
    [anon_sym_POUNDelif] = ACTIONS(9745),
    [anon_sym_POUNDELIF] = ACTIONS(9745),
    [anon_sym_POUNDElif] = ACTIONS(9745),
    [anon_sym_POUNDelse] = ACTIONS(9745),
    [anon_sym_POUNDELSE] = ACTIONS(9745),
    [anon_sym_POUNDElse] = ACTIONS(9745),
    [anon_sym_POUNDendif] = ACTIONS(9745),
    [anon_sym_POUNDENDIF] = ACTIONS(9745),
    [anon_sym_POUNDEndif] = ACTIONS(9745),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9745),
    [sym_trigger_keyword] = ACTIONS(9745),
    [sym_var_keyword] = ACTIONS(9745),
    [sym_local_keyword] = ACTIONS(9745),
    [sym_internal_keyword] = ACTIONS(9745),
    [sym_protected_keyword] = ACTIONS(9745),
    [sym_event_keyword] = ACTIONS(9745),
    [sym_fields_keyword] = ACTIONS(9745),
    [sym_keys_keyword] = ACTIONS(9745),
    [sym_fieldgroups_keyword] = ACTIONS(9745),
    [sym_actions_keyword] = ACTIONS(9745),
    [sym_layout_keyword] = ACTIONS(9745),
    [sym_area_keyword] = ACTIONS(9745),
    [sym_group_keyword] = ACTIONS(9745),
    [sym_repeater_keyword] = ACTIONS(9745),
    [sym_cuegroup_keyword] = ACTIONS(9745),
    [sym_fixed_keyword] = ACTIONS(9745),
    [sym_grid_keyword] = ACTIONS(9745),
    [sym_part_keyword] = ACTIONS(9745),
    [sym_systempart_keyword] = ACTIONS(9745),
    [sym_usercontrol_keyword] = ACTIONS(9745),
    [sym_dataset_keyword] = ACTIONS(9745),
    [sym_elements_keyword] = ACTIONS(9745),
    [sym_dataitem_keyword] = ACTIONS(9745),
    [sym_column_keyword] = ACTIONS(9745),
    [sym_filter_keyword] = ACTIONS(9745),
    [sym_labels_keyword] = ACTIONS(9745),
    [sym_rendering_keyword] = ACTIONS(9745),
    [sym_requestpage_keyword] = ACTIONS(9745),
    [sym_schema_keyword] = ACTIONS(9745),
    [sym_views_keyword] = ACTIONS(9745),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9745),
    [sym_preproc_open] = ACTIONS(9745),
    [sym_preproc_close] = ACTIONS(9745),
  },
  [STATE(3644)] = {
    [anon_sym_SEMI] = ACTIONS(9749),
    [aux_sym_where_condition_token1] = ACTIONS(9751),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9749),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9749),
    [anon_sym_LBRACK] = ACTIONS(9749),
    [aux_sym_basic_type_token6] = ACTIONS(9751),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9749),
    [aux_sym_addafter_modification_token1] = ACTIONS(9749),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9749),
    [aux_sym_modify_modification_token1] = ACTIONS(9749),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9749),
    [aux_sym_movelast_modification_token1] = ACTIONS(9749),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9749),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9749),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9749),
    [anon_sym_POUNDif] = ACTIONS(9749),
    [anon_sym_POUNDIF] = ACTIONS(9749),
    [anon_sym_POUNDIf] = ACTIONS(9749),
    [anon_sym_POUNDelif] = ACTIONS(9749),
    [anon_sym_POUNDELIF] = ACTIONS(9749),
    [anon_sym_POUNDElif] = ACTIONS(9749),
    [anon_sym_POUNDelse] = ACTIONS(9749),
    [anon_sym_POUNDELSE] = ACTIONS(9749),
    [anon_sym_POUNDElse] = ACTIONS(9749),
    [anon_sym_POUNDendif] = ACTIONS(9749),
    [anon_sym_POUNDENDIF] = ACTIONS(9749),
    [anon_sym_POUNDEndif] = ACTIONS(9749),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9749),
    [sym_trigger_keyword] = ACTIONS(9749),
    [sym_var_keyword] = ACTIONS(9749),
    [sym_local_keyword] = ACTIONS(9749),
    [sym_internal_keyword] = ACTIONS(9749),
    [sym_protected_keyword] = ACTIONS(9749),
    [sym_event_keyword] = ACTIONS(9749),
    [sym_fields_keyword] = ACTIONS(9749),
    [sym_keys_keyword] = ACTIONS(9749),
    [sym_fieldgroups_keyword] = ACTIONS(9749),
    [sym_actions_keyword] = ACTIONS(9749),
    [sym_layout_keyword] = ACTIONS(9749),
    [sym_area_keyword] = ACTIONS(9749),
    [sym_group_keyword] = ACTIONS(9749),
    [sym_repeater_keyword] = ACTIONS(9749),
    [sym_cuegroup_keyword] = ACTIONS(9749),
    [sym_fixed_keyword] = ACTIONS(9749),
    [sym_grid_keyword] = ACTIONS(9749),
    [sym_part_keyword] = ACTIONS(9749),
    [sym_systempart_keyword] = ACTIONS(9749),
    [sym_usercontrol_keyword] = ACTIONS(9749),
    [sym_dataset_keyword] = ACTIONS(9749),
    [sym_elements_keyword] = ACTIONS(9749),
    [sym_dataitem_keyword] = ACTIONS(9749),
    [sym_column_keyword] = ACTIONS(9749),
    [sym_filter_keyword] = ACTIONS(9749),
    [sym_labels_keyword] = ACTIONS(9749),
    [sym_rendering_keyword] = ACTIONS(9749),
    [sym_requestpage_keyword] = ACTIONS(9749),
    [sym_schema_keyword] = ACTIONS(9749),
    [sym_views_keyword] = ACTIONS(9749),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9749),
    [sym_preproc_open] = ACTIONS(9749),
    [sym_preproc_close] = ACTIONS(9749),
  },
  [STATE(3645)] = {
    [anon_sym_SEMI] = ACTIONS(9753),
    [aux_sym_where_condition_token1] = ACTIONS(9755),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9753),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9753),
    [anon_sym_LBRACK] = ACTIONS(9753),
    [aux_sym_basic_type_token6] = ACTIONS(9755),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9753),
    [aux_sym_addafter_modification_token1] = ACTIONS(9753),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9753),
    [aux_sym_modify_modification_token1] = ACTIONS(9753),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9753),
    [aux_sym_movelast_modification_token1] = ACTIONS(9753),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9753),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9753),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9753),
    [anon_sym_POUNDif] = ACTIONS(9753),
    [anon_sym_POUNDIF] = ACTIONS(9753),
    [anon_sym_POUNDIf] = ACTIONS(9753),
    [anon_sym_POUNDelif] = ACTIONS(9753),
    [anon_sym_POUNDELIF] = ACTIONS(9753),
    [anon_sym_POUNDElif] = ACTIONS(9753),
    [anon_sym_POUNDelse] = ACTIONS(9753),
    [anon_sym_POUNDELSE] = ACTIONS(9753),
    [anon_sym_POUNDElse] = ACTIONS(9753),
    [anon_sym_POUNDendif] = ACTIONS(9753),
    [anon_sym_POUNDENDIF] = ACTIONS(9753),
    [anon_sym_POUNDEndif] = ACTIONS(9753),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9753),
    [sym_trigger_keyword] = ACTIONS(9753),
    [sym_var_keyword] = ACTIONS(9753),
    [sym_local_keyword] = ACTIONS(9753),
    [sym_internal_keyword] = ACTIONS(9753),
    [sym_protected_keyword] = ACTIONS(9753),
    [sym_event_keyword] = ACTIONS(9753),
    [sym_fields_keyword] = ACTIONS(9753),
    [sym_keys_keyword] = ACTIONS(9753),
    [sym_fieldgroups_keyword] = ACTIONS(9753),
    [sym_actions_keyword] = ACTIONS(9753),
    [sym_layout_keyword] = ACTIONS(9753),
    [sym_area_keyword] = ACTIONS(9753),
    [sym_group_keyword] = ACTIONS(9753),
    [sym_repeater_keyword] = ACTIONS(9753),
    [sym_cuegroup_keyword] = ACTIONS(9753),
    [sym_fixed_keyword] = ACTIONS(9753),
    [sym_grid_keyword] = ACTIONS(9753),
    [sym_part_keyword] = ACTIONS(9753),
    [sym_systempart_keyword] = ACTIONS(9753),
    [sym_usercontrol_keyword] = ACTIONS(9753),
    [sym_dataset_keyword] = ACTIONS(9753),
    [sym_elements_keyword] = ACTIONS(9753),
    [sym_dataitem_keyword] = ACTIONS(9753),
    [sym_column_keyword] = ACTIONS(9753),
    [sym_filter_keyword] = ACTIONS(9753),
    [sym_labels_keyword] = ACTIONS(9753),
    [sym_rendering_keyword] = ACTIONS(9753),
    [sym_requestpage_keyword] = ACTIONS(9753),
    [sym_schema_keyword] = ACTIONS(9753),
    [sym_views_keyword] = ACTIONS(9753),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9753),
    [sym_preproc_open] = ACTIONS(9753),
    [sym_preproc_close] = ACTIONS(9753),
  },
  [STATE(3646)] = {
    [anon_sym_SEMI] = ACTIONS(7154),
    [aux_sym_where_condition_token1] = ACTIONS(7152),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7154),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7154),
    [anon_sym_LBRACK] = ACTIONS(7154),
    [aux_sym_basic_type_token6] = ACTIONS(7152),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7154),
    [aux_sym_addafter_modification_token1] = ACTIONS(7154),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7154),
    [aux_sym_modify_modification_token1] = ACTIONS(7154),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7154),
    [aux_sym_movelast_modification_token1] = ACTIONS(7154),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7154),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7154),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7154),
    [anon_sym_POUNDif] = ACTIONS(7154),
    [anon_sym_POUNDIF] = ACTIONS(7154),
    [anon_sym_POUNDIf] = ACTIONS(7154),
    [anon_sym_POUNDelif] = ACTIONS(7154),
    [anon_sym_POUNDELIF] = ACTIONS(7154),
    [anon_sym_POUNDElif] = ACTIONS(7154),
    [anon_sym_POUNDelse] = ACTIONS(7154),
    [anon_sym_POUNDELSE] = ACTIONS(7154),
    [anon_sym_POUNDElse] = ACTIONS(7154),
    [anon_sym_POUNDendif] = ACTIONS(7154),
    [anon_sym_POUNDENDIF] = ACTIONS(7154),
    [anon_sym_POUNDEndif] = ACTIONS(7154),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7154),
    [sym_trigger_keyword] = ACTIONS(7154),
    [sym_var_keyword] = ACTIONS(7154),
    [sym_local_keyword] = ACTIONS(7154),
    [sym_internal_keyword] = ACTIONS(7154),
    [sym_protected_keyword] = ACTIONS(7154),
    [sym_event_keyword] = ACTIONS(7154),
    [sym_fields_keyword] = ACTIONS(7154),
    [sym_keys_keyword] = ACTIONS(7154),
    [sym_fieldgroups_keyword] = ACTIONS(7154),
    [sym_actions_keyword] = ACTIONS(7154),
    [sym_layout_keyword] = ACTIONS(7154),
    [sym_area_keyword] = ACTIONS(7154),
    [sym_group_keyword] = ACTIONS(7154),
    [sym_repeater_keyword] = ACTIONS(7154),
    [sym_cuegroup_keyword] = ACTIONS(7154),
    [sym_fixed_keyword] = ACTIONS(7154),
    [sym_grid_keyword] = ACTIONS(7154),
    [sym_part_keyword] = ACTIONS(7154),
    [sym_systempart_keyword] = ACTIONS(7154),
    [sym_usercontrol_keyword] = ACTIONS(7154),
    [sym_dataset_keyword] = ACTIONS(7154),
    [sym_elements_keyword] = ACTIONS(7154),
    [sym_dataitem_keyword] = ACTIONS(7154),
    [sym_column_keyword] = ACTIONS(7154),
    [sym_filter_keyword] = ACTIONS(7154),
    [sym_labels_keyword] = ACTIONS(7154),
    [sym_rendering_keyword] = ACTIONS(7154),
    [sym_requestpage_keyword] = ACTIONS(7154),
    [sym_schema_keyword] = ACTIONS(7154),
    [sym_views_keyword] = ACTIONS(7154),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7154),
    [sym_preproc_open] = ACTIONS(7154),
    [sym_preproc_close] = ACTIONS(7154),
  },
  [STATE(3647)] = {
    [anon_sym_SEMI] = ACTIONS(9753),
    [aux_sym_where_condition_token1] = ACTIONS(9755),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9753),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9753),
    [anon_sym_LBRACK] = ACTIONS(9753),
    [aux_sym_basic_type_token6] = ACTIONS(9755),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9753),
    [aux_sym_addafter_modification_token1] = ACTIONS(9753),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9753),
    [aux_sym_modify_modification_token1] = ACTIONS(9753),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9753),
    [aux_sym_movelast_modification_token1] = ACTIONS(9753),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9753),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9753),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9753),
    [anon_sym_POUNDif] = ACTIONS(9753),
    [anon_sym_POUNDIF] = ACTIONS(9753),
    [anon_sym_POUNDIf] = ACTIONS(9753),
    [anon_sym_POUNDelif] = ACTIONS(9753),
    [anon_sym_POUNDELIF] = ACTIONS(9753),
    [anon_sym_POUNDElif] = ACTIONS(9753),
    [anon_sym_POUNDelse] = ACTIONS(9753),
    [anon_sym_POUNDELSE] = ACTIONS(9753),
    [anon_sym_POUNDElse] = ACTIONS(9753),
    [anon_sym_POUNDendif] = ACTIONS(9753),
    [anon_sym_POUNDENDIF] = ACTIONS(9753),
    [anon_sym_POUNDEndif] = ACTIONS(9753),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9753),
    [sym_trigger_keyword] = ACTIONS(9753),
    [sym_var_keyword] = ACTIONS(9753),
    [sym_local_keyword] = ACTIONS(9753),
    [sym_internal_keyword] = ACTIONS(9753),
    [sym_protected_keyword] = ACTIONS(9753),
    [sym_event_keyword] = ACTIONS(9753),
    [sym_fields_keyword] = ACTIONS(9753),
    [sym_keys_keyword] = ACTIONS(9753),
    [sym_fieldgroups_keyword] = ACTIONS(9753),
    [sym_actions_keyword] = ACTIONS(9753),
    [sym_layout_keyword] = ACTIONS(9753),
    [sym_area_keyword] = ACTIONS(9753),
    [sym_group_keyword] = ACTIONS(9753),
    [sym_repeater_keyword] = ACTIONS(9753),
    [sym_cuegroup_keyword] = ACTIONS(9753),
    [sym_fixed_keyword] = ACTIONS(9753),
    [sym_grid_keyword] = ACTIONS(9753),
    [sym_part_keyword] = ACTIONS(9753),
    [sym_systempart_keyword] = ACTIONS(9753),
    [sym_usercontrol_keyword] = ACTIONS(9753),
    [sym_dataset_keyword] = ACTIONS(9753),
    [sym_elements_keyword] = ACTIONS(9753),
    [sym_dataitem_keyword] = ACTIONS(9753),
    [sym_column_keyword] = ACTIONS(9753),
    [sym_filter_keyword] = ACTIONS(9753),
    [sym_labels_keyword] = ACTIONS(9753),
    [sym_rendering_keyword] = ACTIONS(9753),
    [sym_requestpage_keyword] = ACTIONS(9753),
    [sym_schema_keyword] = ACTIONS(9753),
    [sym_views_keyword] = ACTIONS(9753),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9753),
    [sym_preproc_open] = ACTIONS(9753),
    [sym_preproc_close] = ACTIONS(9753),
  },
  [STATE(3648)] = {
    [anon_sym_SEMI] = ACTIONS(9757),
    [aux_sym_where_condition_token1] = ACTIONS(9759),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9757),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9757),
    [anon_sym_LBRACK] = ACTIONS(9757),
    [aux_sym_basic_type_token6] = ACTIONS(9759),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9757),
    [aux_sym_addafter_modification_token1] = ACTIONS(9757),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9757),
    [aux_sym_modify_modification_token1] = ACTIONS(9757),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9757),
    [aux_sym_movelast_modification_token1] = ACTIONS(9757),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9757),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9757),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9757),
    [anon_sym_POUNDif] = ACTIONS(9757),
    [anon_sym_POUNDIF] = ACTIONS(9757),
    [anon_sym_POUNDIf] = ACTIONS(9757),
    [anon_sym_POUNDelif] = ACTIONS(9757),
    [anon_sym_POUNDELIF] = ACTIONS(9757),
    [anon_sym_POUNDElif] = ACTIONS(9757),
    [anon_sym_POUNDelse] = ACTIONS(9757),
    [anon_sym_POUNDELSE] = ACTIONS(9757),
    [anon_sym_POUNDElse] = ACTIONS(9757),
    [anon_sym_POUNDendif] = ACTIONS(9757),
    [anon_sym_POUNDENDIF] = ACTIONS(9757),
    [anon_sym_POUNDEndif] = ACTIONS(9757),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9757),
    [sym_trigger_keyword] = ACTIONS(9757),
    [sym_var_keyword] = ACTIONS(9757),
    [sym_local_keyword] = ACTIONS(9757),
    [sym_internal_keyword] = ACTIONS(9757),
    [sym_protected_keyword] = ACTIONS(9757),
    [sym_event_keyword] = ACTIONS(9757),
    [sym_fields_keyword] = ACTIONS(9757),
    [sym_keys_keyword] = ACTIONS(9757),
    [sym_fieldgroups_keyword] = ACTIONS(9757),
    [sym_actions_keyword] = ACTIONS(9757),
    [sym_layout_keyword] = ACTIONS(9757),
    [sym_area_keyword] = ACTIONS(9757),
    [sym_group_keyword] = ACTIONS(9757),
    [sym_repeater_keyword] = ACTIONS(9757),
    [sym_cuegroup_keyword] = ACTIONS(9757),
    [sym_fixed_keyword] = ACTIONS(9757),
    [sym_grid_keyword] = ACTIONS(9757),
    [sym_part_keyword] = ACTIONS(9757),
    [sym_systempart_keyword] = ACTIONS(9757),
    [sym_usercontrol_keyword] = ACTIONS(9757),
    [sym_dataset_keyword] = ACTIONS(9757),
    [sym_elements_keyword] = ACTIONS(9757),
    [sym_dataitem_keyword] = ACTIONS(9757),
    [sym_column_keyword] = ACTIONS(9757),
    [sym_filter_keyword] = ACTIONS(9757),
    [sym_labels_keyword] = ACTIONS(9757),
    [sym_rendering_keyword] = ACTIONS(9757),
    [sym_requestpage_keyword] = ACTIONS(9757),
    [sym_schema_keyword] = ACTIONS(9757),
    [sym_views_keyword] = ACTIONS(9757),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9757),
    [sym_preproc_open] = ACTIONS(9757),
    [sym_preproc_close] = ACTIONS(9757),
  },
  [STATE(3649)] = {
    [anon_sym_SEMI] = ACTIONS(9757),
    [aux_sym_where_condition_token1] = ACTIONS(9759),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9757),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9757),
    [anon_sym_LBRACK] = ACTIONS(9757),
    [aux_sym_basic_type_token6] = ACTIONS(9759),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9757),
    [aux_sym_addafter_modification_token1] = ACTIONS(9757),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9757),
    [aux_sym_modify_modification_token1] = ACTIONS(9757),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9757),
    [aux_sym_movelast_modification_token1] = ACTIONS(9757),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9757),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9757),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9757),
    [anon_sym_POUNDif] = ACTIONS(9757),
    [anon_sym_POUNDIF] = ACTIONS(9757),
    [anon_sym_POUNDIf] = ACTIONS(9757),
    [anon_sym_POUNDelif] = ACTIONS(9757),
    [anon_sym_POUNDELIF] = ACTIONS(9757),
    [anon_sym_POUNDElif] = ACTIONS(9757),
    [anon_sym_POUNDelse] = ACTIONS(9757),
    [anon_sym_POUNDELSE] = ACTIONS(9757),
    [anon_sym_POUNDElse] = ACTIONS(9757),
    [anon_sym_POUNDendif] = ACTIONS(9757),
    [anon_sym_POUNDENDIF] = ACTIONS(9757),
    [anon_sym_POUNDEndif] = ACTIONS(9757),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9757),
    [sym_trigger_keyword] = ACTIONS(9757),
    [sym_var_keyword] = ACTIONS(9757),
    [sym_local_keyword] = ACTIONS(9757),
    [sym_internal_keyword] = ACTIONS(9757),
    [sym_protected_keyword] = ACTIONS(9757),
    [sym_event_keyword] = ACTIONS(9757),
    [sym_fields_keyword] = ACTIONS(9757),
    [sym_keys_keyword] = ACTIONS(9757),
    [sym_fieldgroups_keyword] = ACTIONS(9757),
    [sym_actions_keyword] = ACTIONS(9757),
    [sym_layout_keyword] = ACTIONS(9757),
    [sym_area_keyword] = ACTIONS(9757),
    [sym_group_keyword] = ACTIONS(9757),
    [sym_repeater_keyword] = ACTIONS(9757),
    [sym_cuegroup_keyword] = ACTIONS(9757),
    [sym_fixed_keyword] = ACTIONS(9757),
    [sym_grid_keyword] = ACTIONS(9757),
    [sym_part_keyword] = ACTIONS(9757),
    [sym_systempart_keyword] = ACTIONS(9757),
    [sym_usercontrol_keyword] = ACTIONS(9757),
    [sym_dataset_keyword] = ACTIONS(9757),
    [sym_elements_keyword] = ACTIONS(9757),
    [sym_dataitem_keyword] = ACTIONS(9757),
    [sym_column_keyword] = ACTIONS(9757),
    [sym_filter_keyword] = ACTIONS(9757),
    [sym_labels_keyword] = ACTIONS(9757),
    [sym_rendering_keyword] = ACTIONS(9757),
    [sym_requestpage_keyword] = ACTIONS(9757),
    [sym_schema_keyword] = ACTIONS(9757),
    [sym_views_keyword] = ACTIONS(9757),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9757),
    [sym_preproc_open] = ACTIONS(9757),
    [sym_preproc_close] = ACTIONS(9757),
  },
  [STATE(3650)] = {
    [anon_sym_SEMI] = ACTIONS(9757),
    [aux_sym_where_condition_token1] = ACTIONS(9759),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9757),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9757),
    [anon_sym_LBRACK] = ACTIONS(9757),
    [aux_sym_basic_type_token6] = ACTIONS(9759),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9757),
    [aux_sym_addafter_modification_token1] = ACTIONS(9757),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9757),
    [aux_sym_modify_modification_token1] = ACTIONS(9757),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9757),
    [aux_sym_movelast_modification_token1] = ACTIONS(9757),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9757),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9757),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9757),
    [anon_sym_POUNDif] = ACTIONS(9757),
    [anon_sym_POUNDIF] = ACTIONS(9757),
    [anon_sym_POUNDIf] = ACTIONS(9757),
    [anon_sym_POUNDelif] = ACTIONS(9757),
    [anon_sym_POUNDELIF] = ACTIONS(9757),
    [anon_sym_POUNDElif] = ACTIONS(9757),
    [anon_sym_POUNDelse] = ACTIONS(9757),
    [anon_sym_POUNDELSE] = ACTIONS(9757),
    [anon_sym_POUNDElse] = ACTIONS(9757),
    [anon_sym_POUNDendif] = ACTIONS(9757),
    [anon_sym_POUNDENDIF] = ACTIONS(9757),
    [anon_sym_POUNDEndif] = ACTIONS(9757),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9757),
    [sym_trigger_keyword] = ACTIONS(9757),
    [sym_var_keyword] = ACTIONS(9757),
    [sym_local_keyword] = ACTIONS(9757),
    [sym_internal_keyword] = ACTIONS(9757),
    [sym_protected_keyword] = ACTIONS(9757),
    [sym_event_keyword] = ACTIONS(9757),
    [sym_fields_keyword] = ACTIONS(9757),
    [sym_keys_keyword] = ACTIONS(9757),
    [sym_fieldgroups_keyword] = ACTIONS(9757),
    [sym_actions_keyword] = ACTIONS(9757),
    [sym_layout_keyword] = ACTIONS(9757),
    [sym_area_keyword] = ACTIONS(9757),
    [sym_group_keyword] = ACTIONS(9757),
    [sym_repeater_keyword] = ACTIONS(9757),
    [sym_cuegroup_keyword] = ACTIONS(9757),
    [sym_fixed_keyword] = ACTIONS(9757),
    [sym_grid_keyword] = ACTIONS(9757),
    [sym_part_keyword] = ACTIONS(9757),
    [sym_systempart_keyword] = ACTIONS(9757),
    [sym_usercontrol_keyword] = ACTIONS(9757),
    [sym_dataset_keyword] = ACTIONS(9757),
    [sym_elements_keyword] = ACTIONS(9757),
    [sym_dataitem_keyword] = ACTIONS(9757),
    [sym_column_keyword] = ACTIONS(9757),
    [sym_filter_keyword] = ACTIONS(9757),
    [sym_labels_keyword] = ACTIONS(9757),
    [sym_rendering_keyword] = ACTIONS(9757),
    [sym_requestpage_keyword] = ACTIONS(9757),
    [sym_schema_keyword] = ACTIONS(9757),
    [sym_views_keyword] = ACTIONS(9757),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9757),
    [sym_preproc_open] = ACTIONS(9757),
    [sym_preproc_close] = ACTIONS(9757),
  },
  [STATE(3651)] = {
    [anon_sym_SEMI] = ACTIONS(9757),
    [aux_sym_where_condition_token1] = ACTIONS(9759),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9757),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9757),
    [anon_sym_LBRACK] = ACTIONS(9757),
    [aux_sym_basic_type_token6] = ACTIONS(9759),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9757),
    [aux_sym_addafter_modification_token1] = ACTIONS(9757),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9757),
    [aux_sym_modify_modification_token1] = ACTIONS(9757),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9757),
    [aux_sym_movelast_modification_token1] = ACTIONS(9757),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9757),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9757),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9757),
    [anon_sym_POUNDif] = ACTIONS(9757),
    [anon_sym_POUNDIF] = ACTIONS(9757),
    [anon_sym_POUNDIf] = ACTIONS(9757),
    [anon_sym_POUNDelif] = ACTIONS(9757),
    [anon_sym_POUNDELIF] = ACTIONS(9757),
    [anon_sym_POUNDElif] = ACTIONS(9757),
    [anon_sym_POUNDelse] = ACTIONS(9757),
    [anon_sym_POUNDELSE] = ACTIONS(9757),
    [anon_sym_POUNDElse] = ACTIONS(9757),
    [anon_sym_POUNDendif] = ACTIONS(9757),
    [anon_sym_POUNDENDIF] = ACTIONS(9757),
    [anon_sym_POUNDEndif] = ACTIONS(9757),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9757),
    [sym_trigger_keyword] = ACTIONS(9757),
    [sym_var_keyword] = ACTIONS(9757),
    [sym_local_keyword] = ACTIONS(9757),
    [sym_internal_keyword] = ACTIONS(9757),
    [sym_protected_keyword] = ACTIONS(9757),
    [sym_event_keyword] = ACTIONS(9757),
    [sym_fields_keyword] = ACTIONS(9757),
    [sym_keys_keyword] = ACTIONS(9757),
    [sym_fieldgroups_keyword] = ACTIONS(9757),
    [sym_actions_keyword] = ACTIONS(9757),
    [sym_layout_keyword] = ACTIONS(9757),
    [sym_area_keyword] = ACTIONS(9757),
    [sym_group_keyword] = ACTIONS(9757),
    [sym_repeater_keyword] = ACTIONS(9757),
    [sym_cuegroup_keyword] = ACTIONS(9757),
    [sym_fixed_keyword] = ACTIONS(9757),
    [sym_grid_keyword] = ACTIONS(9757),
    [sym_part_keyword] = ACTIONS(9757),
    [sym_systempart_keyword] = ACTIONS(9757),
    [sym_usercontrol_keyword] = ACTIONS(9757),
    [sym_dataset_keyword] = ACTIONS(9757),
    [sym_elements_keyword] = ACTIONS(9757),
    [sym_dataitem_keyword] = ACTIONS(9757),
    [sym_column_keyword] = ACTIONS(9757),
    [sym_filter_keyword] = ACTIONS(9757),
    [sym_labels_keyword] = ACTIONS(9757),
    [sym_rendering_keyword] = ACTIONS(9757),
    [sym_requestpage_keyword] = ACTIONS(9757),
    [sym_schema_keyword] = ACTIONS(9757),
    [sym_views_keyword] = ACTIONS(9757),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9757),
    [sym_preproc_open] = ACTIONS(9757),
    [sym_preproc_close] = ACTIONS(9757),
  },
  [STATE(3652)] = {
    [anon_sym_SEMI] = ACTIONS(9761),
    [aux_sym_where_condition_token1] = ACTIONS(9763),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9761),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9761),
    [anon_sym_LBRACK] = ACTIONS(9761),
    [aux_sym_basic_type_token6] = ACTIONS(9763),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9761),
    [aux_sym_addafter_modification_token1] = ACTIONS(9761),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9761),
    [aux_sym_modify_modification_token1] = ACTIONS(9761),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9761),
    [aux_sym_movelast_modification_token1] = ACTIONS(9761),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9761),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9761),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9761),
    [anon_sym_POUNDif] = ACTIONS(9761),
    [anon_sym_POUNDIF] = ACTIONS(9761),
    [anon_sym_POUNDIf] = ACTIONS(9761),
    [anon_sym_POUNDelif] = ACTIONS(9761),
    [anon_sym_POUNDELIF] = ACTIONS(9761),
    [anon_sym_POUNDElif] = ACTIONS(9761),
    [anon_sym_POUNDelse] = ACTIONS(9761),
    [anon_sym_POUNDELSE] = ACTIONS(9761),
    [anon_sym_POUNDElse] = ACTIONS(9761),
    [anon_sym_POUNDendif] = ACTIONS(9761),
    [anon_sym_POUNDENDIF] = ACTIONS(9761),
    [anon_sym_POUNDEndif] = ACTIONS(9761),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9761),
    [sym_trigger_keyword] = ACTIONS(9761),
    [sym_var_keyword] = ACTIONS(9761),
    [sym_local_keyword] = ACTIONS(9761),
    [sym_internal_keyword] = ACTIONS(9761),
    [sym_protected_keyword] = ACTIONS(9761),
    [sym_event_keyword] = ACTIONS(9761),
    [sym_fields_keyword] = ACTIONS(9761),
    [sym_keys_keyword] = ACTIONS(9761),
    [sym_fieldgroups_keyword] = ACTIONS(9761),
    [sym_actions_keyword] = ACTIONS(9761),
    [sym_layout_keyword] = ACTIONS(9761),
    [sym_area_keyword] = ACTIONS(9761),
    [sym_group_keyword] = ACTIONS(9761),
    [sym_repeater_keyword] = ACTIONS(9761),
    [sym_cuegroup_keyword] = ACTIONS(9761),
    [sym_fixed_keyword] = ACTIONS(9761),
    [sym_grid_keyword] = ACTIONS(9761),
    [sym_part_keyword] = ACTIONS(9761),
    [sym_systempart_keyword] = ACTIONS(9761),
    [sym_usercontrol_keyword] = ACTIONS(9761),
    [sym_dataset_keyword] = ACTIONS(9761),
    [sym_elements_keyword] = ACTIONS(9761),
    [sym_dataitem_keyword] = ACTIONS(9761),
    [sym_column_keyword] = ACTIONS(9761),
    [sym_filter_keyword] = ACTIONS(9761),
    [sym_labels_keyword] = ACTIONS(9761),
    [sym_rendering_keyword] = ACTIONS(9761),
    [sym_requestpage_keyword] = ACTIONS(9761),
    [sym_schema_keyword] = ACTIONS(9761),
    [sym_views_keyword] = ACTIONS(9761),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9761),
    [sym_preproc_open] = ACTIONS(9761),
    [sym_preproc_close] = ACTIONS(9761),
  },
  [STATE(3653)] = {
    [anon_sym_SEMI] = ACTIONS(9761),
    [aux_sym_where_condition_token1] = ACTIONS(9763),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9761),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9761),
    [anon_sym_LBRACK] = ACTIONS(9761),
    [aux_sym_basic_type_token6] = ACTIONS(9763),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9761),
    [aux_sym_addafter_modification_token1] = ACTIONS(9761),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9761),
    [aux_sym_modify_modification_token1] = ACTIONS(9761),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9761),
    [aux_sym_movelast_modification_token1] = ACTIONS(9761),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9761),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9761),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9761),
    [anon_sym_POUNDif] = ACTIONS(9761),
    [anon_sym_POUNDIF] = ACTIONS(9761),
    [anon_sym_POUNDIf] = ACTIONS(9761),
    [anon_sym_POUNDelif] = ACTIONS(9761),
    [anon_sym_POUNDELIF] = ACTIONS(9761),
    [anon_sym_POUNDElif] = ACTIONS(9761),
    [anon_sym_POUNDelse] = ACTIONS(9761),
    [anon_sym_POUNDELSE] = ACTIONS(9761),
    [anon_sym_POUNDElse] = ACTIONS(9761),
    [anon_sym_POUNDendif] = ACTIONS(9761),
    [anon_sym_POUNDENDIF] = ACTIONS(9761),
    [anon_sym_POUNDEndif] = ACTIONS(9761),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9761),
    [sym_trigger_keyword] = ACTIONS(9761),
    [sym_var_keyword] = ACTIONS(9761),
    [sym_local_keyword] = ACTIONS(9761),
    [sym_internal_keyword] = ACTIONS(9761),
    [sym_protected_keyword] = ACTIONS(9761),
    [sym_event_keyword] = ACTIONS(9761),
    [sym_fields_keyword] = ACTIONS(9761),
    [sym_keys_keyword] = ACTIONS(9761),
    [sym_fieldgroups_keyword] = ACTIONS(9761),
    [sym_actions_keyword] = ACTIONS(9761),
    [sym_layout_keyword] = ACTIONS(9761),
    [sym_area_keyword] = ACTIONS(9761),
    [sym_group_keyword] = ACTIONS(9761),
    [sym_repeater_keyword] = ACTIONS(9761),
    [sym_cuegroup_keyword] = ACTIONS(9761),
    [sym_fixed_keyword] = ACTIONS(9761),
    [sym_grid_keyword] = ACTIONS(9761),
    [sym_part_keyword] = ACTIONS(9761),
    [sym_systempart_keyword] = ACTIONS(9761),
    [sym_usercontrol_keyword] = ACTIONS(9761),
    [sym_dataset_keyword] = ACTIONS(9761),
    [sym_elements_keyword] = ACTIONS(9761),
    [sym_dataitem_keyword] = ACTIONS(9761),
    [sym_column_keyword] = ACTIONS(9761),
    [sym_filter_keyword] = ACTIONS(9761),
    [sym_labels_keyword] = ACTIONS(9761),
    [sym_rendering_keyword] = ACTIONS(9761),
    [sym_requestpage_keyword] = ACTIONS(9761),
    [sym_schema_keyword] = ACTIONS(9761),
    [sym_views_keyword] = ACTIONS(9761),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9761),
    [sym_preproc_open] = ACTIONS(9761),
    [sym_preproc_close] = ACTIONS(9761),
  },
  [STATE(3654)] = {
    [anon_sym_SEMI] = ACTIONS(9761),
    [aux_sym_where_condition_token1] = ACTIONS(9763),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9761),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9761),
    [anon_sym_LBRACK] = ACTIONS(9761),
    [aux_sym_basic_type_token6] = ACTIONS(9763),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9761),
    [aux_sym_addafter_modification_token1] = ACTIONS(9761),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9761),
    [aux_sym_modify_modification_token1] = ACTIONS(9761),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9761),
    [aux_sym_movelast_modification_token1] = ACTIONS(9761),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9761),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9761),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9761),
    [anon_sym_POUNDif] = ACTIONS(9761),
    [anon_sym_POUNDIF] = ACTIONS(9761),
    [anon_sym_POUNDIf] = ACTIONS(9761),
    [anon_sym_POUNDelif] = ACTIONS(9761),
    [anon_sym_POUNDELIF] = ACTIONS(9761),
    [anon_sym_POUNDElif] = ACTIONS(9761),
    [anon_sym_POUNDelse] = ACTIONS(9761),
    [anon_sym_POUNDELSE] = ACTIONS(9761),
    [anon_sym_POUNDElse] = ACTIONS(9761),
    [anon_sym_POUNDendif] = ACTIONS(9761),
    [anon_sym_POUNDENDIF] = ACTIONS(9761),
    [anon_sym_POUNDEndif] = ACTIONS(9761),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9761),
    [sym_trigger_keyword] = ACTIONS(9761),
    [sym_var_keyword] = ACTIONS(9761),
    [sym_local_keyword] = ACTIONS(9761),
    [sym_internal_keyword] = ACTIONS(9761),
    [sym_protected_keyword] = ACTIONS(9761),
    [sym_event_keyword] = ACTIONS(9761),
    [sym_fields_keyword] = ACTIONS(9761),
    [sym_keys_keyword] = ACTIONS(9761),
    [sym_fieldgroups_keyword] = ACTIONS(9761),
    [sym_actions_keyword] = ACTIONS(9761),
    [sym_layout_keyword] = ACTIONS(9761),
    [sym_area_keyword] = ACTIONS(9761),
    [sym_group_keyword] = ACTIONS(9761),
    [sym_repeater_keyword] = ACTIONS(9761),
    [sym_cuegroup_keyword] = ACTIONS(9761),
    [sym_fixed_keyword] = ACTIONS(9761),
    [sym_grid_keyword] = ACTIONS(9761),
    [sym_part_keyword] = ACTIONS(9761),
    [sym_systempart_keyword] = ACTIONS(9761),
    [sym_usercontrol_keyword] = ACTIONS(9761),
    [sym_dataset_keyword] = ACTIONS(9761),
    [sym_elements_keyword] = ACTIONS(9761),
    [sym_dataitem_keyword] = ACTIONS(9761),
    [sym_column_keyword] = ACTIONS(9761),
    [sym_filter_keyword] = ACTIONS(9761),
    [sym_labels_keyword] = ACTIONS(9761),
    [sym_rendering_keyword] = ACTIONS(9761),
    [sym_requestpage_keyword] = ACTIONS(9761),
    [sym_schema_keyword] = ACTIONS(9761),
    [sym_views_keyword] = ACTIONS(9761),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9761),
    [sym_preproc_open] = ACTIONS(9761),
    [sym_preproc_close] = ACTIONS(9761),
  },
  [STATE(3655)] = {
    [anon_sym_SEMI] = ACTIONS(7373),
    [aux_sym_where_condition_token1] = ACTIONS(7371),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7373),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7373),
    [anon_sym_LBRACK] = ACTIONS(7373),
    [aux_sym_basic_type_token6] = ACTIONS(7371),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7373),
    [aux_sym_addafter_modification_token1] = ACTIONS(7373),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7373),
    [aux_sym_modify_modification_token1] = ACTIONS(7373),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7373),
    [aux_sym_movelast_modification_token1] = ACTIONS(7373),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7373),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7373),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7373),
    [anon_sym_POUNDif] = ACTIONS(7373),
    [anon_sym_POUNDIF] = ACTIONS(7373),
    [anon_sym_POUNDIf] = ACTIONS(7373),
    [anon_sym_POUNDelif] = ACTIONS(7373),
    [anon_sym_POUNDELIF] = ACTIONS(7373),
    [anon_sym_POUNDElif] = ACTIONS(7373),
    [anon_sym_POUNDelse] = ACTIONS(7373),
    [anon_sym_POUNDELSE] = ACTIONS(7373),
    [anon_sym_POUNDElse] = ACTIONS(7373),
    [anon_sym_POUNDendif] = ACTIONS(7373),
    [anon_sym_POUNDENDIF] = ACTIONS(7373),
    [anon_sym_POUNDEndif] = ACTIONS(7373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7373),
    [sym_trigger_keyword] = ACTIONS(7373),
    [sym_var_keyword] = ACTIONS(7373),
    [sym_local_keyword] = ACTIONS(7373),
    [sym_internal_keyword] = ACTIONS(7373),
    [sym_protected_keyword] = ACTIONS(7373),
    [sym_event_keyword] = ACTIONS(7373),
    [sym_fields_keyword] = ACTIONS(7373),
    [sym_keys_keyword] = ACTIONS(7373),
    [sym_fieldgroups_keyword] = ACTIONS(7373),
    [sym_actions_keyword] = ACTIONS(7373),
    [sym_layout_keyword] = ACTIONS(7373),
    [sym_area_keyword] = ACTIONS(7373),
    [sym_group_keyword] = ACTIONS(7373),
    [sym_repeater_keyword] = ACTIONS(7373),
    [sym_cuegroup_keyword] = ACTIONS(7373),
    [sym_fixed_keyword] = ACTIONS(7373),
    [sym_grid_keyword] = ACTIONS(7373),
    [sym_part_keyword] = ACTIONS(7373),
    [sym_systempart_keyword] = ACTIONS(7373),
    [sym_usercontrol_keyword] = ACTIONS(7373),
    [sym_dataset_keyword] = ACTIONS(7373),
    [sym_elements_keyword] = ACTIONS(7373),
    [sym_dataitem_keyword] = ACTIONS(7373),
    [sym_column_keyword] = ACTIONS(7373),
    [sym_filter_keyword] = ACTIONS(7373),
    [sym_labels_keyword] = ACTIONS(7373),
    [sym_rendering_keyword] = ACTIONS(7373),
    [sym_requestpage_keyword] = ACTIONS(7373),
    [sym_schema_keyword] = ACTIONS(7373),
    [sym_views_keyword] = ACTIONS(7373),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7373),
    [sym_preproc_open] = ACTIONS(7373),
    [sym_preproc_close] = ACTIONS(7373),
  },
  [STATE(3656)] = {
    [anon_sym_SEMI] = ACTIONS(9727),
    [aux_sym_where_condition_token1] = ACTIONS(9729),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9727),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9727),
    [anon_sym_LBRACK] = ACTIONS(9727),
    [aux_sym_basic_type_token6] = ACTIONS(9729),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9727),
    [aux_sym_addafter_modification_token1] = ACTIONS(9727),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9727),
    [aux_sym_modify_modification_token1] = ACTIONS(9727),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9727),
    [aux_sym_movelast_modification_token1] = ACTIONS(9727),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9727),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9727),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9727),
    [anon_sym_POUNDif] = ACTIONS(9727),
    [anon_sym_POUNDIF] = ACTIONS(9727),
    [anon_sym_POUNDIf] = ACTIONS(9727),
    [anon_sym_POUNDelif] = ACTIONS(9727),
    [anon_sym_POUNDELIF] = ACTIONS(9727),
    [anon_sym_POUNDElif] = ACTIONS(9727),
    [anon_sym_POUNDelse] = ACTIONS(9727),
    [anon_sym_POUNDELSE] = ACTIONS(9727),
    [anon_sym_POUNDElse] = ACTIONS(9727),
    [anon_sym_POUNDendif] = ACTIONS(9727),
    [anon_sym_POUNDENDIF] = ACTIONS(9727),
    [anon_sym_POUNDEndif] = ACTIONS(9727),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9727),
    [sym_trigger_keyword] = ACTIONS(9727),
    [sym_var_keyword] = ACTIONS(9727),
    [sym_local_keyword] = ACTIONS(9727),
    [sym_internal_keyword] = ACTIONS(9727),
    [sym_protected_keyword] = ACTIONS(9727),
    [sym_event_keyword] = ACTIONS(9727),
    [sym_fields_keyword] = ACTIONS(9727),
    [sym_keys_keyword] = ACTIONS(9727),
    [sym_fieldgroups_keyword] = ACTIONS(9727),
    [sym_actions_keyword] = ACTIONS(9727),
    [sym_layout_keyword] = ACTIONS(9727),
    [sym_area_keyword] = ACTIONS(9727),
    [sym_group_keyword] = ACTIONS(9727),
    [sym_repeater_keyword] = ACTIONS(9727),
    [sym_cuegroup_keyword] = ACTIONS(9727),
    [sym_fixed_keyword] = ACTIONS(9727),
    [sym_grid_keyword] = ACTIONS(9727),
    [sym_part_keyword] = ACTIONS(9727),
    [sym_systempart_keyword] = ACTIONS(9727),
    [sym_usercontrol_keyword] = ACTIONS(9727),
    [sym_dataset_keyword] = ACTIONS(9727),
    [sym_elements_keyword] = ACTIONS(9727),
    [sym_dataitem_keyword] = ACTIONS(9727),
    [sym_column_keyword] = ACTIONS(9727),
    [sym_filter_keyword] = ACTIONS(9727),
    [sym_labels_keyword] = ACTIONS(9727),
    [sym_rendering_keyword] = ACTIONS(9727),
    [sym_requestpage_keyword] = ACTIONS(9727),
    [sym_schema_keyword] = ACTIONS(9727),
    [sym_views_keyword] = ACTIONS(9727),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9727),
    [sym_preproc_open] = ACTIONS(9727),
    [sym_preproc_close] = ACTIONS(9727),
  },
  [STATE(3657)] = {
    [anon_sym_SEMI] = ACTIONS(9765),
    [aux_sym_where_condition_token1] = ACTIONS(9767),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9769),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9769),
    [anon_sym_LBRACK] = ACTIONS(9769),
    [aux_sym_basic_type_token6] = ACTIONS(9767),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9769),
    [aux_sym_addafter_modification_token1] = ACTIONS(9769),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9769),
    [aux_sym_modify_modification_token1] = ACTIONS(9769),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9769),
    [aux_sym_movelast_modification_token1] = ACTIONS(9769),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9769),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9769),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9769),
    [anon_sym_POUNDif] = ACTIONS(9769),
    [anon_sym_POUNDIF] = ACTIONS(9769),
    [anon_sym_POUNDIf] = ACTIONS(9769),
    [anon_sym_POUNDelif] = ACTIONS(9769),
    [anon_sym_POUNDELIF] = ACTIONS(9769),
    [anon_sym_POUNDElif] = ACTIONS(9769),
    [anon_sym_POUNDelse] = ACTIONS(9769),
    [anon_sym_POUNDELSE] = ACTIONS(9769),
    [anon_sym_POUNDElse] = ACTIONS(9769),
    [anon_sym_POUNDendif] = ACTIONS(9769),
    [anon_sym_POUNDENDIF] = ACTIONS(9769),
    [anon_sym_POUNDEndif] = ACTIONS(9769),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9769),
    [sym_trigger_keyword] = ACTIONS(9769),
    [sym_var_keyword] = ACTIONS(9769),
    [sym_local_keyword] = ACTIONS(9769),
    [sym_internal_keyword] = ACTIONS(9769),
    [sym_protected_keyword] = ACTIONS(9769),
    [sym_event_keyword] = ACTIONS(9769),
    [sym_fields_keyword] = ACTIONS(9769),
    [sym_keys_keyword] = ACTIONS(9769),
    [sym_fieldgroups_keyword] = ACTIONS(9769),
    [sym_actions_keyword] = ACTIONS(9769),
    [sym_layout_keyword] = ACTIONS(9769),
    [sym_area_keyword] = ACTIONS(9769),
    [sym_group_keyword] = ACTIONS(9769),
    [sym_repeater_keyword] = ACTIONS(9769),
    [sym_cuegroup_keyword] = ACTIONS(9769),
    [sym_fixed_keyword] = ACTIONS(9769),
    [sym_grid_keyword] = ACTIONS(9769),
    [sym_part_keyword] = ACTIONS(9769),
    [sym_systempart_keyword] = ACTIONS(9769),
    [sym_usercontrol_keyword] = ACTIONS(9769),
    [sym_dataset_keyword] = ACTIONS(9769),
    [sym_elements_keyword] = ACTIONS(9769),
    [sym_dataitem_keyword] = ACTIONS(9769),
    [sym_column_keyword] = ACTIONS(9769),
    [sym_filter_keyword] = ACTIONS(9769),
    [sym_labels_keyword] = ACTIONS(9769),
    [sym_rendering_keyword] = ACTIONS(9769),
    [sym_requestpage_keyword] = ACTIONS(9769),
    [sym_schema_keyword] = ACTIONS(9769),
    [sym_views_keyword] = ACTIONS(9769),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9769),
    [sym_preproc_open] = ACTIONS(9769),
    [sym_preproc_close] = ACTIONS(9769),
  },
  [STATE(3658)] = {
    [anon_sym_SEMI] = ACTIONS(9771),
    [aux_sym_where_condition_token1] = ACTIONS(9773),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9775),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9775),
    [anon_sym_LBRACK] = ACTIONS(9775),
    [aux_sym_basic_type_token6] = ACTIONS(9773),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9775),
    [aux_sym_addafter_modification_token1] = ACTIONS(9775),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9775),
    [aux_sym_modify_modification_token1] = ACTIONS(9775),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9775),
    [aux_sym_movelast_modification_token1] = ACTIONS(9775),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9775),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9775),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9775),
    [anon_sym_POUNDif] = ACTIONS(9775),
    [anon_sym_POUNDIF] = ACTIONS(9775),
    [anon_sym_POUNDIf] = ACTIONS(9775),
    [anon_sym_POUNDelif] = ACTIONS(9775),
    [anon_sym_POUNDELIF] = ACTIONS(9775),
    [anon_sym_POUNDElif] = ACTIONS(9775),
    [anon_sym_POUNDelse] = ACTIONS(9775),
    [anon_sym_POUNDELSE] = ACTIONS(9775),
    [anon_sym_POUNDElse] = ACTIONS(9775),
    [anon_sym_POUNDendif] = ACTIONS(9775),
    [anon_sym_POUNDENDIF] = ACTIONS(9775),
    [anon_sym_POUNDEndif] = ACTIONS(9775),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9775),
    [sym_trigger_keyword] = ACTIONS(9775),
    [sym_var_keyword] = ACTIONS(9775),
    [sym_local_keyword] = ACTIONS(9775),
    [sym_internal_keyword] = ACTIONS(9775),
    [sym_protected_keyword] = ACTIONS(9775),
    [sym_event_keyword] = ACTIONS(9775),
    [sym_fields_keyword] = ACTIONS(9775),
    [sym_keys_keyword] = ACTIONS(9775),
    [sym_fieldgroups_keyword] = ACTIONS(9775),
    [sym_actions_keyword] = ACTIONS(9775),
    [sym_layout_keyword] = ACTIONS(9775),
    [sym_area_keyword] = ACTIONS(9775),
    [sym_group_keyword] = ACTIONS(9775),
    [sym_repeater_keyword] = ACTIONS(9775),
    [sym_cuegroup_keyword] = ACTIONS(9775),
    [sym_fixed_keyword] = ACTIONS(9775),
    [sym_grid_keyword] = ACTIONS(9775),
    [sym_part_keyword] = ACTIONS(9775),
    [sym_systempart_keyword] = ACTIONS(9775),
    [sym_usercontrol_keyword] = ACTIONS(9775),
    [sym_dataset_keyword] = ACTIONS(9775),
    [sym_elements_keyword] = ACTIONS(9775),
    [sym_dataitem_keyword] = ACTIONS(9775),
    [sym_column_keyword] = ACTIONS(9775),
    [sym_filter_keyword] = ACTIONS(9775),
    [sym_labels_keyword] = ACTIONS(9775),
    [sym_rendering_keyword] = ACTIONS(9775),
    [sym_requestpage_keyword] = ACTIONS(9775),
    [sym_schema_keyword] = ACTIONS(9775),
    [sym_views_keyword] = ACTIONS(9775),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9775),
    [sym_preproc_open] = ACTIONS(9775),
    [sym_preproc_close] = ACTIONS(9775),
  },
  [STATE(3659)] = {
    [anon_sym_SEMI] = ACTIONS(9777),
    [aux_sym_where_condition_token1] = ACTIONS(9773),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9775),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9775),
    [anon_sym_LBRACK] = ACTIONS(9775),
    [aux_sym_basic_type_token6] = ACTIONS(9773),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9775),
    [aux_sym_addafter_modification_token1] = ACTIONS(9775),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9775),
    [aux_sym_modify_modification_token1] = ACTIONS(9775),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9775),
    [aux_sym_movelast_modification_token1] = ACTIONS(9775),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9775),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9775),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9775),
    [anon_sym_POUNDif] = ACTIONS(9775),
    [anon_sym_POUNDIF] = ACTIONS(9775),
    [anon_sym_POUNDIf] = ACTIONS(9775),
    [anon_sym_POUNDelif] = ACTIONS(9775),
    [anon_sym_POUNDELIF] = ACTIONS(9775),
    [anon_sym_POUNDElif] = ACTIONS(9775),
    [anon_sym_POUNDelse] = ACTIONS(9775),
    [anon_sym_POUNDELSE] = ACTIONS(9775),
    [anon_sym_POUNDElse] = ACTIONS(9775),
    [anon_sym_POUNDendif] = ACTIONS(9775),
    [anon_sym_POUNDENDIF] = ACTIONS(9775),
    [anon_sym_POUNDEndif] = ACTIONS(9775),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9775),
    [sym_trigger_keyword] = ACTIONS(9775),
    [sym_var_keyword] = ACTIONS(9775),
    [sym_local_keyword] = ACTIONS(9775),
    [sym_internal_keyword] = ACTIONS(9775),
    [sym_protected_keyword] = ACTIONS(9775),
    [sym_event_keyword] = ACTIONS(9775),
    [sym_fields_keyword] = ACTIONS(9775),
    [sym_keys_keyword] = ACTIONS(9775),
    [sym_fieldgroups_keyword] = ACTIONS(9775),
    [sym_actions_keyword] = ACTIONS(9775),
    [sym_layout_keyword] = ACTIONS(9775),
    [sym_area_keyword] = ACTIONS(9775),
    [sym_group_keyword] = ACTIONS(9775),
    [sym_repeater_keyword] = ACTIONS(9775),
    [sym_cuegroup_keyword] = ACTIONS(9775),
    [sym_fixed_keyword] = ACTIONS(9775),
    [sym_grid_keyword] = ACTIONS(9775),
    [sym_part_keyword] = ACTIONS(9775),
    [sym_systempart_keyword] = ACTIONS(9775),
    [sym_usercontrol_keyword] = ACTIONS(9775),
    [sym_dataset_keyword] = ACTIONS(9775),
    [sym_elements_keyword] = ACTIONS(9775),
    [sym_dataitem_keyword] = ACTIONS(9775),
    [sym_column_keyword] = ACTIONS(9775),
    [sym_filter_keyword] = ACTIONS(9775),
    [sym_labels_keyword] = ACTIONS(9775),
    [sym_rendering_keyword] = ACTIONS(9775),
    [sym_requestpage_keyword] = ACTIONS(9775),
    [sym_schema_keyword] = ACTIONS(9775),
    [sym_views_keyword] = ACTIONS(9775),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9775),
    [sym_preproc_open] = ACTIONS(9775),
    [sym_preproc_close] = ACTIONS(9775),
  },
  [STATE(3660)] = {
    [anon_sym_SEMI] = ACTIONS(9779),
    [aux_sym_where_condition_token1] = ACTIONS(9767),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9769),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9769),
    [anon_sym_LBRACK] = ACTIONS(9769),
    [aux_sym_basic_type_token6] = ACTIONS(9767),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9769),
    [aux_sym_addafter_modification_token1] = ACTIONS(9769),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9769),
    [aux_sym_modify_modification_token1] = ACTIONS(9769),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9769),
    [aux_sym_movelast_modification_token1] = ACTIONS(9769),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9769),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9769),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9769),
    [anon_sym_POUNDif] = ACTIONS(9769),
    [anon_sym_POUNDIF] = ACTIONS(9769),
    [anon_sym_POUNDIf] = ACTIONS(9769),
    [anon_sym_POUNDelif] = ACTIONS(9769),
    [anon_sym_POUNDELIF] = ACTIONS(9769),
    [anon_sym_POUNDElif] = ACTIONS(9769),
    [anon_sym_POUNDelse] = ACTIONS(9769),
    [anon_sym_POUNDELSE] = ACTIONS(9769),
    [anon_sym_POUNDElse] = ACTIONS(9769),
    [anon_sym_POUNDendif] = ACTIONS(9769),
    [anon_sym_POUNDENDIF] = ACTIONS(9769),
    [anon_sym_POUNDEndif] = ACTIONS(9769),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9769),
    [sym_trigger_keyword] = ACTIONS(9769),
    [sym_var_keyword] = ACTIONS(9769),
    [sym_local_keyword] = ACTIONS(9769),
    [sym_internal_keyword] = ACTIONS(9769),
    [sym_protected_keyword] = ACTIONS(9769),
    [sym_event_keyword] = ACTIONS(9769),
    [sym_fields_keyword] = ACTIONS(9769),
    [sym_keys_keyword] = ACTIONS(9769),
    [sym_fieldgroups_keyword] = ACTIONS(9769),
    [sym_actions_keyword] = ACTIONS(9769),
    [sym_layout_keyword] = ACTIONS(9769),
    [sym_area_keyword] = ACTIONS(9769),
    [sym_group_keyword] = ACTIONS(9769),
    [sym_repeater_keyword] = ACTIONS(9769),
    [sym_cuegroup_keyword] = ACTIONS(9769),
    [sym_fixed_keyword] = ACTIONS(9769),
    [sym_grid_keyword] = ACTIONS(9769),
    [sym_part_keyword] = ACTIONS(9769),
    [sym_systempart_keyword] = ACTIONS(9769),
    [sym_usercontrol_keyword] = ACTIONS(9769),
    [sym_dataset_keyword] = ACTIONS(9769),
    [sym_elements_keyword] = ACTIONS(9769),
    [sym_dataitem_keyword] = ACTIONS(9769),
    [sym_column_keyword] = ACTIONS(9769),
    [sym_filter_keyword] = ACTIONS(9769),
    [sym_labels_keyword] = ACTIONS(9769),
    [sym_rendering_keyword] = ACTIONS(9769),
    [sym_requestpage_keyword] = ACTIONS(9769),
    [sym_schema_keyword] = ACTIONS(9769),
    [sym_views_keyword] = ACTIONS(9769),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9769),
    [sym_preproc_open] = ACTIONS(9769),
    [sym_preproc_close] = ACTIONS(9769),
  },
  [STATE(3661)] = {
    [sym_preproc_split_procedure] = STATE(3662),
    [sym_var_attribute_item] = STATE(3662),
    [sym_preproc_conditional_var] = STATE(3662),
    [sym_variable_declaration] = STATE(3662),
    [sym_preproc_if] = STATE(2424),
    [sym__identifier_or_quoted] = STATE(10847),
    [sym_keyword_as_identifier] = STATE(10847),
    [aux_sym_var_section_repeat1] = STATE(3662),
    [sym_identifier] = ACTIONS(9781),
    [anon_sym_SEMI] = ACTIONS(6255),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(6255),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_modify_modification_token1] = ACTIONS(6257),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_xmlport_element_token1] = ACTIONS(6257),
    [aux_sym_xmlport_element_token2] = ACTIONS(6257),
    [aux_sym_xmlport_element_token3] = ACTIONS(6257),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6257),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6257),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6257),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(6259),
    [anon_sym_POUNDIF] = ACTIONS(6259),
    [anon_sym_POUNDIf] = ACTIONS(6259),
    [anon_sym_POUNDelif] = ACTIONS(6255),
    [anon_sym_POUNDELIF] = ACTIONS(6255),
    [anon_sym_POUNDElif] = ACTIONS(6255),
    [anon_sym_POUNDelse] = ACTIONS(6255),
    [anon_sym_POUNDELSE] = ACTIONS(6255),
    [anon_sym_POUNDElse] = ACTIONS(6255),
    [anon_sym_POUNDendif] = ACTIONS(6255),
    [anon_sym_POUNDENDIF] = ACTIONS(6255),
    [anon_sym_POUNDEndif] = ACTIONS(6255),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6257),
    [sym_trigger_keyword] = ACTIONS(6257),
    [sym_var_keyword] = ACTIONS(6257),
    [sym_local_keyword] = ACTIONS(6257),
    [sym_internal_keyword] = ACTIONS(6257),
    [sym_protected_keyword] = ACTIONS(6257),
    [sym_event_keyword] = ACTIONS(6257),
    [sym_fields_keyword] = ACTIONS(6257),
    [sym_keys_keyword] = ACTIONS(6257),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(6257),
    [sym_actions_keyword] = ACTIONS(6257),
    [sym_layout_keyword] = ACTIONS(6257),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_elements_keyword] = ACTIONS(6257),
    [sym_labels_keyword] = ACTIONS(6257),
    [sym_rendering_keyword] = ACTIONS(6257),
    [sym_requestpage_keyword] = ACTIONS(6257),
    [sym_schema_keyword] = ACTIONS(6257),
    [sym_views_keyword] = ACTIONS(6257),
    [sym_quoted_identifier] = ACTIONS(9783),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6255),
    [sym_preproc_open] = ACTIONS(6259),
    [sym_preproc_close] = ACTIONS(6255),
    [sym_var_attribute_open] = ACTIONS(9785),
  },
  [STATE(3662)] = {
    [sym_preproc_split_procedure] = STATE(3667),
    [sym_var_attribute_item] = STATE(3667),
    [sym_preproc_conditional_var] = STATE(3667),
    [sym_variable_declaration] = STATE(3667),
    [sym_preproc_if] = STATE(2424),
    [sym__identifier_or_quoted] = STATE(10847),
    [sym_keyword_as_identifier] = STATE(10847),
    [aux_sym_var_section_repeat1] = STATE(3667),
    [sym_identifier] = ACTIONS(9781),
    [anon_sym_SEMI] = ACTIONS(6265),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(6265),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_modify_modification_token1] = ACTIONS(6267),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_xmlport_element_token1] = ACTIONS(6267),
    [aux_sym_xmlport_element_token2] = ACTIONS(6267),
    [aux_sym_xmlport_element_token3] = ACTIONS(6267),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6267),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6267),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6267),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(6259),
    [anon_sym_POUNDIF] = ACTIONS(6259),
    [anon_sym_POUNDIf] = ACTIONS(6259),
    [anon_sym_POUNDelif] = ACTIONS(6265),
    [anon_sym_POUNDELIF] = ACTIONS(6265),
    [anon_sym_POUNDElif] = ACTIONS(6265),
    [anon_sym_POUNDelse] = ACTIONS(6265),
    [anon_sym_POUNDELSE] = ACTIONS(6265),
    [anon_sym_POUNDElse] = ACTIONS(6265),
    [anon_sym_POUNDendif] = ACTIONS(6265),
    [anon_sym_POUNDENDIF] = ACTIONS(6265),
    [anon_sym_POUNDEndif] = ACTIONS(6265),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6267),
    [sym_trigger_keyword] = ACTIONS(6267),
    [sym_var_keyword] = ACTIONS(6267),
    [sym_local_keyword] = ACTIONS(6267),
    [sym_internal_keyword] = ACTIONS(6267),
    [sym_protected_keyword] = ACTIONS(6267),
    [sym_event_keyword] = ACTIONS(6267),
    [sym_fields_keyword] = ACTIONS(6267),
    [sym_keys_keyword] = ACTIONS(6267),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(6267),
    [sym_actions_keyword] = ACTIONS(6267),
    [sym_layout_keyword] = ACTIONS(6267),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_elements_keyword] = ACTIONS(6267),
    [sym_labels_keyword] = ACTIONS(6267),
    [sym_rendering_keyword] = ACTIONS(6267),
    [sym_requestpage_keyword] = ACTIONS(6267),
    [sym_schema_keyword] = ACTIONS(6267),
    [sym_views_keyword] = ACTIONS(6267),
    [sym_quoted_identifier] = ACTIONS(9783),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6265),
    [sym_preproc_open] = ACTIONS(6259),
    [sym_preproc_close] = ACTIONS(6265),
    [sym_var_attribute_open] = ACTIONS(9785),
  },
  [STATE(3663)] = {
    [sym_preproc_split_procedure] = STATE(3669),
    [sym_var_attribute_item] = STATE(3669),
    [sym_preproc_conditional_var] = STATE(3669),
    [sym_variable_declaration] = STATE(3669),
    [sym_preproc_if] = STATE(2424),
    [sym__identifier_or_quoted] = STATE(10847),
    [sym_keyword_as_identifier] = STATE(10847),
    [aux_sym_var_section_repeat1] = STATE(3669),
    [sym_identifier] = ACTIONS(9781),
    [anon_sym_SEMI] = ACTIONS(6265),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(6265),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_modify_modification_token1] = ACTIONS(6267),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_xmlport_element_token1] = ACTIONS(6267),
    [aux_sym_xmlport_element_token2] = ACTIONS(6267),
    [aux_sym_xmlport_element_token3] = ACTIONS(6267),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6267),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6267),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6267),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(6259),
    [anon_sym_POUNDIF] = ACTIONS(6259),
    [anon_sym_POUNDIf] = ACTIONS(6259),
    [anon_sym_POUNDelif] = ACTIONS(6265),
    [anon_sym_POUNDELIF] = ACTIONS(6265),
    [anon_sym_POUNDElif] = ACTIONS(6265),
    [anon_sym_POUNDelse] = ACTIONS(6265),
    [anon_sym_POUNDELSE] = ACTIONS(6265),
    [anon_sym_POUNDElse] = ACTIONS(6265),
    [anon_sym_POUNDendif] = ACTIONS(6265),
    [anon_sym_POUNDENDIF] = ACTIONS(6265),
    [anon_sym_POUNDEndif] = ACTIONS(6265),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6267),
    [sym_trigger_keyword] = ACTIONS(6267),
    [sym_var_keyword] = ACTIONS(6267),
    [sym_local_keyword] = ACTIONS(6267),
    [sym_internal_keyword] = ACTIONS(6267),
    [sym_protected_keyword] = ACTIONS(6267),
    [sym_event_keyword] = ACTIONS(6267),
    [sym_fields_keyword] = ACTIONS(6267),
    [sym_keys_keyword] = ACTIONS(6267),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(6267),
    [sym_actions_keyword] = ACTIONS(6267),
    [sym_layout_keyword] = ACTIONS(6267),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_elements_keyword] = ACTIONS(6267),
    [sym_labels_keyword] = ACTIONS(6267),
    [sym_rendering_keyword] = ACTIONS(6267),
    [sym_requestpage_keyword] = ACTIONS(6267),
    [sym_schema_keyword] = ACTIONS(6267),
    [sym_views_keyword] = ACTIONS(6267),
    [sym_quoted_identifier] = ACTIONS(9783),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6265),
    [sym_preproc_open] = ACTIONS(6259),
    [sym_preproc_close] = ACTIONS(6265),
    [sym_var_attribute_open] = ACTIONS(9785),
  },
  [STATE(3664)] = {
    [anon_sym_SEMI] = ACTIONS(9787),
    [aux_sym_where_condition_token1] = ACTIONS(9789),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9787),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9787),
    [anon_sym_LBRACK] = ACTIONS(9787),
    [aux_sym_basic_type_token6] = ACTIONS(9789),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9787),
    [aux_sym_addafter_modification_token1] = ACTIONS(9787),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9787),
    [aux_sym_modify_modification_token1] = ACTIONS(9787),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9787),
    [aux_sym_movelast_modification_token1] = ACTIONS(9787),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9787),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9787),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9787),
    [anon_sym_POUNDif] = ACTIONS(9787),
    [anon_sym_POUNDIF] = ACTIONS(9787),
    [anon_sym_POUNDIf] = ACTIONS(9787),
    [anon_sym_POUNDelif] = ACTIONS(9787),
    [anon_sym_POUNDELIF] = ACTIONS(9787),
    [anon_sym_POUNDElif] = ACTIONS(9787),
    [anon_sym_POUNDelse] = ACTIONS(9787),
    [anon_sym_POUNDELSE] = ACTIONS(9787),
    [anon_sym_POUNDElse] = ACTIONS(9787),
    [anon_sym_POUNDendif] = ACTIONS(9787),
    [anon_sym_POUNDENDIF] = ACTIONS(9787),
    [anon_sym_POUNDEndif] = ACTIONS(9787),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9787),
    [sym_trigger_keyword] = ACTIONS(9787),
    [sym_var_keyword] = ACTIONS(9787),
    [sym_local_keyword] = ACTIONS(9787),
    [sym_internal_keyword] = ACTIONS(9787),
    [sym_protected_keyword] = ACTIONS(9787),
    [sym_event_keyword] = ACTIONS(9787),
    [sym_fields_keyword] = ACTIONS(9787),
    [sym_keys_keyword] = ACTIONS(9787),
    [sym_fieldgroups_keyword] = ACTIONS(9787),
    [sym_actions_keyword] = ACTIONS(9787),
    [sym_layout_keyword] = ACTIONS(9787),
    [sym_area_keyword] = ACTIONS(9787),
    [sym_group_keyword] = ACTIONS(9787),
    [sym_repeater_keyword] = ACTIONS(9787),
    [sym_cuegroup_keyword] = ACTIONS(9787),
    [sym_fixed_keyword] = ACTIONS(9787),
    [sym_grid_keyword] = ACTIONS(9787),
    [sym_part_keyword] = ACTIONS(9787),
    [sym_systempart_keyword] = ACTIONS(9787),
    [sym_usercontrol_keyword] = ACTIONS(9787),
    [sym_dataset_keyword] = ACTIONS(9787),
    [sym_elements_keyword] = ACTIONS(9787),
    [sym_dataitem_keyword] = ACTIONS(9787),
    [sym_column_keyword] = ACTIONS(9787),
    [sym_filter_keyword] = ACTIONS(9787),
    [sym_labels_keyword] = ACTIONS(9787),
    [sym_rendering_keyword] = ACTIONS(9787),
    [sym_requestpage_keyword] = ACTIONS(9787),
    [sym_schema_keyword] = ACTIONS(9787),
    [sym_views_keyword] = ACTIONS(9787),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9787),
    [sym_preproc_open] = ACTIONS(9787),
    [sym_preproc_close] = ACTIONS(9787),
  },
  [STATE(3665)] = {
    [anon_sym_SEMI] = ACTIONS(9791),
    [aux_sym_where_condition_token1] = ACTIONS(9793),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9791),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9791),
    [anon_sym_LBRACK] = ACTIONS(9791),
    [aux_sym_basic_type_token6] = ACTIONS(9793),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9791),
    [aux_sym_addafter_modification_token1] = ACTIONS(9791),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9791),
    [aux_sym_modify_modification_token1] = ACTIONS(9791),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9791),
    [aux_sym_movelast_modification_token1] = ACTIONS(9791),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9791),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9791),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9791),
    [anon_sym_POUNDif] = ACTIONS(9791),
    [anon_sym_POUNDIF] = ACTIONS(9791),
    [anon_sym_POUNDIf] = ACTIONS(9791),
    [anon_sym_POUNDelif] = ACTIONS(9791),
    [anon_sym_POUNDELIF] = ACTIONS(9791),
    [anon_sym_POUNDElif] = ACTIONS(9791),
    [anon_sym_POUNDelse] = ACTIONS(9791),
    [anon_sym_POUNDELSE] = ACTIONS(9791),
    [anon_sym_POUNDElse] = ACTIONS(9791),
    [anon_sym_POUNDendif] = ACTIONS(9791),
    [anon_sym_POUNDENDIF] = ACTIONS(9791),
    [anon_sym_POUNDEndif] = ACTIONS(9791),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9791),
    [sym_trigger_keyword] = ACTIONS(9791),
    [sym_var_keyword] = ACTIONS(9791),
    [sym_local_keyword] = ACTIONS(9791),
    [sym_internal_keyword] = ACTIONS(9791),
    [sym_protected_keyword] = ACTIONS(9791),
    [sym_event_keyword] = ACTIONS(9791),
    [sym_fields_keyword] = ACTIONS(9791),
    [sym_keys_keyword] = ACTIONS(9791),
    [sym_fieldgroups_keyword] = ACTIONS(9791),
    [sym_actions_keyword] = ACTIONS(9791),
    [sym_layout_keyword] = ACTIONS(9791),
    [sym_area_keyword] = ACTIONS(9791),
    [sym_group_keyword] = ACTIONS(9791),
    [sym_repeater_keyword] = ACTIONS(9791),
    [sym_cuegroup_keyword] = ACTIONS(9791),
    [sym_fixed_keyword] = ACTIONS(9791),
    [sym_grid_keyword] = ACTIONS(9791),
    [sym_part_keyword] = ACTIONS(9791),
    [sym_systempart_keyword] = ACTIONS(9791),
    [sym_usercontrol_keyword] = ACTIONS(9791),
    [sym_dataset_keyword] = ACTIONS(9791),
    [sym_elements_keyword] = ACTIONS(9791),
    [sym_dataitem_keyword] = ACTIONS(9791),
    [sym_column_keyword] = ACTIONS(9791),
    [sym_filter_keyword] = ACTIONS(9791),
    [sym_labels_keyword] = ACTIONS(9791),
    [sym_rendering_keyword] = ACTIONS(9791),
    [sym_requestpage_keyword] = ACTIONS(9791),
    [sym_schema_keyword] = ACTIONS(9791),
    [sym_views_keyword] = ACTIONS(9791),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9791),
    [sym_preproc_open] = ACTIONS(9791),
    [sym_preproc_close] = ACTIONS(9791),
  },
  [STATE(3666)] = {
    [anon_sym_SEMI] = ACTIONS(9795),
    [aux_sym_where_condition_token1] = ACTIONS(9797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9795),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9795),
    [anon_sym_LBRACK] = ACTIONS(9795),
    [aux_sym_basic_type_token6] = ACTIONS(9797),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9795),
    [aux_sym_addafter_modification_token1] = ACTIONS(9795),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9795),
    [aux_sym_modify_modification_token1] = ACTIONS(9795),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9795),
    [aux_sym_movelast_modification_token1] = ACTIONS(9795),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9795),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9795),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9795),
    [anon_sym_POUNDif] = ACTIONS(9795),
    [anon_sym_POUNDIF] = ACTIONS(9795),
    [anon_sym_POUNDIf] = ACTIONS(9795),
    [anon_sym_POUNDelif] = ACTIONS(9795),
    [anon_sym_POUNDELIF] = ACTIONS(9795),
    [anon_sym_POUNDElif] = ACTIONS(9795),
    [anon_sym_POUNDelse] = ACTIONS(9795),
    [anon_sym_POUNDELSE] = ACTIONS(9795),
    [anon_sym_POUNDElse] = ACTIONS(9795),
    [anon_sym_POUNDendif] = ACTIONS(9795),
    [anon_sym_POUNDENDIF] = ACTIONS(9795),
    [anon_sym_POUNDEndif] = ACTIONS(9795),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9795),
    [sym_trigger_keyword] = ACTIONS(9795),
    [sym_var_keyword] = ACTIONS(9795),
    [sym_local_keyword] = ACTIONS(9795),
    [sym_internal_keyword] = ACTIONS(9795),
    [sym_protected_keyword] = ACTIONS(9795),
    [sym_event_keyword] = ACTIONS(9795),
    [sym_fields_keyword] = ACTIONS(9795),
    [sym_keys_keyword] = ACTIONS(9795),
    [sym_fieldgroups_keyword] = ACTIONS(9795),
    [sym_actions_keyword] = ACTIONS(9795),
    [sym_layout_keyword] = ACTIONS(9795),
    [sym_area_keyword] = ACTIONS(9795),
    [sym_group_keyword] = ACTIONS(9795),
    [sym_repeater_keyword] = ACTIONS(9795),
    [sym_cuegroup_keyword] = ACTIONS(9795),
    [sym_fixed_keyword] = ACTIONS(9795),
    [sym_grid_keyword] = ACTIONS(9795),
    [sym_part_keyword] = ACTIONS(9795),
    [sym_systempart_keyword] = ACTIONS(9795),
    [sym_usercontrol_keyword] = ACTIONS(9795),
    [sym_dataset_keyword] = ACTIONS(9795),
    [sym_elements_keyword] = ACTIONS(9795),
    [sym_dataitem_keyword] = ACTIONS(9795),
    [sym_column_keyword] = ACTIONS(9795),
    [sym_filter_keyword] = ACTIONS(9795),
    [sym_labels_keyword] = ACTIONS(9795),
    [sym_rendering_keyword] = ACTIONS(9795),
    [sym_requestpage_keyword] = ACTIONS(9795),
    [sym_schema_keyword] = ACTIONS(9795),
    [sym_views_keyword] = ACTIONS(9795),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9795),
    [sym_preproc_open] = ACTIONS(9795),
    [sym_preproc_close] = ACTIONS(9795),
  },
  [STATE(3667)] = {
    [sym_preproc_split_procedure] = STATE(3667),
    [sym_var_attribute_item] = STATE(3667),
    [sym_preproc_conditional_var] = STATE(3667),
    [sym_variable_declaration] = STATE(3667),
    [sym_preproc_if] = STATE(2424),
    [sym__identifier_or_quoted] = STATE(10847),
    [sym_keyword_as_identifier] = STATE(10847),
    [aux_sym_var_section_repeat1] = STATE(3667),
    [sym_identifier] = ACTIONS(9799),
    [anon_sym_SEMI] = ACTIONS(6239),
    [aux_sym_where_condition_token1] = ACTIONS(6241),
    [anon_sym_LBRACK] = ACTIONS(6239),
    [aux_sym_basic_type_token22] = ACTIONS(6241),
    [aux_sym_basic_type_token53] = ACTIONS(6241),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6241),
    [aux_sym_modify_modification_token1] = ACTIONS(6244),
    [aux_sym_separator_action_token1] = ACTIONS(6241),
    [aux_sym_xmlport_element_token1] = ACTIONS(6244),
    [aux_sym_xmlport_element_token2] = ACTIONS(6244),
    [aux_sym_xmlport_element_token3] = ACTIONS(6244),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6244),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6244),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6244),
    [aux_sym_type_declaration_token1] = ACTIONS(6241),
    [anon_sym_POUNDif] = ACTIONS(6246),
    [anon_sym_POUNDIF] = ACTIONS(6246),
    [anon_sym_POUNDIf] = ACTIONS(6246),
    [anon_sym_POUNDelif] = ACTIONS(6239),
    [anon_sym_POUNDELIF] = ACTIONS(6239),
    [anon_sym_POUNDElif] = ACTIONS(6239),
    [anon_sym_POUNDelse] = ACTIONS(6239),
    [anon_sym_POUNDELSE] = ACTIONS(6239),
    [anon_sym_POUNDElse] = ACTIONS(6239),
    [anon_sym_POUNDendif] = ACTIONS(6239),
    [anon_sym_POUNDENDIF] = ACTIONS(6239),
    [anon_sym_POUNDEndif] = ACTIONS(6239),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6244),
    [sym_trigger_keyword] = ACTIONS(6244),
    [sym_var_keyword] = ACTIONS(6244),
    [sym_local_keyword] = ACTIONS(6244),
    [sym_internal_keyword] = ACTIONS(6244),
    [sym_protected_keyword] = ACTIONS(6244),
    [sym_event_keyword] = ACTIONS(6244),
    [sym_fields_keyword] = ACTIONS(6244),
    [sym_keys_keyword] = ACTIONS(6244),
    [sym_key_keyword] = ACTIONS(6241),
    [sym_fieldgroups_keyword] = ACTIONS(6244),
    [sym_actions_keyword] = ACTIONS(6244),
    [sym_layout_keyword] = ACTIONS(6244),
    [sym_dataset_keyword] = ACTIONS(6241),
    [sym_elements_keyword] = ACTIONS(6244),
    [sym_labels_keyword] = ACTIONS(6244),
    [sym_rendering_keyword] = ACTIONS(6244),
    [sym_requestpage_keyword] = ACTIONS(6244),
    [sym_schema_keyword] = ACTIONS(6244),
    [sym_views_keyword] = ACTIONS(6244),
    [sym_quoted_identifier] = ACTIONS(9802),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6239),
    [sym_preproc_open] = ACTIONS(6246),
    [sym_preproc_close] = ACTIONS(6239),
    [sym_var_attribute_open] = ACTIONS(9805),
  },
  [STATE(3668)] = {
    [anon_sym_SEMI] = ACTIONS(9795),
    [aux_sym_where_condition_token1] = ACTIONS(9797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9795),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9795),
    [anon_sym_LBRACK] = ACTIONS(9795),
    [aux_sym_basic_type_token6] = ACTIONS(9797),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9795),
    [aux_sym_addafter_modification_token1] = ACTIONS(9795),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9795),
    [aux_sym_modify_modification_token1] = ACTIONS(9795),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9795),
    [aux_sym_movelast_modification_token1] = ACTIONS(9795),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9795),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9795),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9795),
    [anon_sym_POUNDif] = ACTIONS(9795),
    [anon_sym_POUNDIF] = ACTIONS(9795),
    [anon_sym_POUNDIf] = ACTIONS(9795),
    [anon_sym_POUNDelif] = ACTIONS(9795),
    [anon_sym_POUNDELIF] = ACTIONS(9795),
    [anon_sym_POUNDElif] = ACTIONS(9795),
    [anon_sym_POUNDelse] = ACTIONS(9795),
    [anon_sym_POUNDELSE] = ACTIONS(9795),
    [anon_sym_POUNDElse] = ACTIONS(9795),
    [anon_sym_POUNDendif] = ACTIONS(9795),
    [anon_sym_POUNDENDIF] = ACTIONS(9795),
    [anon_sym_POUNDEndif] = ACTIONS(9795),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9795),
    [sym_trigger_keyword] = ACTIONS(9795),
    [sym_var_keyword] = ACTIONS(9795),
    [sym_local_keyword] = ACTIONS(9795),
    [sym_internal_keyword] = ACTIONS(9795),
    [sym_protected_keyword] = ACTIONS(9795),
    [sym_event_keyword] = ACTIONS(9795),
    [sym_fields_keyword] = ACTIONS(9795),
    [sym_keys_keyword] = ACTIONS(9795),
    [sym_fieldgroups_keyword] = ACTIONS(9795),
    [sym_actions_keyword] = ACTIONS(9795),
    [sym_layout_keyword] = ACTIONS(9795),
    [sym_area_keyword] = ACTIONS(9795),
    [sym_group_keyword] = ACTIONS(9795),
    [sym_repeater_keyword] = ACTIONS(9795),
    [sym_cuegroup_keyword] = ACTIONS(9795),
    [sym_fixed_keyword] = ACTIONS(9795),
    [sym_grid_keyword] = ACTIONS(9795),
    [sym_part_keyword] = ACTIONS(9795),
    [sym_systempart_keyword] = ACTIONS(9795),
    [sym_usercontrol_keyword] = ACTIONS(9795),
    [sym_dataset_keyword] = ACTIONS(9795),
    [sym_elements_keyword] = ACTIONS(9795),
    [sym_dataitem_keyword] = ACTIONS(9795),
    [sym_column_keyword] = ACTIONS(9795),
    [sym_filter_keyword] = ACTIONS(9795),
    [sym_labels_keyword] = ACTIONS(9795),
    [sym_rendering_keyword] = ACTIONS(9795),
    [sym_requestpage_keyword] = ACTIONS(9795),
    [sym_schema_keyword] = ACTIONS(9795),
    [sym_views_keyword] = ACTIONS(9795),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9795),
    [sym_preproc_open] = ACTIONS(9795),
    [sym_preproc_close] = ACTIONS(9795),
  },
  [STATE(3669)] = {
    [sym_preproc_split_procedure] = STATE(3667),
    [sym_var_attribute_item] = STATE(3667),
    [sym_preproc_conditional_var] = STATE(3667),
    [sym_variable_declaration] = STATE(3667),
    [sym_preproc_if] = STATE(2424),
    [sym__identifier_or_quoted] = STATE(10847),
    [sym_keyword_as_identifier] = STATE(10847),
    [aux_sym_var_section_repeat1] = STATE(3667),
    [sym_identifier] = ACTIONS(9781),
    [anon_sym_SEMI] = ACTIONS(6261),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(6261),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_modify_modification_token1] = ACTIONS(6263),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_xmlport_element_token1] = ACTIONS(6263),
    [aux_sym_xmlport_element_token2] = ACTIONS(6263),
    [aux_sym_xmlport_element_token3] = ACTIONS(6263),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6263),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6263),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6263),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(6259),
    [anon_sym_POUNDIF] = ACTIONS(6259),
    [anon_sym_POUNDIf] = ACTIONS(6259),
    [anon_sym_POUNDelif] = ACTIONS(6261),
    [anon_sym_POUNDELIF] = ACTIONS(6261),
    [anon_sym_POUNDElif] = ACTIONS(6261),
    [anon_sym_POUNDelse] = ACTIONS(6261),
    [anon_sym_POUNDELSE] = ACTIONS(6261),
    [anon_sym_POUNDElse] = ACTIONS(6261),
    [anon_sym_POUNDendif] = ACTIONS(6261),
    [anon_sym_POUNDENDIF] = ACTIONS(6261),
    [anon_sym_POUNDEndif] = ACTIONS(6261),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6263),
    [sym_trigger_keyword] = ACTIONS(6263),
    [sym_var_keyword] = ACTIONS(6263),
    [sym_local_keyword] = ACTIONS(6263),
    [sym_internal_keyword] = ACTIONS(6263),
    [sym_protected_keyword] = ACTIONS(6263),
    [sym_event_keyword] = ACTIONS(6263),
    [sym_fields_keyword] = ACTIONS(6263),
    [sym_keys_keyword] = ACTIONS(6263),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(6263),
    [sym_actions_keyword] = ACTIONS(6263),
    [sym_layout_keyword] = ACTIONS(6263),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_elements_keyword] = ACTIONS(6263),
    [sym_labels_keyword] = ACTIONS(6263),
    [sym_rendering_keyword] = ACTIONS(6263),
    [sym_requestpage_keyword] = ACTIONS(6263),
    [sym_schema_keyword] = ACTIONS(6263),
    [sym_views_keyword] = ACTIONS(6263),
    [sym_quoted_identifier] = ACTIONS(9783),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6261),
    [sym_preproc_open] = ACTIONS(6259),
    [sym_preproc_close] = ACTIONS(6261),
    [sym_var_attribute_open] = ACTIONS(9785),
  },
  [STATE(3670)] = {
    [anon_sym_SEMI] = ACTIONS(9795),
    [aux_sym_where_condition_token1] = ACTIONS(9797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9795),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9795),
    [anon_sym_LBRACK] = ACTIONS(9795),
    [aux_sym_basic_type_token6] = ACTIONS(9797),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9795),
    [aux_sym_addafter_modification_token1] = ACTIONS(9795),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9795),
    [aux_sym_modify_modification_token1] = ACTIONS(9795),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9795),
    [aux_sym_movelast_modification_token1] = ACTIONS(9795),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9795),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9795),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9795),
    [anon_sym_POUNDif] = ACTIONS(9795),
    [anon_sym_POUNDIF] = ACTIONS(9795),
    [anon_sym_POUNDIf] = ACTIONS(9795),
    [anon_sym_POUNDelif] = ACTIONS(9795),
    [anon_sym_POUNDELIF] = ACTIONS(9795),
    [anon_sym_POUNDElif] = ACTIONS(9795),
    [anon_sym_POUNDelse] = ACTIONS(9795),
    [anon_sym_POUNDELSE] = ACTIONS(9795),
    [anon_sym_POUNDElse] = ACTIONS(9795),
    [anon_sym_POUNDendif] = ACTIONS(9795),
    [anon_sym_POUNDENDIF] = ACTIONS(9795),
    [anon_sym_POUNDEndif] = ACTIONS(9795),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9795),
    [sym_trigger_keyword] = ACTIONS(9795),
    [sym_var_keyword] = ACTIONS(9795),
    [sym_local_keyword] = ACTIONS(9795),
    [sym_internal_keyword] = ACTIONS(9795),
    [sym_protected_keyword] = ACTIONS(9795),
    [sym_event_keyword] = ACTIONS(9795),
    [sym_fields_keyword] = ACTIONS(9795),
    [sym_keys_keyword] = ACTIONS(9795),
    [sym_fieldgroups_keyword] = ACTIONS(9795),
    [sym_actions_keyword] = ACTIONS(9795),
    [sym_layout_keyword] = ACTIONS(9795),
    [sym_area_keyword] = ACTIONS(9795),
    [sym_group_keyword] = ACTIONS(9795),
    [sym_repeater_keyword] = ACTIONS(9795),
    [sym_cuegroup_keyword] = ACTIONS(9795),
    [sym_fixed_keyword] = ACTIONS(9795),
    [sym_grid_keyword] = ACTIONS(9795),
    [sym_part_keyword] = ACTIONS(9795),
    [sym_systempart_keyword] = ACTIONS(9795),
    [sym_usercontrol_keyword] = ACTIONS(9795),
    [sym_dataset_keyword] = ACTIONS(9795),
    [sym_elements_keyword] = ACTIONS(9795),
    [sym_dataitem_keyword] = ACTIONS(9795),
    [sym_column_keyword] = ACTIONS(9795),
    [sym_filter_keyword] = ACTIONS(9795),
    [sym_labels_keyword] = ACTIONS(9795),
    [sym_rendering_keyword] = ACTIONS(9795),
    [sym_requestpage_keyword] = ACTIONS(9795),
    [sym_schema_keyword] = ACTIONS(9795),
    [sym_views_keyword] = ACTIONS(9795),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9795),
    [sym_preproc_open] = ACTIONS(9795),
    [sym_preproc_close] = ACTIONS(9795),
  },
  [STATE(3671)] = {
    [anon_sym_SEMI] = ACTIONS(9795),
    [aux_sym_where_condition_token1] = ACTIONS(9797),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9795),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9795),
    [anon_sym_LBRACK] = ACTIONS(9795),
    [aux_sym_basic_type_token6] = ACTIONS(9797),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9795),
    [aux_sym_addafter_modification_token1] = ACTIONS(9795),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9795),
    [aux_sym_modify_modification_token1] = ACTIONS(9795),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9795),
    [aux_sym_movelast_modification_token1] = ACTIONS(9795),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9795),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9795),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9795),
    [anon_sym_POUNDif] = ACTIONS(9795),
    [anon_sym_POUNDIF] = ACTIONS(9795),
    [anon_sym_POUNDIf] = ACTIONS(9795),
    [anon_sym_POUNDelif] = ACTIONS(9795),
    [anon_sym_POUNDELIF] = ACTIONS(9795),
    [anon_sym_POUNDElif] = ACTIONS(9795),
    [anon_sym_POUNDelse] = ACTIONS(9795),
    [anon_sym_POUNDELSE] = ACTIONS(9795),
    [anon_sym_POUNDElse] = ACTIONS(9795),
    [anon_sym_POUNDendif] = ACTIONS(9795),
    [anon_sym_POUNDENDIF] = ACTIONS(9795),
    [anon_sym_POUNDEndif] = ACTIONS(9795),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9795),
    [sym_trigger_keyword] = ACTIONS(9795),
    [sym_var_keyword] = ACTIONS(9795),
    [sym_local_keyword] = ACTIONS(9795),
    [sym_internal_keyword] = ACTIONS(9795),
    [sym_protected_keyword] = ACTIONS(9795),
    [sym_event_keyword] = ACTIONS(9795),
    [sym_fields_keyword] = ACTIONS(9795),
    [sym_keys_keyword] = ACTIONS(9795),
    [sym_fieldgroups_keyword] = ACTIONS(9795),
    [sym_actions_keyword] = ACTIONS(9795),
    [sym_layout_keyword] = ACTIONS(9795),
    [sym_area_keyword] = ACTIONS(9795),
    [sym_group_keyword] = ACTIONS(9795),
    [sym_repeater_keyword] = ACTIONS(9795),
    [sym_cuegroup_keyword] = ACTIONS(9795),
    [sym_fixed_keyword] = ACTIONS(9795),
    [sym_grid_keyword] = ACTIONS(9795),
    [sym_part_keyword] = ACTIONS(9795),
    [sym_systempart_keyword] = ACTIONS(9795),
    [sym_usercontrol_keyword] = ACTIONS(9795),
    [sym_dataset_keyword] = ACTIONS(9795),
    [sym_elements_keyword] = ACTIONS(9795),
    [sym_dataitem_keyword] = ACTIONS(9795),
    [sym_column_keyword] = ACTIONS(9795),
    [sym_filter_keyword] = ACTIONS(9795),
    [sym_labels_keyword] = ACTIONS(9795),
    [sym_rendering_keyword] = ACTIONS(9795),
    [sym_requestpage_keyword] = ACTIONS(9795),
    [sym_schema_keyword] = ACTIONS(9795),
    [sym_views_keyword] = ACTIONS(9795),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9795),
    [sym_preproc_open] = ACTIONS(9795),
    [sym_preproc_close] = ACTIONS(9795),
  },
  [STATE(3672)] = {
    [anon_sym_SEMI] = ACTIONS(9808),
    [aux_sym_where_condition_token1] = ACTIONS(9810),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9808),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9808),
    [anon_sym_LBRACK] = ACTIONS(9808),
    [aux_sym_basic_type_token6] = ACTIONS(9810),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9808),
    [aux_sym_addafter_modification_token1] = ACTIONS(9808),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9808),
    [aux_sym_modify_modification_token1] = ACTIONS(9808),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9808),
    [aux_sym_movelast_modification_token1] = ACTIONS(9808),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9808),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9808),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9808),
    [anon_sym_POUNDif] = ACTIONS(9808),
    [anon_sym_POUNDIF] = ACTIONS(9808),
    [anon_sym_POUNDIf] = ACTIONS(9808),
    [anon_sym_POUNDelif] = ACTIONS(9808),
    [anon_sym_POUNDELIF] = ACTIONS(9808),
    [anon_sym_POUNDElif] = ACTIONS(9808),
    [anon_sym_POUNDelse] = ACTIONS(9808),
    [anon_sym_POUNDELSE] = ACTIONS(9808),
    [anon_sym_POUNDElse] = ACTIONS(9808),
    [anon_sym_POUNDendif] = ACTIONS(9808),
    [anon_sym_POUNDENDIF] = ACTIONS(9808),
    [anon_sym_POUNDEndif] = ACTIONS(9808),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9808),
    [sym_trigger_keyword] = ACTIONS(9808),
    [sym_var_keyword] = ACTIONS(9808),
    [sym_local_keyword] = ACTIONS(9808),
    [sym_internal_keyword] = ACTIONS(9808),
    [sym_protected_keyword] = ACTIONS(9808),
    [sym_event_keyword] = ACTIONS(9808),
    [sym_fields_keyword] = ACTIONS(9808),
    [sym_keys_keyword] = ACTIONS(9808),
    [sym_fieldgroups_keyword] = ACTIONS(9808),
    [sym_actions_keyword] = ACTIONS(9808),
    [sym_layout_keyword] = ACTIONS(9808),
    [sym_area_keyword] = ACTIONS(9808),
    [sym_group_keyword] = ACTIONS(9808),
    [sym_repeater_keyword] = ACTIONS(9808),
    [sym_cuegroup_keyword] = ACTIONS(9808),
    [sym_fixed_keyword] = ACTIONS(9808),
    [sym_grid_keyword] = ACTIONS(9808),
    [sym_part_keyword] = ACTIONS(9808),
    [sym_systempart_keyword] = ACTIONS(9808),
    [sym_usercontrol_keyword] = ACTIONS(9808),
    [sym_dataset_keyword] = ACTIONS(9808),
    [sym_elements_keyword] = ACTIONS(9808),
    [sym_dataitem_keyword] = ACTIONS(9808),
    [sym_column_keyword] = ACTIONS(9808),
    [sym_filter_keyword] = ACTIONS(9808),
    [sym_labels_keyword] = ACTIONS(9808),
    [sym_rendering_keyword] = ACTIONS(9808),
    [sym_requestpage_keyword] = ACTIONS(9808),
    [sym_schema_keyword] = ACTIONS(9808),
    [sym_views_keyword] = ACTIONS(9808),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9808),
    [sym_preproc_open] = ACTIONS(9808),
    [sym_preproc_close] = ACTIONS(9808),
  },
  [STATE(3673)] = {
    [anon_sym_SEMI] = ACTIONS(9808),
    [aux_sym_where_condition_token1] = ACTIONS(9810),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9808),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9808),
    [anon_sym_LBRACK] = ACTIONS(9808),
    [aux_sym_basic_type_token6] = ACTIONS(9810),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9808),
    [aux_sym_addafter_modification_token1] = ACTIONS(9808),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9808),
    [aux_sym_modify_modification_token1] = ACTIONS(9808),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9808),
    [aux_sym_movelast_modification_token1] = ACTIONS(9808),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9808),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9808),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9808),
    [anon_sym_POUNDif] = ACTIONS(9808),
    [anon_sym_POUNDIF] = ACTIONS(9808),
    [anon_sym_POUNDIf] = ACTIONS(9808),
    [anon_sym_POUNDelif] = ACTIONS(9808),
    [anon_sym_POUNDELIF] = ACTIONS(9808),
    [anon_sym_POUNDElif] = ACTIONS(9808),
    [anon_sym_POUNDelse] = ACTIONS(9808),
    [anon_sym_POUNDELSE] = ACTIONS(9808),
    [anon_sym_POUNDElse] = ACTIONS(9808),
    [anon_sym_POUNDendif] = ACTIONS(9808),
    [anon_sym_POUNDENDIF] = ACTIONS(9808),
    [anon_sym_POUNDEndif] = ACTIONS(9808),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9808),
    [sym_trigger_keyword] = ACTIONS(9808),
    [sym_var_keyword] = ACTIONS(9808),
    [sym_local_keyword] = ACTIONS(9808),
    [sym_internal_keyword] = ACTIONS(9808),
    [sym_protected_keyword] = ACTIONS(9808),
    [sym_event_keyword] = ACTIONS(9808),
    [sym_fields_keyword] = ACTIONS(9808),
    [sym_keys_keyword] = ACTIONS(9808),
    [sym_fieldgroups_keyword] = ACTIONS(9808),
    [sym_actions_keyword] = ACTIONS(9808),
    [sym_layout_keyword] = ACTIONS(9808),
    [sym_area_keyword] = ACTIONS(9808),
    [sym_group_keyword] = ACTIONS(9808),
    [sym_repeater_keyword] = ACTIONS(9808),
    [sym_cuegroup_keyword] = ACTIONS(9808),
    [sym_fixed_keyword] = ACTIONS(9808),
    [sym_grid_keyword] = ACTIONS(9808),
    [sym_part_keyword] = ACTIONS(9808),
    [sym_systempart_keyword] = ACTIONS(9808),
    [sym_usercontrol_keyword] = ACTIONS(9808),
    [sym_dataset_keyword] = ACTIONS(9808),
    [sym_elements_keyword] = ACTIONS(9808),
    [sym_dataitem_keyword] = ACTIONS(9808),
    [sym_column_keyword] = ACTIONS(9808),
    [sym_filter_keyword] = ACTIONS(9808),
    [sym_labels_keyword] = ACTIONS(9808),
    [sym_rendering_keyword] = ACTIONS(9808),
    [sym_requestpage_keyword] = ACTIONS(9808),
    [sym_schema_keyword] = ACTIONS(9808),
    [sym_views_keyword] = ACTIONS(9808),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9808),
    [sym_preproc_open] = ACTIONS(9808),
    [sym_preproc_close] = ACTIONS(9808),
  },
  [STATE(3674)] = {
    [anon_sym_SEMI] = ACTIONS(9808),
    [aux_sym_where_condition_token1] = ACTIONS(9810),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9808),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9808),
    [anon_sym_LBRACK] = ACTIONS(9808),
    [aux_sym_basic_type_token6] = ACTIONS(9810),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9808),
    [aux_sym_addafter_modification_token1] = ACTIONS(9808),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9808),
    [aux_sym_modify_modification_token1] = ACTIONS(9808),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9808),
    [aux_sym_movelast_modification_token1] = ACTIONS(9808),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9808),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9808),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9808),
    [anon_sym_POUNDif] = ACTIONS(9808),
    [anon_sym_POUNDIF] = ACTIONS(9808),
    [anon_sym_POUNDIf] = ACTIONS(9808),
    [anon_sym_POUNDelif] = ACTIONS(9808),
    [anon_sym_POUNDELIF] = ACTIONS(9808),
    [anon_sym_POUNDElif] = ACTIONS(9808),
    [anon_sym_POUNDelse] = ACTIONS(9808),
    [anon_sym_POUNDELSE] = ACTIONS(9808),
    [anon_sym_POUNDElse] = ACTIONS(9808),
    [anon_sym_POUNDendif] = ACTIONS(9808),
    [anon_sym_POUNDENDIF] = ACTIONS(9808),
    [anon_sym_POUNDEndif] = ACTIONS(9808),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9808),
    [sym_trigger_keyword] = ACTIONS(9808),
    [sym_var_keyword] = ACTIONS(9808),
    [sym_local_keyword] = ACTIONS(9808),
    [sym_internal_keyword] = ACTIONS(9808),
    [sym_protected_keyword] = ACTIONS(9808),
    [sym_event_keyword] = ACTIONS(9808),
    [sym_fields_keyword] = ACTIONS(9808),
    [sym_keys_keyword] = ACTIONS(9808),
    [sym_fieldgroups_keyword] = ACTIONS(9808),
    [sym_actions_keyword] = ACTIONS(9808),
    [sym_layout_keyword] = ACTIONS(9808),
    [sym_area_keyword] = ACTIONS(9808),
    [sym_group_keyword] = ACTIONS(9808),
    [sym_repeater_keyword] = ACTIONS(9808),
    [sym_cuegroup_keyword] = ACTIONS(9808),
    [sym_fixed_keyword] = ACTIONS(9808),
    [sym_grid_keyword] = ACTIONS(9808),
    [sym_part_keyword] = ACTIONS(9808),
    [sym_systempart_keyword] = ACTIONS(9808),
    [sym_usercontrol_keyword] = ACTIONS(9808),
    [sym_dataset_keyword] = ACTIONS(9808),
    [sym_elements_keyword] = ACTIONS(9808),
    [sym_dataitem_keyword] = ACTIONS(9808),
    [sym_column_keyword] = ACTIONS(9808),
    [sym_filter_keyword] = ACTIONS(9808),
    [sym_labels_keyword] = ACTIONS(9808),
    [sym_rendering_keyword] = ACTIONS(9808),
    [sym_requestpage_keyword] = ACTIONS(9808),
    [sym_schema_keyword] = ACTIONS(9808),
    [sym_views_keyword] = ACTIONS(9808),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9808),
    [sym_preproc_open] = ACTIONS(9808),
    [sym_preproc_close] = ACTIONS(9808),
  },
  [STATE(3675)] = {
    [anon_sym_SEMI] = ACTIONS(9808),
    [aux_sym_where_condition_token1] = ACTIONS(9810),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9808),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9808),
    [anon_sym_LBRACK] = ACTIONS(9808),
    [aux_sym_basic_type_token6] = ACTIONS(9810),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9808),
    [aux_sym_addafter_modification_token1] = ACTIONS(9808),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9808),
    [aux_sym_modify_modification_token1] = ACTIONS(9808),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9808),
    [aux_sym_movelast_modification_token1] = ACTIONS(9808),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9808),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9808),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9808),
    [anon_sym_POUNDif] = ACTIONS(9808),
    [anon_sym_POUNDIF] = ACTIONS(9808),
    [anon_sym_POUNDIf] = ACTIONS(9808),
    [anon_sym_POUNDelif] = ACTIONS(9808),
    [anon_sym_POUNDELIF] = ACTIONS(9808),
    [anon_sym_POUNDElif] = ACTIONS(9808),
    [anon_sym_POUNDelse] = ACTIONS(9808),
    [anon_sym_POUNDELSE] = ACTIONS(9808),
    [anon_sym_POUNDElse] = ACTIONS(9808),
    [anon_sym_POUNDendif] = ACTIONS(9808),
    [anon_sym_POUNDENDIF] = ACTIONS(9808),
    [anon_sym_POUNDEndif] = ACTIONS(9808),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9808),
    [sym_trigger_keyword] = ACTIONS(9808),
    [sym_var_keyword] = ACTIONS(9808),
    [sym_local_keyword] = ACTIONS(9808),
    [sym_internal_keyword] = ACTIONS(9808),
    [sym_protected_keyword] = ACTIONS(9808),
    [sym_event_keyword] = ACTIONS(9808),
    [sym_fields_keyword] = ACTIONS(9808),
    [sym_keys_keyword] = ACTIONS(9808),
    [sym_fieldgroups_keyword] = ACTIONS(9808),
    [sym_actions_keyword] = ACTIONS(9808),
    [sym_layout_keyword] = ACTIONS(9808),
    [sym_area_keyword] = ACTIONS(9808),
    [sym_group_keyword] = ACTIONS(9808),
    [sym_repeater_keyword] = ACTIONS(9808),
    [sym_cuegroup_keyword] = ACTIONS(9808),
    [sym_fixed_keyword] = ACTIONS(9808),
    [sym_grid_keyword] = ACTIONS(9808),
    [sym_part_keyword] = ACTIONS(9808),
    [sym_systempart_keyword] = ACTIONS(9808),
    [sym_usercontrol_keyword] = ACTIONS(9808),
    [sym_dataset_keyword] = ACTIONS(9808),
    [sym_elements_keyword] = ACTIONS(9808),
    [sym_dataitem_keyword] = ACTIONS(9808),
    [sym_column_keyword] = ACTIONS(9808),
    [sym_filter_keyword] = ACTIONS(9808),
    [sym_labels_keyword] = ACTIONS(9808),
    [sym_rendering_keyword] = ACTIONS(9808),
    [sym_requestpage_keyword] = ACTIONS(9808),
    [sym_schema_keyword] = ACTIONS(9808),
    [sym_views_keyword] = ACTIONS(9808),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9808),
    [sym_preproc_open] = ACTIONS(9808),
    [sym_preproc_close] = ACTIONS(9808),
  },
  [STATE(3676)] = {
    [anon_sym_SEMI] = ACTIONS(9812),
    [aux_sym_where_condition_token1] = ACTIONS(9814),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9812),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9812),
    [anon_sym_LBRACK] = ACTIONS(9812),
    [aux_sym_basic_type_token6] = ACTIONS(9814),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9812),
    [aux_sym_addafter_modification_token1] = ACTIONS(9812),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9812),
    [aux_sym_modify_modification_token1] = ACTIONS(9812),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9812),
    [aux_sym_movelast_modification_token1] = ACTIONS(9812),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9812),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9812),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9812),
    [anon_sym_POUNDif] = ACTIONS(9812),
    [anon_sym_POUNDIF] = ACTIONS(9812),
    [anon_sym_POUNDIf] = ACTIONS(9812),
    [anon_sym_POUNDelif] = ACTIONS(9812),
    [anon_sym_POUNDELIF] = ACTIONS(9812),
    [anon_sym_POUNDElif] = ACTIONS(9812),
    [anon_sym_POUNDelse] = ACTIONS(9812),
    [anon_sym_POUNDELSE] = ACTIONS(9812),
    [anon_sym_POUNDElse] = ACTIONS(9812),
    [anon_sym_POUNDendif] = ACTIONS(9812),
    [anon_sym_POUNDENDIF] = ACTIONS(9812),
    [anon_sym_POUNDEndif] = ACTIONS(9812),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9812),
    [sym_trigger_keyword] = ACTIONS(9812),
    [sym_var_keyword] = ACTIONS(9812),
    [sym_local_keyword] = ACTIONS(9812),
    [sym_internal_keyword] = ACTIONS(9812),
    [sym_protected_keyword] = ACTIONS(9812),
    [sym_event_keyword] = ACTIONS(9812),
    [sym_fields_keyword] = ACTIONS(9812),
    [sym_keys_keyword] = ACTIONS(9812),
    [sym_fieldgroups_keyword] = ACTIONS(9812),
    [sym_actions_keyword] = ACTIONS(9812),
    [sym_layout_keyword] = ACTIONS(9812),
    [sym_area_keyword] = ACTIONS(9812),
    [sym_group_keyword] = ACTIONS(9812),
    [sym_repeater_keyword] = ACTIONS(9812),
    [sym_cuegroup_keyword] = ACTIONS(9812),
    [sym_fixed_keyword] = ACTIONS(9812),
    [sym_grid_keyword] = ACTIONS(9812),
    [sym_part_keyword] = ACTIONS(9812),
    [sym_systempart_keyword] = ACTIONS(9812),
    [sym_usercontrol_keyword] = ACTIONS(9812),
    [sym_dataset_keyword] = ACTIONS(9812),
    [sym_elements_keyword] = ACTIONS(9812),
    [sym_dataitem_keyword] = ACTIONS(9812),
    [sym_column_keyword] = ACTIONS(9812),
    [sym_filter_keyword] = ACTIONS(9812),
    [sym_labels_keyword] = ACTIONS(9812),
    [sym_rendering_keyword] = ACTIONS(9812),
    [sym_requestpage_keyword] = ACTIONS(9812),
    [sym_schema_keyword] = ACTIONS(9812),
    [sym_views_keyword] = ACTIONS(9812),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9812),
    [sym_preproc_open] = ACTIONS(9812),
    [sym_preproc_close] = ACTIONS(9812),
  },
  [STATE(3677)] = {
    [anon_sym_SEMI] = ACTIONS(9812),
    [aux_sym_where_condition_token1] = ACTIONS(9814),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9812),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9812),
    [anon_sym_LBRACK] = ACTIONS(9812),
    [aux_sym_basic_type_token6] = ACTIONS(9814),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9812),
    [aux_sym_addafter_modification_token1] = ACTIONS(9812),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9812),
    [aux_sym_modify_modification_token1] = ACTIONS(9812),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9812),
    [aux_sym_movelast_modification_token1] = ACTIONS(9812),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9812),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9812),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9812),
    [anon_sym_POUNDif] = ACTIONS(9812),
    [anon_sym_POUNDIF] = ACTIONS(9812),
    [anon_sym_POUNDIf] = ACTIONS(9812),
    [anon_sym_POUNDelif] = ACTIONS(9812),
    [anon_sym_POUNDELIF] = ACTIONS(9812),
    [anon_sym_POUNDElif] = ACTIONS(9812),
    [anon_sym_POUNDelse] = ACTIONS(9812),
    [anon_sym_POUNDELSE] = ACTIONS(9812),
    [anon_sym_POUNDElse] = ACTIONS(9812),
    [anon_sym_POUNDendif] = ACTIONS(9812),
    [anon_sym_POUNDENDIF] = ACTIONS(9812),
    [anon_sym_POUNDEndif] = ACTIONS(9812),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9812),
    [sym_trigger_keyword] = ACTIONS(9812),
    [sym_var_keyword] = ACTIONS(9812),
    [sym_local_keyword] = ACTIONS(9812),
    [sym_internal_keyword] = ACTIONS(9812),
    [sym_protected_keyword] = ACTIONS(9812),
    [sym_event_keyword] = ACTIONS(9812),
    [sym_fields_keyword] = ACTIONS(9812),
    [sym_keys_keyword] = ACTIONS(9812),
    [sym_fieldgroups_keyword] = ACTIONS(9812),
    [sym_actions_keyword] = ACTIONS(9812),
    [sym_layout_keyword] = ACTIONS(9812),
    [sym_area_keyword] = ACTIONS(9812),
    [sym_group_keyword] = ACTIONS(9812),
    [sym_repeater_keyword] = ACTIONS(9812),
    [sym_cuegroup_keyword] = ACTIONS(9812),
    [sym_fixed_keyword] = ACTIONS(9812),
    [sym_grid_keyword] = ACTIONS(9812),
    [sym_part_keyword] = ACTIONS(9812),
    [sym_systempart_keyword] = ACTIONS(9812),
    [sym_usercontrol_keyword] = ACTIONS(9812),
    [sym_dataset_keyword] = ACTIONS(9812),
    [sym_elements_keyword] = ACTIONS(9812),
    [sym_dataitem_keyword] = ACTIONS(9812),
    [sym_column_keyword] = ACTIONS(9812),
    [sym_filter_keyword] = ACTIONS(9812),
    [sym_labels_keyword] = ACTIONS(9812),
    [sym_rendering_keyword] = ACTIONS(9812),
    [sym_requestpage_keyword] = ACTIONS(9812),
    [sym_schema_keyword] = ACTIONS(9812),
    [sym_views_keyword] = ACTIONS(9812),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9812),
    [sym_preproc_open] = ACTIONS(9812),
    [sym_preproc_close] = ACTIONS(9812),
  },
  [STATE(3678)] = {
    [anon_sym_SEMI] = ACTIONS(9816),
    [aux_sym_where_condition_token1] = ACTIONS(9818),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9816),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9816),
    [anon_sym_LBRACK] = ACTIONS(9816),
    [aux_sym_basic_type_token6] = ACTIONS(9818),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9816),
    [aux_sym_addafter_modification_token1] = ACTIONS(9816),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9816),
    [aux_sym_modify_modification_token1] = ACTIONS(9816),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9816),
    [aux_sym_movelast_modification_token1] = ACTIONS(9816),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9816),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9816),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9816),
    [anon_sym_POUNDif] = ACTIONS(9816),
    [anon_sym_POUNDIF] = ACTIONS(9816),
    [anon_sym_POUNDIf] = ACTIONS(9816),
    [anon_sym_POUNDelif] = ACTIONS(9816),
    [anon_sym_POUNDELIF] = ACTIONS(9816),
    [anon_sym_POUNDElif] = ACTIONS(9816),
    [anon_sym_POUNDelse] = ACTIONS(9816),
    [anon_sym_POUNDELSE] = ACTIONS(9816),
    [anon_sym_POUNDElse] = ACTIONS(9816),
    [anon_sym_POUNDendif] = ACTIONS(9816),
    [anon_sym_POUNDENDIF] = ACTIONS(9816),
    [anon_sym_POUNDEndif] = ACTIONS(9816),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9816),
    [sym_trigger_keyword] = ACTIONS(9816),
    [sym_var_keyword] = ACTIONS(9816),
    [sym_local_keyword] = ACTIONS(9816),
    [sym_internal_keyword] = ACTIONS(9816),
    [sym_protected_keyword] = ACTIONS(9816),
    [sym_event_keyword] = ACTIONS(9816),
    [sym_fields_keyword] = ACTIONS(9816),
    [sym_keys_keyword] = ACTIONS(9816),
    [sym_fieldgroups_keyword] = ACTIONS(9816),
    [sym_actions_keyword] = ACTIONS(9816),
    [sym_layout_keyword] = ACTIONS(9816),
    [sym_area_keyword] = ACTIONS(9816),
    [sym_group_keyword] = ACTIONS(9816),
    [sym_repeater_keyword] = ACTIONS(9816),
    [sym_cuegroup_keyword] = ACTIONS(9816),
    [sym_fixed_keyword] = ACTIONS(9816),
    [sym_grid_keyword] = ACTIONS(9816),
    [sym_part_keyword] = ACTIONS(9816),
    [sym_systempart_keyword] = ACTIONS(9816),
    [sym_usercontrol_keyword] = ACTIONS(9816),
    [sym_dataset_keyword] = ACTIONS(9816),
    [sym_elements_keyword] = ACTIONS(9816),
    [sym_dataitem_keyword] = ACTIONS(9816),
    [sym_column_keyword] = ACTIONS(9816),
    [sym_filter_keyword] = ACTIONS(9816),
    [sym_labels_keyword] = ACTIONS(9816),
    [sym_rendering_keyword] = ACTIONS(9816),
    [sym_requestpage_keyword] = ACTIONS(9816),
    [sym_schema_keyword] = ACTIONS(9816),
    [sym_views_keyword] = ACTIONS(9816),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9816),
    [sym_preproc_open] = ACTIONS(9816),
    [sym_preproc_close] = ACTIONS(9816),
  },
  [STATE(3679)] = {
    [anon_sym_SEMI] = ACTIONS(9816),
    [aux_sym_where_condition_token1] = ACTIONS(9818),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9816),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9816),
    [anon_sym_LBRACK] = ACTIONS(9816),
    [aux_sym_basic_type_token6] = ACTIONS(9818),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9816),
    [aux_sym_addafter_modification_token1] = ACTIONS(9816),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9816),
    [aux_sym_modify_modification_token1] = ACTIONS(9816),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9816),
    [aux_sym_movelast_modification_token1] = ACTIONS(9816),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9816),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9816),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9816),
    [anon_sym_POUNDif] = ACTIONS(9816),
    [anon_sym_POUNDIF] = ACTIONS(9816),
    [anon_sym_POUNDIf] = ACTIONS(9816),
    [anon_sym_POUNDelif] = ACTIONS(9816),
    [anon_sym_POUNDELIF] = ACTIONS(9816),
    [anon_sym_POUNDElif] = ACTIONS(9816),
    [anon_sym_POUNDelse] = ACTIONS(9816),
    [anon_sym_POUNDELSE] = ACTIONS(9816),
    [anon_sym_POUNDElse] = ACTIONS(9816),
    [anon_sym_POUNDendif] = ACTIONS(9816),
    [anon_sym_POUNDENDIF] = ACTIONS(9816),
    [anon_sym_POUNDEndif] = ACTIONS(9816),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9816),
    [sym_trigger_keyword] = ACTIONS(9816),
    [sym_var_keyword] = ACTIONS(9816),
    [sym_local_keyword] = ACTIONS(9816),
    [sym_internal_keyword] = ACTIONS(9816),
    [sym_protected_keyword] = ACTIONS(9816),
    [sym_event_keyword] = ACTIONS(9816),
    [sym_fields_keyword] = ACTIONS(9816),
    [sym_keys_keyword] = ACTIONS(9816),
    [sym_fieldgroups_keyword] = ACTIONS(9816),
    [sym_actions_keyword] = ACTIONS(9816),
    [sym_layout_keyword] = ACTIONS(9816),
    [sym_area_keyword] = ACTIONS(9816),
    [sym_group_keyword] = ACTIONS(9816),
    [sym_repeater_keyword] = ACTIONS(9816),
    [sym_cuegroup_keyword] = ACTIONS(9816),
    [sym_fixed_keyword] = ACTIONS(9816),
    [sym_grid_keyword] = ACTIONS(9816),
    [sym_part_keyword] = ACTIONS(9816),
    [sym_systempart_keyword] = ACTIONS(9816),
    [sym_usercontrol_keyword] = ACTIONS(9816),
    [sym_dataset_keyword] = ACTIONS(9816),
    [sym_elements_keyword] = ACTIONS(9816),
    [sym_dataitem_keyword] = ACTIONS(9816),
    [sym_column_keyword] = ACTIONS(9816),
    [sym_filter_keyword] = ACTIONS(9816),
    [sym_labels_keyword] = ACTIONS(9816),
    [sym_rendering_keyword] = ACTIONS(9816),
    [sym_requestpage_keyword] = ACTIONS(9816),
    [sym_schema_keyword] = ACTIONS(9816),
    [sym_views_keyword] = ACTIONS(9816),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9816),
    [sym_preproc_open] = ACTIONS(9816),
    [sym_preproc_close] = ACTIONS(9816),
  },
  [STATE(3680)] = {
    [anon_sym_SEMI] = ACTIONS(9820),
    [aux_sym_where_condition_token1] = ACTIONS(9822),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9820),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9820),
    [anon_sym_LBRACK] = ACTIONS(9820),
    [aux_sym_basic_type_token6] = ACTIONS(9822),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9820),
    [aux_sym_addafter_modification_token1] = ACTIONS(9820),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9820),
    [aux_sym_modify_modification_token1] = ACTIONS(9820),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9820),
    [aux_sym_movelast_modification_token1] = ACTIONS(9820),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9820),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9820),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9820),
    [anon_sym_POUNDif] = ACTIONS(9820),
    [anon_sym_POUNDIF] = ACTIONS(9820),
    [anon_sym_POUNDIf] = ACTIONS(9820),
    [anon_sym_POUNDelif] = ACTIONS(9820),
    [anon_sym_POUNDELIF] = ACTIONS(9820),
    [anon_sym_POUNDElif] = ACTIONS(9820),
    [anon_sym_POUNDelse] = ACTIONS(9820),
    [anon_sym_POUNDELSE] = ACTIONS(9820),
    [anon_sym_POUNDElse] = ACTIONS(9820),
    [anon_sym_POUNDendif] = ACTIONS(9820),
    [anon_sym_POUNDENDIF] = ACTIONS(9820),
    [anon_sym_POUNDEndif] = ACTIONS(9820),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9820),
    [sym_trigger_keyword] = ACTIONS(9820),
    [sym_var_keyword] = ACTIONS(9820),
    [sym_local_keyword] = ACTIONS(9820),
    [sym_internal_keyword] = ACTIONS(9820),
    [sym_protected_keyword] = ACTIONS(9820),
    [sym_event_keyword] = ACTIONS(9820),
    [sym_fields_keyword] = ACTIONS(9820),
    [sym_keys_keyword] = ACTIONS(9820),
    [sym_fieldgroups_keyword] = ACTIONS(9820),
    [sym_actions_keyword] = ACTIONS(9820),
    [sym_layout_keyword] = ACTIONS(9820),
    [sym_area_keyword] = ACTIONS(9820),
    [sym_group_keyword] = ACTIONS(9820),
    [sym_repeater_keyword] = ACTIONS(9820),
    [sym_cuegroup_keyword] = ACTIONS(9820),
    [sym_fixed_keyword] = ACTIONS(9820),
    [sym_grid_keyword] = ACTIONS(9820),
    [sym_part_keyword] = ACTIONS(9820),
    [sym_systempart_keyword] = ACTIONS(9820),
    [sym_usercontrol_keyword] = ACTIONS(9820),
    [sym_dataset_keyword] = ACTIONS(9820),
    [sym_elements_keyword] = ACTIONS(9820),
    [sym_dataitem_keyword] = ACTIONS(9820),
    [sym_column_keyword] = ACTIONS(9820),
    [sym_filter_keyword] = ACTIONS(9820),
    [sym_labels_keyword] = ACTIONS(9820),
    [sym_rendering_keyword] = ACTIONS(9820),
    [sym_requestpage_keyword] = ACTIONS(9820),
    [sym_schema_keyword] = ACTIONS(9820),
    [sym_views_keyword] = ACTIONS(9820),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9820),
    [sym_preproc_open] = ACTIONS(9820),
    [sym_preproc_close] = ACTIONS(9820),
  },
  [STATE(3681)] = {
    [anon_sym_SEMI] = ACTIONS(9824),
    [aux_sym_where_condition_token1] = ACTIONS(9826),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9828),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9828),
    [anon_sym_LBRACK] = ACTIONS(9828),
    [aux_sym_basic_type_token6] = ACTIONS(9826),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9828),
    [aux_sym_addafter_modification_token1] = ACTIONS(9828),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9828),
    [aux_sym_modify_modification_token1] = ACTIONS(9828),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9828),
    [aux_sym_movelast_modification_token1] = ACTIONS(9828),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9828),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9828),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9828),
    [anon_sym_POUNDif] = ACTIONS(9828),
    [anon_sym_POUNDIF] = ACTIONS(9828),
    [anon_sym_POUNDIf] = ACTIONS(9828),
    [anon_sym_POUNDelif] = ACTIONS(9828),
    [anon_sym_POUNDELIF] = ACTIONS(9828),
    [anon_sym_POUNDElif] = ACTIONS(9828),
    [anon_sym_POUNDelse] = ACTIONS(9828),
    [anon_sym_POUNDELSE] = ACTIONS(9828),
    [anon_sym_POUNDElse] = ACTIONS(9828),
    [anon_sym_POUNDendif] = ACTIONS(9828),
    [anon_sym_POUNDENDIF] = ACTIONS(9828),
    [anon_sym_POUNDEndif] = ACTIONS(9828),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9828),
    [sym_trigger_keyword] = ACTIONS(9828),
    [sym_var_keyword] = ACTIONS(9828),
    [sym_local_keyword] = ACTIONS(9828),
    [sym_internal_keyword] = ACTIONS(9828),
    [sym_protected_keyword] = ACTIONS(9828),
    [sym_event_keyword] = ACTIONS(9828),
    [sym_fields_keyword] = ACTIONS(9828),
    [sym_keys_keyword] = ACTIONS(9828),
    [sym_fieldgroups_keyword] = ACTIONS(9828),
    [sym_actions_keyword] = ACTIONS(9828),
    [sym_layout_keyword] = ACTIONS(9828),
    [sym_area_keyword] = ACTIONS(9828),
    [sym_group_keyword] = ACTIONS(9828),
    [sym_repeater_keyword] = ACTIONS(9828),
    [sym_cuegroup_keyword] = ACTIONS(9828),
    [sym_fixed_keyword] = ACTIONS(9828),
    [sym_grid_keyword] = ACTIONS(9828),
    [sym_part_keyword] = ACTIONS(9828),
    [sym_systempart_keyword] = ACTIONS(9828),
    [sym_usercontrol_keyword] = ACTIONS(9828),
    [sym_dataset_keyword] = ACTIONS(9828),
    [sym_elements_keyword] = ACTIONS(9828),
    [sym_dataitem_keyword] = ACTIONS(9828),
    [sym_column_keyword] = ACTIONS(9828),
    [sym_filter_keyword] = ACTIONS(9828),
    [sym_labels_keyword] = ACTIONS(9828),
    [sym_rendering_keyword] = ACTIONS(9828),
    [sym_requestpage_keyword] = ACTIONS(9828),
    [sym_schema_keyword] = ACTIONS(9828),
    [sym_views_keyword] = ACTIONS(9828),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9828),
    [sym_preproc_open] = ACTIONS(9828),
    [sym_preproc_close] = ACTIONS(9828),
  },
  [STATE(3682)] = {
    [anon_sym_SEMI] = ACTIONS(9830),
    [aux_sym_where_condition_token1] = ACTIONS(9832),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9830),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9830),
    [anon_sym_LBRACK] = ACTIONS(9830),
    [aux_sym_basic_type_token6] = ACTIONS(9832),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9830),
    [aux_sym_addafter_modification_token1] = ACTIONS(9830),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9830),
    [aux_sym_modify_modification_token1] = ACTIONS(9830),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9830),
    [aux_sym_movelast_modification_token1] = ACTIONS(9830),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9830),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9830),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9830),
    [anon_sym_POUNDif] = ACTIONS(9830),
    [anon_sym_POUNDIF] = ACTIONS(9830),
    [anon_sym_POUNDIf] = ACTIONS(9830),
    [anon_sym_POUNDelif] = ACTIONS(9830),
    [anon_sym_POUNDELIF] = ACTIONS(9830),
    [anon_sym_POUNDElif] = ACTIONS(9830),
    [anon_sym_POUNDelse] = ACTIONS(9830),
    [anon_sym_POUNDELSE] = ACTIONS(9830),
    [anon_sym_POUNDElse] = ACTIONS(9830),
    [anon_sym_POUNDendif] = ACTIONS(9830),
    [anon_sym_POUNDENDIF] = ACTIONS(9830),
    [anon_sym_POUNDEndif] = ACTIONS(9830),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9830),
    [sym_trigger_keyword] = ACTIONS(9830),
    [sym_var_keyword] = ACTIONS(9830),
    [sym_local_keyword] = ACTIONS(9830),
    [sym_internal_keyword] = ACTIONS(9830),
    [sym_protected_keyword] = ACTIONS(9830),
    [sym_event_keyword] = ACTIONS(9830),
    [sym_fields_keyword] = ACTIONS(9830),
    [sym_keys_keyword] = ACTIONS(9830),
    [sym_fieldgroups_keyword] = ACTIONS(9830),
    [sym_actions_keyword] = ACTIONS(9830),
    [sym_layout_keyword] = ACTIONS(9830),
    [sym_area_keyword] = ACTIONS(9830),
    [sym_group_keyword] = ACTIONS(9830),
    [sym_repeater_keyword] = ACTIONS(9830),
    [sym_cuegroup_keyword] = ACTIONS(9830),
    [sym_fixed_keyword] = ACTIONS(9830),
    [sym_grid_keyword] = ACTIONS(9830),
    [sym_part_keyword] = ACTIONS(9830),
    [sym_systempart_keyword] = ACTIONS(9830),
    [sym_usercontrol_keyword] = ACTIONS(9830),
    [sym_dataset_keyword] = ACTIONS(9830),
    [sym_elements_keyword] = ACTIONS(9830),
    [sym_dataitem_keyword] = ACTIONS(9830),
    [sym_column_keyword] = ACTIONS(9830),
    [sym_filter_keyword] = ACTIONS(9830),
    [sym_labels_keyword] = ACTIONS(9830),
    [sym_rendering_keyword] = ACTIONS(9830),
    [sym_requestpage_keyword] = ACTIONS(9830),
    [sym_schema_keyword] = ACTIONS(9830),
    [sym_views_keyword] = ACTIONS(9830),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9830),
    [sym_preproc_open] = ACTIONS(9830),
    [sym_preproc_close] = ACTIONS(9830),
  },
  [STATE(3683)] = {
    [anon_sym_SEMI] = ACTIONS(9834),
    [aux_sym_where_condition_token1] = ACTIONS(9836),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9834),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9834),
    [anon_sym_LBRACK] = ACTIONS(9834),
    [aux_sym_basic_type_token6] = ACTIONS(9836),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9834),
    [aux_sym_addafter_modification_token1] = ACTIONS(9834),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9834),
    [aux_sym_modify_modification_token1] = ACTIONS(9834),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9834),
    [aux_sym_movelast_modification_token1] = ACTIONS(9834),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9834),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9834),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9834),
    [anon_sym_POUNDif] = ACTIONS(9834),
    [anon_sym_POUNDIF] = ACTIONS(9834),
    [anon_sym_POUNDIf] = ACTIONS(9834),
    [anon_sym_POUNDelif] = ACTIONS(9834),
    [anon_sym_POUNDELIF] = ACTIONS(9834),
    [anon_sym_POUNDElif] = ACTIONS(9834),
    [anon_sym_POUNDelse] = ACTIONS(9834),
    [anon_sym_POUNDELSE] = ACTIONS(9834),
    [anon_sym_POUNDElse] = ACTIONS(9834),
    [anon_sym_POUNDendif] = ACTIONS(9834),
    [anon_sym_POUNDENDIF] = ACTIONS(9834),
    [anon_sym_POUNDEndif] = ACTIONS(9834),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9834),
    [sym_trigger_keyword] = ACTIONS(9834),
    [sym_var_keyword] = ACTIONS(9834),
    [sym_local_keyword] = ACTIONS(9834),
    [sym_internal_keyword] = ACTIONS(9834),
    [sym_protected_keyword] = ACTIONS(9834),
    [sym_event_keyword] = ACTIONS(9834),
    [sym_fields_keyword] = ACTIONS(9834),
    [sym_keys_keyword] = ACTIONS(9834),
    [sym_fieldgroups_keyword] = ACTIONS(9834),
    [sym_actions_keyword] = ACTIONS(9834),
    [sym_layout_keyword] = ACTIONS(9834),
    [sym_area_keyword] = ACTIONS(9834),
    [sym_group_keyword] = ACTIONS(9834),
    [sym_repeater_keyword] = ACTIONS(9834),
    [sym_cuegroup_keyword] = ACTIONS(9834),
    [sym_fixed_keyword] = ACTIONS(9834),
    [sym_grid_keyword] = ACTIONS(9834),
    [sym_part_keyword] = ACTIONS(9834),
    [sym_systempart_keyword] = ACTIONS(9834),
    [sym_usercontrol_keyword] = ACTIONS(9834),
    [sym_dataset_keyword] = ACTIONS(9834),
    [sym_elements_keyword] = ACTIONS(9834),
    [sym_dataitem_keyword] = ACTIONS(9834),
    [sym_column_keyword] = ACTIONS(9834),
    [sym_filter_keyword] = ACTIONS(9834),
    [sym_labels_keyword] = ACTIONS(9834),
    [sym_rendering_keyword] = ACTIONS(9834),
    [sym_requestpage_keyword] = ACTIONS(9834),
    [sym_schema_keyword] = ACTIONS(9834),
    [sym_views_keyword] = ACTIONS(9834),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9834),
    [sym_preproc_open] = ACTIONS(9834),
    [sym_preproc_close] = ACTIONS(9834),
  },
  [STATE(3684)] = {
    [anon_sym_SEMI] = ACTIONS(9838),
    [aux_sym_where_condition_token1] = ACTIONS(9840),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9838),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9838),
    [anon_sym_LBRACK] = ACTIONS(9838),
    [aux_sym_basic_type_token6] = ACTIONS(9840),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9838),
    [aux_sym_addafter_modification_token1] = ACTIONS(9838),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9838),
    [aux_sym_modify_modification_token1] = ACTIONS(9838),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9838),
    [aux_sym_movelast_modification_token1] = ACTIONS(9838),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9838),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9838),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9838),
    [anon_sym_POUNDif] = ACTIONS(9838),
    [anon_sym_POUNDIF] = ACTIONS(9838),
    [anon_sym_POUNDIf] = ACTIONS(9838),
    [anon_sym_POUNDelif] = ACTIONS(9838),
    [anon_sym_POUNDELIF] = ACTIONS(9838),
    [anon_sym_POUNDElif] = ACTIONS(9838),
    [anon_sym_POUNDelse] = ACTIONS(9838),
    [anon_sym_POUNDELSE] = ACTIONS(9838),
    [anon_sym_POUNDElse] = ACTIONS(9838),
    [anon_sym_POUNDendif] = ACTIONS(9838),
    [anon_sym_POUNDENDIF] = ACTIONS(9838),
    [anon_sym_POUNDEndif] = ACTIONS(9838),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9838),
    [sym_trigger_keyword] = ACTIONS(9838),
    [sym_var_keyword] = ACTIONS(9838),
    [sym_local_keyword] = ACTIONS(9838),
    [sym_internal_keyword] = ACTIONS(9838),
    [sym_protected_keyword] = ACTIONS(9838),
    [sym_event_keyword] = ACTIONS(9838),
    [sym_fields_keyword] = ACTIONS(9838),
    [sym_keys_keyword] = ACTIONS(9838),
    [sym_fieldgroups_keyword] = ACTIONS(9838),
    [sym_actions_keyword] = ACTIONS(9838),
    [sym_layout_keyword] = ACTIONS(9838),
    [sym_area_keyword] = ACTIONS(9838),
    [sym_group_keyword] = ACTIONS(9838),
    [sym_repeater_keyword] = ACTIONS(9838),
    [sym_cuegroup_keyword] = ACTIONS(9838),
    [sym_fixed_keyword] = ACTIONS(9838),
    [sym_grid_keyword] = ACTIONS(9838),
    [sym_part_keyword] = ACTIONS(9838),
    [sym_systempart_keyword] = ACTIONS(9838),
    [sym_usercontrol_keyword] = ACTIONS(9838),
    [sym_dataset_keyword] = ACTIONS(9838),
    [sym_elements_keyword] = ACTIONS(9838),
    [sym_dataitem_keyword] = ACTIONS(9838),
    [sym_column_keyword] = ACTIONS(9838),
    [sym_filter_keyword] = ACTIONS(9838),
    [sym_labels_keyword] = ACTIONS(9838),
    [sym_rendering_keyword] = ACTIONS(9838),
    [sym_requestpage_keyword] = ACTIONS(9838),
    [sym_schema_keyword] = ACTIONS(9838),
    [sym_views_keyword] = ACTIONS(9838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9838),
    [sym_preproc_open] = ACTIONS(9838),
    [sym_preproc_close] = ACTIONS(9838),
  },
  [STATE(3685)] = {
    [anon_sym_SEMI] = ACTIONS(9842),
    [aux_sym_where_condition_token1] = ACTIONS(9844),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9842),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9842),
    [anon_sym_LBRACK] = ACTIONS(9842),
    [aux_sym_basic_type_token6] = ACTIONS(9844),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9842),
    [aux_sym_addafter_modification_token1] = ACTIONS(9842),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9842),
    [aux_sym_modify_modification_token1] = ACTIONS(9842),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9842),
    [aux_sym_movelast_modification_token1] = ACTIONS(9842),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9842),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9842),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9842),
    [anon_sym_POUNDif] = ACTIONS(9842),
    [anon_sym_POUNDIF] = ACTIONS(9842),
    [anon_sym_POUNDIf] = ACTIONS(9842),
    [anon_sym_POUNDelif] = ACTIONS(9842),
    [anon_sym_POUNDELIF] = ACTIONS(9842),
    [anon_sym_POUNDElif] = ACTIONS(9842),
    [anon_sym_POUNDelse] = ACTIONS(9842),
    [anon_sym_POUNDELSE] = ACTIONS(9842),
    [anon_sym_POUNDElse] = ACTIONS(9842),
    [anon_sym_POUNDendif] = ACTIONS(9842),
    [anon_sym_POUNDENDIF] = ACTIONS(9842),
    [anon_sym_POUNDEndif] = ACTIONS(9842),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9842),
    [sym_trigger_keyword] = ACTIONS(9842),
    [sym_var_keyword] = ACTIONS(9842),
    [sym_local_keyword] = ACTIONS(9842),
    [sym_internal_keyword] = ACTIONS(9842),
    [sym_protected_keyword] = ACTIONS(9842),
    [sym_event_keyword] = ACTIONS(9842),
    [sym_fields_keyword] = ACTIONS(9842),
    [sym_keys_keyword] = ACTIONS(9842),
    [sym_fieldgroups_keyword] = ACTIONS(9842),
    [sym_actions_keyword] = ACTIONS(9842),
    [sym_layout_keyword] = ACTIONS(9842),
    [sym_area_keyword] = ACTIONS(9842),
    [sym_group_keyword] = ACTIONS(9842),
    [sym_repeater_keyword] = ACTIONS(9842),
    [sym_cuegroup_keyword] = ACTIONS(9842),
    [sym_fixed_keyword] = ACTIONS(9842),
    [sym_grid_keyword] = ACTIONS(9842),
    [sym_part_keyword] = ACTIONS(9842),
    [sym_systempart_keyword] = ACTIONS(9842),
    [sym_usercontrol_keyword] = ACTIONS(9842),
    [sym_dataset_keyword] = ACTIONS(9842),
    [sym_elements_keyword] = ACTIONS(9842),
    [sym_dataitem_keyword] = ACTIONS(9842),
    [sym_column_keyword] = ACTIONS(9842),
    [sym_filter_keyword] = ACTIONS(9842),
    [sym_labels_keyword] = ACTIONS(9842),
    [sym_rendering_keyword] = ACTIONS(9842),
    [sym_requestpage_keyword] = ACTIONS(9842),
    [sym_schema_keyword] = ACTIONS(9842),
    [sym_views_keyword] = ACTIONS(9842),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9842),
    [sym_preproc_open] = ACTIONS(9842),
    [sym_preproc_close] = ACTIONS(9842),
  },
  [STATE(3686)] = {
    [anon_sym_SEMI] = ACTIONS(9846),
    [aux_sym_where_condition_token1] = ACTIONS(9848),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9850),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9850),
    [anon_sym_LBRACK] = ACTIONS(9850),
    [aux_sym_basic_type_token6] = ACTIONS(9848),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9850),
    [aux_sym_addafter_modification_token1] = ACTIONS(9850),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9850),
    [aux_sym_modify_modification_token1] = ACTIONS(9850),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9850),
    [aux_sym_movelast_modification_token1] = ACTIONS(9850),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9850),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9850),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9850),
    [anon_sym_POUNDif] = ACTIONS(9850),
    [anon_sym_POUNDIF] = ACTIONS(9850),
    [anon_sym_POUNDIf] = ACTIONS(9850),
    [anon_sym_POUNDelif] = ACTIONS(9850),
    [anon_sym_POUNDELIF] = ACTIONS(9850),
    [anon_sym_POUNDElif] = ACTIONS(9850),
    [anon_sym_POUNDelse] = ACTIONS(9850),
    [anon_sym_POUNDELSE] = ACTIONS(9850),
    [anon_sym_POUNDElse] = ACTIONS(9850),
    [anon_sym_POUNDendif] = ACTIONS(9850),
    [anon_sym_POUNDENDIF] = ACTIONS(9850),
    [anon_sym_POUNDEndif] = ACTIONS(9850),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9850),
    [sym_trigger_keyword] = ACTIONS(9850),
    [sym_var_keyword] = ACTIONS(9850),
    [sym_local_keyword] = ACTIONS(9850),
    [sym_internal_keyword] = ACTIONS(9850),
    [sym_protected_keyword] = ACTIONS(9850),
    [sym_event_keyword] = ACTIONS(9850),
    [sym_fields_keyword] = ACTIONS(9850),
    [sym_keys_keyword] = ACTIONS(9850),
    [sym_fieldgroups_keyword] = ACTIONS(9850),
    [sym_actions_keyword] = ACTIONS(9850),
    [sym_layout_keyword] = ACTIONS(9850),
    [sym_area_keyword] = ACTIONS(9850),
    [sym_group_keyword] = ACTIONS(9850),
    [sym_repeater_keyword] = ACTIONS(9850),
    [sym_cuegroup_keyword] = ACTIONS(9850),
    [sym_fixed_keyword] = ACTIONS(9850),
    [sym_grid_keyword] = ACTIONS(9850),
    [sym_part_keyword] = ACTIONS(9850),
    [sym_systempart_keyword] = ACTIONS(9850),
    [sym_usercontrol_keyword] = ACTIONS(9850),
    [sym_dataset_keyword] = ACTIONS(9850),
    [sym_elements_keyword] = ACTIONS(9850),
    [sym_dataitem_keyword] = ACTIONS(9850),
    [sym_column_keyword] = ACTIONS(9850),
    [sym_filter_keyword] = ACTIONS(9850),
    [sym_labels_keyword] = ACTIONS(9850),
    [sym_rendering_keyword] = ACTIONS(9850),
    [sym_requestpage_keyword] = ACTIONS(9850),
    [sym_schema_keyword] = ACTIONS(9850),
    [sym_views_keyword] = ACTIONS(9850),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9850),
    [sym_preproc_open] = ACTIONS(9850),
    [sym_preproc_close] = ACTIONS(9850),
  },
  [STATE(3687)] = {
    [anon_sym_SEMI] = ACTIONS(9852),
    [aux_sym_where_condition_token1] = ACTIONS(9848),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9850),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9850),
    [anon_sym_LBRACK] = ACTIONS(9850),
    [aux_sym_basic_type_token6] = ACTIONS(9848),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9850),
    [aux_sym_addafter_modification_token1] = ACTIONS(9850),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9850),
    [aux_sym_modify_modification_token1] = ACTIONS(9850),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9850),
    [aux_sym_movelast_modification_token1] = ACTIONS(9850),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9850),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9850),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9850),
    [anon_sym_POUNDif] = ACTIONS(9850),
    [anon_sym_POUNDIF] = ACTIONS(9850),
    [anon_sym_POUNDIf] = ACTIONS(9850),
    [anon_sym_POUNDelif] = ACTIONS(9850),
    [anon_sym_POUNDELIF] = ACTIONS(9850),
    [anon_sym_POUNDElif] = ACTIONS(9850),
    [anon_sym_POUNDelse] = ACTIONS(9850),
    [anon_sym_POUNDELSE] = ACTIONS(9850),
    [anon_sym_POUNDElse] = ACTIONS(9850),
    [anon_sym_POUNDendif] = ACTIONS(9850),
    [anon_sym_POUNDENDIF] = ACTIONS(9850),
    [anon_sym_POUNDEndif] = ACTIONS(9850),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9850),
    [sym_trigger_keyword] = ACTIONS(9850),
    [sym_var_keyword] = ACTIONS(9850),
    [sym_local_keyword] = ACTIONS(9850),
    [sym_internal_keyword] = ACTIONS(9850),
    [sym_protected_keyword] = ACTIONS(9850),
    [sym_event_keyword] = ACTIONS(9850),
    [sym_fields_keyword] = ACTIONS(9850),
    [sym_keys_keyword] = ACTIONS(9850),
    [sym_fieldgroups_keyword] = ACTIONS(9850),
    [sym_actions_keyword] = ACTIONS(9850),
    [sym_layout_keyword] = ACTIONS(9850),
    [sym_area_keyword] = ACTIONS(9850),
    [sym_group_keyword] = ACTIONS(9850),
    [sym_repeater_keyword] = ACTIONS(9850),
    [sym_cuegroup_keyword] = ACTIONS(9850),
    [sym_fixed_keyword] = ACTIONS(9850),
    [sym_grid_keyword] = ACTIONS(9850),
    [sym_part_keyword] = ACTIONS(9850),
    [sym_systempart_keyword] = ACTIONS(9850),
    [sym_usercontrol_keyword] = ACTIONS(9850),
    [sym_dataset_keyword] = ACTIONS(9850),
    [sym_elements_keyword] = ACTIONS(9850),
    [sym_dataitem_keyword] = ACTIONS(9850),
    [sym_column_keyword] = ACTIONS(9850),
    [sym_filter_keyword] = ACTIONS(9850),
    [sym_labels_keyword] = ACTIONS(9850),
    [sym_rendering_keyword] = ACTIONS(9850),
    [sym_requestpage_keyword] = ACTIONS(9850),
    [sym_schema_keyword] = ACTIONS(9850),
    [sym_views_keyword] = ACTIONS(9850),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9850),
    [sym_preproc_open] = ACTIONS(9850),
    [sym_preproc_close] = ACTIONS(9850),
  },
  [STATE(3688)] = {
    [anon_sym_SEMI] = ACTIONS(9854),
    [aux_sym_where_condition_token1] = ACTIONS(9844),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9842),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9842),
    [anon_sym_LBRACK] = ACTIONS(9842),
    [aux_sym_basic_type_token6] = ACTIONS(9844),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9842),
    [aux_sym_addafter_modification_token1] = ACTIONS(9842),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9842),
    [aux_sym_modify_modification_token1] = ACTIONS(9842),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9842),
    [aux_sym_movelast_modification_token1] = ACTIONS(9842),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9842),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9842),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9842),
    [anon_sym_POUNDif] = ACTIONS(9842),
    [anon_sym_POUNDIF] = ACTIONS(9842),
    [anon_sym_POUNDIf] = ACTIONS(9842),
    [anon_sym_POUNDelif] = ACTIONS(9842),
    [anon_sym_POUNDELIF] = ACTIONS(9842),
    [anon_sym_POUNDElif] = ACTIONS(9842),
    [anon_sym_POUNDelse] = ACTIONS(9842),
    [anon_sym_POUNDELSE] = ACTIONS(9842),
    [anon_sym_POUNDElse] = ACTIONS(9842),
    [anon_sym_POUNDendif] = ACTIONS(9842),
    [anon_sym_POUNDENDIF] = ACTIONS(9842),
    [anon_sym_POUNDEndif] = ACTIONS(9842),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9842),
    [sym_trigger_keyword] = ACTIONS(9842),
    [sym_var_keyword] = ACTIONS(9842),
    [sym_local_keyword] = ACTIONS(9842),
    [sym_internal_keyword] = ACTIONS(9842),
    [sym_protected_keyword] = ACTIONS(9842),
    [sym_event_keyword] = ACTIONS(9842),
    [sym_fields_keyword] = ACTIONS(9842),
    [sym_keys_keyword] = ACTIONS(9842),
    [sym_fieldgroups_keyword] = ACTIONS(9842),
    [sym_actions_keyword] = ACTIONS(9842),
    [sym_layout_keyword] = ACTIONS(9842),
    [sym_area_keyword] = ACTIONS(9842),
    [sym_group_keyword] = ACTIONS(9842),
    [sym_repeater_keyword] = ACTIONS(9842),
    [sym_cuegroup_keyword] = ACTIONS(9842),
    [sym_fixed_keyword] = ACTIONS(9842),
    [sym_grid_keyword] = ACTIONS(9842),
    [sym_part_keyword] = ACTIONS(9842),
    [sym_systempart_keyword] = ACTIONS(9842),
    [sym_usercontrol_keyword] = ACTIONS(9842),
    [sym_dataset_keyword] = ACTIONS(9842),
    [sym_elements_keyword] = ACTIONS(9842),
    [sym_dataitem_keyword] = ACTIONS(9842),
    [sym_column_keyword] = ACTIONS(9842),
    [sym_filter_keyword] = ACTIONS(9842),
    [sym_labels_keyword] = ACTIONS(9842),
    [sym_rendering_keyword] = ACTIONS(9842),
    [sym_requestpage_keyword] = ACTIONS(9842),
    [sym_schema_keyword] = ACTIONS(9842),
    [sym_views_keyword] = ACTIONS(9842),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9842),
    [sym_preproc_open] = ACTIONS(9842),
    [sym_preproc_close] = ACTIONS(9842),
  },
  [STATE(3689)] = {
    [anon_sym_SEMI] = ACTIONS(9856),
    [aux_sym_where_condition_token1] = ACTIONS(9858),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9860),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9860),
    [anon_sym_LBRACK] = ACTIONS(9860),
    [aux_sym_basic_type_token6] = ACTIONS(9858),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9860),
    [aux_sym_addafter_modification_token1] = ACTIONS(9860),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9860),
    [aux_sym_modify_modification_token1] = ACTIONS(9860),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9860),
    [aux_sym_movelast_modification_token1] = ACTIONS(9860),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9860),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9860),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9860),
    [anon_sym_POUNDif] = ACTIONS(9860),
    [anon_sym_POUNDIF] = ACTIONS(9860),
    [anon_sym_POUNDIf] = ACTIONS(9860),
    [anon_sym_POUNDelif] = ACTIONS(9860),
    [anon_sym_POUNDELIF] = ACTIONS(9860),
    [anon_sym_POUNDElif] = ACTIONS(9860),
    [anon_sym_POUNDelse] = ACTIONS(9860),
    [anon_sym_POUNDELSE] = ACTIONS(9860),
    [anon_sym_POUNDElse] = ACTIONS(9860),
    [anon_sym_POUNDendif] = ACTIONS(9860),
    [anon_sym_POUNDENDIF] = ACTIONS(9860),
    [anon_sym_POUNDEndif] = ACTIONS(9860),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9860),
    [sym_trigger_keyword] = ACTIONS(9860),
    [sym_var_keyword] = ACTIONS(9860),
    [sym_local_keyword] = ACTIONS(9860),
    [sym_internal_keyword] = ACTIONS(9860),
    [sym_protected_keyword] = ACTIONS(9860),
    [sym_event_keyword] = ACTIONS(9860),
    [sym_fields_keyword] = ACTIONS(9860),
    [sym_keys_keyword] = ACTIONS(9860),
    [sym_fieldgroups_keyword] = ACTIONS(9860),
    [sym_actions_keyword] = ACTIONS(9860),
    [sym_layout_keyword] = ACTIONS(9860),
    [sym_area_keyword] = ACTIONS(9860),
    [sym_group_keyword] = ACTIONS(9860),
    [sym_repeater_keyword] = ACTIONS(9860),
    [sym_cuegroup_keyword] = ACTIONS(9860),
    [sym_fixed_keyword] = ACTIONS(9860),
    [sym_grid_keyword] = ACTIONS(9860),
    [sym_part_keyword] = ACTIONS(9860),
    [sym_systempart_keyword] = ACTIONS(9860),
    [sym_usercontrol_keyword] = ACTIONS(9860),
    [sym_dataset_keyword] = ACTIONS(9860),
    [sym_elements_keyword] = ACTIONS(9860),
    [sym_dataitem_keyword] = ACTIONS(9860),
    [sym_column_keyword] = ACTIONS(9860),
    [sym_filter_keyword] = ACTIONS(9860),
    [sym_labels_keyword] = ACTIONS(9860),
    [sym_rendering_keyword] = ACTIONS(9860),
    [sym_requestpage_keyword] = ACTIONS(9860),
    [sym_schema_keyword] = ACTIONS(9860),
    [sym_views_keyword] = ACTIONS(9860),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9860),
    [sym_preproc_open] = ACTIONS(9860),
    [sym_preproc_close] = ACTIONS(9860),
  },
  [STATE(3690)] = {
    [anon_sym_SEMI] = ACTIONS(9862),
    [aux_sym_where_condition_token1] = ACTIONS(9858),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9860),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9860),
    [anon_sym_LBRACK] = ACTIONS(9860),
    [aux_sym_basic_type_token6] = ACTIONS(9858),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9860),
    [aux_sym_addafter_modification_token1] = ACTIONS(9860),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9860),
    [aux_sym_modify_modification_token1] = ACTIONS(9860),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9860),
    [aux_sym_movelast_modification_token1] = ACTIONS(9860),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9860),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9860),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9860),
    [anon_sym_POUNDif] = ACTIONS(9860),
    [anon_sym_POUNDIF] = ACTIONS(9860),
    [anon_sym_POUNDIf] = ACTIONS(9860),
    [anon_sym_POUNDelif] = ACTIONS(9860),
    [anon_sym_POUNDELIF] = ACTIONS(9860),
    [anon_sym_POUNDElif] = ACTIONS(9860),
    [anon_sym_POUNDelse] = ACTIONS(9860),
    [anon_sym_POUNDELSE] = ACTIONS(9860),
    [anon_sym_POUNDElse] = ACTIONS(9860),
    [anon_sym_POUNDendif] = ACTIONS(9860),
    [anon_sym_POUNDENDIF] = ACTIONS(9860),
    [anon_sym_POUNDEndif] = ACTIONS(9860),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9860),
    [sym_trigger_keyword] = ACTIONS(9860),
    [sym_var_keyword] = ACTIONS(9860),
    [sym_local_keyword] = ACTIONS(9860),
    [sym_internal_keyword] = ACTIONS(9860),
    [sym_protected_keyword] = ACTIONS(9860),
    [sym_event_keyword] = ACTIONS(9860),
    [sym_fields_keyword] = ACTIONS(9860),
    [sym_keys_keyword] = ACTIONS(9860),
    [sym_fieldgroups_keyword] = ACTIONS(9860),
    [sym_actions_keyword] = ACTIONS(9860),
    [sym_layout_keyword] = ACTIONS(9860),
    [sym_area_keyword] = ACTIONS(9860),
    [sym_group_keyword] = ACTIONS(9860),
    [sym_repeater_keyword] = ACTIONS(9860),
    [sym_cuegroup_keyword] = ACTIONS(9860),
    [sym_fixed_keyword] = ACTIONS(9860),
    [sym_grid_keyword] = ACTIONS(9860),
    [sym_part_keyword] = ACTIONS(9860),
    [sym_systempart_keyword] = ACTIONS(9860),
    [sym_usercontrol_keyword] = ACTIONS(9860),
    [sym_dataset_keyword] = ACTIONS(9860),
    [sym_elements_keyword] = ACTIONS(9860),
    [sym_dataitem_keyword] = ACTIONS(9860),
    [sym_column_keyword] = ACTIONS(9860),
    [sym_filter_keyword] = ACTIONS(9860),
    [sym_labels_keyword] = ACTIONS(9860),
    [sym_rendering_keyword] = ACTIONS(9860),
    [sym_requestpage_keyword] = ACTIONS(9860),
    [sym_schema_keyword] = ACTIONS(9860),
    [sym_views_keyword] = ACTIONS(9860),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9860),
    [sym_preproc_open] = ACTIONS(9860),
    [sym_preproc_close] = ACTIONS(9860),
  },
  [STATE(3691)] = {
    [anon_sym_SEMI] = ACTIONS(9864),
    [aux_sym_where_condition_token1] = ACTIONS(9866),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9868),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9868),
    [anon_sym_LBRACK] = ACTIONS(9868),
    [aux_sym_basic_type_token6] = ACTIONS(9866),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9868),
    [aux_sym_addafter_modification_token1] = ACTIONS(9868),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9868),
    [aux_sym_modify_modification_token1] = ACTIONS(9868),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9868),
    [aux_sym_movelast_modification_token1] = ACTIONS(9868),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9868),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9868),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9868),
    [anon_sym_POUNDif] = ACTIONS(9868),
    [anon_sym_POUNDIF] = ACTIONS(9868),
    [anon_sym_POUNDIf] = ACTIONS(9868),
    [anon_sym_POUNDelif] = ACTIONS(9868),
    [anon_sym_POUNDELIF] = ACTIONS(9868),
    [anon_sym_POUNDElif] = ACTIONS(9868),
    [anon_sym_POUNDelse] = ACTIONS(9868),
    [anon_sym_POUNDELSE] = ACTIONS(9868),
    [anon_sym_POUNDElse] = ACTIONS(9868),
    [anon_sym_POUNDendif] = ACTIONS(9868),
    [anon_sym_POUNDENDIF] = ACTIONS(9868),
    [anon_sym_POUNDEndif] = ACTIONS(9868),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9868),
    [sym_trigger_keyword] = ACTIONS(9868),
    [sym_var_keyword] = ACTIONS(9868),
    [sym_local_keyword] = ACTIONS(9868),
    [sym_internal_keyword] = ACTIONS(9868),
    [sym_protected_keyword] = ACTIONS(9868),
    [sym_event_keyword] = ACTIONS(9868),
    [sym_fields_keyword] = ACTIONS(9868),
    [sym_keys_keyword] = ACTIONS(9868),
    [sym_fieldgroups_keyword] = ACTIONS(9868),
    [sym_actions_keyword] = ACTIONS(9868),
    [sym_layout_keyword] = ACTIONS(9868),
    [sym_area_keyword] = ACTIONS(9868),
    [sym_group_keyword] = ACTIONS(9868),
    [sym_repeater_keyword] = ACTIONS(9868),
    [sym_cuegroup_keyword] = ACTIONS(9868),
    [sym_fixed_keyword] = ACTIONS(9868),
    [sym_grid_keyword] = ACTIONS(9868),
    [sym_part_keyword] = ACTIONS(9868),
    [sym_systempart_keyword] = ACTIONS(9868),
    [sym_usercontrol_keyword] = ACTIONS(9868),
    [sym_dataset_keyword] = ACTIONS(9868),
    [sym_elements_keyword] = ACTIONS(9868),
    [sym_dataitem_keyword] = ACTIONS(9868),
    [sym_column_keyword] = ACTIONS(9868),
    [sym_filter_keyword] = ACTIONS(9868),
    [sym_labels_keyword] = ACTIONS(9868),
    [sym_rendering_keyword] = ACTIONS(9868),
    [sym_requestpage_keyword] = ACTIONS(9868),
    [sym_schema_keyword] = ACTIONS(9868),
    [sym_views_keyword] = ACTIONS(9868),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9868),
    [sym_preproc_open] = ACTIONS(9868),
    [sym_preproc_close] = ACTIONS(9868),
  },
  [STATE(3692)] = {
    [anon_sym_SEMI] = ACTIONS(9870),
    [aux_sym_where_condition_token1] = ACTIONS(9866),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9868),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9868),
    [anon_sym_LBRACK] = ACTIONS(9868),
    [aux_sym_basic_type_token6] = ACTIONS(9866),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9868),
    [aux_sym_addafter_modification_token1] = ACTIONS(9868),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9868),
    [aux_sym_modify_modification_token1] = ACTIONS(9868),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9868),
    [aux_sym_movelast_modification_token1] = ACTIONS(9868),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9868),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9868),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9868),
    [anon_sym_POUNDif] = ACTIONS(9868),
    [anon_sym_POUNDIF] = ACTIONS(9868),
    [anon_sym_POUNDIf] = ACTIONS(9868),
    [anon_sym_POUNDelif] = ACTIONS(9868),
    [anon_sym_POUNDELIF] = ACTIONS(9868),
    [anon_sym_POUNDElif] = ACTIONS(9868),
    [anon_sym_POUNDelse] = ACTIONS(9868),
    [anon_sym_POUNDELSE] = ACTIONS(9868),
    [anon_sym_POUNDElse] = ACTIONS(9868),
    [anon_sym_POUNDendif] = ACTIONS(9868),
    [anon_sym_POUNDENDIF] = ACTIONS(9868),
    [anon_sym_POUNDEndif] = ACTIONS(9868),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9868),
    [sym_trigger_keyword] = ACTIONS(9868),
    [sym_var_keyword] = ACTIONS(9868),
    [sym_local_keyword] = ACTIONS(9868),
    [sym_internal_keyword] = ACTIONS(9868),
    [sym_protected_keyword] = ACTIONS(9868),
    [sym_event_keyword] = ACTIONS(9868),
    [sym_fields_keyword] = ACTIONS(9868),
    [sym_keys_keyword] = ACTIONS(9868),
    [sym_fieldgroups_keyword] = ACTIONS(9868),
    [sym_actions_keyword] = ACTIONS(9868),
    [sym_layout_keyword] = ACTIONS(9868),
    [sym_area_keyword] = ACTIONS(9868),
    [sym_group_keyword] = ACTIONS(9868),
    [sym_repeater_keyword] = ACTIONS(9868),
    [sym_cuegroup_keyword] = ACTIONS(9868),
    [sym_fixed_keyword] = ACTIONS(9868),
    [sym_grid_keyword] = ACTIONS(9868),
    [sym_part_keyword] = ACTIONS(9868),
    [sym_systempart_keyword] = ACTIONS(9868),
    [sym_usercontrol_keyword] = ACTIONS(9868),
    [sym_dataset_keyword] = ACTIONS(9868),
    [sym_elements_keyword] = ACTIONS(9868),
    [sym_dataitem_keyword] = ACTIONS(9868),
    [sym_column_keyword] = ACTIONS(9868),
    [sym_filter_keyword] = ACTIONS(9868),
    [sym_labels_keyword] = ACTIONS(9868),
    [sym_rendering_keyword] = ACTIONS(9868),
    [sym_requestpage_keyword] = ACTIONS(9868),
    [sym_schema_keyword] = ACTIONS(9868),
    [sym_views_keyword] = ACTIONS(9868),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9868),
    [sym_preproc_open] = ACTIONS(9868),
    [sym_preproc_close] = ACTIONS(9868),
  },
  [STATE(3693)] = {
    [anon_sym_SEMI] = ACTIONS(9872),
    [aux_sym_where_condition_token1] = ACTIONS(9874),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9872),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9872),
    [anon_sym_LBRACK] = ACTIONS(9872),
    [aux_sym_basic_type_token6] = ACTIONS(9874),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9872),
    [aux_sym_addafter_modification_token1] = ACTIONS(9872),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9872),
    [aux_sym_modify_modification_token1] = ACTIONS(9872),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9872),
    [aux_sym_movelast_modification_token1] = ACTIONS(9872),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9872),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9872),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9872),
    [anon_sym_POUNDif] = ACTIONS(9872),
    [anon_sym_POUNDIF] = ACTIONS(9872),
    [anon_sym_POUNDIf] = ACTIONS(9872),
    [anon_sym_POUNDelif] = ACTIONS(9872),
    [anon_sym_POUNDELIF] = ACTIONS(9872),
    [anon_sym_POUNDElif] = ACTIONS(9872),
    [anon_sym_POUNDelse] = ACTIONS(9872),
    [anon_sym_POUNDELSE] = ACTIONS(9872),
    [anon_sym_POUNDElse] = ACTIONS(9872),
    [anon_sym_POUNDendif] = ACTIONS(9872),
    [anon_sym_POUNDENDIF] = ACTIONS(9872),
    [anon_sym_POUNDEndif] = ACTIONS(9872),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9872),
    [sym_trigger_keyword] = ACTIONS(9872),
    [sym_var_keyword] = ACTIONS(9872),
    [sym_local_keyword] = ACTIONS(9872),
    [sym_internal_keyword] = ACTIONS(9872),
    [sym_protected_keyword] = ACTIONS(9872),
    [sym_event_keyword] = ACTIONS(9872),
    [sym_fields_keyword] = ACTIONS(9872),
    [sym_keys_keyword] = ACTIONS(9872),
    [sym_fieldgroups_keyword] = ACTIONS(9872),
    [sym_actions_keyword] = ACTIONS(9872),
    [sym_layout_keyword] = ACTIONS(9872),
    [sym_area_keyword] = ACTIONS(9872),
    [sym_group_keyword] = ACTIONS(9872),
    [sym_repeater_keyword] = ACTIONS(9872),
    [sym_cuegroup_keyword] = ACTIONS(9872),
    [sym_fixed_keyword] = ACTIONS(9872),
    [sym_grid_keyword] = ACTIONS(9872),
    [sym_part_keyword] = ACTIONS(9872),
    [sym_systempart_keyword] = ACTIONS(9872),
    [sym_usercontrol_keyword] = ACTIONS(9872),
    [sym_dataset_keyword] = ACTIONS(9872),
    [sym_elements_keyword] = ACTIONS(9872),
    [sym_dataitem_keyword] = ACTIONS(9872),
    [sym_column_keyword] = ACTIONS(9872),
    [sym_filter_keyword] = ACTIONS(9872),
    [sym_labels_keyword] = ACTIONS(9872),
    [sym_rendering_keyword] = ACTIONS(9872),
    [sym_requestpage_keyword] = ACTIONS(9872),
    [sym_schema_keyword] = ACTIONS(9872),
    [sym_views_keyword] = ACTIONS(9872),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9872),
    [sym_preproc_open] = ACTIONS(9872),
    [sym_preproc_close] = ACTIONS(9872),
  },
  [STATE(3694)] = {
    [anon_sym_SEMI] = ACTIONS(9876),
    [aux_sym_where_condition_token1] = ACTIONS(9878),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9876),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9876),
    [anon_sym_LBRACK] = ACTIONS(9876),
    [aux_sym_basic_type_token6] = ACTIONS(9878),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9876),
    [aux_sym_addafter_modification_token1] = ACTIONS(9876),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9876),
    [aux_sym_modify_modification_token1] = ACTIONS(9876),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9876),
    [aux_sym_movelast_modification_token1] = ACTIONS(9876),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9876),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9876),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9876),
    [anon_sym_POUNDif] = ACTIONS(9876),
    [anon_sym_POUNDIF] = ACTIONS(9876),
    [anon_sym_POUNDIf] = ACTIONS(9876),
    [anon_sym_POUNDelif] = ACTIONS(9876),
    [anon_sym_POUNDELIF] = ACTIONS(9876),
    [anon_sym_POUNDElif] = ACTIONS(9876),
    [anon_sym_POUNDelse] = ACTIONS(9876),
    [anon_sym_POUNDELSE] = ACTIONS(9876),
    [anon_sym_POUNDElse] = ACTIONS(9876),
    [anon_sym_POUNDendif] = ACTIONS(9876),
    [anon_sym_POUNDENDIF] = ACTIONS(9876),
    [anon_sym_POUNDEndif] = ACTIONS(9876),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9876),
    [sym_trigger_keyword] = ACTIONS(9876),
    [sym_var_keyword] = ACTIONS(9876),
    [sym_local_keyword] = ACTIONS(9876),
    [sym_internal_keyword] = ACTIONS(9876),
    [sym_protected_keyword] = ACTIONS(9876),
    [sym_event_keyword] = ACTIONS(9876),
    [sym_fields_keyword] = ACTIONS(9876),
    [sym_keys_keyword] = ACTIONS(9876),
    [sym_fieldgroups_keyword] = ACTIONS(9876),
    [sym_actions_keyword] = ACTIONS(9876),
    [sym_layout_keyword] = ACTIONS(9876),
    [sym_area_keyword] = ACTIONS(9876),
    [sym_group_keyword] = ACTIONS(9876),
    [sym_repeater_keyword] = ACTIONS(9876),
    [sym_cuegroup_keyword] = ACTIONS(9876),
    [sym_fixed_keyword] = ACTIONS(9876),
    [sym_grid_keyword] = ACTIONS(9876),
    [sym_part_keyword] = ACTIONS(9876),
    [sym_systempart_keyword] = ACTIONS(9876),
    [sym_usercontrol_keyword] = ACTIONS(9876),
    [sym_dataset_keyword] = ACTIONS(9876),
    [sym_elements_keyword] = ACTIONS(9876),
    [sym_dataitem_keyword] = ACTIONS(9876),
    [sym_column_keyword] = ACTIONS(9876),
    [sym_filter_keyword] = ACTIONS(9876),
    [sym_labels_keyword] = ACTIONS(9876),
    [sym_rendering_keyword] = ACTIONS(9876),
    [sym_requestpage_keyword] = ACTIONS(9876),
    [sym_schema_keyword] = ACTIONS(9876),
    [sym_views_keyword] = ACTIONS(9876),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9876),
    [sym_preproc_open] = ACTIONS(9876),
    [sym_preproc_close] = ACTIONS(9876),
  },
  [STATE(3695)] = {
    [anon_sym_SEMI] = ACTIONS(9880),
    [aux_sym_where_condition_token1] = ACTIONS(9882),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9884),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9884),
    [anon_sym_LBRACK] = ACTIONS(9884),
    [aux_sym_basic_type_token6] = ACTIONS(9882),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9884),
    [aux_sym_addafter_modification_token1] = ACTIONS(9884),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9884),
    [aux_sym_modify_modification_token1] = ACTIONS(9884),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9884),
    [aux_sym_movelast_modification_token1] = ACTIONS(9884),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9884),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9884),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9884),
    [anon_sym_POUNDif] = ACTIONS(9884),
    [anon_sym_POUNDIF] = ACTIONS(9884),
    [anon_sym_POUNDIf] = ACTIONS(9884),
    [anon_sym_POUNDelif] = ACTIONS(9884),
    [anon_sym_POUNDELIF] = ACTIONS(9884),
    [anon_sym_POUNDElif] = ACTIONS(9884),
    [anon_sym_POUNDelse] = ACTIONS(9884),
    [anon_sym_POUNDELSE] = ACTIONS(9884),
    [anon_sym_POUNDElse] = ACTIONS(9884),
    [anon_sym_POUNDendif] = ACTIONS(9884),
    [anon_sym_POUNDENDIF] = ACTIONS(9884),
    [anon_sym_POUNDEndif] = ACTIONS(9884),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9884),
    [sym_trigger_keyword] = ACTIONS(9884),
    [sym_var_keyword] = ACTIONS(9884),
    [sym_local_keyword] = ACTIONS(9884),
    [sym_internal_keyword] = ACTIONS(9884),
    [sym_protected_keyword] = ACTIONS(9884),
    [sym_event_keyword] = ACTIONS(9884),
    [sym_fields_keyword] = ACTIONS(9884),
    [sym_keys_keyword] = ACTIONS(9884),
    [sym_fieldgroups_keyword] = ACTIONS(9884),
    [sym_actions_keyword] = ACTIONS(9884),
    [sym_layout_keyword] = ACTIONS(9884),
    [sym_area_keyword] = ACTIONS(9884),
    [sym_group_keyword] = ACTIONS(9884),
    [sym_repeater_keyword] = ACTIONS(9884),
    [sym_cuegroup_keyword] = ACTIONS(9884),
    [sym_fixed_keyword] = ACTIONS(9884),
    [sym_grid_keyword] = ACTIONS(9884),
    [sym_part_keyword] = ACTIONS(9884),
    [sym_systempart_keyword] = ACTIONS(9884),
    [sym_usercontrol_keyword] = ACTIONS(9884),
    [sym_dataset_keyword] = ACTIONS(9884),
    [sym_elements_keyword] = ACTIONS(9884),
    [sym_dataitem_keyword] = ACTIONS(9884),
    [sym_column_keyword] = ACTIONS(9884),
    [sym_filter_keyword] = ACTIONS(9884),
    [sym_labels_keyword] = ACTIONS(9884),
    [sym_rendering_keyword] = ACTIONS(9884),
    [sym_requestpage_keyword] = ACTIONS(9884),
    [sym_schema_keyword] = ACTIONS(9884),
    [sym_views_keyword] = ACTIONS(9884),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9884),
    [sym_preproc_open] = ACTIONS(9884),
    [sym_preproc_close] = ACTIONS(9884),
  },
  [STATE(3696)] = {
    [anon_sym_SEMI] = ACTIONS(9886),
    [aux_sym_where_condition_token1] = ACTIONS(9882),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9884),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9884),
    [anon_sym_LBRACK] = ACTIONS(9884),
    [aux_sym_basic_type_token6] = ACTIONS(9882),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9884),
    [aux_sym_addafter_modification_token1] = ACTIONS(9884),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9884),
    [aux_sym_modify_modification_token1] = ACTIONS(9884),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9884),
    [aux_sym_movelast_modification_token1] = ACTIONS(9884),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9884),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9884),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9884),
    [anon_sym_POUNDif] = ACTIONS(9884),
    [anon_sym_POUNDIF] = ACTIONS(9884),
    [anon_sym_POUNDIf] = ACTIONS(9884),
    [anon_sym_POUNDelif] = ACTIONS(9884),
    [anon_sym_POUNDELIF] = ACTIONS(9884),
    [anon_sym_POUNDElif] = ACTIONS(9884),
    [anon_sym_POUNDelse] = ACTIONS(9884),
    [anon_sym_POUNDELSE] = ACTIONS(9884),
    [anon_sym_POUNDElse] = ACTIONS(9884),
    [anon_sym_POUNDendif] = ACTIONS(9884),
    [anon_sym_POUNDENDIF] = ACTIONS(9884),
    [anon_sym_POUNDEndif] = ACTIONS(9884),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9884),
    [sym_trigger_keyword] = ACTIONS(9884),
    [sym_var_keyword] = ACTIONS(9884),
    [sym_local_keyword] = ACTIONS(9884),
    [sym_internal_keyword] = ACTIONS(9884),
    [sym_protected_keyword] = ACTIONS(9884),
    [sym_event_keyword] = ACTIONS(9884),
    [sym_fields_keyword] = ACTIONS(9884),
    [sym_keys_keyword] = ACTIONS(9884),
    [sym_fieldgroups_keyword] = ACTIONS(9884),
    [sym_actions_keyword] = ACTIONS(9884),
    [sym_layout_keyword] = ACTIONS(9884),
    [sym_area_keyword] = ACTIONS(9884),
    [sym_group_keyword] = ACTIONS(9884),
    [sym_repeater_keyword] = ACTIONS(9884),
    [sym_cuegroup_keyword] = ACTIONS(9884),
    [sym_fixed_keyword] = ACTIONS(9884),
    [sym_grid_keyword] = ACTIONS(9884),
    [sym_part_keyword] = ACTIONS(9884),
    [sym_systempart_keyword] = ACTIONS(9884),
    [sym_usercontrol_keyword] = ACTIONS(9884),
    [sym_dataset_keyword] = ACTIONS(9884),
    [sym_elements_keyword] = ACTIONS(9884),
    [sym_dataitem_keyword] = ACTIONS(9884),
    [sym_column_keyword] = ACTIONS(9884),
    [sym_filter_keyword] = ACTIONS(9884),
    [sym_labels_keyword] = ACTIONS(9884),
    [sym_rendering_keyword] = ACTIONS(9884),
    [sym_requestpage_keyword] = ACTIONS(9884),
    [sym_schema_keyword] = ACTIONS(9884),
    [sym_views_keyword] = ACTIONS(9884),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9884),
    [sym_preproc_open] = ACTIONS(9884),
    [sym_preproc_close] = ACTIONS(9884),
  },
  [STATE(3697)] = {
    [anon_sym_SEMI] = ACTIONS(9888),
    [aux_sym_where_condition_token1] = ACTIONS(9840),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9838),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9838),
    [anon_sym_LBRACK] = ACTIONS(9838),
    [aux_sym_basic_type_token6] = ACTIONS(9840),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9838),
    [aux_sym_addafter_modification_token1] = ACTIONS(9838),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9838),
    [aux_sym_modify_modification_token1] = ACTIONS(9838),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9838),
    [aux_sym_movelast_modification_token1] = ACTIONS(9838),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9838),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9838),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9838),
    [anon_sym_POUNDif] = ACTIONS(9838),
    [anon_sym_POUNDIF] = ACTIONS(9838),
    [anon_sym_POUNDIf] = ACTIONS(9838),
    [anon_sym_POUNDelif] = ACTIONS(9838),
    [anon_sym_POUNDELIF] = ACTIONS(9838),
    [anon_sym_POUNDElif] = ACTIONS(9838),
    [anon_sym_POUNDelse] = ACTIONS(9838),
    [anon_sym_POUNDELSE] = ACTIONS(9838),
    [anon_sym_POUNDElse] = ACTIONS(9838),
    [anon_sym_POUNDendif] = ACTIONS(9838),
    [anon_sym_POUNDENDIF] = ACTIONS(9838),
    [anon_sym_POUNDEndif] = ACTIONS(9838),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9838),
    [sym_trigger_keyword] = ACTIONS(9838),
    [sym_var_keyword] = ACTIONS(9838),
    [sym_local_keyword] = ACTIONS(9838),
    [sym_internal_keyword] = ACTIONS(9838),
    [sym_protected_keyword] = ACTIONS(9838),
    [sym_event_keyword] = ACTIONS(9838),
    [sym_fields_keyword] = ACTIONS(9838),
    [sym_keys_keyword] = ACTIONS(9838),
    [sym_fieldgroups_keyword] = ACTIONS(9838),
    [sym_actions_keyword] = ACTIONS(9838),
    [sym_layout_keyword] = ACTIONS(9838),
    [sym_area_keyword] = ACTIONS(9838),
    [sym_group_keyword] = ACTIONS(9838),
    [sym_repeater_keyword] = ACTIONS(9838),
    [sym_cuegroup_keyword] = ACTIONS(9838),
    [sym_fixed_keyword] = ACTIONS(9838),
    [sym_grid_keyword] = ACTIONS(9838),
    [sym_part_keyword] = ACTIONS(9838),
    [sym_systempart_keyword] = ACTIONS(9838),
    [sym_usercontrol_keyword] = ACTIONS(9838),
    [sym_dataset_keyword] = ACTIONS(9838),
    [sym_elements_keyword] = ACTIONS(9838),
    [sym_dataitem_keyword] = ACTIONS(9838),
    [sym_column_keyword] = ACTIONS(9838),
    [sym_filter_keyword] = ACTIONS(9838),
    [sym_labels_keyword] = ACTIONS(9838),
    [sym_rendering_keyword] = ACTIONS(9838),
    [sym_requestpage_keyword] = ACTIONS(9838),
    [sym_schema_keyword] = ACTIONS(9838),
    [sym_views_keyword] = ACTIONS(9838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9838),
    [sym_preproc_open] = ACTIONS(9838),
    [sym_preproc_close] = ACTIONS(9838),
  },
  [STATE(3698)] = {
    [anon_sym_SEMI] = ACTIONS(9890),
    [aux_sym_where_condition_token1] = ACTIONS(9840),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9838),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9838),
    [anon_sym_LBRACK] = ACTIONS(9838),
    [aux_sym_basic_type_token6] = ACTIONS(9840),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9838),
    [aux_sym_addafter_modification_token1] = ACTIONS(9838),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9838),
    [aux_sym_modify_modification_token1] = ACTIONS(9838),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9838),
    [aux_sym_movelast_modification_token1] = ACTIONS(9838),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9838),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9838),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9838),
    [anon_sym_POUNDif] = ACTIONS(9838),
    [anon_sym_POUNDIF] = ACTIONS(9838),
    [anon_sym_POUNDIf] = ACTIONS(9838),
    [anon_sym_POUNDelif] = ACTIONS(9838),
    [anon_sym_POUNDELIF] = ACTIONS(9838),
    [anon_sym_POUNDElif] = ACTIONS(9838),
    [anon_sym_POUNDelse] = ACTIONS(9838),
    [anon_sym_POUNDELSE] = ACTIONS(9838),
    [anon_sym_POUNDElse] = ACTIONS(9838),
    [anon_sym_POUNDendif] = ACTIONS(9838),
    [anon_sym_POUNDENDIF] = ACTIONS(9838),
    [anon_sym_POUNDEndif] = ACTIONS(9838),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9838),
    [sym_trigger_keyword] = ACTIONS(9838),
    [sym_var_keyword] = ACTIONS(9838),
    [sym_local_keyword] = ACTIONS(9838),
    [sym_internal_keyword] = ACTIONS(9838),
    [sym_protected_keyword] = ACTIONS(9838),
    [sym_event_keyword] = ACTIONS(9838),
    [sym_fields_keyword] = ACTIONS(9838),
    [sym_keys_keyword] = ACTIONS(9838),
    [sym_fieldgroups_keyword] = ACTIONS(9838),
    [sym_actions_keyword] = ACTIONS(9838),
    [sym_layout_keyword] = ACTIONS(9838),
    [sym_area_keyword] = ACTIONS(9838),
    [sym_group_keyword] = ACTIONS(9838),
    [sym_repeater_keyword] = ACTIONS(9838),
    [sym_cuegroup_keyword] = ACTIONS(9838),
    [sym_fixed_keyword] = ACTIONS(9838),
    [sym_grid_keyword] = ACTIONS(9838),
    [sym_part_keyword] = ACTIONS(9838),
    [sym_systempart_keyword] = ACTIONS(9838),
    [sym_usercontrol_keyword] = ACTIONS(9838),
    [sym_dataset_keyword] = ACTIONS(9838),
    [sym_elements_keyword] = ACTIONS(9838),
    [sym_dataitem_keyword] = ACTIONS(9838),
    [sym_column_keyword] = ACTIONS(9838),
    [sym_filter_keyword] = ACTIONS(9838),
    [sym_labels_keyword] = ACTIONS(9838),
    [sym_rendering_keyword] = ACTIONS(9838),
    [sym_requestpage_keyword] = ACTIONS(9838),
    [sym_schema_keyword] = ACTIONS(9838),
    [sym_views_keyword] = ACTIONS(9838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9838),
    [sym_preproc_open] = ACTIONS(9838),
    [sym_preproc_close] = ACTIONS(9838),
  },
  [STATE(3699)] = {
    [anon_sym_SEMI] = ACTIONS(9892),
    [aux_sym_where_condition_token1] = ACTIONS(9894),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9892),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9892),
    [anon_sym_LBRACK] = ACTIONS(9892),
    [aux_sym_basic_type_token6] = ACTIONS(9894),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9892),
    [aux_sym_addafter_modification_token1] = ACTIONS(9892),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9892),
    [aux_sym_modify_modification_token1] = ACTIONS(9892),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9892),
    [aux_sym_movelast_modification_token1] = ACTIONS(9892),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9892),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9892),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9892),
    [anon_sym_POUNDif] = ACTIONS(9892),
    [anon_sym_POUNDIF] = ACTIONS(9892),
    [anon_sym_POUNDIf] = ACTIONS(9892),
    [anon_sym_POUNDelif] = ACTIONS(9892),
    [anon_sym_POUNDELIF] = ACTIONS(9892),
    [anon_sym_POUNDElif] = ACTIONS(9892),
    [anon_sym_POUNDelse] = ACTIONS(9892),
    [anon_sym_POUNDELSE] = ACTIONS(9892),
    [anon_sym_POUNDElse] = ACTIONS(9892),
    [anon_sym_POUNDendif] = ACTIONS(9892),
    [anon_sym_POUNDENDIF] = ACTIONS(9892),
    [anon_sym_POUNDEndif] = ACTIONS(9892),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9892),
    [sym_trigger_keyword] = ACTIONS(9892),
    [sym_var_keyword] = ACTIONS(9892),
    [sym_local_keyword] = ACTIONS(9892),
    [sym_internal_keyword] = ACTIONS(9892),
    [sym_protected_keyword] = ACTIONS(9892),
    [sym_event_keyword] = ACTIONS(9892),
    [sym_fields_keyword] = ACTIONS(9892),
    [sym_keys_keyword] = ACTIONS(9892),
    [sym_fieldgroups_keyword] = ACTIONS(9892),
    [sym_actions_keyword] = ACTIONS(9892),
    [sym_layout_keyword] = ACTIONS(9892),
    [sym_area_keyword] = ACTIONS(9892),
    [sym_group_keyword] = ACTIONS(9892),
    [sym_repeater_keyword] = ACTIONS(9892),
    [sym_cuegroup_keyword] = ACTIONS(9892),
    [sym_fixed_keyword] = ACTIONS(9892),
    [sym_grid_keyword] = ACTIONS(9892),
    [sym_part_keyword] = ACTIONS(9892),
    [sym_systempart_keyword] = ACTIONS(9892),
    [sym_usercontrol_keyword] = ACTIONS(9892),
    [sym_dataset_keyword] = ACTIONS(9892),
    [sym_elements_keyword] = ACTIONS(9892),
    [sym_dataitem_keyword] = ACTIONS(9892),
    [sym_column_keyword] = ACTIONS(9892),
    [sym_filter_keyword] = ACTIONS(9892),
    [sym_labels_keyword] = ACTIONS(9892),
    [sym_rendering_keyword] = ACTIONS(9892),
    [sym_requestpage_keyword] = ACTIONS(9892),
    [sym_schema_keyword] = ACTIONS(9892),
    [sym_views_keyword] = ACTIONS(9892),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9892),
    [sym_preproc_open] = ACTIONS(9892),
    [sym_preproc_close] = ACTIONS(9892),
  },
  [STATE(3700)] = {
    [anon_sym_SEMI] = ACTIONS(9876),
    [aux_sym_where_condition_token1] = ACTIONS(9878),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9876),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9876),
    [anon_sym_LBRACK] = ACTIONS(9876),
    [aux_sym_basic_type_token6] = ACTIONS(9878),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9876),
    [aux_sym_addafter_modification_token1] = ACTIONS(9876),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9876),
    [aux_sym_modify_modification_token1] = ACTIONS(9876),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9876),
    [aux_sym_movelast_modification_token1] = ACTIONS(9876),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9876),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9876),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9876),
    [anon_sym_POUNDif] = ACTIONS(9876),
    [anon_sym_POUNDIF] = ACTIONS(9876),
    [anon_sym_POUNDIf] = ACTIONS(9876),
    [anon_sym_POUNDelif] = ACTIONS(9876),
    [anon_sym_POUNDELIF] = ACTIONS(9876),
    [anon_sym_POUNDElif] = ACTIONS(9876),
    [anon_sym_POUNDelse] = ACTIONS(9876),
    [anon_sym_POUNDELSE] = ACTIONS(9876),
    [anon_sym_POUNDElse] = ACTIONS(9876),
    [anon_sym_POUNDendif] = ACTIONS(9876),
    [anon_sym_POUNDENDIF] = ACTIONS(9876),
    [anon_sym_POUNDEndif] = ACTIONS(9876),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9876),
    [sym_trigger_keyword] = ACTIONS(9876),
    [sym_var_keyword] = ACTIONS(9876),
    [sym_local_keyword] = ACTIONS(9876),
    [sym_internal_keyword] = ACTIONS(9876),
    [sym_protected_keyword] = ACTIONS(9876),
    [sym_event_keyword] = ACTIONS(9876),
    [sym_fields_keyword] = ACTIONS(9876),
    [sym_keys_keyword] = ACTIONS(9876),
    [sym_fieldgroups_keyword] = ACTIONS(9876),
    [sym_actions_keyword] = ACTIONS(9876),
    [sym_layout_keyword] = ACTIONS(9876),
    [sym_area_keyword] = ACTIONS(9876),
    [sym_group_keyword] = ACTIONS(9876),
    [sym_repeater_keyword] = ACTIONS(9876),
    [sym_cuegroup_keyword] = ACTIONS(9876),
    [sym_fixed_keyword] = ACTIONS(9876),
    [sym_grid_keyword] = ACTIONS(9876),
    [sym_part_keyword] = ACTIONS(9876),
    [sym_systempart_keyword] = ACTIONS(9876),
    [sym_usercontrol_keyword] = ACTIONS(9876),
    [sym_dataset_keyword] = ACTIONS(9876),
    [sym_elements_keyword] = ACTIONS(9876),
    [sym_dataitem_keyword] = ACTIONS(9876),
    [sym_column_keyword] = ACTIONS(9876),
    [sym_filter_keyword] = ACTIONS(9876),
    [sym_labels_keyword] = ACTIONS(9876),
    [sym_rendering_keyword] = ACTIONS(9876),
    [sym_requestpage_keyword] = ACTIONS(9876),
    [sym_schema_keyword] = ACTIONS(9876),
    [sym_views_keyword] = ACTIONS(9876),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9876),
    [sym_preproc_open] = ACTIONS(9876),
    [sym_preproc_close] = ACTIONS(9876),
  },
  [STATE(3701)] = {
    [anon_sym_SEMI] = ACTIONS(9896),
    [aux_sym_where_condition_token1] = ACTIONS(9898),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9896),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9896),
    [anon_sym_LBRACK] = ACTIONS(9896),
    [aux_sym_basic_type_token6] = ACTIONS(9898),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9896),
    [aux_sym_addafter_modification_token1] = ACTIONS(9896),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9896),
    [aux_sym_modify_modification_token1] = ACTIONS(9896),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9896),
    [aux_sym_movelast_modification_token1] = ACTIONS(9896),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9896),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9896),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9896),
    [anon_sym_POUNDif] = ACTIONS(9896),
    [anon_sym_POUNDIF] = ACTIONS(9896),
    [anon_sym_POUNDIf] = ACTIONS(9896),
    [anon_sym_POUNDelif] = ACTIONS(9896),
    [anon_sym_POUNDELIF] = ACTIONS(9896),
    [anon_sym_POUNDElif] = ACTIONS(9896),
    [anon_sym_POUNDelse] = ACTIONS(9896),
    [anon_sym_POUNDELSE] = ACTIONS(9896),
    [anon_sym_POUNDElse] = ACTIONS(9896),
    [anon_sym_POUNDendif] = ACTIONS(9896),
    [anon_sym_POUNDENDIF] = ACTIONS(9896),
    [anon_sym_POUNDEndif] = ACTIONS(9896),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9896),
    [sym_trigger_keyword] = ACTIONS(9896),
    [sym_var_keyword] = ACTIONS(9896),
    [sym_local_keyword] = ACTIONS(9896),
    [sym_internal_keyword] = ACTIONS(9896),
    [sym_protected_keyword] = ACTIONS(9896),
    [sym_event_keyword] = ACTIONS(9896),
    [sym_fields_keyword] = ACTIONS(9896),
    [sym_keys_keyword] = ACTIONS(9896),
    [sym_fieldgroups_keyword] = ACTIONS(9896),
    [sym_actions_keyword] = ACTIONS(9896),
    [sym_layout_keyword] = ACTIONS(9896),
    [sym_area_keyword] = ACTIONS(9896),
    [sym_group_keyword] = ACTIONS(9896),
    [sym_repeater_keyword] = ACTIONS(9896),
    [sym_cuegroup_keyword] = ACTIONS(9896),
    [sym_fixed_keyword] = ACTIONS(9896),
    [sym_grid_keyword] = ACTIONS(9896),
    [sym_part_keyword] = ACTIONS(9896),
    [sym_systempart_keyword] = ACTIONS(9896),
    [sym_usercontrol_keyword] = ACTIONS(9896),
    [sym_dataset_keyword] = ACTIONS(9896),
    [sym_elements_keyword] = ACTIONS(9896),
    [sym_dataitem_keyword] = ACTIONS(9896),
    [sym_column_keyword] = ACTIONS(9896),
    [sym_filter_keyword] = ACTIONS(9896),
    [sym_labels_keyword] = ACTIONS(9896),
    [sym_rendering_keyword] = ACTIONS(9896),
    [sym_requestpage_keyword] = ACTIONS(9896),
    [sym_schema_keyword] = ACTIONS(9896),
    [sym_views_keyword] = ACTIONS(9896),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9896),
    [sym_preproc_open] = ACTIONS(9896),
    [sym_preproc_close] = ACTIONS(9896),
  },
  [STATE(3702)] = {
    [anon_sym_SEMI] = ACTIONS(9896),
    [aux_sym_where_condition_token1] = ACTIONS(9898),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9896),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9896),
    [anon_sym_LBRACK] = ACTIONS(9896),
    [aux_sym_basic_type_token6] = ACTIONS(9898),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9896),
    [aux_sym_addafter_modification_token1] = ACTIONS(9896),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9896),
    [aux_sym_modify_modification_token1] = ACTIONS(9896),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9896),
    [aux_sym_movelast_modification_token1] = ACTIONS(9896),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9896),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9896),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9896),
    [anon_sym_POUNDif] = ACTIONS(9896),
    [anon_sym_POUNDIF] = ACTIONS(9896),
    [anon_sym_POUNDIf] = ACTIONS(9896),
    [anon_sym_POUNDelif] = ACTIONS(9896),
    [anon_sym_POUNDELIF] = ACTIONS(9896),
    [anon_sym_POUNDElif] = ACTIONS(9896),
    [anon_sym_POUNDelse] = ACTIONS(9896),
    [anon_sym_POUNDELSE] = ACTIONS(9896),
    [anon_sym_POUNDElse] = ACTIONS(9896),
    [anon_sym_POUNDendif] = ACTIONS(9896),
    [anon_sym_POUNDENDIF] = ACTIONS(9896),
    [anon_sym_POUNDEndif] = ACTIONS(9896),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9896),
    [sym_trigger_keyword] = ACTIONS(9896),
    [sym_var_keyword] = ACTIONS(9896),
    [sym_local_keyword] = ACTIONS(9896),
    [sym_internal_keyword] = ACTIONS(9896),
    [sym_protected_keyword] = ACTIONS(9896),
    [sym_event_keyword] = ACTIONS(9896),
    [sym_fields_keyword] = ACTIONS(9896),
    [sym_keys_keyword] = ACTIONS(9896),
    [sym_fieldgroups_keyword] = ACTIONS(9896),
    [sym_actions_keyword] = ACTIONS(9896),
    [sym_layout_keyword] = ACTIONS(9896),
    [sym_area_keyword] = ACTIONS(9896),
    [sym_group_keyword] = ACTIONS(9896),
    [sym_repeater_keyword] = ACTIONS(9896),
    [sym_cuegroup_keyword] = ACTIONS(9896),
    [sym_fixed_keyword] = ACTIONS(9896),
    [sym_grid_keyword] = ACTIONS(9896),
    [sym_part_keyword] = ACTIONS(9896),
    [sym_systempart_keyword] = ACTIONS(9896),
    [sym_usercontrol_keyword] = ACTIONS(9896),
    [sym_dataset_keyword] = ACTIONS(9896),
    [sym_elements_keyword] = ACTIONS(9896),
    [sym_dataitem_keyword] = ACTIONS(9896),
    [sym_column_keyword] = ACTIONS(9896),
    [sym_filter_keyword] = ACTIONS(9896),
    [sym_labels_keyword] = ACTIONS(9896),
    [sym_rendering_keyword] = ACTIONS(9896),
    [sym_requestpage_keyword] = ACTIONS(9896),
    [sym_schema_keyword] = ACTIONS(9896),
    [sym_views_keyword] = ACTIONS(9896),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9896),
    [sym_preproc_open] = ACTIONS(9896),
    [sym_preproc_close] = ACTIONS(9896),
  },
  [STATE(3703)] = {
    [anon_sym_SEMI] = ACTIONS(9900),
    [aux_sym_where_condition_token1] = ACTIONS(9902),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9900),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9900),
    [anon_sym_LBRACK] = ACTIONS(9900),
    [aux_sym_basic_type_token6] = ACTIONS(9902),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9900),
    [aux_sym_addafter_modification_token1] = ACTIONS(9900),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9900),
    [aux_sym_modify_modification_token1] = ACTIONS(9900),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9900),
    [aux_sym_movelast_modification_token1] = ACTIONS(9900),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9900),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9900),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9900),
    [anon_sym_POUNDif] = ACTIONS(9900),
    [anon_sym_POUNDIF] = ACTIONS(9900),
    [anon_sym_POUNDIf] = ACTIONS(9900),
    [anon_sym_POUNDelif] = ACTIONS(9900),
    [anon_sym_POUNDELIF] = ACTIONS(9900),
    [anon_sym_POUNDElif] = ACTIONS(9900),
    [anon_sym_POUNDelse] = ACTIONS(9900),
    [anon_sym_POUNDELSE] = ACTIONS(9900),
    [anon_sym_POUNDElse] = ACTIONS(9900),
    [anon_sym_POUNDendif] = ACTIONS(9900),
    [anon_sym_POUNDENDIF] = ACTIONS(9900),
    [anon_sym_POUNDEndif] = ACTIONS(9900),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9900),
    [sym_trigger_keyword] = ACTIONS(9900),
    [sym_var_keyword] = ACTIONS(9900),
    [sym_local_keyword] = ACTIONS(9900),
    [sym_internal_keyword] = ACTIONS(9900),
    [sym_protected_keyword] = ACTIONS(9900),
    [sym_event_keyword] = ACTIONS(9900),
    [sym_fields_keyword] = ACTIONS(9900),
    [sym_keys_keyword] = ACTIONS(9900),
    [sym_fieldgroups_keyword] = ACTIONS(9900),
    [sym_actions_keyword] = ACTIONS(9900),
    [sym_layout_keyword] = ACTIONS(9900),
    [sym_area_keyword] = ACTIONS(9900),
    [sym_group_keyword] = ACTIONS(9900),
    [sym_repeater_keyword] = ACTIONS(9900),
    [sym_cuegroup_keyword] = ACTIONS(9900),
    [sym_fixed_keyword] = ACTIONS(9900),
    [sym_grid_keyword] = ACTIONS(9900),
    [sym_part_keyword] = ACTIONS(9900),
    [sym_systempart_keyword] = ACTIONS(9900),
    [sym_usercontrol_keyword] = ACTIONS(9900),
    [sym_dataset_keyword] = ACTIONS(9900),
    [sym_elements_keyword] = ACTIONS(9900),
    [sym_dataitem_keyword] = ACTIONS(9900),
    [sym_column_keyword] = ACTIONS(9900),
    [sym_filter_keyword] = ACTIONS(9900),
    [sym_labels_keyword] = ACTIONS(9900),
    [sym_rendering_keyword] = ACTIONS(9900),
    [sym_requestpage_keyword] = ACTIONS(9900),
    [sym_schema_keyword] = ACTIONS(9900),
    [sym_views_keyword] = ACTIONS(9900),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9900),
    [sym_preproc_open] = ACTIONS(9900),
    [sym_preproc_close] = ACTIONS(9900),
  },
  [STATE(3704)] = {
    [anon_sym_SEMI] = ACTIONS(9904),
    [aux_sym_where_condition_token1] = ACTIONS(9906),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9904),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9904),
    [anon_sym_LBRACK] = ACTIONS(9904),
    [aux_sym_basic_type_token6] = ACTIONS(9906),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9904),
    [aux_sym_addafter_modification_token1] = ACTIONS(9904),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9904),
    [aux_sym_modify_modification_token1] = ACTIONS(9904),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9904),
    [aux_sym_movelast_modification_token1] = ACTIONS(9904),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9904),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9904),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9904),
    [anon_sym_POUNDif] = ACTIONS(9904),
    [anon_sym_POUNDIF] = ACTIONS(9904),
    [anon_sym_POUNDIf] = ACTIONS(9904),
    [anon_sym_POUNDelif] = ACTIONS(9904),
    [anon_sym_POUNDELIF] = ACTIONS(9904),
    [anon_sym_POUNDElif] = ACTIONS(9904),
    [anon_sym_POUNDelse] = ACTIONS(9904),
    [anon_sym_POUNDELSE] = ACTIONS(9904),
    [anon_sym_POUNDElse] = ACTIONS(9904),
    [anon_sym_POUNDendif] = ACTIONS(9904),
    [anon_sym_POUNDENDIF] = ACTIONS(9904),
    [anon_sym_POUNDEndif] = ACTIONS(9904),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9904),
    [sym_trigger_keyword] = ACTIONS(9904),
    [sym_var_keyword] = ACTIONS(9904),
    [sym_local_keyword] = ACTIONS(9904),
    [sym_internal_keyword] = ACTIONS(9904),
    [sym_protected_keyword] = ACTIONS(9904),
    [sym_event_keyword] = ACTIONS(9904),
    [sym_fields_keyword] = ACTIONS(9904),
    [sym_keys_keyword] = ACTIONS(9904),
    [sym_fieldgroups_keyword] = ACTIONS(9904),
    [sym_actions_keyword] = ACTIONS(9904),
    [sym_layout_keyword] = ACTIONS(9904),
    [sym_area_keyword] = ACTIONS(9904),
    [sym_group_keyword] = ACTIONS(9904),
    [sym_repeater_keyword] = ACTIONS(9904),
    [sym_cuegroup_keyword] = ACTIONS(9904),
    [sym_fixed_keyword] = ACTIONS(9904),
    [sym_grid_keyword] = ACTIONS(9904),
    [sym_part_keyword] = ACTIONS(9904),
    [sym_systempart_keyword] = ACTIONS(9904),
    [sym_usercontrol_keyword] = ACTIONS(9904),
    [sym_dataset_keyword] = ACTIONS(9904),
    [sym_elements_keyword] = ACTIONS(9904),
    [sym_dataitem_keyword] = ACTIONS(9904),
    [sym_column_keyword] = ACTIONS(9904),
    [sym_filter_keyword] = ACTIONS(9904),
    [sym_labels_keyword] = ACTIONS(9904),
    [sym_rendering_keyword] = ACTIONS(9904),
    [sym_requestpage_keyword] = ACTIONS(9904),
    [sym_schema_keyword] = ACTIONS(9904),
    [sym_views_keyword] = ACTIONS(9904),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9904),
    [sym_preproc_open] = ACTIONS(9904),
    [sym_preproc_close] = ACTIONS(9904),
  },
  [STATE(3705)] = {
    [anon_sym_SEMI] = ACTIONS(9908),
    [aux_sym_where_condition_token1] = ACTIONS(9910),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9908),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9908),
    [anon_sym_LBRACK] = ACTIONS(9908),
    [aux_sym_basic_type_token6] = ACTIONS(9910),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9908),
    [aux_sym_addafter_modification_token1] = ACTIONS(9908),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9908),
    [aux_sym_modify_modification_token1] = ACTIONS(9908),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9908),
    [aux_sym_movelast_modification_token1] = ACTIONS(9908),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9908),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9908),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9908),
    [anon_sym_POUNDif] = ACTIONS(9908),
    [anon_sym_POUNDIF] = ACTIONS(9908),
    [anon_sym_POUNDIf] = ACTIONS(9908),
    [anon_sym_POUNDelif] = ACTIONS(9908),
    [anon_sym_POUNDELIF] = ACTIONS(9908),
    [anon_sym_POUNDElif] = ACTIONS(9908),
    [anon_sym_POUNDelse] = ACTIONS(9908),
    [anon_sym_POUNDELSE] = ACTIONS(9908),
    [anon_sym_POUNDElse] = ACTIONS(9908),
    [anon_sym_POUNDendif] = ACTIONS(9908),
    [anon_sym_POUNDENDIF] = ACTIONS(9908),
    [anon_sym_POUNDEndif] = ACTIONS(9908),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9908),
    [sym_trigger_keyword] = ACTIONS(9908),
    [sym_var_keyword] = ACTIONS(9908),
    [sym_local_keyword] = ACTIONS(9908),
    [sym_internal_keyword] = ACTIONS(9908),
    [sym_protected_keyword] = ACTIONS(9908),
    [sym_event_keyword] = ACTIONS(9908),
    [sym_fields_keyword] = ACTIONS(9908),
    [sym_keys_keyword] = ACTIONS(9908),
    [sym_fieldgroups_keyword] = ACTIONS(9908),
    [sym_actions_keyword] = ACTIONS(9908),
    [sym_layout_keyword] = ACTIONS(9908),
    [sym_area_keyword] = ACTIONS(9908),
    [sym_group_keyword] = ACTIONS(9908),
    [sym_repeater_keyword] = ACTIONS(9908),
    [sym_cuegroup_keyword] = ACTIONS(9908),
    [sym_fixed_keyword] = ACTIONS(9908),
    [sym_grid_keyword] = ACTIONS(9908),
    [sym_part_keyword] = ACTIONS(9908),
    [sym_systempart_keyword] = ACTIONS(9908),
    [sym_usercontrol_keyword] = ACTIONS(9908),
    [sym_dataset_keyword] = ACTIONS(9908),
    [sym_elements_keyword] = ACTIONS(9908),
    [sym_dataitem_keyword] = ACTIONS(9908),
    [sym_column_keyword] = ACTIONS(9908),
    [sym_filter_keyword] = ACTIONS(9908),
    [sym_labels_keyword] = ACTIONS(9908),
    [sym_rendering_keyword] = ACTIONS(9908),
    [sym_requestpage_keyword] = ACTIONS(9908),
    [sym_schema_keyword] = ACTIONS(9908),
    [sym_views_keyword] = ACTIONS(9908),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9908),
    [sym_preproc_open] = ACTIONS(9908),
    [sym_preproc_close] = ACTIONS(9908),
  },
  [STATE(3706)] = {
    [anon_sym_SEMI] = ACTIONS(9912),
    [aux_sym_where_condition_token1] = ACTIONS(9914),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9912),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9912),
    [anon_sym_LBRACK] = ACTIONS(9912),
    [aux_sym_basic_type_token6] = ACTIONS(9914),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9912),
    [aux_sym_addafter_modification_token1] = ACTIONS(9912),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9912),
    [aux_sym_modify_modification_token1] = ACTIONS(9912),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9912),
    [aux_sym_movelast_modification_token1] = ACTIONS(9912),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9912),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9912),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9912),
    [anon_sym_POUNDif] = ACTIONS(9912),
    [anon_sym_POUNDIF] = ACTIONS(9912),
    [anon_sym_POUNDIf] = ACTIONS(9912),
    [anon_sym_POUNDelif] = ACTIONS(9912),
    [anon_sym_POUNDELIF] = ACTIONS(9912),
    [anon_sym_POUNDElif] = ACTIONS(9912),
    [anon_sym_POUNDelse] = ACTIONS(9912),
    [anon_sym_POUNDELSE] = ACTIONS(9912),
    [anon_sym_POUNDElse] = ACTIONS(9912),
    [anon_sym_POUNDendif] = ACTIONS(9912),
    [anon_sym_POUNDENDIF] = ACTIONS(9912),
    [anon_sym_POUNDEndif] = ACTIONS(9912),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9912),
    [sym_trigger_keyword] = ACTIONS(9912),
    [sym_var_keyword] = ACTIONS(9912),
    [sym_local_keyword] = ACTIONS(9912),
    [sym_internal_keyword] = ACTIONS(9912),
    [sym_protected_keyword] = ACTIONS(9912),
    [sym_event_keyword] = ACTIONS(9912),
    [sym_fields_keyword] = ACTIONS(9912),
    [sym_keys_keyword] = ACTIONS(9912),
    [sym_fieldgroups_keyword] = ACTIONS(9912),
    [sym_actions_keyword] = ACTIONS(9912),
    [sym_layout_keyword] = ACTIONS(9912),
    [sym_area_keyword] = ACTIONS(9912),
    [sym_group_keyword] = ACTIONS(9912),
    [sym_repeater_keyword] = ACTIONS(9912),
    [sym_cuegroup_keyword] = ACTIONS(9912),
    [sym_fixed_keyword] = ACTIONS(9912),
    [sym_grid_keyword] = ACTIONS(9912),
    [sym_part_keyword] = ACTIONS(9912),
    [sym_systempart_keyword] = ACTIONS(9912),
    [sym_usercontrol_keyword] = ACTIONS(9912),
    [sym_dataset_keyword] = ACTIONS(9912),
    [sym_elements_keyword] = ACTIONS(9912),
    [sym_dataitem_keyword] = ACTIONS(9912),
    [sym_column_keyword] = ACTIONS(9912),
    [sym_filter_keyword] = ACTIONS(9912),
    [sym_labels_keyword] = ACTIONS(9912),
    [sym_rendering_keyword] = ACTIONS(9912),
    [sym_requestpage_keyword] = ACTIONS(9912),
    [sym_schema_keyword] = ACTIONS(9912),
    [sym_views_keyword] = ACTIONS(9912),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9912),
    [sym_preproc_open] = ACTIONS(9912),
    [sym_preproc_close] = ACTIONS(9912),
  },
  [STATE(3707)] = {
    [anon_sym_SEMI] = ACTIONS(9912),
    [aux_sym_where_condition_token1] = ACTIONS(9914),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9912),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9912),
    [anon_sym_LBRACK] = ACTIONS(9912),
    [aux_sym_basic_type_token6] = ACTIONS(9914),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9912),
    [aux_sym_addafter_modification_token1] = ACTIONS(9912),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9912),
    [aux_sym_modify_modification_token1] = ACTIONS(9912),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9912),
    [aux_sym_movelast_modification_token1] = ACTIONS(9912),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9912),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9912),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9912),
    [anon_sym_POUNDif] = ACTIONS(9912),
    [anon_sym_POUNDIF] = ACTIONS(9912),
    [anon_sym_POUNDIf] = ACTIONS(9912),
    [anon_sym_POUNDelif] = ACTIONS(9912),
    [anon_sym_POUNDELIF] = ACTIONS(9912),
    [anon_sym_POUNDElif] = ACTIONS(9912),
    [anon_sym_POUNDelse] = ACTIONS(9912),
    [anon_sym_POUNDELSE] = ACTIONS(9912),
    [anon_sym_POUNDElse] = ACTIONS(9912),
    [anon_sym_POUNDendif] = ACTIONS(9912),
    [anon_sym_POUNDENDIF] = ACTIONS(9912),
    [anon_sym_POUNDEndif] = ACTIONS(9912),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9912),
    [sym_trigger_keyword] = ACTIONS(9912),
    [sym_var_keyword] = ACTIONS(9912),
    [sym_local_keyword] = ACTIONS(9912),
    [sym_internal_keyword] = ACTIONS(9912),
    [sym_protected_keyword] = ACTIONS(9912),
    [sym_event_keyword] = ACTIONS(9912),
    [sym_fields_keyword] = ACTIONS(9912),
    [sym_keys_keyword] = ACTIONS(9912),
    [sym_fieldgroups_keyword] = ACTIONS(9912),
    [sym_actions_keyword] = ACTIONS(9912),
    [sym_layout_keyword] = ACTIONS(9912),
    [sym_area_keyword] = ACTIONS(9912),
    [sym_group_keyword] = ACTIONS(9912),
    [sym_repeater_keyword] = ACTIONS(9912),
    [sym_cuegroup_keyword] = ACTIONS(9912),
    [sym_fixed_keyword] = ACTIONS(9912),
    [sym_grid_keyword] = ACTIONS(9912),
    [sym_part_keyword] = ACTIONS(9912),
    [sym_systempart_keyword] = ACTIONS(9912),
    [sym_usercontrol_keyword] = ACTIONS(9912),
    [sym_dataset_keyword] = ACTIONS(9912),
    [sym_elements_keyword] = ACTIONS(9912),
    [sym_dataitem_keyword] = ACTIONS(9912),
    [sym_column_keyword] = ACTIONS(9912),
    [sym_filter_keyword] = ACTIONS(9912),
    [sym_labels_keyword] = ACTIONS(9912),
    [sym_rendering_keyword] = ACTIONS(9912),
    [sym_requestpage_keyword] = ACTIONS(9912),
    [sym_schema_keyword] = ACTIONS(9912),
    [sym_views_keyword] = ACTIONS(9912),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9912),
    [sym_preproc_open] = ACTIONS(9912),
    [sym_preproc_close] = ACTIONS(9912),
  },
  [STATE(3708)] = {
    [anon_sym_SEMI] = ACTIONS(9916),
    [aux_sym_where_condition_token1] = ACTIONS(9918),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9916),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9916),
    [anon_sym_LBRACK] = ACTIONS(9916),
    [aux_sym_basic_type_token6] = ACTIONS(9918),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9916),
    [aux_sym_addafter_modification_token1] = ACTIONS(9916),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9916),
    [aux_sym_modify_modification_token1] = ACTIONS(9916),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9916),
    [aux_sym_movelast_modification_token1] = ACTIONS(9916),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9916),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9916),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9916),
    [anon_sym_POUNDif] = ACTIONS(9916),
    [anon_sym_POUNDIF] = ACTIONS(9916),
    [anon_sym_POUNDIf] = ACTIONS(9916),
    [anon_sym_POUNDelif] = ACTIONS(9916),
    [anon_sym_POUNDELIF] = ACTIONS(9916),
    [anon_sym_POUNDElif] = ACTIONS(9916),
    [anon_sym_POUNDelse] = ACTIONS(9916),
    [anon_sym_POUNDELSE] = ACTIONS(9916),
    [anon_sym_POUNDElse] = ACTIONS(9916),
    [anon_sym_POUNDendif] = ACTIONS(9916),
    [anon_sym_POUNDENDIF] = ACTIONS(9916),
    [anon_sym_POUNDEndif] = ACTIONS(9916),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9916),
    [sym_trigger_keyword] = ACTIONS(9916),
    [sym_var_keyword] = ACTIONS(9916),
    [sym_local_keyword] = ACTIONS(9916),
    [sym_internal_keyword] = ACTIONS(9916),
    [sym_protected_keyword] = ACTIONS(9916),
    [sym_event_keyword] = ACTIONS(9916),
    [sym_fields_keyword] = ACTIONS(9916),
    [sym_keys_keyword] = ACTIONS(9916),
    [sym_fieldgroups_keyword] = ACTIONS(9916),
    [sym_actions_keyword] = ACTIONS(9916),
    [sym_layout_keyword] = ACTIONS(9916),
    [sym_area_keyword] = ACTIONS(9916),
    [sym_group_keyword] = ACTIONS(9916),
    [sym_repeater_keyword] = ACTIONS(9916),
    [sym_cuegroup_keyword] = ACTIONS(9916),
    [sym_fixed_keyword] = ACTIONS(9916),
    [sym_grid_keyword] = ACTIONS(9916),
    [sym_part_keyword] = ACTIONS(9916),
    [sym_systempart_keyword] = ACTIONS(9916),
    [sym_usercontrol_keyword] = ACTIONS(9916),
    [sym_dataset_keyword] = ACTIONS(9916),
    [sym_elements_keyword] = ACTIONS(9916),
    [sym_dataitem_keyword] = ACTIONS(9916),
    [sym_column_keyword] = ACTIONS(9916),
    [sym_filter_keyword] = ACTIONS(9916),
    [sym_labels_keyword] = ACTIONS(9916),
    [sym_rendering_keyword] = ACTIONS(9916),
    [sym_requestpage_keyword] = ACTIONS(9916),
    [sym_schema_keyword] = ACTIONS(9916),
    [sym_views_keyword] = ACTIONS(9916),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9916),
    [sym_preproc_open] = ACTIONS(9916),
    [sym_preproc_close] = ACTIONS(9916),
  },
  [STATE(3709)] = {
    [anon_sym_SEMI] = ACTIONS(9908),
    [aux_sym_where_condition_token1] = ACTIONS(9910),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9908),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9908),
    [anon_sym_LBRACK] = ACTIONS(9908),
    [aux_sym_basic_type_token6] = ACTIONS(9910),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9908),
    [aux_sym_addafter_modification_token1] = ACTIONS(9908),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9908),
    [aux_sym_modify_modification_token1] = ACTIONS(9908),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9908),
    [aux_sym_movelast_modification_token1] = ACTIONS(9908),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9908),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9908),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9908),
    [anon_sym_POUNDif] = ACTIONS(9908),
    [anon_sym_POUNDIF] = ACTIONS(9908),
    [anon_sym_POUNDIf] = ACTIONS(9908),
    [anon_sym_POUNDelif] = ACTIONS(9908),
    [anon_sym_POUNDELIF] = ACTIONS(9908),
    [anon_sym_POUNDElif] = ACTIONS(9908),
    [anon_sym_POUNDelse] = ACTIONS(9908),
    [anon_sym_POUNDELSE] = ACTIONS(9908),
    [anon_sym_POUNDElse] = ACTIONS(9908),
    [anon_sym_POUNDendif] = ACTIONS(9908),
    [anon_sym_POUNDENDIF] = ACTIONS(9908),
    [anon_sym_POUNDEndif] = ACTIONS(9908),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9908),
    [sym_trigger_keyword] = ACTIONS(9908),
    [sym_var_keyword] = ACTIONS(9908),
    [sym_local_keyword] = ACTIONS(9908),
    [sym_internal_keyword] = ACTIONS(9908),
    [sym_protected_keyword] = ACTIONS(9908),
    [sym_event_keyword] = ACTIONS(9908),
    [sym_fields_keyword] = ACTIONS(9908),
    [sym_keys_keyword] = ACTIONS(9908),
    [sym_fieldgroups_keyword] = ACTIONS(9908),
    [sym_actions_keyword] = ACTIONS(9908),
    [sym_layout_keyword] = ACTIONS(9908),
    [sym_area_keyword] = ACTIONS(9908),
    [sym_group_keyword] = ACTIONS(9908),
    [sym_repeater_keyword] = ACTIONS(9908),
    [sym_cuegroup_keyword] = ACTIONS(9908),
    [sym_fixed_keyword] = ACTIONS(9908),
    [sym_grid_keyword] = ACTIONS(9908),
    [sym_part_keyword] = ACTIONS(9908),
    [sym_systempart_keyword] = ACTIONS(9908),
    [sym_usercontrol_keyword] = ACTIONS(9908),
    [sym_dataset_keyword] = ACTIONS(9908),
    [sym_elements_keyword] = ACTIONS(9908),
    [sym_dataitem_keyword] = ACTIONS(9908),
    [sym_column_keyword] = ACTIONS(9908),
    [sym_filter_keyword] = ACTIONS(9908),
    [sym_labels_keyword] = ACTIONS(9908),
    [sym_rendering_keyword] = ACTIONS(9908),
    [sym_requestpage_keyword] = ACTIONS(9908),
    [sym_schema_keyword] = ACTIONS(9908),
    [sym_views_keyword] = ACTIONS(9908),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9908),
    [sym_preproc_open] = ACTIONS(9908),
    [sym_preproc_close] = ACTIONS(9908),
  },
  [STATE(3710)] = {
    [anon_sym_SEMI] = ACTIONS(9920),
    [aux_sym_where_condition_token1] = ACTIONS(9922),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9920),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9920),
    [anon_sym_LBRACK] = ACTIONS(9920),
    [aux_sym_basic_type_token6] = ACTIONS(9922),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9920),
    [aux_sym_addafter_modification_token1] = ACTIONS(9920),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9920),
    [aux_sym_modify_modification_token1] = ACTIONS(9920),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9920),
    [aux_sym_movelast_modification_token1] = ACTIONS(9920),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9920),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9920),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9920),
    [anon_sym_POUNDif] = ACTIONS(9920),
    [anon_sym_POUNDIF] = ACTIONS(9920),
    [anon_sym_POUNDIf] = ACTIONS(9920),
    [anon_sym_POUNDelif] = ACTIONS(9920),
    [anon_sym_POUNDELIF] = ACTIONS(9920),
    [anon_sym_POUNDElif] = ACTIONS(9920),
    [anon_sym_POUNDelse] = ACTIONS(9920),
    [anon_sym_POUNDELSE] = ACTIONS(9920),
    [anon_sym_POUNDElse] = ACTIONS(9920),
    [anon_sym_POUNDendif] = ACTIONS(9920),
    [anon_sym_POUNDENDIF] = ACTIONS(9920),
    [anon_sym_POUNDEndif] = ACTIONS(9920),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9920),
    [sym_trigger_keyword] = ACTIONS(9920),
    [sym_var_keyword] = ACTIONS(9920),
    [sym_local_keyword] = ACTIONS(9920),
    [sym_internal_keyword] = ACTIONS(9920),
    [sym_protected_keyword] = ACTIONS(9920),
    [sym_event_keyword] = ACTIONS(9920),
    [sym_fields_keyword] = ACTIONS(9920),
    [sym_keys_keyword] = ACTIONS(9920),
    [sym_fieldgroups_keyword] = ACTIONS(9920),
    [sym_actions_keyword] = ACTIONS(9920),
    [sym_layout_keyword] = ACTIONS(9920),
    [sym_area_keyword] = ACTIONS(9920),
    [sym_group_keyword] = ACTIONS(9920),
    [sym_repeater_keyword] = ACTIONS(9920),
    [sym_cuegroup_keyword] = ACTIONS(9920),
    [sym_fixed_keyword] = ACTIONS(9920),
    [sym_grid_keyword] = ACTIONS(9920),
    [sym_part_keyword] = ACTIONS(9920),
    [sym_systempart_keyword] = ACTIONS(9920),
    [sym_usercontrol_keyword] = ACTIONS(9920),
    [sym_dataset_keyword] = ACTIONS(9920),
    [sym_elements_keyword] = ACTIONS(9920),
    [sym_dataitem_keyword] = ACTIONS(9920),
    [sym_column_keyword] = ACTIONS(9920),
    [sym_filter_keyword] = ACTIONS(9920),
    [sym_labels_keyword] = ACTIONS(9920),
    [sym_rendering_keyword] = ACTIONS(9920),
    [sym_requestpage_keyword] = ACTIONS(9920),
    [sym_schema_keyword] = ACTIONS(9920),
    [sym_views_keyword] = ACTIONS(9920),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9920),
    [sym_preproc_open] = ACTIONS(9920),
    [sym_preproc_close] = ACTIONS(9920),
  },
  [STATE(3711)] = {
    [anon_sym_SEMI] = ACTIONS(9924),
    [aux_sym_where_condition_token1] = ACTIONS(9926),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9924),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9924),
    [anon_sym_LBRACK] = ACTIONS(9924),
    [aux_sym_basic_type_token6] = ACTIONS(9926),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9924),
    [aux_sym_addafter_modification_token1] = ACTIONS(9924),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9924),
    [aux_sym_modify_modification_token1] = ACTIONS(9924),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9924),
    [aux_sym_movelast_modification_token1] = ACTIONS(9924),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9924),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9924),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9924),
    [anon_sym_POUNDif] = ACTIONS(9924),
    [anon_sym_POUNDIF] = ACTIONS(9924),
    [anon_sym_POUNDIf] = ACTIONS(9924),
    [anon_sym_POUNDelif] = ACTIONS(9924),
    [anon_sym_POUNDELIF] = ACTIONS(9924),
    [anon_sym_POUNDElif] = ACTIONS(9924),
    [anon_sym_POUNDelse] = ACTIONS(9924),
    [anon_sym_POUNDELSE] = ACTIONS(9924),
    [anon_sym_POUNDElse] = ACTIONS(9924),
    [anon_sym_POUNDendif] = ACTIONS(9924),
    [anon_sym_POUNDENDIF] = ACTIONS(9924),
    [anon_sym_POUNDEndif] = ACTIONS(9924),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9924),
    [sym_trigger_keyword] = ACTIONS(9924),
    [sym_var_keyword] = ACTIONS(9924),
    [sym_local_keyword] = ACTIONS(9924),
    [sym_internal_keyword] = ACTIONS(9924),
    [sym_protected_keyword] = ACTIONS(9924),
    [sym_event_keyword] = ACTIONS(9924),
    [sym_fields_keyword] = ACTIONS(9924),
    [sym_keys_keyword] = ACTIONS(9924),
    [sym_fieldgroups_keyword] = ACTIONS(9924),
    [sym_actions_keyword] = ACTIONS(9924),
    [sym_layout_keyword] = ACTIONS(9924),
    [sym_area_keyword] = ACTIONS(9924),
    [sym_group_keyword] = ACTIONS(9924),
    [sym_repeater_keyword] = ACTIONS(9924),
    [sym_cuegroup_keyword] = ACTIONS(9924),
    [sym_fixed_keyword] = ACTIONS(9924),
    [sym_grid_keyword] = ACTIONS(9924),
    [sym_part_keyword] = ACTIONS(9924),
    [sym_systempart_keyword] = ACTIONS(9924),
    [sym_usercontrol_keyword] = ACTIONS(9924),
    [sym_dataset_keyword] = ACTIONS(9924),
    [sym_elements_keyword] = ACTIONS(9924),
    [sym_dataitem_keyword] = ACTIONS(9924),
    [sym_column_keyword] = ACTIONS(9924),
    [sym_filter_keyword] = ACTIONS(9924),
    [sym_labels_keyword] = ACTIONS(9924),
    [sym_rendering_keyword] = ACTIONS(9924),
    [sym_requestpage_keyword] = ACTIONS(9924),
    [sym_schema_keyword] = ACTIONS(9924),
    [sym_views_keyword] = ACTIONS(9924),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9924),
    [sym_preproc_open] = ACTIONS(9924),
    [sym_preproc_close] = ACTIONS(9924),
  },
  [STATE(3712)] = {
    [anon_sym_SEMI] = ACTIONS(9928),
    [aux_sym_where_condition_token1] = ACTIONS(9930),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9928),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9928),
    [anon_sym_LBRACK] = ACTIONS(9928),
    [aux_sym_basic_type_token6] = ACTIONS(9930),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9928),
    [aux_sym_addafter_modification_token1] = ACTIONS(9928),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9928),
    [aux_sym_modify_modification_token1] = ACTIONS(9928),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9928),
    [aux_sym_movelast_modification_token1] = ACTIONS(9928),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9928),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9928),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9928),
    [anon_sym_POUNDif] = ACTIONS(9928),
    [anon_sym_POUNDIF] = ACTIONS(9928),
    [anon_sym_POUNDIf] = ACTIONS(9928),
    [anon_sym_POUNDelif] = ACTIONS(9928),
    [anon_sym_POUNDELIF] = ACTIONS(9928),
    [anon_sym_POUNDElif] = ACTIONS(9928),
    [anon_sym_POUNDelse] = ACTIONS(9928),
    [anon_sym_POUNDELSE] = ACTIONS(9928),
    [anon_sym_POUNDElse] = ACTIONS(9928),
    [anon_sym_POUNDendif] = ACTIONS(9928),
    [anon_sym_POUNDENDIF] = ACTIONS(9928),
    [anon_sym_POUNDEndif] = ACTIONS(9928),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9928),
    [sym_trigger_keyword] = ACTIONS(9928),
    [sym_var_keyword] = ACTIONS(9928),
    [sym_local_keyword] = ACTIONS(9928),
    [sym_internal_keyword] = ACTIONS(9928),
    [sym_protected_keyword] = ACTIONS(9928),
    [sym_event_keyword] = ACTIONS(9928),
    [sym_fields_keyword] = ACTIONS(9928),
    [sym_keys_keyword] = ACTIONS(9928),
    [sym_fieldgroups_keyword] = ACTIONS(9928),
    [sym_actions_keyword] = ACTIONS(9928),
    [sym_layout_keyword] = ACTIONS(9928),
    [sym_area_keyword] = ACTIONS(9928),
    [sym_group_keyword] = ACTIONS(9928),
    [sym_repeater_keyword] = ACTIONS(9928),
    [sym_cuegroup_keyword] = ACTIONS(9928),
    [sym_fixed_keyword] = ACTIONS(9928),
    [sym_grid_keyword] = ACTIONS(9928),
    [sym_part_keyword] = ACTIONS(9928),
    [sym_systempart_keyword] = ACTIONS(9928),
    [sym_usercontrol_keyword] = ACTIONS(9928),
    [sym_dataset_keyword] = ACTIONS(9928),
    [sym_elements_keyword] = ACTIONS(9928),
    [sym_dataitem_keyword] = ACTIONS(9928),
    [sym_column_keyword] = ACTIONS(9928),
    [sym_filter_keyword] = ACTIONS(9928),
    [sym_labels_keyword] = ACTIONS(9928),
    [sym_rendering_keyword] = ACTIONS(9928),
    [sym_requestpage_keyword] = ACTIONS(9928),
    [sym_schema_keyword] = ACTIONS(9928),
    [sym_views_keyword] = ACTIONS(9928),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9928),
    [sym_preproc_open] = ACTIONS(9928),
    [sym_preproc_close] = ACTIONS(9928),
  },
  [STATE(3713)] = {
    [anon_sym_SEMI] = ACTIONS(9932),
    [aux_sym_where_condition_token1] = ACTIONS(9934),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9936),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9936),
    [anon_sym_LBRACK] = ACTIONS(9936),
    [aux_sym_basic_type_token6] = ACTIONS(9934),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9936),
    [aux_sym_addafter_modification_token1] = ACTIONS(9936),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9936),
    [aux_sym_modify_modification_token1] = ACTIONS(9936),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9936),
    [aux_sym_movelast_modification_token1] = ACTIONS(9936),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9936),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9936),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9936),
    [anon_sym_POUNDif] = ACTIONS(9936),
    [anon_sym_POUNDIF] = ACTIONS(9936),
    [anon_sym_POUNDIf] = ACTIONS(9936),
    [anon_sym_POUNDelif] = ACTIONS(9936),
    [anon_sym_POUNDELIF] = ACTIONS(9936),
    [anon_sym_POUNDElif] = ACTIONS(9936),
    [anon_sym_POUNDelse] = ACTIONS(9936),
    [anon_sym_POUNDELSE] = ACTIONS(9936),
    [anon_sym_POUNDElse] = ACTIONS(9936),
    [anon_sym_POUNDendif] = ACTIONS(9936),
    [anon_sym_POUNDENDIF] = ACTIONS(9936),
    [anon_sym_POUNDEndif] = ACTIONS(9936),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9936),
    [sym_trigger_keyword] = ACTIONS(9936),
    [sym_var_keyword] = ACTIONS(9936),
    [sym_local_keyword] = ACTIONS(9936),
    [sym_internal_keyword] = ACTIONS(9936),
    [sym_protected_keyword] = ACTIONS(9936),
    [sym_event_keyword] = ACTIONS(9936),
    [sym_fields_keyword] = ACTIONS(9936),
    [sym_keys_keyword] = ACTIONS(9936),
    [sym_fieldgroups_keyword] = ACTIONS(9936),
    [sym_actions_keyword] = ACTIONS(9936),
    [sym_layout_keyword] = ACTIONS(9936),
    [sym_area_keyword] = ACTIONS(9936),
    [sym_group_keyword] = ACTIONS(9936),
    [sym_repeater_keyword] = ACTIONS(9936),
    [sym_cuegroup_keyword] = ACTIONS(9936),
    [sym_fixed_keyword] = ACTIONS(9936),
    [sym_grid_keyword] = ACTIONS(9936),
    [sym_part_keyword] = ACTIONS(9936),
    [sym_systempart_keyword] = ACTIONS(9936),
    [sym_usercontrol_keyword] = ACTIONS(9936),
    [sym_dataset_keyword] = ACTIONS(9936),
    [sym_elements_keyword] = ACTIONS(9936),
    [sym_dataitem_keyword] = ACTIONS(9936),
    [sym_column_keyword] = ACTIONS(9936),
    [sym_filter_keyword] = ACTIONS(9936),
    [sym_labels_keyword] = ACTIONS(9936),
    [sym_rendering_keyword] = ACTIONS(9936),
    [sym_requestpage_keyword] = ACTIONS(9936),
    [sym_schema_keyword] = ACTIONS(9936),
    [sym_views_keyword] = ACTIONS(9936),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9936),
    [sym_preproc_open] = ACTIONS(9936),
    [sym_preproc_close] = ACTIONS(9936),
  },
  [STATE(3714)] = {
    [anon_sym_SEMI] = ACTIONS(9938),
    [aux_sym_where_condition_token1] = ACTIONS(9940),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9938),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9938),
    [anon_sym_LBRACK] = ACTIONS(9938),
    [aux_sym_basic_type_token6] = ACTIONS(9940),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9938),
    [aux_sym_addafter_modification_token1] = ACTIONS(9938),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9938),
    [aux_sym_modify_modification_token1] = ACTIONS(9938),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9938),
    [aux_sym_movelast_modification_token1] = ACTIONS(9938),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9938),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9938),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9938),
    [anon_sym_POUNDif] = ACTIONS(9938),
    [anon_sym_POUNDIF] = ACTIONS(9938),
    [anon_sym_POUNDIf] = ACTIONS(9938),
    [anon_sym_POUNDelif] = ACTIONS(9938),
    [anon_sym_POUNDELIF] = ACTIONS(9938),
    [anon_sym_POUNDElif] = ACTIONS(9938),
    [anon_sym_POUNDelse] = ACTIONS(9938),
    [anon_sym_POUNDELSE] = ACTIONS(9938),
    [anon_sym_POUNDElse] = ACTIONS(9938),
    [anon_sym_POUNDendif] = ACTIONS(9938),
    [anon_sym_POUNDENDIF] = ACTIONS(9938),
    [anon_sym_POUNDEndif] = ACTIONS(9938),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9938),
    [sym_trigger_keyword] = ACTIONS(9938),
    [sym_var_keyword] = ACTIONS(9938),
    [sym_local_keyword] = ACTIONS(9938),
    [sym_internal_keyword] = ACTIONS(9938),
    [sym_protected_keyword] = ACTIONS(9938),
    [sym_event_keyword] = ACTIONS(9938),
    [sym_fields_keyword] = ACTIONS(9938),
    [sym_keys_keyword] = ACTIONS(9938),
    [sym_fieldgroups_keyword] = ACTIONS(9938),
    [sym_actions_keyword] = ACTIONS(9938),
    [sym_layout_keyword] = ACTIONS(9938),
    [sym_area_keyword] = ACTIONS(9938),
    [sym_group_keyword] = ACTIONS(9938),
    [sym_repeater_keyword] = ACTIONS(9938),
    [sym_cuegroup_keyword] = ACTIONS(9938),
    [sym_fixed_keyword] = ACTIONS(9938),
    [sym_grid_keyword] = ACTIONS(9938),
    [sym_part_keyword] = ACTIONS(9938),
    [sym_systempart_keyword] = ACTIONS(9938),
    [sym_usercontrol_keyword] = ACTIONS(9938),
    [sym_dataset_keyword] = ACTIONS(9938),
    [sym_elements_keyword] = ACTIONS(9938),
    [sym_dataitem_keyword] = ACTIONS(9938),
    [sym_column_keyword] = ACTIONS(9938),
    [sym_filter_keyword] = ACTIONS(9938),
    [sym_labels_keyword] = ACTIONS(9938),
    [sym_rendering_keyword] = ACTIONS(9938),
    [sym_requestpage_keyword] = ACTIONS(9938),
    [sym_schema_keyword] = ACTIONS(9938),
    [sym_views_keyword] = ACTIONS(9938),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9938),
    [sym_preproc_open] = ACTIONS(9938),
    [sym_preproc_close] = ACTIONS(9938),
  },
  [STATE(3715)] = {
    [anon_sym_SEMI] = ACTIONS(9942),
    [aux_sym_where_condition_token1] = ACTIONS(9944),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9942),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9942),
    [anon_sym_LBRACK] = ACTIONS(9942),
    [aux_sym_basic_type_token6] = ACTIONS(9944),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9942),
    [aux_sym_addafter_modification_token1] = ACTIONS(9942),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9942),
    [aux_sym_modify_modification_token1] = ACTIONS(9942),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9942),
    [aux_sym_movelast_modification_token1] = ACTIONS(9942),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9942),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9942),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9942),
    [anon_sym_POUNDif] = ACTIONS(9942),
    [anon_sym_POUNDIF] = ACTIONS(9942),
    [anon_sym_POUNDIf] = ACTIONS(9942),
    [anon_sym_POUNDelif] = ACTIONS(9942),
    [anon_sym_POUNDELIF] = ACTIONS(9942),
    [anon_sym_POUNDElif] = ACTIONS(9942),
    [anon_sym_POUNDelse] = ACTIONS(9942),
    [anon_sym_POUNDELSE] = ACTIONS(9942),
    [anon_sym_POUNDElse] = ACTIONS(9942),
    [anon_sym_POUNDendif] = ACTIONS(9942),
    [anon_sym_POUNDENDIF] = ACTIONS(9942),
    [anon_sym_POUNDEndif] = ACTIONS(9942),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9942),
    [sym_trigger_keyword] = ACTIONS(9942),
    [sym_var_keyword] = ACTIONS(9942),
    [sym_local_keyword] = ACTIONS(9942),
    [sym_internal_keyword] = ACTIONS(9942),
    [sym_protected_keyword] = ACTIONS(9942),
    [sym_event_keyword] = ACTIONS(9942),
    [sym_fields_keyword] = ACTIONS(9942),
    [sym_keys_keyword] = ACTIONS(9942),
    [sym_fieldgroups_keyword] = ACTIONS(9942),
    [sym_actions_keyword] = ACTIONS(9942),
    [sym_layout_keyword] = ACTIONS(9942),
    [sym_area_keyword] = ACTIONS(9942),
    [sym_group_keyword] = ACTIONS(9942),
    [sym_repeater_keyword] = ACTIONS(9942),
    [sym_cuegroup_keyword] = ACTIONS(9942),
    [sym_fixed_keyword] = ACTIONS(9942),
    [sym_grid_keyword] = ACTIONS(9942),
    [sym_part_keyword] = ACTIONS(9942),
    [sym_systempart_keyword] = ACTIONS(9942),
    [sym_usercontrol_keyword] = ACTIONS(9942),
    [sym_dataset_keyword] = ACTIONS(9942),
    [sym_elements_keyword] = ACTIONS(9942),
    [sym_dataitem_keyword] = ACTIONS(9942),
    [sym_column_keyword] = ACTIONS(9942),
    [sym_filter_keyword] = ACTIONS(9942),
    [sym_labels_keyword] = ACTIONS(9942),
    [sym_rendering_keyword] = ACTIONS(9942),
    [sym_requestpage_keyword] = ACTIONS(9942),
    [sym_schema_keyword] = ACTIONS(9942),
    [sym_views_keyword] = ACTIONS(9942),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9942),
    [sym_preproc_open] = ACTIONS(9942),
    [sym_preproc_close] = ACTIONS(9942),
  },
  [STATE(3716)] = {
    [anon_sym_SEMI] = ACTIONS(9928),
    [aux_sym_where_condition_token1] = ACTIONS(9930),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9928),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9928),
    [anon_sym_LBRACK] = ACTIONS(9928),
    [aux_sym_basic_type_token6] = ACTIONS(9930),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9928),
    [aux_sym_addafter_modification_token1] = ACTIONS(9928),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9928),
    [aux_sym_modify_modification_token1] = ACTIONS(9928),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9928),
    [aux_sym_movelast_modification_token1] = ACTIONS(9928),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9928),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9928),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9928),
    [anon_sym_POUNDif] = ACTIONS(9928),
    [anon_sym_POUNDIF] = ACTIONS(9928),
    [anon_sym_POUNDIf] = ACTIONS(9928),
    [anon_sym_POUNDelif] = ACTIONS(9928),
    [anon_sym_POUNDELIF] = ACTIONS(9928),
    [anon_sym_POUNDElif] = ACTIONS(9928),
    [anon_sym_POUNDelse] = ACTIONS(9928),
    [anon_sym_POUNDELSE] = ACTIONS(9928),
    [anon_sym_POUNDElse] = ACTIONS(9928),
    [anon_sym_POUNDendif] = ACTIONS(9928),
    [anon_sym_POUNDENDIF] = ACTIONS(9928),
    [anon_sym_POUNDEndif] = ACTIONS(9928),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9928),
    [sym_trigger_keyword] = ACTIONS(9928),
    [sym_var_keyword] = ACTIONS(9928),
    [sym_local_keyword] = ACTIONS(9928),
    [sym_internal_keyword] = ACTIONS(9928),
    [sym_protected_keyword] = ACTIONS(9928),
    [sym_event_keyword] = ACTIONS(9928),
    [sym_fields_keyword] = ACTIONS(9928),
    [sym_keys_keyword] = ACTIONS(9928),
    [sym_fieldgroups_keyword] = ACTIONS(9928),
    [sym_actions_keyword] = ACTIONS(9928),
    [sym_layout_keyword] = ACTIONS(9928),
    [sym_area_keyword] = ACTIONS(9928),
    [sym_group_keyword] = ACTIONS(9928),
    [sym_repeater_keyword] = ACTIONS(9928),
    [sym_cuegroup_keyword] = ACTIONS(9928),
    [sym_fixed_keyword] = ACTIONS(9928),
    [sym_grid_keyword] = ACTIONS(9928),
    [sym_part_keyword] = ACTIONS(9928),
    [sym_systempart_keyword] = ACTIONS(9928),
    [sym_usercontrol_keyword] = ACTIONS(9928),
    [sym_dataset_keyword] = ACTIONS(9928),
    [sym_elements_keyword] = ACTIONS(9928),
    [sym_dataitem_keyword] = ACTIONS(9928),
    [sym_column_keyword] = ACTIONS(9928),
    [sym_filter_keyword] = ACTIONS(9928),
    [sym_labels_keyword] = ACTIONS(9928),
    [sym_rendering_keyword] = ACTIONS(9928),
    [sym_requestpage_keyword] = ACTIONS(9928),
    [sym_schema_keyword] = ACTIONS(9928),
    [sym_views_keyword] = ACTIONS(9928),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9928),
    [sym_preproc_open] = ACTIONS(9928),
    [sym_preproc_close] = ACTIONS(9928),
  },
  [STATE(3717)] = {
    [anon_sym_SEMI] = ACTIONS(9946),
    [aux_sym_where_condition_token1] = ACTIONS(9948),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9946),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9946),
    [anon_sym_LBRACK] = ACTIONS(9946),
    [aux_sym_basic_type_token6] = ACTIONS(9948),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9946),
    [aux_sym_addafter_modification_token1] = ACTIONS(9946),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9946),
    [aux_sym_modify_modification_token1] = ACTIONS(9946),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9946),
    [aux_sym_movelast_modification_token1] = ACTIONS(9946),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9946),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9946),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9946),
    [anon_sym_POUNDif] = ACTIONS(9946),
    [anon_sym_POUNDIF] = ACTIONS(9946),
    [anon_sym_POUNDIf] = ACTIONS(9946),
    [anon_sym_POUNDelif] = ACTIONS(9946),
    [anon_sym_POUNDELIF] = ACTIONS(9946),
    [anon_sym_POUNDElif] = ACTIONS(9946),
    [anon_sym_POUNDelse] = ACTIONS(9946),
    [anon_sym_POUNDELSE] = ACTIONS(9946),
    [anon_sym_POUNDElse] = ACTIONS(9946),
    [anon_sym_POUNDendif] = ACTIONS(9946),
    [anon_sym_POUNDENDIF] = ACTIONS(9946),
    [anon_sym_POUNDEndif] = ACTIONS(9946),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9946),
    [sym_trigger_keyword] = ACTIONS(9946),
    [sym_var_keyword] = ACTIONS(9946),
    [sym_local_keyword] = ACTIONS(9946),
    [sym_internal_keyword] = ACTIONS(9946),
    [sym_protected_keyword] = ACTIONS(9946),
    [sym_event_keyword] = ACTIONS(9946),
    [sym_fields_keyword] = ACTIONS(9946),
    [sym_keys_keyword] = ACTIONS(9946),
    [sym_fieldgroups_keyword] = ACTIONS(9946),
    [sym_actions_keyword] = ACTIONS(9946),
    [sym_layout_keyword] = ACTIONS(9946),
    [sym_area_keyword] = ACTIONS(9946),
    [sym_group_keyword] = ACTIONS(9946),
    [sym_repeater_keyword] = ACTIONS(9946),
    [sym_cuegroup_keyword] = ACTIONS(9946),
    [sym_fixed_keyword] = ACTIONS(9946),
    [sym_grid_keyword] = ACTIONS(9946),
    [sym_part_keyword] = ACTIONS(9946),
    [sym_systempart_keyword] = ACTIONS(9946),
    [sym_usercontrol_keyword] = ACTIONS(9946),
    [sym_dataset_keyword] = ACTIONS(9946),
    [sym_elements_keyword] = ACTIONS(9946),
    [sym_dataitem_keyword] = ACTIONS(9946),
    [sym_column_keyword] = ACTIONS(9946),
    [sym_filter_keyword] = ACTIONS(9946),
    [sym_labels_keyword] = ACTIONS(9946),
    [sym_rendering_keyword] = ACTIONS(9946),
    [sym_requestpage_keyword] = ACTIONS(9946),
    [sym_schema_keyword] = ACTIONS(9946),
    [sym_views_keyword] = ACTIONS(9946),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9946),
    [sym_preproc_open] = ACTIONS(9946),
    [sym_preproc_close] = ACTIONS(9946),
  },
  [STATE(3718)] = {
    [anon_sym_SEMI] = ACTIONS(9938),
    [aux_sym_where_condition_token1] = ACTIONS(9940),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9938),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9938),
    [anon_sym_LBRACK] = ACTIONS(9938),
    [aux_sym_basic_type_token6] = ACTIONS(9940),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9938),
    [aux_sym_addafter_modification_token1] = ACTIONS(9938),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9938),
    [aux_sym_modify_modification_token1] = ACTIONS(9938),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9938),
    [aux_sym_movelast_modification_token1] = ACTIONS(9938),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9938),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9938),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9938),
    [anon_sym_POUNDif] = ACTIONS(9938),
    [anon_sym_POUNDIF] = ACTIONS(9938),
    [anon_sym_POUNDIf] = ACTIONS(9938),
    [anon_sym_POUNDelif] = ACTIONS(9938),
    [anon_sym_POUNDELIF] = ACTIONS(9938),
    [anon_sym_POUNDElif] = ACTIONS(9938),
    [anon_sym_POUNDelse] = ACTIONS(9938),
    [anon_sym_POUNDELSE] = ACTIONS(9938),
    [anon_sym_POUNDElse] = ACTIONS(9938),
    [anon_sym_POUNDendif] = ACTIONS(9938),
    [anon_sym_POUNDENDIF] = ACTIONS(9938),
    [anon_sym_POUNDEndif] = ACTIONS(9938),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9938),
    [sym_trigger_keyword] = ACTIONS(9938),
    [sym_var_keyword] = ACTIONS(9938),
    [sym_local_keyword] = ACTIONS(9938),
    [sym_internal_keyword] = ACTIONS(9938),
    [sym_protected_keyword] = ACTIONS(9938),
    [sym_event_keyword] = ACTIONS(9938),
    [sym_fields_keyword] = ACTIONS(9938),
    [sym_keys_keyword] = ACTIONS(9938),
    [sym_fieldgroups_keyword] = ACTIONS(9938),
    [sym_actions_keyword] = ACTIONS(9938),
    [sym_layout_keyword] = ACTIONS(9938),
    [sym_area_keyword] = ACTIONS(9938),
    [sym_group_keyword] = ACTIONS(9938),
    [sym_repeater_keyword] = ACTIONS(9938),
    [sym_cuegroup_keyword] = ACTIONS(9938),
    [sym_fixed_keyword] = ACTIONS(9938),
    [sym_grid_keyword] = ACTIONS(9938),
    [sym_part_keyword] = ACTIONS(9938),
    [sym_systempart_keyword] = ACTIONS(9938),
    [sym_usercontrol_keyword] = ACTIONS(9938),
    [sym_dataset_keyword] = ACTIONS(9938),
    [sym_elements_keyword] = ACTIONS(9938),
    [sym_dataitem_keyword] = ACTIONS(9938),
    [sym_column_keyword] = ACTIONS(9938),
    [sym_filter_keyword] = ACTIONS(9938),
    [sym_labels_keyword] = ACTIONS(9938),
    [sym_rendering_keyword] = ACTIONS(9938),
    [sym_requestpage_keyword] = ACTIONS(9938),
    [sym_schema_keyword] = ACTIONS(9938),
    [sym_views_keyword] = ACTIONS(9938),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9938),
    [sym_preproc_open] = ACTIONS(9938),
    [sym_preproc_close] = ACTIONS(9938),
  },
  [STATE(3719)] = {
    [anon_sym_SEMI] = ACTIONS(9950),
    [aux_sym_where_condition_token1] = ACTIONS(9952),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9950),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9950),
    [anon_sym_LBRACK] = ACTIONS(9950),
    [aux_sym_basic_type_token6] = ACTIONS(9952),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9950),
    [aux_sym_addafter_modification_token1] = ACTIONS(9950),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9950),
    [aux_sym_modify_modification_token1] = ACTIONS(9950),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9950),
    [aux_sym_movelast_modification_token1] = ACTIONS(9950),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9950),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9950),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9950),
    [anon_sym_POUNDif] = ACTIONS(9950),
    [anon_sym_POUNDIF] = ACTIONS(9950),
    [anon_sym_POUNDIf] = ACTIONS(9950),
    [anon_sym_POUNDelif] = ACTIONS(9950),
    [anon_sym_POUNDELIF] = ACTIONS(9950),
    [anon_sym_POUNDElif] = ACTIONS(9950),
    [anon_sym_POUNDelse] = ACTIONS(9950),
    [anon_sym_POUNDELSE] = ACTIONS(9950),
    [anon_sym_POUNDElse] = ACTIONS(9950),
    [anon_sym_POUNDendif] = ACTIONS(9950),
    [anon_sym_POUNDENDIF] = ACTIONS(9950),
    [anon_sym_POUNDEndif] = ACTIONS(9950),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9950),
    [sym_trigger_keyword] = ACTIONS(9950),
    [sym_var_keyword] = ACTIONS(9950),
    [sym_local_keyword] = ACTIONS(9950),
    [sym_internal_keyword] = ACTIONS(9950),
    [sym_protected_keyword] = ACTIONS(9950),
    [sym_event_keyword] = ACTIONS(9950),
    [sym_fields_keyword] = ACTIONS(9950),
    [sym_keys_keyword] = ACTIONS(9950),
    [sym_fieldgroups_keyword] = ACTIONS(9950),
    [sym_actions_keyword] = ACTIONS(9950),
    [sym_layout_keyword] = ACTIONS(9950),
    [sym_area_keyword] = ACTIONS(9950),
    [sym_group_keyword] = ACTIONS(9950),
    [sym_repeater_keyword] = ACTIONS(9950),
    [sym_cuegroup_keyword] = ACTIONS(9950),
    [sym_fixed_keyword] = ACTIONS(9950),
    [sym_grid_keyword] = ACTIONS(9950),
    [sym_part_keyword] = ACTIONS(9950),
    [sym_systempart_keyword] = ACTIONS(9950),
    [sym_usercontrol_keyword] = ACTIONS(9950),
    [sym_dataset_keyword] = ACTIONS(9950),
    [sym_elements_keyword] = ACTIONS(9950),
    [sym_dataitem_keyword] = ACTIONS(9950),
    [sym_column_keyword] = ACTIONS(9950),
    [sym_filter_keyword] = ACTIONS(9950),
    [sym_labels_keyword] = ACTIONS(9950),
    [sym_rendering_keyword] = ACTIONS(9950),
    [sym_requestpage_keyword] = ACTIONS(9950),
    [sym_schema_keyword] = ACTIONS(9950),
    [sym_views_keyword] = ACTIONS(9950),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9950),
    [sym_preproc_open] = ACTIONS(9950),
    [sym_preproc_close] = ACTIONS(9950),
  },
  [STATE(3720)] = {
    [anon_sym_SEMI] = ACTIONS(9954),
    [aux_sym_where_condition_token1] = ACTIONS(9956),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9954),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9954),
    [anon_sym_LBRACK] = ACTIONS(9954),
    [aux_sym_basic_type_token6] = ACTIONS(9956),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9954),
    [aux_sym_addafter_modification_token1] = ACTIONS(9954),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9954),
    [aux_sym_modify_modification_token1] = ACTIONS(9954),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9954),
    [aux_sym_movelast_modification_token1] = ACTIONS(9954),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9954),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9954),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9954),
    [anon_sym_POUNDif] = ACTIONS(9954),
    [anon_sym_POUNDIF] = ACTIONS(9954),
    [anon_sym_POUNDIf] = ACTIONS(9954),
    [anon_sym_POUNDelif] = ACTIONS(9954),
    [anon_sym_POUNDELIF] = ACTIONS(9954),
    [anon_sym_POUNDElif] = ACTIONS(9954),
    [anon_sym_POUNDelse] = ACTIONS(9954),
    [anon_sym_POUNDELSE] = ACTIONS(9954),
    [anon_sym_POUNDElse] = ACTIONS(9954),
    [anon_sym_POUNDendif] = ACTIONS(9954),
    [anon_sym_POUNDENDIF] = ACTIONS(9954),
    [anon_sym_POUNDEndif] = ACTIONS(9954),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9954),
    [sym_trigger_keyword] = ACTIONS(9954),
    [sym_var_keyword] = ACTIONS(9954),
    [sym_local_keyword] = ACTIONS(9954),
    [sym_internal_keyword] = ACTIONS(9954),
    [sym_protected_keyword] = ACTIONS(9954),
    [sym_event_keyword] = ACTIONS(9954),
    [sym_fields_keyword] = ACTIONS(9954),
    [sym_keys_keyword] = ACTIONS(9954),
    [sym_fieldgroups_keyword] = ACTIONS(9954),
    [sym_actions_keyword] = ACTIONS(9954),
    [sym_layout_keyword] = ACTIONS(9954),
    [sym_area_keyword] = ACTIONS(9954),
    [sym_group_keyword] = ACTIONS(9954),
    [sym_repeater_keyword] = ACTIONS(9954),
    [sym_cuegroup_keyword] = ACTIONS(9954),
    [sym_fixed_keyword] = ACTIONS(9954),
    [sym_grid_keyword] = ACTIONS(9954),
    [sym_part_keyword] = ACTIONS(9954),
    [sym_systempart_keyword] = ACTIONS(9954),
    [sym_usercontrol_keyword] = ACTIONS(9954),
    [sym_dataset_keyword] = ACTIONS(9954),
    [sym_elements_keyword] = ACTIONS(9954),
    [sym_dataitem_keyword] = ACTIONS(9954),
    [sym_column_keyword] = ACTIONS(9954),
    [sym_filter_keyword] = ACTIONS(9954),
    [sym_labels_keyword] = ACTIONS(9954),
    [sym_rendering_keyword] = ACTIONS(9954),
    [sym_requestpage_keyword] = ACTIONS(9954),
    [sym_schema_keyword] = ACTIONS(9954),
    [sym_views_keyword] = ACTIONS(9954),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9954),
    [sym_preproc_open] = ACTIONS(9954),
    [sym_preproc_close] = ACTIONS(9954),
  },
  [STATE(3721)] = {
    [anon_sym_SEMI] = ACTIONS(9958),
    [aux_sym_where_condition_token1] = ACTIONS(9960),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9962),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9962),
    [anon_sym_LBRACK] = ACTIONS(9962),
    [aux_sym_basic_type_token6] = ACTIONS(9960),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9962),
    [aux_sym_addafter_modification_token1] = ACTIONS(9962),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9962),
    [aux_sym_modify_modification_token1] = ACTIONS(9962),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9962),
    [aux_sym_movelast_modification_token1] = ACTIONS(9962),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9962),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9962),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9962),
    [anon_sym_POUNDif] = ACTIONS(9962),
    [anon_sym_POUNDIF] = ACTIONS(9962),
    [anon_sym_POUNDIf] = ACTIONS(9962),
    [anon_sym_POUNDelif] = ACTIONS(9962),
    [anon_sym_POUNDELIF] = ACTIONS(9962),
    [anon_sym_POUNDElif] = ACTIONS(9962),
    [anon_sym_POUNDelse] = ACTIONS(9962),
    [anon_sym_POUNDELSE] = ACTIONS(9962),
    [anon_sym_POUNDElse] = ACTIONS(9962),
    [anon_sym_POUNDendif] = ACTIONS(9962),
    [anon_sym_POUNDENDIF] = ACTIONS(9962),
    [anon_sym_POUNDEndif] = ACTIONS(9962),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9962),
    [sym_trigger_keyword] = ACTIONS(9962),
    [sym_var_keyword] = ACTIONS(9962),
    [sym_local_keyword] = ACTIONS(9962),
    [sym_internal_keyword] = ACTIONS(9962),
    [sym_protected_keyword] = ACTIONS(9962),
    [sym_event_keyword] = ACTIONS(9962),
    [sym_fields_keyword] = ACTIONS(9962),
    [sym_keys_keyword] = ACTIONS(9962),
    [sym_fieldgroups_keyword] = ACTIONS(9962),
    [sym_actions_keyword] = ACTIONS(9962),
    [sym_layout_keyword] = ACTIONS(9962),
    [sym_area_keyword] = ACTIONS(9962),
    [sym_group_keyword] = ACTIONS(9962),
    [sym_repeater_keyword] = ACTIONS(9962),
    [sym_cuegroup_keyword] = ACTIONS(9962),
    [sym_fixed_keyword] = ACTIONS(9962),
    [sym_grid_keyword] = ACTIONS(9962),
    [sym_part_keyword] = ACTIONS(9962),
    [sym_systempart_keyword] = ACTIONS(9962),
    [sym_usercontrol_keyword] = ACTIONS(9962),
    [sym_dataset_keyword] = ACTIONS(9962),
    [sym_elements_keyword] = ACTIONS(9962),
    [sym_dataitem_keyword] = ACTIONS(9962),
    [sym_column_keyword] = ACTIONS(9962),
    [sym_filter_keyword] = ACTIONS(9962),
    [sym_labels_keyword] = ACTIONS(9962),
    [sym_rendering_keyword] = ACTIONS(9962),
    [sym_requestpage_keyword] = ACTIONS(9962),
    [sym_schema_keyword] = ACTIONS(9962),
    [sym_views_keyword] = ACTIONS(9962),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9962),
    [sym_preproc_open] = ACTIONS(9962),
    [sym_preproc_close] = ACTIONS(9962),
  },
  [STATE(3722)] = {
    [anon_sym_SEMI] = ACTIONS(9964),
    [aux_sym_where_condition_token1] = ACTIONS(9966),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9964),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9964),
    [anon_sym_LBRACK] = ACTIONS(9968),
    [aux_sym_basic_type_token6] = ACTIONS(9966),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9964),
    [aux_sym_addafter_modification_token1] = ACTIONS(9964),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9964),
    [aux_sym_modify_modification_token1] = ACTIONS(9964),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9964),
    [aux_sym_movelast_modification_token1] = ACTIONS(9964),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9964),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9964),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9964),
    [anon_sym_POUNDif] = ACTIONS(9964),
    [anon_sym_POUNDIF] = ACTIONS(9964),
    [anon_sym_POUNDIf] = ACTIONS(9964),
    [anon_sym_POUNDelif] = ACTIONS(9964),
    [anon_sym_POUNDELIF] = ACTIONS(9964),
    [anon_sym_POUNDElif] = ACTIONS(9964),
    [anon_sym_POUNDelse] = ACTIONS(9964),
    [anon_sym_POUNDELSE] = ACTIONS(9964),
    [anon_sym_POUNDElse] = ACTIONS(9964),
    [anon_sym_POUNDendif] = ACTIONS(9964),
    [anon_sym_POUNDENDIF] = ACTIONS(9964),
    [anon_sym_POUNDEndif] = ACTIONS(9964),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9968),
    [sym_trigger_keyword] = ACTIONS(9964),
    [sym_var_keyword] = ACTIONS(9964),
    [sym_local_keyword] = ACTIONS(9968),
    [sym_internal_keyword] = ACTIONS(9968),
    [sym_protected_keyword] = ACTIONS(9968),
    [sym_event_keyword] = ACTIONS(9964),
    [sym_fields_keyword] = ACTIONS(9964),
    [sym_keys_keyword] = ACTIONS(9964),
    [sym_fieldgroups_keyword] = ACTIONS(9964),
    [sym_actions_keyword] = ACTIONS(9964),
    [sym_layout_keyword] = ACTIONS(9964),
    [sym_area_keyword] = ACTIONS(9964),
    [sym_group_keyword] = ACTIONS(9964),
    [sym_repeater_keyword] = ACTIONS(9964),
    [sym_cuegroup_keyword] = ACTIONS(9964),
    [sym_fixed_keyword] = ACTIONS(9964),
    [sym_grid_keyword] = ACTIONS(9964),
    [sym_part_keyword] = ACTIONS(9964),
    [sym_systempart_keyword] = ACTIONS(9964),
    [sym_usercontrol_keyword] = ACTIONS(9964),
    [sym_dataset_keyword] = ACTIONS(9964),
    [sym_elements_keyword] = ACTIONS(9964),
    [sym_dataitem_keyword] = ACTIONS(9964),
    [sym_column_keyword] = ACTIONS(9964),
    [sym_filter_keyword] = ACTIONS(9964),
    [sym_labels_keyword] = ACTIONS(9964),
    [sym_rendering_keyword] = ACTIONS(9964),
    [sym_requestpage_keyword] = ACTIONS(9964),
    [sym_schema_keyword] = ACTIONS(9964),
    [sym_views_keyword] = ACTIONS(9964),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9964),
    [sym_preproc_open] = ACTIONS(9964),
    [sym_preproc_close] = ACTIONS(9964),
  },
  [STATE(3723)] = {
    [anon_sym_SEMI] = ACTIONS(9971),
    [aux_sym_where_condition_token1] = ACTIONS(9973),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9971),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9971),
    [anon_sym_LBRACK] = ACTIONS(9971),
    [aux_sym_basic_type_token6] = ACTIONS(9973),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9971),
    [aux_sym_addafter_modification_token1] = ACTIONS(9971),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9971),
    [aux_sym_modify_modification_token1] = ACTIONS(9971),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9971),
    [aux_sym_movelast_modification_token1] = ACTIONS(9971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9971),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9971),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9971),
    [anon_sym_POUNDif] = ACTIONS(9971),
    [anon_sym_POUNDIF] = ACTIONS(9971),
    [anon_sym_POUNDIf] = ACTIONS(9971),
    [anon_sym_POUNDelif] = ACTIONS(9971),
    [anon_sym_POUNDELIF] = ACTIONS(9971),
    [anon_sym_POUNDElif] = ACTIONS(9971),
    [anon_sym_POUNDelse] = ACTIONS(9971),
    [anon_sym_POUNDELSE] = ACTIONS(9971),
    [anon_sym_POUNDElse] = ACTIONS(9971),
    [anon_sym_POUNDendif] = ACTIONS(9971),
    [anon_sym_POUNDENDIF] = ACTIONS(9971),
    [anon_sym_POUNDEndif] = ACTIONS(9971),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9971),
    [sym_trigger_keyword] = ACTIONS(9971),
    [sym_var_keyword] = ACTIONS(9971),
    [sym_local_keyword] = ACTIONS(9971),
    [sym_internal_keyword] = ACTIONS(9971),
    [sym_protected_keyword] = ACTIONS(9971),
    [sym_event_keyword] = ACTIONS(9971),
    [sym_fields_keyword] = ACTIONS(9971),
    [sym_keys_keyword] = ACTIONS(9971),
    [sym_fieldgroups_keyword] = ACTIONS(9971),
    [sym_actions_keyword] = ACTIONS(9971),
    [sym_layout_keyword] = ACTIONS(9971),
    [sym_area_keyword] = ACTIONS(9971),
    [sym_group_keyword] = ACTIONS(9971),
    [sym_repeater_keyword] = ACTIONS(9971),
    [sym_cuegroup_keyword] = ACTIONS(9971),
    [sym_fixed_keyword] = ACTIONS(9971),
    [sym_grid_keyword] = ACTIONS(9971),
    [sym_part_keyword] = ACTIONS(9971),
    [sym_systempart_keyword] = ACTIONS(9971),
    [sym_usercontrol_keyword] = ACTIONS(9971),
    [sym_dataset_keyword] = ACTIONS(9971),
    [sym_elements_keyword] = ACTIONS(9971),
    [sym_dataitem_keyword] = ACTIONS(9971),
    [sym_column_keyword] = ACTIONS(9971),
    [sym_filter_keyword] = ACTIONS(9971),
    [sym_labels_keyword] = ACTIONS(9971),
    [sym_rendering_keyword] = ACTIONS(9971),
    [sym_requestpage_keyword] = ACTIONS(9971),
    [sym_schema_keyword] = ACTIONS(9971),
    [sym_views_keyword] = ACTIONS(9971),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9971),
    [sym_preproc_open] = ACTIONS(9971),
    [sym_preproc_close] = ACTIONS(9971),
  },
  [STATE(3724)] = {
    [anon_sym_SEMI] = ACTIONS(9975),
    [aux_sym_where_condition_token1] = ACTIONS(9934),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9936),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9936),
    [anon_sym_LBRACK] = ACTIONS(9936),
    [aux_sym_basic_type_token6] = ACTIONS(9934),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9936),
    [aux_sym_addafter_modification_token1] = ACTIONS(9936),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9936),
    [aux_sym_modify_modification_token1] = ACTIONS(9936),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9936),
    [aux_sym_movelast_modification_token1] = ACTIONS(9936),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9936),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9936),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9936),
    [anon_sym_POUNDif] = ACTIONS(9936),
    [anon_sym_POUNDIF] = ACTIONS(9936),
    [anon_sym_POUNDIf] = ACTIONS(9936),
    [anon_sym_POUNDelif] = ACTIONS(9936),
    [anon_sym_POUNDELIF] = ACTIONS(9936),
    [anon_sym_POUNDElif] = ACTIONS(9936),
    [anon_sym_POUNDelse] = ACTIONS(9936),
    [anon_sym_POUNDELSE] = ACTIONS(9936),
    [anon_sym_POUNDElse] = ACTIONS(9936),
    [anon_sym_POUNDendif] = ACTIONS(9936),
    [anon_sym_POUNDENDIF] = ACTIONS(9936),
    [anon_sym_POUNDEndif] = ACTIONS(9936),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9936),
    [sym_trigger_keyword] = ACTIONS(9936),
    [sym_var_keyword] = ACTIONS(9936),
    [sym_local_keyword] = ACTIONS(9936),
    [sym_internal_keyword] = ACTIONS(9936),
    [sym_protected_keyword] = ACTIONS(9936),
    [sym_event_keyword] = ACTIONS(9936),
    [sym_fields_keyword] = ACTIONS(9936),
    [sym_keys_keyword] = ACTIONS(9936),
    [sym_fieldgroups_keyword] = ACTIONS(9936),
    [sym_actions_keyword] = ACTIONS(9936),
    [sym_layout_keyword] = ACTIONS(9936),
    [sym_area_keyword] = ACTIONS(9936),
    [sym_group_keyword] = ACTIONS(9936),
    [sym_repeater_keyword] = ACTIONS(9936),
    [sym_cuegroup_keyword] = ACTIONS(9936),
    [sym_fixed_keyword] = ACTIONS(9936),
    [sym_grid_keyword] = ACTIONS(9936),
    [sym_part_keyword] = ACTIONS(9936),
    [sym_systempart_keyword] = ACTIONS(9936),
    [sym_usercontrol_keyword] = ACTIONS(9936),
    [sym_dataset_keyword] = ACTIONS(9936),
    [sym_elements_keyword] = ACTIONS(9936),
    [sym_dataitem_keyword] = ACTIONS(9936),
    [sym_column_keyword] = ACTIONS(9936),
    [sym_filter_keyword] = ACTIONS(9936),
    [sym_labels_keyword] = ACTIONS(9936),
    [sym_rendering_keyword] = ACTIONS(9936),
    [sym_requestpage_keyword] = ACTIONS(9936),
    [sym_schema_keyword] = ACTIONS(9936),
    [sym_views_keyword] = ACTIONS(9936),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9936),
    [sym_preproc_open] = ACTIONS(9936),
    [sym_preproc_close] = ACTIONS(9936),
  },
  [STATE(3725)] = {
    [anon_sym_SEMI] = ACTIONS(9977),
    [aux_sym_where_condition_token1] = ACTIONS(9960),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9962),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9962),
    [anon_sym_LBRACK] = ACTIONS(9962),
    [aux_sym_basic_type_token6] = ACTIONS(9960),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9962),
    [aux_sym_addafter_modification_token1] = ACTIONS(9962),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9962),
    [aux_sym_modify_modification_token1] = ACTIONS(9962),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9962),
    [aux_sym_movelast_modification_token1] = ACTIONS(9962),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9962),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9962),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9962),
    [anon_sym_POUNDif] = ACTIONS(9962),
    [anon_sym_POUNDIF] = ACTIONS(9962),
    [anon_sym_POUNDIf] = ACTIONS(9962),
    [anon_sym_POUNDelif] = ACTIONS(9962),
    [anon_sym_POUNDELIF] = ACTIONS(9962),
    [anon_sym_POUNDElif] = ACTIONS(9962),
    [anon_sym_POUNDelse] = ACTIONS(9962),
    [anon_sym_POUNDELSE] = ACTIONS(9962),
    [anon_sym_POUNDElse] = ACTIONS(9962),
    [anon_sym_POUNDendif] = ACTIONS(9962),
    [anon_sym_POUNDENDIF] = ACTIONS(9962),
    [anon_sym_POUNDEndif] = ACTIONS(9962),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9962),
    [sym_trigger_keyword] = ACTIONS(9962),
    [sym_var_keyword] = ACTIONS(9962),
    [sym_local_keyword] = ACTIONS(9962),
    [sym_internal_keyword] = ACTIONS(9962),
    [sym_protected_keyword] = ACTIONS(9962),
    [sym_event_keyword] = ACTIONS(9962),
    [sym_fields_keyword] = ACTIONS(9962),
    [sym_keys_keyword] = ACTIONS(9962),
    [sym_fieldgroups_keyword] = ACTIONS(9962),
    [sym_actions_keyword] = ACTIONS(9962),
    [sym_layout_keyword] = ACTIONS(9962),
    [sym_area_keyword] = ACTIONS(9962),
    [sym_group_keyword] = ACTIONS(9962),
    [sym_repeater_keyword] = ACTIONS(9962),
    [sym_cuegroup_keyword] = ACTIONS(9962),
    [sym_fixed_keyword] = ACTIONS(9962),
    [sym_grid_keyword] = ACTIONS(9962),
    [sym_part_keyword] = ACTIONS(9962),
    [sym_systempart_keyword] = ACTIONS(9962),
    [sym_usercontrol_keyword] = ACTIONS(9962),
    [sym_dataset_keyword] = ACTIONS(9962),
    [sym_elements_keyword] = ACTIONS(9962),
    [sym_dataitem_keyword] = ACTIONS(9962),
    [sym_column_keyword] = ACTIONS(9962),
    [sym_filter_keyword] = ACTIONS(9962),
    [sym_labels_keyword] = ACTIONS(9962),
    [sym_rendering_keyword] = ACTIONS(9962),
    [sym_requestpage_keyword] = ACTIONS(9962),
    [sym_schema_keyword] = ACTIONS(9962),
    [sym_views_keyword] = ACTIONS(9962),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9962),
    [sym_preproc_open] = ACTIONS(9962),
    [sym_preproc_close] = ACTIONS(9962),
  },
  [STATE(3726)] = {
    [anon_sym_SEMI] = ACTIONS(9979),
    [aux_sym_where_condition_token1] = ACTIONS(9981),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9979),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9979),
    [anon_sym_LBRACK] = ACTIONS(9979),
    [aux_sym_basic_type_token6] = ACTIONS(9981),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9979),
    [aux_sym_addafter_modification_token1] = ACTIONS(9979),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9979),
    [aux_sym_modify_modification_token1] = ACTIONS(9979),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9979),
    [aux_sym_movelast_modification_token1] = ACTIONS(9979),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9979),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9979),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9979),
    [anon_sym_POUNDif] = ACTIONS(9979),
    [anon_sym_POUNDIF] = ACTIONS(9979),
    [anon_sym_POUNDIf] = ACTIONS(9979),
    [anon_sym_POUNDelif] = ACTIONS(9979),
    [anon_sym_POUNDELIF] = ACTIONS(9979),
    [anon_sym_POUNDElif] = ACTIONS(9979),
    [anon_sym_POUNDelse] = ACTIONS(9979),
    [anon_sym_POUNDELSE] = ACTIONS(9979),
    [anon_sym_POUNDElse] = ACTIONS(9979),
    [anon_sym_POUNDendif] = ACTIONS(9979),
    [anon_sym_POUNDENDIF] = ACTIONS(9979),
    [anon_sym_POUNDEndif] = ACTIONS(9979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9979),
    [sym_trigger_keyword] = ACTIONS(9979),
    [sym_var_keyword] = ACTIONS(9979),
    [sym_local_keyword] = ACTIONS(9979),
    [sym_internal_keyword] = ACTIONS(9979),
    [sym_protected_keyword] = ACTIONS(9979),
    [sym_event_keyword] = ACTIONS(9979),
    [sym_fields_keyword] = ACTIONS(9979),
    [sym_keys_keyword] = ACTIONS(9979),
    [sym_fieldgroups_keyword] = ACTIONS(9979),
    [sym_actions_keyword] = ACTIONS(9979),
    [sym_layout_keyword] = ACTIONS(9979),
    [sym_area_keyword] = ACTIONS(9979),
    [sym_group_keyword] = ACTIONS(9979),
    [sym_repeater_keyword] = ACTIONS(9979),
    [sym_cuegroup_keyword] = ACTIONS(9979),
    [sym_fixed_keyword] = ACTIONS(9979),
    [sym_grid_keyword] = ACTIONS(9979),
    [sym_part_keyword] = ACTIONS(9979),
    [sym_systempart_keyword] = ACTIONS(9979),
    [sym_usercontrol_keyword] = ACTIONS(9979),
    [sym_dataset_keyword] = ACTIONS(9979),
    [sym_elements_keyword] = ACTIONS(9979),
    [sym_dataitem_keyword] = ACTIONS(9979),
    [sym_column_keyword] = ACTIONS(9979),
    [sym_filter_keyword] = ACTIONS(9979),
    [sym_labels_keyword] = ACTIONS(9979),
    [sym_rendering_keyword] = ACTIONS(9979),
    [sym_requestpage_keyword] = ACTIONS(9979),
    [sym_schema_keyword] = ACTIONS(9979),
    [sym_views_keyword] = ACTIONS(9979),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9979),
    [sym_preproc_open] = ACTIONS(9979),
    [sym_preproc_close] = ACTIONS(9979),
  },
  [STATE(3727)] = {
    [anon_sym_SEMI] = ACTIONS(9979),
    [aux_sym_where_condition_token1] = ACTIONS(9981),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9979),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9979),
    [anon_sym_LBRACK] = ACTIONS(9979),
    [aux_sym_basic_type_token6] = ACTIONS(9981),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9979),
    [aux_sym_addafter_modification_token1] = ACTIONS(9979),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9979),
    [aux_sym_modify_modification_token1] = ACTIONS(9979),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9979),
    [aux_sym_movelast_modification_token1] = ACTIONS(9979),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9979),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9979),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9979),
    [anon_sym_POUNDif] = ACTIONS(9979),
    [anon_sym_POUNDIF] = ACTIONS(9979),
    [anon_sym_POUNDIf] = ACTIONS(9979),
    [anon_sym_POUNDelif] = ACTIONS(9979),
    [anon_sym_POUNDELIF] = ACTIONS(9979),
    [anon_sym_POUNDElif] = ACTIONS(9979),
    [anon_sym_POUNDelse] = ACTIONS(9979),
    [anon_sym_POUNDELSE] = ACTIONS(9979),
    [anon_sym_POUNDElse] = ACTIONS(9979),
    [anon_sym_POUNDendif] = ACTIONS(9979),
    [anon_sym_POUNDENDIF] = ACTIONS(9979),
    [anon_sym_POUNDEndif] = ACTIONS(9979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9979),
    [sym_trigger_keyword] = ACTIONS(9979),
    [sym_var_keyword] = ACTIONS(9979),
    [sym_local_keyword] = ACTIONS(9979),
    [sym_internal_keyword] = ACTIONS(9979),
    [sym_protected_keyword] = ACTIONS(9979),
    [sym_event_keyword] = ACTIONS(9979),
    [sym_fields_keyword] = ACTIONS(9979),
    [sym_keys_keyword] = ACTIONS(9979),
    [sym_fieldgroups_keyword] = ACTIONS(9979),
    [sym_actions_keyword] = ACTIONS(9979),
    [sym_layout_keyword] = ACTIONS(9979),
    [sym_area_keyword] = ACTIONS(9979),
    [sym_group_keyword] = ACTIONS(9979),
    [sym_repeater_keyword] = ACTIONS(9979),
    [sym_cuegroup_keyword] = ACTIONS(9979),
    [sym_fixed_keyword] = ACTIONS(9979),
    [sym_grid_keyword] = ACTIONS(9979),
    [sym_part_keyword] = ACTIONS(9979),
    [sym_systempart_keyword] = ACTIONS(9979),
    [sym_usercontrol_keyword] = ACTIONS(9979),
    [sym_dataset_keyword] = ACTIONS(9979),
    [sym_elements_keyword] = ACTIONS(9979),
    [sym_dataitem_keyword] = ACTIONS(9979),
    [sym_column_keyword] = ACTIONS(9979),
    [sym_filter_keyword] = ACTIONS(9979),
    [sym_labels_keyword] = ACTIONS(9979),
    [sym_rendering_keyword] = ACTIONS(9979),
    [sym_requestpage_keyword] = ACTIONS(9979),
    [sym_schema_keyword] = ACTIONS(9979),
    [sym_views_keyword] = ACTIONS(9979),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9979),
    [sym_preproc_open] = ACTIONS(9979),
    [sym_preproc_close] = ACTIONS(9979),
  },
  [STATE(3728)] = {
    [anon_sym_SEMI] = ACTIONS(9983),
    [aux_sym_where_condition_token1] = ACTIONS(9985),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9983),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9983),
    [anon_sym_LBRACK] = ACTIONS(9983),
    [aux_sym_basic_type_token6] = ACTIONS(9985),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9983),
    [aux_sym_addafter_modification_token1] = ACTIONS(9983),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9983),
    [aux_sym_modify_modification_token1] = ACTIONS(9983),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9983),
    [aux_sym_movelast_modification_token1] = ACTIONS(9983),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9983),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9983),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9983),
    [anon_sym_POUNDif] = ACTIONS(9983),
    [anon_sym_POUNDIF] = ACTIONS(9983),
    [anon_sym_POUNDIf] = ACTIONS(9983),
    [anon_sym_POUNDelif] = ACTIONS(9983),
    [anon_sym_POUNDELIF] = ACTIONS(9983),
    [anon_sym_POUNDElif] = ACTIONS(9983),
    [anon_sym_POUNDelse] = ACTIONS(9983),
    [anon_sym_POUNDELSE] = ACTIONS(9983),
    [anon_sym_POUNDElse] = ACTIONS(9983),
    [anon_sym_POUNDendif] = ACTIONS(9983),
    [anon_sym_POUNDENDIF] = ACTIONS(9983),
    [anon_sym_POUNDEndif] = ACTIONS(9983),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9983),
    [sym_trigger_keyword] = ACTIONS(9983),
    [sym_var_keyword] = ACTIONS(9983),
    [sym_local_keyword] = ACTIONS(9983),
    [sym_internal_keyword] = ACTIONS(9983),
    [sym_protected_keyword] = ACTIONS(9983),
    [sym_event_keyword] = ACTIONS(9983),
    [sym_fields_keyword] = ACTIONS(9983),
    [sym_keys_keyword] = ACTIONS(9983),
    [sym_fieldgroups_keyword] = ACTIONS(9983),
    [sym_actions_keyword] = ACTIONS(9983),
    [sym_layout_keyword] = ACTIONS(9983),
    [sym_area_keyword] = ACTIONS(9983),
    [sym_group_keyword] = ACTIONS(9983),
    [sym_repeater_keyword] = ACTIONS(9983),
    [sym_cuegroup_keyword] = ACTIONS(9983),
    [sym_fixed_keyword] = ACTIONS(9983),
    [sym_grid_keyword] = ACTIONS(9983),
    [sym_part_keyword] = ACTIONS(9983),
    [sym_systempart_keyword] = ACTIONS(9983),
    [sym_usercontrol_keyword] = ACTIONS(9983),
    [sym_dataset_keyword] = ACTIONS(9983),
    [sym_elements_keyword] = ACTIONS(9983),
    [sym_dataitem_keyword] = ACTIONS(9983),
    [sym_column_keyword] = ACTIONS(9983),
    [sym_filter_keyword] = ACTIONS(9983),
    [sym_labels_keyword] = ACTIONS(9983),
    [sym_rendering_keyword] = ACTIONS(9983),
    [sym_requestpage_keyword] = ACTIONS(9983),
    [sym_schema_keyword] = ACTIONS(9983),
    [sym_views_keyword] = ACTIONS(9983),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9983),
    [sym_preproc_open] = ACTIONS(9983),
    [sym_preproc_close] = ACTIONS(9983),
  },
  [STATE(3729)] = {
    [anon_sym_SEMI] = ACTIONS(9987),
    [aux_sym_where_condition_token1] = ACTIONS(9989),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9987),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9987),
    [anon_sym_LBRACK] = ACTIONS(9987),
    [aux_sym_basic_type_token6] = ACTIONS(9989),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9987),
    [aux_sym_addafter_modification_token1] = ACTIONS(9987),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9987),
    [aux_sym_modify_modification_token1] = ACTIONS(9987),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9987),
    [aux_sym_movelast_modification_token1] = ACTIONS(9987),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9987),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9987),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9987),
    [anon_sym_POUNDif] = ACTIONS(9987),
    [anon_sym_POUNDIF] = ACTIONS(9987),
    [anon_sym_POUNDIf] = ACTIONS(9987),
    [anon_sym_POUNDelif] = ACTIONS(9987),
    [anon_sym_POUNDELIF] = ACTIONS(9987),
    [anon_sym_POUNDElif] = ACTIONS(9987),
    [anon_sym_POUNDelse] = ACTIONS(9987),
    [anon_sym_POUNDELSE] = ACTIONS(9987),
    [anon_sym_POUNDElse] = ACTIONS(9987),
    [anon_sym_POUNDendif] = ACTIONS(9987),
    [anon_sym_POUNDENDIF] = ACTIONS(9987),
    [anon_sym_POUNDEndif] = ACTIONS(9987),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9987),
    [sym_trigger_keyword] = ACTIONS(9987),
    [sym_var_keyword] = ACTIONS(9987),
    [sym_local_keyword] = ACTIONS(9987),
    [sym_internal_keyword] = ACTIONS(9987),
    [sym_protected_keyword] = ACTIONS(9987),
    [sym_event_keyword] = ACTIONS(9987),
    [sym_fields_keyword] = ACTIONS(9987),
    [sym_keys_keyword] = ACTIONS(9987),
    [sym_fieldgroups_keyword] = ACTIONS(9987),
    [sym_actions_keyword] = ACTIONS(9987),
    [sym_layout_keyword] = ACTIONS(9987),
    [sym_area_keyword] = ACTIONS(9987),
    [sym_group_keyword] = ACTIONS(9987),
    [sym_repeater_keyword] = ACTIONS(9987),
    [sym_cuegroup_keyword] = ACTIONS(9987),
    [sym_fixed_keyword] = ACTIONS(9987),
    [sym_grid_keyword] = ACTIONS(9987),
    [sym_part_keyword] = ACTIONS(9987),
    [sym_systempart_keyword] = ACTIONS(9987),
    [sym_usercontrol_keyword] = ACTIONS(9987),
    [sym_dataset_keyword] = ACTIONS(9987),
    [sym_elements_keyword] = ACTIONS(9987),
    [sym_dataitem_keyword] = ACTIONS(9987),
    [sym_column_keyword] = ACTIONS(9987),
    [sym_filter_keyword] = ACTIONS(9987),
    [sym_labels_keyword] = ACTIONS(9987),
    [sym_rendering_keyword] = ACTIONS(9987),
    [sym_requestpage_keyword] = ACTIONS(9987),
    [sym_schema_keyword] = ACTIONS(9987),
    [sym_views_keyword] = ACTIONS(9987),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9987),
    [sym_preproc_open] = ACTIONS(9987),
    [sym_preproc_close] = ACTIONS(9987),
  },
  [STATE(3730)] = {
    [sym_boolean] = STATE(8843),
    [sym_option_member] = STATE(8796),
    [sym_keyword_identifier] = STATE(8843),
    [sym_codeunit_keyword] = STATE(8787),
    [sym_xmlport_keyword] = STATE(8787),
    [sym_enum_keyword] = STATE(8787),
    [sym_keyword_as_identifier] = STATE(8843),
    [sym_identifier] = ACTIONS(9350),
    [anon_sym_SEMI] = ACTIONS(389),
    [anon_sym_COMMA] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(9354),
    [aux_sym_boolean_token1] = ACTIONS(9356),
    [aux_sym_boolean_token2] = ACTIONS(9356),
    [aux_sym_where_condition_token1] = ACTIONS(9358),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9360),
    [aux_sym_record_type_token1] = ACTIONS(9360),
    [aux_sym_basic_type_token21] = ACTIONS(9360),
    [aux_sym_basic_type_token22] = ACTIONS(9362),
    [aux_sym_basic_type_token48] = ACTIONS(9360),
    [aux_sym_basic_type_token53] = ACTIONS(9358),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9358),
    [aux_sym_separator_action_token1] = ACTIONS(9358),
    [aux_sym_type_declaration_token1] = ACTIONS(9358),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(391),
    [anon_sym_POUNDif] = ACTIONS(389),
    [anon_sym_POUNDIF] = ACTIONS(389),
    [anon_sym_POUNDIf] = ACTIONS(389),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9360),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9360),
    [sym_page_keyword] = ACTIONS(9360),
    [anon_sym_codeunit] = ACTIONS(9364),
    [anon_sym_CODEUNIT] = ACTIONS(9364),
    [anon_sym_Codeunit] = ACTIONS(9364),
    [anon_sym_CodeUnit] = ACTIONS(9364),
    [anon_sym_COdeunit] = ACTIONS(9364),
    [anon_sym_codeUnit] = ACTIONS(9364),
    [sym_report_keyword] = ACTIONS(9360),
    [sym_query_keyword] = ACTIONS(9360),
    [anon_sym_xmlport] = ACTIONS(9366),
    [anon_sym_XMLPORT] = ACTIONS(9366),
    [anon_sym_Xmlport] = ACTIONS(9366),
    [anon_sym_XMLport] = ACTIONS(9366),
    [anon_sym_XMLPort] = ACTIONS(9366),
    [anon_sym_XmlPort] = ACTIONS(9366),
    [anon_sym_enum] = ACTIONS(9368),
    [anon_sym_ENUM] = ACTIONS(9368),
    [anon_sym_Enum] = ACTIONS(9368),
    [anon_sym_eNUM] = ACTIONS(9368),
    [anon_sym_eNum] = ACTIONS(9368),
    [anon_sym_ENum] = ACTIONS(9368),
    [sym_var_keyword] = ACTIONS(391),
    [sym_local_keyword] = ACTIONS(9991),
    [sym_internal_keyword] = ACTIONS(9350),
    [sym_protected_keyword] = ACTIONS(9991),
    [sym_key_keyword] = ACTIONS(9358),
    [sym_dataset_keyword] = ACTIONS(9358),
    [sym_quoted_identifier] = ACTIONS(9370),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9370),
    [sym_integer] = ACTIONS(9370),
    [sym_preproc_open] = ACTIONS(389),
    [sym_begin_keyword] = ACTIONS(389),
  },
  [STATE(3731)] = {
    [anon_sym_SEMI] = ACTIONS(9994),
    [aux_sym_where_condition_token1] = ACTIONS(9996),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9998),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9998),
    [anon_sym_LBRACK] = ACTIONS(9998),
    [aux_sym_basic_type_token6] = ACTIONS(9996),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9998),
    [aux_sym_addafter_modification_token1] = ACTIONS(9998),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9998),
    [aux_sym_modify_modification_token1] = ACTIONS(9998),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9998),
    [aux_sym_movelast_modification_token1] = ACTIONS(9998),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9998),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9998),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9998),
    [anon_sym_POUNDif] = ACTIONS(9998),
    [anon_sym_POUNDIF] = ACTIONS(9998),
    [anon_sym_POUNDIf] = ACTIONS(9998),
    [anon_sym_POUNDelif] = ACTIONS(9998),
    [anon_sym_POUNDELIF] = ACTIONS(9998),
    [anon_sym_POUNDElif] = ACTIONS(9998),
    [anon_sym_POUNDelse] = ACTIONS(9998),
    [anon_sym_POUNDELSE] = ACTIONS(9998),
    [anon_sym_POUNDElse] = ACTIONS(9998),
    [anon_sym_POUNDendif] = ACTIONS(9998),
    [anon_sym_POUNDENDIF] = ACTIONS(9998),
    [anon_sym_POUNDEndif] = ACTIONS(9998),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9998),
    [sym_trigger_keyword] = ACTIONS(9998),
    [sym_var_keyword] = ACTIONS(9998),
    [sym_local_keyword] = ACTIONS(9998),
    [sym_internal_keyword] = ACTIONS(9998),
    [sym_protected_keyword] = ACTIONS(9998),
    [sym_event_keyword] = ACTIONS(9998),
    [sym_fields_keyword] = ACTIONS(9998),
    [sym_keys_keyword] = ACTIONS(9998),
    [sym_fieldgroups_keyword] = ACTIONS(9998),
    [sym_actions_keyword] = ACTIONS(9998),
    [sym_layout_keyword] = ACTIONS(9998),
    [sym_area_keyword] = ACTIONS(9998),
    [sym_group_keyword] = ACTIONS(9998),
    [sym_repeater_keyword] = ACTIONS(9998),
    [sym_cuegroup_keyword] = ACTIONS(9998),
    [sym_fixed_keyword] = ACTIONS(9998),
    [sym_grid_keyword] = ACTIONS(9998),
    [sym_part_keyword] = ACTIONS(9998),
    [sym_systempart_keyword] = ACTIONS(9998),
    [sym_usercontrol_keyword] = ACTIONS(9998),
    [sym_dataset_keyword] = ACTIONS(9998),
    [sym_elements_keyword] = ACTIONS(9998),
    [sym_dataitem_keyword] = ACTIONS(9998),
    [sym_column_keyword] = ACTIONS(9998),
    [sym_filter_keyword] = ACTIONS(9998),
    [sym_labels_keyword] = ACTIONS(9998),
    [sym_rendering_keyword] = ACTIONS(9998),
    [sym_requestpage_keyword] = ACTIONS(9998),
    [sym_schema_keyword] = ACTIONS(9998),
    [sym_views_keyword] = ACTIONS(9998),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9998),
    [sym_preproc_open] = ACTIONS(9998),
    [sym_preproc_close] = ACTIONS(9998),
  },
  [STATE(3732)] = {
    [anon_sym_SEMI] = ACTIONS(10000),
    [aux_sym_where_condition_token1] = ACTIONS(9996),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9998),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9998),
    [anon_sym_LBRACK] = ACTIONS(9998),
    [aux_sym_basic_type_token6] = ACTIONS(9996),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9998),
    [aux_sym_addafter_modification_token1] = ACTIONS(9998),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9998),
    [aux_sym_modify_modification_token1] = ACTIONS(9998),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9998),
    [aux_sym_movelast_modification_token1] = ACTIONS(9998),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9998),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9998),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9998),
    [anon_sym_POUNDif] = ACTIONS(9998),
    [anon_sym_POUNDIF] = ACTIONS(9998),
    [anon_sym_POUNDIf] = ACTIONS(9998),
    [anon_sym_POUNDelif] = ACTIONS(9998),
    [anon_sym_POUNDELIF] = ACTIONS(9998),
    [anon_sym_POUNDElif] = ACTIONS(9998),
    [anon_sym_POUNDelse] = ACTIONS(9998),
    [anon_sym_POUNDELSE] = ACTIONS(9998),
    [anon_sym_POUNDElse] = ACTIONS(9998),
    [anon_sym_POUNDendif] = ACTIONS(9998),
    [anon_sym_POUNDENDIF] = ACTIONS(9998),
    [anon_sym_POUNDEndif] = ACTIONS(9998),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9998),
    [sym_trigger_keyword] = ACTIONS(9998),
    [sym_var_keyword] = ACTIONS(9998),
    [sym_local_keyword] = ACTIONS(9998),
    [sym_internal_keyword] = ACTIONS(9998),
    [sym_protected_keyword] = ACTIONS(9998),
    [sym_event_keyword] = ACTIONS(9998),
    [sym_fields_keyword] = ACTIONS(9998),
    [sym_keys_keyword] = ACTIONS(9998),
    [sym_fieldgroups_keyword] = ACTIONS(9998),
    [sym_actions_keyword] = ACTIONS(9998),
    [sym_layout_keyword] = ACTIONS(9998),
    [sym_area_keyword] = ACTIONS(9998),
    [sym_group_keyword] = ACTIONS(9998),
    [sym_repeater_keyword] = ACTIONS(9998),
    [sym_cuegroup_keyword] = ACTIONS(9998),
    [sym_fixed_keyword] = ACTIONS(9998),
    [sym_grid_keyword] = ACTIONS(9998),
    [sym_part_keyword] = ACTIONS(9998),
    [sym_systempart_keyword] = ACTIONS(9998),
    [sym_usercontrol_keyword] = ACTIONS(9998),
    [sym_dataset_keyword] = ACTIONS(9998),
    [sym_elements_keyword] = ACTIONS(9998),
    [sym_dataitem_keyword] = ACTIONS(9998),
    [sym_column_keyword] = ACTIONS(9998),
    [sym_filter_keyword] = ACTIONS(9998),
    [sym_labels_keyword] = ACTIONS(9998),
    [sym_rendering_keyword] = ACTIONS(9998),
    [sym_requestpage_keyword] = ACTIONS(9998),
    [sym_schema_keyword] = ACTIONS(9998),
    [sym_views_keyword] = ACTIONS(9998),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9998),
    [sym_preproc_open] = ACTIONS(9998),
    [sym_preproc_close] = ACTIONS(9998),
  },
  [STATE(3733)] = {
    [anon_sym_SEMI] = ACTIONS(10002),
    [aux_sym_where_condition_token1] = ACTIONS(10004),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10002),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10002),
    [anon_sym_LBRACK] = ACTIONS(10002),
    [aux_sym_basic_type_token6] = ACTIONS(10004),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10002),
    [aux_sym_addafter_modification_token1] = ACTIONS(10002),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10002),
    [aux_sym_modify_modification_token1] = ACTIONS(10002),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10002),
    [aux_sym_movelast_modification_token1] = ACTIONS(10002),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10002),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10002),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10002),
    [anon_sym_POUNDif] = ACTIONS(10002),
    [anon_sym_POUNDIF] = ACTIONS(10002),
    [anon_sym_POUNDIf] = ACTIONS(10002),
    [anon_sym_POUNDelif] = ACTIONS(10002),
    [anon_sym_POUNDELIF] = ACTIONS(10002),
    [anon_sym_POUNDElif] = ACTIONS(10002),
    [anon_sym_POUNDelse] = ACTIONS(10002),
    [anon_sym_POUNDELSE] = ACTIONS(10002),
    [anon_sym_POUNDElse] = ACTIONS(10002),
    [anon_sym_POUNDendif] = ACTIONS(10002),
    [anon_sym_POUNDENDIF] = ACTIONS(10002),
    [anon_sym_POUNDEndif] = ACTIONS(10002),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10002),
    [sym_trigger_keyword] = ACTIONS(10002),
    [sym_var_keyword] = ACTIONS(10002),
    [sym_local_keyword] = ACTIONS(10002),
    [sym_internal_keyword] = ACTIONS(10002),
    [sym_protected_keyword] = ACTIONS(10002),
    [sym_event_keyword] = ACTIONS(10002),
    [sym_fields_keyword] = ACTIONS(10002),
    [sym_keys_keyword] = ACTIONS(10002),
    [sym_fieldgroups_keyword] = ACTIONS(10002),
    [sym_actions_keyword] = ACTIONS(10002),
    [sym_layout_keyword] = ACTIONS(10002),
    [sym_area_keyword] = ACTIONS(10002),
    [sym_group_keyword] = ACTIONS(10002),
    [sym_repeater_keyword] = ACTIONS(10002),
    [sym_cuegroup_keyword] = ACTIONS(10002),
    [sym_fixed_keyword] = ACTIONS(10002),
    [sym_grid_keyword] = ACTIONS(10002),
    [sym_part_keyword] = ACTIONS(10002),
    [sym_systempart_keyword] = ACTIONS(10002),
    [sym_usercontrol_keyword] = ACTIONS(10002),
    [sym_dataset_keyword] = ACTIONS(10002),
    [sym_elements_keyword] = ACTIONS(10002),
    [sym_dataitem_keyword] = ACTIONS(10002),
    [sym_column_keyword] = ACTIONS(10002),
    [sym_filter_keyword] = ACTIONS(10002),
    [sym_labels_keyword] = ACTIONS(10002),
    [sym_rendering_keyword] = ACTIONS(10002),
    [sym_requestpage_keyword] = ACTIONS(10002),
    [sym_schema_keyword] = ACTIONS(10002),
    [sym_views_keyword] = ACTIONS(10002),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10002),
    [sym_preproc_open] = ACTIONS(10002),
    [sym_preproc_close] = ACTIONS(10002),
  },
  [STATE(3734)] = {
    [anon_sym_SEMI] = ACTIONS(10002),
    [aux_sym_where_condition_token1] = ACTIONS(10004),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10002),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10002),
    [anon_sym_LBRACK] = ACTIONS(10002),
    [aux_sym_basic_type_token6] = ACTIONS(10004),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10002),
    [aux_sym_addafter_modification_token1] = ACTIONS(10002),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10002),
    [aux_sym_modify_modification_token1] = ACTIONS(10002),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10002),
    [aux_sym_movelast_modification_token1] = ACTIONS(10002),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10002),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10002),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10002),
    [anon_sym_POUNDif] = ACTIONS(10002),
    [anon_sym_POUNDIF] = ACTIONS(10002),
    [anon_sym_POUNDIf] = ACTIONS(10002),
    [anon_sym_POUNDelif] = ACTIONS(10002),
    [anon_sym_POUNDELIF] = ACTIONS(10002),
    [anon_sym_POUNDElif] = ACTIONS(10002),
    [anon_sym_POUNDelse] = ACTIONS(10002),
    [anon_sym_POUNDELSE] = ACTIONS(10002),
    [anon_sym_POUNDElse] = ACTIONS(10002),
    [anon_sym_POUNDendif] = ACTIONS(10002),
    [anon_sym_POUNDENDIF] = ACTIONS(10002),
    [anon_sym_POUNDEndif] = ACTIONS(10002),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10002),
    [sym_trigger_keyword] = ACTIONS(10002),
    [sym_var_keyword] = ACTIONS(10002),
    [sym_local_keyword] = ACTIONS(10002),
    [sym_internal_keyword] = ACTIONS(10002),
    [sym_protected_keyword] = ACTIONS(10002),
    [sym_event_keyword] = ACTIONS(10002),
    [sym_fields_keyword] = ACTIONS(10002),
    [sym_keys_keyword] = ACTIONS(10002),
    [sym_fieldgroups_keyword] = ACTIONS(10002),
    [sym_actions_keyword] = ACTIONS(10002),
    [sym_layout_keyword] = ACTIONS(10002),
    [sym_area_keyword] = ACTIONS(10002),
    [sym_group_keyword] = ACTIONS(10002),
    [sym_repeater_keyword] = ACTIONS(10002),
    [sym_cuegroup_keyword] = ACTIONS(10002),
    [sym_fixed_keyword] = ACTIONS(10002),
    [sym_grid_keyword] = ACTIONS(10002),
    [sym_part_keyword] = ACTIONS(10002),
    [sym_systempart_keyword] = ACTIONS(10002),
    [sym_usercontrol_keyword] = ACTIONS(10002),
    [sym_dataset_keyword] = ACTIONS(10002),
    [sym_elements_keyword] = ACTIONS(10002),
    [sym_dataitem_keyword] = ACTIONS(10002),
    [sym_column_keyword] = ACTIONS(10002),
    [sym_filter_keyword] = ACTIONS(10002),
    [sym_labels_keyword] = ACTIONS(10002),
    [sym_rendering_keyword] = ACTIONS(10002),
    [sym_requestpage_keyword] = ACTIONS(10002),
    [sym_schema_keyword] = ACTIONS(10002),
    [sym_views_keyword] = ACTIONS(10002),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10002),
    [sym_preproc_open] = ACTIONS(10002),
    [sym_preproc_close] = ACTIONS(10002),
  },
  [STATE(3735)] = {
    [anon_sym_SEMI] = ACTIONS(10006),
    [aux_sym_where_condition_token1] = ACTIONS(10008),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10010),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10010),
    [anon_sym_LBRACK] = ACTIONS(10010),
    [aux_sym_basic_type_token6] = ACTIONS(10008),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10010),
    [aux_sym_addafter_modification_token1] = ACTIONS(10010),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10010),
    [aux_sym_modify_modification_token1] = ACTIONS(10010),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10010),
    [aux_sym_movelast_modification_token1] = ACTIONS(10010),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10010),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10010),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10010),
    [anon_sym_POUNDif] = ACTIONS(10010),
    [anon_sym_POUNDIF] = ACTIONS(10010),
    [anon_sym_POUNDIf] = ACTIONS(10010),
    [anon_sym_POUNDelif] = ACTIONS(10010),
    [anon_sym_POUNDELIF] = ACTIONS(10010),
    [anon_sym_POUNDElif] = ACTIONS(10010),
    [anon_sym_POUNDelse] = ACTIONS(10010),
    [anon_sym_POUNDELSE] = ACTIONS(10010),
    [anon_sym_POUNDElse] = ACTIONS(10010),
    [anon_sym_POUNDendif] = ACTIONS(10010),
    [anon_sym_POUNDENDIF] = ACTIONS(10010),
    [anon_sym_POUNDEndif] = ACTIONS(10010),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10010),
    [sym_trigger_keyword] = ACTIONS(10010),
    [sym_var_keyword] = ACTIONS(10010),
    [sym_local_keyword] = ACTIONS(10010),
    [sym_internal_keyword] = ACTIONS(10010),
    [sym_protected_keyword] = ACTIONS(10010),
    [sym_event_keyword] = ACTIONS(10010),
    [sym_fields_keyword] = ACTIONS(10010),
    [sym_keys_keyword] = ACTIONS(10010),
    [sym_fieldgroups_keyword] = ACTIONS(10010),
    [sym_actions_keyword] = ACTIONS(10010),
    [sym_layout_keyword] = ACTIONS(10010),
    [sym_area_keyword] = ACTIONS(10010),
    [sym_group_keyword] = ACTIONS(10010),
    [sym_repeater_keyword] = ACTIONS(10010),
    [sym_cuegroup_keyword] = ACTIONS(10010),
    [sym_fixed_keyword] = ACTIONS(10010),
    [sym_grid_keyword] = ACTIONS(10010),
    [sym_part_keyword] = ACTIONS(10010),
    [sym_systempart_keyword] = ACTIONS(10010),
    [sym_usercontrol_keyword] = ACTIONS(10010),
    [sym_dataset_keyword] = ACTIONS(10010),
    [sym_elements_keyword] = ACTIONS(10010),
    [sym_dataitem_keyword] = ACTIONS(10010),
    [sym_column_keyword] = ACTIONS(10010),
    [sym_filter_keyword] = ACTIONS(10010),
    [sym_labels_keyword] = ACTIONS(10010),
    [sym_rendering_keyword] = ACTIONS(10010),
    [sym_requestpage_keyword] = ACTIONS(10010),
    [sym_schema_keyword] = ACTIONS(10010),
    [sym_views_keyword] = ACTIONS(10010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10010),
    [sym_preproc_open] = ACTIONS(10010),
    [sym_preproc_close] = ACTIONS(10010),
  },
  [STATE(3736)] = {
    [anon_sym_SEMI] = ACTIONS(10012),
    [aux_sym_where_condition_token1] = ACTIONS(10008),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10010),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10010),
    [anon_sym_LBRACK] = ACTIONS(10010),
    [aux_sym_basic_type_token6] = ACTIONS(10008),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10010),
    [aux_sym_addafter_modification_token1] = ACTIONS(10010),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10010),
    [aux_sym_modify_modification_token1] = ACTIONS(10010),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10010),
    [aux_sym_movelast_modification_token1] = ACTIONS(10010),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10010),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10010),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10010),
    [anon_sym_POUNDif] = ACTIONS(10010),
    [anon_sym_POUNDIF] = ACTIONS(10010),
    [anon_sym_POUNDIf] = ACTIONS(10010),
    [anon_sym_POUNDelif] = ACTIONS(10010),
    [anon_sym_POUNDELIF] = ACTIONS(10010),
    [anon_sym_POUNDElif] = ACTIONS(10010),
    [anon_sym_POUNDelse] = ACTIONS(10010),
    [anon_sym_POUNDELSE] = ACTIONS(10010),
    [anon_sym_POUNDElse] = ACTIONS(10010),
    [anon_sym_POUNDendif] = ACTIONS(10010),
    [anon_sym_POUNDENDIF] = ACTIONS(10010),
    [anon_sym_POUNDEndif] = ACTIONS(10010),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10010),
    [sym_trigger_keyword] = ACTIONS(10010),
    [sym_var_keyword] = ACTIONS(10010),
    [sym_local_keyword] = ACTIONS(10010),
    [sym_internal_keyword] = ACTIONS(10010),
    [sym_protected_keyword] = ACTIONS(10010),
    [sym_event_keyword] = ACTIONS(10010),
    [sym_fields_keyword] = ACTIONS(10010),
    [sym_keys_keyword] = ACTIONS(10010),
    [sym_fieldgroups_keyword] = ACTIONS(10010),
    [sym_actions_keyword] = ACTIONS(10010),
    [sym_layout_keyword] = ACTIONS(10010),
    [sym_area_keyword] = ACTIONS(10010),
    [sym_group_keyword] = ACTIONS(10010),
    [sym_repeater_keyword] = ACTIONS(10010),
    [sym_cuegroup_keyword] = ACTIONS(10010),
    [sym_fixed_keyword] = ACTIONS(10010),
    [sym_grid_keyword] = ACTIONS(10010),
    [sym_part_keyword] = ACTIONS(10010),
    [sym_systempart_keyword] = ACTIONS(10010),
    [sym_usercontrol_keyword] = ACTIONS(10010),
    [sym_dataset_keyword] = ACTIONS(10010),
    [sym_elements_keyword] = ACTIONS(10010),
    [sym_dataitem_keyword] = ACTIONS(10010),
    [sym_column_keyword] = ACTIONS(10010),
    [sym_filter_keyword] = ACTIONS(10010),
    [sym_labels_keyword] = ACTIONS(10010),
    [sym_rendering_keyword] = ACTIONS(10010),
    [sym_requestpage_keyword] = ACTIONS(10010),
    [sym_schema_keyword] = ACTIONS(10010),
    [sym_views_keyword] = ACTIONS(10010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10010),
    [sym_preproc_open] = ACTIONS(10010),
    [sym_preproc_close] = ACTIONS(10010),
  },
  [STATE(3737)] = {
    [anon_sym_SEMI] = ACTIONS(10014),
    [aux_sym_where_condition_token1] = ACTIONS(10004),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10002),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10002),
    [anon_sym_LBRACK] = ACTIONS(10002),
    [aux_sym_basic_type_token6] = ACTIONS(10004),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10002),
    [aux_sym_addafter_modification_token1] = ACTIONS(10002),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10002),
    [aux_sym_modify_modification_token1] = ACTIONS(10002),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10002),
    [aux_sym_movelast_modification_token1] = ACTIONS(10002),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10002),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10002),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10002),
    [anon_sym_POUNDif] = ACTIONS(10002),
    [anon_sym_POUNDIF] = ACTIONS(10002),
    [anon_sym_POUNDIf] = ACTIONS(10002),
    [anon_sym_POUNDelif] = ACTIONS(10002),
    [anon_sym_POUNDELIF] = ACTIONS(10002),
    [anon_sym_POUNDElif] = ACTIONS(10002),
    [anon_sym_POUNDelse] = ACTIONS(10002),
    [anon_sym_POUNDELSE] = ACTIONS(10002),
    [anon_sym_POUNDElse] = ACTIONS(10002),
    [anon_sym_POUNDendif] = ACTIONS(10002),
    [anon_sym_POUNDENDIF] = ACTIONS(10002),
    [anon_sym_POUNDEndif] = ACTIONS(10002),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10002),
    [sym_trigger_keyword] = ACTIONS(10002),
    [sym_var_keyword] = ACTIONS(10002),
    [sym_local_keyword] = ACTIONS(10002),
    [sym_internal_keyword] = ACTIONS(10002),
    [sym_protected_keyword] = ACTIONS(10002),
    [sym_event_keyword] = ACTIONS(10002),
    [sym_fields_keyword] = ACTIONS(10002),
    [sym_keys_keyword] = ACTIONS(10002),
    [sym_fieldgroups_keyword] = ACTIONS(10002),
    [sym_actions_keyword] = ACTIONS(10002),
    [sym_layout_keyword] = ACTIONS(10002),
    [sym_area_keyword] = ACTIONS(10002),
    [sym_group_keyword] = ACTIONS(10002),
    [sym_repeater_keyword] = ACTIONS(10002),
    [sym_cuegroup_keyword] = ACTIONS(10002),
    [sym_fixed_keyword] = ACTIONS(10002),
    [sym_grid_keyword] = ACTIONS(10002),
    [sym_part_keyword] = ACTIONS(10002),
    [sym_systempart_keyword] = ACTIONS(10002),
    [sym_usercontrol_keyword] = ACTIONS(10002),
    [sym_dataset_keyword] = ACTIONS(10002),
    [sym_elements_keyword] = ACTIONS(10002),
    [sym_dataitem_keyword] = ACTIONS(10002),
    [sym_column_keyword] = ACTIONS(10002),
    [sym_filter_keyword] = ACTIONS(10002),
    [sym_labels_keyword] = ACTIONS(10002),
    [sym_rendering_keyword] = ACTIONS(10002),
    [sym_requestpage_keyword] = ACTIONS(10002),
    [sym_schema_keyword] = ACTIONS(10002),
    [sym_views_keyword] = ACTIONS(10002),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10002),
    [sym_preproc_open] = ACTIONS(10002),
    [sym_preproc_close] = ACTIONS(10002),
  },
  [STATE(3738)] = {
    [anon_sym_SEMI] = ACTIONS(10016),
    [aux_sym_where_condition_token1] = ACTIONS(10004),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10002),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10002),
    [anon_sym_LBRACK] = ACTIONS(10002),
    [aux_sym_basic_type_token6] = ACTIONS(10004),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10002),
    [aux_sym_addafter_modification_token1] = ACTIONS(10002),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10002),
    [aux_sym_modify_modification_token1] = ACTIONS(10002),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10002),
    [aux_sym_movelast_modification_token1] = ACTIONS(10002),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10002),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10002),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10002),
    [anon_sym_POUNDif] = ACTIONS(10002),
    [anon_sym_POUNDIF] = ACTIONS(10002),
    [anon_sym_POUNDIf] = ACTIONS(10002),
    [anon_sym_POUNDelif] = ACTIONS(10002),
    [anon_sym_POUNDELIF] = ACTIONS(10002),
    [anon_sym_POUNDElif] = ACTIONS(10002),
    [anon_sym_POUNDelse] = ACTIONS(10002),
    [anon_sym_POUNDELSE] = ACTIONS(10002),
    [anon_sym_POUNDElse] = ACTIONS(10002),
    [anon_sym_POUNDendif] = ACTIONS(10002),
    [anon_sym_POUNDENDIF] = ACTIONS(10002),
    [anon_sym_POUNDEndif] = ACTIONS(10002),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10002),
    [sym_trigger_keyword] = ACTIONS(10002),
    [sym_var_keyword] = ACTIONS(10002),
    [sym_local_keyword] = ACTIONS(10002),
    [sym_internal_keyword] = ACTIONS(10002),
    [sym_protected_keyword] = ACTIONS(10002),
    [sym_event_keyword] = ACTIONS(10002),
    [sym_fields_keyword] = ACTIONS(10002),
    [sym_keys_keyword] = ACTIONS(10002),
    [sym_fieldgroups_keyword] = ACTIONS(10002),
    [sym_actions_keyword] = ACTIONS(10002),
    [sym_layout_keyword] = ACTIONS(10002),
    [sym_area_keyword] = ACTIONS(10002),
    [sym_group_keyword] = ACTIONS(10002),
    [sym_repeater_keyword] = ACTIONS(10002),
    [sym_cuegroup_keyword] = ACTIONS(10002),
    [sym_fixed_keyword] = ACTIONS(10002),
    [sym_grid_keyword] = ACTIONS(10002),
    [sym_part_keyword] = ACTIONS(10002),
    [sym_systempart_keyword] = ACTIONS(10002),
    [sym_usercontrol_keyword] = ACTIONS(10002),
    [sym_dataset_keyword] = ACTIONS(10002),
    [sym_elements_keyword] = ACTIONS(10002),
    [sym_dataitem_keyword] = ACTIONS(10002),
    [sym_column_keyword] = ACTIONS(10002),
    [sym_filter_keyword] = ACTIONS(10002),
    [sym_labels_keyword] = ACTIONS(10002),
    [sym_rendering_keyword] = ACTIONS(10002),
    [sym_requestpage_keyword] = ACTIONS(10002),
    [sym_schema_keyword] = ACTIONS(10002),
    [sym_views_keyword] = ACTIONS(10002),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10002),
    [sym_preproc_open] = ACTIONS(10002),
    [sym_preproc_close] = ACTIONS(10002),
  },
  [STATE(3739)] = {
    [anon_sym_SEMI] = ACTIONS(10018),
    [aux_sym_where_condition_token1] = ACTIONS(10020),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10018),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10018),
    [anon_sym_LBRACK] = ACTIONS(10018),
    [aux_sym_basic_type_token6] = ACTIONS(10020),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10018),
    [aux_sym_addafter_modification_token1] = ACTIONS(10018),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10018),
    [aux_sym_modify_modification_token1] = ACTIONS(10018),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10018),
    [aux_sym_movelast_modification_token1] = ACTIONS(10018),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10018),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10018),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10018),
    [anon_sym_POUNDif] = ACTIONS(10018),
    [anon_sym_POUNDIF] = ACTIONS(10018),
    [anon_sym_POUNDIf] = ACTIONS(10018),
    [anon_sym_POUNDelif] = ACTIONS(10018),
    [anon_sym_POUNDELIF] = ACTIONS(10018),
    [anon_sym_POUNDElif] = ACTIONS(10018),
    [anon_sym_POUNDelse] = ACTIONS(10018),
    [anon_sym_POUNDELSE] = ACTIONS(10018),
    [anon_sym_POUNDElse] = ACTIONS(10018),
    [anon_sym_POUNDendif] = ACTIONS(10018),
    [anon_sym_POUNDENDIF] = ACTIONS(10018),
    [anon_sym_POUNDEndif] = ACTIONS(10018),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10018),
    [sym_trigger_keyword] = ACTIONS(10018),
    [sym_var_keyword] = ACTIONS(10018),
    [sym_local_keyword] = ACTIONS(10018),
    [sym_internal_keyword] = ACTIONS(10018),
    [sym_protected_keyword] = ACTIONS(10018),
    [sym_event_keyword] = ACTIONS(10018),
    [sym_fields_keyword] = ACTIONS(10018),
    [sym_keys_keyword] = ACTIONS(10018),
    [sym_fieldgroups_keyword] = ACTIONS(10018),
    [sym_actions_keyword] = ACTIONS(10018),
    [sym_layout_keyword] = ACTIONS(10018),
    [sym_area_keyword] = ACTIONS(10018),
    [sym_group_keyword] = ACTIONS(10018),
    [sym_repeater_keyword] = ACTIONS(10018),
    [sym_cuegroup_keyword] = ACTIONS(10018),
    [sym_fixed_keyword] = ACTIONS(10018),
    [sym_grid_keyword] = ACTIONS(10018),
    [sym_part_keyword] = ACTIONS(10018),
    [sym_systempart_keyword] = ACTIONS(10018),
    [sym_usercontrol_keyword] = ACTIONS(10018),
    [sym_dataset_keyword] = ACTIONS(10018),
    [sym_elements_keyword] = ACTIONS(10018),
    [sym_dataitem_keyword] = ACTIONS(10018),
    [sym_column_keyword] = ACTIONS(10018),
    [sym_filter_keyword] = ACTIONS(10018),
    [sym_labels_keyword] = ACTIONS(10018),
    [sym_rendering_keyword] = ACTIONS(10018),
    [sym_requestpage_keyword] = ACTIONS(10018),
    [sym_schema_keyword] = ACTIONS(10018),
    [sym_views_keyword] = ACTIONS(10018),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10018),
    [sym_preproc_open] = ACTIONS(10018),
    [sym_preproc_close] = ACTIONS(10018),
  },
  [STATE(3740)] = {
    [anon_sym_SEMI] = ACTIONS(10018),
    [aux_sym_where_condition_token1] = ACTIONS(10020),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10018),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10018),
    [anon_sym_LBRACK] = ACTIONS(10018),
    [aux_sym_basic_type_token6] = ACTIONS(10020),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10018),
    [aux_sym_addafter_modification_token1] = ACTIONS(10018),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10018),
    [aux_sym_modify_modification_token1] = ACTIONS(10018),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10018),
    [aux_sym_movelast_modification_token1] = ACTIONS(10018),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10018),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10018),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10018),
    [anon_sym_POUNDif] = ACTIONS(10018),
    [anon_sym_POUNDIF] = ACTIONS(10018),
    [anon_sym_POUNDIf] = ACTIONS(10018),
    [anon_sym_POUNDelif] = ACTIONS(10018),
    [anon_sym_POUNDELIF] = ACTIONS(10018),
    [anon_sym_POUNDElif] = ACTIONS(10018),
    [anon_sym_POUNDelse] = ACTIONS(10018),
    [anon_sym_POUNDELSE] = ACTIONS(10018),
    [anon_sym_POUNDElse] = ACTIONS(10018),
    [anon_sym_POUNDendif] = ACTIONS(10018),
    [anon_sym_POUNDENDIF] = ACTIONS(10018),
    [anon_sym_POUNDEndif] = ACTIONS(10018),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10018),
    [sym_trigger_keyword] = ACTIONS(10018),
    [sym_var_keyword] = ACTIONS(10018),
    [sym_local_keyword] = ACTIONS(10018),
    [sym_internal_keyword] = ACTIONS(10018),
    [sym_protected_keyword] = ACTIONS(10018),
    [sym_event_keyword] = ACTIONS(10018),
    [sym_fields_keyword] = ACTIONS(10018),
    [sym_keys_keyword] = ACTIONS(10018),
    [sym_fieldgroups_keyword] = ACTIONS(10018),
    [sym_actions_keyword] = ACTIONS(10018),
    [sym_layout_keyword] = ACTIONS(10018),
    [sym_area_keyword] = ACTIONS(10018),
    [sym_group_keyword] = ACTIONS(10018),
    [sym_repeater_keyword] = ACTIONS(10018),
    [sym_cuegroup_keyword] = ACTIONS(10018),
    [sym_fixed_keyword] = ACTIONS(10018),
    [sym_grid_keyword] = ACTIONS(10018),
    [sym_part_keyword] = ACTIONS(10018),
    [sym_systempart_keyword] = ACTIONS(10018),
    [sym_usercontrol_keyword] = ACTIONS(10018),
    [sym_dataset_keyword] = ACTIONS(10018),
    [sym_elements_keyword] = ACTIONS(10018),
    [sym_dataitem_keyword] = ACTIONS(10018),
    [sym_column_keyword] = ACTIONS(10018),
    [sym_filter_keyword] = ACTIONS(10018),
    [sym_labels_keyword] = ACTIONS(10018),
    [sym_rendering_keyword] = ACTIONS(10018),
    [sym_requestpage_keyword] = ACTIONS(10018),
    [sym_schema_keyword] = ACTIONS(10018),
    [sym_views_keyword] = ACTIONS(10018),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10018),
    [sym_preproc_open] = ACTIONS(10018),
    [sym_preproc_close] = ACTIONS(10018),
  },
  [STATE(3741)] = {
    [anon_sym_SEMI] = ACTIONS(10022),
    [aux_sym_where_condition_token1] = ACTIONS(10024),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10026),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10026),
    [anon_sym_LBRACK] = ACTIONS(10026),
    [aux_sym_basic_type_token6] = ACTIONS(10024),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10026),
    [aux_sym_addafter_modification_token1] = ACTIONS(10026),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10026),
    [aux_sym_modify_modification_token1] = ACTIONS(10026),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10026),
    [aux_sym_movelast_modification_token1] = ACTIONS(10026),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10026),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10026),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10026),
    [anon_sym_POUNDif] = ACTIONS(10026),
    [anon_sym_POUNDIF] = ACTIONS(10026),
    [anon_sym_POUNDIf] = ACTIONS(10026),
    [anon_sym_POUNDelif] = ACTIONS(10026),
    [anon_sym_POUNDELIF] = ACTIONS(10026),
    [anon_sym_POUNDElif] = ACTIONS(10026),
    [anon_sym_POUNDelse] = ACTIONS(10026),
    [anon_sym_POUNDELSE] = ACTIONS(10026),
    [anon_sym_POUNDElse] = ACTIONS(10026),
    [anon_sym_POUNDendif] = ACTIONS(10026),
    [anon_sym_POUNDENDIF] = ACTIONS(10026),
    [anon_sym_POUNDEndif] = ACTIONS(10026),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10026),
    [sym_trigger_keyword] = ACTIONS(10026),
    [sym_var_keyword] = ACTIONS(10026),
    [sym_local_keyword] = ACTIONS(10026),
    [sym_internal_keyword] = ACTIONS(10026),
    [sym_protected_keyword] = ACTIONS(10026),
    [sym_event_keyword] = ACTIONS(10026),
    [sym_fields_keyword] = ACTIONS(10026),
    [sym_keys_keyword] = ACTIONS(10026),
    [sym_fieldgroups_keyword] = ACTIONS(10026),
    [sym_actions_keyword] = ACTIONS(10026),
    [sym_layout_keyword] = ACTIONS(10026),
    [sym_area_keyword] = ACTIONS(10026),
    [sym_group_keyword] = ACTIONS(10026),
    [sym_repeater_keyword] = ACTIONS(10026),
    [sym_cuegroup_keyword] = ACTIONS(10026),
    [sym_fixed_keyword] = ACTIONS(10026),
    [sym_grid_keyword] = ACTIONS(10026),
    [sym_part_keyword] = ACTIONS(10026),
    [sym_systempart_keyword] = ACTIONS(10026),
    [sym_usercontrol_keyword] = ACTIONS(10026),
    [sym_dataset_keyword] = ACTIONS(10026),
    [sym_elements_keyword] = ACTIONS(10026),
    [sym_dataitem_keyword] = ACTIONS(10026),
    [sym_column_keyword] = ACTIONS(10026),
    [sym_filter_keyword] = ACTIONS(10026),
    [sym_labels_keyword] = ACTIONS(10026),
    [sym_rendering_keyword] = ACTIONS(10026),
    [sym_requestpage_keyword] = ACTIONS(10026),
    [sym_schema_keyword] = ACTIONS(10026),
    [sym_views_keyword] = ACTIONS(10026),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10026),
    [sym_preproc_open] = ACTIONS(10026),
    [sym_preproc_close] = ACTIONS(10026),
  },
  [STATE(3742)] = {
    [anon_sym_SEMI] = ACTIONS(10028),
    [aux_sym_where_condition_token1] = ACTIONS(10024),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10026),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10026),
    [anon_sym_LBRACK] = ACTIONS(10026),
    [aux_sym_basic_type_token6] = ACTIONS(10024),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10026),
    [aux_sym_addafter_modification_token1] = ACTIONS(10026),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10026),
    [aux_sym_modify_modification_token1] = ACTIONS(10026),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10026),
    [aux_sym_movelast_modification_token1] = ACTIONS(10026),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10026),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10026),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10026),
    [anon_sym_POUNDif] = ACTIONS(10026),
    [anon_sym_POUNDIF] = ACTIONS(10026),
    [anon_sym_POUNDIf] = ACTIONS(10026),
    [anon_sym_POUNDelif] = ACTIONS(10026),
    [anon_sym_POUNDELIF] = ACTIONS(10026),
    [anon_sym_POUNDElif] = ACTIONS(10026),
    [anon_sym_POUNDelse] = ACTIONS(10026),
    [anon_sym_POUNDELSE] = ACTIONS(10026),
    [anon_sym_POUNDElse] = ACTIONS(10026),
    [anon_sym_POUNDendif] = ACTIONS(10026),
    [anon_sym_POUNDENDIF] = ACTIONS(10026),
    [anon_sym_POUNDEndif] = ACTIONS(10026),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10026),
    [sym_trigger_keyword] = ACTIONS(10026),
    [sym_var_keyword] = ACTIONS(10026),
    [sym_local_keyword] = ACTIONS(10026),
    [sym_internal_keyword] = ACTIONS(10026),
    [sym_protected_keyword] = ACTIONS(10026),
    [sym_event_keyword] = ACTIONS(10026),
    [sym_fields_keyword] = ACTIONS(10026),
    [sym_keys_keyword] = ACTIONS(10026),
    [sym_fieldgroups_keyword] = ACTIONS(10026),
    [sym_actions_keyword] = ACTIONS(10026),
    [sym_layout_keyword] = ACTIONS(10026),
    [sym_area_keyword] = ACTIONS(10026),
    [sym_group_keyword] = ACTIONS(10026),
    [sym_repeater_keyword] = ACTIONS(10026),
    [sym_cuegroup_keyword] = ACTIONS(10026),
    [sym_fixed_keyword] = ACTIONS(10026),
    [sym_grid_keyword] = ACTIONS(10026),
    [sym_part_keyword] = ACTIONS(10026),
    [sym_systempart_keyword] = ACTIONS(10026),
    [sym_usercontrol_keyword] = ACTIONS(10026),
    [sym_dataset_keyword] = ACTIONS(10026),
    [sym_elements_keyword] = ACTIONS(10026),
    [sym_dataitem_keyword] = ACTIONS(10026),
    [sym_column_keyword] = ACTIONS(10026),
    [sym_filter_keyword] = ACTIONS(10026),
    [sym_labels_keyword] = ACTIONS(10026),
    [sym_rendering_keyword] = ACTIONS(10026),
    [sym_requestpage_keyword] = ACTIONS(10026),
    [sym_schema_keyword] = ACTIONS(10026),
    [sym_views_keyword] = ACTIONS(10026),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10026),
    [sym_preproc_open] = ACTIONS(10026),
    [sym_preproc_close] = ACTIONS(10026),
  },
  [STATE(3743)] = {
    [anon_sym_SEMI] = ACTIONS(10030),
    [aux_sym_where_condition_token1] = ACTIONS(10020),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10018),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10018),
    [anon_sym_LBRACK] = ACTIONS(10018),
    [aux_sym_basic_type_token6] = ACTIONS(10020),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10018),
    [aux_sym_addafter_modification_token1] = ACTIONS(10018),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10018),
    [aux_sym_modify_modification_token1] = ACTIONS(10018),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10018),
    [aux_sym_movelast_modification_token1] = ACTIONS(10018),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10018),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10018),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10018),
    [anon_sym_POUNDif] = ACTIONS(10018),
    [anon_sym_POUNDIF] = ACTIONS(10018),
    [anon_sym_POUNDIf] = ACTIONS(10018),
    [anon_sym_POUNDelif] = ACTIONS(10018),
    [anon_sym_POUNDELIF] = ACTIONS(10018),
    [anon_sym_POUNDElif] = ACTIONS(10018),
    [anon_sym_POUNDelse] = ACTIONS(10018),
    [anon_sym_POUNDELSE] = ACTIONS(10018),
    [anon_sym_POUNDElse] = ACTIONS(10018),
    [anon_sym_POUNDendif] = ACTIONS(10018),
    [anon_sym_POUNDENDIF] = ACTIONS(10018),
    [anon_sym_POUNDEndif] = ACTIONS(10018),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10018),
    [sym_trigger_keyword] = ACTIONS(10018),
    [sym_var_keyword] = ACTIONS(10018),
    [sym_local_keyword] = ACTIONS(10018),
    [sym_internal_keyword] = ACTIONS(10018),
    [sym_protected_keyword] = ACTIONS(10018),
    [sym_event_keyword] = ACTIONS(10018),
    [sym_fields_keyword] = ACTIONS(10018),
    [sym_keys_keyword] = ACTIONS(10018),
    [sym_fieldgroups_keyword] = ACTIONS(10018),
    [sym_actions_keyword] = ACTIONS(10018),
    [sym_layout_keyword] = ACTIONS(10018),
    [sym_area_keyword] = ACTIONS(10018),
    [sym_group_keyword] = ACTIONS(10018),
    [sym_repeater_keyword] = ACTIONS(10018),
    [sym_cuegroup_keyword] = ACTIONS(10018),
    [sym_fixed_keyword] = ACTIONS(10018),
    [sym_grid_keyword] = ACTIONS(10018),
    [sym_part_keyword] = ACTIONS(10018),
    [sym_systempart_keyword] = ACTIONS(10018),
    [sym_usercontrol_keyword] = ACTIONS(10018),
    [sym_dataset_keyword] = ACTIONS(10018),
    [sym_elements_keyword] = ACTIONS(10018),
    [sym_dataitem_keyword] = ACTIONS(10018),
    [sym_column_keyword] = ACTIONS(10018),
    [sym_filter_keyword] = ACTIONS(10018),
    [sym_labels_keyword] = ACTIONS(10018),
    [sym_rendering_keyword] = ACTIONS(10018),
    [sym_requestpage_keyword] = ACTIONS(10018),
    [sym_schema_keyword] = ACTIONS(10018),
    [sym_views_keyword] = ACTIONS(10018),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10018),
    [sym_preproc_open] = ACTIONS(10018),
    [sym_preproc_close] = ACTIONS(10018),
  },
  [STATE(3744)] = {
    [anon_sym_SEMI] = ACTIONS(10032),
    [aux_sym_where_condition_token1] = ACTIONS(10020),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10018),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10018),
    [anon_sym_LBRACK] = ACTIONS(10018),
    [aux_sym_basic_type_token6] = ACTIONS(10020),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10018),
    [aux_sym_addafter_modification_token1] = ACTIONS(10018),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10018),
    [aux_sym_modify_modification_token1] = ACTIONS(10018),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10018),
    [aux_sym_movelast_modification_token1] = ACTIONS(10018),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10018),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10018),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10018),
    [anon_sym_POUNDif] = ACTIONS(10018),
    [anon_sym_POUNDIF] = ACTIONS(10018),
    [anon_sym_POUNDIf] = ACTIONS(10018),
    [anon_sym_POUNDelif] = ACTIONS(10018),
    [anon_sym_POUNDELIF] = ACTIONS(10018),
    [anon_sym_POUNDElif] = ACTIONS(10018),
    [anon_sym_POUNDelse] = ACTIONS(10018),
    [anon_sym_POUNDELSE] = ACTIONS(10018),
    [anon_sym_POUNDElse] = ACTIONS(10018),
    [anon_sym_POUNDendif] = ACTIONS(10018),
    [anon_sym_POUNDENDIF] = ACTIONS(10018),
    [anon_sym_POUNDEndif] = ACTIONS(10018),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10018),
    [sym_trigger_keyword] = ACTIONS(10018),
    [sym_var_keyword] = ACTIONS(10018),
    [sym_local_keyword] = ACTIONS(10018),
    [sym_internal_keyword] = ACTIONS(10018),
    [sym_protected_keyword] = ACTIONS(10018),
    [sym_event_keyword] = ACTIONS(10018),
    [sym_fields_keyword] = ACTIONS(10018),
    [sym_keys_keyword] = ACTIONS(10018),
    [sym_fieldgroups_keyword] = ACTIONS(10018),
    [sym_actions_keyword] = ACTIONS(10018),
    [sym_layout_keyword] = ACTIONS(10018),
    [sym_area_keyword] = ACTIONS(10018),
    [sym_group_keyword] = ACTIONS(10018),
    [sym_repeater_keyword] = ACTIONS(10018),
    [sym_cuegroup_keyword] = ACTIONS(10018),
    [sym_fixed_keyword] = ACTIONS(10018),
    [sym_grid_keyword] = ACTIONS(10018),
    [sym_part_keyword] = ACTIONS(10018),
    [sym_systempart_keyword] = ACTIONS(10018),
    [sym_usercontrol_keyword] = ACTIONS(10018),
    [sym_dataset_keyword] = ACTIONS(10018),
    [sym_elements_keyword] = ACTIONS(10018),
    [sym_dataitem_keyword] = ACTIONS(10018),
    [sym_column_keyword] = ACTIONS(10018),
    [sym_filter_keyword] = ACTIONS(10018),
    [sym_labels_keyword] = ACTIONS(10018),
    [sym_rendering_keyword] = ACTIONS(10018),
    [sym_requestpage_keyword] = ACTIONS(10018),
    [sym_schema_keyword] = ACTIONS(10018),
    [sym_views_keyword] = ACTIONS(10018),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10018),
    [sym_preproc_open] = ACTIONS(10018),
    [sym_preproc_close] = ACTIONS(10018),
  },
  [STATE(3745)] = {
    [anon_sym_SEMI] = ACTIONS(10034),
    [aux_sym_where_condition_token1] = ACTIONS(10036),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10038),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10038),
    [anon_sym_LBRACK] = ACTIONS(10038),
    [aux_sym_basic_type_token6] = ACTIONS(10036),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10038),
    [aux_sym_addafter_modification_token1] = ACTIONS(10038),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10038),
    [aux_sym_modify_modification_token1] = ACTIONS(10038),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10038),
    [aux_sym_movelast_modification_token1] = ACTIONS(10038),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10038),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10038),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10038),
    [anon_sym_POUNDif] = ACTIONS(10038),
    [anon_sym_POUNDIF] = ACTIONS(10038),
    [anon_sym_POUNDIf] = ACTIONS(10038),
    [anon_sym_POUNDelif] = ACTIONS(10038),
    [anon_sym_POUNDELIF] = ACTIONS(10038),
    [anon_sym_POUNDElif] = ACTIONS(10038),
    [anon_sym_POUNDelse] = ACTIONS(10038),
    [anon_sym_POUNDELSE] = ACTIONS(10038),
    [anon_sym_POUNDElse] = ACTIONS(10038),
    [anon_sym_POUNDendif] = ACTIONS(10038),
    [anon_sym_POUNDENDIF] = ACTIONS(10038),
    [anon_sym_POUNDEndif] = ACTIONS(10038),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10038),
    [sym_trigger_keyword] = ACTIONS(10038),
    [sym_var_keyword] = ACTIONS(10038),
    [sym_local_keyword] = ACTIONS(10038),
    [sym_internal_keyword] = ACTIONS(10038),
    [sym_protected_keyword] = ACTIONS(10038),
    [sym_event_keyword] = ACTIONS(10038),
    [sym_fields_keyword] = ACTIONS(10038),
    [sym_keys_keyword] = ACTIONS(10038),
    [sym_fieldgroups_keyword] = ACTIONS(10038),
    [sym_actions_keyword] = ACTIONS(10038),
    [sym_layout_keyword] = ACTIONS(10038),
    [sym_area_keyword] = ACTIONS(10038),
    [sym_group_keyword] = ACTIONS(10038),
    [sym_repeater_keyword] = ACTIONS(10038),
    [sym_cuegroup_keyword] = ACTIONS(10038),
    [sym_fixed_keyword] = ACTIONS(10038),
    [sym_grid_keyword] = ACTIONS(10038),
    [sym_part_keyword] = ACTIONS(10038),
    [sym_systempart_keyword] = ACTIONS(10038),
    [sym_usercontrol_keyword] = ACTIONS(10038),
    [sym_dataset_keyword] = ACTIONS(10038),
    [sym_elements_keyword] = ACTIONS(10038),
    [sym_dataitem_keyword] = ACTIONS(10038),
    [sym_column_keyword] = ACTIONS(10038),
    [sym_filter_keyword] = ACTIONS(10038),
    [sym_labels_keyword] = ACTIONS(10038),
    [sym_rendering_keyword] = ACTIONS(10038),
    [sym_requestpage_keyword] = ACTIONS(10038),
    [sym_schema_keyword] = ACTIONS(10038),
    [sym_views_keyword] = ACTIONS(10038),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10038),
    [sym_preproc_open] = ACTIONS(10038),
    [sym_preproc_close] = ACTIONS(10038),
  },
  [STATE(3746)] = {
    [anon_sym_SEMI] = ACTIONS(10040),
    [aux_sym_where_condition_token1] = ACTIONS(10036),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10038),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10038),
    [anon_sym_LBRACK] = ACTIONS(10038),
    [aux_sym_basic_type_token6] = ACTIONS(10036),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10038),
    [aux_sym_addafter_modification_token1] = ACTIONS(10038),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10038),
    [aux_sym_modify_modification_token1] = ACTIONS(10038),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10038),
    [aux_sym_movelast_modification_token1] = ACTIONS(10038),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10038),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10038),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10038),
    [anon_sym_POUNDif] = ACTIONS(10038),
    [anon_sym_POUNDIF] = ACTIONS(10038),
    [anon_sym_POUNDIf] = ACTIONS(10038),
    [anon_sym_POUNDelif] = ACTIONS(10038),
    [anon_sym_POUNDELIF] = ACTIONS(10038),
    [anon_sym_POUNDElif] = ACTIONS(10038),
    [anon_sym_POUNDelse] = ACTIONS(10038),
    [anon_sym_POUNDELSE] = ACTIONS(10038),
    [anon_sym_POUNDElse] = ACTIONS(10038),
    [anon_sym_POUNDendif] = ACTIONS(10038),
    [anon_sym_POUNDENDIF] = ACTIONS(10038),
    [anon_sym_POUNDEndif] = ACTIONS(10038),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10038),
    [sym_trigger_keyword] = ACTIONS(10038),
    [sym_var_keyword] = ACTIONS(10038),
    [sym_local_keyword] = ACTIONS(10038),
    [sym_internal_keyword] = ACTIONS(10038),
    [sym_protected_keyword] = ACTIONS(10038),
    [sym_event_keyword] = ACTIONS(10038),
    [sym_fields_keyword] = ACTIONS(10038),
    [sym_keys_keyword] = ACTIONS(10038),
    [sym_fieldgroups_keyword] = ACTIONS(10038),
    [sym_actions_keyword] = ACTIONS(10038),
    [sym_layout_keyword] = ACTIONS(10038),
    [sym_area_keyword] = ACTIONS(10038),
    [sym_group_keyword] = ACTIONS(10038),
    [sym_repeater_keyword] = ACTIONS(10038),
    [sym_cuegroup_keyword] = ACTIONS(10038),
    [sym_fixed_keyword] = ACTIONS(10038),
    [sym_grid_keyword] = ACTIONS(10038),
    [sym_part_keyword] = ACTIONS(10038),
    [sym_systempart_keyword] = ACTIONS(10038),
    [sym_usercontrol_keyword] = ACTIONS(10038),
    [sym_dataset_keyword] = ACTIONS(10038),
    [sym_elements_keyword] = ACTIONS(10038),
    [sym_dataitem_keyword] = ACTIONS(10038),
    [sym_column_keyword] = ACTIONS(10038),
    [sym_filter_keyword] = ACTIONS(10038),
    [sym_labels_keyword] = ACTIONS(10038),
    [sym_rendering_keyword] = ACTIONS(10038),
    [sym_requestpage_keyword] = ACTIONS(10038),
    [sym_schema_keyword] = ACTIONS(10038),
    [sym_views_keyword] = ACTIONS(10038),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10038),
    [sym_preproc_open] = ACTIONS(10038),
    [sym_preproc_close] = ACTIONS(10038),
  },
  [STATE(3747)] = {
    [anon_sym_SEMI] = ACTIONS(10042),
    [aux_sym_where_condition_token1] = ACTIONS(9985),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9983),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9983),
    [anon_sym_LBRACK] = ACTIONS(9983),
    [aux_sym_basic_type_token6] = ACTIONS(9985),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9983),
    [aux_sym_addafter_modification_token1] = ACTIONS(9983),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9983),
    [aux_sym_modify_modification_token1] = ACTIONS(9983),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9983),
    [aux_sym_movelast_modification_token1] = ACTIONS(9983),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9983),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9983),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9983),
    [anon_sym_POUNDif] = ACTIONS(9983),
    [anon_sym_POUNDIF] = ACTIONS(9983),
    [anon_sym_POUNDIf] = ACTIONS(9983),
    [anon_sym_POUNDelif] = ACTIONS(9983),
    [anon_sym_POUNDELIF] = ACTIONS(9983),
    [anon_sym_POUNDElif] = ACTIONS(9983),
    [anon_sym_POUNDelse] = ACTIONS(9983),
    [anon_sym_POUNDELSE] = ACTIONS(9983),
    [anon_sym_POUNDElse] = ACTIONS(9983),
    [anon_sym_POUNDendif] = ACTIONS(9983),
    [anon_sym_POUNDENDIF] = ACTIONS(9983),
    [anon_sym_POUNDEndif] = ACTIONS(9983),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9983),
    [sym_trigger_keyword] = ACTIONS(9983),
    [sym_var_keyword] = ACTIONS(9983),
    [sym_local_keyword] = ACTIONS(9983),
    [sym_internal_keyword] = ACTIONS(9983),
    [sym_protected_keyword] = ACTIONS(9983),
    [sym_event_keyword] = ACTIONS(9983),
    [sym_fields_keyword] = ACTIONS(9983),
    [sym_keys_keyword] = ACTIONS(9983),
    [sym_fieldgroups_keyword] = ACTIONS(9983),
    [sym_actions_keyword] = ACTIONS(9983),
    [sym_layout_keyword] = ACTIONS(9983),
    [sym_area_keyword] = ACTIONS(9983),
    [sym_group_keyword] = ACTIONS(9983),
    [sym_repeater_keyword] = ACTIONS(9983),
    [sym_cuegroup_keyword] = ACTIONS(9983),
    [sym_fixed_keyword] = ACTIONS(9983),
    [sym_grid_keyword] = ACTIONS(9983),
    [sym_part_keyword] = ACTIONS(9983),
    [sym_systempart_keyword] = ACTIONS(9983),
    [sym_usercontrol_keyword] = ACTIONS(9983),
    [sym_dataset_keyword] = ACTIONS(9983),
    [sym_elements_keyword] = ACTIONS(9983),
    [sym_dataitem_keyword] = ACTIONS(9983),
    [sym_column_keyword] = ACTIONS(9983),
    [sym_filter_keyword] = ACTIONS(9983),
    [sym_labels_keyword] = ACTIONS(9983),
    [sym_rendering_keyword] = ACTIONS(9983),
    [sym_requestpage_keyword] = ACTIONS(9983),
    [sym_schema_keyword] = ACTIONS(9983),
    [sym_views_keyword] = ACTIONS(9983),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9983),
    [sym_preproc_open] = ACTIONS(9983),
    [sym_preproc_close] = ACTIONS(9983),
  },
  [STATE(3748)] = {
    [anon_sym_SEMI] = ACTIONS(10044),
    [aux_sym_where_condition_token1] = ACTIONS(10046),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10048),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10048),
    [anon_sym_LBRACK] = ACTIONS(10048),
    [aux_sym_basic_type_token6] = ACTIONS(10046),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10048),
    [aux_sym_addafter_modification_token1] = ACTIONS(10048),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10048),
    [aux_sym_modify_modification_token1] = ACTIONS(10048),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10048),
    [aux_sym_movelast_modification_token1] = ACTIONS(10048),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10048),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10048),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10048),
    [anon_sym_POUNDif] = ACTIONS(10048),
    [anon_sym_POUNDIF] = ACTIONS(10048),
    [anon_sym_POUNDIf] = ACTIONS(10048),
    [anon_sym_POUNDelif] = ACTIONS(10048),
    [anon_sym_POUNDELIF] = ACTIONS(10048),
    [anon_sym_POUNDElif] = ACTIONS(10048),
    [anon_sym_POUNDelse] = ACTIONS(10048),
    [anon_sym_POUNDELSE] = ACTIONS(10048),
    [anon_sym_POUNDElse] = ACTIONS(10048),
    [anon_sym_POUNDendif] = ACTIONS(10048),
    [anon_sym_POUNDENDIF] = ACTIONS(10048),
    [anon_sym_POUNDEndif] = ACTIONS(10048),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10048),
    [sym_trigger_keyword] = ACTIONS(10048),
    [sym_var_keyword] = ACTIONS(10048),
    [sym_local_keyword] = ACTIONS(10048),
    [sym_internal_keyword] = ACTIONS(10048),
    [sym_protected_keyword] = ACTIONS(10048),
    [sym_event_keyword] = ACTIONS(10048),
    [sym_fields_keyword] = ACTIONS(10048),
    [sym_keys_keyword] = ACTIONS(10048),
    [sym_fieldgroups_keyword] = ACTIONS(10048),
    [sym_actions_keyword] = ACTIONS(10048),
    [sym_layout_keyword] = ACTIONS(10048),
    [sym_area_keyword] = ACTIONS(10048),
    [sym_group_keyword] = ACTIONS(10048),
    [sym_repeater_keyword] = ACTIONS(10048),
    [sym_cuegroup_keyword] = ACTIONS(10048),
    [sym_fixed_keyword] = ACTIONS(10048),
    [sym_grid_keyword] = ACTIONS(10048),
    [sym_part_keyword] = ACTIONS(10048),
    [sym_systempart_keyword] = ACTIONS(10048),
    [sym_usercontrol_keyword] = ACTIONS(10048),
    [sym_dataset_keyword] = ACTIONS(10048),
    [sym_elements_keyword] = ACTIONS(10048),
    [sym_dataitem_keyword] = ACTIONS(10048),
    [sym_column_keyword] = ACTIONS(10048),
    [sym_filter_keyword] = ACTIONS(10048),
    [sym_labels_keyword] = ACTIONS(10048),
    [sym_rendering_keyword] = ACTIONS(10048),
    [sym_requestpage_keyword] = ACTIONS(10048),
    [sym_schema_keyword] = ACTIONS(10048),
    [sym_views_keyword] = ACTIONS(10048),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10048),
    [sym_preproc_open] = ACTIONS(10048),
    [sym_preproc_close] = ACTIONS(10048),
  },
  [STATE(3749)] = {
    [anon_sym_SEMI] = ACTIONS(10050),
    [aux_sym_where_condition_token1] = ACTIONS(10046),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10048),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10048),
    [anon_sym_LBRACK] = ACTIONS(10048),
    [aux_sym_basic_type_token6] = ACTIONS(10046),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10048),
    [aux_sym_addafter_modification_token1] = ACTIONS(10048),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10048),
    [aux_sym_modify_modification_token1] = ACTIONS(10048),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10048),
    [aux_sym_movelast_modification_token1] = ACTIONS(10048),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10048),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10048),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10048),
    [anon_sym_POUNDif] = ACTIONS(10048),
    [anon_sym_POUNDIF] = ACTIONS(10048),
    [anon_sym_POUNDIf] = ACTIONS(10048),
    [anon_sym_POUNDelif] = ACTIONS(10048),
    [anon_sym_POUNDELIF] = ACTIONS(10048),
    [anon_sym_POUNDElif] = ACTIONS(10048),
    [anon_sym_POUNDelse] = ACTIONS(10048),
    [anon_sym_POUNDELSE] = ACTIONS(10048),
    [anon_sym_POUNDElse] = ACTIONS(10048),
    [anon_sym_POUNDendif] = ACTIONS(10048),
    [anon_sym_POUNDENDIF] = ACTIONS(10048),
    [anon_sym_POUNDEndif] = ACTIONS(10048),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10048),
    [sym_trigger_keyword] = ACTIONS(10048),
    [sym_var_keyword] = ACTIONS(10048),
    [sym_local_keyword] = ACTIONS(10048),
    [sym_internal_keyword] = ACTIONS(10048),
    [sym_protected_keyword] = ACTIONS(10048),
    [sym_event_keyword] = ACTIONS(10048),
    [sym_fields_keyword] = ACTIONS(10048),
    [sym_keys_keyword] = ACTIONS(10048),
    [sym_fieldgroups_keyword] = ACTIONS(10048),
    [sym_actions_keyword] = ACTIONS(10048),
    [sym_layout_keyword] = ACTIONS(10048),
    [sym_area_keyword] = ACTIONS(10048),
    [sym_group_keyword] = ACTIONS(10048),
    [sym_repeater_keyword] = ACTIONS(10048),
    [sym_cuegroup_keyword] = ACTIONS(10048),
    [sym_fixed_keyword] = ACTIONS(10048),
    [sym_grid_keyword] = ACTIONS(10048),
    [sym_part_keyword] = ACTIONS(10048),
    [sym_systempart_keyword] = ACTIONS(10048),
    [sym_usercontrol_keyword] = ACTIONS(10048),
    [sym_dataset_keyword] = ACTIONS(10048),
    [sym_elements_keyword] = ACTIONS(10048),
    [sym_dataitem_keyword] = ACTIONS(10048),
    [sym_column_keyword] = ACTIONS(10048),
    [sym_filter_keyword] = ACTIONS(10048),
    [sym_labels_keyword] = ACTIONS(10048),
    [sym_rendering_keyword] = ACTIONS(10048),
    [sym_requestpage_keyword] = ACTIONS(10048),
    [sym_schema_keyword] = ACTIONS(10048),
    [sym_views_keyword] = ACTIONS(10048),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10048),
    [sym_preproc_open] = ACTIONS(10048),
    [sym_preproc_close] = ACTIONS(10048),
  },
  [STATE(3750)] = {
    [anon_sym_SEMI] = ACTIONS(10052),
    [aux_sym_where_condition_token1] = ACTIONS(10054),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10056),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10056),
    [anon_sym_LBRACK] = ACTIONS(10056),
    [aux_sym_basic_type_token6] = ACTIONS(10054),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10056),
    [aux_sym_addafter_modification_token1] = ACTIONS(10056),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10056),
    [aux_sym_modify_modification_token1] = ACTIONS(10056),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10056),
    [aux_sym_movelast_modification_token1] = ACTIONS(10056),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10056),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10056),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10056),
    [anon_sym_POUNDif] = ACTIONS(10056),
    [anon_sym_POUNDIF] = ACTIONS(10056),
    [anon_sym_POUNDIf] = ACTIONS(10056),
    [anon_sym_POUNDelif] = ACTIONS(10056),
    [anon_sym_POUNDELIF] = ACTIONS(10056),
    [anon_sym_POUNDElif] = ACTIONS(10056),
    [anon_sym_POUNDelse] = ACTIONS(10056),
    [anon_sym_POUNDELSE] = ACTIONS(10056),
    [anon_sym_POUNDElse] = ACTIONS(10056),
    [anon_sym_POUNDendif] = ACTIONS(10056),
    [anon_sym_POUNDENDIF] = ACTIONS(10056),
    [anon_sym_POUNDEndif] = ACTIONS(10056),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10056),
    [sym_trigger_keyword] = ACTIONS(10056),
    [sym_var_keyword] = ACTIONS(10056),
    [sym_local_keyword] = ACTIONS(10056),
    [sym_internal_keyword] = ACTIONS(10056),
    [sym_protected_keyword] = ACTIONS(10056),
    [sym_event_keyword] = ACTIONS(10056),
    [sym_fields_keyword] = ACTIONS(10056),
    [sym_keys_keyword] = ACTIONS(10056),
    [sym_fieldgroups_keyword] = ACTIONS(10056),
    [sym_actions_keyword] = ACTIONS(10056),
    [sym_layout_keyword] = ACTIONS(10056),
    [sym_area_keyword] = ACTIONS(10056),
    [sym_group_keyword] = ACTIONS(10056),
    [sym_repeater_keyword] = ACTIONS(10056),
    [sym_cuegroup_keyword] = ACTIONS(10056),
    [sym_fixed_keyword] = ACTIONS(10056),
    [sym_grid_keyword] = ACTIONS(10056),
    [sym_part_keyword] = ACTIONS(10056),
    [sym_systempart_keyword] = ACTIONS(10056),
    [sym_usercontrol_keyword] = ACTIONS(10056),
    [sym_dataset_keyword] = ACTIONS(10056),
    [sym_elements_keyword] = ACTIONS(10056),
    [sym_dataitem_keyword] = ACTIONS(10056),
    [sym_column_keyword] = ACTIONS(10056),
    [sym_filter_keyword] = ACTIONS(10056),
    [sym_labels_keyword] = ACTIONS(10056),
    [sym_rendering_keyword] = ACTIONS(10056),
    [sym_requestpage_keyword] = ACTIONS(10056),
    [sym_schema_keyword] = ACTIONS(10056),
    [sym_views_keyword] = ACTIONS(10056),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10056),
    [sym_preproc_open] = ACTIONS(10056),
    [sym_preproc_close] = ACTIONS(10056),
  },
  [STATE(3751)] = {
    [anon_sym_SEMI] = ACTIONS(10058),
    [aux_sym_where_condition_token1] = ACTIONS(10054),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10056),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10056),
    [anon_sym_LBRACK] = ACTIONS(10056),
    [aux_sym_basic_type_token6] = ACTIONS(10054),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10056),
    [aux_sym_addafter_modification_token1] = ACTIONS(10056),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10056),
    [aux_sym_modify_modification_token1] = ACTIONS(10056),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10056),
    [aux_sym_movelast_modification_token1] = ACTIONS(10056),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10056),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10056),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10056),
    [anon_sym_POUNDif] = ACTIONS(10056),
    [anon_sym_POUNDIF] = ACTIONS(10056),
    [anon_sym_POUNDIf] = ACTIONS(10056),
    [anon_sym_POUNDelif] = ACTIONS(10056),
    [anon_sym_POUNDELIF] = ACTIONS(10056),
    [anon_sym_POUNDElif] = ACTIONS(10056),
    [anon_sym_POUNDelse] = ACTIONS(10056),
    [anon_sym_POUNDELSE] = ACTIONS(10056),
    [anon_sym_POUNDElse] = ACTIONS(10056),
    [anon_sym_POUNDendif] = ACTIONS(10056),
    [anon_sym_POUNDENDIF] = ACTIONS(10056),
    [anon_sym_POUNDEndif] = ACTIONS(10056),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10056),
    [sym_trigger_keyword] = ACTIONS(10056),
    [sym_var_keyword] = ACTIONS(10056),
    [sym_local_keyword] = ACTIONS(10056),
    [sym_internal_keyword] = ACTIONS(10056),
    [sym_protected_keyword] = ACTIONS(10056),
    [sym_event_keyword] = ACTIONS(10056),
    [sym_fields_keyword] = ACTIONS(10056),
    [sym_keys_keyword] = ACTIONS(10056),
    [sym_fieldgroups_keyword] = ACTIONS(10056),
    [sym_actions_keyword] = ACTIONS(10056),
    [sym_layout_keyword] = ACTIONS(10056),
    [sym_area_keyword] = ACTIONS(10056),
    [sym_group_keyword] = ACTIONS(10056),
    [sym_repeater_keyword] = ACTIONS(10056),
    [sym_cuegroup_keyword] = ACTIONS(10056),
    [sym_fixed_keyword] = ACTIONS(10056),
    [sym_grid_keyword] = ACTIONS(10056),
    [sym_part_keyword] = ACTIONS(10056),
    [sym_systempart_keyword] = ACTIONS(10056),
    [sym_usercontrol_keyword] = ACTIONS(10056),
    [sym_dataset_keyword] = ACTIONS(10056),
    [sym_elements_keyword] = ACTIONS(10056),
    [sym_dataitem_keyword] = ACTIONS(10056),
    [sym_column_keyword] = ACTIONS(10056),
    [sym_filter_keyword] = ACTIONS(10056),
    [sym_labels_keyword] = ACTIONS(10056),
    [sym_rendering_keyword] = ACTIONS(10056),
    [sym_requestpage_keyword] = ACTIONS(10056),
    [sym_schema_keyword] = ACTIONS(10056),
    [sym_views_keyword] = ACTIONS(10056),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10056),
    [sym_preproc_open] = ACTIONS(10056),
    [sym_preproc_close] = ACTIONS(10056),
  },
  [STATE(3752)] = {
    [anon_sym_SEMI] = ACTIONS(10060),
    [aux_sym_where_condition_token1] = ACTIONS(9503),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9501),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9501),
    [anon_sym_LBRACK] = ACTIONS(9501),
    [aux_sym_basic_type_token6] = ACTIONS(9503),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9501),
    [aux_sym_addafter_modification_token1] = ACTIONS(9501),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9501),
    [aux_sym_modify_modification_token1] = ACTIONS(9501),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9501),
    [aux_sym_movelast_modification_token1] = ACTIONS(9501),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9501),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9501),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9501),
    [anon_sym_POUNDif] = ACTIONS(9501),
    [anon_sym_POUNDIF] = ACTIONS(9501),
    [anon_sym_POUNDIf] = ACTIONS(9501),
    [anon_sym_POUNDelif] = ACTIONS(9501),
    [anon_sym_POUNDELIF] = ACTIONS(9501),
    [anon_sym_POUNDElif] = ACTIONS(9501),
    [anon_sym_POUNDelse] = ACTIONS(9501),
    [anon_sym_POUNDELSE] = ACTIONS(9501),
    [anon_sym_POUNDElse] = ACTIONS(9501),
    [anon_sym_POUNDendif] = ACTIONS(9501),
    [anon_sym_POUNDENDIF] = ACTIONS(9501),
    [anon_sym_POUNDEndif] = ACTIONS(9501),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9501),
    [sym_trigger_keyword] = ACTIONS(9501),
    [sym_var_keyword] = ACTIONS(9501),
    [sym_local_keyword] = ACTIONS(9501),
    [sym_internal_keyword] = ACTIONS(9501),
    [sym_protected_keyword] = ACTIONS(9501),
    [sym_event_keyword] = ACTIONS(9501),
    [sym_fields_keyword] = ACTIONS(9501),
    [sym_keys_keyword] = ACTIONS(9501),
    [sym_fieldgroups_keyword] = ACTIONS(9501),
    [sym_actions_keyword] = ACTIONS(9501),
    [sym_layout_keyword] = ACTIONS(9501),
    [sym_area_keyword] = ACTIONS(9501),
    [sym_group_keyword] = ACTIONS(9501),
    [sym_repeater_keyword] = ACTIONS(9501),
    [sym_cuegroup_keyword] = ACTIONS(9501),
    [sym_fixed_keyword] = ACTIONS(9501),
    [sym_grid_keyword] = ACTIONS(9501),
    [sym_part_keyword] = ACTIONS(9501),
    [sym_systempart_keyword] = ACTIONS(9501),
    [sym_usercontrol_keyword] = ACTIONS(9501),
    [sym_dataset_keyword] = ACTIONS(9501),
    [sym_elements_keyword] = ACTIONS(9501),
    [sym_dataitem_keyword] = ACTIONS(9501),
    [sym_column_keyword] = ACTIONS(9501),
    [sym_filter_keyword] = ACTIONS(9501),
    [sym_labels_keyword] = ACTIONS(9501),
    [sym_rendering_keyword] = ACTIONS(9501),
    [sym_requestpage_keyword] = ACTIONS(9501),
    [sym_schema_keyword] = ACTIONS(9501),
    [sym_views_keyword] = ACTIONS(9501),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9501),
    [sym_preproc_open] = ACTIONS(9501),
    [sym_preproc_close] = ACTIONS(9501),
  },
  [STATE(3753)] = {
    [anon_sym_SEMI] = ACTIONS(10062),
    [aux_sym_where_condition_token1] = ACTIONS(9503),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9501),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9501),
    [anon_sym_LBRACK] = ACTIONS(9501),
    [aux_sym_basic_type_token6] = ACTIONS(9503),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9501),
    [aux_sym_addafter_modification_token1] = ACTIONS(9501),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9501),
    [aux_sym_modify_modification_token1] = ACTIONS(9501),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9501),
    [aux_sym_movelast_modification_token1] = ACTIONS(9501),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9501),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9501),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9501),
    [anon_sym_POUNDif] = ACTIONS(9501),
    [anon_sym_POUNDIF] = ACTIONS(9501),
    [anon_sym_POUNDIf] = ACTIONS(9501),
    [anon_sym_POUNDelif] = ACTIONS(9501),
    [anon_sym_POUNDELIF] = ACTIONS(9501),
    [anon_sym_POUNDElif] = ACTIONS(9501),
    [anon_sym_POUNDelse] = ACTIONS(9501),
    [anon_sym_POUNDELSE] = ACTIONS(9501),
    [anon_sym_POUNDElse] = ACTIONS(9501),
    [anon_sym_POUNDendif] = ACTIONS(9501),
    [anon_sym_POUNDENDIF] = ACTIONS(9501),
    [anon_sym_POUNDEndif] = ACTIONS(9501),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9501),
    [sym_trigger_keyword] = ACTIONS(9501),
    [sym_var_keyword] = ACTIONS(9501),
    [sym_local_keyword] = ACTIONS(9501),
    [sym_internal_keyword] = ACTIONS(9501),
    [sym_protected_keyword] = ACTIONS(9501),
    [sym_event_keyword] = ACTIONS(9501),
    [sym_fields_keyword] = ACTIONS(9501),
    [sym_keys_keyword] = ACTIONS(9501),
    [sym_fieldgroups_keyword] = ACTIONS(9501),
    [sym_actions_keyword] = ACTIONS(9501),
    [sym_layout_keyword] = ACTIONS(9501),
    [sym_area_keyword] = ACTIONS(9501),
    [sym_group_keyword] = ACTIONS(9501),
    [sym_repeater_keyword] = ACTIONS(9501),
    [sym_cuegroup_keyword] = ACTIONS(9501),
    [sym_fixed_keyword] = ACTIONS(9501),
    [sym_grid_keyword] = ACTIONS(9501),
    [sym_part_keyword] = ACTIONS(9501),
    [sym_systempart_keyword] = ACTIONS(9501),
    [sym_usercontrol_keyword] = ACTIONS(9501),
    [sym_dataset_keyword] = ACTIONS(9501),
    [sym_elements_keyword] = ACTIONS(9501),
    [sym_dataitem_keyword] = ACTIONS(9501),
    [sym_column_keyword] = ACTIONS(9501),
    [sym_filter_keyword] = ACTIONS(9501),
    [sym_labels_keyword] = ACTIONS(9501),
    [sym_rendering_keyword] = ACTIONS(9501),
    [sym_requestpage_keyword] = ACTIONS(9501),
    [sym_schema_keyword] = ACTIONS(9501),
    [sym_views_keyword] = ACTIONS(9501),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9501),
    [sym_preproc_open] = ACTIONS(9501),
    [sym_preproc_close] = ACTIONS(9501),
  },
  [STATE(3754)] = {
    [anon_sym_SEMI] = ACTIONS(10064),
    [aux_sym_where_condition_token1] = ACTIONS(10066),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10068),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10068),
    [anon_sym_LBRACK] = ACTIONS(10068),
    [aux_sym_basic_type_token6] = ACTIONS(10066),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10068),
    [aux_sym_addafter_modification_token1] = ACTIONS(10068),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10068),
    [aux_sym_modify_modification_token1] = ACTIONS(10068),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10068),
    [aux_sym_movelast_modification_token1] = ACTIONS(10068),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10068),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10068),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10068),
    [anon_sym_POUNDif] = ACTIONS(10068),
    [anon_sym_POUNDIF] = ACTIONS(10068),
    [anon_sym_POUNDIf] = ACTIONS(10068),
    [anon_sym_POUNDelif] = ACTIONS(10068),
    [anon_sym_POUNDELIF] = ACTIONS(10068),
    [anon_sym_POUNDElif] = ACTIONS(10068),
    [anon_sym_POUNDelse] = ACTIONS(10068),
    [anon_sym_POUNDELSE] = ACTIONS(10068),
    [anon_sym_POUNDElse] = ACTIONS(10068),
    [anon_sym_POUNDendif] = ACTIONS(10068),
    [anon_sym_POUNDENDIF] = ACTIONS(10068),
    [anon_sym_POUNDEndif] = ACTIONS(10068),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10068),
    [sym_trigger_keyword] = ACTIONS(10068),
    [sym_var_keyword] = ACTIONS(10068),
    [sym_local_keyword] = ACTIONS(10068),
    [sym_internal_keyword] = ACTIONS(10068),
    [sym_protected_keyword] = ACTIONS(10068),
    [sym_event_keyword] = ACTIONS(10068),
    [sym_fields_keyword] = ACTIONS(10068),
    [sym_keys_keyword] = ACTIONS(10068),
    [sym_fieldgroups_keyword] = ACTIONS(10068),
    [sym_actions_keyword] = ACTIONS(10068),
    [sym_layout_keyword] = ACTIONS(10068),
    [sym_area_keyword] = ACTIONS(10068),
    [sym_group_keyword] = ACTIONS(10068),
    [sym_repeater_keyword] = ACTIONS(10068),
    [sym_cuegroup_keyword] = ACTIONS(10068),
    [sym_fixed_keyword] = ACTIONS(10068),
    [sym_grid_keyword] = ACTIONS(10068),
    [sym_part_keyword] = ACTIONS(10068),
    [sym_systempart_keyword] = ACTIONS(10068),
    [sym_usercontrol_keyword] = ACTIONS(10068),
    [sym_dataset_keyword] = ACTIONS(10068),
    [sym_elements_keyword] = ACTIONS(10068),
    [sym_dataitem_keyword] = ACTIONS(10068),
    [sym_column_keyword] = ACTIONS(10068),
    [sym_filter_keyword] = ACTIONS(10068),
    [sym_labels_keyword] = ACTIONS(10068),
    [sym_rendering_keyword] = ACTIONS(10068),
    [sym_requestpage_keyword] = ACTIONS(10068),
    [sym_schema_keyword] = ACTIONS(10068),
    [sym_views_keyword] = ACTIONS(10068),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10068),
    [sym_preproc_open] = ACTIONS(10068),
    [sym_preproc_close] = ACTIONS(10068),
  },
  [STATE(3755)] = {
    [anon_sym_SEMI] = ACTIONS(10070),
    [aux_sym_where_condition_token1] = ACTIONS(10066),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10068),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10068),
    [anon_sym_LBRACK] = ACTIONS(10068),
    [aux_sym_basic_type_token6] = ACTIONS(10066),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10068),
    [aux_sym_addafter_modification_token1] = ACTIONS(10068),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10068),
    [aux_sym_modify_modification_token1] = ACTIONS(10068),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10068),
    [aux_sym_movelast_modification_token1] = ACTIONS(10068),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10068),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10068),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10068),
    [anon_sym_POUNDif] = ACTIONS(10068),
    [anon_sym_POUNDIF] = ACTIONS(10068),
    [anon_sym_POUNDIf] = ACTIONS(10068),
    [anon_sym_POUNDelif] = ACTIONS(10068),
    [anon_sym_POUNDELIF] = ACTIONS(10068),
    [anon_sym_POUNDElif] = ACTIONS(10068),
    [anon_sym_POUNDelse] = ACTIONS(10068),
    [anon_sym_POUNDELSE] = ACTIONS(10068),
    [anon_sym_POUNDElse] = ACTIONS(10068),
    [anon_sym_POUNDendif] = ACTIONS(10068),
    [anon_sym_POUNDENDIF] = ACTIONS(10068),
    [anon_sym_POUNDEndif] = ACTIONS(10068),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10068),
    [sym_trigger_keyword] = ACTIONS(10068),
    [sym_var_keyword] = ACTIONS(10068),
    [sym_local_keyword] = ACTIONS(10068),
    [sym_internal_keyword] = ACTIONS(10068),
    [sym_protected_keyword] = ACTIONS(10068),
    [sym_event_keyword] = ACTIONS(10068),
    [sym_fields_keyword] = ACTIONS(10068),
    [sym_keys_keyword] = ACTIONS(10068),
    [sym_fieldgroups_keyword] = ACTIONS(10068),
    [sym_actions_keyword] = ACTIONS(10068),
    [sym_layout_keyword] = ACTIONS(10068),
    [sym_area_keyword] = ACTIONS(10068),
    [sym_group_keyword] = ACTIONS(10068),
    [sym_repeater_keyword] = ACTIONS(10068),
    [sym_cuegroup_keyword] = ACTIONS(10068),
    [sym_fixed_keyword] = ACTIONS(10068),
    [sym_grid_keyword] = ACTIONS(10068),
    [sym_part_keyword] = ACTIONS(10068),
    [sym_systempart_keyword] = ACTIONS(10068),
    [sym_usercontrol_keyword] = ACTIONS(10068),
    [sym_dataset_keyword] = ACTIONS(10068),
    [sym_elements_keyword] = ACTIONS(10068),
    [sym_dataitem_keyword] = ACTIONS(10068),
    [sym_column_keyword] = ACTIONS(10068),
    [sym_filter_keyword] = ACTIONS(10068),
    [sym_labels_keyword] = ACTIONS(10068),
    [sym_rendering_keyword] = ACTIONS(10068),
    [sym_requestpage_keyword] = ACTIONS(10068),
    [sym_schema_keyword] = ACTIONS(10068),
    [sym_views_keyword] = ACTIONS(10068),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10068),
    [sym_preproc_open] = ACTIONS(10068),
    [sym_preproc_close] = ACTIONS(10068),
  },
  [STATE(3756)] = {
    [anon_sym_SEMI] = ACTIONS(8201),
    [aux_sym_where_condition_token1] = ACTIONS(8199),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8201),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8201),
    [anon_sym_LBRACK] = ACTIONS(8201),
    [aux_sym_basic_type_token6] = ACTIONS(8199),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8201),
    [aux_sym_addafter_modification_token1] = ACTIONS(8201),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8201),
    [aux_sym_modify_modification_token1] = ACTIONS(8201),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8201),
    [aux_sym_movelast_modification_token1] = ACTIONS(8201),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8201),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8201),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8201),
    [anon_sym_POUNDif] = ACTIONS(8201),
    [anon_sym_POUNDIF] = ACTIONS(8201),
    [anon_sym_POUNDIf] = ACTIONS(8201),
    [anon_sym_POUNDelif] = ACTIONS(8201),
    [anon_sym_POUNDELIF] = ACTIONS(8201),
    [anon_sym_POUNDElif] = ACTIONS(8201),
    [anon_sym_POUNDelse] = ACTIONS(8201),
    [anon_sym_POUNDELSE] = ACTIONS(8201),
    [anon_sym_POUNDElse] = ACTIONS(8201),
    [anon_sym_POUNDendif] = ACTIONS(8201),
    [anon_sym_POUNDENDIF] = ACTIONS(8201),
    [anon_sym_POUNDEndif] = ACTIONS(8201),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8201),
    [sym_trigger_keyword] = ACTIONS(8201),
    [sym_var_keyword] = ACTIONS(8201),
    [sym_local_keyword] = ACTIONS(8201),
    [sym_internal_keyword] = ACTIONS(8201),
    [sym_protected_keyword] = ACTIONS(8201),
    [sym_event_keyword] = ACTIONS(8201),
    [sym_fields_keyword] = ACTIONS(8201),
    [sym_keys_keyword] = ACTIONS(8201),
    [sym_fieldgroups_keyword] = ACTIONS(8201),
    [sym_actions_keyword] = ACTIONS(8201),
    [sym_layout_keyword] = ACTIONS(8201),
    [sym_area_keyword] = ACTIONS(8201),
    [sym_group_keyword] = ACTIONS(8201),
    [sym_repeater_keyword] = ACTIONS(8201),
    [sym_cuegroup_keyword] = ACTIONS(8201),
    [sym_fixed_keyword] = ACTIONS(8201),
    [sym_grid_keyword] = ACTIONS(8201),
    [sym_part_keyword] = ACTIONS(8201),
    [sym_systempart_keyword] = ACTIONS(8201),
    [sym_usercontrol_keyword] = ACTIONS(8201),
    [sym_dataset_keyword] = ACTIONS(8201),
    [sym_elements_keyword] = ACTIONS(8201),
    [sym_dataitem_keyword] = ACTIONS(8201),
    [sym_column_keyword] = ACTIONS(8201),
    [sym_filter_keyword] = ACTIONS(8201),
    [sym_labels_keyword] = ACTIONS(8201),
    [sym_rendering_keyword] = ACTIONS(8201),
    [sym_requestpage_keyword] = ACTIONS(8201),
    [sym_schema_keyword] = ACTIONS(8201),
    [sym_views_keyword] = ACTIONS(8201),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8201),
    [sym_preproc_open] = ACTIONS(8201),
    [sym_preproc_close] = ACTIONS(8201),
  },
  [STATE(3757)] = {
    [anon_sym_SEMI] = ACTIONS(8201),
    [aux_sym_where_condition_token1] = ACTIONS(8199),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8201),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8201),
    [anon_sym_LBRACK] = ACTIONS(8201),
    [aux_sym_basic_type_token6] = ACTIONS(8199),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8201),
    [aux_sym_addafter_modification_token1] = ACTIONS(8201),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8201),
    [aux_sym_modify_modification_token1] = ACTIONS(8201),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8201),
    [aux_sym_movelast_modification_token1] = ACTIONS(8201),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8201),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8201),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8201),
    [anon_sym_POUNDif] = ACTIONS(8201),
    [anon_sym_POUNDIF] = ACTIONS(8201),
    [anon_sym_POUNDIf] = ACTIONS(8201),
    [anon_sym_POUNDelif] = ACTIONS(8201),
    [anon_sym_POUNDELIF] = ACTIONS(8201),
    [anon_sym_POUNDElif] = ACTIONS(8201),
    [anon_sym_POUNDelse] = ACTIONS(8201),
    [anon_sym_POUNDELSE] = ACTIONS(8201),
    [anon_sym_POUNDElse] = ACTIONS(8201),
    [anon_sym_POUNDendif] = ACTIONS(8201),
    [anon_sym_POUNDENDIF] = ACTIONS(8201),
    [anon_sym_POUNDEndif] = ACTIONS(8201),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8201),
    [sym_trigger_keyword] = ACTIONS(8201),
    [sym_var_keyword] = ACTIONS(8201),
    [sym_local_keyword] = ACTIONS(8201),
    [sym_internal_keyword] = ACTIONS(8201),
    [sym_protected_keyword] = ACTIONS(8201),
    [sym_event_keyword] = ACTIONS(8201),
    [sym_fields_keyword] = ACTIONS(8201),
    [sym_keys_keyword] = ACTIONS(8201),
    [sym_fieldgroups_keyword] = ACTIONS(8201),
    [sym_actions_keyword] = ACTIONS(8201),
    [sym_layout_keyword] = ACTIONS(8201),
    [sym_area_keyword] = ACTIONS(8201),
    [sym_group_keyword] = ACTIONS(8201),
    [sym_repeater_keyword] = ACTIONS(8201),
    [sym_cuegroup_keyword] = ACTIONS(8201),
    [sym_fixed_keyword] = ACTIONS(8201),
    [sym_grid_keyword] = ACTIONS(8201),
    [sym_part_keyword] = ACTIONS(8201),
    [sym_systempart_keyword] = ACTIONS(8201),
    [sym_usercontrol_keyword] = ACTIONS(8201),
    [sym_dataset_keyword] = ACTIONS(8201),
    [sym_elements_keyword] = ACTIONS(8201),
    [sym_dataitem_keyword] = ACTIONS(8201),
    [sym_column_keyword] = ACTIONS(8201),
    [sym_filter_keyword] = ACTIONS(8201),
    [sym_labels_keyword] = ACTIONS(8201),
    [sym_rendering_keyword] = ACTIONS(8201),
    [sym_requestpage_keyword] = ACTIONS(8201),
    [sym_schema_keyword] = ACTIONS(8201),
    [sym_views_keyword] = ACTIONS(8201),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8201),
    [sym_preproc_open] = ACTIONS(8201),
    [sym_preproc_close] = ACTIONS(8201),
  },
  [STATE(3758)] = {
    [anon_sym_SEMI] = ACTIONS(8201),
    [aux_sym_where_condition_token1] = ACTIONS(8199),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8201),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8201),
    [anon_sym_LBRACK] = ACTIONS(8201),
    [aux_sym_basic_type_token6] = ACTIONS(8199),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8201),
    [aux_sym_addafter_modification_token1] = ACTIONS(8201),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8201),
    [aux_sym_modify_modification_token1] = ACTIONS(8201),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8201),
    [aux_sym_movelast_modification_token1] = ACTIONS(8201),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8201),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8201),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8201),
    [anon_sym_POUNDif] = ACTIONS(8201),
    [anon_sym_POUNDIF] = ACTIONS(8201),
    [anon_sym_POUNDIf] = ACTIONS(8201),
    [anon_sym_POUNDelif] = ACTIONS(8201),
    [anon_sym_POUNDELIF] = ACTIONS(8201),
    [anon_sym_POUNDElif] = ACTIONS(8201),
    [anon_sym_POUNDelse] = ACTIONS(8201),
    [anon_sym_POUNDELSE] = ACTIONS(8201),
    [anon_sym_POUNDElse] = ACTIONS(8201),
    [anon_sym_POUNDendif] = ACTIONS(8201),
    [anon_sym_POUNDENDIF] = ACTIONS(8201),
    [anon_sym_POUNDEndif] = ACTIONS(8201),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8201),
    [sym_trigger_keyword] = ACTIONS(8201),
    [sym_var_keyword] = ACTIONS(8201),
    [sym_local_keyword] = ACTIONS(8201),
    [sym_internal_keyword] = ACTIONS(8201),
    [sym_protected_keyword] = ACTIONS(8201),
    [sym_event_keyword] = ACTIONS(8201),
    [sym_fields_keyword] = ACTIONS(8201),
    [sym_keys_keyword] = ACTIONS(8201),
    [sym_fieldgroups_keyword] = ACTIONS(8201),
    [sym_actions_keyword] = ACTIONS(8201),
    [sym_layout_keyword] = ACTIONS(8201),
    [sym_area_keyword] = ACTIONS(8201),
    [sym_group_keyword] = ACTIONS(8201),
    [sym_repeater_keyword] = ACTIONS(8201),
    [sym_cuegroup_keyword] = ACTIONS(8201),
    [sym_fixed_keyword] = ACTIONS(8201),
    [sym_grid_keyword] = ACTIONS(8201),
    [sym_part_keyword] = ACTIONS(8201),
    [sym_systempart_keyword] = ACTIONS(8201),
    [sym_usercontrol_keyword] = ACTIONS(8201),
    [sym_dataset_keyword] = ACTIONS(8201),
    [sym_elements_keyword] = ACTIONS(8201),
    [sym_dataitem_keyword] = ACTIONS(8201),
    [sym_column_keyword] = ACTIONS(8201),
    [sym_filter_keyword] = ACTIONS(8201),
    [sym_labels_keyword] = ACTIONS(8201),
    [sym_rendering_keyword] = ACTIONS(8201),
    [sym_requestpage_keyword] = ACTIONS(8201),
    [sym_schema_keyword] = ACTIONS(8201),
    [sym_views_keyword] = ACTIONS(8201),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8201),
    [sym_preproc_open] = ACTIONS(8201),
    [sym_preproc_close] = ACTIONS(8201),
  },
  [STATE(3759)] = {
    [anon_sym_SEMI] = ACTIONS(6978),
    [aux_sym_where_condition_token1] = ACTIONS(6976),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6978),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6978),
    [anon_sym_LBRACK] = ACTIONS(6978),
    [aux_sym_basic_type_token6] = ACTIONS(6976),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6978),
    [aux_sym_addafter_modification_token1] = ACTIONS(6978),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6978),
    [aux_sym_modify_modification_token1] = ACTIONS(6978),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6978),
    [aux_sym_movelast_modification_token1] = ACTIONS(6978),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6978),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6978),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6978),
    [anon_sym_POUNDif] = ACTIONS(6978),
    [anon_sym_POUNDIF] = ACTIONS(6978),
    [anon_sym_POUNDIf] = ACTIONS(6978),
    [anon_sym_POUNDelif] = ACTIONS(6978),
    [anon_sym_POUNDELIF] = ACTIONS(6978),
    [anon_sym_POUNDElif] = ACTIONS(6978),
    [anon_sym_POUNDelse] = ACTIONS(6978),
    [anon_sym_POUNDELSE] = ACTIONS(6978),
    [anon_sym_POUNDElse] = ACTIONS(6978),
    [anon_sym_POUNDendif] = ACTIONS(6978),
    [anon_sym_POUNDENDIF] = ACTIONS(6978),
    [anon_sym_POUNDEndif] = ACTIONS(6978),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6978),
    [sym_trigger_keyword] = ACTIONS(6978),
    [sym_var_keyword] = ACTIONS(6978),
    [sym_local_keyword] = ACTIONS(6978),
    [sym_internal_keyword] = ACTIONS(6978),
    [sym_protected_keyword] = ACTIONS(6978),
    [sym_event_keyword] = ACTIONS(6978),
    [sym_fields_keyword] = ACTIONS(6978),
    [sym_keys_keyword] = ACTIONS(6978),
    [sym_fieldgroups_keyword] = ACTIONS(6978),
    [sym_actions_keyword] = ACTIONS(6978),
    [sym_layout_keyword] = ACTIONS(6978),
    [sym_area_keyword] = ACTIONS(6978),
    [sym_group_keyword] = ACTIONS(6978),
    [sym_repeater_keyword] = ACTIONS(6978),
    [sym_cuegroup_keyword] = ACTIONS(6978),
    [sym_fixed_keyword] = ACTIONS(6978),
    [sym_grid_keyword] = ACTIONS(6978),
    [sym_part_keyword] = ACTIONS(6978),
    [sym_systempart_keyword] = ACTIONS(6978),
    [sym_usercontrol_keyword] = ACTIONS(6978),
    [sym_dataset_keyword] = ACTIONS(6978),
    [sym_elements_keyword] = ACTIONS(6978),
    [sym_dataitem_keyword] = ACTIONS(6978),
    [sym_column_keyword] = ACTIONS(6978),
    [sym_filter_keyword] = ACTIONS(6978),
    [sym_labels_keyword] = ACTIONS(6978),
    [sym_rendering_keyword] = ACTIONS(6978),
    [sym_requestpage_keyword] = ACTIONS(6978),
    [sym_schema_keyword] = ACTIONS(6978),
    [sym_views_keyword] = ACTIONS(6978),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6978),
    [sym_preproc_open] = ACTIONS(6978),
    [sym_preproc_close] = ACTIONS(6978),
  },
  [STATE(3760)] = {
    [anon_sym_SEMI] = ACTIONS(10072),
    [aux_sym_where_condition_token1] = ACTIONS(10074),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10072),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10072),
    [anon_sym_LBRACK] = ACTIONS(10072),
    [aux_sym_basic_type_token6] = ACTIONS(10074),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10072),
    [aux_sym_addafter_modification_token1] = ACTIONS(10072),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10072),
    [aux_sym_modify_modification_token1] = ACTIONS(10072),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10072),
    [aux_sym_movelast_modification_token1] = ACTIONS(10072),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10072),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10072),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10072),
    [anon_sym_POUNDif] = ACTIONS(10072),
    [anon_sym_POUNDIF] = ACTIONS(10072),
    [anon_sym_POUNDIf] = ACTIONS(10072),
    [anon_sym_POUNDelif] = ACTIONS(10072),
    [anon_sym_POUNDELIF] = ACTIONS(10072),
    [anon_sym_POUNDElif] = ACTIONS(10072),
    [anon_sym_POUNDelse] = ACTIONS(10072),
    [anon_sym_POUNDELSE] = ACTIONS(10072),
    [anon_sym_POUNDElse] = ACTIONS(10072),
    [anon_sym_POUNDendif] = ACTIONS(10072),
    [anon_sym_POUNDENDIF] = ACTIONS(10072),
    [anon_sym_POUNDEndif] = ACTIONS(10072),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10072),
    [sym_trigger_keyword] = ACTIONS(10072),
    [sym_var_keyword] = ACTIONS(10072),
    [sym_local_keyword] = ACTIONS(10072),
    [sym_internal_keyword] = ACTIONS(10072),
    [sym_protected_keyword] = ACTIONS(10072),
    [sym_event_keyword] = ACTIONS(10072),
    [sym_fields_keyword] = ACTIONS(10072),
    [sym_keys_keyword] = ACTIONS(10072),
    [sym_fieldgroups_keyword] = ACTIONS(10072),
    [sym_actions_keyword] = ACTIONS(10072),
    [sym_layout_keyword] = ACTIONS(10072),
    [sym_area_keyword] = ACTIONS(10072),
    [sym_group_keyword] = ACTIONS(10072),
    [sym_repeater_keyword] = ACTIONS(10072),
    [sym_cuegroup_keyword] = ACTIONS(10072),
    [sym_fixed_keyword] = ACTIONS(10072),
    [sym_grid_keyword] = ACTIONS(10072),
    [sym_part_keyword] = ACTIONS(10072),
    [sym_systempart_keyword] = ACTIONS(10072),
    [sym_usercontrol_keyword] = ACTIONS(10072),
    [sym_dataset_keyword] = ACTIONS(10072),
    [sym_elements_keyword] = ACTIONS(10072),
    [sym_dataitem_keyword] = ACTIONS(10072),
    [sym_column_keyword] = ACTIONS(10072),
    [sym_filter_keyword] = ACTIONS(10072),
    [sym_labels_keyword] = ACTIONS(10072),
    [sym_rendering_keyword] = ACTIONS(10072),
    [sym_requestpage_keyword] = ACTIONS(10072),
    [sym_schema_keyword] = ACTIONS(10072),
    [sym_views_keyword] = ACTIONS(10072),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10072),
    [sym_preproc_open] = ACTIONS(10072),
    [sym_preproc_close] = ACTIONS(10072),
  },
  [STATE(3761)] = {
    [anon_sym_SEMI] = ACTIONS(9697),
    [aux_sym_where_condition_token1] = ACTIONS(9699),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9697),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9697),
    [anon_sym_LBRACK] = ACTIONS(9697),
    [aux_sym_basic_type_token6] = ACTIONS(9699),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9697),
    [aux_sym_addafter_modification_token1] = ACTIONS(9697),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9697),
    [aux_sym_modify_modification_token1] = ACTIONS(9697),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9697),
    [aux_sym_movelast_modification_token1] = ACTIONS(9697),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9697),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9697),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9697),
    [anon_sym_POUNDif] = ACTIONS(9697),
    [anon_sym_POUNDIF] = ACTIONS(9697),
    [anon_sym_POUNDIf] = ACTIONS(9697),
    [anon_sym_POUNDelif] = ACTIONS(9697),
    [anon_sym_POUNDELIF] = ACTIONS(9697),
    [anon_sym_POUNDElif] = ACTIONS(9697),
    [anon_sym_POUNDelse] = ACTIONS(9697),
    [anon_sym_POUNDELSE] = ACTIONS(9697),
    [anon_sym_POUNDElse] = ACTIONS(9697),
    [anon_sym_POUNDendif] = ACTIONS(9697),
    [anon_sym_POUNDENDIF] = ACTIONS(9697),
    [anon_sym_POUNDEndif] = ACTIONS(9697),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9697),
    [sym_trigger_keyword] = ACTIONS(9697),
    [sym_var_keyword] = ACTIONS(9697),
    [sym_local_keyword] = ACTIONS(9697),
    [sym_internal_keyword] = ACTIONS(9697),
    [sym_protected_keyword] = ACTIONS(9697),
    [sym_event_keyword] = ACTIONS(9697),
    [sym_fields_keyword] = ACTIONS(9697),
    [sym_keys_keyword] = ACTIONS(9697),
    [sym_fieldgroups_keyword] = ACTIONS(9697),
    [sym_actions_keyword] = ACTIONS(9697),
    [sym_layout_keyword] = ACTIONS(9697),
    [sym_area_keyword] = ACTIONS(9697),
    [sym_group_keyword] = ACTIONS(9697),
    [sym_repeater_keyword] = ACTIONS(9697),
    [sym_cuegroup_keyword] = ACTIONS(9697),
    [sym_fixed_keyword] = ACTIONS(9697),
    [sym_grid_keyword] = ACTIONS(9697),
    [sym_part_keyword] = ACTIONS(9697),
    [sym_systempart_keyword] = ACTIONS(9697),
    [sym_usercontrol_keyword] = ACTIONS(9697),
    [sym_dataset_keyword] = ACTIONS(9697),
    [sym_elements_keyword] = ACTIONS(9697),
    [sym_dataitem_keyword] = ACTIONS(9697),
    [sym_column_keyword] = ACTIONS(9697),
    [sym_filter_keyword] = ACTIONS(9697),
    [sym_labels_keyword] = ACTIONS(9697),
    [sym_rendering_keyword] = ACTIONS(9697),
    [sym_requestpage_keyword] = ACTIONS(9697),
    [sym_schema_keyword] = ACTIONS(9697),
    [sym_views_keyword] = ACTIONS(9697),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9697),
    [sym_preproc_open] = ACTIONS(9697),
    [sym_preproc_close] = ACTIONS(9697),
  },
  [STATE(3762)] = {
    [anon_sym_SEMI] = ACTIONS(8237),
    [aux_sym_where_condition_token1] = ACTIONS(8235),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8237),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8237),
    [anon_sym_LBRACK] = ACTIONS(8237),
    [aux_sym_basic_type_token6] = ACTIONS(8235),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8237),
    [aux_sym_addafter_modification_token1] = ACTIONS(8237),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8237),
    [aux_sym_modify_modification_token1] = ACTIONS(8237),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8237),
    [aux_sym_movelast_modification_token1] = ACTIONS(8237),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8237),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8237),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8237),
    [anon_sym_POUNDif] = ACTIONS(8237),
    [anon_sym_POUNDIF] = ACTIONS(8237),
    [anon_sym_POUNDIf] = ACTIONS(8237),
    [anon_sym_POUNDelif] = ACTIONS(8237),
    [anon_sym_POUNDELIF] = ACTIONS(8237),
    [anon_sym_POUNDElif] = ACTIONS(8237),
    [anon_sym_POUNDelse] = ACTIONS(8237),
    [anon_sym_POUNDELSE] = ACTIONS(8237),
    [anon_sym_POUNDElse] = ACTIONS(8237),
    [anon_sym_POUNDendif] = ACTIONS(8237),
    [anon_sym_POUNDENDIF] = ACTIONS(8237),
    [anon_sym_POUNDEndif] = ACTIONS(8237),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8237),
    [sym_trigger_keyword] = ACTIONS(8237),
    [sym_var_keyword] = ACTIONS(8237),
    [sym_local_keyword] = ACTIONS(8237),
    [sym_internal_keyword] = ACTIONS(8237),
    [sym_protected_keyword] = ACTIONS(8237),
    [sym_event_keyword] = ACTIONS(8237),
    [sym_fields_keyword] = ACTIONS(8237),
    [sym_keys_keyword] = ACTIONS(8237),
    [sym_fieldgroups_keyword] = ACTIONS(8237),
    [sym_actions_keyword] = ACTIONS(8237),
    [sym_layout_keyword] = ACTIONS(8237),
    [sym_area_keyword] = ACTIONS(8237),
    [sym_group_keyword] = ACTIONS(8237),
    [sym_repeater_keyword] = ACTIONS(8237),
    [sym_cuegroup_keyword] = ACTIONS(8237),
    [sym_fixed_keyword] = ACTIONS(8237),
    [sym_grid_keyword] = ACTIONS(8237),
    [sym_part_keyword] = ACTIONS(8237),
    [sym_systempart_keyword] = ACTIONS(8237),
    [sym_usercontrol_keyword] = ACTIONS(8237),
    [sym_dataset_keyword] = ACTIONS(8237),
    [sym_elements_keyword] = ACTIONS(8237),
    [sym_dataitem_keyword] = ACTIONS(8237),
    [sym_column_keyword] = ACTIONS(8237),
    [sym_filter_keyword] = ACTIONS(8237),
    [sym_labels_keyword] = ACTIONS(8237),
    [sym_rendering_keyword] = ACTIONS(8237),
    [sym_requestpage_keyword] = ACTIONS(8237),
    [sym_schema_keyword] = ACTIONS(8237),
    [sym_views_keyword] = ACTIONS(8237),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8237),
    [sym_preproc_open] = ACTIONS(8237),
    [sym_preproc_close] = ACTIONS(8237),
  },
  [STATE(3763)] = {
    [anon_sym_SEMI] = ACTIONS(10076),
    [aux_sym_where_condition_token1] = ACTIONS(10078),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10076),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10076),
    [anon_sym_LBRACK] = ACTIONS(10076),
    [aux_sym_basic_type_token6] = ACTIONS(10078),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10076),
    [aux_sym_addafter_modification_token1] = ACTIONS(10076),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10076),
    [aux_sym_modify_modification_token1] = ACTIONS(10076),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10076),
    [aux_sym_movelast_modification_token1] = ACTIONS(10076),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10076),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10076),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10076),
    [anon_sym_POUNDif] = ACTIONS(10076),
    [anon_sym_POUNDIF] = ACTIONS(10076),
    [anon_sym_POUNDIf] = ACTIONS(10076),
    [anon_sym_POUNDelif] = ACTIONS(10076),
    [anon_sym_POUNDELIF] = ACTIONS(10076),
    [anon_sym_POUNDElif] = ACTIONS(10076),
    [anon_sym_POUNDelse] = ACTIONS(10076),
    [anon_sym_POUNDELSE] = ACTIONS(10076),
    [anon_sym_POUNDElse] = ACTIONS(10076),
    [anon_sym_POUNDendif] = ACTIONS(10076),
    [anon_sym_POUNDENDIF] = ACTIONS(10076),
    [anon_sym_POUNDEndif] = ACTIONS(10076),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10076),
    [sym_trigger_keyword] = ACTIONS(10076),
    [sym_var_keyword] = ACTIONS(10076),
    [sym_local_keyword] = ACTIONS(10076),
    [sym_internal_keyword] = ACTIONS(10076),
    [sym_protected_keyword] = ACTIONS(10076),
    [sym_event_keyword] = ACTIONS(10076),
    [sym_fields_keyword] = ACTIONS(10076),
    [sym_keys_keyword] = ACTIONS(10076),
    [sym_fieldgroups_keyword] = ACTIONS(10076),
    [sym_actions_keyword] = ACTIONS(10076),
    [sym_layout_keyword] = ACTIONS(10076),
    [sym_area_keyword] = ACTIONS(10076),
    [sym_group_keyword] = ACTIONS(10076),
    [sym_repeater_keyword] = ACTIONS(10076),
    [sym_cuegroup_keyword] = ACTIONS(10076),
    [sym_fixed_keyword] = ACTIONS(10076),
    [sym_grid_keyword] = ACTIONS(10076),
    [sym_part_keyword] = ACTIONS(10076),
    [sym_systempart_keyword] = ACTIONS(10076),
    [sym_usercontrol_keyword] = ACTIONS(10076),
    [sym_dataset_keyword] = ACTIONS(10076),
    [sym_elements_keyword] = ACTIONS(10076),
    [sym_dataitem_keyword] = ACTIONS(10076),
    [sym_column_keyword] = ACTIONS(10076),
    [sym_filter_keyword] = ACTIONS(10076),
    [sym_labels_keyword] = ACTIONS(10076),
    [sym_rendering_keyword] = ACTIONS(10076),
    [sym_requestpage_keyword] = ACTIONS(10076),
    [sym_schema_keyword] = ACTIONS(10076),
    [sym_views_keyword] = ACTIONS(10076),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10076),
    [sym_preproc_open] = ACTIONS(10076),
    [sym_preproc_close] = ACTIONS(10076),
  },
  [STATE(3764)] = {
    [anon_sym_SEMI] = ACTIONS(9838),
    [aux_sym_where_condition_token1] = ACTIONS(9840),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9838),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9838),
    [anon_sym_LBRACK] = ACTIONS(9838),
    [aux_sym_basic_type_token6] = ACTIONS(9840),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9838),
    [aux_sym_addafter_modification_token1] = ACTIONS(9838),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9838),
    [aux_sym_modify_modification_token1] = ACTIONS(9838),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9838),
    [aux_sym_movelast_modification_token1] = ACTIONS(9838),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9838),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9838),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9838),
    [anon_sym_POUNDif] = ACTIONS(9838),
    [anon_sym_POUNDIF] = ACTIONS(9838),
    [anon_sym_POUNDIf] = ACTIONS(9838),
    [anon_sym_POUNDelif] = ACTIONS(9838),
    [anon_sym_POUNDELIF] = ACTIONS(9838),
    [anon_sym_POUNDElif] = ACTIONS(9838),
    [anon_sym_POUNDelse] = ACTIONS(9838),
    [anon_sym_POUNDELSE] = ACTIONS(9838),
    [anon_sym_POUNDElse] = ACTIONS(9838),
    [anon_sym_POUNDendif] = ACTIONS(9838),
    [anon_sym_POUNDENDIF] = ACTIONS(9838),
    [anon_sym_POUNDEndif] = ACTIONS(9838),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9838),
    [sym_trigger_keyword] = ACTIONS(9838),
    [sym_var_keyword] = ACTIONS(9838),
    [sym_local_keyword] = ACTIONS(9838),
    [sym_internal_keyword] = ACTIONS(9838),
    [sym_protected_keyword] = ACTIONS(9838),
    [sym_event_keyword] = ACTIONS(9838),
    [sym_fields_keyword] = ACTIONS(9838),
    [sym_keys_keyword] = ACTIONS(9838),
    [sym_fieldgroups_keyword] = ACTIONS(9838),
    [sym_actions_keyword] = ACTIONS(9838),
    [sym_layout_keyword] = ACTIONS(9838),
    [sym_area_keyword] = ACTIONS(9838),
    [sym_group_keyword] = ACTIONS(9838),
    [sym_repeater_keyword] = ACTIONS(9838),
    [sym_cuegroup_keyword] = ACTIONS(9838),
    [sym_fixed_keyword] = ACTIONS(9838),
    [sym_grid_keyword] = ACTIONS(9838),
    [sym_part_keyword] = ACTIONS(9838),
    [sym_systempart_keyword] = ACTIONS(9838),
    [sym_usercontrol_keyword] = ACTIONS(9838),
    [sym_dataset_keyword] = ACTIONS(9838),
    [sym_elements_keyword] = ACTIONS(9838),
    [sym_dataitem_keyword] = ACTIONS(9838),
    [sym_column_keyword] = ACTIONS(9838),
    [sym_filter_keyword] = ACTIONS(9838),
    [sym_labels_keyword] = ACTIONS(9838),
    [sym_rendering_keyword] = ACTIONS(9838),
    [sym_requestpage_keyword] = ACTIONS(9838),
    [sym_schema_keyword] = ACTIONS(9838),
    [sym_views_keyword] = ACTIONS(9838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9838),
    [sym_preproc_open] = ACTIONS(9838),
    [sym_preproc_close] = ACTIONS(9838),
  },
  [STATE(3765)] = {
    [anon_sym_SEMI] = ACTIONS(10080),
    [aux_sym_where_condition_token1] = ACTIONS(10082),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10080),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10080),
    [anon_sym_LBRACK] = ACTIONS(10080),
    [aux_sym_basic_type_token6] = ACTIONS(10082),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10080),
    [aux_sym_addafter_modification_token1] = ACTIONS(10080),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10080),
    [aux_sym_modify_modification_token1] = ACTIONS(10080),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10080),
    [aux_sym_movelast_modification_token1] = ACTIONS(10080),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10080),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10080),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10080),
    [anon_sym_POUNDif] = ACTIONS(10080),
    [anon_sym_POUNDIF] = ACTIONS(10080),
    [anon_sym_POUNDIf] = ACTIONS(10080),
    [anon_sym_POUNDelif] = ACTIONS(10080),
    [anon_sym_POUNDELIF] = ACTIONS(10080),
    [anon_sym_POUNDElif] = ACTIONS(10080),
    [anon_sym_POUNDelse] = ACTIONS(10080),
    [anon_sym_POUNDELSE] = ACTIONS(10080),
    [anon_sym_POUNDElse] = ACTIONS(10080),
    [anon_sym_POUNDendif] = ACTIONS(10080),
    [anon_sym_POUNDENDIF] = ACTIONS(10080),
    [anon_sym_POUNDEndif] = ACTIONS(10080),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10080),
    [sym_trigger_keyword] = ACTIONS(10080),
    [sym_var_keyword] = ACTIONS(10080),
    [sym_local_keyword] = ACTIONS(10080),
    [sym_internal_keyword] = ACTIONS(10080),
    [sym_protected_keyword] = ACTIONS(10080),
    [sym_event_keyword] = ACTIONS(10080),
    [sym_fields_keyword] = ACTIONS(10080),
    [sym_keys_keyword] = ACTIONS(10080),
    [sym_fieldgroups_keyword] = ACTIONS(10080),
    [sym_actions_keyword] = ACTIONS(10080),
    [sym_layout_keyword] = ACTIONS(10080),
    [sym_area_keyword] = ACTIONS(10080),
    [sym_group_keyword] = ACTIONS(10080),
    [sym_repeater_keyword] = ACTIONS(10080),
    [sym_cuegroup_keyword] = ACTIONS(10080),
    [sym_fixed_keyword] = ACTIONS(10080),
    [sym_grid_keyword] = ACTIONS(10080),
    [sym_part_keyword] = ACTIONS(10080),
    [sym_systempart_keyword] = ACTIONS(10080),
    [sym_usercontrol_keyword] = ACTIONS(10080),
    [sym_dataset_keyword] = ACTIONS(10080),
    [sym_elements_keyword] = ACTIONS(10080),
    [sym_dataitem_keyword] = ACTIONS(10080),
    [sym_column_keyword] = ACTIONS(10080),
    [sym_filter_keyword] = ACTIONS(10080),
    [sym_labels_keyword] = ACTIONS(10080),
    [sym_rendering_keyword] = ACTIONS(10080),
    [sym_requestpage_keyword] = ACTIONS(10080),
    [sym_schema_keyword] = ACTIONS(10080),
    [sym_views_keyword] = ACTIONS(10080),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10080),
    [sym_preproc_open] = ACTIONS(10080),
    [sym_preproc_close] = ACTIONS(10080),
  },
  [STATE(3766)] = {
    [anon_sym_SEMI] = ACTIONS(10080),
    [aux_sym_where_condition_token1] = ACTIONS(10082),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10080),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10080),
    [anon_sym_LBRACK] = ACTIONS(10080),
    [aux_sym_basic_type_token6] = ACTIONS(10082),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10080),
    [aux_sym_addafter_modification_token1] = ACTIONS(10080),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10080),
    [aux_sym_modify_modification_token1] = ACTIONS(10080),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10080),
    [aux_sym_movelast_modification_token1] = ACTIONS(10080),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10080),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10080),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10080),
    [anon_sym_POUNDif] = ACTIONS(10080),
    [anon_sym_POUNDIF] = ACTIONS(10080),
    [anon_sym_POUNDIf] = ACTIONS(10080),
    [anon_sym_POUNDelif] = ACTIONS(10080),
    [anon_sym_POUNDELIF] = ACTIONS(10080),
    [anon_sym_POUNDElif] = ACTIONS(10080),
    [anon_sym_POUNDelse] = ACTIONS(10080),
    [anon_sym_POUNDELSE] = ACTIONS(10080),
    [anon_sym_POUNDElse] = ACTIONS(10080),
    [anon_sym_POUNDendif] = ACTIONS(10080),
    [anon_sym_POUNDENDIF] = ACTIONS(10080),
    [anon_sym_POUNDEndif] = ACTIONS(10080),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10080),
    [sym_trigger_keyword] = ACTIONS(10080),
    [sym_var_keyword] = ACTIONS(10080),
    [sym_local_keyword] = ACTIONS(10080),
    [sym_internal_keyword] = ACTIONS(10080),
    [sym_protected_keyword] = ACTIONS(10080),
    [sym_event_keyword] = ACTIONS(10080),
    [sym_fields_keyword] = ACTIONS(10080),
    [sym_keys_keyword] = ACTIONS(10080),
    [sym_fieldgroups_keyword] = ACTIONS(10080),
    [sym_actions_keyword] = ACTIONS(10080),
    [sym_layout_keyword] = ACTIONS(10080),
    [sym_area_keyword] = ACTIONS(10080),
    [sym_group_keyword] = ACTIONS(10080),
    [sym_repeater_keyword] = ACTIONS(10080),
    [sym_cuegroup_keyword] = ACTIONS(10080),
    [sym_fixed_keyword] = ACTIONS(10080),
    [sym_grid_keyword] = ACTIONS(10080),
    [sym_part_keyword] = ACTIONS(10080),
    [sym_systempart_keyword] = ACTIONS(10080),
    [sym_usercontrol_keyword] = ACTIONS(10080),
    [sym_dataset_keyword] = ACTIONS(10080),
    [sym_elements_keyword] = ACTIONS(10080),
    [sym_dataitem_keyword] = ACTIONS(10080),
    [sym_column_keyword] = ACTIONS(10080),
    [sym_filter_keyword] = ACTIONS(10080),
    [sym_labels_keyword] = ACTIONS(10080),
    [sym_rendering_keyword] = ACTIONS(10080),
    [sym_requestpage_keyword] = ACTIONS(10080),
    [sym_schema_keyword] = ACTIONS(10080),
    [sym_views_keyword] = ACTIONS(10080),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10080),
    [sym_preproc_open] = ACTIONS(10080),
    [sym_preproc_close] = ACTIONS(10080),
  },
  [STATE(3767)] = {
    [anon_sym_SEMI] = ACTIONS(10084),
    [aux_sym_where_condition_token1] = ACTIONS(10086),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10084),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10084),
    [anon_sym_LBRACK] = ACTIONS(10084),
    [aux_sym_basic_type_token6] = ACTIONS(10086),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10084),
    [aux_sym_addafter_modification_token1] = ACTIONS(10084),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10084),
    [aux_sym_modify_modification_token1] = ACTIONS(10084),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10084),
    [aux_sym_movelast_modification_token1] = ACTIONS(10084),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10084),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10084),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10084),
    [anon_sym_POUNDif] = ACTIONS(10084),
    [anon_sym_POUNDIF] = ACTIONS(10084),
    [anon_sym_POUNDIf] = ACTIONS(10084),
    [anon_sym_POUNDelif] = ACTIONS(10084),
    [anon_sym_POUNDELIF] = ACTIONS(10084),
    [anon_sym_POUNDElif] = ACTIONS(10084),
    [anon_sym_POUNDelse] = ACTIONS(10084),
    [anon_sym_POUNDELSE] = ACTIONS(10084),
    [anon_sym_POUNDElse] = ACTIONS(10084),
    [anon_sym_POUNDendif] = ACTIONS(10084),
    [anon_sym_POUNDENDIF] = ACTIONS(10084),
    [anon_sym_POUNDEndif] = ACTIONS(10084),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10084),
    [sym_trigger_keyword] = ACTIONS(10084),
    [sym_var_keyword] = ACTIONS(10084),
    [sym_local_keyword] = ACTIONS(10084),
    [sym_internal_keyword] = ACTIONS(10084),
    [sym_protected_keyword] = ACTIONS(10084),
    [sym_event_keyword] = ACTIONS(10084),
    [sym_fields_keyword] = ACTIONS(10084),
    [sym_keys_keyword] = ACTIONS(10084),
    [sym_fieldgroups_keyword] = ACTIONS(10084),
    [sym_actions_keyword] = ACTIONS(10084),
    [sym_layout_keyword] = ACTIONS(10084),
    [sym_area_keyword] = ACTIONS(10084),
    [sym_group_keyword] = ACTIONS(10084),
    [sym_repeater_keyword] = ACTIONS(10084),
    [sym_cuegroup_keyword] = ACTIONS(10084),
    [sym_fixed_keyword] = ACTIONS(10084),
    [sym_grid_keyword] = ACTIONS(10084),
    [sym_part_keyword] = ACTIONS(10084),
    [sym_systempart_keyword] = ACTIONS(10084),
    [sym_usercontrol_keyword] = ACTIONS(10084),
    [sym_dataset_keyword] = ACTIONS(10084),
    [sym_elements_keyword] = ACTIONS(10084),
    [sym_dataitem_keyword] = ACTIONS(10084),
    [sym_column_keyword] = ACTIONS(10084),
    [sym_filter_keyword] = ACTIONS(10084),
    [sym_labels_keyword] = ACTIONS(10084),
    [sym_rendering_keyword] = ACTIONS(10084),
    [sym_requestpage_keyword] = ACTIONS(10084),
    [sym_schema_keyword] = ACTIONS(10084),
    [sym_views_keyword] = ACTIONS(10084),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10084),
    [sym_preproc_open] = ACTIONS(10084),
    [sym_preproc_close] = ACTIONS(10084),
  },
  [STATE(3768)] = {
    [anon_sym_SEMI] = ACTIONS(10084),
    [aux_sym_where_condition_token1] = ACTIONS(10086),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10084),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10084),
    [anon_sym_LBRACK] = ACTIONS(10084),
    [aux_sym_basic_type_token6] = ACTIONS(10086),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10084),
    [aux_sym_addafter_modification_token1] = ACTIONS(10084),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10084),
    [aux_sym_modify_modification_token1] = ACTIONS(10084),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10084),
    [aux_sym_movelast_modification_token1] = ACTIONS(10084),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10084),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10084),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10084),
    [anon_sym_POUNDif] = ACTIONS(10084),
    [anon_sym_POUNDIF] = ACTIONS(10084),
    [anon_sym_POUNDIf] = ACTIONS(10084),
    [anon_sym_POUNDelif] = ACTIONS(10084),
    [anon_sym_POUNDELIF] = ACTIONS(10084),
    [anon_sym_POUNDElif] = ACTIONS(10084),
    [anon_sym_POUNDelse] = ACTIONS(10084),
    [anon_sym_POUNDELSE] = ACTIONS(10084),
    [anon_sym_POUNDElse] = ACTIONS(10084),
    [anon_sym_POUNDendif] = ACTIONS(10084),
    [anon_sym_POUNDENDIF] = ACTIONS(10084),
    [anon_sym_POUNDEndif] = ACTIONS(10084),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10084),
    [sym_trigger_keyword] = ACTIONS(10084),
    [sym_var_keyword] = ACTIONS(10084),
    [sym_local_keyword] = ACTIONS(10084),
    [sym_internal_keyword] = ACTIONS(10084),
    [sym_protected_keyword] = ACTIONS(10084),
    [sym_event_keyword] = ACTIONS(10084),
    [sym_fields_keyword] = ACTIONS(10084),
    [sym_keys_keyword] = ACTIONS(10084),
    [sym_fieldgroups_keyword] = ACTIONS(10084),
    [sym_actions_keyword] = ACTIONS(10084),
    [sym_layout_keyword] = ACTIONS(10084),
    [sym_area_keyword] = ACTIONS(10084),
    [sym_group_keyword] = ACTIONS(10084),
    [sym_repeater_keyword] = ACTIONS(10084),
    [sym_cuegroup_keyword] = ACTIONS(10084),
    [sym_fixed_keyword] = ACTIONS(10084),
    [sym_grid_keyword] = ACTIONS(10084),
    [sym_part_keyword] = ACTIONS(10084),
    [sym_systempart_keyword] = ACTIONS(10084),
    [sym_usercontrol_keyword] = ACTIONS(10084),
    [sym_dataset_keyword] = ACTIONS(10084),
    [sym_elements_keyword] = ACTIONS(10084),
    [sym_dataitem_keyword] = ACTIONS(10084),
    [sym_column_keyword] = ACTIONS(10084),
    [sym_filter_keyword] = ACTIONS(10084),
    [sym_labels_keyword] = ACTIONS(10084),
    [sym_rendering_keyword] = ACTIONS(10084),
    [sym_requestpage_keyword] = ACTIONS(10084),
    [sym_schema_keyword] = ACTIONS(10084),
    [sym_views_keyword] = ACTIONS(10084),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10084),
    [sym_preproc_open] = ACTIONS(10084),
    [sym_preproc_close] = ACTIONS(10084),
  },
  [STATE(3769)] = {
    [anon_sym_SEMI] = ACTIONS(10088),
    [aux_sym_where_condition_token1] = ACTIONS(10090),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10088),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10088),
    [anon_sym_LBRACK] = ACTIONS(10088),
    [aux_sym_basic_type_token6] = ACTIONS(10090),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10088),
    [aux_sym_addafter_modification_token1] = ACTIONS(10088),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10088),
    [aux_sym_modify_modification_token1] = ACTIONS(10088),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10088),
    [aux_sym_movelast_modification_token1] = ACTIONS(10088),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10088),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10088),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10088),
    [anon_sym_POUNDif] = ACTIONS(10088),
    [anon_sym_POUNDIF] = ACTIONS(10088),
    [anon_sym_POUNDIf] = ACTIONS(10088),
    [anon_sym_POUNDelif] = ACTIONS(10088),
    [anon_sym_POUNDELIF] = ACTIONS(10088),
    [anon_sym_POUNDElif] = ACTIONS(10088),
    [anon_sym_POUNDelse] = ACTIONS(10088),
    [anon_sym_POUNDELSE] = ACTIONS(10088),
    [anon_sym_POUNDElse] = ACTIONS(10088),
    [anon_sym_POUNDendif] = ACTIONS(10088),
    [anon_sym_POUNDENDIF] = ACTIONS(10088),
    [anon_sym_POUNDEndif] = ACTIONS(10088),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10088),
    [sym_trigger_keyword] = ACTIONS(10088),
    [sym_var_keyword] = ACTIONS(10088),
    [sym_local_keyword] = ACTIONS(10088),
    [sym_internal_keyword] = ACTIONS(10088),
    [sym_protected_keyword] = ACTIONS(10088),
    [sym_event_keyword] = ACTIONS(10088),
    [sym_fields_keyword] = ACTIONS(10088),
    [sym_keys_keyword] = ACTIONS(10088),
    [sym_fieldgroups_keyword] = ACTIONS(10088),
    [sym_actions_keyword] = ACTIONS(10088),
    [sym_layout_keyword] = ACTIONS(10088),
    [sym_area_keyword] = ACTIONS(10088),
    [sym_group_keyword] = ACTIONS(10088),
    [sym_repeater_keyword] = ACTIONS(10088),
    [sym_cuegroup_keyword] = ACTIONS(10088),
    [sym_fixed_keyword] = ACTIONS(10088),
    [sym_grid_keyword] = ACTIONS(10088),
    [sym_part_keyword] = ACTIONS(10088),
    [sym_systempart_keyword] = ACTIONS(10088),
    [sym_usercontrol_keyword] = ACTIONS(10088),
    [sym_dataset_keyword] = ACTIONS(10088),
    [sym_elements_keyword] = ACTIONS(10088),
    [sym_dataitem_keyword] = ACTIONS(10088),
    [sym_column_keyword] = ACTIONS(10088),
    [sym_filter_keyword] = ACTIONS(10088),
    [sym_labels_keyword] = ACTIONS(10088),
    [sym_rendering_keyword] = ACTIONS(10088),
    [sym_requestpage_keyword] = ACTIONS(10088),
    [sym_schema_keyword] = ACTIONS(10088),
    [sym_views_keyword] = ACTIONS(10088),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10088),
    [sym_preproc_open] = ACTIONS(10088),
    [sym_preproc_close] = ACTIONS(10088),
  },
  [STATE(3770)] = {
    [anon_sym_SEMI] = ACTIONS(10088),
    [aux_sym_where_condition_token1] = ACTIONS(10090),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10088),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10088),
    [anon_sym_LBRACK] = ACTIONS(10088),
    [aux_sym_basic_type_token6] = ACTIONS(10090),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10088),
    [aux_sym_addafter_modification_token1] = ACTIONS(10088),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10088),
    [aux_sym_modify_modification_token1] = ACTIONS(10088),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10088),
    [aux_sym_movelast_modification_token1] = ACTIONS(10088),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10088),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10088),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10088),
    [anon_sym_POUNDif] = ACTIONS(10088),
    [anon_sym_POUNDIF] = ACTIONS(10088),
    [anon_sym_POUNDIf] = ACTIONS(10088),
    [anon_sym_POUNDelif] = ACTIONS(10088),
    [anon_sym_POUNDELIF] = ACTIONS(10088),
    [anon_sym_POUNDElif] = ACTIONS(10088),
    [anon_sym_POUNDelse] = ACTIONS(10088),
    [anon_sym_POUNDELSE] = ACTIONS(10088),
    [anon_sym_POUNDElse] = ACTIONS(10088),
    [anon_sym_POUNDendif] = ACTIONS(10088),
    [anon_sym_POUNDENDIF] = ACTIONS(10088),
    [anon_sym_POUNDEndif] = ACTIONS(10088),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10088),
    [sym_trigger_keyword] = ACTIONS(10088),
    [sym_var_keyword] = ACTIONS(10088),
    [sym_local_keyword] = ACTIONS(10088),
    [sym_internal_keyword] = ACTIONS(10088),
    [sym_protected_keyword] = ACTIONS(10088),
    [sym_event_keyword] = ACTIONS(10088),
    [sym_fields_keyword] = ACTIONS(10088),
    [sym_keys_keyword] = ACTIONS(10088),
    [sym_fieldgroups_keyword] = ACTIONS(10088),
    [sym_actions_keyword] = ACTIONS(10088),
    [sym_layout_keyword] = ACTIONS(10088),
    [sym_area_keyword] = ACTIONS(10088),
    [sym_group_keyword] = ACTIONS(10088),
    [sym_repeater_keyword] = ACTIONS(10088),
    [sym_cuegroup_keyword] = ACTIONS(10088),
    [sym_fixed_keyword] = ACTIONS(10088),
    [sym_grid_keyword] = ACTIONS(10088),
    [sym_part_keyword] = ACTIONS(10088),
    [sym_systempart_keyword] = ACTIONS(10088),
    [sym_usercontrol_keyword] = ACTIONS(10088),
    [sym_dataset_keyword] = ACTIONS(10088),
    [sym_elements_keyword] = ACTIONS(10088),
    [sym_dataitem_keyword] = ACTIONS(10088),
    [sym_column_keyword] = ACTIONS(10088),
    [sym_filter_keyword] = ACTIONS(10088),
    [sym_labels_keyword] = ACTIONS(10088),
    [sym_rendering_keyword] = ACTIONS(10088),
    [sym_requestpage_keyword] = ACTIONS(10088),
    [sym_schema_keyword] = ACTIONS(10088),
    [sym_views_keyword] = ACTIONS(10088),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10088),
    [sym_preproc_open] = ACTIONS(10088),
    [sym_preproc_close] = ACTIONS(10088),
  },
  [STATE(3771)] = {
    [anon_sym_SEMI] = ACTIONS(10092),
    [aux_sym_where_condition_token1] = ACTIONS(10094),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10096),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10096),
    [anon_sym_LBRACK] = ACTIONS(10096),
    [aux_sym_basic_type_token6] = ACTIONS(10094),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10096),
    [aux_sym_addafter_modification_token1] = ACTIONS(10096),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10096),
    [aux_sym_modify_modification_token1] = ACTIONS(10096),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10096),
    [aux_sym_movelast_modification_token1] = ACTIONS(10096),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10096),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10096),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10096),
    [anon_sym_POUNDif] = ACTIONS(10096),
    [anon_sym_POUNDIF] = ACTIONS(10096),
    [anon_sym_POUNDIf] = ACTIONS(10096),
    [anon_sym_POUNDelif] = ACTIONS(10096),
    [anon_sym_POUNDELIF] = ACTIONS(10096),
    [anon_sym_POUNDElif] = ACTIONS(10096),
    [anon_sym_POUNDelse] = ACTIONS(10096),
    [anon_sym_POUNDELSE] = ACTIONS(10096),
    [anon_sym_POUNDElse] = ACTIONS(10096),
    [anon_sym_POUNDendif] = ACTIONS(10096),
    [anon_sym_POUNDENDIF] = ACTIONS(10096),
    [anon_sym_POUNDEndif] = ACTIONS(10096),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10096),
    [sym_trigger_keyword] = ACTIONS(10096),
    [sym_var_keyword] = ACTIONS(10096),
    [sym_local_keyword] = ACTIONS(10096),
    [sym_internal_keyword] = ACTIONS(10096),
    [sym_protected_keyword] = ACTIONS(10096),
    [sym_event_keyword] = ACTIONS(10096),
    [sym_fields_keyword] = ACTIONS(10096),
    [sym_keys_keyword] = ACTIONS(10096),
    [sym_fieldgroups_keyword] = ACTIONS(10096),
    [sym_actions_keyword] = ACTIONS(10096),
    [sym_layout_keyword] = ACTIONS(10096),
    [sym_area_keyword] = ACTIONS(10096),
    [sym_group_keyword] = ACTIONS(10096),
    [sym_repeater_keyword] = ACTIONS(10096),
    [sym_cuegroup_keyword] = ACTIONS(10096),
    [sym_fixed_keyword] = ACTIONS(10096),
    [sym_grid_keyword] = ACTIONS(10096),
    [sym_part_keyword] = ACTIONS(10096),
    [sym_systempart_keyword] = ACTIONS(10096),
    [sym_usercontrol_keyword] = ACTIONS(10096),
    [sym_dataset_keyword] = ACTIONS(10096),
    [sym_elements_keyword] = ACTIONS(10096),
    [sym_dataitem_keyword] = ACTIONS(10096),
    [sym_column_keyword] = ACTIONS(10096),
    [sym_filter_keyword] = ACTIONS(10096),
    [sym_labels_keyword] = ACTIONS(10096),
    [sym_rendering_keyword] = ACTIONS(10096),
    [sym_requestpage_keyword] = ACTIONS(10096),
    [sym_schema_keyword] = ACTIONS(10096),
    [sym_views_keyword] = ACTIONS(10096),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10096),
    [sym_preproc_open] = ACTIONS(10096),
    [sym_preproc_close] = ACTIONS(10096),
  },
  [STATE(3772)] = {
    [anon_sym_SEMI] = ACTIONS(10098),
    [aux_sym_where_condition_token1] = ACTIONS(10094),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10096),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10096),
    [anon_sym_LBRACK] = ACTIONS(10096),
    [aux_sym_basic_type_token6] = ACTIONS(10094),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10096),
    [aux_sym_addafter_modification_token1] = ACTIONS(10096),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10096),
    [aux_sym_modify_modification_token1] = ACTIONS(10096),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10096),
    [aux_sym_movelast_modification_token1] = ACTIONS(10096),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10096),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10096),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10096),
    [anon_sym_POUNDif] = ACTIONS(10096),
    [anon_sym_POUNDIF] = ACTIONS(10096),
    [anon_sym_POUNDIf] = ACTIONS(10096),
    [anon_sym_POUNDelif] = ACTIONS(10096),
    [anon_sym_POUNDELIF] = ACTIONS(10096),
    [anon_sym_POUNDElif] = ACTIONS(10096),
    [anon_sym_POUNDelse] = ACTIONS(10096),
    [anon_sym_POUNDELSE] = ACTIONS(10096),
    [anon_sym_POUNDElse] = ACTIONS(10096),
    [anon_sym_POUNDendif] = ACTIONS(10096),
    [anon_sym_POUNDENDIF] = ACTIONS(10096),
    [anon_sym_POUNDEndif] = ACTIONS(10096),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10096),
    [sym_trigger_keyword] = ACTIONS(10096),
    [sym_var_keyword] = ACTIONS(10096),
    [sym_local_keyword] = ACTIONS(10096),
    [sym_internal_keyword] = ACTIONS(10096),
    [sym_protected_keyword] = ACTIONS(10096),
    [sym_event_keyword] = ACTIONS(10096),
    [sym_fields_keyword] = ACTIONS(10096),
    [sym_keys_keyword] = ACTIONS(10096),
    [sym_fieldgroups_keyword] = ACTIONS(10096),
    [sym_actions_keyword] = ACTIONS(10096),
    [sym_layout_keyword] = ACTIONS(10096),
    [sym_area_keyword] = ACTIONS(10096),
    [sym_group_keyword] = ACTIONS(10096),
    [sym_repeater_keyword] = ACTIONS(10096),
    [sym_cuegroup_keyword] = ACTIONS(10096),
    [sym_fixed_keyword] = ACTIONS(10096),
    [sym_grid_keyword] = ACTIONS(10096),
    [sym_part_keyword] = ACTIONS(10096),
    [sym_systempart_keyword] = ACTIONS(10096),
    [sym_usercontrol_keyword] = ACTIONS(10096),
    [sym_dataset_keyword] = ACTIONS(10096),
    [sym_elements_keyword] = ACTIONS(10096),
    [sym_dataitem_keyword] = ACTIONS(10096),
    [sym_column_keyword] = ACTIONS(10096),
    [sym_filter_keyword] = ACTIONS(10096),
    [sym_labels_keyword] = ACTIONS(10096),
    [sym_rendering_keyword] = ACTIONS(10096),
    [sym_requestpage_keyword] = ACTIONS(10096),
    [sym_schema_keyword] = ACTIONS(10096),
    [sym_views_keyword] = ACTIONS(10096),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10096),
    [sym_preproc_open] = ACTIONS(10096),
    [sym_preproc_close] = ACTIONS(10096),
  },
  [STATE(3773)] = {
    [anon_sym_SEMI] = ACTIONS(10100),
    [aux_sym_where_condition_token1] = ACTIONS(10102),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10100),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10100),
    [anon_sym_LBRACK] = ACTIONS(10100),
    [aux_sym_basic_type_token6] = ACTIONS(10102),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10100),
    [aux_sym_addafter_modification_token1] = ACTIONS(10100),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10100),
    [aux_sym_modify_modification_token1] = ACTIONS(10100),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10100),
    [aux_sym_movelast_modification_token1] = ACTIONS(10100),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10100),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10100),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10100),
    [anon_sym_POUNDif] = ACTIONS(10100),
    [anon_sym_POUNDIF] = ACTIONS(10100),
    [anon_sym_POUNDIf] = ACTIONS(10100),
    [anon_sym_POUNDelif] = ACTIONS(10100),
    [anon_sym_POUNDELIF] = ACTIONS(10100),
    [anon_sym_POUNDElif] = ACTIONS(10100),
    [anon_sym_POUNDelse] = ACTIONS(10100),
    [anon_sym_POUNDELSE] = ACTIONS(10100),
    [anon_sym_POUNDElse] = ACTIONS(10100),
    [anon_sym_POUNDendif] = ACTIONS(10100),
    [anon_sym_POUNDENDIF] = ACTIONS(10100),
    [anon_sym_POUNDEndif] = ACTIONS(10100),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10100),
    [sym_trigger_keyword] = ACTIONS(10100),
    [sym_var_keyword] = ACTIONS(10100),
    [sym_local_keyword] = ACTIONS(10100),
    [sym_internal_keyword] = ACTIONS(10100),
    [sym_protected_keyword] = ACTIONS(10100),
    [sym_event_keyword] = ACTIONS(10100),
    [sym_fields_keyword] = ACTIONS(10100),
    [sym_keys_keyword] = ACTIONS(10100),
    [sym_fieldgroups_keyword] = ACTIONS(10100),
    [sym_actions_keyword] = ACTIONS(10100),
    [sym_layout_keyword] = ACTIONS(10100),
    [sym_area_keyword] = ACTIONS(10100),
    [sym_group_keyword] = ACTIONS(10100),
    [sym_repeater_keyword] = ACTIONS(10100),
    [sym_cuegroup_keyword] = ACTIONS(10100),
    [sym_fixed_keyword] = ACTIONS(10100),
    [sym_grid_keyword] = ACTIONS(10100),
    [sym_part_keyword] = ACTIONS(10100),
    [sym_systempart_keyword] = ACTIONS(10100),
    [sym_usercontrol_keyword] = ACTIONS(10100),
    [sym_dataset_keyword] = ACTIONS(10100),
    [sym_elements_keyword] = ACTIONS(10100),
    [sym_dataitem_keyword] = ACTIONS(10100),
    [sym_column_keyword] = ACTIONS(10100),
    [sym_filter_keyword] = ACTIONS(10100),
    [sym_labels_keyword] = ACTIONS(10100),
    [sym_rendering_keyword] = ACTIONS(10100),
    [sym_requestpage_keyword] = ACTIONS(10100),
    [sym_schema_keyword] = ACTIONS(10100),
    [sym_views_keyword] = ACTIONS(10100),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10100),
    [sym_preproc_open] = ACTIONS(10100),
    [sym_preproc_close] = ACTIONS(10100),
  },
  [STATE(3774)] = {
    [anon_sym_SEMI] = ACTIONS(6978),
    [aux_sym_where_condition_token1] = ACTIONS(6976),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6978),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6978),
    [anon_sym_LBRACK] = ACTIONS(6978),
    [aux_sym_basic_type_token6] = ACTIONS(6976),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6978),
    [aux_sym_addafter_modification_token1] = ACTIONS(6978),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6978),
    [aux_sym_modify_modification_token1] = ACTIONS(6978),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6978),
    [aux_sym_movelast_modification_token1] = ACTIONS(6978),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6978),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6978),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6978),
    [anon_sym_POUNDif] = ACTIONS(6978),
    [anon_sym_POUNDIF] = ACTIONS(6978),
    [anon_sym_POUNDIf] = ACTIONS(6978),
    [anon_sym_POUNDelif] = ACTIONS(6978),
    [anon_sym_POUNDELIF] = ACTIONS(6978),
    [anon_sym_POUNDElif] = ACTIONS(6978),
    [anon_sym_POUNDelse] = ACTIONS(6978),
    [anon_sym_POUNDELSE] = ACTIONS(6978),
    [anon_sym_POUNDElse] = ACTIONS(6978),
    [anon_sym_POUNDendif] = ACTIONS(6978),
    [anon_sym_POUNDENDIF] = ACTIONS(6978),
    [anon_sym_POUNDEndif] = ACTIONS(6978),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6978),
    [sym_trigger_keyword] = ACTIONS(6978),
    [sym_var_keyword] = ACTIONS(6978),
    [sym_local_keyword] = ACTIONS(6978),
    [sym_internal_keyword] = ACTIONS(6978),
    [sym_protected_keyword] = ACTIONS(6978),
    [sym_event_keyword] = ACTIONS(6978),
    [sym_fields_keyword] = ACTIONS(6978),
    [sym_keys_keyword] = ACTIONS(6978),
    [sym_fieldgroups_keyword] = ACTIONS(6978),
    [sym_actions_keyword] = ACTIONS(6978),
    [sym_layout_keyword] = ACTIONS(6978),
    [sym_area_keyword] = ACTIONS(6978),
    [sym_group_keyword] = ACTIONS(6978),
    [sym_repeater_keyword] = ACTIONS(6978),
    [sym_cuegroup_keyword] = ACTIONS(6978),
    [sym_fixed_keyword] = ACTIONS(6978),
    [sym_grid_keyword] = ACTIONS(6978),
    [sym_part_keyword] = ACTIONS(6978),
    [sym_systempart_keyword] = ACTIONS(6978),
    [sym_usercontrol_keyword] = ACTIONS(6978),
    [sym_dataset_keyword] = ACTIONS(6978),
    [sym_elements_keyword] = ACTIONS(6978),
    [sym_dataitem_keyword] = ACTIONS(6978),
    [sym_column_keyword] = ACTIONS(6978),
    [sym_filter_keyword] = ACTIONS(6978),
    [sym_labels_keyword] = ACTIONS(6978),
    [sym_rendering_keyword] = ACTIONS(6978),
    [sym_requestpage_keyword] = ACTIONS(6978),
    [sym_schema_keyword] = ACTIONS(6978),
    [sym_views_keyword] = ACTIONS(6978),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6978),
    [sym_preproc_open] = ACTIONS(6978),
    [sym_preproc_close] = ACTIONS(6978),
  },
  [STATE(3775)] = {
    [anon_sym_SEMI] = ACTIONS(7168),
    [aux_sym_where_condition_token1] = ACTIONS(7166),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7168),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7168),
    [anon_sym_LBRACK] = ACTIONS(7168),
    [aux_sym_basic_type_token6] = ACTIONS(7166),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7168),
    [aux_sym_addafter_modification_token1] = ACTIONS(7168),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7168),
    [aux_sym_modify_modification_token1] = ACTIONS(7168),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7168),
    [aux_sym_movelast_modification_token1] = ACTIONS(7168),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7168),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7168),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7168),
    [anon_sym_POUNDif] = ACTIONS(7168),
    [anon_sym_POUNDIF] = ACTIONS(7168),
    [anon_sym_POUNDIf] = ACTIONS(7168),
    [anon_sym_POUNDelif] = ACTIONS(7168),
    [anon_sym_POUNDELIF] = ACTIONS(7168),
    [anon_sym_POUNDElif] = ACTIONS(7168),
    [anon_sym_POUNDelse] = ACTIONS(7168),
    [anon_sym_POUNDELSE] = ACTIONS(7168),
    [anon_sym_POUNDElse] = ACTIONS(7168),
    [anon_sym_POUNDendif] = ACTIONS(7168),
    [anon_sym_POUNDENDIF] = ACTIONS(7168),
    [anon_sym_POUNDEndif] = ACTIONS(7168),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7168),
    [sym_trigger_keyword] = ACTIONS(7168),
    [sym_var_keyword] = ACTIONS(7168),
    [sym_local_keyword] = ACTIONS(7168),
    [sym_internal_keyword] = ACTIONS(7168),
    [sym_protected_keyword] = ACTIONS(7168),
    [sym_event_keyword] = ACTIONS(7168),
    [sym_fields_keyword] = ACTIONS(7168),
    [sym_keys_keyword] = ACTIONS(7168),
    [sym_fieldgroups_keyword] = ACTIONS(7168),
    [sym_actions_keyword] = ACTIONS(7168),
    [sym_layout_keyword] = ACTIONS(7168),
    [sym_area_keyword] = ACTIONS(7168),
    [sym_group_keyword] = ACTIONS(7168),
    [sym_repeater_keyword] = ACTIONS(7168),
    [sym_cuegroup_keyword] = ACTIONS(7168),
    [sym_fixed_keyword] = ACTIONS(7168),
    [sym_grid_keyword] = ACTIONS(7168),
    [sym_part_keyword] = ACTIONS(7168),
    [sym_systempart_keyword] = ACTIONS(7168),
    [sym_usercontrol_keyword] = ACTIONS(7168),
    [sym_dataset_keyword] = ACTIONS(7168),
    [sym_elements_keyword] = ACTIONS(7168),
    [sym_dataitem_keyword] = ACTIONS(7168),
    [sym_column_keyword] = ACTIONS(7168),
    [sym_filter_keyword] = ACTIONS(7168),
    [sym_labels_keyword] = ACTIONS(7168),
    [sym_rendering_keyword] = ACTIONS(7168),
    [sym_requestpage_keyword] = ACTIONS(7168),
    [sym_schema_keyword] = ACTIONS(7168),
    [sym_views_keyword] = ACTIONS(7168),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7168),
    [sym_preproc_open] = ACTIONS(7168),
    [sym_preproc_close] = ACTIONS(7168),
  },
  [STATE(3776)] = {
    [anon_sym_SEMI] = ACTIONS(9497),
    [aux_sym_where_condition_token1] = ACTIONS(9499),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9497),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9497),
    [anon_sym_LBRACK] = ACTIONS(9497),
    [aux_sym_basic_type_token6] = ACTIONS(9499),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9497),
    [aux_sym_addafter_modification_token1] = ACTIONS(9497),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9497),
    [aux_sym_modify_modification_token1] = ACTIONS(9497),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9497),
    [aux_sym_movelast_modification_token1] = ACTIONS(9497),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9497),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9497),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9497),
    [anon_sym_POUNDif] = ACTIONS(9497),
    [anon_sym_POUNDIF] = ACTIONS(9497),
    [anon_sym_POUNDIf] = ACTIONS(9497),
    [anon_sym_POUNDelif] = ACTIONS(9497),
    [anon_sym_POUNDELIF] = ACTIONS(9497),
    [anon_sym_POUNDElif] = ACTIONS(9497),
    [anon_sym_POUNDelse] = ACTIONS(9497),
    [anon_sym_POUNDELSE] = ACTIONS(9497),
    [anon_sym_POUNDElse] = ACTIONS(9497),
    [anon_sym_POUNDendif] = ACTIONS(9497),
    [anon_sym_POUNDENDIF] = ACTIONS(9497),
    [anon_sym_POUNDEndif] = ACTIONS(9497),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9497),
    [sym_trigger_keyword] = ACTIONS(9497),
    [sym_var_keyword] = ACTIONS(9497),
    [sym_local_keyword] = ACTIONS(9497),
    [sym_internal_keyword] = ACTIONS(9497),
    [sym_protected_keyword] = ACTIONS(9497),
    [sym_event_keyword] = ACTIONS(9497),
    [sym_fields_keyword] = ACTIONS(9497),
    [sym_keys_keyword] = ACTIONS(9497),
    [sym_fieldgroups_keyword] = ACTIONS(9497),
    [sym_actions_keyword] = ACTIONS(9497),
    [sym_layout_keyword] = ACTIONS(9497),
    [sym_area_keyword] = ACTIONS(9497),
    [sym_group_keyword] = ACTIONS(9497),
    [sym_repeater_keyword] = ACTIONS(9497),
    [sym_cuegroup_keyword] = ACTIONS(9497),
    [sym_fixed_keyword] = ACTIONS(9497),
    [sym_grid_keyword] = ACTIONS(9497),
    [sym_part_keyword] = ACTIONS(9497),
    [sym_systempart_keyword] = ACTIONS(9497),
    [sym_usercontrol_keyword] = ACTIONS(9497),
    [sym_dataset_keyword] = ACTIONS(9497),
    [sym_elements_keyword] = ACTIONS(9497),
    [sym_dataitem_keyword] = ACTIONS(9497),
    [sym_column_keyword] = ACTIONS(9497),
    [sym_filter_keyword] = ACTIONS(9497),
    [sym_labels_keyword] = ACTIONS(9497),
    [sym_rendering_keyword] = ACTIONS(9497),
    [sym_requestpage_keyword] = ACTIONS(9497),
    [sym_schema_keyword] = ACTIONS(9497),
    [sym_views_keyword] = ACTIONS(9497),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9497),
    [sym_preproc_open] = ACTIONS(9497),
    [sym_preproc_close] = ACTIONS(9497),
  },
  [STATE(3777)] = {
    [anon_sym_SEMI] = ACTIONS(10100),
    [aux_sym_where_condition_token1] = ACTIONS(10102),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10100),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10100),
    [anon_sym_LBRACK] = ACTIONS(10100),
    [aux_sym_basic_type_token6] = ACTIONS(10102),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10100),
    [aux_sym_addafter_modification_token1] = ACTIONS(10100),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10100),
    [aux_sym_modify_modification_token1] = ACTIONS(10100),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10100),
    [aux_sym_movelast_modification_token1] = ACTIONS(10100),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10100),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10100),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10100),
    [anon_sym_POUNDif] = ACTIONS(10100),
    [anon_sym_POUNDIF] = ACTIONS(10100),
    [anon_sym_POUNDIf] = ACTIONS(10100),
    [anon_sym_POUNDelif] = ACTIONS(10100),
    [anon_sym_POUNDELIF] = ACTIONS(10100),
    [anon_sym_POUNDElif] = ACTIONS(10100),
    [anon_sym_POUNDelse] = ACTIONS(10100),
    [anon_sym_POUNDELSE] = ACTIONS(10100),
    [anon_sym_POUNDElse] = ACTIONS(10100),
    [anon_sym_POUNDendif] = ACTIONS(10100),
    [anon_sym_POUNDENDIF] = ACTIONS(10100),
    [anon_sym_POUNDEndif] = ACTIONS(10100),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10100),
    [sym_trigger_keyword] = ACTIONS(10100),
    [sym_var_keyword] = ACTIONS(10100),
    [sym_local_keyword] = ACTIONS(10100),
    [sym_internal_keyword] = ACTIONS(10100),
    [sym_protected_keyword] = ACTIONS(10100),
    [sym_event_keyword] = ACTIONS(10100),
    [sym_fields_keyword] = ACTIONS(10100),
    [sym_keys_keyword] = ACTIONS(10100),
    [sym_fieldgroups_keyword] = ACTIONS(10100),
    [sym_actions_keyword] = ACTIONS(10100),
    [sym_layout_keyword] = ACTIONS(10100),
    [sym_area_keyword] = ACTIONS(10100),
    [sym_group_keyword] = ACTIONS(10100),
    [sym_repeater_keyword] = ACTIONS(10100),
    [sym_cuegroup_keyword] = ACTIONS(10100),
    [sym_fixed_keyword] = ACTIONS(10100),
    [sym_grid_keyword] = ACTIONS(10100),
    [sym_part_keyword] = ACTIONS(10100),
    [sym_systempart_keyword] = ACTIONS(10100),
    [sym_usercontrol_keyword] = ACTIONS(10100),
    [sym_dataset_keyword] = ACTIONS(10100),
    [sym_elements_keyword] = ACTIONS(10100),
    [sym_dataitem_keyword] = ACTIONS(10100),
    [sym_column_keyword] = ACTIONS(10100),
    [sym_filter_keyword] = ACTIONS(10100),
    [sym_labels_keyword] = ACTIONS(10100),
    [sym_rendering_keyword] = ACTIONS(10100),
    [sym_requestpage_keyword] = ACTIONS(10100),
    [sym_schema_keyword] = ACTIONS(10100),
    [sym_views_keyword] = ACTIONS(10100),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10100),
    [sym_preproc_open] = ACTIONS(10100),
    [sym_preproc_close] = ACTIONS(10100),
  },
  [STATE(3778)] = {
    [anon_sym_SEMI] = ACTIONS(10104),
    [aux_sym_where_condition_token1] = ACTIONS(10106),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10104),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10104),
    [anon_sym_LBRACK] = ACTIONS(10104),
    [aux_sym_basic_type_token6] = ACTIONS(10106),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10104),
    [aux_sym_addafter_modification_token1] = ACTIONS(10104),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10104),
    [aux_sym_modify_modification_token1] = ACTIONS(10104),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10104),
    [aux_sym_movelast_modification_token1] = ACTIONS(10104),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10104),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10104),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10104),
    [anon_sym_POUNDif] = ACTIONS(10104),
    [anon_sym_POUNDIF] = ACTIONS(10104),
    [anon_sym_POUNDIf] = ACTIONS(10104),
    [anon_sym_POUNDelif] = ACTIONS(10104),
    [anon_sym_POUNDELIF] = ACTIONS(10104),
    [anon_sym_POUNDElif] = ACTIONS(10104),
    [anon_sym_POUNDelse] = ACTIONS(10104),
    [anon_sym_POUNDELSE] = ACTIONS(10104),
    [anon_sym_POUNDElse] = ACTIONS(10104),
    [anon_sym_POUNDendif] = ACTIONS(10104),
    [anon_sym_POUNDENDIF] = ACTIONS(10104),
    [anon_sym_POUNDEndif] = ACTIONS(10104),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10104),
    [sym_trigger_keyword] = ACTIONS(10104),
    [sym_var_keyword] = ACTIONS(10104),
    [sym_local_keyword] = ACTIONS(10104),
    [sym_internal_keyword] = ACTIONS(10104),
    [sym_protected_keyword] = ACTIONS(10104),
    [sym_event_keyword] = ACTIONS(10104),
    [sym_fields_keyword] = ACTIONS(10104),
    [sym_keys_keyword] = ACTIONS(10104),
    [sym_fieldgroups_keyword] = ACTIONS(10104),
    [sym_actions_keyword] = ACTIONS(10104),
    [sym_layout_keyword] = ACTIONS(10104),
    [sym_area_keyword] = ACTIONS(10104),
    [sym_group_keyword] = ACTIONS(10104),
    [sym_repeater_keyword] = ACTIONS(10104),
    [sym_cuegroup_keyword] = ACTIONS(10104),
    [sym_fixed_keyword] = ACTIONS(10104),
    [sym_grid_keyword] = ACTIONS(10104),
    [sym_part_keyword] = ACTIONS(10104),
    [sym_systempart_keyword] = ACTIONS(10104),
    [sym_usercontrol_keyword] = ACTIONS(10104),
    [sym_dataset_keyword] = ACTIONS(10104),
    [sym_elements_keyword] = ACTIONS(10104),
    [sym_dataitem_keyword] = ACTIONS(10104),
    [sym_column_keyword] = ACTIONS(10104),
    [sym_filter_keyword] = ACTIONS(10104),
    [sym_labels_keyword] = ACTIONS(10104),
    [sym_rendering_keyword] = ACTIONS(10104),
    [sym_requestpage_keyword] = ACTIONS(10104),
    [sym_schema_keyword] = ACTIONS(10104),
    [sym_views_keyword] = ACTIONS(10104),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10104),
    [sym_preproc_open] = ACTIONS(10104),
    [sym_preproc_close] = ACTIONS(10104),
  },
  [STATE(3779)] = {
    [anon_sym_SEMI] = ACTIONS(10108),
    [aux_sym_where_condition_token1] = ACTIONS(10110),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10108),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10108),
    [anon_sym_LBRACK] = ACTIONS(10108),
    [aux_sym_basic_type_token6] = ACTIONS(10110),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10108),
    [aux_sym_addafter_modification_token1] = ACTIONS(10108),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10108),
    [aux_sym_modify_modification_token1] = ACTIONS(10108),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10108),
    [aux_sym_movelast_modification_token1] = ACTIONS(10108),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10108),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10108),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10108),
    [anon_sym_POUNDif] = ACTIONS(10108),
    [anon_sym_POUNDIF] = ACTIONS(10108),
    [anon_sym_POUNDIf] = ACTIONS(10108),
    [anon_sym_POUNDelif] = ACTIONS(10108),
    [anon_sym_POUNDELIF] = ACTIONS(10108),
    [anon_sym_POUNDElif] = ACTIONS(10108),
    [anon_sym_POUNDelse] = ACTIONS(10108),
    [anon_sym_POUNDELSE] = ACTIONS(10108),
    [anon_sym_POUNDElse] = ACTIONS(10108),
    [anon_sym_POUNDendif] = ACTIONS(10108),
    [anon_sym_POUNDENDIF] = ACTIONS(10108),
    [anon_sym_POUNDEndif] = ACTIONS(10108),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10108),
    [sym_trigger_keyword] = ACTIONS(10108),
    [sym_var_keyword] = ACTIONS(10108),
    [sym_local_keyword] = ACTIONS(10108),
    [sym_internal_keyword] = ACTIONS(10108),
    [sym_protected_keyword] = ACTIONS(10108),
    [sym_event_keyword] = ACTIONS(10108),
    [sym_fields_keyword] = ACTIONS(10108),
    [sym_keys_keyword] = ACTIONS(10108),
    [sym_fieldgroups_keyword] = ACTIONS(10108),
    [sym_actions_keyword] = ACTIONS(10108),
    [sym_layout_keyword] = ACTIONS(10108),
    [sym_area_keyword] = ACTIONS(10108),
    [sym_group_keyword] = ACTIONS(10108),
    [sym_repeater_keyword] = ACTIONS(10108),
    [sym_cuegroup_keyword] = ACTIONS(10108),
    [sym_fixed_keyword] = ACTIONS(10108),
    [sym_grid_keyword] = ACTIONS(10108),
    [sym_part_keyword] = ACTIONS(10108),
    [sym_systempart_keyword] = ACTIONS(10108),
    [sym_usercontrol_keyword] = ACTIONS(10108),
    [sym_dataset_keyword] = ACTIONS(10108),
    [sym_elements_keyword] = ACTIONS(10108),
    [sym_dataitem_keyword] = ACTIONS(10108),
    [sym_column_keyword] = ACTIONS(10108),
    [sym_filter_keyword] = ACTIONS(10108),
    [sym_labels_keyword] = ACTIONS(10108),
    [sym_rendering_keyword] = ACTIONS(10108),
    [sym_requestpage_keyword] = ACTIONS(10108),
    [sym_schema_keyword] = ACTIONS(10108),
    [sym_views_keyword] = ACTIONS(10108),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10108),
    [sym_preproc_open] = ACTIONS(10108),
    [sym_preproc_close] = ACTIONS(10108),
  },
  [STATE(3780)] = {
    [anon_sym_SEMI] = ACTIONS(7154),
    [aux_sym_where_condition_token1] = ACTIONS(7152),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7154),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7154),
    [anon_sym_LBRACK] = ACTIONS(7154),
    [aux_sym_basic_type_token6] = ACTIONS(7152),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7154),
    [aux_sym_addafter_modification_token1] = ACTIONS(7154),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7154),
    [aux_sym_modify_modification_token1] = ACTIONS(7154),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7154),
    [aux_sym_movelast_modification_token1] = ACTIONS(7154),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7154),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7154),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7154),
    [anon_sym_POUNDif] = ACTIONS(7154),
    [anon_sym_POUNDIF] = ACTIONS(7154),
    [anon_sym_POUNDIf] = ACTIONS(7154),
    [anon_sym_POUNDelif] = ACTIONS(7154),
    [anon_sym_POUNDELIF] = ACTIONS(7154),
    [anon_sym_POUNDElif] = ACTIONS(7154),
    [anon_sym_POUNDelse] = ACTIONS(7154),
    [anon_sym_POUNDELSE] = ACTIONS(7154),
    [anon_sym_POUNDElse] = ACTIONS(7154),
    [anon_sym_POUNDendif] = ACTIONS(7154),
    [anon_sym_POUNDENDIF] = ACTIONS(7154),
    [anon_sym_POUNDEndif] = ACTIONS(7154),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7154),
    [sym_trigger_keyword] = ACTIONS(7154),
    [sym_var_keyword] = ACTIONS(7154),
    [sym_local_keyword] = ACTIONS(7154),
    [sym_internal_keyword] = ACTIONS(7154),
    [sym_protected_keyword] = ACTIONS(7154),
    [sym_event_keyword] = ACTIONS(7154),
    [sym_fields_keyword] = ACTIONS(7154),
    [sym_keys_keyword] = ACTIONS(7154),
    [sym_fieldgroups_keyword] = ACTIONS(7154),
    [sym_actions_keyword] = ACTIONS(7154),
    [sym_layout_keyword] = ACTIONS(7154),
    [sym_area_keyword] = ACTIONS(7154),
    [sym_group_keyword] = ACTIONS(7154),
    [sym_repeater_keyword] = ACTIONS(7154),
    [sym_cuegroup_keyword] = ACTIONS(7154),
    [sym_fixed_keyword] = ACTIONS(7154),
    [sym_grid_keyword] = ACTIONS(7154),
    [sym_part_keyword] = ACTIONS(7154),
    [sym_systempart_keyword] = ACTIONS(7154),
    [sym_usercontrol_keyword] = ACTIONS(7154),
    [sym_dataset_keyword] = ACTIONS(7154),
    [sym_elements_keyword] = ACTIONS(7154),
    [sym_dataitem_keyword] = ACTIONS(7154),
    [sym_column_keyword] = ACTIONS(7154),
    [sym_filter_keyword] = ACTIONS(7154),
    [sym_labels_keyword] = ACTIONS(7154),
    [sym_rendering_keyword] = ACTIONS(7154),
    [sym_requestpage_keyword] = ACTIONS(7154),
    [sym_schema_keyword] = ACTIONS(7154),
    [sym_views_keyword] = ACTIONS(7154),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7154),
    [sym_preproc_open] = ACTIONS(7154),
    [sym_preproc_close] = ACTIONS(7154),
  },
  [STATE(3781)] = {
    [anon_sym_SEMI] = ACTIONS(10108),
    [aux_sym_where_condition_token1] = ACTIONS(10110),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10108),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10108),
    [anon_sym_LBRACK] = ACTIONS(10108),
    [aux_sym_basic_type_token6] = ACTIONS(10110),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10108),
    [aux_sym_addafter_modification_token1] = ACTIONS(10108),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10108),
    [aux_sym_modify_modification_token1] = ACTIONS(10108),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10108),
    [aux_sym_movelast_modification_token1] = ACTIONS(10108),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10108),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10108),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10108),
    [anon_sym_POUNDif] = ACTIONS(10108),
    [anon_sym_POUNDIF] = ACTIONS(10108),
    [anon_sym_POUNDIf] = ACTIONS(10108),
    [anon_sym_POUNDelif] = ACTIONS(10108),
    [anon_sym_POUNDELIF] = ACTIONS(10108),
    [anon_sym_POUNDElif] = ACTIONS(10108),
    [anon_sym_POUNDelse] = ACTIONS(10108),
    [anon_sym_POUNDELSE] = ACTIONS(10108),
    [anon_sym_POUNDElse] = ACTIONS(10108),
    [anon_sym_POUNDendif] = ACTIONS(10108),
    [anon_sym_POUNDENDIF] = ACTIONS(10108),
    [anon_sym_POUNDEndif] = ACTIONS(10108),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10108),
    [sym_trigger_keyword] = ACTIONS(10108),
    [sym_var_keyword] = ACTIONS(10108),
    [sym_local_keyword] = ACTIONS(10108),
    [sym_internal_keyword] = ACTIONS(10108),
    [sym_protected_keyword] = ACTIONS(10108),
    [sym_event_keyword] = ACTIONS(10108),
    [sym_fields_keyword] = ACTIONS(10108),
    [sym_keys_keyword] = ACTIONS(10108),
    [sym_fieldgroups_keyword] = ACTIONS(10108),
    [sym_actions_keyword] = ACTIONS(10108),
    [sym_layout_keyword] = ACTIONS(10108),
    [sym_area_keyword] = ACTIONS(10108),
    [sym_group_keyword] = ACTIONS(10108),
    [sym_repeater_keyword] = ACTIONS(10108),
    [sym_cuegroup_keyword] = ACTIONS(10108),
    [sym_fixed_keyword] = ACTIONS(10108),
    [sym_grid_keyword] = ACTIONS(10108),
    [sym_part_keyword] = ACTIONS(10108),
    [sym_systempart_keyword] = ACTIONS(10108),
    [sym_usercontrol_keyword] = ACTIONS(10108),
    [sym_dataset_keyword] = ACTIONS(10108),
    [sym_elements_keyword] = ACTIONS(10108),
    [sym_dataitem_keyword] = ACTIONS(10108),
    [sym_column_keyword] = ACTIONS(10108),
    [sym_filter_keyword] = ACTIONS(10108),
    [sym_labels_keyword] = ACTIONS(10108),
    [sym_rendering_keyword] = ACTIONS(10108),
    [sym_requestpage_keyword] = ACTIONS(10108),
    [sym_schema_keyword] = ACTIONS(10108),
    [sym_views_keyword] = ACTIONS(10108),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10108),
    [sym_preproc_open] = ACTIONS(10108),
    [sym_preproc_close] = ACTIONS(10108),
  },
  [STATE(3782)] = {
    [anon_sym_SEMI] = ACTIONS(10104),
    [aux_sym_where_condition_token1] = ACTIONS(10106),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10104),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10104),
    [anon_sym_LBRACK] = ACTIONS(10104),
    [aux_sym_basic_type_token6] = ACTIONS(10106),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10104),
    [aux_sym_addafter_modification_token1] = ACTIONS(10104),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10104),
    [aux_sym_modify_modification_token1] = ACTIONS(10104),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10104),
    [aux_sym_movelast_modification_token1] = ACTIONS(10104),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10104),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10104),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10104),
    [anon_sym_POUNDif] = ACTIONS(10104),
    [anon_sym_POUNDIF] = ACTIONS(10104),
    [anon_sym_POUNDIf] = ACTIONS(10104),
    [anon_sym_POUNDelif] = ACTIONS(10104),
    [anon_sym_POUNDELIF] = ACTIONS(10104),
    [anon_sym_POUNDElif] = ACTIONS(10104),
    [anon_sym_POUNDelse] = ACTIONS(10104),
    [anon_sym_POUNDELSE] = ACTIONS(10104),
    [anon_sym_POUNDElse] = ACTIONS(10104),
    [anon_sym_POUNDendif] = ACTIONS(10104),
    [anon_sym_POUNDENDIF] = ACTIONS(10104),
    [anon_sym_POUNDEndif] = ACTIONS(10104),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10104),
    [sym_trigger_keyword] = ACTIONS(10104),
    [sym_var_keyword] = ACTIONS(10104),
    [sym_local_keyword] = ACTIONS(10104),
    [sym_internal_keyword] = ACTIONS(10104),
    [sym_protected_keyword] = ACTIONS(10104),
    [sym_event_keyword] = ACTIONS(10104),
    [sym_fields_keyword] = ACTIONS(10104),
    [sym_keys_keyword] = ACTIONS(10104),
    [sym_fieldgroups_keyword] = ACTIONS(10104),
    [sym_actions_keyword] = ACTIONS(10104),
    [sym_layout_keyword] = ACTIONS(10104),
    [sym_area_keyword] = ACTIONS(10104),
    [sym_group_keyword] = ACTIONS(10104),
    [sym_repeater_keyword] = ACTIONS(10104),
    [sym_cuegroup_keyword] = ACTIONS(10104),
    [sym_fixed_keyword] = ACTIONS(10104),
    [sym_grid_keyword] = ACTIONS(10104),
    [sym_part_keyword] = ACTIONS(10104),
    [sym_systempart_keyword] = ACTIONS(10104),
    [sym_usercontrol_keyword] = ACTIONS(10104),
    [sym_dataset_keyword] = ACTIONS(10104),
    [sym_elements_keyword] = ACTIONS(10104),
    [sym_dataitem_keyword] = ACTIONS(10104),
    [sym_column_keyword] = ACTIONS(10104),
    [sym_filter_keyword] = ACTIONS(10104),
    [sym_labels_keyword] = ACTIONS(10104),
    [sym_rendering_keyword] = ACTIONS(10104),
    [sym_requestpage_keyword] = ACTIONS(10104),
    [sym_schema_keyword] = ACTIONS(10104),
    [sym_views_keyword] = ACTIONS(10104),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10104),
    [sym_preproc_open] = ACTIONS(10104),
    [sym_preproc_close] = ACTIONS(10104),
  },
  [STATE(3783)] = {
    [anon_sym_SEMI] = ACTIONS(10112),
    [aux_sym_where_condition_token1] = ACTIONS(9493),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9495),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9495),
    [anon_sym_LBRACK] = ACTIONS(9495),
    [aux_sym_basic_type_token6] = ACTIONS(9493),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9495),
    [aux_sym_addafter_modification_token1] = ACTIONS(9495),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9495),
    [aux_sym_modify_modification_token1] = ACTIONS(9495),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9495),
    [aux_sym_movelast_modification_token1] = ACTIONS(9495),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9495),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9495),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9495),
    [anon_sym_POUNDif] = ACTIONS(9495),
    [anon_sym_POUNDIF] = ACTIONS(9495),
    [anon_sym_POUNDIf] = ACTIONS(9495),
    [anon_sym_POUNDelif] = ACTIONS(9495),
    [anon_sym_POUNDELIF] = ACTIONS(9495),
    [anon_sym_POUNDElif] = ACTIONS(9495),
    [anon_sym_POUNDelse] = ACTIONS(9495),
    [anon_sym_POUNDELSE] = ACTIONS(9495),
    [anon_sym_POUNDElse] = ACTIONS(9495),
    [anon_sym_POUNDendif] = ACTIONS(9495),
    [anon_sym_POUNDENDIF] = ACTIONS(9495),
    [anon_sym_POUNDEndif] = ACTIONS(9495),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9495),
    [sym_trigger_keyword] = ACTIONS(9495),
    [sym_var_keyword] = ACTIONS(9495),
    [sym_local_keyword] = ACTIONS(9495),
    [sym_internal_keyword] = ACTIONS(9495),
    [sym_protected_keyword] = ACTIONS(9495),
    [sym_event_keyword] = ACTIONS(9495),
    [sym_fields_keyword] = ACTIONS(9495),
    [sym_keys_keyword] = ACTIONS(9495),
    [sym_fieldgroups_keyword] = ACTIONS(9495),
    [sym_actions_keyword] = ACTIONS(9495),
    [sym_layout_keyword] = ACTIONS(9495),
    [sym_area_keyword] = ACTIONS(9495),
    [sym_group_keyword] = ACTIONS(9495),
    [sym_repeater_keyword] = ACTIONS(9495),
    [sym_cuegroup_keyword] = ACTIONS(9495),
    [sym_fixed_keyword] = ACTIONS(9495),
    [sym_grid_keyword] = ACTIONS(9495),
    [sym_part_keyword] = ACTIONS(9495),
    [sym_systempart_keyword] = ACTIONS(9495),
    [sym_usercontrol_keyword] = ACTIONS(9495),
    [sym_dataset_keyword] = ACTIONS(9495),
    [sym_elements_keyword] = ACTIONS(9495),
    [sym_dataitem_keyword] = ACTIONS(9495),
    [sym_column_keyword] = ACTIONS(9495),
    [sym_filter_keyword] = ACTIONS(9495),
    [sym_labels_keyword] = ACTIONS(9495),
    [sym_rendering_keyword] = ACTIONS(9495),
    [sym_requestpage_keyword] = ACTIONS(9495),
    [sym_schema_keyword] = ACTIONS(9495),
    [sym_views_keyword] = ACTIONS(9495),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9495),
    [sym_preproc_open] = ACTIONS(9495),
    [sym_preproc_close] = ACTIONS(9495),
  },
  [STATE(3784)] = {
    [anon_sym_SEMI] = ACTIONS(10114),
    [aux_sym_where_condition_token1] = ACTIONS(10116),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10114),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10114),
    [anon_sym_LBRACK] = ACTIONS(10114),
    [aux_sym_basic_type_token6] = ACTIONS(10116),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10114),
    [aux_sym_addafter_modification_token1] = ACTIONS(10114),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10114),
    [aux_sym_modify_modification_token1] = ACTIONS(10114),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10114),
    [aux_sym_movelast_modification_token1] = ACTIONS(10114),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10114),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10114),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10114),
    [anon_sym_POUNDif] = ACTIONS(10114),
    [anon_sym_POUNDIF] = ACTIONS(10114),
    [anon_sym_POUNDIf] = ACTIONS(10114),
    [anon_sym_POUNDelif] = ACTIONS(10114),
    [anon_sym_POUNDELIF] = ACTIONS(10114),
    [anon_sym_POUNDElif] = ACTIONS(10114),
    [anon_sym_POUNDelse] = ACTIONS(10114),
    [anon_sym_POUNDELSE] = ACTIONS(10114),
    [anon_sym_POUNDElse] = ACTIONS(10114),
    [anon_sym_POUNDendif] = ACTIONS(10114),
    [anon_sym_POUNDENDIF] = ACTIONS(10114),
    [anon_sym_POUNDEndif] = ACTIONS(10114),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10114),
    [sym_trigger_keyword] = ACTIONS(10114),
    [sym_var_keyword] = ACTIONS(10114),
    [sym_local_keyword] = ACTIONS(10114),
    [sym_internal_keyword] = ACTIONS(10114),
    [sym_protected_keyword] = ACTIONS(10114),
    [sym_event_keyword] = ACTIONS(10114),
    [sym_fields_keyword] = ACTIONS(10114),
    [sym_keys_keyword] = ACTIONS(10114),
    [sym_fieldgroups_keyword] = ACTIONS(10114),
    [sym_actions_keyword] = ACTIONS(10114),
    [sym_layout_keyword] = ACTIONS(10114),
    [sym_area_keyword] = ACTIONS(10114),
    [sym_group_keyword] = ACTIONS(10114),
    [sym_repeater_keyword] = ACTIONS(10114),
    [sym_cuegroup_keyword] = ACTIONS(10114),
    [sym_fixed_keyword] = ACTIONS(10114),
    [sym_grid_keyword] = ACTIONS(10114),
    [sym_part_keyword] = ACTIONS(10114),
    [sym_systempart_keyword] = ACTIONS(10114),
    [sym_usercontrol_keyword] = ACTIONS(10114),
    [sym_dataset_keyword] = ACTIONS(10114),
    [sym_elements_keyword] = ACTIONS(10114),
    [sym_dataitem_keyword] = ACTIONS(10114),
    [sym_column_keyword] = ACTIONS(10114),
    [sym_filter_keyword] = ACTIONS(10114),
    [sym_labels_keyword] = ACTIONS(10114),
    [sym_rendering_keyword] = ACTIONS(10114),
    [sym_requestpage_keyword] = ACTIONS(10114),
    [sym_schema_keyword] = ACTIONS(10114),
    [sym_views_keyword] = ACTIONS(10114),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10114),
    [sym_preproc_open] = ACTIONS(10114),
    [sym_preproc_close] = ACTIONS(10114),
  },
  [STATE(3785)] = {
    [anon_sym_SEMI] = ACTIONS(10114),
    [aux_sym_where_condition_token1] = ACTIONS(10116),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10114),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10114),
    [anon_sym_LBRACK] = ACTIONS(10114),
    [aux_sym_basic_type_token6] = ACTIONS(10116),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10114),
    [aux_sym_addafter_modification_token1] = ACTIONS(10114),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10114),
    [aux_sym_modify_modification_token1] = ACTIONS(10114),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10114),
    [aux_sym_movelast_modification_token1] = ACTIONS(10114),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10114),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10114),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10114),
    [anon_sym_POUNDif] = ACTIONS(10114),
    [anon_sym_POUNDIF] = ACTIONS(10114),
    [anon_sym_POUNDIf] = ACTIONS(10114),
    [anon_sym_POUNDelif] = ACTIONS(10114),
    [anon_sym_POUNDELIF] = ACTIONS(10114),
    [anon_sym_POUNDElif] = ACTIONS(10114),
    [anon_sym_POUNDelse] = ACTIONS(10114),
    [anon_sym_POUNDELSE] = ACTIONS(10114),
    [anon_sym_POUNDElse] = ACTIONS(10114),
    [anon_sym_POUNDendif] = ACTIONS(10114),
    [anon_sym_POUNDENDIF] = ACTIONS(10114),
    [anon_sym_POUNDEndif] = ACTIONS(10114),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10114),
    [sym_trigger_keyword] = ACTIONS(10114),
    [sym_var_keyword] = ACTIONS(10114),
    [sym_local_keyword] = ACTIONS(10114),
    [sym_internal_keyword] = ACTIONS(10114),
    [sym_protected_keyword] = ACTIONS(10114),
    [sym_event_keyword] = ACTIONS(10114),
    [sym_fields_keyword] = ACTIONS(10114),
    [sym_keys_keyword] = ACTIONS(10114),
    [sym_fieldgroups_keyword] = ACTIONS(10114),
    [sym_actions_keyword] = ACTIONS(10114),
    [sym_layout_keyword] = ACTIONS(10114),
    [sym_area_keyword] = ACTIONS(10114),
    [sym_group_keyword] = ACTIONS(10114),
    [sym_repeater_keyword] = ACTIONS(10114),
    [sym_cuegroup_keyword] = ACTIONS(10114),
    [sym_fixed_keyword] = ACTIONS(10114),
    [sym_grid_keyword] = ACTIONS(10114),
    [sym_part_keyword] = ACTIONS(10114),
    [sym_systempart_keyword] = ACTIONS(10114),
    [sym_usercontrol_keyword] = ACTIONS(10114),
    [sym_dataset_keyword] = ACTIONS(10114),
    [sym_elements_keyword] = ACTIONS(10114),
    [sym_dataitem_keyword] = ACTIONS(10114),
    [sym_column_keyword] = ACTIONS(10114),
    [sym_filter_keyword] = ACTIONS(10114),
    [sym_labels_keyword] = ACTIONS(10114),
    [sym_rendering_keyword] = ACTIONS(10114),
    [sym_requestpage_keyword] = ACTIONS(10114),
    [sym_schema_keyword] = ACTIONS(10114),
    [sym_views_keyword] = ACTIONS(10114),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10114),
    [sym_preproc_open] = ACTIONS(10114),
    [sym_preproc_close] = ACTIONS(10114),
  },
  [STATE(3786)] = {
    [anon_sym_SEMI] = ACTIONS(10118),
    [aux_sym_where_condition_token1] = ACTIONS(10120),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10122),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10122),
    [anon_sym_LBRACK] = ACTIONS(10122),
    [aux_sym_basic_type_token6] = ACTIONS(10120),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10122),
    [aux_sym_addafter_modification_token1] = ACTIONS(10122),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10122),
    [aux_sym_modify_modification_token1] = ACTIONS(10122),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10122),
    [aux_sym_movelast_modification_token1] = ACTIONS(10122),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10122),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10122),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10122),
    [anon_sym_POUNDif] = ACTIONS(10122),
    [anon_sym_POUNDIF] = ACTIONS(10122),
    [anon_sym_POUNDIf] = ACTIONS(10122),
    [anon_sym_POUNDelif] = ACTIONS(10122),
    [anon_sym_POUNDELIF] = ACTIONS(10122),
    [anon_sym_POUNDElif] = ACTIONS(10122),
    [anon_sym_POUNDelse] = ACTIONS(10122),
    [anon_sym_POUNDELSE] = ACTIONS(10122),
    [anon_sym_POUNDElse] = ACTIONS(10122),
    [anon_sym_POUNDendif] = ACTIONS(10122),
    [anon_sym_POUNDENDIF] = ACTIONS(10122),
    [anon_sym_POUNDEndif] = ACTIONS(10122),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10122),
    [sym_trigger_keyword] = ACTIONS(10122),
    [sym_var_keyword] = ACTIONS(10122),
    [sym_local_keyword] = ACTIONS(10122),
    [sym_internal_keyword] = ACTIONS(10122),
    [sym_protected_keyword] = ACTIONS(10122),
    [sym_event_keyword] = ACTIONS(10122),
    [sym_fields_keyword] = ACTIONS(10122),
    [sym_keys_keyword] = ACTIONS(10122),
    [sym_fieldgroups_keyword] = ACTIONS(10122),
    [sym_actions_keyword] = ACTIONS(10122),
    [sym_layout_keyword] = ACTIONS(10122),
    [sym_area_keyword] = ACTIONS(10122),
    [sym_group_keyword] = ACTIONS(10122),
    [sym_repeater_keyword] = ACTIONS(10122),
    [sym_cuegroup_keyword] = ACTIONS(10122),
    [sym_fixed_keyword] = ACTIONS(10122),
    [sym_grid_keyword] = ACTIONS(10122),
    [sym_part_keyword] = ACTIONS(10122),
    [sym_systempart_keyword] = ACTIONS(10122),
    [sym_usercontrol_keyword] = ACTIONS(10122),
    [sym_dataset_keyword] = ACTIONS(10122),
    [sym_elements_keyword] = ACTIONS(10122),
    [sym_dataitem_keyword] = ACTIONS(10122),
    [sym_column_keyword] = ACTIONS(10122),
    [sym_filter_keyword] = ACTIONS(10122),
    [sym_labels_keyword] = ACTIONS(10122),
    [sym_rendering_keyword] = ACTIONS(10122),
    [sym_requestpage_keyword] = ACTIONS(10122),
    [sym_schema_keyword] = ACTIONS(10122),
    [sym_views_keyword] = ACTIONS(10122),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10122),
    [sym_preproc_open] = ACTIONS(10122),
    [sym_preproc_close] = ACTIONS(10122),
  },
  [STATE(3787)] = {
    [anon_sym_SEMI] = ACTIONS(10124),
    [aux_sym_where_condition_token1] = ACTIONS(10120),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10122),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10122),
    [anon_sym_LBRACK] = ACTIONS(10122),
    [aux_sym_basic_type_token6] = ACTIONS(10120),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10122),
    [aux_sym_addafter_modification_token1] = ACTIONS(10122),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10122),
    [aux_sym_modify_modification_token1] = ACTIONS(10122),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10122),
    [aux_sym_movelast_modification_token1] = ACTIONS(10122),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10122),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10122),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10122),
    [anon_sym_POUNDif] = ACTIONS(10122),
    [anon_sym_POUNDIF] = ACTIONS(10122),
    [anon_sym_POUNDIf] = ACTIONS(10122),
    [anon_sym_POUNDelif] = ACTIONS(10122),
    [anon_sym_POUNDELIF] = ACTIONS(10122),
    [anon_sym_POUNDElif] = ACTIONS(10122),
    [anon_sym_POUNDelse] = ACTIONS(10122),
    [anon_sym_POUNDELSE] = ACTIONS(10122),
    [anon_sym_POUNDElse] = ACTIONS(10122),
    [anon_sym_POUNDendif] = ACTIONS(10122),
    [anon_sym_POUNDENDIF] = ACTIONS(10122),
    [anon_sym_POUNDEndif] = ACTIONS(10122),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10122),
    [sym_trigger_keyword] = ACTIONS(10122),
    [sym_var_keyword] = ACTIONS(10122),
    [sym_local_keyword] = ACTIONS(10122),
    [sym_internal_keyword] = ACTIONS(10122),
    [sym_protected_keyword] = ACTIONS(10122),
    [sym_event_keyword] = ACTIONS(10122),
    [sym_fields_keyword] = ACTIONS(10122),
    [sym_keys_keyword] = ACTIONS(10122),
    [sym_fieldgroups_keyword] = ACTIONS(10122),
    [sym_actions_keyword] = ACTIONS(10122),
    [sym_layout_keyword] = ACTIONS(10122),
    [sym_area_keyword] = ACTIONS(10122),
    [sym_group_keyword] = ACTIONS(10122),
    [sym_repeater_keyword] = ACTIONS(10122),
    [sym_cuegroup_keyword] = ACTIONS(10122),
    [sym_fixed_keyword] = ACTIONS(10122),
    [sym_grid_keyword] = ACTIONS(10122),
    [sym_part_keyword] = ACTIONS(10122),
    [sym_systempart_keyword] = ACTIONS(10122),
    [sym_usercontrol_keyword] = ACTIONS(10122),
    [sym_dataset_keyword] = ACTIONS(10122),
    [sym_elements_keyword] = ACTIONS(10122),
    [sym_dataitem_keyword] = ACTIONS(10122),
    [sym_column_keyword] = ACTIONS(10122),
    [sym_filter_keyword] = ACTIONS(10122),
    [sym_labels_keyword] = ACTIONS(10122),
    [sym_rendering_keyword] = ACTIONS(10122),
    [sym_requestpage_keyword] = ACTIONS(10122),
    [sym_schema_keyword] = ACTIONS(10122),
    [sym_views_keyword] = ACTIONS(10122),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10122),
    [sym_preproc_open] = ACTIONS(10122),
    [sym_preproc_close] = ACTIONS(10122),
  },
  [STATE(3788)] = {
    [anon_sym_SEMI] = ACTIONS(10126),
    [aux_sym_where_condition_token1] = ACTIONS(10116),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10114),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10114),
    [anon_sym_LBRACK] = ACTIONS(10114),
    [aux_sym_basic_type_token6] = ACTIONS(10116),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10114),
    [aux_sym_addafter_modification_token1] = ACTIONS(10114),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10114),
    [aux_sym_modify_modification_token1] = ACTIONS(10114),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10114),
    [aux_sym_movelast_modification_token1] = ACTIONS(10114),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10114),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10114),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10114),
    [anon_sym_POUNDif] = ACTIONS(10114),
    [anon_sym_POUNDIF] = ACTIONS(10114),
    [anon_sym_POUNDIf] = ACTIONS(10114),
    [anon_sym_POUNDelif] = ACTIONS(10114),
    [anon_sym_POUNDELIF] = ACTIONS(10114),
    [anon_sym_POUNDElif] = ACTIONS(10114),
    [anon_sym_POUNDelse] = ACTIONS(10114),
    [anon_sym_POUNDELSE] = ACTIONS(10114),
    [anon_sym_POUNDElse] = ACTIONS(10114),
    [anon_sym_POUNDendif] = ACTIONS(10114),
    [anon_sym_POUNDENDIF] = ACTIONS(10114),
    [anon_sym_POUNDEndif] = ACTIONS(10114),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10114),
    [sym_trigger_keyword] = ACTIONS(10114),
    [sym_var_keyword] = ACTIONS(10114),
    [sym_local_keyword] = ACTIONS(10114),
    [sym_internal_keyword] = ACTIONS(10114),
    [sym_protected_keyword] = ACTIONS(10114),
    [sym_event_keyword] = ACTIONS(10114),
    [sym_fields_keyword] = ACTIONS(10114),
    [sym_keys_keyword] = ACTIONS(10114),
    [sym_fieldgroups_keyword] = ACTIONS(10114),
    [sym_actions_keyword] = ACTIONS(10114),
    [sym_layout_keyword] = ACTIONS(10114),
    [sym_area_keyword] = ACTIONS(10114),
    [sym_group_keyword] = ACTIONS(10114),
    [sym_repeater_keyword] = ACTIONS(10114),
    [sym_cuegroup_keyword] = ACTIONS(10114),
    [sym_fixed_keyword] = ACTIONS(10114),
    [sym_grid_keyword] = ACTIONS(10114),
    [sym_part_keyword] = ACTIONS(10114),
    [sym_systempart_keyword] = ACTIONS(10114),
    [sym_usercontrol_keyword] = ACTIONS(10114),
    [sym_dataset_keyword] = ACTIONS(10114),
    [sym_elements_keyword] = ACTIONS(10114),
    [sym_dataitem_keyword] = ACTIONS(10114),
    [sym_column_keyword] = ACTIONS(10114),
    [sym_filter_keyword] = ACTIONS(10114),
    [sym_labels_keyword] = ACTIONS(10114),
    [sym_rendering_keyword] = ACTIONS(10114),
    [sym_requestpage_keyword] = ACTIONS(10114),
    [sym_schema_keyword] = ACTIONS(10114),
    [sym_views_keyword] = ACTIONS(10114),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10114),
    [sym_preproc_open] = ACTIONS(10114),
    [sym_preproc_close] = ACTIONS(10114),
  },
  [STATE(3789)] = {
    [anon_sym_SEMI] = ACTIONS(10128),
    [aux_sym_where_condition_token1] = ACTIONS(10116),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10114),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10114),
    [anon_sym_LBRACK] = ACTIONS(10114),
    [aux_sym_basic_type_token6] = ACTIONS(10116),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10114),
    [aux_sym_addafter_modification_token1] = ACTIONS(10114),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10114),
    [aux_sym_modify_modification_token1] = ACTIONS(10114),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10114),
    [aux_sym_movelast_modification_token1] = ACTIONS(10114),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10114),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10114),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10114),
    [anon_sym_POUNDif] = ACTIONS(10114),
    [anon_sym_POUNDIF] = ACTIONS(10114),
    [anon_sym_POUNDIf] = ACTIONS(10114),
    [anon_sym_POUNDelif] = ACTIONS(10114),
    [anon_sym_POUNDELIF] = ACTIONS(10114),
    [anon_sym_POUNDElif] = ACTIONS(10114),
    [anon_sym_POUNDelse] = ACTIONS(10114),
    [anon_sym_POUNDELSE] = ACTIONS(10114),
    [anon_sym_POUNDElse] = ACTIONS(10114),
    [anon_sym_POUNDendif] = ACTIONS(10114),
    [anon_sym_POUNDENDIF] = ACTIONS(10114),
    [anon_sym_POUNDEndif] = ACTIONS(10114),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10114),
    [sym_trigger_keyword] = ACTIONS(10114),
    [sym_var_keyword] = ACTIONS(10114),
    [sym_local_keyword] = ACTIONS(10114),
    [sym_internal_keyword] = ACTIONS(10114),
    [sym_protected_keyword] = ACTIONS(10114),
    [sym_event_keyword] = ACTIONS(10114),
    [sym_fields_keyword] = ACTIONS(10114),
    [sym_keys_keyword] = ACTIONS(10114),
    [sym_fieldgroups_keyword] = ACTIONS(10114),
    [sym_actions_keyword] = ACTIONS(10114),
    [sym_layout_keyword] = ACTIONS(10114),
    [sym_area_keyword] = ACTIONS(10114),
    [sym_group_keyword] = ACTIONS(10114),
    [sym_repeater_keyword] = ACTIONS(10114),
    [sym_cuegroup_keyword] = ACTIONS(10114),
    [sym_fixed_keyword] = ACTIONS(10114),
    [sym_grid_keyword] = ACTIONS(10114),
    [sym_part_keyword] = ACTIONS(10114),
    [sym_systempart_keyword] = ACTIONS(10114),
    [sym_usercontrol_keyword] = ACTIONS(10114),
    [sym_dataset_keyword] = ACTIONS(10114),
    [sym_elements_keyword] = ACTIONS(10114),
    [sym_dataitem_keyword] = ACTIONS(10114),
    [sym_column_keyword] = ACTIONS(10114),
    [sym_filter_keyword] = ACTIONS(10114),
    [sym_labels_keyword] = ACTIONS(10114),
    [sym_rendering_keyword] = ACTIONS(10114),
    [sym_requestpage_keyword] = ACTIONS(10114),
    [sym_schema_keyword] = ACTIONS(10114),
    [sym_views_keyword] = ACTIONS(10114),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10114),
    [sym_preproc_open] = ACTIONS(10114),
    [sym_preproc_close] = ACTIONS(10114),
  },
  [STATE(3790)] = {
    [anon_sym_SEMI] = ACTIONS(10130),
    [aux_sym_where_condition_token1] = ACTIONS(10132),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10130),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10130),
    [anon_sym_LBRACK] = ACTIONS(10130),
    [aux_sym_basic_type_token6] = ACTIONS(10132),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10130),
    [aux_sym_addafter_modification_token1] = ACTIONS(10130),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10130),
    [aux_sym_modify_modification_token1] = ACTIONS(10130),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10130),
    [aux_sym_movelast_modification_token1] = ACTIONS(10130),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10130),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10130),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10130),
    [anon_sym_POUNDif] = ACTIONS(10130),
    [anon_sym_POUNDIF] = ACTIONS(10130),
    [anon_sym_POUNDIf] = ACTIONS(10130),
    [anon_sym_POUNDelif] = ACTIONS(10130),
    [anon_sym_POUNDELIF] = ACTIONS(10130),
    [anon_sym_POUNDElif] = ACTIONS(10130),
    [anon_sym_POUNDelse] = ACTIONS(10130),
    [anon_sym_POUNDELSE] = ACTIONS(10130),
    [anon_sym_POUNDElse] = ACTIONS(10130),
    [anon_sym_POUNDendif] = ACTIONS(10130),
    [anon_sym_POUNDENDIF] = ACTIONS(10130),
    [anon_sym_POUNDEndif] = ACTIONS(10130),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10130),
    [sym_trigger_keyword] = ACTIONS(10130),
    [sym_var_keyword] = ACTIONS(10130),
    [sym_local_keyword] = ACTIONS(10130),
    [sym_internal_keyword] = ACTIONS(10130),
    [sym_protected_keyword] = ACTIONS(10130),
    [sym_event_keyword] = ACTIONS(10130),
    [sym_fields_keyword] = ACTIONS(10130),
    [sym_keys_keyword] = ACTIONS(10130),
    [sym_fieldgroups_keyword] = ACTIONS(10130),
    [sym_actions_keyword] = ACTIONS(10130),
    [sym_layout_keyword] = ACTIONS(10130),
    [sym_area_keyword] = ACTIONS(10130),
    [sym_group_keyword] = ACTIONS(10130),
    [sym_repeater_keyword] = ACTIONS(10130),
    [sym_cuegroup_keyword] = ACTIONS(10130),
    [sym_fixed_keyword] = ACTIONS(10130),
    [sym_grid_keyword] = ACTIONS(10130),
    [sym_part_keyword] = ACTIONS(10130),
    [sym_systempart_keyword] = ACTIONS(10130),
    [sym_usercontrol_keyword] = ACTIONS(10130),
    [sym_dataset_keyword] = ACTIONS(10130),
    [sym_elements_keyword] = ACTIONS(10130),
    [sym_dataitem_keyword] = ACTIONS(10130),
    [sym_column_keyword] = ACTIONS(10130),
    [sym_filter_keyword] = ACTIONS(10130),
    [sym_labels_keyword] = ACTIONS(10130),
    [sym_rendering_keyword] = ACTIONS(10130),
    [sym_requestpage_keyword] = ACTIONS(10130),
    [sym_schema_keyword] = ACTIONS(10130),
    [sym_views_keyword] = ACTIONS(10130),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10130),
    [sym_preproc_open] = ACTIONS(10130),
    [sym_preproc_close] = ACTIONS(10130),
  },
  [STATE(3791)] = {
    [anon_sym_SEMI] = ACTIONS(10134),
    [aux_sym_where_condition_token1] = ACTIONS(10136),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10138),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10138),
    [anon_sym_LBRACK] = ACTIONS(10138),
    [aux_sym_basic_type_token6] = ACTIONS(10136),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10138),
    [aux_sym_addafter_modification_token1] = ACTIONS(10138),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10138),
    [aux_sym_modify_modification_token1] = ACTIONS(10138),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10138),
    [aux_sym_movelast_modification_token1] = ACTIONS(10138),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10138),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10138),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10138),
    [anon_sym_POUNDif] = ACTIONS(10138),
    [anon_sym_POUNDIF] = ACTIONS(10138),
    [anon_sym_POUNDIf] = ACTIONS(10138),
    [anon_sym_POUNDelif] = ACTIONS(10138),
    [anon_sym_POUNDELIF] = ACTIONS(10138),
    [anon_sym_POUNDElif] = ACTIONS(10138),
    [anon_sym_POUNDelse] = ACTIONS(10138),
    [anon_sym_POUNDELSE] = ACTIONS(10138),
    [anon_sym_POUNDElse] = ACTIONS(10138),
    [anon_sym_POUNDendif] = ACTIONS(10138),
    [anon_sym_POUNDENDIF] = ACTIONS(10138),
    [anon_sym_POUNDEndif] = ACTIONS(10138),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10138),
    [sym_trigger_keyword] = ACTIONS(10138),
    [sym_var_keyword] = ACTIONS(10138),
    [sym_local_keyword] = ACTIONS(10138),
    [sym_internal_keyword] = ACTIONS(10138),
    [sym_protected_keyword] = ACTIONS(10138),
    [sym_event_keyword] = ACTIONS(10138),
    [sym_fields_keyword] = ACTIONS(10138),
    [sym_keys_keyword] = ACTIONS(10138),
    [sym_fieldgroups_keyword] = ACTIONS(10138),
    [sym_actions_keyword] = ACTIONS(10138),
    [sym_layout_keyword] = ACTIONS(10138),
    [sym_area_keyword] = ACTIONS(10138),
    [sym_group_keyword] = ACTIONS(10138),
    [sym_repeater_keyword] = ACTIONS(10138),
    [sym_cuegroup_keyword] = ACTIONS(10138),
    [sym_fixed_keyword] = ACTIONS(10138),
    [sym_grid_keyword] = ACTIONS(10138),
    [sym_part_keyword] = ACTIONS(10138),
    [sym_systempart_keyword] = ACTIONS(10138),
    [sym_usercontrol_keyword] = ACTIONS(10138),
    [sym_dataset_keyword] = ACTIONS(10138),
    [sym_elements_keyword] = ACTIONS(10138),
    [sym_dataitem_keyword] = ACTIONS(10138),
    [sym_column_keyword] = ACTIONS(10138),
    [sym_filter_keyword] = ACTIONS(10138),
    [sym_labels_keyword] = ACTIONS(10138),
    [sym_rendering_keyword] = ACTIONS(10138),
    [sym_requestpage_keyword] = ACTIONS(10138),
    [sym_schema_keyword] = ACTIONS(10138),
    [sym_views_keyword] = ACTIONS(10138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10138),
    [sym_preproc_open] = ACTIONS(10138),
    [sym_preproc_close] = ACTIONS(10138),
  },
  [STATE(3792)] = {
    [anon_sym_SEMI] = ACTIONS(10140),
    [aux_sym_where_condition_token1] = ACTIONS(10136),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10138),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10138),
    [anon_sym_LBRACK] = ACTIONS(10138),
    [aux_sym_basic_type_token6] = ACTIONS(10136),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10138),
    [aux_sym_addafter_modification_token1] = ACTIONS(10138),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10138),
    [aux_sym_modify_modification_token1] = ACTIONS(10138),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10138),
    [aux_sym_movelast_modification_token1] = ACTIONS(10138),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10138),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10138),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10138),
    [anon_sym_POUNDif] = ACTIONS(10138),
    [anon_sym_POUNDIF] = ACTIONS(10138),
    [anon_sym_POUNDIf] = ACTIONS(10138),
    [anon_sym_POUNDelif] = ACTIONS(10138),
    [anon_sym_POUNDELIF] = ACTIONS(10138),
    [anon_sym_POUNDElif] = ACTIONS(10138),
    [anon_sym_POUNDelse] = ACTIONS(10138),
    [anon_sym_POUNDELSE] = ACTIONS(10138),
    [anon_sym_POUNDElse] = ACTIONS(10138),
    [anon_sym_POUNDendif] = ACTIONS(10138),
    [anon_sym_POUNDENDIF] = ACTIONS(10138),
    [anon_sym_POUNDEndif] = ACTIONS(10138),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10138),
    [sym_trigger_keyword] = ACTIONS(10138),
    [sym_var_keyword] = ACTIONS(10138),
    [sym_local_keyword] = ACTIONS(10138),
    [sym_internal_keyword] = ACTIONS(10138),
    [sym_protected_keyword] = ACTIONS(10138),
    [sym_event_keyword] = ACTIONS(10138),
    [sym_fields_keyword] = ACTIONS(10138),
    [sym_keys_keyword] = ACTIONS(10138),
    [sym_fieldgroups_keyword] = ACTIONS(10138),
    [sym_actions_keyword] = ACTIONS(10138),
    [sym_layout_keyword] = ACTIONS(10138),
    [sym_area_keyword] = ACTIONS(10138),
    [sym_group_keyword] = ACTIONS(10138),
    [sym_repeater_keyword] = ACTIONS(10138),
    [sym_cuegroup_keyword] = ACTIONS(10138),
    [sym_fixed_keyword] = ACTIONS(10138),
    [sym_grid_keyword] = ACTIONS(10138),
    [sym_part_keyword] = ACTIONS(10138),
    [sym_systempart_keyword] = ACTIONS(10138),
    [sym_usercontrol_keyword] = ACTIONS(10138),
    [sym_dataset_keyword] = ACTIONS(10138),
    [sym_elements_keyword] = ACTIONS(10138),
    [sym_dataitem_keyword] = ACTIONS(10138),
    [sym_column_keyword] = ACTIONS(10138),
    [sym_filter_keyword] = ACTIONS(10138),
    [sym_labels_keyword] = ACTIONS(10138),
    [sym_rendering_keyword] = ACTIONS(10138),
    [sym_requestpage_keyword] = ACTIONS(10138),
    [sym_schema_keyword] = ACTIONS(10138),
    [sym_views_keyword] = ACTIONS(10138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10138),
    [sym_preproc_open] = ACTIONS(10138),
    [sym_preproc_close] = ACTIONS(10138),
  },
  [STATE(3793)] = {
    [anon_sym_SEMI] = ACTIONS(9936),
    [aux_sym_where_condition_token1] = ACTIONS(9934),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9936),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9936),
    [anon_sym_LBRACK] = ACTIONS(9936),
    [aux_sym_basic_type_token6] = ACTIONS(9934),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9936),
    [aux_sym_addafter_modification_token1] = ACTIONS(9936),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9936),
    [aux_sym_modify_modification_token1] = ACTIONS(9936),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9936),
    [aux_sym_movelast_modification_token1] = ACTIONS(9936),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9936),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9936),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9936),
    [anon_sym_POUNDif] = ACTIONS(9936),
    [anon_sym_POUNDIF] = ACTIONS(9936),
    [anon_sym_POUNDIf] = ACTIONS(9936),
    [anon_sym_POUNDelif] = ACTIONS(9936),
    [anon_sym_POUNDELIF] = ACTIONS(9936),
    [anon_sym_POUNDElif] = ACTIONS(9936),
    [anon_sym_POUNDelse] = ACTIONS(9936),
    [anon_sym_POUNDELSE] = ACTIONS(9936),
    [anon_sym_POUNDElse] = ACTIONS(9936),
    [anon_sym_POUNDendif] = ACTIONS(9936),
    [anon_sym_POUNDENDIF] = ACTIONS(9936),
    [anon_sym_POUNDEndif] = ACTIONS(9936),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9936),
    [sym_trigger_keyword] = ACTIONS(9936),
    [sym_var_keyword] = ACTIONS(9936),
    [sym_local_keyword] = ACTIONS(9936),
    [sym_internal_keyword] = ACTIONS(9936),
    [sym_protected_keyword] = ACTIONS(9936),
    [sym_event_keyword] = ACTIONS(9936),
    [sym_fields_keyword] = ACTIONS(9936),
    [sym_keys_keyword] = ACTIONS(9936),
    [sym_fieldgroups_keyword] = ACTIONS(9936),
    [sym_actions_keyword] = ACTIONS(9936),
    [sym_layout_keyword] = ACTIONS(9936),
    [sym_area_keyword] = ACTIONS(9936),
    [sym_group_keyword] = ACTIONS(9936),
    [sym_repeater_keyword] = ACTIONS(9936),
    [sym_cuegroup_keyword] = ACTIONS(9936),
    [sym_fixed_keyword] = ACTIONS(9936),
    [sym_grid_keyword] = ACTIONS(9936),
    [sym_part_keyword] = ACTIONS(9936),
    [sym_systempart_keyword] = ACTIONS(9936),
    [sym_usercontrol_keyword] = ACTIONS(9936),
    [sym_dataset_keyword] = ACTIONS(9936),
    [sym_elements_keyword] = ACTIONS(9936),
    [sym_dataitem_keyword] = ACTIONS(9936),
    [sym_column_keyword] = ACTIONS(9936),
    [sym_filter_keyword] = ACTIONS(9936),
    [sym_labels_keyword] = ACTIONS(9936),
    [sym_rendering_keyword] = ACTIONS(9936),
    [sym_requestpage_keyword] = ACTIONS(9936),
    [sym_schema_keyword] = ACTIONS(9936),
    [sym_views_keyword] = ACTIONS(9936),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9936),
    [sym_preproc_open] = ACTIONS(9936),
    [sym_preproc_close] = ACTIONS(9936),
  },
  [STATE(3794)] = {
    [anon_sym_SEMI] = ACTIONS(9936),
    [aux_sym_where_condition_token1] = ACTIONS(9934),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9936),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9936),
    [anon_sym_LBRACK] = ACTIONS(9936),
    [aux_sym_basic_type_token6] = ACTIONS(9934),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9936),
    [aux_sym_addafter_modification_token1] = ACTIONS(9936),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9936),
    [aux_sym_modify_modification_token1] = ACTIONS(9936),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9936),
    [aux_sym_movelast_modification_token1] = ACTIONS(9936),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9936),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9936),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9936),
    [anon_sym_POUNDif] = ACTIONS(9936),
    [anon_sym_POUNDIF] = ACTIONS(9936),
    [anon_sym_POUNDIf] = ACTIONS(9936),
    [anon_sym_POUNDelif] = ACTIONS(9936),
    [anon_sym_POUNDELIF] = ACTIONS(9936),
    [anon_sym_POUNDElif] = ACTIONS(9936),
    [anon_sym_POUNDelse] = ACTIONS(9936),
    [anon_sym_POUNDELSE] = ACTIONS(9936),
    [anon_sym_POUNDElse] = ACTIONS(9936),
    [anon_sym_POUNDendif] = ACTIONS(9936),
    [anon_sym_POUNDENDIF] = ACTIONS(9936),
    [anon_sym_POUNDEndif] = ACTIONS(9936),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9936),
    [sym_trigger_keyword] = ACTIONS(9936),
    [sym_var_keyword] = ACTIONS(9936),
    [sym_local_keyword] = ACTIONS(9936),
    [sym_internal_keyword] = ACTIONS(9936),
    [sym_protected_keyword] = ACTIONS(9936),
    [sym_event_keyword] = ACTIONS(9936),
    [sym_fields_keyword] = ACTIONS(9936),
    [sym_keys_keyword] = ACTIONS(9936),
    [sym_fieldgroups_keyword] = ACTIONS(9936),
    [sym_actions_keyword] = ACTIONS(9936),
    [sym_layout_keyword] = ACTIONS(9936),
    [sym_area_keyword] = ACTIONS(9936),
    [sym_group_keyword] = ACTIONS(9936),
    [sym_repeater_keyword] = ACTIONS(9936),
    [sym_cuegroup_keyword] = ACTIONS(9936),
    [sym_fixed_keyword] = ACTIONS(9936),
    [sym_grid_keyword] = ACTIONS(9936),
    [sym_part_keyword] = ACTIONS(9936),
    [sym_systempart_keyword] = ACTIONS(9936),
    [sym_usercontrol_keyword] = ACTIONS(9936),
    [sym_dataset_keyword] = ACTIONS(9936),
    [sym_elements_keyword] = ACTIONS(9936),
    [sym_dataitem_keyword] = ACTIONS(9936),
    [sym_column_keyword] = ACTIONS(9936),
    [sym_filter_keyword] = ACTIONS(9936),
    [sym_labels_keyword] = ACTIONS(9936),
    [sym_rendering_keyword] = ACTIONS(9936),
    [sym_requestpage_keyword] = ACTIONS(9936),
    [sym_schema_keyword] = ACTIONS(9936),
    [sym_views_keyword] = ACTIONS(9936),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9936),
    [sym_preproc_open] = ACTIONS(9936),
    [sym_preproc_close] = ACTIONS(9936),
  },
  [STATE(3795)] = {
    [anon_sym_SEMI] = ACTIONS(10142),
    [aux_sym_where_condition_token1] = ACTIONS(10144),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10146),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10146),
    [anon_sym_LBRACK] = ACTIONS(10146),
    [aux_sym_basic_type_token6] = ACTIONS(10144),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10146),
    [aux_sym_addafter_modification_token1] = ACTIONS(10146),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10146),
    [aux_sym_modify_modification_token1] = ACTIONS(10146),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10146),
    [aux_sym_movelast_modification_token1] = ACTIONS(10146),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10146),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10146),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10146),
    [anon_sym_POUNDif] = ACTIONS(10146),
    [anon_sym_POUNDIF] = ACTIONS(10146),
    [anon_sym_POUNDIf] = ACTIONS(10146),
    [anon_sym_POUNDelif] = ACTIONS(10146),
    [anon_sym_POUNDELIF] = ACTIONS(10146),
    [anon_sym_POUNDElif] = ACTIONS(10146),
    [anon_sym_POUNDelse] = ACTIONS(10146),
    [anon_sym_POUNDELSE] = ACTIONS(10146),
    [anon_sym_POUNDElse] = ACTIONS(10146),
    [anon_sym_POUNDendif] = ACTIONS(10146),
    [anon_sym_POUNDENDIF] = ACTIONS(10146),
    [anon_sym_POUNDEndif] = ACTIONS(10146),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10146),
    [sym_trigger_keyword] = ACTIONS(10146),
    [sym_var_keyword] = ACTIONS(10146),
    [sym_local_keyword] = ACTIONS(10146),
    [sym_internal_keyword] = ACTIONS(10146),
    [sym_protected_keyword] = ACTIONS(10146),
    [sym_event_keyword] = ACTIONS(10146),
    [sym_fields_keyword] = ACTIONS(10146),
    [sym_keys_keyword] = ACTIONS(10146),
    [sym_fieldgroups_keyword] = ACTIONS(10146),
    [sym_actions_keyword] = ACTIONS(10146),
    [sym_layout_keyword] = ACTIONS(10146),
    [sym_area_keyword] = ACTIONS(10146),
    [sym_group_keyword] = ACTIONS(10146),
    [sym_repeater_keyword] = ACTIONS(10146),
    [sym_cuegroup_keyword] = ACTIONS(10146),
    [sym_fixed_keyword] = ACTIONS(10146),
    [sym_grid_keyword] = ACTIONS(10146),
    [sym_part_keyword] = ACTIONS(10146),
    [sym_systempart_keyword] = ACTIONS(10146),
    [sym_usercontrol_keyword] = ACTIONS(10146),
    [sym_dataset_keyword] = ACTIONS(10146),
    [sym_elements_keyword] = ACTIONS(10146),
    [sym_dataitem_keyword] = ACTIONS(10146),
    [sym_column_keyword] = ACTIONS(10146),
    [sym_filter_keyword] = ACTIONS(10146),
    [sym_labels_keyword] = ACTIONS(10146),
    [sym_rendering_keyword] = ACTIONS(10146),
    [sym_requestpage_keyword] = ACTIONS(10146),
    [sym_schema_keyword] = ACTIONS(10146),
    [sym_views_keyword] = ACTIONS(10146),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10146),
    [sym_preproc_open] = ACTIONS(10146),
    [sym_preproc_close] = ACTIONS(10146),
  },
  [STATE(3796)] = {
    [anon_sym_SEMI] = ACTIONS(10148),
    [aux_sym_where_condition_token1] = ACTIONS(10144),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10146),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10146),
    [anon_sym_LBRACK] = ACTIONS(10146),
    [aux_sym_basic_type_token6] = ACTIONS(10144),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10146),
    [aux_sym_addafter_modification_token1] = ACTIONS(10146),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10146),
    [aux_sym_modify_modification_token1] = ACTIONS(10146),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10146),
    [aux_sym_movelast_modification_token1] = ACTIONS(10146),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10146),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10146),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10146),
    [anon_sym_POUNDif] = ACTIONS(10146),
    [anon_sym_POUNDIF] = ACTIONS(10146),
    [anon_sym_POUNDIf] = ACTIONS(10146),
    [anon_sym_POUNDelif] = ACTIONS(10146),
    [anon_sym_POUNDELIF] = ACTIONS(10146),
    [anon_sym_POUNDElif] = ACTIONS(10146),
    [anon_sym_POUNDelse] = ACTIONS(10146),
    [anon_sym_POUNDELSE] = ACTIONS(10146),
    [anon_sym_POUNDElse] = ACTIONS(10146),
    [anon_sym_POUNDendif] = ACTIONS(10146),
    [anon_sym_POUNDENDIF] = ACTIONS(10146),
    [anon_sym_POUNDEndif] = ACTIONS(10146),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10146),
    [sym_trigger_keyword] = ACTIONS(10146),
    [sym_var_keyword] = ACTIONS(10146),
    [sym_local_keyword] = ACTIONS(10146),
    [sym_internal_keyword] = ACTIONS(10146),
    [sym_protected_keyword] = ACTIONS(10146),
    [sym_event_keyword] = ACTIONS(10146),
    [sym_fields_keyword] = ACTIONS(10146),
    [sym_keys_keyword] = ACTIONS(10146),
    [sym_fieldgroups_keyword] = ACTIONS(10146),
    [sym_actions_keyword] = ACTIONS(10146),
    [sym_layout_keyword] = ACTIONS(10146),
    [sym_area_keyword] = ACTIONS(10146),
    [sym_group_keyword] = ACTIONS(10146),
    [sym_repeater_keyword] = ACTIONS(10146),
    [sym_cuegroup_keyword] = ACTIONS(10146),
    [sym_fixed_keyword] = ACTIONS(10146),
    [sym_grid_keyword] = ACTIONS(10146),
    [sym_part_keyword] = ACTIONS(10146),
    [sym_systempart_keyword] = ACTIONS(10146),
    [sym_usercontrol_keyword] = ACTIONS(10146),
    [sym_dataset_keyword] = ACTIONS(10146),
    [sym_elements_keyword] = ACTIONS(10146),
    [sym_dataitem_keyword] = ACTIONS(10146),
    [sym_column_keyword] = ACTIONS(10146),
    [sym_filter_keyword] = ACTIONS(10146),
    [sym_labels_keyword] = ACTIONS(10146),
    [sym_rendering_keyword] = ACTIONS(10146),
    [sym_requestpage_keyword] = ACTIONS(10146),
    [sym_schema_keyword] = ACTIONS(10146),
    [sym_views_keyword] = ACTIONS(10146),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10146),
    [sym_preproc_open] = ACTIONS(10146),
    [sym_preproc_close] = ACTIONS(10146),
  },
  [STATE(3797)] = {
    [anon_sym_SEMI] = ACTIONS(9761),
    [aux_sym_where_condition_token1] = ACTIONS(9763),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9761),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9761),
    [anon_sym_LBRACK] = ACTIONS(9761),
    [aux_sym_basic_type_token6] = ACTIONS(9763),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9761),
    [aux_sym_addafter_modification_token1] = ACTIONS(9761),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9761),
    [aux_sym_modify_modification_token1] = ACTIONS(9761),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9761),
    [aux_sym_movelast_modification_token1] = ACTIONS(9761),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9761),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9761),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9761),
    [anon_sym_POUNDif] = ACTIONS(9761),
    [anon_sym_POUNDIF] = ACTIONS(9761),
    [anon_sym_POUNDIf] = ACTIONS(9761),
    [anon_sym_POUNDelif] = ACTIONS(9761),
    [anon_sym_POUNDELIF] = ACTIONS(9761),
    [anon_sym_POUNDElif] = ACTIONS(9761),
    [anon_sym_POUNDelse] = ACTIONS(9761),
    [anon_sym_POUNDELSE] = ACTIONS(9761),
    [anon_sym_POUNDElse] = ACTIONS(9761),
    [anon_sym_POUNDendif] = ACTIONS(9761),
    [anon_sym_POUNDENDIF] = ACTIONS(9761),
    [anon_sym_POUNDEndif] = ACTIONS(9761),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9761),
    [sym_trigger_keyword] = ACTIONS(9761),
    [sym_var_keyword] = ACTIONS(9761),
    [sym_local_keyword] = ACTIONS(9761),
    [sym_internal_keyword] = ACTIONS(9761),
    [sym_protected_keyword] = ACTIONS(9761),
    [sym_event_keyword] = ACTIONS(9761),
    [sym_fields_keyword] = ACTIONS(9761),
    [sym_keys_keyword] = ACTIONS(9761),
    [sym_fieldgroups_keyword] = ACTIONS(9761),
    [sym_actions_keyword] = ACTIONS(9761),
    [sym_layout_keyword] = ACTIONS(9761),
    [sym_area_keyword] = ACTIONS(9761),
    [sym_group_keyword] = ACTIONS(9761),
    [sym_repeater_keyword] = ACTIONS(9761),
    [sym_cuegroup_keyword] = ACTIONS(9761),
    [sym_fixed_keyword] = ACTIONS(9761),
    [sym_grid_keyword] = ACTIONS(9761),
    [sym_part_keyword] = ACTIONS(9761),
    [sym_systempart_keyword] = ACTIONS(9761),
    [sym_usercontrol_keyword] = ACTIONS(9761),
    [sym_dataset_keyword] = ACTIONS(9761),
    [sym_elements_keyword] = ACTIONS(9761),
    [sym_dataitem_keyword] = ACTIONS(9761),
    [sym_column_keyword] = ACTIONS(9761),
    [sym_filter_keyword] = ACTIONS(9761),
    [sym_labels_keyword] = ACTIONS(9761),
    [sym_rendering_keyword] = ACTIONS(9761),
    [sym_requestpage_keyword] = ACTIONS(9761),
    [sym_schema_keyword] = ACTIONS(9761),
    [sym_views_keyword] = ACTIONS(9761),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9761),
    [sym_preproc_open] = ACTIONS(9761),
    [sym_preproc_close] = ACTIONS(9761),
  },
  [STATE(3798)] = {
    [sym_identifier] = ACTIONS(7805),
    [anon_sym_SEMI] = ACTIONS(7807),
    [anon_sym_RBRACE] = ACTIONS(7807),
    [aux_sym_where_condition_token1] = ACTIONS(7805),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7805),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7805),
    [anon_sym_LBRACK] = ACTIONS(7807),
    [aux_sym_basic_type_token6] = ACTIONS(7805),
    [aux_sym_basic_type_token22] = ACTIONS(7805),
    [aux_sym_basic_type_token53] = ACTIONS(7805),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7805),
    [aux_sym_addafter_modification_token1] = ACTIONS(7805),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7805),
    [aux_sym_modify_modification_token1] = ACTIONS(7805),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7805),
    [aux_sym_movelast_modification_token1] = ACTIONS(7805),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7805),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7805),
    [aux_sym_separator_action_token1] = ACTIONS(7805),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7805),
    [aux_sym_type_declaration_token1] = ACTIONS(7805),
    [anon_sym_POUNDif] = ACTIONS(7807),
    [anon_sym_POUNDIF] = ACTIONS(7807),
    [anon_sym_POUNDIf] = ACTIONS(7807),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7805),
    [sym_trigger_keyword] = ACTIONS(7805),
    [sym_var_keyword] = ACTIONS(7805),
    [sym_local_keyword] = ACTIONS(7805),
    [sym_internal_keyword] = ACTIONS(7805),
    [sym_protected_keyword] = ACTIONS(7805),
    [sym_event_keyword] = ACTIONS(7805),
    [sym_fields_keyword] = ACTIONS(7805),
    [sym_keys_keyword] = ACTIONS(7805),
    [sym_key_keyword] = ACTIONS(7805),
    [sym_fieldgroups_keyword] = ACTIONS(7805),
    [sym_actions_keyword] = ACTIONS(7805),
    [sym_layout_keyword] = ACTIONS(7805),
    [sym_area_keyword] = ACTIONS(7805),
    [sym_group_keyword] = ACTIONS(7805),
    [sym_repeater_keyword] = ACTIONS(7805),
    [sym_cuegroup_keyword] = ACTIONS(7805),
    [sym_fixed_keyword] = ACTIONS(7805),
    [sym_grid_keyword] = ACTIONS(7805),
    [sym_part_keyword] = ACTIONS(7805),
    [sym_systempart_keyword] = ACTIONS(7805),
    [sym_usercontrol_keyword] = ACTIONS(7805),
    [sym_dataset_keyword] = ACTIONS(7805),
    [sym_elements_keyword] = ACTIONS(7805),
    [sym_dataitem_keyword] = ACTIONS(7805),
    [sym_column_keyword] = ACTIONS(7805),
    [sym_filter_keyword] = ACTIONS(7805),
    [sym_labels_keyword] = ACTIONS(7805),
    [sym_rendering_keyword] = ACTIONS(7805),
    [sym_requestpage_keyword] = ACTIONS(7805),
    [sym_schema_keyword] = ACTIONS(7805),
    [sym_views_keyword] = ACTIONS(7805),
    [sym_quoted_identifier] = ACTIONS(7807),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7807),
    [sym_preproc_open] = ACTIONS(7807),
    [sym_var_attribute_open] = ACTIONS(7807),
  },
  [STATE(3799)] = {
    [sym_identifier] = ACTIONS(4411),
    [anon_sym_SEMI] = ACTIONS(4413),
    [anon_sym_RBRACE] = ACTIONS(4413),
    [aux_sym_where_condition_token1] = ACTIONS(4411),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4411),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4411),
    [anon_sym_LBRACK] = ACTIONS(4413),
    [aux_sym_basic_type_token6] = ACTIONS(4411),
    [aux_sym_basic_type_token22] = ACTIONS(4411),
    [aux_sym_basic_type_token53] = ACTIONS(4411),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4411),
    [aux_sym_addafter_modification_token1] = ACTIONS(4411),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4411),
    [aux_sym_modify_modification_token1] = ACTIONS(4411),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4411),
    [aux_sym_movelast_modification_token1] = ACTIONS(4411),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4411),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4411),
    [aux_sym_separator_action_token1] = ACTIONS(4411),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4411),
    [aux_sym_type_declaration_token1] = ACTIONS(4411),
    [anon_sym_POUNDif] = ACTIONS(4413),
    [anon_sym_POUNDIF] = ACTIONS(4413),
    [anon_sym_POUNDIf] = ACTIONS(4413),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4411),
    [sym_trigger_keyword] = ACTIONS(4411),
    [sym_var_keyword] = ACTIONS(4411),
    [sym_local_keyword] = ACTIONS(4411),
    [sym_internal_keyword] = ACTIONS(4411),
    [sym_protected_keyword] = ACTIONS(4411),
    [sym_event_keyword] = ACTIONS(4411),
    [sym_fields_keyword] = ACTIONS(4411),
    [sym_keys_keyword] = ACTIONS(4411),
    [sym_key_keyword] = ACTIONS(4411),
    [sym_fieldgroups_keyword] = ACTIONS(4411),
    [sym_actions_keyword] = ACTIONS(4411),
    [sym_layout_keyword] = ACTIONS(4411),
    [sym_area_keyword] = ACTIONS(4411),
    [sym_group_keyword] = ACTIONS(4411),
    [sym_repeater_keyword] = ACTIONS(4411),
    [sym_cuegroup_keyword] = ACTIONS(4411),
    [sym_fixed_keyword] = ACTIONS(4411),
    [sym_grid_keyword] = ACTIONS(4411),
    [sym_part_keyword] = ACTIONS(4411),
    [sym_systempart_keyword] = ACTIONS(4411),
    [sym_usercontrol_keyword] = ACTIONS(4411),
    [sym_dataset_keyword] = ACTIONS(4411),
    [sym_elements_keyword] = ACTIONS(4411),
    [sym_dataitem_keyword] = ACTIONS(4411),
    [sym_column_keyword] = ACTIONS(4411),
    [sym_filter_keyword] = ACTIONS(4411),
    [sym_labels_keyword] = ACTIONS(4411),
    [sym_rendering_keyword] = ACTIONS(4411),
    [sym_requestpage_keyword] = ACTIONS(4411),
    [sym_schema_keyword] = ACTIONS(4411),
    [sym_views_keyword] = ACTIONS(4411),
    [sym_quoted_identifier] = ACTIONS(4413),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4413),
    [sym_preproc_open] = ACTIONS(4413),
    [sym_var_attribute_open] = ACTIONS(4413),
  },
  [STATE(3800)] = {
    [sym_identifier] = ACTIONS(7359),
    [anon_sym_SEMI] = ACTIONS(7361),
    [anon_sym_RBRACE] = ACTIONS(7361),
    [aux_sym_where_condition_token1] = ACTIONS(7359),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7359),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7361),
    [aux_sym_basic_type_token6] = ACTIONS(7359),
    [aux_sym_basic_type_token22] = ACTIONS(7359),
    [aux_sym_basic_type_token53] = ACTIONS(7359),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7359),
    [aux_sym_addafter_modification_token1] = ACTIONS(7359),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7359),
    [aux_sym_modify_modification_token1] = ACTIONS(7359),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7359),
    [aux_sym_movelast_modification_token1] = ACTIONS(7359),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7359),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7359),
    [aux_sym_separator_action_token1] = ACTIONS(7359),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7359),
    [aux_sym_type_declaration_token1] = ACTIONS(7359),
    [anon_sym_POUNDif] = ACTIONS(7361),
    [anon_sym_POUNDIF] = ACTIONS(7361),
    [anon_sym_POUNDIf] = ACTIONS(7361),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7359),
    [sym_trigger_keyword] = ACTIONS(7359),
    [sym_var_keyword] = ACTIONS(7359),
    [sym_local_keyword] = ACTIONS(7359),
    [sym_internal_keyword] = ACTIONS(7359),
    [sym_protected_keyword] = ACTIONS(7359),
    [sym_event_keyword] = ACTIONS(7359),
    [sym_fields_keyword] = ACTIONS(7359),
    [sym_keys_keyword] = ACTIONS(7359),
    [sym_key_keyword] = ACTIONS(7359),
    [sym_fieldgroups_keyword] = ACTIONS(7359),
    [sym_actions_keyword] = ACTIONS(7359),
    [sym_layout_keyword] = ACTIONS(7359),
    [sym_area_keyword] = ACTIONS(7359),
    [sym_group_keyword] = ACTIONS(7359),
    [sym_repeater_keyword] = ACTIONS(7359),
    [sym_cuegroup_keyword] = ACTIONS(7359),
    [sym_fixed_keyword] = ACTIONS(7359),
    [sym_grid_keyword] = ACTIONS(7359),
    [sym_part_keyword] = ACTIONS(7359),
    [sym_systempart_keyword] = ACTIONS(7359),
    [sym_usercontrol_keyword] = ACTIONS(7359),
    [sym_dataset_keyword] = ACTIONS(7359),
    [sym_elements_keyword] = ACTIONS(7359),
    [sym_dataitem_keyword] = ACTIONS(7359),
    [sym_column_keyword] = ACTIONS(7359),
    [sym_filter_keyword] = ACTIONS(7359),
    [sym_labels_keyword] = ACTIONS(7359),
    [sym_rendering_keyword] = ACTIONS(7359),
    [sym_requestpage_keyword] = ACTIONS(7359),
    [sym_schema_keyword] = ACTIONS(7359),
    [sym_views_keyword] = ACTIONS(7359),
    [sym_quoted_identifier] = ACTIONS(7361),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7361),
    [sym_preproc_open] = ACTIONS(7361),
    [sym_var_attribute_open] = ACTIONS(7361),
  },
  [STATE(3801)] = {
    [sym_identifier] = ACTIONS(7152),
    [anon_sym_SEMI] = ACTIONS(7154),
    [anon_sym_RBRACE] = ACTIONS(7154),
    [aux_sym_where_condition_token1] = ACTIONS(7152),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7152),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7152),
    [anon_sym_LBRACK] = ACTIONS(7154),
    [aux_sym_basic_type_token6] = ACTIONS(7152),
    [aux_sym_basic_type_token22] = ACTIONS(7152),
    [aux_sym_basic_type_token53] = ACTIONS(7152),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7152),
    [aux_sym_addafter_modification_token1] = ACTIONS(7152),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7152),
    [aux_sym_modify_modification_token1] = ACTIONS(7152),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7152),
    [aux_sym_movelast_modification_token1] = ACTIONS(7152),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7152),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7152),
    [aux_sym_separator_action_token1] = ACTIONS(7152),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7152),
    [aux_sym_type_declaration_token1] = ACTIONS(7152),
    [anon_sym_POUNDif] = ACTIONS(7154),
    [anon_sym_POUNDIF] = ACTIONS(7154),
    [anon_sym_POUNDIf] = ACTIONS(7154),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7152),
    [sym_trigger_keyword] = ACTIONS(7152),
    [sym_var_keyword] = ACTIONS(7152),
    [sym_local_keyword] = ACTIONS(7152),
    [sym_internal_keyword] = ACTIONS(7152),
    [sym_protected_keyword] = ACTIONS(7152),
    [sym_event_keyword] = ACTIONS(7152),
    [sym_fields_keyword] = ACTIONS(7152),
    [sym_keys_keyword] = ACTIONS(7152),
    [sym_key_keyword] = ACTIONS(7152),
    [sym_fieldgroups_keyword] = ACTIONS(7152),
    [sym_actions_keyword] = ACTIONS(7152),
    [sym_layout_keyword] = ACTIONS(7152),
    [sym_area_keyword] = ACTIONS(7152),
    [sym_group_keyword] = ACTIONS(7152),
    [sym_repeater_keyword] = ACTIONS(7152),
    [sym_cuegroup_keyword] = ACTIONS(7152),
    [sym_fixed_keyword] = ACTIONS(7152),
    [sym_grid_keyword] = ACTIONS(7152),
    [sym_part_keyword] = ACTIONS(7152),
    [sym_systempart_keyword] = ACTIONS(7152),
    [sym_usercontrol_keyword] = ACTIONS(7152),
    [sym_dataset_keyword] = ACTIONS(7152),
    [sym_elements_keyword] = ACTIONS(7152),
    [sym_dataitem_keyword] = ACTIONS(7152),
    [sym_column_keyword] = ACTIONS(7152),
    [sym_filter_keyword] = ACTIONS(7152),
    [sym_labels_keyword] = ACTIONS(7152),
    [sym_rendering_keyword] = ACTIONS(7152),
    [sym_requestpage_keyword] = ACTIONS(7152),
    [sym_schema_keyword] = ACTIONS(7152),
    [sym_views_keyword] = ACTIONS(7152),
    [sym_quoted_identifier] = ACTIONS(7154),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7154),
    [sym_preproc_open] = ACTIONS(7154),
    [sym_var_attribute_open] = ACTIONS(7154),
  },
  [STATE(3802)] = {
    [sym_preproc_conditional_controladdin] = STATE(3854),
    [sym__body_element] = STATE(3854),
    [sym_empty_statement] = STATE(3854),
    [sym_property] = STATE(3854),
    [sym_fields_section] = STATE(3854),
    [sym_keys_section] = STATE(3854),
    [sym_fieldgroups_section] = STATE(3854),
    [sym_enum_value_declaration] = STATE(3854),
    [sym_labels_section] = STATE(3854),
    [sym_layout_section] = STATE(3854),
    [sym_modify_modification] = STATE(3854),
    [sym_actions_section] = STATE(3854),
    [sym_views_section] = STATE(3854),
    [sym_dataset_section] = STATE(3854),
    [sym_requestpage_section] = STATE(3854),
    [sym_rendering_section] = STATE(3854),
    [sym_elements_section] = STATE(3854),
    [sym_schema_section] = STATE(3854),
    [sym_assembly_declaration] = STATE(3854),
    [sym_event_declaration] = STATE(3854),
    [sym_procedure] = STATE(3854),
    [sym_preproc_split_procedure] = STATE(3854),
    [sym_interface_procedure] = STATE(3854),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3854),
    [sym_var_section] = STATE(3854),
    [sym_attribute_item] = STATE(3854),
    [sym_preproc_conditional] = STATE(3854),
    [sym_preproc_if] = STATE(2633),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3854),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(10150),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10152),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3803)] = {
    [sym_identifier] = ACTIONS(8013),
    [anon_sym_SEMI] = ACTIONS(8015),
    [anon_sym_RBRACE] = ACTIONS(8015),
    [aux_sym_where_condition_token1] = ACTIONS(8013),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8013),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8013),
    [anon_sym_LBRACK] = ACTIONS(8015),
    [aux_sym_basic_type_token6] = ACTIONS(8013),
    [aux_sym_basic_type_token22] = ACTIONS(8013),
    [aux_sym_basic_type_token53] = ACTIONS(8013),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8013),
    [aux_sym_addafter_modification_token1] = ACTIONS(8013),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8013),
    [aux_sym_modify_modification_token1] = ACTIONS(8013),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8013),
    [aux_sym_movelast_modification_token1] = ACTIONS(8013),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8013),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8013),
    [aux_sym_separator_action_token1] = ACTIONS(8013),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8013),
    [aux_sym_type_declaration_token1] = ACTIONS(8013),
    [anon_sym_POUNDif] = ACTIONS(8015),
    [anon_sym_POUNDIF] = ACTIONS(8015),
    [anon_sym_POUNDIf] = ACTIONS(8015),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8013),
    [sym_trigger_keyword] = ACTIONS(8013),
    [sym_var_keyword] = ACTIONS(8013),
    [sym_local_keyword] = ACTIONS(8013),
    [sym_internal_keyword] = ACTIONS(8013),
    [sym_protected_keyword] = ACTIONS(8013),
    [sym_event_keyword] = ACTIONS(8013),
    [sym_fields_keyword] = ACTIONS(8013),
    [sym_keys_keyword] = ACTIONS(8013),
    [sym_key_keyword] = ACTIONS(8013),
    [sym_fieldgroups_keyword] = ACTIONS(8013),
    [sym_actions_keyword] = ACTIONS(8013),
    [sym_layout_keyword] = ACTIONS(8013),
    [sym_area_keyword] = ACTIONS(8013),
    [sym_group_keyword] = ACTIONS(8013),
    [sym_repeater_keyword] = ACTIONS(8013),
    [sym_cuegroup_keyword] = ACTIONS(8013),
    [sym_fixed_keyword] = ACTIONS(8013),
    [sym_grid_keyword] = ACTIONS(8013),
    [sym_part_keyword] = ACTIONS(8013),
    [sym_systempart_keyword] = ACTIONS(8013),
    [sym_usercontrol_keyword] = ACTIONS(8013),
    [sym_dataset_keyword] = ACTIONS(8013),
    [sym_elements_keyword] = ACTIONS(8013),
    [sym_dataitem_keyword] = ACTIONS(8013),
    [sym_column_keyword] = ACTIONS(8013),
    [sym_filter_keyword] = ACTIONS(8013),
    [sym_labels_keyword] = ACTIONS(8013),
    [sym_rendering_keyword] = ACTIONS(8013),
    [sym_requestpage_keyword] = ACTIONS(8013),
    [sym_schema_keyword] = ACTIONS(8013),
    [sym_views_keyword] = ACTIONS(8013),
    [sym_quoted_identifier] = ACTIONS(8015),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8015),
    [sym_preproc_open] = ACTIONS(8015),
    [sym_var_attribute_open] = ACTIONS(8015),
  },
  [STATE(3804)] = {
    [sym_preproc_conditional_controladdin] = STATE(3808),
    [sym__body_element] = STATE(3808),
    [sym_empty_statement] = STATE(3808),
    [sym_property] = STATE(3808),
    [sym_fields_section] = STATE(3808),
    [sym_keys_section] = STATE(3808),
    [sym_fieldgroups_section] = STATE(3808),
    [sym_enum_value_declaration] = STATE(3808),
    [sym_labels_section] = STATE(3808),
    [sym_layout_section] = STATE(3808),
    [sym_modify_modification] = STATE(3808),
    [sym_actions_section] = STATE(3808),
    [sym_views_section] = STATE(3808),
    [sym_dataset_section] = STATE(3808),
    [sym_requestpage_section] = STATE(3808),
    [sym_rendering_section] = STATE(3808),
    [sym_elements_section] = STATE(3808),
    [sym_schema_section] = STATE(3808),
    [sym_assembly_declaration] = STATE(3808),
    [sym_event_declaration] = STATE(3808),
    [sym_procedure] = STATE(3808),
    [sym_preproc_split_procedure] = STATE(3808),
    [sym_interface_procedure] = STATE(3808),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3808),
    [sym_var_section] = STATE(3808),
    [sym_attribute_item] = STATE(3808),
    [sym_preproc_conditional] = STATE(3808),
    [sym_preproc_if] = STATE(2633),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3808),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(10154),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10152),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3805)] = {
    [sym_identifier] = ACTIONS(7941),
    [anon_sym_SEMI] = ACTIONS(7943),
    [anon_sym_RBRACE] = ACTIONS(7943),
    [aux_sym_where_condition_token1] = ACTIONS(7941),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7941),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7941),
    [anon_sym_LBRACK] = ACTIONS(7943),
    [aux_sym_basic_type_token6] = ACTIONS(7941),
    [aux_sym_basic_type_token22] = ACTIONS(7941),
    [aux_sym_basic_type_token53] = ACTIONS(7941),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7941),
    [aux_sym_addafter_modification_token1] = ACTIONS(7941),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7941),
    [aux_sym_modify_modification_token1] = ACTIONS(7941),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7941),
    [aux_sym_movelast_modification_token1] = ACTIONS(7941),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7941),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7941),
    [aux_sym_separator_action_token1] = ACTIONS(7941),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7941),
    [aux_sym_type_declaration_token1] = ACTIONS(7941),
    [anon_sym_POUNDif] = ACTIONS(7943),
    [anon_sym_POUNDIF] = ACTIONS(7943),
    [anon_sym_POUNDIf] = ACTIONS(7943),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7941),
    [sym_trigger_keyword] = ACTIONS(7941),
    [sym_var_keyword] = ACTIONS(7941),
    [sym_local_keyword] = ACTIONS(7941),
    [sym_internal_keyword] = ACTIONS(7941),
    [sym_protected_keyword] = ACTIONS(7941),
    [sym_event_keyword] = ACTIONS(7941),
    [sym_fields_keyword] = ACTIONS(7941),
    [sym_keys_keyword] = ACTIONS(7941),
    [sym_key_keyword] = ACTIONS(7941),
    [sym_fieldgroups_keyword] = ACTIONS(7941),
    [sym_actions_keyword] = ACTIONS(7941),
    [sym_layout_keyword] = ACTIONS(7941),
    [sym_area_keyword] = ACTIONS(7941),
    [sym_group_keyword] = ACTIONS(7941),
    [sym_repeater_keyword] = ACTIONS(7941),
    [sym_cuegroup_keyword] = ACTIONS(7941),
    [sym_fixed_keyword] = ACTIONS(7941),
    [sym_grid_keyword] = ACTIONS(7941),
    [sym_part_keyword] = ACTIONS(7941),
    [sym_systempart_keyword] = ACTIONS(7941),
    [sym_usercontrol_keyword] = ACTIONS(7941),
    [sym_dataset_keyword] = ACTIONS(7941),
    [sym_elements_keyword] = ACTIONS(7941),
    [sym_dataitem_keyword] = ACTIONS(7941),
    [sym_column_keyword] = ACTIONS(7941),
    [sym_filter_keyword] = ACTIONS(7941),
    [sym_labels_keyword] = ACTIONS(7941),
    [sym_rendering_keyword] = ACTIONS(7941),
    [sym_requestpage_keyword] = ACTIONS(7941),
    [sym_schema_keyword] = ACTIONS(7941),
    [sym_views_keyword] = ACTIONS(7941),
    [sym_quoted_identifier] = ACTIONS(7943),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7943),
    [sym_preproc_open] = ACTIONS(7943),
    [sym_var_attribute_open] = ACTIONS(7943),
  },
  [STATE(3806)] = {
    [sym_identifier] = ACTIONS(8263),
    [anon_sym_SEMI] = ACTIONS(8265),
    [anon_sym_RBRACE] = ACTIONS(8265),
    [aux_sym_where_condition_token1] = ACTIONS(8263),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8263),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8263),
    [anon_sym_LBRACK] = ACTIONS(8265),
    [aux_sym_basic_type_token6] = ACTIONS(8263),
    [aux_sym_basic_type_token22] = ACTIONS(8263),
    [aux_sym_basic_type_token53] = ACTIONS(8263),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8263),
    [aux_sym_addafter_modification_token1] = ACTIONS(8263),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8263),
    [aux_sym_modify_modification_token1] = ACTIONS(8263),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8263),
    [aux_sym_movelast_modification_token1] = ACTIONS(8263),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8263),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8263),
    [aux_sym_separator_action_token1] = ACTIONS(8263),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8263),
    [aux_sym_type_declaration_token1] = ACTIONS(8263),
    [anon_sym_POUNDif] = ACTIONS(8265),
    [anon_sym_POUNDIF] = ACTIONS(8265),
    [anon_sym_POUNDIf] = ACTIONS(8265),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8263),
    [sym_trigger_keyword] = ACTIONS(8263),
    [sym_var_keyword] = ACTIONS(8263),
    [sym_local_keyword] = ACTIONS(8263),
    [sym_internal_keyword] = ACTIONS(8263),
    [sym_protected_keyword] = ACTIONS(8263),
    [sym_event_keyword] = ACTIONS(8263),
    [sym_fields_keyword] = ACTIONS(8263),
    [sym_keys_keyword] = ACTIONS(8263),
    [sym_key_keyword] = ACTIONS(8263),
    [sym_fieldgroups_keyword] = ACTIONS(8263),
    [sym_actions_keyword] = ACTIONS(8263),
    [sym_layout_keyword] = ACTIONS(8263),
    [sym_area_keyword] = ACTIONS(8263),
    [sym_group_keyword] = ACTIONS(8263),
    [sym_repeater_keyword] = ACTIONS(8263),
    [sym_cuegroup_keyword] = ACTIONS(8263),
    [sym_fixed_keyword] = ACTIONS(8263),
    [sym_grid_keyword] = ACTIONS(8263),
    [sym_part_keyword] = ACTIONS(8263),
    [sym_systempart_keyword] = ACTIONS(8263),
    [sym_usercontrol_keyword] = ACTIONS(8263),
    [sym_dataset_keyword] = ACTIONS(8263),
    [sym_elements_keyword] = ACTIONS(8263),
    [sym_dataitem_keyword] = ACTIONS(8263),
    [sym_column_keyword] = ACTIONS(8263),
    [sym_filter_keyword] = ACTIONS(8263),
    [sym_labels_keyword] = ACTIONS(8263),
    [sym_rendering_keyword] = ACTIONS(8263),
    [sym_requestpage_keyword] = ACTIONS(8263),
    [sym_schema_keyword] = ACTIONS(8263),
    [sym_views_keyword] = ACTIONS(8263),
    [sym_quoted_identifier] = ACTIONS(8265),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8265),
    [sym_preproc_open] = ACTIONS(8265),
    [sym_var_attribute_open] = ACTIONS(8265),
  },
  [STATE(3807)] = {
    [sym_identifier] = ACTIONS(7166),
    [anon_sym_SEMI] = ACTIONS(7168),
    [anon_sym_RBRACE] = ACTIONS(7168),
    [aux_sym_where_condition_token1] = ACTIONS(7166),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7166),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7166),
    [anon_sym_LBRACK] = ACTIONS(7168),
    [aux_sym_basic_type_token6] = ACTIONS(7166),
    [aux_sym_basic_type_token22] = ACTIONS(7166),
    [aux_sym_basic_type_token53] = ACTIONS(7166),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7166),
    [aux_sym_addafter_modification_token1] = ACTIONS(7166),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7166),
    [aux_sym_modify_modification_token1] = ACTIONS(7166),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7166),
    [aux_sym_movelast_modification_token1] = ACTIONS(7166),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7166),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7166),
    [aux_sym_separator_action_token1] = ACTIONS(7166),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7166),
    [aux_sym_type_declaration_token1] = ACTIONS(7166),
    [anon_sym_POUNDif] = ACTIONS(7168),
    [anon_sym_POUNDIF] = ACTIONS(7168),
    [anon_sym_POUNDIf] = ACTIONS(7168),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7166),
    [sym_trigger_keyword] = ACTIONS(7166),
    [sym_var_keyword] = ACTIONS(7166),
    [sym_local_keyword] = ACTIONS(7166),
    [sym_internal_keyword] = ACTIONS(7166),
    [sym_protected_keyword] = ACTIONS(7166),
    [sym_event_keyword] = ACTIONS(7166),
    [sym_fields_keyword] = ACTIONS(7166),
    [sym_keys_keyword] = ACTIONS(7166),
    [sym_key_keyword] = ACTIONS(7166),
    [sym_fieldgroups_keyword] = ACTIONS(7166),
    [sym_actions_keyword] = ACTIONS(7166),
    [sym_layout_keyword] = ACTIONS(7166),
    [sym_area_keyword] = ACTIONS(7166),
    [sym_group_keyword] = ACTIONS(7166),
    [sym_repeater_keyword] = ACTIONS(7166),
    [sym_cuegroup_keyword] = ACTIONS(7166),
    [sym_fixed_keyword] = ACTIONS(7166),
    [sym_grid_keyword] = ACTIONS(7166),
    [sym_part_keyword] = ACTIONS(7166),
    [sym_systempart_keyword] = ACTIONS(7166),
    [sym_usercontrol_keyword] = ACTIONS(7166),
    [sym_dataset_keyword] = ACTIONS(7166),
    [sym_elements_keyword] = ACTIONS(7166),
    [sym_dataitem_keyword] = ACTIONS(7166),
    [sym_column_keyword] = ACTIONS(7166),
    [sym_filter_keyword] = ACTIONS(7166),
    [sym_labels_keyword] = ACTIONS(7166),
    [sym_rendering_keyword] = ACTIONS(7166),
    [sym_requestpage_keyword] = ACTIONS(7166),
    [sym_schema_keyword] = ACTIONS(7166),
    [sym_views_keyword] = ACTIONS(7166),
    [sym_quoted_identifier] = ACTIONS(7168),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7168),
    [sym_preproc_open] = ACTIONS(7168),
    [sym_var_attribute_open] = ACTIONS(7168),
  },
  [STATE(3808)] = {
    [sym_preproc_conditional_controladdin] = STATE(3867),
    [sym__body_element] = STATE(3867),
    [sym_empty_statement] = STATE(3867),
    [sym_property] = STATE(3867),
    [sym_fields_section] = STATE(3867),
    [sym_keys_section] = STATE(3867),
    [sym_fieldgroups_section] = STATE(3867),
    [sym_enum_value_declaration] = STATE(3867),
    [sym_labels_section] = STATE(3867),
    [sym_layout_section] = STATE(3867),
    [sym_modify_modification] = STATE(3867),
    [sym_actions_section] = STATE(3867),
    [sym_views_section] = STATE(3867),
    [sym_dataset_section] = STATE(3867),
    [sym_requestpage_section] = STATE(3867),
    [sym_rendering_section] = STATE(3867),
    [sym_elements_section] = STATE(3867),
    [sym_schema_section] = STATE(3867),
    [sym_assembly_declaration] = STATE(3867),
    [sym_event_declaration] = STATE(3867),
    [sym_procedure] = STATE(3867),
    [sym_preproc_split_procedure] = STATE(3867),
    [sym_interface_procedure] = STATE(3867),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3867),
    [sym_var_section] = STATE(3867),
    [sym_attribute_item] = STATE(3867),
    [sym_preproc_conditional] = STATE(3867),
    [sym_preproc_if] = STATE(2633),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3867),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(10156),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10152),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3809)] = {
    [sym_identifier] = ACTIONS(7375),
    [anon_sym_SEMI] = ACTIONS(7377),
    [anon_sym_RBRACE] = ACTIONS(7377),
    [aux_sym_where_condition_token1] = ACTIONS(7375),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7375),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7375),
    [anon_sym_LBRACK] = ACTIONS(7377),
    [aux_sym_basic_type_token6] = ACTIONS(7375),
    [aux_sym_basic_type_token22] = ACTIONS(7375),
    [aux_sym_basic_type_token53] = ACTIONS(7375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7375),
    [aux_sym_addafter_modification_token1] = ACTIONS(7375),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7375),
    [aux_sym_modify_modification_token1] = ACTIONS(7375),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7375),
    [aux_sym_movelast_modification_token1] = ACTIONS(7375),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7375),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7375),
    [aux_sym_separator_action_token1] = ACTIONS(7375),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7375),
    [aux_sym_type_declaration_token1] = ACTIONS(7375),
    [anon_sym_POUNDif] = ACTIONS(7377),
    [anon_sym_POUNDIF] = ACTIONS(7377),
    [anon_sym_POUNDIf] = ACTIONS(7377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7375),
    [sym_trigger_keyword] = ACTIONS(7375),
    [sym_var_keyword] = ACTIONS(7375),
    [sym_local_keyword] = ACTIONS(7375),
    [sym_internal_keyword] = ACTIONS(7375),
    [sym_protected_keyword] = ACTIONS(7375),
    [sym_event_keyword] = ACTIONS(7375),
    [sym_fields_keyword] = ACTIONS(7375),
    [sym_keys_keyword] = ACTIONS(7375),
    [sym_key_keyword] = ACTIONS(7375),
    [sym_fieldgroups_keyword] = ACTIONS(7375),
    [sym_actions_keyword] = ACTIONS(7375),
    [sym_layout_keyword] = ACTIONS(7375),
    [sym_area_keyword] = ACTIONS(7375),
    [sym_group_keyword] = ACTIONS(7375),
    [sym_repeater_keyword] = ACTIONS(7375),
    [sym_cuegroup_keyword] = ACTIONS(7375),
    [sym_fixed_keyword] = ACTIONS(7375),
    [sym_grid_keyword] = ACTIONS(7375),
    [sym_part_keyword] = ACTIONS(7375),
    [sym_systempart_keyword] = ACTIONS(7375),
    [sym_usercontrol_keyword] = ACTIONS(7375),
    [sym_dataset_keyword] = ACTIONS(7375),
    [sym_elements_keyword] = ACTIONS(7375),
    [sym_dataitem_keyword] = ACTIONS(7375),
    [sym_column_keyword] = ACTIONS(7375),
    [sym_filter_keyword] = ACTIONS(7375),
    [sym_labels_keyword] = ACTIONS(7375),
    [sym_rendering_keyword] = ACTIONS(7375),
    [sym_requestpage_keyword] = ACTIONS(7375),
    [sym_schema_keyword] = ACTIONS(7375),
    [sym_views_keyword] = ACTIONS(7375),
    [sym_quoted_identifier] = ACTIONS(7377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7377),
    [sym_preproc_open] = ACTIONS(7377),
    [sym_var_attribute_open] = ACTIONS(7377),
  },
  [STATE(3810)] = {
    [sym_identifier] = ACTIONS(7615),
    [anon_sym_SEMI] = ACTIONS(7617),
    [anon_sym_RBRACE] = ACTIONS(7617),
    [aux_sym_where_condition_token1] = ACTIONS(7615),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7615),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7615),
    [anon_sym_LBRACK] = ACTIONS(7617),
    [aux_sym_basic_type_token6] = ACTIONS(7615),
    [aux_sym_basic_type_token22] = ACTIONS(7615),
    [aux_sym_basic_type_token53] = ACTIONS(7615),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7615),
    [aux_sym_addafter_modification_token1] = ACTIONS(7615),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7615),
    [aux_sym_modify_modification_token1] = ACTIONS(7615),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7615),
    [aux_sym_movelast_modification_token1] = ACTIONS(7615),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7615),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7615),
    [aux_sym_separator_action_token1] = ACTIONS(7615),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7615),
    [aux_sym_type_declaration_token1] = ACTIONS(7615),
    [anon_sym_POUNDif] = ACTIONS(7617),
    [anon_sym_POUNDIF] = ACTIONS(7617),
    [anon_sym_POUNDIf] = ACTIONS(7617),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7615),
    [sym_trigger_keyword] = ACTIONS(7615),
    [sym_var_keyword] = ACTIONS(7615),
    [sym_local_keyword] = ACTIONS(7615),
    [sym_internal_keyword] = ACTIONS(7615),
    [sym_protected_keyword] = ACTIONS(7615),
    [sym_event_keyword] = ACTIONS(7615),
    [sym_fields_keyword] = ACTIONS(7615),
    [sym_keys_keyword] = ACTIONS(7615),
    [sym_key_keyword] = ACTIONS(7615),
    [sym_fieldgroups_keyword] = ACTIONS(7615),
    [sym_actions_keyword] = ACTIONS(7615),
    [sym_layout_keyword] = ACTIONS(7615),
    [sym_area_keyword] = ACTIONS(7615),
    [sym_group_keyword] = ACTIONS(7615),
    [sym_repeater_keyword] = ACTIONS(7615),
    [sym_cuegroup_keyword] = ACTIONS(7615),
    [sym_fixed_keyword] = ACTIONS(7615),
    [sym_grid_keyword] = ACTIONS(7615),
    [sym_part_keyword] = ACTIONS(7615),
    [sym_systempart_keyword] = ACTIONS(7615),
    [sym_usercontrol_keyword] = ACTIONS(7615),
    [sym_dataset_keyword] = ACTIONS(7615),
    [sym_elements_keyword] = ACTIONS(7615),
    [sym_dataitem_keyword] = ACTIONS(7615),
    [sym_column_keyword] = ACTIONS(7615),
    [sym_filter_keyword] = ACTIONS(7615),
    [sym_labels_keyword] = ACTIONS(7615),
    [sym_rendering_keyword] = ACTIONS(7615),
    [sym_requestpage_keyword] = ACTIONS(7615),
    [sym_schema_keyword] = ACTIONS(7615),
    [sym_views_keyword] = ACTIONS(7615),
    [sym_quoted_identifier] = ACTIONS(7617),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7617),
    [sym_preproc_open] = ACTIONS(7617),
    [sym_var_attribute_open] = ACTIONS(7617),
  },
  [STATE(3811)] = {
    [sym_identifier] = ACTIONS(7615),
    [anon_sym_SEMI] = ACTIONS(7617),
    [anon_sym_RBRACE] = ACTIONS(7617),
    [aux_sym_where_condition_token1] = ACTIONS(7615),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7615),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7615),
    [anon_sym_LBRACK] = ACTIONS(7617),
    [aux_sym_basic_type_token6] = ACTIONS(7615),
    [aux_sym_basic_type_token22] = ACTIONS(7615),
    [aux_sym_basic_type_token53] = ACTIONS(7615),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7615),
    [aux_sym_addafter_modification_token1] = ACTIONS(7615),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7615),
    [aux_sym_modify_modification_token1] = ACTIONS(7615),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7615),
    [aux_sym_movelast_modification_token1] = ACTIONS(7615),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7615),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7615),
    [aux_sym_separator_action_token1] = ACTIONS(7615),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7615),
    [aux_sym_type_declaration_token1] = ACTIONS(7615),
    [anon_sym_POUNDif] = ACTIONS(7617),
    [anon_sym_POUNDIF] = ACTIONS(7617),
    [anon_sym_POUNDIf] = ACTIONS(7617),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7615),
    [sym_trigger_keyword] = ACTIONS(7615),
    [sym_var_keyword] = ACTIONS(7615),
    [sym_local_keyword] = ACTIONS(7615),
    [sym_internal_keyword] = ACTIONS(7615),
    [sym_protected_keyword] = ACTIONS(7615),
    [sym_event_keyword] = ACTIONS(7615),
    [sym_fields_keyword] = ACTIONS(7615),
    [sym_keys_keyword] = ACTIONS(7615),
    [sym_key_keyword] = ACTIONS(7615),
    [sym_fieldgroups_keyword] = ACTIONS(7615),
    [sym_actions_keyword] = ACTIONS(7615),
    [sym_layout_keyword] = ACTIONS(7615),
    [sym_area_keyword] = ACTIONS(7615),
    [sym_group_keyword] = ACTIONS(7615),
    [sym_repeater_keyword] = ACTIONS(7615),
    [sym_cuegroup_keyword] = ACTIONS(7615),
    [sym_fixed_keyword] = ACTIONS(7615),
    [sym_grid_keyword] = ACTIONS(7615),
    [sym_part_keyword] = ACTIONS(7615),
    [sym_systempart_keyword] = ACTIONS(7615),
    [sym_usercontrol_keyword] = ACTIONS(7615),
    [sym_dataset_keyword] = ACTIONS(7615),
    [sym_elements_keyword] = ACTIONS(7615),
    [sym_dataitem_keyword] = ACTIONS(7615),
    [sym_column_keyword] = ACTIONS(7615),
    [sym_filter_keyword] = ACTIONS(7615),
    [sym_labels_keyword] = ACTIONS(7615),
    [sym_rendering_keyword] = ACTIONS(7615),
    [sym_requestpage_keyword] = ACTIONS(7615),
    [sym_schema_keyword] = ACTIONS(7615),
    [sym_views_keyword] = ACTIONS(7615),
    [sym_quoted_identifier] = ACTIONS(7617),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7617),
    [sym_preproc_open] = ACTIONS(7617),
    [sym_var_attribute_open] = ACTIONS(7617),
  },
  [STATE(3812)] = {
    [sym_identifier] = ACTIONS(4395),
    [anon_sym_SEMI] = ACTIONS(4397),
    [anon_sym_RBRACE] = ACTIONS(4397),
    [aux_sym_where_condition_token1] = ACTIONS(4395),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4395),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4395),
    [anon_sym_LBRACK] = ACTIONS(4397),
    [aux_sym_basic_type_token6] = ACTIONS(4395),
    [aux_sym_basic_type_token22] = ACTIONS(4395),
    [aux_sym_basic_type_token53] = ACTIONS(4395),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4395),
    [aux_sym_addafter_modification_token1] = ACTIONS(4395),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4395),
    [aux_sym_modify_modification_token1] = ACTIONS(4395),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4395),
    [aux_sym_movelast_modification_token1] = ACTIONS(4395),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4395),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4395),
    [aux_sym_separator_action_token1] = ACTIONS(4395),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4395),
    [aux_sym_type_declaration_token1] = ACTIONS(4395),
    [anon_sym_POUNDif] = ACTIONS(4397),
    [anon_sym_POUNDIF] = ACTIONS(4397),
    [anon_sym_POUNDIf] = ACTIONS(4397),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4395),
    [sym_trigger_keyword] = ACTIONS(4395),
    [sym_var_keyword] = ACTIONS(4395),
    [sym_local_keyword] = ACTIONS(4395),
    [sym_internal_keyword] = ACTIONS(4395),
    [sym_protected_keyword] = ACTIONS(4395),
    [sym_event_keyword] = ACTIONS(4395),
    [sym_fields_keyword] = ACTIONS(4395),
    [sym_keys_keyword] = ACTIONS(4395),
    [sym_key_keyword] = ACTIONS(4395),
    [sym_fieldgroups_keyword] = ACTIONS(4395),
    [sym_actions_keyword] = ACTIONS(4395),
    [sym_layout_keyword] = ACTIONS(4395),
    [sym_area_keyword] = ACTIONS(4395),
    [sym_group_keyword] = ACTIONS(4395),
    [sym_repeater_keyword] = ACTIONS(4395),
    [sym_cuegroup_keyword] = ACTIONS(4395),
    [sym_fixed_keyword] = ACTIONS(4395),
    [sym_grid_keyword] = ACTIONS(4395),
    [sym_part_keyword] = ACTIONS(4395),
    [sym_systempart_keyword] = ACTIONS(4395),
    [sym_usercontrol_keyword] = ACTIONS(4395),
    [sym_dataset_keyword] = ACTIONS(4395),
    [sym_elements_keyword] = ACTIONS(4395),
    [sym_dataitem_keyword] = ACTIONS(4395),
    [sym_column_keyword] = ACTIONS(4395),
    [sym_filter_keyword] = ACTIONS(4395),
    [sym_labels_keyword] = ACTIONS(4395),
    [sym_rendering_keyword] = ACTIONS(4395),
    [sym_requestpage_keyword] = ACTIONS(4395),
    [sym_schema_keyword] = ACTIONS(4395),
    [sym_views_keyword] = ACTIONS(4395),
    [sym_quoted_identifier] = ACTIONS(4397),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4397),
    [sym_preproc_open] = ACTIONS(4397),
    [sym_var_attribute_open] = ACTIONS(4397),
  },
  [STATE(3813)] = {
    [sym_preproc_split_procedure_body] = STATE(3760),
    [sym_interface_procedure_suffix] = STATE(6248),
    [sym__procedure_return_specification] = STATE(5407),
    [sym__procedure_named_return] = STATE(5408),
    [sym_code_block] = STATE(3760),
    [sym_preproc_conditional_var_block] = STATE(11000),
    [sym_var_section] = STATE(11000),
    [sym_preproc_if] = STATE(7416),
    [sym__identifier_or_quoted] = STATE(11219),
    [sym_keyword_as_identifier] = STATE(11219),
    [sym_identifier] = ACTIONS(10158),
    [anon_sym_SEMI] = ACTIONS(10160),
    [anon_sym_COLON] = ACTIONS(10162),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(10164),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_modify_modification_token1] = ACTIONS(10166),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10166),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(10168),
    [anon_sym_POUNDif] = ACTIONS(10170),
    [anon_sym_POUNDIF] = ACTIONS(10170),
    [anon_sym_POUNDIf] = ACTIONS(10170),
    [anon_sym_POUNDelif] = ACTIONS(10164),
    [anon_sym_POUNDELIF] = ACTIONS(10164),
    [anon_sym_POUNDElif] = ACTIONS(10164),
    [anon_sym_POUNDelse] = ACTIONS(10164),
    [anon_sym_POUNDELSE] = ACTIONS(10164),
    [anon_sym_POUNDElse] = ACTIONS(10164),
    [anon_sym_POUNDendif] = ACTIONS(10164),
    [anon_sym_POUNDENDIF] = ACTIONS(10164),
    [anon_sym_POUNDEndif] = ACTIONS(10164),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10166),
    [sym_trigger_keyword] = ACTIONS(10166),
    [sym_var_keyword] = ACTIONS(10172),
    [sym_local_keyword] = ACTIONS(10174),
    [sym_internal_keyword] = ACTIONS(10166),
    [sym_protected_keyword] = ACTIONS(10174),
    [sym_event_keyword] = ACTIONS(10166),
    [sym_fields_keyword] = ACTIONS(10166),
    [sym_keys_keyword] = ACTIONS(10166),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(10166),
    [sym_actions_keyword] = ACTIONS(10166),
    [sym_layout_keyword] = ACTIONS(10166),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_elements_keyword] = ACTIONS(10166),
    [sym_labels_keyword] = ACTIONS(10166),
    [sym_rendering_keyword] = ACTIONS(10166),
    [sym_requestpage_keyword] = ACTIONS(10166),
    [sym_schema_keyword] = ACTIONS(10166),
    [sym_views_keyword] = ACTIONS(10166),
    [sym_quoted_identifier] = ACTIONS(10176),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10164),
    [sym_preproc_open] = ACTIONS(10170),
    [sym_preproc_close] = ACTIONS(10164),
    [sym_begin_keyword] = ACTIONS(10178),
  },
  [STATE(3814)] = {
    [sym_identifier] = ACTIONS(4455),
    [anon_sym_SEMI] = ACTIONS(4457),
    [anon_sym_RBRACE] = ACTIONS(4457),
    [aux_sym_where_condition_token1] = ACTIONS(4455),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4455),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4455),
    [anon_sym_LBRACK] = ACTIONS(4457),
    [aux_sym_basic_type_token6] = ACTIONS(4455),
    [aux_sym_basic_type_token22] = ACTIONS(4455),
    [aux_sym_basic_type_token53] = ACTIONS(4455),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4455),
    [aux_sym_addafter_modification_token1] = ACTIONS(4455),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4455),
    [aux_sym_modify_modification_token1] = ACTIONS(4455),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4455),
    [aux_sym_movelast_modification_token1] = ACTIONS(4455),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4455),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [aux_sym_separator_action_token1] = ACTIONS(4455),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4455),
    [aux_sym_type_declaration_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(4457),
    [anon_sym_POUNDIF] = ACTIONS(4457),
    [anon_sym_POUNDIf] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4455),
    [sym_trigger_keyword] = ACTIONS(4455),
    [sym_var_keyword] = ACTIONS(4455),
    [sym_local_keyword] = ACTIONS(4455),
    [sym_internal_keyword] = ACTIONS(4455),
    [sym_protected_keyword] = ACTIONS(4455),
    [sym_event_keyword] = ACTIONS(4455),
    [sym_fields_keyword] = ACTIONS(4455),
    [sym_keys_keyword] = ACTIONS(4455),
    [sym_key_keyword] = ACTIONS(4455),
    [sym_fieldgroups_keyword] = ACTIONS(4455),
    [sym_actions_keyword] = ACTIONS(4455),
    [sym_layout_keyword] = ACTIONS(4455),
    [sym_area_keyword] = ACTIONS(4455),
    [sym_group_keyword] = ACTIONS(4455),
    [sym_repeater_keyword] = ACTIONS(4455),
    [sym_cuegroup_keyword] = ACTIONS(4455),
    [sym_fixed_keyword] = ACTIONS(4455),
    [sym_grid_keyword] = ACTIONS(4455),
    [sym_part_keyword] = ACTIONS(4455),
    [sym_systempart_keyword] = ACTIONS(4455),
    [sym_usercontrol_keyword] = ACTIONS(4455),
    [sym_dataset_keyword] = ACTIONS(4455),
    [sym_elements_keyword] = ACTIONS(4455),
    [sym_dataitem_keyword] = ACTIONS(4455),
    [sym_column_keyword] = ACTIONS(4455),
    [sym_filter_keyword] = ACTIONS(4455),
    [sym_labels_keyword] = ACTIONS(4455),
    [sym_rendering_keyword] = ACTIONS(4455),
    [sym_requestpage_keyword] = ACTIONS(4455),
    [sym_schema_keyword] = ACTIONS(4455),
    [sym_views_keyword] = ACTIONS(4455),
    [sym_quoted_identifier] = ACTIONS(4457),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4457),
    [sym_preproc_open] = ACTIONS(4457),
    [sym_var_attribute_open] = ACTIONS(4457),
  },
  [STATE(3815)] = {
    [sym_identifier] = ACTIONS(7575),
    [anon_sym_SEMI] = ACTIONS(7577),
    [anon_sym_RBRACE] = ACTIONS(7577),
    [aux_sym_where_condition_token1] = ACTIONS(7575),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7575),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7575),
    [anon_sym_LBRACK] = ACTIONS(7577),
    [aux_sym_basic_type_token6] = ACTIONS(7575),
    [aux_sym_basic_type_token22] = ACTIONS(7575),
    [aux_sym_basic_type_token53] = ACTIONS(7575),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7575),
    [aux_sym_addafter_modification_token1] = ACTIONS(7575),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7575),
    [aux_sym_modify_modification_token1] = ACTIONS(7575),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7575),
    [aux_sym_movelast_modification_token1] = ACTIONS(7575),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7575),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7575),
    [aux_sym_separator_action_token1] = ACTIONS(7575),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7575),
    [aux_sym_type_declaration_token1] = ACTIONS(7575),
    [anon_sym_POUNDif] = ACTIONS(7577),
    [anon_sym_POUNDIF] = ACTIONS(7577),
    [anon_sym_POUNDIf] = ACTIONS(7577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7575),
    [sym_trigger_keyword] = ACTIONS(7575),
    [sym_var_keyword] = ACTIONS(7575),
    [sym_local_keyword] = ACTIONS(7575),
    [sym_internal_keyword] = ACTIONS(7575),
    [sym_protected_keyword] = ACTIONS(7575),
    [sym_event_keyword] = ACTIONS(7575),
    [sym_fields_keyword] = ACTIONS(7575),
    [sym_keys_keyword] = ACTIONS(7575),
    [sym_key_keyword] = ACTIONS(7575),
    [sym_fieldgroups_keyword] = ACTIONS(7575),
    [sym_actions_keyword] = ACTIONS(7575),
    [sym_layout_keyword] = ACTIONS(7575),
    [sym_area_keyword] = ACTIONS(7575),
    [sym_group_keyword] = ACTIONS(7575),
    [sym_repeater_keyword] = ACTIONS(7575),
    [sym_cuegroup_keyword] = ACTIONS(7575),
    [sym_fixed_keyword] = ACTIONS(7575),
    [sym_grid_keyword] = ACTIONS(7575),
    [sym_part_keyword] = ACTIONS(7575),
    [sym_systempart_keyword] = ACTIONS(7575),
    [sym_usercontrol_keyword] = ACTIONS(7575),
    [sym_dataset_keyword] = ACTIONS(7575),
    [sym_elements_keyword] = ACTIONS(7575),
    [sym_dataitem_keyword] = ACTIONS(7575),
    [sym_column_keyword] = ACTIONS(7575),
    [sym_filter_keyword] = ACTIONS(7575),
    [sym_labels_keyword] = ACTIONS(7575),
    [sym_rendering_keyword] = ACTIONS(7575),
    [sym_requestpage_keyword] = ACTIONS(7575),
    [sym_schema_keyword] = ACTIONS(7575),
    [sym_views_keyword] = ACTIONS(7575),
    [sym_quoted_identifier] = ACTIONS(7577),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7577),
    [sym_preproc_open] = ACTIONS(7577),
    [sym_var_attribute_open] = ACTIONS(7577),
  },
  [STATE(3816)] = {
    [sym_identifier] = ACTIONS(7575),
    [anon_sym_SEMI] = ACTIONS(7577),
    [anon_sym_RBRACE] = ACTIONS(7577),
    [aux_sym_where_condition_token1] = ACTIONS(7575),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7575),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7575),
    [anon_sym_LBRACK] = ACTIONS(7577),
    [aux_sym_basic_type_token6] = ACTIONS(7575),
    [aux_sym_basic_type_token22] = ACTIONS(7575),
    [aux_sym_basic_type_token53] = ACTIONS(7575),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7575),
    [aux_sym_addafter_modification_token1] = ACTIONS(7575),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7575),
    [aux_sym_modify_modification_token1] = ACTIONS(7575),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7575),
    [aux_sym_movelast_modification_token1] = ACTIONS(7575),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7575),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7575),
    [aux_sym_separator_action_token1] = ACTIONS(7575),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7575),
    [aux_sym_type_declaration_token1] = ACTIONS(7575),
    [anon_sym_POUNDif] = ACTIONS(7577),
    [anon_sym_POUNDIF] = ACTIONS(7577),
    [anon_sym_POUNDIf] = ACTIONS(7577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7575),
    [sym_trigger_keyword] = ACTIONS(7575),
    [sym_var_keyword] = ACTIONS(7575),
    [sym_local_keyword] = ACTIONS(7575),
    [sym_internal_keyword] = ACTIONS(7575),
    [sym_protected_keyword] = ACTIONS(7575),
    [sym_event_keyword] = ACTIONS(7575),
    [sym_fields_keyword] = ACTIONS(7575),
    [sym_keys_keyword] = ACTIONS(7575),
    [sym_key_keyword] = ACTIONS(7575),
    [sym_fieldgroups_keyword] = ACTIONS(7575),
    [sym_actions_keyword] = ACTIONS(7575),
    [sym_layout_keyword] = ACTIONS(7575),
    [sym_area_keyword] = ACTIONS(7575),
    [sym_group_keyword] = ACTIONS(7575),
    [sym_repeater_keyword] = ACTIONS(7575),
    [sym_cuegroup_keyword] = ACTIONS(7575),
    [sym_fixed_keyword] = ACTIONS(7575),
    [sym_grid_keyword] = ACTIONS(7575),
    [sym_part_keyword] = ACTIONS(7575),
    [sym_systempart_keyword] = ACTIONS(7575),
    [sym_usercontrol_keyword] = ACTIONS(7575),
    [sym_dataset_keyword] = ACTIONS(7575),
    [sym_elements_keyword] = ACTIONS(7575),
    [sym_dataitem_keyword] = ACTIONS(7575),
    [sym_column_keyword] = ACTIONS(7575),
    [sym_filter_keyword] = ACTIONS(7575),
    [sym_labels_keyword] = ACTIONS(7575),
    [sym_rendering_keyword] = ACTIONS(7575),
    [sym_requestpage_keyword] = ACTIONS(7575),
    [sym_schema_keyword] = ACTIONS(7575),
    [sym_views_keyword] = ACTIONS(7575),
    [sym_quoted_identifier] = ACTIONS(7577),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7577),
    [sym_preproc_open] = ACTIONS(7577),
    [sym_var_attribute_open] = ACTIONS(7577),
  },
  [STATE(3817)] = {
    [sym_identifier] = ACTIONS(7152),
    [anon_sym_SEMI] = ACTIONS(7154),
    [anon_sym_RBRACE] = ACTIONS(7154),
    [aux_sym_where_condition_token1] = ACTIONS(7152),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7152),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7152),
    [anon_sym_LBRACK] = ACTIONS(7154),
    [aux_sym_basic_type_token6] = ACTIONS(7152),
    [aux_sym_basic_type_token22] = ACTIONS(7152),
    [aux_sym_basic_type_token53] = ACTIONS(7152),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7152),
    [aux_sym_addafter_modification_token1] = ACTIONS(7152),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7152),
    [aux_sym_modify_modification_token1] = ACTIONS(7152),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7152),
    [aux_sym_movelast_modification_token1] = ACTIONS(7152),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7152),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7152),
    [aux_sym_separator_action_token1] = ACTIONS(7152),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7152),
    [aux_sym_type_declaration_token1] = ACTIONS(7152),
    [anon_sym_POUNDif] = ACTIONS(7154),
    [anon_sym_POUNDIF] = ACTIONS(7154),
    [anon_sym_POUNDIf] = ACTIONS(7154),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7152),
    [sym_trigger_keyword] = ACTIONS(7152),
    [sym_var_keyword] = ACTIONS(7152),
    [sym_local_keyword] = ACTIONS(7152),
    [sym_internal_keyword] = ACTIONS(7152),
    [sym_protected_keyword] = ACTIONS(7152),
    [sym_event_keyword] = ACTIONS(7152),
    [sym_fields_keyword] = ACTIONS(7152),
    [sym_keys_keyword] = ACTIONS(7152),
    [sym_key_keyword] = ACTIONS(7152),
    [sym_fieldgroups_keyword] = ACTIONS(7152),
    [sym_actions_keyword] = ACTIONS(7152),
    [sym_layout_keyword] = ACTIONS(7152),
    [sym_area_keyword] = ACTIONS(7152),
    [sym_group_keyword] = ACTIONS(7152),
    [sym_repeater_keyword] = ACTIONS(7152),
    [sym_cuegroup_keyword] = ACTIONS(7152),
    [sym_fixed_keyword] = ACTIONS(7152),
    [sym_grid_keyword] = ACTIONS(7152),
    [sym_part_keyword] = ACTIONS(7152),
    [sym_systempart_keyword] = ACTIONS(7152),
    [sym_usercontrol_keyword] = ACTIONS(7152),
    [sym_dataset_keyword] = ACTIONS(7152),
    [sym_elements_keyword] = ACTIONS(7152),
    [sym_dataitem_keyword] = ACTIONS(7152),
    [sym_column_keyword] = ACTIONS(7152),
    [sym_filter_keyword] = ACTIONS(7152),
    [sym_labels_keyword] = ACTIONS(7152),
    [sym_rendering_keyword] = ACTIONS(7152),
    [sym_requestpage_keyword] = ACTIONS(7152),
    [sym_schema_keyword] = ACTIONS(7152),
    [sym_views_keyword] = ACTIONS(7152),
    [sym_quoted_identifier] = ACTIONS(7154),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7154),
    [sym_preproc_open] = ACTIONS(7154),
    [sym_var_attribute_open] = ACTIONS(7154),
  },
  [STATE(3818)] = {
    [sym_identifier] = ACTIONS(8199),
    [anon_sym_SEMI] = ACTIONS(8201),
    [anon_sym_RBRACE] = ACTIONS(8201),
    [aux_sym_where_condition_token1] = ACTIONS(8199),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8199),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8199),
    [anon_sym_LBRACK] = ACTIONS(8201),
    [aux_sym_basic_type_token6] = ACTIONS(8199),
    [aux_sym_basic_type_token22] = ACTIONS(8199),
    [aux_sym_basic_type_token53] = ACTIONS(8199),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8199),
    [aux_sym_addafter_modification_token1] = ACTIONS(8199),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8199),
    [aux_sym_modify_modification_token1] = ACTIONS(8199),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8199),
    [aux_sym_movelast_modification_token1] = ACTIONS(8199),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8199),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8199),
    [aux_sym_separator_action_token1] = ACTIONS(8199),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8199),
    [aux_sym_type_declaration_token1] = ACTIONS(8199),
    [anon_sym_POUNDif] = ACTIONS(8201),
    [anon_sym_POUNDIF] = ACTIONS(8201),
    [anon_sym_POUNDIf] = ACTIONS(8201),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8199),
    [sym_trigger_keyword] = ACTIONS(8199),
    [sym_var_keyword] = ACTIONS(8199),
    [sym_local_keyword] = ACTIONS(8199),
    [sym_internal_keyword] = ACTIONS(8199),
    [sym_protected_keyword] = ACTIONS(8199),
    [sym_event_keyword] = ACTIONS(8199),
    [sym_fields_keyword] = ACTIONS(8199),
    [sym_keys_keyword] = ACTIONS(8199),
    [sym_key_keyword] = ACTIONS(8199),
    [sym_fieldgroups_keyword] = ACTIONS(8199),
    [sym_actions_keyword] = ACTIONS(8199),
    [sym_layout_keyword] = ACTIONS(8199),
    [sym_area_keyword] = ACTIONS(8199),
    [sym_group_keyword] = ACTIONS(8199),
    [sym_repeater_keyword] = ACTIONS(8199),
    [sym_cuegroup_keyword] = ACTIONS(8199),
    [sym_fixed_keyword] = ACTIONS(8199),
    [sym_grid_keyword] = ACTIONS(8199),
    [sym_part_keyword] = ACTIONS(8199),
    [sym_systempart_keyword] = ACTIONS(8199),
    [sym_usercontrol_keyword] = ACTIONS(8199),
    [sym_dataset_keyword] = ACTIONS(8199),
    [sym_elements_keyword] = ACTIONS(8199),
    [sym_dataitem_keyword] = ACTIONS(8199),
    [sym_column_keyword] = ACTIONS(8199),
    [sym_filter_keyword] = ACTIONS(8199),
    [sym_labels_keyword] = ACTIONS(8199),
    [sym_rendering_keyword] = ACTIONS(8199),
    [sym_requestpage_keyword] = ACTIONS(8199),
    [sym_schema_keyword] = ACTIONS(8199),
    [sym_views_keyword] = ACTIONS(8199),
    [sym_quoted_identifier] = ACTIONS(8201),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8201),
    [sym_preproc_open] = ACTIONS(8201),
    [sym_var_attribute_open] = ACTIONS(8201),
  },
  [STATE(3819)] = {
    [sym_identifier] = ACTIONS(7575),
    [anon_sym_SEMI] = ACTIONS(7577),
    [anon_sym_RBRACE] = ACTIONS(7577),
    [aux_sym_where_condition_token1] = ACTIONS(7575),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7575),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7575),
    [anon_sym_LBRACK] = ACTIONS(7577),
    [aux_sym_basic_type_token6] = ACTIONS(7575),
    [aux_sym_basic_type_token22] = ACTIONS(7575),
    [aux_sym_basic_type_token53] = ACTIONS(7575),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7575),
    [aux_sym_addafter_modification_token1] = ACTIONS(7575),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7575),
    [aux_sym_modify_modification_token1] = ACTIONS(7575),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7575),
    [aux_sym_movelast_modification_token1] = ACTIONS(7575),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7575),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7575),
    [aux_sym_separator_action_token1] = ACTIONS(7575),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7575),
    [aux_sym_type_declaration_token1] = ACTIONS(7575),
    [anon_sym_POUNDif] = ACTIONS(7577),
    [anon_sym_POUNDIF] = ACTIONS(7577),
    [anon_sym_POUNDIf] = ACTIONS(7577),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7575),
    [sym_trigger_keyword] = ACTIONS(7575),
    [sym_var_keyword] = ACTIONS(7575),
    [sym_local_keyword] = ACTIONS(7575),
    [sym_internal_keyword] = ACTIONS(7575),
    [sym_protected_keyword] = ACTIONS(7575),
    [sym_event_keyword] = ACTIONS(7575),
    [sym_fields_keyword] = ACTIONS(7575),
    [sym_keys_keyword] = ACTIONS(7575),
    [sym_key_keyword] = ACTIONS(7575),
    [sym_fieldgroups_keyword] = ACTIONS(7575),
    [sym_actions_keyword] = ACTIONS(7575),
    [sym_layout_keyword] = ACTIONS(7575),
    [sym_area_keyword] = ACTIONS(7575),
    [sym_group_keyword] = ACTIONS(7575),
    [sym_repeater_keyword] = ACTIONS(7575),
    [sym_cuegroup_keyword] = ACTIONS(7575),
    [sym_fixed_keyword] = ACTIONS(7575),
    [sym_grid_keyword] = ACTIONS(7575),
    [sym_part_keyword] = ACTIONS(7575),
    [sym_systempart_keyword] = ACTIONS(7575),
    [sym_usercontrol_keyword] = ACTIONS(7575),
    [sym_dataset_keyword] = ACTIONS(7575),
    [sym_elements_keyword] = ACTIONS(7575),
    [sym_dataitem_keyword] = ACTIONS(7575),
    [sym_column_keyword] = ACTIONS(7575),
    [sym_filter_keyword] = ACTIONS(7575),
    [sym_labels_keyword] = ACTIONS(7575),
    [sym_rendering_keyword] = ACTIONS(7575),
    [sym_requestpage_keyword] = ACTIONS(7575),
    [sym_schema_keyword] = ACTIONS(7575),
    [sym_views_keyword] = ACTIONS(7575),
    [sym_quoted_identifier] = ACTIONS(7577),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7577),
    [sym_preproc_open] = ACTIONS(7577),
    [sym_var_attribute_open] = ACTIONS(7577),
  },
  [STATE(3820)] = {
    [sym_identifier] = ACTIONS(7539),
    [anon_sym_SEMI] = ACTIONS(7541),
    [anon_sym_RBRACE] = ACTIONS(7541),
    [aux_sym_where_condition_token1] = ACTIONS(7539),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7539),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7539),
    [anon_sym_LBRACK] = ACTIONS(7541),
    [aux_sym_basic_type_token6] = ACTIONS(7539),
    [aux_sym_basic_type_token22] = ACTIONS(7539),
    [aux_sym_basic_type_token53] = ACTIONS(7539),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7539),
    [aux_sym_addafter_modification_token1] = ACTIONS(7539),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7539),
    [aux_sym_modify_modification_token1] = ACTIONS(7539),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7539),
    [aux_sym_movelast_modification_token1] = ACTIONS(7539),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7539),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7539),
    [aux_sym_separator_action_token1] = ACTIONS(7539),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7539),
    [aux_sym_type_declaration_token1] = ACTIONS(7539),
    [anon_sym_POUNDif] = ACTIONS(7541),
    [anon_sym_POUNDIF] = ACTIONS(7541),
    [anon_sym_POUNDIf] = ACTIONS(7541),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7539),
    [sym_trigger_keyword] = ACTIONS(7539),
    [sym_var_keyword] = ACTIONS(7539),
    [sym_local_keyword] = ACTIONS(7539),
    [sym_internal_keyword] = ACTIONS(7539),
    [sym_protected_keyword] = ACTIONS(7539),
    [sym_event_keyword] = ACTIONS(7539),
    [sym_fields_keyword] = ACTIONS(7539),
    [sym_keys_keyword] = ACTIONS(7539),
    [sym_key_keyword] = ACTIONS(7539),
    [sym_fieldgroups_keyword] = ACTIONS(7539),
    [sym_actions_keyword] = ACTIONS(7539),
    [sym_layout_keyword] = ACTIONS(7539),
    [sym_area_keyword] = ACTIONS(7539),
    [sym_group_keyword] = ACTIONS(7539),
    [sym_repeater_keyword] = ACTIONS(7539),
    [sym_cuegroup_keyword] = ACTIONS(7539),
    [sym_fixed_keyword] = ACTIONS(7539),
    [sym_grid_keyword] = ACTIONS(7539),
    [sym_part_keyword] = ACTIONS(7539),
    [sym_systempart_keyword] = ACTIONS(7539),
    [sym_usercontrol_keyword] = ACTIONS(7539),
    [sym_dataset_keyword] = ACTIONS(7539),
    [sym_elements_keyword] = ACTIONS(7539),
    [sym_dataitem_keyword] = ACTIONS(7539),
    [sym_column_keyword] = ACTIONS(7539),
    [sym_filter_keyword] = ACTIONS(7539),
    [sym_labels_keyword] = ACTIONS(7539),
    [sym_rendering_keyword] = ACTIONS(7539),
    [sym_requestpage_keyword] = ACTIONS(7539),
    [sym_schema_keyword] = ACTIONS(7539),
    [sym_views_keyword] = ACTIONS(7539),
    [sym_quoted_identifier] = ACTIONS(7541),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7541),
    [sym_preproc_open] = ACTIONS(7541),
    [sym_var_attribute_open] = ACTIONS(7541),
  },
  [STATE(3821)] = {
    [sym_identifier] = ACTIONS(4395),
    [anon_sym_SEMI] = ACTIONS(4397),
    [anon_sym_RBRACE] = ACTIONS(4397),
    [aux_sym_where_condition_token1] = ACTIONS(4395),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4395),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4395),
    [anon_sym_LBRACK] = ACTIONS(4397),
    [aux_sym_basic_type_token6] = ACTIONS(4395),
    [aux_sym_basic_type_token22] = ACTIONS(4395),
    [aux_sym_basic_type_token53] = ACTIONS(4395),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4395),
    [aux_sym_addafter_modification_token1] = ACTIONS(4395),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4395),
    [aux_sym_modify_modification_token1] = ACTIONS(4395),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4395),
    [aux_sym_movelast_modification_token1] = ACTIONS(4395),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4395),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4395),
    [aux_sym_separator_action_token1] = ACTIONS(4395),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4395),
    [aux_sym_type_declaration_token1] = ACTIONS(4395),
    [anon_sym_POUNDif] = ACTIONS(4397),
    [anon_sym_POUNDIF] = ACTIONS(4397),
    [anon_sym_POUNDIf] = ACTIONS(4397),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4395),
    [sym_trigger_keyword] = ACTIONS(4395),
    [sym_var_keyword] = ACTIONS(4395),
    [sym_local_keyword] = ACTIONS(4395),
    [sym_internal_keyword] = ACTIONS(4395),
    [sym_protected_keyword] = ACTIONS(4395),
    [sym_event_keyword] = ACTIONS(4395),
    [sym_fields_keyword] = ACTIONS(4395),
    [sym_keys_keyword] = ACTIONS(4395),
    [sym_key_keyword] = ACTIONS(4395),
    [sym_fieldgroups_keyword] = ACTIONS(4395),
    [sym_actions_keyword] = ACTIONS(4395),
    [sym_layout_keyword] = ACTIONS(4395),
    [sym_area_keyword] = ACTIONS(4395),
    [sym_group_keyword] = ACTIONS(4395),
    [sym_repeater_keyword] = ACTIONS(4395),
    [sym_cuegroup_keyword] = ACTIONS(4395),
    [sym_fixed_keyword] = ACTIONS(4395),
    [sym_grid_keyword] = ACTIONS(4395),
    [sym_part_keyword] = ACTIONS(4395),
    [sym_systempart_keyword] = ACTIONS(4395),
    [sym_usercontrol_keyword] = ACTIONS(4395),
    [sym_dataset_keyword] = ACTIONS(4395),
    [sym_elements_keyword] = ACTIONS(4395),
    [sym_dataitem_keyword] = ACTIONS(4395),
    [sym_column_keyword] = ACTIONS(4395),
    [sym_filter_keyword] = ACTIONS(4395),
    [sym_labels_keyword] = ACTIONS(4395),
    [sym_rendering_keyword] = ACTIONS(4395),
    [sym_requestpage_keyword] = ACTIONS(4395),
    [sym_schema_keyword] = ACTIONS(4395),
    [sym_views_keyword] = ACTIONS(4395),
    [sym_quoted_identifier] = ACTIONS(4397),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4397),
    [sym_preproc_open] = ACTIONS(4397),
    [sym_var_attribute_open] = ACTIONS(4397),
  },
  [STATE(3822)] = {
    [sym_identifier] = ACTIONS(7933),
    [anon_sym_SEMI] = ACTIONS(7935),
    [anon_sym_RBRACE] = ACTIONS(7935),
    [aux_sym_where_condition_token1] = ACTIONS(7933),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7933),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7933),
    [anon_sym_LBRACK] = ACTIONS(7935),
    [aux_sym_basic_type_token6] = ACTIONS(7933),
    [aux_sym_basic_type_token22] = ACTIONS(7933),
    [aux_sym_basic_type_token53] = ACTIONS(7933),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7933),
    [aux_sym_addafter_modification_token1] = ACTIONS(7933),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7933),
    [aux_sym_modify_modification_token1] = ACTIONS(7933),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7933),
    [aux_sym_movelast_modification_token1] = ACTIONS(7933),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7933),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7933),
    [aux_sym_separator_action_token1] = ACTIONS(7933),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7933),
    [aux_sym_type_declaration_token1] = ACTIONS(7933),
    [anon_sym_POUNDif] = ACTIONS(7935),
    [anon_sym_POUNDIF] = ACTIONS(7935),
    [anon_sym_POUNDIf] = ACTIONS(7935),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7933),
    [sym_trigger_keyword] = ACTIONS(7933),
    [sym_var_keyword] = ACTIONS(7933),
    [sym_local_keyword] = ACTIONS(7933),
    [sym_internal_keyword] = ACTIONS(7933),
    [sym_protected_keyword] = ACTIONS(7933),
    [sym_event_keyword] = ACTIONS(7933),
    [sym_fields_keyword] = ACTIONS(7933),
    [sym_keys_keyword] = ACTIONS(7933),
    [sym_key_keyword] = ACTIONS(7933),
    [sym_fieldgroups_keyword] = ACTIONS(7933),
    [sym_actions_keyword] = ACTIONS(7933),
    [sym_layout_keyword] = ACTIONS(7933),
    [sym_area_keyword] = ACTIONS(7933),
    [sym_group_keyword] = ACTIONS(7933),
    [sym_repeater_keyword] = ACTIONS(7933),
    [sym_cuegroup_keyword] = ACTIONS(7933),
    [sym_fixed_keyword] = ACTIONS(7933),
    [sym_grid_keyword] = ACTIONS(7933),
    [sym_part_keyword] = ACTIONS(7933),
    [sym_systempart_keyword] = ACTIONS(7933),
    [sym_usercontrol_keyword] = ACTIONS(7933),
    [sym_dataset_keyword] = ACTIONS(7933),
    [sym_elements_keyword] = ACTIONS(7933),
    [sym_dataitem_keyword] = ACTIONS(7933),
    [sym_column_keyword] = ACTIONS(7933),
    [sym_filter_keyword] = ACTIONS(7933),
    [sym_labels_keyword] = ACTIONS(7933),
    [sym_rendering_keyword] = ACTIONS(7933),
    [sym_requestpage_keyword] = ACTIONS(7933),
    [sym_schema_keyword] = ACTIONS(7933),
    [sym_views_keyword] = ACTIONS(7933),
    [sym_quoted_identifier] = ACTIONS(7935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7935),
    [sym_preproc_open] = ACTIONS(7935),
    [sym_var_attribute_open] = ACTIONS(7935),
  },
  [STATE(3823)] = {
    [sym_identifier] = ACTIONS(7543),
    [anon_sym_SEMI] = ACTIONS(7545),
    [anon_sym_RBRACE] = ACTIONS(7545),
    [aux_sym_where_condition_token1] = ACTIONS(7543),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7543),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7543),
    [anon_sym_LBRACK] = ACTIONS(7545),
    [aux_sym_basic_type_token6] = ACTIONS(7543),
    [aux_sym_basic_type_token22] = ACTIONS(7543),
    [aux_sym_basic_type_token53] = ACTIONS(7543),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7543),
    [aux_sym_addafter_modification_token1] = ACTIONS(7543),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7543),
    [aux_sym_modify_modification_token1] = ACTIONS(7543),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7543),
    [aux_sym_movelast_modification_token1] = ACTIONS(7543),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7543),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7543),
    [aux_sym_separator_action_token1] = ACTIONS(7543),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7543),
    [aux_sym_type_declaration_token1] = ACTIONS(7543),
    [anon_sym_POUNDif] = ACTIONS(7545),
    [anon_sym_POUNDIF] = ACTIONS(7545),
    [anon_sym_POUNDIf] = ACTIONS(7545),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7543),
    [sym_trigger_keyword] = ACTIONS(7543),
    [sym_var_keyword] = ACTIONS(7543),
    [sym_local_keyword] = ACTIONS(7543),
    [sym_internal_keyword] = ACTIONS(7543),
    [sym_protected_keyword] = ACTIONS(7543),
    [sym_event_keyword] = ACTIONS(7543),
    [sym_fields_keyword] = ACTIONS(7543),
    [sym_keys_keyword] = ACTIONS(7543),
    [sym_key_keyword] = ACTIONS(7543),
    [sym_fieldgroups_keyword] = ACTIONS(7543),
    [sym_actions_keyword] = ACTIONS(7543),
    [sym_layout_keyword] = ACTIONS(7543),
    [sym_area_keyword] = ACTIONS(7543),
    [sym_group_keyword] = ACTIONS(7543),
    [sym_repeater_keyword] = ACTIONS(7543),
    [sym_cuegroup_keyword] = ACTIONS(7543),
    [sym_fixed_keyword] = ACTIONS(7543),
    [sym_grid_keyword] = ACTIONS(7543),
    [sym_part_keyword] = ACTIONS(7543),
    [sym_systempart_keyword] = ACTIONS(7543),
    [sym_usercontrol_keyword] = ACTIONS(7543),
    [sym_dataset_keyword] = ACTIONS(7543),
    [sym_elements_keyword] = ACTIONS(7543),
    [sym_dataitem_keyword] = ACTIONS(7543),
    [sym_column_keyword] = ACTIONS(7543),
    [sym_filter_keyword] = ACTIONS(7543),
    [sym_labels_keyword] = ACTIONS(7543),
    [sym_rendering_keyword] = ACTIONS(7543),
    [sym_requestpage_keyword] = ACTIONS(7543),
    [sym_schema_keyword] = ACTIONS(7543),
    [sym_views_keyword] = ACTIONS(7543),
    [sym_quoted_identifier] = ACTIONS(7545),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7545),
    [sym_preproc_open] = ACTIONS(7545),
    [sym_var_attribute_open] = ACTIONS(7545),
  },
  [STATE(3824)] = {
    [sym_identifier] = ACTIONS(8211),
    [anon_sym_SEMI] = ACTIONS(8213),
    [anon_sym_RBRACE] = ACTIONS(8213),
    [aux_sym_where_condition_token1] = ACTIONS(8211),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8211),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8211),
    [anon_sym_LBRACK] = ACTIONS(8213),
    [aux_sym_basic_type_token6] = ACTIONS(8211),
    [aux_sym_basic_type_token22] = ACTIONS(8211),
    [aux_sym_basic_type_token53] = ACTIONS(8211),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8211),
    [aux_sym_addafter_modification_token1] = ACTIONS(8211),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8211),
    [aux_sym_modify_modification_token1] = ACTIONS(8211),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8211),
    [aux_sym_movelast_modification_token1] = ACTIONS(8211),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8211),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8211),
    [aux_sym_separator_action_token1] = ACTIONS(8211),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8211),
    [aux_sym_type_declaration_token1] = ACTIONS(8211),
    [anon_sym_POUNDif] = ACTIONS(8213),
    [anon_sym_POUNDIF] = ACTIONS(8213),
    [anon_sym_POUNDIf] = ACTIONS(8213),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8211),
    [sym_trigger_keyword] = ACTIONS(8211),
    [sym_var_keyword] = ACTIONS(8211),
    [sym_local_keyword] = ACTIONS(8211),
    [sym_internal_keyword] = ACTIONS(8211),
    [sym_protected_keyword] = ACTIONS(8211),
    [sym_event_keyword] = ACTIONS(8211),
    [sym_fields_keyword] = ACTIONS(8211),
    [sym_keys_keyword] = ACTIONS(8211),
    [sym_key_keyword] = ACTIONS(8211),
    [sym_fieldgroups_keyword] = ACTIONS(8211),
    [sym_actions_keyword] = ACTIONS(8211),
    [sym_layout_keyword] = ACTIONS(8211),
    [sym_area_keyword] = ACTIONS(8211),
    [sym_group_keyword] = ACTIONS(8211),
    [sym_repeater_keyword] = ACTIONS(8211),
    [sym_cuegroup_keyword] = ACTIONS(8211),
    [sym_fixed_keyword] = ACTIONS(8211),
    [sym_grid_keyword] = ACTIONS(8211),
    [sym_part_keyword] = ACTIONS(8211),
    [sym_systempart_keyword] = ACTIONS(8211),
    [sym_usercontrol_keyword] = ACTIONS(8211),
    [sym_dataset_keyword] = ACTIONS(8211),
    [sym_elements_keyword] = ACTIONS(8211),
    [sym_dataitem_keyword] = ACTIONS(8211),
    [sym_column_keyword] = ACTIONS(8211),
    [sym_filter_keyword] = ACTIONS(8211),
    [sym_labels_keyword] = ACTIONS(8211),
    [sym_rendering_keyword] = ACTIONS(8211),
    [sym_requestpage_keyword] = ACTIONS(8211),
    [sym_schema_keyword] = ACTIONS(8211),
    [sym_views_keyword] = ACTIONS(8211),
    [sym_quoted_identifier] = ACTIONS(8213),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8213),
    [sym_preproc_open] = ACTIONS(8213),
    [sym_var_attribute_open] = ACTIONS(8213),
  },
  [STATE(3825)] = {
    [sym_identifier] = ACTIONS(7367),
    [anon_sym_SEMI] = ACTIONS(7369),
    [anon_sym_RBRACE] = ACTIONS(7369),
    [aux_sym_where_condition_token1] = ACTIONS(7367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7367),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7367),
    [anon_sym_LBRACK] = ACTIONS(7369),
    [aux_sym_basic_type_token6] = ACTIONS(7367),
    [aux_sym_basic_type_token22] = ACTIONS(7367),
    [aux_sym_basic_type_token53] = ACTIONS(7367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7367),
    [aux_sym_addafter_modification_token1] = ACTIONS(7367),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7367),
    [aux_sym_modify_modification_token1] = ACTIONS(7367),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7367),
    [aux_sym_movelast_modification_token1] = ACTIONS(7367),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7367),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7367),
    [aux_sym_separator_action_token1] = ACTIONS(7367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7367),
    [aux_sym_type_declaration_token1] = ACTIONS(7367),
    [anon_sym_POUNDif] = ACTIONS(7369),
    [anon_sym_POUNDIF] = ACTIONS(7369),
    [anon_sym_POUNDIf] = ACTIONS(7369),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7367),
    [sym_trigger_keyword] = ACTIONS(7367),
    [sym_var_keyword] = ACTIONS(7367),
    [sym_local_keyword] = ACTIONS(7367),
    [sym_internal_keyword] = ACTIONS(7367),
    [sym_protected_keyword] = ACTIONS(7367),
    [sym_event_keyword] = ACTIONS(7367),
    [sym_fields_keyword] = ACTIONS(7367),
    [sym_keys_keyword] = ACTIONS(7367),
    [sym_key_keyword] = ACTIONS(7367),
    [sym_fieldgroups_keyword] = ACTIONS(7367),
    [sym_actions_keyword] = ACTIONS(7367),
    [sym_layout_keyword] = ACTIONS(7367),
    [sym_area_keyword] = ACTIONS(7367),
    [sym_group_keyword] = ACTIONS(7367),
    [sym_repeater_keyword] = ACTIONS(7367),
    [sym_cuegroup_keyword] = ACTIONS(7367),
    [sym_fixed_keyword] = ACTIONS(7367),
    [sym_grid_keyword] = ACTIONS(7367),
    [sym_part_keyword] = ACTIONS(7367),
    [sym_systempart_keyword] = ACTIONS(7367),
    [sym_usercontrol_keyword] = ACTIONS(7367),
    [sym_dataset_keyword] = ACTIONS(7367),
    [sym_elements_keyword] = ACTIONS(7367),
    [sym_dataitem_keyword] = ACTIONS(7367),
    [sym_column_keyword] = ACTIONS(7367),
    [sym_filter_keyword] = ACTIONS(7367),
    [sym_labels_keyword] = ACTIONS(7367),
    [sym_rendering_keyword] = ACTIONS(7367),
    [sym_requestpage_keyword] = ACTIONS(7367),
    [sym_schema_keyword] = ACTIONS(7367),
    [sym_views_keyword] = ACTIONS(7367),
    [sym_quoted_identifier] = ACTIONS(7369),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7369),
    [sym_preproc_open] = ACTIONS(7369),
    [sym_var_attribute_open] = ACTIONS(7369),
  },
  [STATE(3826)] = {
    [sym_identifier] = ACTIONS(4399),
    [anon_sym_SEMI] = ACTIONS(4401),
    [anon_sym_RBRACE] = ACTIONS(4401),
    [aux_sym_where_condition_token1] = ACTIONS(4399),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4399),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4399),
    [anon_sym_LBRACK] = ACTIONS(4401),
    [aux_sym_basic_type_token6] = ACTIONS(4399),
    [aux_sym_basic_type_token22] = ACTIONS(4399),
    [aux_sym_basic_type_token53] = ACTIONS(4399),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4399),
    [aux_sym_addafter_modification_token1] = ACTIONS(4399),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4399),
    [aux_sym_modify_modification_token1] = ACTIONS(4399),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4399),
    [aux_sym_movelast_modification_token1] = ACTIONS(4399),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4399),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4399),
    [aux_sym_separator_action_token1] = ACTIONS(4399),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4399),
    [aux_sym_type_declaration_token1] = ACTIONS(4399),
    [anon_sym_POUNDif] = ACTIONS(4401),
    [anon_sym_POUNDIF] = ACTIONS(4401),
    [anon_sym_POUNDIf] = ACTIONS(4401),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4399),
    [sym_trigger_keyword] = ACTIONS(4399),
    [sym_var_keyword] = ACTIONS(4399),
    [sym_local_keyword] = ACTIONS(4399),
    [sym_internal_keyword] = ACTIONS(4399),
    [sym_protected_keyword] = ACTIONS(4399),
    [sym_event_keyword] = ACTIONS(4399),
    [sym_fields_keyword] = ACTIONS(4399),
    [sym_keys_keyword] = ACTIONS(4399),
    [sym_key_keyword] = ACTIONS(4399),
    [sym_fieldgroups_keyword] = ACTIONS(4399),
    [sym_actions_keyword] = ACTIONS(4399),
    [sym_layout_keyword] = ACTIONS(4399),
    [sym_area_keyword] = ACTIONS(4399),
    [sym_group_keyword] = ACTIONS(4399),
    [sym_repeater_keyword] = ACTIONS(4399),
    [sym_cuegroup_keyword] = ACTIONS(4399),
    [sym_fixed_keyword] = ACTIONS(4399),
    [sym_grid_keyword] = ACTIONS(4399),
    [sym_part_keyword] = ACTIONS(4399),
    [sym_systempart_keyword] = ACTIONS(4399),
    [sym_usercontrol_keyword] = ACTIONS(4399),
    [sym_dataset_keyword] = ACTIONS(4399),
    [sym_elements_keyword] = ACTIONS(4399),
    [sym_dataitem_keyword] = ACTIONS(4399),
    [sym_column_keyword] = ACTIONS(4399),
    [sym_filter_keyword] = ACTIONS(4399),
    [sym_labels_keyword] = ACTIONS(4399),
    [sym_rendering_keyword] = ACTIONS(4399),
    [sym_requestpage_keyword] = ACTIONS(4399),
    [sym_schema_keyword] = ACTIONS(4399),
    [sym_views_keyword] = ACTIONS(4399),
    [sym_quoted_identifier] = ACTIONS(4401),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4401),
    [sym_preproc_open] = ACTIONS(4401),
    [sym_var_attribute_open] = ACTIONS(4401),
  },
  [STATE(3827)] = {
    [sym_identifier] = ACTIONS(4373),
    [anon_sym_SEMI] = ACTIONS(10180),
    [anon_sym_RBRACE] = ACTIONS(4377),
    [aux_sym_where_condition_token1] = ACTIONS(4373),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4373),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4373),
    [anon_sym_LBRACK] = ACTIONS(4377),
    [aux_sym_basic_type_token6] = ACTIONS(4373),
    [aux_sym_basic_type_token22] = ACTIONS(4373),
    [aux_sym_basic_type_token53] = ACTIONS(4373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4373),
    [aux_sym_addafter_modification_token1] = ACTIONS(4373),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4373),
    [aux_sym_modify_modification_token1] = ACTIONS(4373),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4373),
    [aux_sym_movelast_modification_token1] = ACTIONS(4373),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4373),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4373),
    [aux_sym_separator_action_token1] = ACTIONS(4373),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4373),
    [aux_sym_type_declaration_token1] = ACTIONS(4373),
    [anon_sym_POUNDif] = ACTIONS(4377),
    [anon_sym_POUNDIF] = ACTIONS(4377),
    [anon_sym_POUNDIf] = ACTIONS(4377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4373),
    [sym_trigger_keyword] = ACTIONS(4373),
    [sym_var_keyword] = ACTIONS(4373),
    [sym_local_keyword] = ACTIONS(4373),
    [sym_internal_keyword] = ACTIONS(4373),
    [sym_protected_keyword] = ACTIONS(4373),
    [sym_event_keyword] = ACTIONS(4373),
    [sym_fields_keyword] = ACTIONS(4373),
    [sym_keys_keyword] = ACTIONS(4373),
    [sym_key_keyword] = ACTIONS(4373),
    [sym_fieldgroups_keyword] = ACTIONS(4373),
    [sym_actions_keyword] = ACTIONS(4373),
    [sym_layout_keyword] = ACTIONS(4373),
    [sym_area_keyword] = ACTIONS(4373),
    [sym_group_keyword] = ACTIONS(4373),
    [sym_repeater_keyword] = ACTIONS(4373),
    [sym_cuegroup_keyword] = ACTIONS(4373),
    [sym_fixed_keyword] = ACTIONS(4373),
    [sym_grid_keyword] = ACTIONS(4373),
    [sym_part_keyword] = ACTIONS(4373),
    [sym_systempart_keyword] = ACTIONS(4373),
    [sym_usercontrol_keyword] = ACTIONS(4373),
    [sym_dataset_keyword] = ACTIONS(4373),
    [sym_elements_keyword] = ACTIONS(4373),
    [sym_dataitem_keyword] = ACTIONS(4373),
    [sym_column_keyword] = ACTIONS(4373),
    [sym_filter_keyword] = ACTIONS(4373),
    [sym_labels_keyword] = ACTIONS(4373),
    [sym_rendering_keyword] = ACTIONS(4373),
    [sym_requestpage_keyword] = ACTIONS(4373),
    [sym_schema_keyword] = ACTIONS(4373),
    [sym_views_keyword] = ACTIONS(4373),
    [sym_quoted_identifier] = ACTIONS(4377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4377),
    [sym_preproc_open] = ACTIONS(4377),
    [sym_var_attribute_open] = ACTIONS(4377),
  },
  [STATE(3828)] = {
    [sym_preproc_split_procedure_body] = STATE(3760),
    [sym_interface_procedure_suffix] = STATE(6248),
    [sym__procedure_return_specification] = STATE(5412),
    [sym__procedure_named_return] = STATE(5406),
    [sym_code_block] = STATE(3760),
    [sym_preproc_conditional_var_block] = STATE(11000),
    [sym_var_section] = STATE(11000),
    [sym_preproc_if] = STATE(7416),
    [sym__identifier_or_quoted] = STATE(11219),
    [sym_keyword_as_identifier] = STATE(11219),
    [sym_identifier] = ACTIONS(10158),
    [anon_sym_SEMI] = ACTIONS(10160),
    [anon_sym_COLON] = ACTIONS(10162),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(10164),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_modify_modification_token1] = ACTIONS(10166),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10166),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(10168),
    [anon_sym_POUNDif] = ACTIONS(10170),
    [anon_sym_POUNDIF] = ACTIONS(10170),
    [anon_sym_POUNDIf] = ACTIONS(10170),
    [anon_sym_POUNDelif] = ACTIONS(10182),
    [anon_sym_POUNDELIF] = ACTIONS(10182),
    [anon_sym_POUNDElif] = ACTIONS(10182),
    [anon_sym_POUNDelse] = ACTIONS(10182),
    [anon_sym_POUNDELSE] = ACTIONS(10182),
    [anon_sym_POUNDElse] = ACTIONS(10182),
    [anon_sym_POUNDendif] = ACTIONS(10182),
    [anon_sym_POUNDENDIF] = ACTIONS(10182),
    [anon_sym_POUNDEndif] = ACTIONS(10182),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10166),
    [sym_trigger_keyword] = ACTIONS(10166),
    [sym_var_keyword] = ACTIONS(10172),
    [sym_local_keyword] = ACTIONS(10174),
    [sym_internal_keyword] = ACTIONS(10166),
    [sym_protected_keyword] = ACTIONS(10174),
    [sym_event_keyword] = ACTIONS(10166),
    [sym_fields_keyword] = ACTIONS(10166),
    [sym_keys_keyword] = ACTIONS(10166),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(10166),
    [sym_actions_keyword] = ACTIONS(10166),
    [sym_layout_keyword] = ACTIONS(10166),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_elements_keyword] = ACTIONS(10166),
    [sym_labels_keyword] = ACTIONS(10166),
    [sym_rendering_keyword] = ACTIONS(10166),
    [sym_requestpage_keyword] = ACTIONS(10166),
    [sym_schema_keyword] = ACTIONS(10166),
    [sym_views_keyword] = ACTIONS(10166),
    [sym_quoted_identifier] = ACTIONS(10176),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10164),
    [sym_preproc_open] = ACTIONS(10170),
    [sym_preproc_close] = ACTIONS(10182),
    [sym_begin_keyword] = ACTIONS(10178),
  },
  [STATE(3829)] = {
    [sym_identifier] = ACTIONS(4427),
    [anon_sym_SEMI] = ACTIONS(4429),
    [anon_sym_RBRACE] = ACTIONS(4429),
    [aux_sym_where_condition_token1] = ACTIONS(4427),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4427),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4427),
    [anon_sym_LBRACK] = ACTIONS(4429),
    [aux_sym_basic_type_token6] = ACTIONS(4427),
    [aux_sym_basic_type_token22] = ACTIONS(4427),
    [aux_sym_basic_type_token53] = ACTIONS(4427),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4427),
    [aux_sym_addafter_modification_token1] = ACTIONS(4427),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4427),
    [aux_sym_modify_modification_token1] = ACTIONS(4427),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4427),
    [aux_sym_movelast_modification_token1] = ACTIONS(4427),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4427),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4427),
    [aux_sym_separator_action_token1] = ACTIONS(4427),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4427),
    [aux_sym_type_declaration_token1] = ACTIONS(4427),
    [anon_sym_POUNDif] = ACTIONS(4429),
    [anon_sym_POUNDIF] = ACTIONS(4429),
    [anon_sym_POUNDIf] = ACTIONS(4429),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4427),
    [sym_trigger_keyword] = ACTIONS(4427),
    [sym_var_keyword] = ACTIONS(4427),
    [sym_local_keyword] = ACTIONS(4427),
    [sym_internal_keyword] = ACTIONS(4427),
    [sym_protected_keyword] = ACTIONS(4427),
    [sym_event_keyword] = ACTIONS(4427),
    [sym_fields_keyword] = ACTIONS(4427),
    [sym_keys_keyword] = ACTIONS(4427),
    [sym_key_keyword] = ACTIONS(4427),
    [sym_fieldgroups_keyword] = ACTIONS(4427),
    [sym_actions_keyword] = ACTIONS(4427),
    [sym_layout_keyword] = ACTIONS(4427),
    [sym_area_keyword] = ACTIONS(4427),
    [sym_group_keyword] = ACTIONS(4427),
    [sym_repeater_keyword] = ACTIONS(4427),
    [sym_cuegroup_keyword] = ACTIONS(4427),
    [sym_fixed_keyword] = ACTIONS(4427),
    [sym_grid_keyword] = ACTIONS(4427),
    [sym_part_keyword] = ACTIONS(4427),
    [sym_systempart_keyword] = ACTIONS(4427),
    [sym_usercontrol_keyword] = ACTIONS(4427),
    [sym_dataset_keyword] = ACTIONS(4427),
    [sym_elements_keyword] = ACTIONS(4427),
    [sym_dataitem_keyword] = ACTIONS(4427),
    [sym_column_keyword] = ACTIONS(4427),
    [sym_filter_keyword] = ACTIONS(4427),
    [sym_labels_keyword] = ACTIONS(4427),
    [sym_rendering_keyword] = ACTIONS(4427),
    [sym_requestpage_keyword] = ACTIONS(4427),
    [sym_schema_keyword] = ACTIONS(4427),
    [sym_views_keyword] = ACTIONS(4427),
    [sym_quoted_identifier] = ACTIONS(4429),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4429),
    [sym_preproc_open] = ACTIONS(4429),
    [sym_var_attribute_open] = ACTIONS(4429),
  },
  [STATE(3830)] = {
    [sym_identifier] = ACTIONS(4407),
    [anon_sym_SEMI] = ACTIONS(4409),
    [anon_sym_RBRACE] = ACTIONS(4409),
    [aux_sym_where_condition_token1] = ACTIONS(4407),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4407),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4407),
    [anon_sym_LBRACK] = ACTIONS(4409),
    [aux_sym_basic_type_token6] = ACTIONS(4407),
    [aux_sym_basic_type_token22] = ACTIONS(4407),
    [aux_sym_basic_type_token53] = ACTIONS(4407),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4407),
    [aux_sym_addafter_modification_token1] = ACTIONS(4407),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4407),
    [aux_sym_modify_modification_token1] = ACTIONS(4407),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4407),
    [aux_sym_movelast_modification_token1] = ACTIONS(4407),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4407),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4407),
    [aux_sym_separator_action_token1] = ACTIONS(4407),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4407),
    [aux_sym_type_declaration_token1] = ACTIONS(4407),
    [anon_sym_POUNDif] = ACTIONS(4409),
    [anon_sym_POUNDIF] = ACTIONS(4409),
    [anon_sym_POUNDIf] = ACTIONS(4409),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4407),
    [sym_trigger_keyword] = ACTIONS(4407),
    [sym_var_keyword] = ACTIONS(4407),
    [sym_local_keyword] = ACTIONS(4407),
    [sym_internal_keyword] = ACTIONS(4407),
    [sym_protected_keyword] = ACTIONS(4407),
    [sym_event_keyword] = ACTIONS(4407),
    [sym_fields_keyword] = ACTIONS(4407),
    [sym_keys_keyword] = ACTIONS(4407),
    [sym_key_keyword] = ACTIONS(4407),
    [sym_fieldgroups_keyword] = ACTIONS(4407),
    [sym_actions_keyword] = ACTIONS(4407),
    [sym_layout_keyword] = ACTIONS(4407),
    [sym_area_keyword] = ACTIONS(4407),
    [sym_group_keyword] = ACTIONS(4407),
    [sym_repeater_keyword] = ACTIONS(4407),
    [sym_cuegroup_keyword] = ACTIONS(4407),
    [sym_fixed_keyword] = ACTIONS(4407),
    [sym_grid_keyword] = ACTIONS(4407),
    [sym_part_keyword] = ACTIONS(4407),
    [sym_systempart_keyword] = ACTIONS(4407),
    [sym_usercontrol_keyword] = ACTIONS(4407),
    [sym_dataset_keyword] = ACTIONS(4407),
    [sym_elements_keyword] = ACTIONS(4407),
    [sym_dataitem_keyword] = ACTIONS(4407),
    [sym_column_keyword] = ACTIONS(4407),
    [sym_filter_keyword] = ACTIONS(4407),
    [sym_labels_keyword] = ACTIONS(4407),
    [sym_rendering_keyword] = ACTIONS(4407),
    [sym_requestpage_keyword] = ACTIONS(4407),
    [sym_schema_keyword] = ACTIONS(4407),
    [sym_views_keyword] = ACTIONS(4407),
    [sym_quoted_identifier] = ACTIONS(4409),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4409),
    [sym_preproc_open] = ACTIONS(4409),
    [sym_var_attribute_open] = ACTIONS(4409),
  },
  [STATE(3831)] = {
    [sym_identifier] = ACTIONS(4403),
    [anon_sym_SEMI] = ACTIONS(4405),
    [anon_sym_RBRACE] = ACTIONS(4405),
    [aux_sym_where_condition_token1] = ACTIONS(4403),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4403),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4403),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [aux_sym_basic_type_token6] = ACTIONS(4403),
    [aux_sym_basic_type_token22] = ACTIONS(4403),
    [aux_sym_basic_type_token53] = ACTIONS(4403),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4403),
    [aux_sym_addafter_modification_token1] = ACTIONS(4403),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4403),
    [aux_sym_modify_modification_token1] = ACTIONS(4403),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4403),
    [aux_sym_movelast_modification_token1] = ACTIONS(4403),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4403),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4403),
    [aux_sym_separator_action_token1] = ACTIONS(4403),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4403),
    [aux_sym_type_declaration_token1] = ACTIONS(4403),
    [anon_sym_POUNDif] = ACTIONS(4405),
    [anon_sym_POUNDIF] = ACTIONS(4405),
    [anon_sym_POUNDIf] = ACTIONS(4405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4403),
    [sym_trigger_keyword] = ACTIONS(4403),
    [sym_var_keyword] = ACTIONS(4403),
    [sym_local_keyword] = ACTIONS(4403),
    [sym_internal_keyword] = ACTIONS(4403),
    [sym_protected_keyword] = ACTIONS(4403),
    [sym_event_keyword] = ACTIONS(4403),
    [sym_fields_keyword] = ACTIONS(4403),
    [sym_keys_keyword] = ACTIONS(4403),
    [sym_key_keyword] = ACTIONS(4403),
    [sym_fieldgroups_keyword] = ACTIONS(4403),
    [sym_actions_keyword] = ACTIONS(4403),
    [sym_layout_keyword] = ACTIONS(4403),
    [sym_area_keyword] = ACTIONS(4403),
    [sym_group_keyword] = ACTIONS(4403),
    [sym_repeater_keyword] = ACTIONS(4403),
    [sym_cuegroup_keyword] = ACTIONS(4403),
    [sym_fixed_keyword] = ACTIONS(4403),
    [sym_grid_keyword] = ACTIONS(4403),
    [sym_part_keyword] = ACTIONS(4403),
    [sym_systempart_keyword] = ACTIONS(4403),
    [sym_usercontrol_keyword] = ACTIONS(4403),
    [sym_dataset_keyword] = ACTIONS(4403),
    [sym_elements_keyword] = ACTIONS(4403),
    [sym_dataitem_keyword] = ACTIONS(4403),
    [sym_column_keyword] = ACTIONS(4403),
    [sym_filter_keyword] = ACTIONS(4403),
    [sym_labels_keyword] = ACTIONS(4403),
    [sym_rendering_keyword] = ACTIONS(4403),
    [sym_requestpage_keyword] = ACTIONS(4403),
    [sym_schema_keyword] = ACTIONS(4403),
    [sym_views_keyword] = ACTIONS(4403),
    [sym_quoted_identifier] = ACTIONS(4405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4405),
    [sym_preproc_open] = ACTIONS(4405),
    [sym_var_attribute_open] = ACTIONS(4405),
  },
  [STATE(3832)] = {
    [sym_identifier] = ACTIONS(4419),
    [anon_sym_SEMI] = ACTIONS(4421),
    [anon_sym_RBRACE] = ACTIONS(4421),
    [aux_sym_where_condition_token1] = ACTIONS(4419),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4419),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4419),
    [anon_sym_LBRACK] = ACTIONS(4421),
    [aux_sym_basic_type_token6] = ACTIONS(4419),
    [aux_sym_basic_type_token22] = ACTIONS(4419),
    [aux_sym_basic_type_token53] = ACTIONS(4419),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4419),
    [aux_sym_addafter_modification_token1] = ACTIONS(4419),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4419),
    [aux_sym_modify_modification_token1] = ACTIONS(4419),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4419),
    [aux_sym_movelast_modification_token1] = ACTIONS(4419),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4419),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4419),
    [aux_sym_separator_action_token1] = ACTIONS(4419),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4419),
    [aux_sym_type_declaration_token1] = ACTIONS(4419),
    [anon_sym_POUNDif] = ACTIONS(4421),
    [anon_sym_POUNDIF] = ACTIONS(4421),
    [anon_sym_POUNDIf] = ACTIONS(4421),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4419),
    [sym_trigger_keyword] = ACTIONS(4419),
    [sym_var_keyword] = ACTIONS(4419),
    [sym_local_keyword] = ACTIONS(4419),
    [sym_internal_keyword] = ACTIONS(4419),
    [sym_protected_keyword] = ACTIONS(4419),
    [sym_event_keyword] = ACTIONS(4419),
    [sym_fields_keyword] = ACTIONS(4419),
    [sym_keys_keyword] = ACTIONS(4419),
    [sym_key_keyword] = ACTIONS(4419),
    [sym_fieldgroups_keyword] = ACTIONS(4419),
    [sym_actions_keyword] = ACTIONS(4419),
    [sym_layout_keyword] = ACTIONS(4419),
    [sym_area_keyword] = ACTIONS(4419),
    [sym_group_keyword] = ACTIONS(4419),
    [sym_repeater_keyword] = ACTIONS(4419),
    [sym_cuegroup_keyword] = ACTIONS(4419),
    [sym_fixed_keyword] = ACTIONS(4419),
    [sym_grid_keyword] = ACTIONS(4419),
    [sym_part_keyword] = ACTIONS(4419),
    [sym_systempart_keyword] = ACTIONS(4419),
    [sym_usercontrol_keyword] = ACTIONS(4419),
    [sym_dataset_keyword] = ACTIONS(4419),
    [sym_elements_keyword] = ACTIONS(4419),
    [sym_dataitem_keyword] = ACTIONS(4419),
    [sym_column_keyword] = ACTIONS(4419),
    [sym_filter_keyword] = ACTIONS(4419),
    [sym_labels_keyword] = ACTIONS(4419),
    [sym_rendering_keyword] = ACTIONS(4419),
    [sym_requestpage_keyword] = ACTIONS(4419),
    [sym_schema_keyword] = ACTIONS(4419),
    [sym_views_keyword] = ACTIONS(4419),
    [sym_quoted_identifier] = ACTIONS(4421),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4421),
    [sym_preproc_open] = ACTIONS(4421),
    [sym_var_attribute_open] = ACTIONS(4421),
  },
  [STATE(3833)] = {
    [sym_identifier] = ACTIONS(7371),
    [anon_sym_SEMI] = ACTIONS(7373),
    [anon_sym_RBRACE] = ACTIONS(7373),
    [aux_sym_where_condition_token1] = ACTIONS(7371),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7371),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7371),
    [anon_sym_LBRACK] = ACTIONS(7373),
    [aux_sym_basic_type_token6] = ACTIONS(7371),
    [aux_sym_basic_type_token22] = ACTIONS(7371),
    [aux_sym_basic_type_token53] = ACTIONS(7371),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7371),
    [aux_sym_addafter_modification_token1] = ACTIONS(7371),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7371),
    [aux_sym_modify_modification_token1] = ACTIONS(7371),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7371),
    [aux_sym_movelast_modification_token1] = ACTIONS(7371),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7371),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7371),
    [aux_sym_separator_action_token1] = ACTIONS(7371),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7371),
    [aux_sym_type_declaration_token1] = ACTIONS(7371),
    [anon_sym_POUNDif] = ACTIONS(7373),
    [anon_sym_POUNDIF] = ACTIONS(7373),
    [anon_sym_POUNDIf] = ACTIONS(7373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7371),
    [sym_trigger_keyword] = ACTIONS(7371),
    [sym_var_keyword] = ACTIONS(7371),
    [sym_local_keyword] = ACTIONS(7371),
    [sym_internal_keyword] = ACTIONS(7371),
    [sym_protected_keyword] = ACTIONS(7371),
    [sym_event_keyword] = ACTIONS(7371),
    [sym_fields_keyword] = ACTIONS(7371),
    [sym_keys_keyword] = ACTIONS(7371),
    [sym_key_keyword] = ACTIONS(7371),
    [sym_fieldgroups_keyword] = ACTIONS(7371),
    [sym_actions_keyword] = ACTIONS(7371),
    [sym_layout_keyword] = ACTIONS(7371),
    [sym_area_keyword] = ACTIONS(7371),
    [sym_group_keyword] = ACTIONS(7371),
    [sym_repeater_keyword] = ACTIONS(7371),
    [sym_cuegroup_keyword] = ACTIONS(7371),
    [sym_fixed_keyword] = ACTIONS(7371),
    [sym_grid_keyword] = ACTIONS(7371),
    [sym_part_keyword] = ACTIONS(7371),
    [sym_systempart_keyword] = ACTIONS(7371),
    [sym_usercontrol_keyword] = ACTIONS(7371),
    [sym_dataset_keyword] = ACTIONS(7371),
    [sym_elements_keyword] = ACTIONS(7371),
    [sym_dataitem_keyword] = ACTIONS(7371),
    [sym_column_keyword] = ACTIONS(7371),
    [sym_filter_keyword] = ACTIONS(7371),
    [sym_labels_keyword] = ACTIONS(7371),
    [sym_rendering_keyword] = ACTIONS(7371),
    [sym_requestpage_keyword] = ACTIONS(7371),
    [sym_schema_keyword] = ACTIONS(7371),
    [sym_views_keyword] = ACTIONS(7371),
    [sym_quoted_identifier] = ACTIONS(7373),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7373),
    [sym_preproc_open] = ACTIONS(7373),
    [sym_var_attribute_open] = ACTIONS(7373),
  },
  [STATE(3834)] = {
    [sym_identifier] = ACTIONS(8017),
    [anon_sym_SEMI] = ACTIONS(8019),
    [anon_sym_RBRACE] = ACTIONS(8019),
    [aux_sym_where_condition_token1] = ACTIONS(8017),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8017),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8017),
    [anon_sym_LBRACK] = ACTIONS(8019),
    [aux_sym_basic_type_token6] = ACTIONS(8017),
    [aux_sym_basic_type_token22] = ACTIONS(8017),
    [aux_sym_basic_type_token53] = ACTIONS(8017),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8017),
    [aux_sym_addafter_modification_token1] = ACTIONS(8017),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8017),
    [aux_sym_modify_modification_token1] = ACTIONS(8017),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8017),
    [aux_sym_movelast_modification_token1] = ACTIONS(8017),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8017),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8017),
    [aux_sym_separator_action_token1] = ACTIONS(8017),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8017),
    [aux_sym_type_declaration_token1] = ACTIONS(8017),
    [anon_sym_POUNDif] = ACTIONS(8019),
    [anon_sym_POUNDIF] = ACTIONS(8019),
    [anon_sym_POUNDIf] = ACTIONS(8019),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8017),
    [sym_trigger_keyword] = ACTIONS(8017),
    [sym_var_keyword] = ACTIONS(8017),
    [sym_local_keyword] = ACTIONS(8017),
    [sym_internal_keyword] = ACTIONS(8017),
    [sym_protected_keyword] = ACTIONS(8017),
    [sym_event_keyword] = ACTIONS(8017),
    [sym_fields_keyword] = ACTIONS(8017),
    [sym_keys_keyword] = ACTIONS(8017),
    [sym_key_keyword] = ACTIONS(8017),
    [sym_fieldgroups_keyword] = ACTIONS(8017),
    [sym_actions_keyword] = ACTIONS(8017),
    [sym_layout_keyword] = ACTIONS(8017),
    [sym_area_keyword] = ACTIONS(8017),
    [sym_group_keyword] = ACTIONS(8017),
    [sym_repeater_keyword] = ACTIONS(8017),
    [sym_cuegroup_keyword] = ACTIONS(8017),
    [sym_fixed_keyword] = ACTIONS(8017),
    [sym_grid_keyword] = ACTIONS(8017),
    [sym_part_keyword] = ACTIONS(8017),
    [sym_systempart_keyword] = ACTIONS(8017),
    [sym_usercontrol_keyword] = ACTIONS(8017),
    [sym_dataset_keyword] = ACTIONS(8017),
    [sym_elements_keyword] = ACTIONS(8017),
    [sym_dataitem_keyword] = ACTIONS(8017),
    [sym_column_keyword] = ACTIONS(8017),
    [sym_filter_keyword] = ACTIONS(8017),
    [sym_labels_keyword] = ACTIONS(8017),
    [sym_rendering_keyword] = ACTIONS(8017),
    [sym_requestpage_keyword] = ACTIONS(8017),
    [sym_schema_keyword] = ACTIONS(8017),
    [sym_views_keyword] = ACTIONS(8017),
    [sym_quoted_identifier] = ACTIONS(8019),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8019),
    [sym_preproc_open] = ACTIONS(8019),
    [sym_var_attribute_open] = ACTIONS(8019),
  },
  [STATE(3835)] = {
    [sym_identifier] = ACTIONS(4431),
    [anon_sym_SEMI] = ACTIONS(4433),
    [anon_sym_RBRACE] = ACTIONS(4433),
    [aux_sym_where_condition_token1] = ACTIONS(4431),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4431),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4431),
    [anon_sym_LBRACK] = ACTIONS(4433),
    [aux_sym_basic_type_token6] = ACTIONS(4431),
    [aux_sym_basic_type_token22] = ACTIONS(4431),
    [aux_sym_basic_type_token53] = ACTIONS(4431),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4431),
    [aux_sym_addafter_modification_token1] = ACTIONS(4431),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4431),
    [aux_sym_modify_modification_token1] = ACTIONS(4431),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4431),
    [aux_sym_movelast_modification_token1] = ACTIONS(4431),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4431),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4431),
    [aux_sym_separator_action_token1] = ACTIONS(4431),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4431),
    [aux_sym_type_declaration_token1] = ACTIONS(4431),
    [anon_sym_POUNDif] = ACTIONS(4433),
    [anon_sym_POUNDIF] = ACTIONS(4433),
    [anon_sym_POUNDIf] = ACTIONS(4433),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4431),
    [sym_trigger_keyword] = ACTIONS(4431),
    [sym_var_keyword] = ACTIONS(4431),
    [sym_local_keyword] = ACTIONS(4431),
    [sym_internal_keyword] = ACTIONS(4431),
    [sym_protected_keyword] = ACTIONS(4431),
    [sym_event_keyword] = ACTIONS(4431),
    [sym_fields_keyword] = ACTIONS(4431),
    [sym_keys_keyword] = ACTIONS(4431),
    [sym_key_keyword] = ACTIONS(4431),
    [sym_fieldgroups_keyword] = ACTIONS(4431),
    [sym_actions_keyword] = ACTIONS(4431),
    [sym_layout_keyword] = ACTIONS(4431),
    [sym_area_keyword] = ACTIONS(4431),
    [sym_group_keyword] = ACTIONS(4431),
    [sym_repeater_keyword] = ACTIONS(4431),
    [sym_cuegroup_keyword] = ACTIONS(4431),
    [sym_fixed_keyword] = ACTIONS(4431),
    [sym_grid_keyword] = ACTIONS(4431),
    [sym_part_keyword] = ACTIONS(4431),
    [sym_systempart_keyword] = ACTIONS(4431),
    [sym_usercontrol_keyword] = ACTIONS(4431),
    [sym_dataset_keyword] = ACTIONS(4431),
    [sym_elements_keyword] = ACTIONS(4431),
    [sym_dataitem_keyword] = ACTIONS(4431),
    [sym_column_keyword] = ACTIONS(4431),
    [sym_filter_keyword] = ACTIONS(4431),
    [sym_labels_keyword] = ACTIONS(4431),
    [sym_rendering_keyword] = ACTIONS(4431),
    [sym_requestpage_keyword] = ACTIONS(4431),
    [sym_schema_keyword] = ACTIONS(4431),
    [sym_views_keyword] = ACTIONS(4431),
    [sym_quoted_identifier] = ACTIONS(4433),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4433),
    [sym_preproc_open] = ACTIONS(4433),
    [sym_var_attribute_open] = ACTIONS(4433),
  },
  [STATE(3836)] = {
    [sym_identifier] = ACTIONS(7371),
    [anon_sym_SEMI] = ACTIONS(7373),
    [anon_sym_RBRACE] = ACTIONS(7373),
    [aux_sym_where_condition_token1] = ACTIONS(7371),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7371),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7371),
    [anon_sym_LBRACK] = ACTIONS(7373),
    [aux_sym_basic_type_token6] = ACTIONS(7371),
    [aux_sym_basic_type_token22] = ACTIONS(7371),
    [aux_sym_basic_type_token53] = ACTIONS(7371),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7371),
    [aux_sym_addafter_modification_token1] = ACTIONS(7371),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7371),
    [aux_sym_modify_modification_token1] = ACTIONS(7371),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7371),
    [aux_sym_movelast_modification_token1] = ACTIONS(7371),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7371),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7371),
    [aux_sym_separator_action_token1] = ACTIONS(7371),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7371),
    [aux_sym_type_declaration_token1] = ACTIONS(7371),
    [anon_sym_POUNDif] = ACTIONS(7373),
    [anon_sym_POUNDIF] = ACTIONS(7373),
    [anon_sym_POUNDIf] = ACTIONS(7373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7371),
    [sym_trigger_keyword] = ACTIONS(7371),
    [sym_var_keyword] = ACTIONS(7371),
    [sym_local_keyword] = ACTIONS(7371),
    [sym_internal_keyword] = ACTIONS(7371),
    [sym_protected_keyword] = ACTIONS(7371),
    [sym_event_keyword] = ACTIONS(7371),
    [sym_fields_keyword] = ACTIONS(7371),
    [sym_keys_keyword] = ACTIONS(7371),
    [sym_key_keyword] = ACTIONS(7371),
    [sym_fieldgroups_keyword] = ACTIONS(7371),
    [sym_actions_keyword] = ACTIONS(7371),
    [sym_layout_keyword] = ACTIONS(7371),
    [sym_area_keyword] = ACTIONS(7371),
    [sym_group_keyword] = ACTIONS(7371),
    [sym_repeater_keyword] = ACTIONS(7371),
    [sym_cuegroup_keyword] = ACTIONS(7371),
    [sym_fixed_keyword] = ACTIONS(7371),
    [sym_grid_keyword] = ACTIONS(7371),
    [sym_part_keyword] = ACTIONS(7371),
    [sym_systempart_keyword] = ACTIONS(7371),
    [sym_usercontrol_keyword] = ACTIONS(7371),
    [sym_dataset_keyword] = ACTIONS(7371),
    [sym_elements_keyword] = ACTIONS(7371),
    [sym_dataitem_keyword] = ACTIONS(7371),
    [sym_column_keyword] = ACTIONS(7371),
    [sym_filter_keyword] = ACTIONS(7371),
    [sym_labels_keyword] = ACTIONS(7371),
    [sym_rendering_keyword] = ACTIONS(7371),
    [sym_requestpage_keyword] = ACTIONS(7371),
    [sym_schema_keyword] = ACTIONS(7371),
    [sym_views_keyword] = ACTIONS(7371),
    [sym_quoted_identifier] = ACTIONS(7373),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7373),
    [sym_preproc_open] = ACTIONS(7373),
    [sym_var_attribute_open] = ACTIONS(7373),
  },
  [STATE(3837)] = {
    [sym_preproc_split_procedure_body] = STATE(3546),
    [sym_interface_procedure_suffix] = STATE(6250),
    [sym__procedure_return_specification] = STATE(5417),
    [sym__procedure_named_return] = STATE(5418),
    [sym_code_block] = STATE(3546),
    [sym_preproc_conditional_var_block] = STATE(10500),
    [sym_var_section] = STATE(10500),
    [sym_preproc_if] = STATE(7416),
    [sym__identifier_or_quoted] = STATE(11219),
    [sym_keyword_as_identifier] = STATE(11219),
    [sym_identifier] = ACTIONS(10158),
    [anon_sym_SEMI] = ACTIONS(10184),
    [anon_sym_COLON] = ACTIONS(10162),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(10186),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_modify_modification_token1] = ACTIONS(10188),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10188),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(10168),
    [anon_sym_POUNDif] = ACTIONS(10170),
    [anon_sym_POUNDIF] = ACTIONS(10170),
    [anon_sym_POUNDIf] = ACTIONS(10170),
    [anon_sym_POUNDelif] = ACTIONS(10190),
    [anon_sym_POUNDELIF] = ACTIONS(10190),
    [anon_sym_POUNDElif] = ACTIONS(10190),
    [anon_sym_POUNDelse] = ACTIONS(10190),
    [anon_sym_POUNDELSE] = ACTIONS(10190),
    [anon_sym_POUNDElse] = ACTIONS(10190),
    [anon_sym_POUNDendif] = ACTIONS(10190),
    [anon_sym_POUNDENDIF] = ACTIONS(10190),
    [anon_sym_POUNDEndif] = ACTIONS(10190),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10188),
    [sym_trigger_keyword] = ACTIONS(10188),
    [sym_var_keyword] = ACTIONS(10172),
    [sym_local_keyword] = ACTIONS(10174),
    [sym_internal_keyword] = ACTIONS(10188),
    [sym_protected_keyword] = ACTIONS(10174),
    [sym_event_keyword] = ACTIONS(10188),
    [sym_fields_keyword] = ACTIONS(10188),
    [sym_keys_keyword] = ACTIONS(10188),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(10188),
    [sym_actions_keyword] = ACTIONS(10188),
    [sym_layout_keyword] = ACTIONS(10188),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_elements_keyword] = ACTIONS(10188),
    [sym_labels_keyword] = ACTIONS(10188),
    [sym_rendering_keyword] = ACTIONS(10188),
    [sym_requestpage_keyword] = ACTIONS(10188),
    [sym_schema_keyword] = ACTIONS(10188),
    [sym_views_keyword] = ACTIONS(10188),
    [sym_quoted_identifier] = ACTIONS(10176),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10186),
    [sym_preproc_open] = ACTIONS(10170),
    [sym_preproc_close] = ACTIONS(10190),
    [sym_begin_keyword] = ACTIONS(10178),
  },
  [STATE(3838)] = {
    [sym_identifier] = ACTIONS(6976),
    [anon_sym_SEMI] = ACTIONS(6978),
    [anon_sym_RBRACE] = ACTIONS(6978),
    [aux_sym_where_condition_token1] = ACTIONS(6976),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6976),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6976),
    [anon_sym_LBRACK] = ACTIONS(6978),
    [aux_sym_basic_type_token6] = ACTIONS(6976),
    [aux_sym_basic_type_token22] = ACTIONS(6976),
    [aux_sym_basic_type_token53] = ACTIONS(6976),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6976),
    [aux_sym_addafter_modification_token1] = ACTIONS(6976),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6976),
    [aux_sym_modify_modification_token1] = ACTIONS(6976),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6976),
    [aux_sym_movelast_modification_token1] = ACTIONS(6976),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6976),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6976),
    [aux_sym_separator_action_token1] = ACTIONS(6976),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6976),
    [aux_sym_type_declaration_token1] = ACTIONS(6976),
    [anon_sym_POUNDif] = ACTIONS(6978),
    [anon_sym_POUNDIF] = ACTIONS(6978),
    [anon_sym_POUNDIf] = ACTIONS(6978),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6976),
    [sym_trigger_keyword] = ACTIONS(6976),
    [sym_var_keyword] = ACTIONS(6976),
    [sym_local_keyword] = ACTIONS(6976),
    [sym_internal_keyword] = ACTIONS(6976),
    [sym_protected_keyword] = ACTIONS(6976),
    [sym_event_keyword] = ACTIONS(6976),
    [sym_fields_keyword] = ACTIONS(6976),
    [sym_keys_keyword] = ACTIONS(6976),
    [sym_key_keyword] = ACTIONS(6976),
    [sym_fieldgroups_keyword] = ACTIONS(6976),
    [sym_actions_keyword] = ACTIONS(6976),
    [sym_layout_keyword] = ACTIONS(6976),
    [sym_area_keyword] = ACTIONS(6976),
    [sym_group_keyword] = ACTIONS(6976),
    [sym_repeater_keyword] = ACTIONS(6976),
    [sym_cuegroup_keyword] = ACTIONS(6976),
    [sym_fixed_keyword] = ACTIONS(6976),
    [sym_grid_keyword] = ACTIONS(6976),
    [sym_part_keyword] = ACTIONS(6976),
    [sym_systempart_keyword] = ACTIONS(6976),
    [sym_usercontrol_keyword] = ACTIONS(6976),
    [sym_dataset_keyword] = ACTIONS(6976),
    [sym_elements_keyword] = ACTIONS(6976),
    [sym_dataitem_keyword] = ACTIONS(6976),
    [sym_column_keyword] = ACTIONS(6976),
    [sym_filter_keyword] = ACTIONS(6976),
    [sym_labels_keyword] = ACTIONS(6976),
    [sym_rendering_keyword] = ACTIONS(6976),
    [sym_requestpage_keyword] = ACTIONS(6976),
    [sym_schema_keyword] = ACTIONS(6976),
    [sym_views_keyword] = ACTIONS(6976),
    [sym_quoted_identifier] = ACTIONS(6978),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6978),
    [sym_preproc_open] = ACTIONS(6978),
    [sym_var_attribute_open] = ACTIONS(6978),
  },
  [STATE(3839)] = {
    [sym_preproc_split_procedure_body] = STATE(3546),
    [sym_interface_procedure_suffix] = STATE(6250),
    [sym__procedure_return_specification] = STATE(5414),
    [sym__procedure_named_return] = STATE(5410),
    [sym_code_block] = STATE(3546),
    [sym_preproc_conditional_var_block] = STATE(10500),
    [sym_var_section] = STATE(10500),
    [sym_preproc_if] = STATE(7416),
    [sym__identifier_or_quoted] = STATE(11219),
    [sym_keyword_as_identifier] = STATE(11219),
    [sym_identifier] = ACTIONS(10158),
    [anon_sym_SEMI] = ACTIONS(10184),
    [anon_sym_COLON] = ACTIONS(10162),
    [aux_sym_where_condition_token1] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(10186),
    [aux_sym_basic_type_token22] = ACTIONS(2209),
    [aux_sym_basic_type_token53] = ACTIONS(2209),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2209),
    [aux_sym_modify_modification_token1] = ACTIONS(10188),
    [aux_sym_separator_action_token1] = ACTIONS(2209),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10188),
    [aux_sym_type_declaration_token1] = ACTIONS(2209),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(10168),
    [anon_sym_POUNDif] = ACTIONS(10170),
    [anon_sym_POUNDIF] = ACTIONS(10170),
    [anon_sym_POUNDIf] = ACTIONS(10170),
    [anon_sym_POUNDelif] = ACTIONS(10186),
    [anon_sym_POUNDELIF] = ACTIONS(10186),
    [anon_sym_POUNDElif] = ACTIONS(10186),
    [anon_sym_POUNDelse] = ACTIONS(10186),
    [anon_sym_POUNDELSE] = ACTIONS(10186),
    [anon_sym_POUNDElse] = ACTIONS(10186),
    [anon_sym_POUNDendif] = ACTIONS(10186),
    [anon_sym_POUNDENDIF] = ACTIONS(10186),
    [anon_sym_POUNDEndif] = ACTIONS(10186),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10188),
    [sym_trigger_keyword] = ACTIONS(10188),
    [sym_var_keyword] = ACTIONS(10172),
    [sym_local_keyword] = ACTIONS(10174),
    [sym_internal_keyword] = ACTIONS(10188),
    [sym_protected_keyword] = ACTIONS(10174),
    [sym_event_keyword] = ACTIONS(10188),
    [sym_fields_keyword] = ACTIONS(10188),
    [sym_keys_keyword] = ACTIONS(10188),
    [sym_key_keyword] = ACTIONS(2209),
    [sym_fieldgroups_keyword] = ACTIONS(10188),
    [sym_actions_keyword] = ACTIONS(10188),
    [sym_layout_keyword] = ACTIONS(10188),
    [sym_dataset_keyword] = ACTIONS(2209),
    [sym_elements_keyword] = ACTIONS(10188),
    [sym_labels_keyword] = ACTIONS(10188),
    [sym_rendering_keyword] = ACTIONS(10188),
    [sym_requestpage_keyword] = ACTIONS(10188),
    [sym_schema_keyword] = ACTIONS(10188),
    [sym_views_keyword] = ACTIONS(10188),
    [sym_quoted_identifier] = ACTIONS(10176),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10186),
    [sym_preproc_open] = ACTIONS(10170),
    [sym_preproc_close] = ACTIONS(10186),
    [sym_begin_keyword] = ACTIONS(10178),
  },
  [STATE(3840)] = {
    [sym_identifier] = ACTIONS(8235),
    [anon_sym_SEMI] = ACTIONS(8237),
    [anon_sym_RBRACE] = ACTIONS(8237),
    [aux_sym_where_condition_token1] = ACTIONS(8235),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8235),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8235),
    [anon_sym_LBRACK] = ACTIONS(8237),
    [aux_sym_basic_type_token6] = ACTIONS(8235),
    [aux_sym_basic_type_token22] = ACTIONS(8235),
    [aux_sym_basic_type_token53] = ACTIONS(8235),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8235),
    [aux_sym_addafter_modification_token1] = ACTIONS(8235),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8235),
    [aux_sym_modify_modification_token1] = ACTIONS(8235),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8235),
    [aux_sym_movelast_modification_token1] = ACTIONS(8235),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8235),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8235),
    [aux_sym_separator_action_token1] = ACTIONS(8235),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8235),
    [aux_sym_type_declaration_token1] = ACTIONS(8235),
    [anon_sym_POUNDif] = ACTIONS(8237),
    [anon_sym_POUNDIF] = ACTIONS(8237),
    [anon_sym_POUNDIf] = ACTIONS(8237),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8235),
    [sym_trigger_keyword] = ACTIONS(8235),
    [sym_var_keyword] = ACTIONS(8235),
    [sym_local_keyword] = ACTIONS(8235),
    [sym_internal_keyword] = ACTIONS(8235),
    [sym_protected_keyword] = ACTIONS(8235),
    [sym_event_keyword] = ACTIONS(8235),
    [sym_fields_keyword] = ACTIONS(8235),
    [sym_keys_keyword] = ACTIONS(8235),
    [sym_key_keyword] = ACTIONS(8235),
    [sym_fieldgroups_keyword] = ACTIONS(8235),
    [sym_actions_keyword] = ACTIONS(8235),
    [sym_layout_keyword] = ACTIONS(8235),
    [sym_area_keyword] = ACTIONS(8235),
    [sym_group_keyword] = ACTIONS(8235),
    [sym_repeater_keyword] = ACTIONS(8235),
    [sym_cuegroup_keyword] = ACTIONS(8235),
    [sym_fixed_keyword] = ACTIONS(8235),
    [sym_grid_keyword] = ACTIONS(8235),
    [sym_part_keyword] = ACTIONS(8235),
    [sym_systempart_keyword] = ACTIONS(8235),
    [sym_usercontrol_keyword] = ACTIONS(8235),
    [sym_dataset_keyword] = ACTIONS(8235),
    [sym_elements_keyword] = ACTIONS(8235),
    [sym_dataitem_keyword] = ACTIONS(8235),
    [sym_column_keyword] = ACTIONS(8235),
    [sym_filter_keyword] = ACTIONS(8235),
    [sym_labels_keyword] = ACTIONS(8235),
    [sym_rendering_keyword] = ACTIONS(8235),
    [sym_requestpage_keyword] = ACTIONS(8235),
    [sym_schema_keyword] = ACTIONS(8235),
    [sym_views_keyword] = ACTIONS(8235),
    [sym_quoted_identifier] = ACTIONS(8237),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8237),
    [sym_preproc_open] = ACTIONS(8237),
    [sym_var_attribute_open] = ACTIONS(8237),
  },
  [STATE(3841)] = {
    [sym_identifier] = ACTIONS(4415),
    [anon_sym_SEMI] = ACTIONS(4417),
    [anon_sym_RBRACE] = ACTIONS(4417),
    [aux_sym_where_condition_token1] = ACTIONS(4415),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4415),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4415),
    [anon_sym_LBRACK] = ACTIONS(4417),
    [aux_sym_basic_type_token6] = ACTIONS(4415),
    [aux_sym_basic_type_token22] = ACTIONS(4415),
    [aux_sym_basic_type_token53] = ACTIONS(4415),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4415),
    [aux_sym_addafter_modification_token1] = ACTIONS(4415),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4415),
    [aux_sym_modify_modification_token1] = ACTIONS(4415),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4415),
    [aux_sym_movelast_modification_token1] = ACTIONS(4415),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4415),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4415),
    [aux_sym_separator_action_token1] = ACTIONS(4415),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4415),
    [aux_sym_type_declaration_token1] = ACTIONS(4415),
    [anon_sym_POUNDif] = ACTIONS(4417),
    [anon_sym_POUNDIF] = ACTIONS(4417),
    [anon_sym_POUNDIf] = ACTIONS(4417),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4415),
    [sym_trigger_keyword] = ACTIONS(4415),
    [sym_var_keyword] = ACTIONS(4415),
    [sym_local_keyword] = ACTIONS(4415),
    [sym_internal_keyword] = ACTIONS(4415),
    [sym_protected_keyword] = ACTIONS(4415),
    [sym_event_keyword] = ACTIONS(4415),
    [sym_fields_keyword] = ACTIONS(4415),
    [sym_keys_keyword] = ACTIONS(4415),
    [sym_key_keyword] = ACTIONS(4415),
    [sym_fieldgroups_keyword] = ACTIONS(4415),
    [sym_actions_keyword] = ACTIONS(4415),
    [sym_layout_keyword] = ACTIONS(4415),
    [sym_area_keyword] = ACTIONS(4415),
    [sym_group_keyword] = ACTIONS(4415),
    [sym_repeater_keyword] = ACTIONS(4415),
    [sym_cuegroup_keyword] = ACTIONS(4415),
    [sym_fixed_keyword] = ACTIONS(4415),
    [sym_grid_keyword] = ACTIONS(4415),
    [sym_part_keyword] = ACTIONS(4415),
    [sym_systempart_keyword] = ACTIONS(4415),
    [sym_usercontrol_keyword] = ACTIONS(4415),
    [sym_dataset_keyword] = ACTIONS(4415),
    [sym_elements_keyword] = ACTIONS(4415),
    [sym_dataitem_keyword] = ACTIONS(4415),
    [sym_column_keyword] = ACTIONS(4415),
    [sym_filter_keyword] = ACTIONS(4415),
    [sym_labels_keyword] = ACTIONS(4415),
    [sym_rendering_keyword] = ACTIONS(4415),
    [sym_requestpage_keyword] = ACTIONS(4415),
    [sym_schema_keyword] = ACTIONS(4415),
    [sym_views_keyword] = ACTIONS(4415),
    [sym_quoted_identifier] = ACTIONS(4417),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4417),
    [sym_preproc_open] = ACTIONS(4417),
    [sym_var_attribute_open] = ACTIONS(4417),
  },
  [STATE(3842)] = {
    [sym_identifier] = ACTIONS(8471),
    [anon_sym_SEMI] = ACTIONS(8473),
    [anon_sym_RBRACE] = ACTIONS(8473),
    [aux_sym_where_condition_token1] = ACTIONS(8471),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8471),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8471),
    [anon_sym_LBRACK] = ACTIONS(8473),
    [aux_sym_basic_type_token6] = ACTIONS(8471),
    [aux_sym_basic_type_token22] = ACTIONS(8471),
    [aux_sym_basic_type_token53] = ACTIONS(8471),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8471),
    [aux_sym_addafter_modification_token1] = ACTIONS(8471),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8471),
    [aux_sym_modify_modification_token1] = ACTIONS(8471),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8471),
    [aux_sym_movelast_modification_token1] = ACTIONS(8471),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8471),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8471),
    [aux_sym_separator_action_token1] = ACTIONS(8471),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8471),
    [aux_sym_type_declaration_token1] = ACTIONS(8471),
    [anon_sym_POUNDif] = ACTIONS(8473),
    [anon_sym_POUNDIF] = ACTIONS(8473),
    [anon_sym_POUNDIf] = ACTIONS(8473),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8471),
    [sym_trigger_keyword] = ACTIONS(8471),
    [sym_var_keyword] = ACTIONS(8471),
    [sym_local_keyword] = ACTIONS(8471),
    [sym_internal_keyword] = ACTIONS(8471),
    [sym_protected_keyword] = ACTIONS(8471),
    [sym_event_keyword] = ACTIONS(8471),
    [sym_fields_keyword] = ACTIONS(8471),
    [sym_keys_keyword] = ACTIONS(8471),
    [sym_key_keyword] = ACTIONS(8471),
    [sym_fieldgroups_keyword] = ACTIONS(8471),
    [sym_actions_keyword] = ACTIONS(8471),
    [sym_layout_keyword] = ACTIONS(8471),
    [sym_area_keyword] = ACTIONS(8471),
    [sym_group_keyword] = ACTIONS(8471),
    [sym_repeater_keyword] = ACTIONS(8471),
    [sym_cuegroup_keyword] = ACTIONS(8471),
    [sym_fixed_keyword] = ACTIONS(8471),
    [sym_grid_keyword] = ACTIONS(8471),
    [sym_part_keyword] = ACTIONS(8471),
    [sym_systempart_keyword] = ACTIONS(8471),
    [sym_usercontrol_keyword] = ACTIONS(8471),
    [sym_dataset_keyword] = ACTIONS(8471),
    [sym_elements_keyword] = ACTIONS(8471),
    [sym_dataitem_keyword] = ACTIONS(8471),
    [sym_column_keyword] = ACTIONS(8471),
    [sym_filter_keyword] = ACTIONS(8471),
    [sym_labels_keyword] = ACTIONS(8471),
    [sym_rendering_keyword] = ACTIONS(8471),
    [sym_requestpage_keyword] = ACTIONS(8471),
    [sym_schema_keyword] = ACTIONS(8471),
    [sym_views_keyword] = ACTIONS(8471),
    [sym_quoted_identifier] = ACTIONS(8473),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8473),
    [sym_preproc_open] = ACTIONS(8473),
    [sym_var_attribute_open] = ACTIONS(8473),
  },
  [STATE(3843)] = {
    [sym_identifier] = ACTIONS(6976),
    [anon_sym_SEMI] = ACTIONS(6978),
    [anon_sym_RBRACE] = ACTIONS(6978),
    [aux_sym_where_condition_token1] = ACTIONS(6976),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6976),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6976),
    [anon_sym_LBRACK] = ACTIONS(6978),
    [aux_sym_basic_type_token6] = ACTIONS(6976),
    [aux_sym_basic_type_token22] = ACTIONS(6976),
    [aux_sym_basic_type_token53] = ACTIONS(6976),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6976),
    [aux_sym_addafter_modification_token1] = ACTIONS(6976),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6976),
    [aux_sym_modify_modification_token1] = ACTIONS(6976),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6976),
    [aux_sym_movelast_modification_token1] = ACTIONS(6976),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6976),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6976),
    [aux_sym_separator_action_token1] = ACTIONS(6976),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6976),
    [aux_sym_type_declaration_token1] = ACTIONS(6976),
    [anon_sym_POUNDif] = ACTIONS(6978),
    [anon_sym_POUNDIF] = ACTIONS(6978),
    [anon_sym_POUNDIf] = ACTIONS(6978),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6976),
    [sym_trigger_keyword] = ACTIONS(6976),
    [sym_var_keyword] = ACTIONS(6976),
    [sym_local_keyword] = ACTIONS(6976),
    [sym_internal_keyword] = ACTIONS(6976),
    [sym_protected_keyword] = ACTIONS(6976),
    [sym_event_keyword] = ACTIONS(6976),
    [sym_fields_keyword] = ACTIONS(6976),
    [sym_keys_keyword] = ACTIONS(6976),
    [sym_key_keyword] = ACTIONS(6976),
    [sym_fieldgroups_keyword] = ACTIONS(6976),
    [sym_actions_keyword] = ACTIONS(6976),
    [sym_layout_keyword] = ACTIONS(6976),
    [sym_area_keyword] = ACTIONS(6976),
    [sym_group_keyword] = ACTIONS(6976),
    [sym_repeater_keyword] = ACTIONS(6976),
    [sym_cuegroup_keyword] = ACTIONS(6976),
    [sym_fixed_keyword] = ACTIONS(6976),
    [sym_grid_keyword] = ACTIONS(6976),
    [sym_part_keyword] = ACTIONS(6976),
    [sym_systempart_keyword] = ACTIONS(6976),
    [sym_usercontrol_keyword] = ACTIONS(6976),
    [sym_dataset_keyword] = ACTIONS(6976),
    [sym_elements_keyword] = ACTIONS(6976),
    [sym_dataitem_keyword] = ACTIONS(6976),
    [sym_column_keyword] = ACTIONS(6976),
    [sym_filter_keyword] = ACTIONS(6976),
    [sym_labels_keyword] = ACTIONS(6976),
    [sym_rendering_keyword] = ACTIONS(6976),
    [sym_requestpage_keyword] = ACTIONS(6976),
    [sym_schema_keyword] = ACTIONS(6976),
    [sym_views_keyword] = ACTIONS(6976),
    [sym_quoted_identifier] = ACTIONS(6978),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6978),
    [sym_preproc_open] = ACTIONS(6978),
    [sym_var_attribute_open] = ACTIONS(6978),
  },
  [STATE(3844)] = {
    [sym_identifier] = ACTIONS(4423),
    [anon_sym_SEMI] = ACTIONS(4425),
    [anon_sym_RBRACE] = ACTIONS(4425),
    [aux_sym_where_condition_token1] = ACTIONS(4423),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4423),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4423),
    [anon_sym_LBRACK] = ACTIONS(4425),
    [aux_sym_basic_type_token6] = ACTIONS(4423),
    [aux_sym_basic_type_token22] = ACTIONS(4423),
    [aux_sym_basic_type_token53] = ACTIONS(4423),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4423),
    [aux_sym_addafter_modification_token1] = ACTIONS(4423),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4423),
    [aux_sym_modify_modification_token1] = ACTIONS(4423),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4423),
    [aux_sym_movelast_modification_token1] = ACTIONS(4423),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4423),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4423),
    [aux_sym_separator_action_token1] = ACTIONS(4423),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4423),
    [aux_sym_type_declaration_token1] = ACTIONS(4423),
    [anon_sym_POUNDif] = ACTIONS(4425),
    [anon_sym_POUNDIF] = ACTIONS(4425),
    [anon_sym_POUNDIf] = ACTIONS(4425),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4423),
    [sym_trigger_keyword] = ACTIONS(4423),
    [sym_var_keyword] = ACTIONS(4423),
    [sym_local_keyword] = ACTIONS(4423),
    [sym_internal_keyword] = ACTIONS(4423),
    [sym_protected_keyword] = ACTIONS(4423),
    [sym_event_keyword] = ACTIONS(4423),
    [sym_fields_keyword] = ACTIONS(4423),
    [sym_keys_keyword] = ACTIONS(4423),
    [sym_key_keyword] = ACTIONS(4423),
    [sym_fieldgroups_keyword] = ACTIONS(4423),
    [sym_actions_keyword] = ACTIONS(4423),
    [sym_layout_keyword] = ACTIONS(4423),
    [sym_area_keyword] = ACTIONS(4423),
    [sym_group_keyword] = ACTIONS(4423),
    [sym_repeater_keyword] = ACTIONS(4423),
    [sym_cuegroup_keyword] = ACTIONS(4423),
    [sym_fixed_keyword] = ACTIONS(4423),
    [sym_grid_keyword] = ACTIONS(4423),
    [sym_part_keyword] = ACTIONS(4423),
    [sym_systempart_keyword] = ACTIONS(4423),
    [sym_usercontrol_keyword] = ACTIONS(4423),
    [sym_dataset_keyword] = ACTIONS(4423),
    [sym_elements_keyword] = ACTIONS(4423),
    [sym_dataitem_keyword] = ACTIONS(4423),
    [sym_column_keyword] = ACTIONS(4423),
    [sym_filter_keyword] = ACTIONS(4423),
    [sym_labels_keyword] = ACTIONS(4423),
    [sym_rendering_keyword] = ACTIONS(4423),
    [sym_requestpage_keyword] = ACTIONS(4423),
    [sym_schema_keyword] = ACTIONS(4423),
    [sym_views_keyword] = ACTIONS(4423),
    [sym_quoted_identifier] = ACTIONS(4425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4425),
    [sym_preproc_open] = ACTIONS(4425),
    [sym_var_attribute_open] = ACTIONS(4425),
  },
  [STATE(3845)] = {
    [sym_identifier] = ACTIONS(8175),
    [anon_sym_SEMI] = ACTIONS(8177),
    [anon_sym_RBRACE] = ACTIONS(8177),
    [aux_sym_where_condition_token1] = ACTIONS(8175),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8175),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8175),
    [anon_sym_LBRACK] = ACTIONS(8177),
    [aux_sym_basic_type_token6] = ACTIONS(8175),
    [aux_sym_basic_type_token22] = ACTIONS(8175),
    [aux_sym_basic_type_token53] = ACTIONS(8175),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8175),
    [aux_sym_addafter_modification_token1] = ACTIONS(8175),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8175),
    [aux_sym_modify_modification_token1] = ACTIONS(8175),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8175),
    [aux_sym_movelast_modification_token1] = ACTIONS(8175),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8175),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8175),
    [aux_sym_separator_action_token1] = ACTIONS(8175),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8175),
    [aux_sym_type_declaration_token1] = ACTIONS(8175),
    [anon_sym_POUNDif] = ACTIONS(8177),
    [anon_sym_POUNDIF] = ACTIONS(8177),
    [anon_sym_POUNDIf] = ACTIONS(8177),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8175),
    [sym_trigger_keyword] = ACTIONS(8175),
    [sym_var_keyword] = ACTIONS(8175),
    [sym_local_keyword] = ACTIONS(8175),
    [sym_internal_keyword] = ACTIONS(8175),
    [sym_protected_keyword] = ACTIONS(8175),
    [sym_event_keyword] = ACTIONS(8175),
    [sym_fields_keyword] = ACTIONS(8175),
    [sym_keys_keyword] = ACTIONS(8175),
    [sym_key_keyword] = ACTIONS(8175),
    [sym_fieldgroups_keyword] = ACTIONS(8175),
    [sym_actions_keyword] = ACTIONS(8175),
    [sym_layout_keyword] = ACTIONS(8175),
    [sym_area_keyword] = ACTIONS(8175),
    [sym_group_keyword] = ACTIONS(8175),
    [sym_repeater_keyword] = ACTIONS(8175),
    [sym_cuegroup_keyword] = ACTIONS(8175),
    [sym_fixed_keyword] = ACTIONS(8175),
    [sym_grid_keyword] = ACTIONS(8175),
    [sym_part_keyword] = ACTIONS(8175),
    [sym_systempart_keyword] = ACTIONS(8175),
    [sym_usercontrol_keyword] = ACTIONS(8175),
    [sym_dataset_keyword] = ACTIONS(8175),
    [sym_elements_keyword] = ACTIONS(8175),
    [sym_dataitem_keyword] = ACTIONS(8175),
    [sym_column_keyword] = ACTIONS(8175),
    [sym_filter_keyword] = ACTIONS(8175),
    [sym_labels_keyword] = ACTIONS(8175),
    [sym_rendering_keyword] = ACTIONS(8175),
    [sym_requestpage_keyword] = ACTIONS(8175),
    [sym_schema_keyword] = ACTIONS(8175),
    [sym_views_keyword] = ACTIONS(8175),
    [sym_quoted_identifier] = ACTIONS(8177),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8177),
    [sym_preproc_open] = ACTIONS(8177),
    [sym_var_attribute_open] = ACTIONS(8177),
  },
  [STATE(3846)] = {
    [sym_identifier] = ACTIONS(4379),
    [anon_sym_SEMI] = ACTIONS(4381),
    [anon_sym_RBRACE] = ACTIONS(4381),
    [aux_sym_where_condition_token1] = ACTIONS(4379),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4379),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4379),
    [anon_sym_LBRACK] = ACTIONS(4381),
    [aux_sym_basic_type_token6] = ACTIONS(4379),
    [aux_sym_basic_type_token22] = ACTIONS(4379),
    [aux_sym_basic_type_token53] = ACTIONS(4379),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4379),
    [aux_sym_addafter_modification_token1] = ACTIONS(4379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4379),
    [aux_sym_modify_modification_token1] = ACTIONS(4379),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4379),
    [aux_sym_movelast_modification_token1] = ACTIONS(4379),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4379),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4379),
    [aux_sym_separator_action_token1] = ACTIONS(4379),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4379),
    [aux_sym_type_declaration_token1] = ACTIONS(4379),
    [anon_sym_POUNDif] = ACTIONS(4381),
    [anon_sym_POUNDIF] = ACTIONS(4381),
    [anon_sym_POUNDIf] = ACTIONS(4381),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4379),
    [sym_trigger_keyword] = ACTIONS(4379),
    [sym_var_keyword] = ACTIONS(4379),
    [sym_local_keyword] = ACTIONS(4379),
    [sym_internal_keyword] = ACTIONS(4379),
    [sym_protected_keyword] = ACTIONS(4379),
    [sym_event_keyword] = ACTIONS(4379),
    [sym_fields_keyword] = ACTIONS(4379),
    [sym_keys_keyword] = ACTIONS(4379),
    [sym_key_keyword] = ACTIONS(4379),
    [sym_fieldgroups_keyword] = ACTIONS(4379),
    [sym_actions_keyword] = ACTIONS(4379),
    [sym_layout_keyword] = ACTIONS(4379),
    [sym_area_keyword] = ACTIONS(4379),
    [sym_group_keyword] = ACTIONS(4379),
    [sym_repeater_keyword] = ACTIONS(4379),
    [sym_cuegroup_keyword] = ACTIONS(4379),
    [sym_fixed_keyword] = ACTIONS(4379),
    [sym_grid_keyword] = ACTIONS(4379),
    [sym_part_keyword] = ACTIONS(4379),
    [sym_systempart_keyword] = ACTIONS(4379),
    [sym_usercontrol_keyword] = ACTIONS(4379),
    [sym_dataset_keyword] = ACTIONS(4379),
    [sym_elements_keyword] = ACTIONS(4379),
    [sym_dataitem_keyword] = ACTIONS(4379),
    [sym_column_keyword] = ACTIONS(4379),
    [sym_filter_keyword] = ACTIONS(4379),
    [sym_labels_keyword] = ACTIONS(4379),
    [sym_rendering_keyword] = ACTIONS(4379),
    [sym_requestpage_keyword] = ACTIONS(4379),
    [sym_schema_keyword] = ACTIONS(4379),
    [sym_views_keyword] = ACTIONS(4379),
    [sym_quoted_identifier] = ACTIONS(4381),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4381),
    [sym_preproc_open] = ACTIONS(4381),
    [sym_var_attribute_open] = ACTIONS(4381),
  },
  [STATE(3847)] = {
    [sym_identifier] = ACTIONS(7809),
    [anon_sym_SEMI] = ACTIONS(7811),
    [anon_sym_RBRACE] = ACTIONS(7811),
    [aux_sym_where_condition_token1] = ACTIONS(7809),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7809),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7809),
    [anon_sym_LBRACK] = ACTIONS(7811),
    [aux_sym_basic_type_token6] = ACTIONS(7809),
    [aux_sym_basic_type_token22] = ACTIONS(7809),
    [aux_sym_basic_type_token53] = ACTIONS(7809),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7809),
    [aux_sym_addafter_modification_token1] = ACTIONS(7809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7809),
    [aux_sym_modify_modification_token1] = ACTIONS(7809),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7809),
    [aux_sym_movelast_modification_token1] = ACTIONS(7809),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7809),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7809),
    [aux_sym_separator_action_token1] = ACTIONS(7809),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7809),
    [aux_sym_type_declaration_token1] = ACTIONS(7809),
    [anon_sym_POUNDif] = ACTIONS(7811),
    [anon_sym_POUNDIF] = ACTIONS(7811),
    [anon_sym_POUNDIf] = ACTIONS(7811),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7809),
    [sym_trigger_keyword] = ACTIONS(7809),
    [sym_var_keyword] = ACTIONS(7809),
    [sym_local_keyword] = ACTIONS(7809),
    [sym_internal_keyword] = ACTIONS(7809),
    [sym_protected_keyword] = ACTIONS(7809),
    [sym_event_keyword] = ACTIONS(7809),
    [sym_fields_keyword] = ACTIONS(7809),
    [sym_keys_keyword] = ACTIONS(7809),
    [sym_key_keyword] = ACTIONS(7809),
    [sym_fieldgroups_keyword] = ACTIONS(7809),
    [sym_actions_keyword] = ACTIONS(7809),
    [sym_layout_keyword] = ACTIONS(7809),
    [sym_area_keyword] = ACTIONS(7809),
    [sym_group_keyword] = ACTIONS(7809),
    [sym_repeater_keyword] = ACTIONS(7809),
    [sym_cuegroup_keyword] = ACTIONS(7809),
    [sym_fixed_keyword] = ACTIONS(7809),
    [sym_grid_keyword] = ACTIONS(7809),
    [sym_part_keyword] = ACTIONS(7809),
    [sym_systempart_keyword] = ACTIONS(7809),
    [sym_usercontrol_keyword] = ACTIONS(7809),
    [sym_dataset_keyword] = ACTIONS(7809),
    [sym_elements_keyword] = ACTIONS(7809),
    [sym_dataitem_keyword] = ACTIONS(7809),
    [sym_column_keyword] = ACTIONS(7809),
    [sym_filter_keyword] = ACTIONS(7809),
    [sym_labels_keyword] = ACTIONS(7809),
    [sym_rendering_keyword] = ACTIONS(7809),
    [sym_requestpage_keyword] = ACTIONS(7809),
    [sym_schema_keyword] = ACTIONS(7809),
    [sym_views_keyword] = ACTIONS(7809),
    [sym_quoted_identifier] = ACTIONS(7811),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7811),
    [sym_preproc_open] = ACTIONS(7811),
    [sym_var_attribute_open] = ACTIONS(7811),
  },
  [STATE(3848)] = {
    [sym_identifier] = ACTIONS(7375),
    [anon_sym_SEMI] = ACTIONS(7377),
    [anon_sym_RBRACE] = ACTIONS(7377),
    [aux_sym_where_condition_token1] = ACTIONS(7375),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7375),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7375),
    [anon_sym_LBRACK] = ACTIONS(7377),
    [aux_sym_basic_type_token6] = ACTIONS(7375),
    [aux_sym_basic_type_token22] = ACTIONS(7375),
    [aux_sym_basic_type_token53] = ACTIONS(7375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7375),
    [aux_sym_addafter_modification_token1] = ACTIONS(7375),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7375),
    [aux_sym_modify_modification_token1] = ACTIONS(7375),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7375),
    [aux_sym_movelast_modification_token1] = ACTIONS(7375),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7375),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7375),
    [aux_sym_separator_action_token1] = ACTIONS(7375),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7375),
    [aux_sym_type_declaration_token1] = ACTIONS(7375),
    [anon_sym_POUNDif] = ACTIONS(7377),
    [anon_sym_POUNDIF] = ACTIONS(7377),
    [anon_sym_POUNDIf] = ACTIONS(7377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7375),
    [sym_trigger_keyword] = ACTIONS(7375),
    [sym_var_keyword] = ACTIONS(7375),
    [sym_local_keyword] = ACTIONS(7375),
    [sym_internal_keyword] = ACTIONS(7375),
    [sym_protected_keyword] = ACTIONS(7375),
    [sym_event_keyword] = ACTIONS(7375),
    [sym_fields_keyword] = ACTIONS(7375),
    [sym_keys_keyword] = ACTIONS(7375),
    [sym_key_keyword] = ACTIONS(7375),
    [sym_fieldgroups_keyword] = ACTIONS(7375),
    [sym_actions_keyword] = ACTIONS(7375),
    [sym_layout_keyword] = ACTIONS(7375),
    [sym_area_keyword] = ACTIONS(7375),
    [sym_group_keyword] = ACTIONS(7375),
    [sym_repeater_keyword] = ACTIONS(7375),
    [sym_cuegroup_keyword] = ACTIONS(7375),
    [sym_fixed_keyword] = ACTIONS(7375),
    [sym_grid_keyword] = ACTIONS(7375),
    [sym_part_keyword] = ACTIONS(7375),
    [sym_systempart_keyword] = ACTIONS(7375),
    [sym_usercontrol_keyword] = ACTIONS(7375),
    [sym_dataset_keyword] = ACTIONS(7375),
    [sym_elements_keyword] = ACTIONS(7375),
    [sym_dataitem_keyword] = ACTIONS(7375),
    [sym_column_keyword] = ACTIONS(7375),
    [sym_filter_keyword] = ACTIONS(7375),
    [sym_labels_keyword] = ACTIONS(7375),
    [sym_rendering_keyword] = ACTIONS(7375),
    [sym_requestpage_keyword] = ACTIONS(7375),
    [sym_schema_keyword] = ACTIONS(7375),
    [sym_views_keyword] = ACTIONS(7375),
    [sym_quoted_identifier] = ACTIONS(7377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7377),
    [sym_preproc_open] = ACTIONS(7377),
    [sym_var_attribute_open] = ACTIONS(7377),
  },
  [STATE(3849)] = {
    [sym_identifier] = ACTIONS(4383),
    [anon_sym_SEMI] = ACTIONS(10192),
    [anon_sym_RBRACE] = ACTIONS(4387),
    [aux_sym_where_condition_token1] = ACTIONS(4383),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4383),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4383),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_basic_type_token6] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_basic_type_token53] = ACTIONS(4383),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4383),
    [aux_sym_addafter_modification_token1] = ACTIONS(4383),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4383),
    [aux_sym_modify_modification_token1] = ACTIONS(4383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4383),
    [aux_sym_movelast_modification_token1] = ACTIONS(4383),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4383),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4383),
    [aux_sym_separator_action_token1] = ACTIONS(4383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4383),
    [aux_sym_type_declaration_token1] = ACTIONS(4383),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4383),
    [sym_trigger_keyword] = ACTIONS(4383),
    [sym_var_keyword] = ACTIONS(4383),
    [sym_local_keyword] = ACTIONS(4383),
    [sym_internal_keyword] = ACTIONS(4383),
    [sym_protected_keyword] = ACTIONS(4383),
    [sym_event_keyword] = ACTIONS(4383),
    [sym_fields_keyword] = ACTIONS(4383),
    [sym_keys_keyword] = ACTIONS(4383),
    [sym_key_keyword] = ACTIONS(4383),
    [sym_fieldgroups_keyword] = ACTIONS(4383),
    [sym_actions_keyword] = ACTIONS(4383),
    [sym_layout_keyword] = ACTIONS(4383),
    [sym_area_keyword] = ACTIONS(4383),
    [sym_group_keyword] = ACTIONS(4383),
    [sym_repeater_keyword] = ACTIONS(4383),
    [sym_cuegroup_keyword] = ACTIONS(4383),
    [sym_fixed_keyword] = ACTIONS(4383),
    [sym_grid_keyword] = ACTIONS(4383),
    [sym_part_keyword] = ACTIONS(4383),
    [sym_systempart_keyword] = ACTIONS(4383),
    [sym_usercontrol_keyword] = ACTIONS(4383),
    [sym_dataset_keyword] = ACTIONS(4383),
    [sym_elements_keyword] = ACTIONS(4383),
    [sym_dataitem_keyword] = ACTIONS(4383),
    [sym_column_keyword] = ACTIONS(4383),
    [sym_filter_keyword] = ACTIONS(4383),
    [sym_labels_keyword] = ACTIONS(4383),
    [sym_rendering_keyword] = ACTIONS(4383),
    [sym_requestpage_keyword] = ACTIONS(4383),
    [sym_schema_keyword] = ACTIONS(4383),
    [sym_views_keyword] = ACTIONS(4383),
    [sym_quoted_identifier] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
    [sym_var_attribute_open] = ACTIONS(4387),
  },
  [STATE(3850)] = {
    [sym_identifier] = ACTIONS(4435),
    [anon_sym_SEMI] = ACTIONS(4437),
    [anon_sym_RBRACE] = ACTIONS(4437),
    [aux_sym_where_condition_token1] = ACTIONS(4435),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4435),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4435),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [aux_sym_basic_type_token6] = ACTIONS(4435),
    [aux_sym_basic_type_token22] = ACTIONS(4435),
    [aux_sym_basic_type_token53] = ACTIONS(4435),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4435),
    [aux_sym_addafter_modification_token1] = ACTIONS(4435),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4435),
    [aux_sym_modify_modification_token1] = ACTIONS(4435),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4435),
    [aux_sym_movelast_modification_token1] = ACTIONS(4435),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4435),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4435),
    [aux_sym_separator_action_token1] = ACTIONS(4435),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4435),
    [aux_sym_type_declaration_token1] = ACTIONS(4435),
    [anon_sym_POUNDif] = ACTIONS(4437),
    [anon_sym_POUNDIF] = ACTIONS(4437),
    [anon_sym_POUNDIf] = ACTIONS(4437),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4435),
    [sym_trigger_keyword] = ACTIONS(4435),
    [sym_var_keyword] = ACTIONS(4435),
    [sym_local_keyword] = ACTIONS(4435),
    [sym_internal_keyword] = ACTIONS(4435),
    [sym_protected_keyword] = ACTIONS(4435),
    [sym_event_keyword] = ACTIONS(4435),
    [sym_fields_keyword] = ACTIONS(4435),
    [sym_keys_keyword] = ACTIONS(4435),
    [sym_key_keyword] = ACTIONS(4435),
    [sym_fieldgroups_keyword] = ACTIONS(4435),
    [sym_actions_keyword] = ACTIONS(4435),
    [sym_layout_keyword] = ACTIONS(4435),
    [sym_area_keyword] = ACTIONS(4435),
    [sym_group_keyword] = ACTIONS(4435),
    [sym_repeater_keyword] = ACTIONS(4435),
    [sym_cuegroup_keyword] = ACTIONS(4435),
    [sym_fixed_keyword] = ACTIONS(4435),
    [sym_grid_keyword] = ACTIONS(4435),
    [sym_part_keyword] = ACTIONS(4435),
    [sym_systempart_keyword] = ACTIONS(4435),
    [sym_usercontrol_keyword] = ACTIONS(4435),
    [sym_dataset_keyword] = ACTIONS(4435),
    [sym_elements_keyword] = ACTIONS(4435),
    [sym_dataitem_keyword] = ACTIONS(4435),
    [sym_column_keyword] = ACTIONS(4435),
    [sym_filter_keyword] = ACTIONS(4435),
    [sym_labels_keyword] = ACTIONS(4435),
    [sym_rendering_keyword] = ACTIONS(4435),
    [sym_requestpage_keyword] = ACTIONS(4435),
    [sym_schema_keyword] = ACTIONS(4435),
    [sym_views_keyword] = ACTIONS(4435),
    [sym_quoted_identifier] = ACTIONS(4437),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4437),
    [sym_preproc_open] = ACTIONS(4437),
    [sym_var_attribute_open] = ACTIONS(4437),
  },
  [STATE(3851)] = {
    [sym_identifier] = ACTIONS(7152),
    [anon_sym_SEMI] = ACTIONS(7154),
    [anon_sym_RBRACE] = ACTIONS(7154),
    [aux_sym_where_condition_token1] = ACTIONS(7152),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7152),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7152),
    [anon_sym_LBRACK] = ACTIONS(7154),
    [aux_sym_basic_type_token6] = ACTIONS(7152),
    [aux_sym_basic_type_token22] = ACTIONS(7152),
    [aux_sym_basic_type_token53] = ACTIONS(7152),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7152),
    [aux_sym_addafter_modification_token1] = ACTIONS(7152),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7152),
    [aux_sym_modify_modification_token1] = ACTIONS(7152),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7152),
    [aux_sym_movelast_modification_token1] = ACTIONS(7152),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7152),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7152),
    [aux_sym_separator_action_token1] = ACTIONS(7152),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7152),
    [aux_sym_type_declaration_token1] = ACTIONS(7152),
    [anon_sym_POUNDif] = ACTIONS(7154),
    [anon_sym_POUNDIF] = ACTIONS(7154),
    [anon_sym_POUNDIf] = ACTIONS(7154),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7152),
    [sym_trigger_keyword] = ACTIONS(7152),
    [sym_var_keyword] = ACTIONS(7152),
    [sym_local_keyword] = ACTIONS(7152),
    [sym_internal_keyword] = ACTIONS(7152),
    [sym_protected_keyword] = ACTIONS(7152),
    [sym_event_keyword] = ACTIONS(7152),
    [sym_fields_keyword] = ACTIONS(7152),
    [sym_keys_keyword] = ACTIONS(7152),
    [sym_key_keyword] = ACTIONS(7152),
    [sym_fieldgroups_keyword] = ACTIONS(7152),
    [sym_actions_keyword] = ACTIONS(7152),
    [sym_layout_keyword] = ACTIONS(7152),
    [sym_area_keyword] = ACTIONS(7152),
    [sym_group_keyword] = ACTIONS(7152),
    [sym_repeater_keyword] = ACTIONS(7152),
    [sym_cuegroup_keyword] = ACTIONS(7152),
    [sym_fixed_keyword] = ACTIONS(7152),
    [sym_grid_keyword] = ACTIONS(7152),
    [sym_part_keyword] = ACTIONS(7152),
    [sym_systempart_keyword] = ACTIONS(7152),
    [sym_usercontrol_keyword] = ACTIONS(7152),
    [sym_dataset_keyword] = ACTIONS(7152),
    [sym_elements_keyword] = ACTIONS(7152),
    [sym_dataitem_keyword] = ACTIONS(7152),
    [sym_column_keyword] = ACTIONS(7152),
    [sym_filter_keyword] = ACTIONS(7152),
    [sym_labels_keyword] = ACTIONS(7152),
    [sym_rendering_keyword] = ACTIONS(7152),
    [sym_requestpage_keyword] = ACTIONS(7152),
    [sym_schema_keyword] = ACTIONS(7152),
    [sym_views_keyword] = ACTIONS(7152),
    [sym_quoted_identifier] = ACTIONS(7154),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7154),
    [sym_preproc_open] = ACTIONS(7154),
    [sym_var_attribute_open] = ACTIONS(7154),
  },
  [STATE(3852)] = {
    [sym__layout_element] = STATE(3852),
    [sym_area_section] = STATE(3852),
    [sym_group_section] = STATE(3852),
    [sym_repeater_section] = STATE(3852),
    [sym_cuegroup_section] = STATE(3852),
    [sym_fixed_section] = STATE(3852),
    [sym_grid_section] = STATE(3852),
    [sym_page_field] = STATE(3852),
    [sym_part_section] = STATE(3852),
    [sym_systempart_section] = STATE(3852),
    [sym_usercontrol_section] = STATE(3852),
    [sym_preproc_split_field] = STATE(3852),
    [sym_label_section] = STATE(3852),
    [sym_addfirst_modification] = STATE(3852),
    [sym_addlast_modification] = STATE(3852),
    [sym_addafter_modification] = STATE(3852),
    [sym_addbefore_modification] = STATE(3852),
    [sym_modify_modification] = STATE(3852),
    [sym_movefirst_modification] = STATE(3852),
    [sym_movelast_modification] = STATE(3852),
    [sym_moveafter_modification] = STATE(3852),
    [sym_movebefore_modification] = STATE(3852),
    [sym_preproc_if] = STATE(3384),
    [sym_preproc_conditional_layout] = STATE(3852),
    [aux_sym_layout_section_repeat1] = STATE(3852),
    [anon_sym_RBRACE] = ACTIONS(10194),
    [aux_sym_where_condition_token1] = ACTIONS(10196),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(10199),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(10202),
    [aux_sym_basic_type_token6] = ACTIONS(10205),
    [aux_sym_addafter_modification_token1] = ACTIONS(10208),
    [aux_sym_addbefore_modification_token1] = ACTIONS(10211),
    [aux_sym_modify_modification_token1] = ACTIONS(10214),
    [aux_sym_movefirst_modification_token1] = ACTIONS(10217),
    [aux_sym_movelast_modification_token1] = ACTIONS(10220),
    [aux_sym_moveafter_modification_token1] = ACTIONS(10223),
    [aux_sym_movebefore_modification_token1] = ACTIONS(10226),
    [anon_sym_POUNDif] = ACTIONS(10229),
    [anon_sym_POUNDIF] = ACTIONS(10229),
    [anon_sym_POUNDIf] = ACTIONS(10229),
    [anon_sym_POUNDelif] = ACTIONS(10194),
    [anon_sym_POUNDELIF] = ACTIONS(10194),
    [anon_sym_POUNDElif] = ACTIONS(10194),
    [anon_sym_POUNDelse] = ACTIONS(10194),
    [anon_sym_POUNDELSE] = ACTIONS(10194),
    [anon_sym_POUNDElse] = ACTIONS(10194),
    [anon_sym_POUNDendif] = ACTIONS(10194),
    [anon_sym_POUNDENDIF] = ACTIONS(10194),
    [anon_sym_POUNDEndif] = ACTIONS(10194),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(10232),
    [sym_group_keyword] = ACTIONS(10235),
    [sym_repeater_keyword] = ACTIONS(10238),
    [sym_cuegroup_keyword] = ACTIONS(10241),
    [sym_fixed_keyword] = ACTIONS(10244),
    [sym_grid_keyword] = ACTIONS(10247),
    [sym_part_keyword] = ACTIONS(10250),
    [sym_systempart_keyword] = ACTIONS(10253),
    [sym_usercontrol_keyword] = ACTIONS(10256),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(10229),
    [sym_preproc_close] = ACTIONS(10194),
  },
  [STATE(3853)] = {
    [sym_identifier] = ACTIONS(4383),
    [anon_sym_SEMI] = ACTIONS(10259),
    [anon_sym_RBRACE] = ACTIONS(4387),
    [aux_sym_where_condition_token1] = ACTIONS(4383),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4383),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4383),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_basic_type_token6] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_basic_type_token53] = ACTIONS(4383),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4383),
    [aux_sym_addafter_modification_token1] = ACTIONS(4383),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4383),
    [aux_sym_modify_modification_token1] = ACTIONS(4383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4383),
    [aux_sym_movelast_modification_token1] = ACTIONS(4383),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4383),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4383),
    [aux_sym_separator_action_token1] = ACTIONS(4383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4383),
    [aux_sym_type_declaration_token1] = ACTIONS(4383),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4383),
    [sym_trigger_keyword] = ACTIONS(4383),
    [sym_var_keyword] = ACTIONS(4383),
    [sym_local_keyword] = ACTIONS(4383),
    [sym_internal_keyword] = ACTIONS(4383),
    [sym_protected_keyword] = ACTIONS(4383),
    [sym_event_keyword] = ACTIONS(4383),
    [sym_fields_keyword] = ACTIONS(4383),
    [sym_keys_keyword] = ACTIONS(4383),
    [sym_key_keyword] = ACTIONS(4383),
    [sym_fieldgroups_keyword] = ACTIONS(4383),
    [sym_actions_keyword] = ACTIONS(4383),
    [sym_layout_keyword] = ACTIONS(4383),
    [sym_area_keyword] = ACTIONS(4383),
    [sym_group_keyword] = ACTIONS(4383),
    [sym_repeater_keyword] = ACTIONS(4383),
    [sym_cuegroup_keyword] = ACTIONS(4383),
    [sym_fixed_keyword] = ACTIONS(4383),
    [sym_grid_keyword] = ACTIONS(4383),
    [sym_part_keyword] = ACTIONS(4383),
    [sym_systempart_keyword] = ACTIONS(4383),
    [sym_usercontrol_keyword] = ACTIONS(4383),
    [sym_dataset_keyword] = ACTIONS(4383),
    [sym_elements_keyword] = ACTIONS(4383),
    [sym_dataitem_keyword] = ACTIONS(4383),
    [sym_column_keyword] = ACTIONS(4383),
    [sym_filter_keyword] = ACTIONS(4383),
    [sym_labels_keyword] = ACTIONS(4383),
    [sym_rendering_keyword] = ACTIONS(4383),
    [sym_requestpage_keyword] = ACTIONS(4383),
    [sym_schema_keyword] = ACTIONS(4383),
    [sym_views_keyword] = ACTIONS(4383),
    [sym_quoted_identifier] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
    [sym_var_attribute_open] = ACTIONS(4387),
  },
  [STATE(3854)] = {
    [sym_preproc_conditional_controladdin] = STATE(3867),
    [sym__body_element] = STATE(3867),
    [sym_empty_statement] = STATE(3867),
    [sym_property] = STATE(3867),
    [sym_fields_section] = STATE(3867),
    [sym_keys_section] = STATE(3867),
    [sym_fieldgroups_section] = STATE(3867),
    [sym_enum_value_declaration] = STATE(3867),
    [sym_labels_section] = STATE(3867),
    [sym_layout_section] = STATE(3867),
    [sym_modify_modification] = STATE(3867),
    [sym_actions_section] = STATE(3867),
    [sym_views_section] = STATE(3867),
    [sym_dataset_section] = STATE(3867),
    [sym_requestpage_section] = STATE(3867),
    [sym_rendering_section] = STATE(3867),
    [sym_elements_section] = STATE(3867),
    [sym_schema_section] = STATE(3867),
    [sym_assembly_declaration] = STATE(3867),
    [sym_event_declaration] = STATE(3867),
    [sym_procedure] = STATE(3867),
    [sym_preproc_split_procedure] = STATE(3867),
    [sym_interface_procedure] = STATE(3867),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3867),
    [sym_var_section] = STATE(3867),
    [sym_attribute_item] = STATE(3867),
    [sym_preproc_conditional] = STATE(3867),
    [sym_preproc_if] = STATE(2633),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3867),
    [anon_sym_SEMI] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(10261),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3807),
    [aux_sym_modify_modification_token1] = ACTIONS(3813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3823),
    [anon_sym_POUNDif] = ACTIONS(2875),
    [anon_sym_POUNDIF] = ACTIONS(2875),
    [anon_sym_POUNDIf] = ACTIONS(2875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10152),
    [sym_trigger_keyword] = ACTIONS(3827),
    [sym_var_keyword] = ACTIONS(3829),
    [sym_local_keyword] = ACTIONS(3831),
    [sym_internal_keyword] = ACTIONS(2891),
    [sym_protected_keyword] = ACTIONS(3831),
    [sym_event_keyword] = ACTIONS(3833),
    [sym_fields_keyword] = ACTIONS(3835),
    [sym_keys_keyword] = ACTIONS(3837),
    [sym_fieldgroups_keyword] = ACTIONS(3839),
    [sym_actions_keyword] = ACTIONS(3841),
    [sym_layout_keyword] = ACTIONS(3843),
    [sym_dataset_keyword] = ACTIONS(3863),
    [sym_elements_keyword] = ACTIONS(3865),
    [sym_labels_keyword] = ACTIONS(3867),
    [sym_rendering_keyword] = ACTIONS(3869),
    [sym_requestpage_keyword] = ACTIONS(3871),
    [sym_schema_keyword] = ACTIONS(3873),
    [sym_views_keyword] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3877),
    [sym_preproc_open] = ACTIONS(2875),
  },
  [STATE(3855)] = {
    [sym_identifier] = ACTIONS(4443),
    [anon_sym_SEMI] = ACTIONS(4445),
    [anon_sym_RBRACE] = ACTIONS(4445),
    [aux_sym_where_condition_token1] = ACTIONS(4443),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4443),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4443),
    [anon_sym_LBRACK] = ACTIONS(4445),
    [aux_sym_basic_type_token6] = ACTIONS(4443),
    [aux_sym_basic_type_token22] = ACTIONS(4443),
    [aux_sym_basic_type_token53] = ACTIONS(4443),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4443),
    [aux_sym_addafter_modification_token1] = ACTIONS(4443),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4443),
    [aux_sym_modify_modification_token1] = ACTIONS(4443),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4443),
    [aux_sym_movelast_modification_token1] = ACTIONS(4443),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4443),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4443),
    [aux_sym_separator_action_token1] = ACTIONS(4443),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4443),
    [aux_sym_type_declaration_token1] = ACTIONS(4443),
    [anon_sym_POUNDif] = ACTIONS(4445),
    [anon_sym_POUNDIF] = ACTIONS(4445),
    [anon_sym_POUNDIf] = ACTIONS(4445),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4443),
    [sym_trigger_keyword] = ACTIONS(4443),
    [sym_var_keyword] = ACTIONS(4443),
    [sym_local_keyword] = ACTIONS(4443),
    [sym_internal_keyword] = ACTIONS(4443),
    [sym_protected_keyword] = ACTIONS(4443),
    [sym_event_keyword] = ACTIONS(4443),
    [sym_fields_keyword] = ACTIONS(4443),
    [sym_keys_keyword] = ACTIONS(4443),
    [sym_key_keyword] = ACTIONS(4443),
    [sym_fieldgroups_keyword] = ACTIONS(4443),
    [sym_actions_keyword] = ACTIONS(4443),
    [sym_layout_keyword] = ACTIONS(4443),
    [sym_area_keyword] = ACTIONS(4443),
    [sym_group_keyword] = ACTIONS(4443),
    [sym_repeater_keyword] = ACTIONS(4443),
    [sym_cuegroup_keyword] = ACTIONS(4443),
    [sym_fixed_keyword] = ACTIONS(4443),
    [sym_grid_keyword] = ACTIONS(4443),
    [sym_part_keyword] = ACTIONS(4443),
    [sym_systempart_keyword] = ACTIONS(4443),
    [sym_usercontrol_keyword] = ACTIONS(4443),
    [sym_dataset_keyword] = ACTIONS(4443),
    [sym_elements_keyword] = ACTIONS(4443),
    [sym_dataitem_keyword] = ACTIONS(4443),
    [sym_column_keyword] = ACTIONS(4443),
    [sym_filter_keyword] = ACTIONS(4443),
    [sym_labels_keyword] = ACTIONS(4443),
    [sym_rendering_keyword] = ACTIONS(4443),
    [sym_requestpage_keyword] = ACTIONS(4443),
    [sym_schema_keyword] = ACTIONS(4443),
    [sym_views_keyword] = ACTIONS(4443),
    [sym_quoted_identifier] = ACTIONS(4445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4445),
    [sym_preproc_open] = ACTIONS(4445),
    [sym_var_attribute_open] = ACTIONS(4445),
  },
  [STATE(3856)] = {
    [sym_identifier] = ACTIONS(2843),
    [anon_sym_SEMI] = ACTIONS(2841),
    [anon_sym_RBRACE] = ACTIONS(2841),
    [aux_sym_where_condition_token1] = ACTIONS(2843),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(2843),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(2843),
    [anon_sym_LBRACK] = ACTIONS(2841),
    [aux_sym_basic_type_token6] = ACTIONS(2843),
    [aux_sym_basic_type_token22] = ACTIONS(2843),
    [aux_sym_basic_type_token53] = ACTIONS(2843),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(2843),
    [aux_sym_addafter_modification_token1] = ACTIONS(2843),
    [aux_sym_addbefore_modification_token1] = ACTIONS(2843),
    [aux_sym_modify_modification_token1] = ACTIONS(2843),
    [aux_sym_movefirst_modification_token1] = ACTIONS(2843),
    [aux_sym_movelast_modification_token1] = ACTIONS(2843),
    [aux_sym_moveafter_modification_token1] = ACTIONS(2843),
    [aux_sym_movebefore_modification_token1] = ACTIONS(2843),
    [aux_sym_separator_action_token1] = ACTIONS(2843),
    [aux_sym_assembly_declaration_token1] = ACTIONS(2843),
    [aux_sym_type_declaration_token1] = ACTIONS(2843),
    [anon_sym_POUNDif] = ACTIONS(2841),
    [anon_sym_POUNDIF] = ACTIONS(2841),
    [anon_sym_POUNDIf] = ACTIONS(2841),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(2843),
    [sym_trigger_keyword] = ACTIONS(2843),
    [sym_var_keyword] = ACTIONS(2843),
    [sym_local_keyword] = ACTIONS(2843),
    [sym_internal_keyword] = ACTIONS(2843),
    [sym_protected_keyword] = ACTIONS(2843),
    [sym_event_keyword] = ACTIONS(2843),
    [sym_fields_keyword] = ACTIONS(2843),
    [sym_keys_keyword] = ACTIONS(2843),
    [sym_key_keyword] = ACTIONS(2843),
    [sym_fieldgroups_keyword] = ACTIONS(2843),
    [sym_actions_keyword] = ACTIONS(2843),
    [sym_layout_keyword] = ACTIONS(2843),
    [sym_area_keyword] = ACTIONS(2843),
    [sym_group_keyword] = ACTIONS(2843),
    [sym_repeater_keyword] = ACTIONS(2843),
    [sym_cuegroup_keyword] = ACTIONS(2843),
    [sym_fixed_keyword] = ACTIONS(2843),
    [sym_grid_keyword] = ACTIONS(2843),
    [sym_part_keyword] = ACTIONS(2843),
    [sym_systempart_keyword] = ACTIONS(2843),
    [sym_usercontrol_keyword] = ACTIONS(2843),
    [sym_dataset_keyword] = ACTIONS(2843),
    [sym_elements_keyword] = ACTIONS(2843),
    [sym_dataitem_keyword] = ACTIONS(2843),
    [sym_column_keyword] = ACTIONS(2843),
    [sym_filter_keyword] = ACTIONS(2843),
    [sym_labels_keyword] = ACTIONS(2843),
    [sym_rendering_keyword] = ACTIONS(2843),
    [sym_requestpage_keyword] = ACTIONS(2843),
    [sym_schema_keyword] = ACTIONS(2843),
    [sym_views_keyword] = ACTIONS(2843),
    [sym_quoted_identifier] = ACTIONS(2841),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(2841),
    [sym_preproc_open] = ACTIONS(2841),
    [sym_var_attribute_open] = ACTIONS(2841),
  },
  [STATE(3857)] = {
    [sym_identifier] = ACTIONS(4439),
    [anon_sym_SEMI] = ACTIONS(4441),
    [anon_sym_RBRACE] = ACTIONS(4441),
    [aux_sym_where_condition_token1] = ACTIONS(4439),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4439),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(4439),
    [aux_sym_basic_type_token22] = ACTIONS(4439),
    [aux_sym_basic_type_token53] = ACTIONS(4439),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4439),
    [aux_sym_addafter_modification_token1] = ACTIONS(4439),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4439),
    [aux_sym_modify_modification_token1] = ACTIONS(4439),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4439),
    [aux_sym_movelast_modification_token1] = ACTIONS(4439),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4439),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4439),
    [aux_sym_separator_action_token1] = ACTIONS(4439),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4439),
    [aux_sym_type_declaration_token1] = ACTIONS(4439),
    [anon_sym_POUNDif] = ACTIONS(4441),
    [anon_sym_POUNDIF] = ACTIONS(4441),
    [anon_sym_POUNDIf] = ACTIONS(4441),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4439),
    [sym_trigger_keyword] = ACTIONS(4439),
    [sym_var_keyword] = ACTIONS(4439),
    [sym_local_keyword] = ACTIONS(4439),
    [sym_internal_keyword] = ACTIONS(4439),
    [sym_protected_keyword] = ACTIONS(4439),
    [sym_event_keyword] = ACTIONS(4439),
    [sym_fields_keyword] = ACTIONS(4439),
    [sym_keys_keyword] = ACTIONS(4439),
    [sym_key_keyword] = ACTIONS(4439),
    [sym_fieldgroups_keyword] = ACTIONS(4439),
    [sym_actions_keyword] = ACTIONS(4439),
    [sym_layout_keyword] = ACTIONS(4439),
    [sym_area_keyword] = ACTIONS(4439),
    [sym_group_keyword] = ACTIONS(4439),
    [sym_repeater_keyword] = ACTIONS(4439),
    [sym_cuegroup_keyword] = ACTIONS(4439),
    [sym_fixed_keyword] = ACTIONS(4439),
    [sym_grid_keyword] = ACTIONS(4439),
    [sym_part_keyword] = ACTIONS(4439),
    [sym_systempart_keyword] = ACTIONS(4439),
    [sym_usercontrol_keyword] = ACTIONS(4439),
    [sym_dataset_keyword] = ACTIONS(4439),
    [sym_elements_keyword] = ACTIONS(4439),
    [sym_dataitem_keyword] = ACTIONS(4439),
    [sym_column_keyword] = ACTIONS(4439),
    [sym_filter_keyword] = ACTIONS(4439),
    [sym_labels_keyword] = ACTIONS(4439),
    [sym_rendering_keyword] = ACTIONS(4439),
    [sym_requestpage_keyword] = ACTIONS(4439),
    [sym_schema_keyword] = ACTIONS(4439),
    [sym_views_keyword] = ACTIONS(4439),
    [sym_quoted_identifier] = ACTIONS(4441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4441),
    [sym_preproc_open] = ACTIONS(4441),
    [sym_var_attribute_open] = ACTIONS(4441),
  },
  [STATE(3858)] = {
    [sym_identifier] = ACTIONS(8199),
    [anon_sym_SEMI] = ACTIONS(8201),
    [anon_sym_RBRACE] = ACTIONS(8201),
    [aux_sym_where_condition_token1] = ACTIONS(8199),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8199),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8199),
    [anon_sym_LBRACK] = ACTIONS(8201),
    [aux_sym_basic_type_token6] = ACTIONS(8199),
    [aux_sym_basic_type_token22] = ACTIONS(8199),
    [aux_sym_basic_type_token53] = ACTIONS(8199),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8199),
    [aux_sym_addafter_modification_token1] = ACTIONS(8199),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8199),
    [aux_sym_modify_modification_token1] = ACTIONS(8199),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8199),
    [aux_sym_movelast_modification_token1] = ACTIONS(8199),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8199),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8199),
    [aux_sym_separator_action_token1] = ACTIONS(8199),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8199),
    [aux_sym_type_declaration_token1] = ACTIONS(8199),
    [anon_sym_POUNDif] = ACTIONS(8201),
    [anon_sym_POUNDIF] = ACTIONS(8201),
    [anon_sym_POUNDIf] = ACTIONS(8201),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8199),
    [sym_trigger_keyword] = ACTIONS(8199),
    [sym_var_keyword] = ACTIONS(8199),
    [sym_local_keyword] = ACTIONS(8199),
    [sym_internal_keyword] = ACTIONS(8199),
    [sym_protected_keyword] = ACTIONS(8199),
    [sym_event_keyword] = ACTIONS(8199),
    [sym_fields_keyword] = ACTIONS(8199),
    [sym_keys_keyword] = ACTIONS(8199),
    [sym_key_keyword] = ACTIONS(8199),
    [sym_fieldgroups_keyword] = ACTIONS(8199),
    [sym_actions_keyword] = ACTIONS(8199),
    [sym_layout_keyword] = ACTIONS(8199),
    [sym_area_keyword] = ACTIONS(8199),
    [sym_group_keyword] = ACTIONS(8199),
    [sym_repeater_keyword] = ACTIONS(8199),
    [sym_cuegroup_keyword] = ACTIONS(8199),
    [sym_fixed_keyword] = ACTIONS(8199),
    [sym_grid_keyword] = ACTIONS(8199),
    [sym_part_keyword] = ACTIONS(8199),
    [sym_systempart_keyword] = ACTIONS(8199),
    [sym_usercontrol_keyword] = ACTIONS(8199),
    [sym_dataset_keyword] = ACTIONS(8199),
    [sym_elements_keyword] = ACTIONS(8199),
    [sym_dataitem_keyword] = ACTIONS(8199),
    [sym_column_keyword] = ACTIONS(8199),
    [sym_filter_keyword] = ACTIONS(8199),
    [sym_labels_keyword] = ACTIONS(8199),
    [sym_rendering_keyword] = ACTIONS(8199),
    [sym_requestpage_keyword] = ACTIONS(8199),
    [sym_schema_keyword] = ACTIONS(8199),
    [sym_views_keyword] = ACTIONS(8199),
    [sym_quoted_identifier] = ACTIONS(8201),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8201),
    [sym_preproc_open] = ACTIONS(8201),
    [sym_var_attribute_open] = ACTIONS(8201),
  },
  [STATE(3859)] = {
    [sym_identifier] = ACTIONS(8199),
    [anon_sym_SEMI] = ACTIONS(8201),
    [anon_sym_RBRACE] = ACTIONS(8201),
    [aux_sym_where_condition_token1] = ACTIONS(8199),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8199),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8199),
    [anon_sym_LBRACK] = ACTIONS(8201),
    [aux_sym_basic_type_token6] = ACTIONS(8199),
    [aux_sym_basic_type_token22] = ACTIONS(8199),
    [aux_sym_basic_type_token53] = ACTIONS(8199),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8199),
    [aux_sym_addafter_modification_token1] = ACTIONS(8199),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8199),
    [aux_sym_modify_modification_token1] = ACTIONS(8199),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8199),
    [aux_sym_movelast_modification_token1] = ACTIONS(8199),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8199),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8199),
    [aux_sym_separator_action_token1] = ACTIONS(8199),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8199),
    [aux_sym_type_declaration_token1] = ACTIONS(8199),
    [anon_sym_POUNDif] = ACTIONS(8201),
    [anon_sym_POUNDIF] = ACTIONS(8201),
    [anon_sym_POUNDIf] = ACTIONS(8201),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8199),
    [sym_trigger_keyword] = ACTIONS(8199),
    [sym_var_keyword] = ACTIONS(8199),
    [sym_local_keyword] = ACTIONS(8199),
    [sym_internal_keyword] = ACTIONS(8199),
    [sym_protected_keyword] = ACTIONS(8199),
    [sym_event_keyword] = ACTIONS(8199),
    [sym_fields_keyword] = ACTIONS(8199),
    [sym_keys_keyword] = ACTIONS(8199),
    [sym_key_keyword] = ACTIONS(8199),
    [sym_fieldgroups_keyword] = ACTIONS(8199),
    [sym_actions_keyword] = ACTIONS(8199),
    [sym_layout_keyword] = ACTIONS(8199),
    [sym_area_keyword] = ACTIONS(8199),
    [sym_group_keyword] = ACTIONS(8199),
    [sym_repeater_keyword] = ACTIONS(8199),
    [sym_cuegroup_keyword] = ACTIONS(8199),
    [sym_fixed_keyword] = ACTIONS(8199),
    [sym_grid_keyword] = ACTIONS(8199),
    [sym_part_keyword] = ACTIONS(8199),
    [sym_systempart_keyword] = ACTIONS(8199),
    [sym_usercontrol_keyword] = ACTIONS(8199),
    [sym_dataset_keyword] = ACTIONS(8199),
    [sym_elements_keyword] = ACTIONS(8199),
    [sym_dataitem_keyword] = ACTIONS(8199),
    [sym_column_keyword] = ACTIONS(8199),
    [sym_filter_keyword] = ACTIONS(8199),
    [sym_labels_keyword] = ACTIONS(8199),
    [sym_rendering_keyword] = ACTIONS(8199),
    [sym_requestpage_keyword] = ACTIONS(8199),
    [sym_schema_keyword] = ACTIONS(8199),
    [sym_views_keyword] = ACTIONS(8199),
    [sym_quoted_identifier] = ACTIONS(8201),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8201),
    [sym_preproc_open] = ACTIONS(8201),
    [sym_var_attribute_open] = ACTIONS(8201),
  },
  [STATE(3860)] = {
    [sym_identifier] = ACTIONS(4373),
    [anon_sym_SEMI] = ACTIONS(4377),
    [anon_sym_RBRACE] = ACTIONS(4377),
    [aux_sym_where_condition_token1] = ACTIONS(4373),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4373),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4373),
    [anon_sym_LBRACK] = ACTIONS(4377),
    [aux_sym_basic_type_token6] = ACTIONS(4373),
    [aux_sym_basic_type_token22] = ACTIONS(4373),
    [aux_sym_basic_type_token53] = ACTIONS(4373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4373),
    [aux_sym_addafter_modification_token1] = ACTIONS(4373),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4373),
    [aux_sym_modify_modification_token1] = ACTIONS(4373),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4373),
    [aux_sym_movelast_modification_token1] = ACTIONS(4373),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4373),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4373),
    [aux_sym_separator_action_token1] = ACTIONS(4373),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4373),
    [aux_sym_type_declaration_token1] = ACTIONS(4373),
    [anon_sym_POUNDif] = ACTIONS(4377),
    [anon_sym_POUNDIF] = ACTIONS(4377),
    [anon_sym_POUNDIf] = ACTIONS(4377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4373),
    [sym_trigger_keyword] = ACTIONS(4373),
    [sym_var_keyword] = ACTIONS(4373),
    [sym_local_keyword] = ACTIONS(4373),
    [sym_internal_keyword] = ACTIONS(4373),
    [sym_protected_keyword] = ACTIONS(4373),
    [sym_event_keyword] = ACTIONS(4373),
    [sym_fields_keyword] = ACTIONS(4373),
    [sym_keys_keyword] = ACTIONS(4373),
    [sym_key_keyword] = ACTIONS(4373),
    [sym_fieldgroups_keyword] = ACTIONS(4373),
    [sym_actions_keyword] = ACTIONS(4373),
    [sym_layout_keyword] = ACTIONS(4373),
    [sym_area_keyword] = ACTIONS(4373),
    [sym_group_keyword] = ACTIONS(4373),
    [sym_repeater_keyword] = ACTIONS(4373),
    [sym_cuegroup_keyword] = ACTIONS(4373),
    [sym_fixed_keyword] = ACTIONS(4373),
    [sym_grid_keyword] = ACTIONS(4373),
    [sym_part_keyword] = ACTIONS(4373),
    [sym_systempart_keyword] = ACTIONS(4373),
    [sym_usercontrol_keyword] = ACTIONS(4373),
    [sym_dataset_keyword] = ACTIONS(4373),
    [sym_elements_keyword] = ACTIONS(4373),
    [sym_dataitem_keyword] = ACTIONS(4373),
    [sym_column_keyword] = ACTIONS(4373),
    [sym_filter_keyword] = ACTIONS(4373),
    [sym_labels_keyword] = ACTIONS(4373),
    [sym_rendering_keyword] = ACTIONS(4373),
    [sym_requestpage_keyword] = ACTIONS(4373),
    [sym_schema_keyword] = ACTIONS(4373),
    [sym_views_keyword] = ACTIONS(4373),
    [sym_quoted_identifier] = ACTIONS(4377),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4377),
    [sym_preproc_open] = ACTIONS(4377),
    [sym_var_attribute_open] = ACTIONS(4377),
  },
  [STATE(3861)] = {
    [sym_identifier] = ACTIONS(4383),
    [anon_sym_SEMI] = ACTIONS(4387),
    [anon_sym_RBRACE] = ACTIONS(4387),
    [aux_sym_where_condition_token1] = ACTIONS(4383),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4383),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4383),
    [anon_sym_LBRACK] = ACTIONS(4387),
    [aux_sym_basic_type_token6] = ACTIONS(4383),
    [aux_sym_basic_type_token22] = ACTIONS(4383),
    [aux_sym_basic_type_token53] = ACTIONS(4383),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4383),
    [aux_sym_addafter_modification_token1] = ACTIONS(4383),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4383),
    [aux_sym_modify_modification_token1] = ACTIONS(4383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4383),
    [aux_sym_movelast_modification_token1] = ACTIONS(4383),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4383),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4383),
    [aux_sym_separator_action_token1] = ACTIONS(4383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4383),
    [aux_sym_type_declaration_token1] = ACTIONS(4383),
    [anon_sym_POUNDif] = ACTIONS(4387),
    [anon_sym_POUNDIF] = ACTIONS(4387),
    [anon_sym_POUNDIf] = ACTIONS(4387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4383),
    [sym_trigger_keyword] = ACTIONS(4383),
    [sym_var_keyword] = ACTIONS(4383),
    [sym_local_keyword] = ACTIONS(4383),
    [sym_internal_keyword] = ACTIONS(4383),
    [sym_protected_keyword] = ACTIONS(4383),
    [sym_event_keyword] = ACTIONS(4383),
    [sym_fields_keyword] = ACTIONS(4383),
    [sym_keys_keyword] = ACTIONS(4383),
    [sym_key_keyword] = ACTIONS(4383),
    [sym_fieldgroups_keyword] = ACTIONS(4383),
    [sym_actions_keyword] = ACTIONS(4383),
    [sym_layout_keyword] = ACTIONS(4383),
    [sym_area_keyword] = ACTIONS(4383),
    [sym_group_keyword] = ACTIONS(4383),
    [sym_repeater_keyword] = ACTIONS(4383),
    [sym_cuegroup_keyword] = ACTIONS(4383),
    [sym_fixed_keyword] = ACTIONS(4383),
    [sym_grid_keyword] = ACTIONS(4383),
    [sym_part_keyword] = ACTIONS(4383),
    [sym_systempart_keyword] = ACTIONS(4383),
    [sym_usercontrol_keyword] = ACTIONS(4383),
    [sym_dataset_keyword] = ACTIONS(4383),
    [sym_elements_keyword] = ACTIONS(4383),
    [sym_dataitem_keyword] = ACTIONS(4383),
    [sym_column_keyword] = ACTIONS(4383),
    [sym_filter_keyword] = ACTIONS(4383),
    [sym_labels_keyword] = ACTIONS(4383),
    [sym_rendering_keyword] = ACTIONS(4383),
    [sym_requestpage_keyword] = ACTIONS(4383),
    [sym_schema_keyword] = ACTIONS(4383),
    [sym_views_keyword] = ACTIONS(4383),
    [sym_quoted_identifier] = ACTIONS(4387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4387),
    [sym_var_attribute_open] = ACTIONS(4387),
  },
  [STATE(3862)] = {
    [sym_identifier] = ACTIONS(4447),
    [anon_sym_SEMI] = ACTIONS(4449),
    [anon_sym_RBRACE] = ACTIONS(4449),
    [aux_sym_where_condition_token1] = ACTIONS(4447),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4447),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4447),
    [anon_sym_LBRACK] = ACTIONS(4449),
    [aux_sym_basic_type_token6] = ACTIONS(4447),
    [aux_sym_basic_type_token22] = ACTIONS(4447),
    [aux_sym_basic_type_token53] = ACTIONS(4447),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4447),
    [aux_sym_addafter_modification_token1] = ACTIONS(4447),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(4447),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4447),
    [aux_sym_movelast_modification_token1] = ACTIONS(4447),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4447),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4447),
    [aux_sym_separator_action_token1] = ACTIONS(4447),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4447),
    [aux_sym_type_declaration_token1] = ACTIONS(4447),
    [anon_sym_POUNDif] = ACTIONS(4449),
    [anon_sym_POUNDIF] = ACTIONS(4449),
    [anon_sym_POUNDIf] = ACTIONS(4449),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4447),
    [sym_trigger_keyword] = ACTIONS(4447),
    [sym_var_keyword] = ACTIONS(4447),
    [sym_local_keyword] = ACTIONS(4447),
    [sym_internal_keyword] = ACTIONS(4447),
    [sym_protected_keyword] = ACTIONS(4447),
    [sym_event_keyword] = ACTIONS(4447),
    [sym_fields_keyword] = ACTIONS(4447),
    [sym_keys_keyword] = ACTIONS(4447),
    [sym_key_keyword] = ACTIONS(4447),
    [sym_fieldgroups_keyword] = ACTIONS(4447),
    [sym_actions_keyword] = ACTIONS(4447),
    [sym_layout_keyword] = ACTIONS(4447),
    [sym_area_keyword] = ACTIONS(4447),
    [sym_group_keyword] = ACTIONS(4447),
    [sym_repeater_keyword] = ACTIONS(4447),
    [sym_cuegroup_keyword] = ACTIONS(4447),
    [sym_fixed_keyword] = ACTIONS(4447),
    [sym_grid_keyword] = ACTIONS(4447),
    [sym_part_keyword] = ACTIONS(4447),
    [sym_systempart_keyword] = ACTIONS(4447),
    [sym_usercontrol_keyword] = ACTIONS(4447),
    [sym_dataset_keyword] = ACTIONS(4447),
    [sym_elements_keyword] = ACTIONS(4447),
    [sym_dataitem_keyword] = ACTIONS(4447),
    [sym_column_keyword] = ACTIONS(4447),
    [sym_filter_keyword] = ACTIONS(4447),
    [sym_labels_keyword] = ACTIONS(4447),
    [sym_rendering_keyword] = ACTIONS(4447),
    [sym_requestpage_keyword] = ACTIONS(4447),
    [sym_schema_keyword] = ACTIONS(4447),
    [sym_views_keyword] = ACTIONS(4447),
    [sym_quoted_identifier] = ACTIONS(4449),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4449),
    [sym_preproc_open] = ACTIONS(4449),
    [sym_var_attribute_open] = ACTIONS(4449),
  },
  [STATE(3863)] = {
    [sym_identifier] = ACTIONS(4451),
    [anon_sym_SEMI] = ACTIONS(4453),
    [anon_sym_RBRACE] = ACTIONS(4453),
    [aux_sym_where_condition_token1] = ACTIONS(4451),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4451),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4451),
    [anon_sym_LBRACK] = ACTIONS(4453),
    [aux_sym_basic_type_token6] = ACTIONS(4451),
    [aux_sym_basic_type_token22] = ACTIONS(4451),
    [aux_sym_basic_type_token53] = ACTIONS(4451),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4451),
    [aux_sym_addafter_modification_token1] = ACTIONS(4451),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4451),
    [aux_sym_modify_modification_token1] = ACTIONS(4451),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4451),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4451),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4451),
    [aux_sym_separator_action_token1] = ACTIONS(4451),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4451),
    [aux_sym_type_declaration_token1] = ACTIONS(4451),
    [anon_sym_POUNDif] = ACTIONS(4453),
    [anon_sym_POUNDIF] = ACTIONS(4453),
    [anon_sym_POUNDIf] = ACTIONS(4453),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4451),
    [sym_trigger_keyword] = ACTIONS(4451),
    [sym_var_keyword] = ACTIONS(4451),
    [sym_local_keyword] = ACTIONS(4451),
    [sym_internal_keyword] = ACTIONS(4451),
    [sym_protected_keyword] = ACTIONS(4451),
    [sym_event_keyword] = ACTIONS(4451),
    [sym_fields_keyword] = ACTIONS(4451),
    [sym_keys_keyword] = ACTIONS(4451),
    [sym_key_keyword] = ACTIONS(4451),
    [sym_fieldgroups_keyword] = ACTIONS(4451),
    [sym_actions_keyword] = ACTIONS(4451),
    [sym_layout_keyword] = ACTIONS(4451),
    [sym_area_keyword] = ACTIONS(4451),
    [sym_group_keyword] = ACTIONS(4451),
    [sym_repeater_keyword] = ACTIONS(4451),
    [sym_cuegroup_keyword] = ACTIONS(4451),
    [sym_fixed_keyword] = ACTIONS(4451),
    [sym_grid_keyword] = ACTIONS(4451),
    [sym_part_keyword] = ACTIONS(4451),
    [sym_systempart_keyword] = ACTIONS(4451),
    [sym_usercontrol_keyword] = ACTIONS(4451),
    [sym_dataset_keyword] = ACTIONS(4451),
    [sym_elements_keyword] = ACTIONS(4451),
    [sym_dataitem_keyword] = ACTIONS(4451),
    [sym_column_keyword] = ACTIONS(4451),
    [sym_filter_keyword] = ACTIONS(4451),
    [sym_labels_keyword] = ACTIONS(4451),
    [sym_rendering_keyword] = ACTIONS(4451),
    [sym_requestpage_keyword] = ACTIONS(4451),
    [sym_schema_keyword] = ACTIONS(4451),
    [sym_views_keyword] = ACTIONS(4451),
    [sym_quoted_identifier] = ACTIONS(4453),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4453),
    [sym_preproc_open] = ACTIONS(4453),
    [sym_var_attribute_open] = ACTIONS(4453),
  },
  [STATE(3864)] = {
    [sym_identifier] = ACTIONS(7166),
    [anon_sym_SEMI] = ACTIONS(7168),
    [anon_sym_RBRACE] = ACTIONS(7168),
    [aux_sym_where_condition_token1] = ACTIONS(7166),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7166),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7166),
    [anon_sym_LBRACK] = ACTIONS(7168),
    [aux_sym_basic_type_token6] = ACTIONS(7166),
    [aux_sym_basic_type_token22] = ACTIONS(7166),
    [aux_sym_basic_type_token53] = ACTIONS(7166),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7166),
    [aux_sym_addafter_modification_token1] = ACTIONS(7166),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7166),
    [aux_sym_modify_modification_token1] = ACTIONS(7166),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7166),
    [aux_sym_movelast_modification_token1] = ACTIONS(7166),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7166),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7166),
    [aux_sym_separator_action_token1] = ACTIONS(7166),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7166),
    [aux_sym_type_declaration_token1] = ACTIONS(7166),
    [anon_sym_POUNDif] = ACTIONS(7168),
    [anon_sym_POUNDIF] = ACTIONS(7168),
    [anon_sym_POUNDIf] = ACTIONS(7168),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7166),
    [sym_trigger_keyword] = ACTIONS(7166),
    [sym_var_keyword] = ACTIONS(7166),
    [sym_local_keyword] = ACTIONS(7166),
    [sym_internal_keyword] = ACTIONS(7166),
    [sym_protected_keyword] = ACTIONS(7166),
    [sym_event_keyword] = ACTIONS(7166),
    [sym_fields_keyword] = ACTIONS(7166),
    [sym_keys_keyword] = ACTIONS(7166),
    [sym_key_keyword] = ACTIONS(7166),
    [sym_fieldgroups_keyword] = ACTIONS(7166),
    [sym_actions_keyword] = ACTIONS(7166),
    [sym_layout_keyword] = ACTIONS(7166),
    [sym_area_keyword] = ACTIONS(7166),
    [sym_group_keyword] = ACTIONS(7166),
    [sym_repeater_keyword] = ACTIONS(7166),
    [sym_cuegroup_keyword] = ACTIONS(7166),
    [sym_fixed_keyword] = ACTIONS(7166),
    [sym_grid_keyword] = ACTIONS(7166),
    [sym_part_keyword] = ACTIONS(7166),
    [sym_systempart_keyword] = ACTIONS(7166),
    [sym_usercontrol_keyword] = ACTIONS(7166),
    [sym_dataset_keyword] = ACTIONS(7166),
    [sym_elements_keyword] = ACTIONS(7166),
    [sym_dataitem_keyword] = ACTIONS(7166),
    [sym_column_keyword] = ACTIONS(7166),
    [sym_filter_keyword] = ACTIONS(7166),
    [sym_labels_keyword] = ACTIONS(7166),
    [sym_rendering_keyword] = ACTIONS(7166),
    [sym_requestpage_keyword] = ACTIONS(7166),
    [sym_schema_keyword] = ACTIONS(7166),
    [sym_views_keyword] = ACTIONS(7166),
    [sym_quoted_identifier] = ACTIONS(7168),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7168),
    [sym_preproc_open] = ACTIONS(7168),
    [sym_var_attribute_open] = ACTIONS(7168),
  },
  [STATE(3865)] = {
    [sym_identifier] = ACTIONS(7937),
    [anon_sym_SEMI] = ACTIONS(7939),
    [anon_sym_RBRACE] = ACTIONS(7939),
    [aux_sym_where_condition_token1] = ACTIONS(7937),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7937),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7937),
    [anon_sym_LBRACK] = ACTIONS(7939),
    [aux_sym_basic_type_token6] = ACTIONS(7937),
    [aux_sym_basic_type_token22] = ACTIONS(7937),
    [aux_sym_basic_type_token53] = ACTIONS(7937),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7937),
    [aux_sym_addafter_modification_token1] = ACTIONS(7937),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7937),
    [aux_sym_modify_modification_token1] = ACTIONS(7937),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7937),
    [aux_sym_movelast_modification_token1] = ACTIONS(7937),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7937),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7937),
    [aux_sym_separator_action_token1] = ACTIONS(7937),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7937),
    [aux_sym_type_declaration_token1] = ACTIONS(7937),
    [anon_sym_POUNDif] = ACTIONS(7939),
    [anon_sym_POUNDIF] = ACTIONS(7939),
    [anon_sym_POUNDIf] = ACTIONS(7939),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7937),
    [sym_trigger_keyword] = ACTIONS(7937),
    [sym_var_keyword] = ACTIONS(7937),
    [sym_local_keyword] = ACTIONS(7937),
    [sym_internal_keyword] = ACTIONS(7937),
    [sym_protected_keyword] = ACTIONS(7937),
    [sym_event_keyword] = ACTIONS(7937),
    [sym_fields_keyword] = ACTIONS(7937),
    [sym_keys_keyword] = ACTIONS(7937),
    [sym_key_keyword] = ACTIONS(7937),
    [sym_fieldgroups_keyword] = ACTIONS(7937),
    [sym_actions_keyword] = ACTIONS(7937),
    [sym_layout_keyword] = ACTIONS(7937),
    [sym_area_keyword] = ACTIONS(7937),
    [sym_group_keyword] = ACTIONS(7937),
    [sym_repeater_keyword] = ACTIONS(7937),
    [sym_cuegroup_keyword] = ACTIONS(7937),
    [sym_fixed_keyword] = ACTIONS(7937),
    [sym_grid_keyword] = ACTIONS(7937),
    [sym_part_keyword] = ACTIONS(7937),
    [sym_systempart_keyword] = ACTIONS(7937),
    [sym_usercontrol_keyword] = ACTIONS(7937),
    [sym_dataset_keyword] = ACTIONS(7937),
    [sym_elements_keyword] = ACTIONS(7937),
    [sym_dataitem_keyword] = ACTIONS(7937),
    [sym_column_keyword] = ACTIONS(7937),
    [sym_filter_keyword] = ACTIONS(7937),
    [sym_labels_keyword] = ACTIONS(7937),
    [sym_rendering_keyword] = ACTIONS(7937),
    [sym_requestpage_keyword] = ACTIONS(7937),
    [sym_schema_keyword] = ACTIONS(7937),
    [sym_views_keyword] = ACTIONS(7937),
    [sym_quoted_identifier] = ACTIONS(7939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7939),
    [sym_preproc_open] = ACTIONS(7939),
    [sym_var_attribute_open] = ACTIONS(7939),
  },
  [STATE(3866)] = {
    [sym_identifier] = ACTIONS(7166),
    [anon_sym_SEMI] = ACTIONS(7168),
    [anon_sym_RBRACE] = ACTIONS(7168),
    [aux_sym_where_condition_token1] = ACTIONS(7166),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7166),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7166),
    [anon_sym_LBRACK] = ACTIONS(7168),
    [aux_sym_basic_type_token6] = ACTIONS(7166),
    [aux_sym_basic_type_token22] = ACTIONS(7166),
    [aux_sym_basic_type_token53] = ACTIONS(7166),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7166),
    [aux_sym_addafter_modification_token1] = ACTIONS(7166),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7166),
    [aux_sym_modify_modification_token1] = ACTIONS(7166),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7166),
    [aux_sym_movelast_modification_token1] = ACTIONS(7166),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7166),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7166),
    [aux_sym_separator_action_token1] = ACTIONS(7166),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7166),
    [aux_sym_type_declaration_token1] = ACTIONS(7166),
    [anon_sym_POUNDif] = ACTIONS(7168),
    [anon_sym_POUNDIF] = ACTIONS(7168),
    [anon_sym_POUNDIf] = ACTIONS(7168),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7166),
    [sym_trigger_keyword] = ACTIONS(7166),
    [sym_var_keyword] = ACTIONS(7166),
    [sym_local_keyword] = ACTIONS(7166),
    [sym_internal_keyword] = ACTIONS(7166),
    [sym_protected_keyword] = ACTIONS(7166),
    [sym_event_keyword] = ACTIONS(7166),
    [sym_fields_keyword] = ACTIONS(7166),
    [sym_keys_keyword] = ACTIONS(7166),
    [sym_key_keyword] = ACTIONS(7166),
    [sym_fieldgroups_keyword] = ACTIONS(7166),
    [sym_actions_keyword] = ACTIONS(7166),
    [sym_layout_keyword] = ACTIONS(7166),
    [sym_area_keyword] = ACTIONS(7166),
    [sym_group_keyword] = ACTIONS(7166),
    [sym_repeater_keyword] = ACTIONS(7166),
    [sym_cuegroup_keyword] = ACTIONS(7166),
    [sym_fixed_keyword] = ACTIONS(7166),
    [sym_grid_keyword] = ACTIONS(7166),
    [sym_part_keyword] = ACTIONS(7166),
    [sym_systempart_keyword] = ACTIONS(7166),
    [sym_usercontrol_keyword] = ACTIONS(7166),
    [sym_dataset_keyword] = ACTIONS(7166),
    [sym_elements_keyword] = ACTIONS(7166),
    [sym_dataitem_keyword] = ACTIONS(7166),
    [sym_column_keyword] = ACTIONS(7166),
    [sym_filter_keyword] = ACTIONS(7166),
    [sym_labels_keyword] = ACTIONS(7166),
    [sym_rendering_keyword] = ACTIONS(7166),
    [sym_requestpage_keyword] = ACTIONS(7166),
    [sym_schema_keyword] = ACTIONS(7166),
    [sym_views_keyword] = ACTIONS(7166),
    [sym_quoted_identifier] = ACTIONS(7168),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7168),
    [sym_preproc_open] = ACTIONS(7168),
    [sym_var_attribute_open] = ACTIONS(7168),
  },
  [STATE(3867)] = {
    [sym_preproc_conditional_controladdin] = STATE(3867),
    [sym__body_element] = STATE(3867),
    [sym_empty_statement] = STATE(3867),
    [sym_property] = STATE(3867),
    [sym_fields_section] = STATE(3867),
    [sym_keys_section] = STATE(3867),
    [sym_fieldgroups_section] = STATE(3867),
    [sym_enum_value_declaration] = STATE(3867),
    [sym_labels_section] = STATE(3867),
    [sym_layout_section] = STATE(3867),
    [sym_modify_modification] = STATE(3867),
    [sym_actions_section] = STATE(3867),
    [sym_views_section] = STATE(3867),
    [sym_dataset_section] = STATE(3867),
    [sym_requestpage_section] = STATE(3867),
    [sym_rendering_section] = STATE(3867),
    [sym_elements_section] = STATE(3867),
    [sym_schema_section] = STATE(3867),
    [sym_assembly_declaration] = STATE(3867),
    [sym_event_declaration] = STATE(3867),
    [sym_procedure] = STATE(3867),
    [sym_preproc_split_procedure] = STATE(3867),
    [sym_interface_procedure] = STATE(3867),
    [sym_procedure_modifier] = STATE(12573),
    [sym_trigger_declaration] = STATE(3867),
    [sym_var_section] = STATE(3867),
    [sym_attribute_item] = STATE(3867),
    [sym_preproc_conditional] = STATE(3867),
    [sym_preproc_if] = STATE(2633),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3867),
    [anon_sym_SEMI] = ACTIONS(10263),
    [anon_sym_RBRACE] = ACTIONS(7212),
    [anon_sym_LBRACK] = ACTIONS(10266),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10269),
    [aux_sym_modify_modification_token1] = ACTIONS(10272),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10275),
    [anon_sym_POUNDif] = ACTIONS(7209),
    [anon_sym_POUNDIF] = ACTIONS(7209),
    [anon_sym_POUNDIf] = ACTIONS(7209),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10278),
    [sym_trigger_keyword] = ACTIONS(10281),
    [sym_var_keyword] = ACTIONS(10284),
    [sym_local_keyword] = ACTIONS(10287),
    [sym_internal_keyword] = ACTIONS(7226),
    [sym_protected_keyword] = ACTIONS(10287),
    [sym_event_keyword] = ACTIONS(10290),
    [sym_fields_keyword] = ACTIONS(10293),
    [sym_keys_keyword] = ACTIONS(10296),
    [sym_fieldgroups_keyword] = ACTIONS(10299),
    [sym_actions_keyword] = ACTIONS(10302),
    [sym_layout_keyword] = ACTIONS(10305),
    [sym_dataset_keyword] = ACTIONS(10308),
    [sym_elements_keyword] = ACTIONS(10311),
    [sym_labels_keyword] = ACTIONS(10314),
    [sym_rendering_keyword] = ACTIONS(10317),
    [sym_requestpage_keyword] = ACTIONS(10320),
    [sym_schema_keyword] = ACTIONS(10323),
    [sym_views_keyword] = ACTIONS(10326),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10329),
    [sym_preproc_open] = ACTIONS(7209),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10152), 1,
      sym_procedure_keyword,
    ACTIONS(10332), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3887), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [125] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10152), 1,
      sym_procedure_keyword,
    ACTIONS(10334), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3876), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [250] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10152), 1,
      sym_procedure_keyword,
    ACTIONS(10336), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3886), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [375] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10152), 1,
      sym_procedure_keyword,
    ACTIONS(10338), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3893), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [500] = 4,
    ACTIONS(10342), 1,
      anon_sym_LBRACE,
    ACTIONS(10344), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10340), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [573] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10152), 1,
      sym_procedure_keyword,
    ACTIONS(10346), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3877), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [698] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10152), 1,
      sym_procedure_keyword,
    ACTIONS(10348), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3881), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [823] = 4,
    ACTIONS(10352), 1,
      anon_sym_LBRACE,
    ACTIONS(10354), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10350), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [896] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10152), 1,
      sym_procedure_keyword,
    ACTIONS(10356), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3893), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [1021] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10152), 1,
      sym_procedure_keyword,
    ACTIONS(10358), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3893), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [1146] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10152), 1,
      sym_procedure_keyword,
    ACTIONS(10360), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3893), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [1271] = 25,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10362), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    STATE(3890), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [1386] = 4,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    ACTIONS(10368), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10364), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [1459] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10152), 1,
      sym_procedure_keyword,
    ACTIONS(10370), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3893), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [1584] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10152), 1,
      sym_procedure_keyword,
    ACTIONS(10372), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3871), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [1709] = 4,
    ACTIONS(10376), 1,
      anon_sym_LBRACE,
    ACTIONS(10378), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10374), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [1782] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2266), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2268), 51,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      aux_sym_interface_declaration_token1,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      aux_sym_if_table_relation_token2,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_implements_keyword,
      sym_extends_keyword,
      sym_customizes_keyword,
      sym_temporary_keyword,
  [1853] = 4,
    ACTIONS(10382), 1,
      anon_sym_LBRACE,
    ACTIONS(10384), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10380), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [1926] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10152), 1,
      sym_procedure_keyword,
    ACTIONS(10386), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3893), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [2051] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10152), 1,
      sym_procedure_keyword,
    ACTIONS(10388), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3893), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [2176] = 3,
    ACTIONS(2843), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 56,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [2247] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10152), 1,
      sym_procedure_keyword,
    ACTIONS(10390), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3891), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [2372] = 25,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10392), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    STATE(3852), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [2487] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10152), 1,
      sym_procedure_keyword,
    ACTIONS(10394), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3893), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [2612] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10152), 1,
      sym_procedure_keyword,
    ACTIONS(10396), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3878), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [2737] = 30,
    ACTIONS(10398), 1,
      anon_sym_SEMI,
    ACTIONS(10401), 1,
      anon_sym_RBRACE,
    ACTIONS(10403), 1,
      anon_sym_LBRACK,
    ACTIONS(10406), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(10409), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10412), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(10418), 1,
      sym_procedure_keyword,
    ACTIONS(10421), 1,
      sym_trigger_keyword,
    ACTIONS(10424), 1,
      sym_var_keyword,
    ACTIONS(10430), 1,
      sym_internal_keyword,
    ACTIONS(10433), 1,
      sym_event_keyword,
    ACTIONS(10436), 1,
      sym_fields_keyword,
    ACTIONS(10439), 1,
      sym_keys_keyword,
    ACTIONS(10442), 1,
      sym_fieldgroups_keyword,
    ACTIONS(10445), 1,
      sym_actions_keyword,
    ACTIONS(10448), 1,
      sym_layout_keyword,
    ACTIONS(10451), 1,
      sym_dataset_keyword,
    ACTIONS(10454), 1,
      sym_elements_keyword,
    ACTIONS(10457), 1,
      sym_labels_keyword,
    ACTIONS(10460), 1,
      sym_rendering_keyword,
    ACTIONS(10463), 1,
      sym_requestpage_keyword,
    ACTIONS(10466), 1,
      sym_schema_keyword,
    ACTIONS(10469), 1,
      sym_views_keyword,
    ACTIONS(10472), 1,
      sym_property_name,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(10427), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10415), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3893), 27,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_interface_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_interface_declaration_repeat1,
  [2862] = 3,
    ACTIONS(9535), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9533), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [2932] = 3,
    ACTIONS(9527), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9525), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3002] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10475), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [3126] = 3,
    ACTIONS(9531), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9529), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3196] = 3,
    ACTIONS(9531), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9529), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3266] = 3,
    ACTIONS(9531), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9529), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3336] = 3,
    ACTIONS(9531), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9529), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3406] = 3,
    ACTIONS(9535), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9533), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3476] = 3,
    ACTIONS(9535), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9533), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3546] = 3,
    ACTIONS(9535), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9533), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3616] = 3,
    ACTIONS(10479), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10477), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3686] = 3,
    ACTIONS(10483), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10481), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3756] = 3,
    ACTIONS(10487), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10485), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3826] = 3,
    ACTIONS(10491), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10489), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3896] = 3,
    ACTIONS(10495), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10493), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3966] = 3,
    ACTIONS(10499), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10497), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4036] = 3,
    ACTIONS(10503), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10501), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4106] = 3,
    ACTIONS(10507), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10505), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4176] = 3,
    ACTIONS(10511), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10509), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4246] = 3,
    ACTIONS(10515), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10513), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4316] = 3,
    ACTIONS(10519), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10517), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4386] = 3,
    ACTIONS(10523), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10521), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4456] = 3,
    ACTIONS(10527), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10525), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4526] = 3,
    ACTIONS(10531), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10529), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4596] = 3,
    ACTIONS(10535), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10533), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4666] = 3,
    ACTIONS(10539), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10537), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4736] = 3,
    ACTIONS(9836), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9834), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4806] = 3,
    ACTIONS(9551), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9549), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4876] = 3,
    ACTIONS(9555), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9553), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4946] = 3,
    ACTIONS(9555), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9553), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5016] = 3,
    ACTIONS(9555), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9553), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5086] = 3,
    ACTIONS(10543), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10541), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5156] = 3,
    ACTIONS(10547), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10545), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5226] = 3,
    ACTIONS(10551), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10549), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5296] = 3,
    ACTIONS(10555), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10553), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5366] = 3,
    ACTIONS(10559), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10557), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5436] = 3,
    ACTIONS(10563), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10561), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5506] = 3,
    ACTIONS(10567), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10565), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5576] = 3,
    ACTIONS(10571), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10569), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5646] = 3,
    ACTIONS(10575), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10573), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5716] = 3,
    ACTIONS(9555), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9553), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5786] = 3,
    ACTIONS(10579), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10577), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5856] = 3,
    ACTIONS(10583), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10581), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5926] = 3,
    ACTIONS(10587), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10585), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5996] = 3,
    ACTIONS(10591), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10589), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6066] = 3,
    ACTIONS(10595), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10593), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6136] = 3,
    ACTIONS(10599), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10597), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6206] = 3,
    ACTIONS(9559), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9557), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6276] = 3,
    ACTIONS(9559), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9557), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6346] = 3,
    ACTIONS(10603), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10601), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6416] = 3,
    ACTIONS(10607), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10605), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6486] = 3,
    ACTIONS(10611), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10609), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6556] = 3,
    ACTIONS(10615), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10613), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6626] = 3,
    ACTIONS(10619), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10617), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6696] = 3,
    ACTIONS(9559), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9557), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6766] = 3,
    ACTIONS(9559), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9557), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6836] = 3,
    ACTIONS(10623), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10621), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6906] = 3,
    ACTIONS(8821), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8819), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6976] = 3,
    ACTIONS(8821), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8819), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7046] = 3,
    ACTIONS(8825), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8823), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7116] = 3,
    ACTIONS(8825), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8823), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7186] = 3,
    ACTIONS(8829), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8827), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7256] = 3,
    ACTIONS(10627), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10625), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7326] = 3,
    ACTIONS(8833), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7396] = 3,
    ACTIONS(8833), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7466] = 3,
    ACTIONS(8833), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7536] = 3,
    ACTIONS(10631), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10629), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7606] = 3,
    ACTIONS(8837), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7676] = 3,
    ACTIONS(8837), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7746] = 3,
    ACTIONS(8837), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7816] = 3,
    ACTIONS(9874), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9872), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7886] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10633), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4136), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [8010] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10635), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [8134] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10637), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [8258] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10639), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [8382] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10641), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [8506] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10643), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [8630] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10645), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [8754] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10647), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [8878] = 3,
    ACTIONS(9894), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9892), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [8948] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10649), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4068), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [9072] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10651), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [9196] = 3,
    ACTIONS(9918), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9916), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9266] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10653), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [9390] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10655), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [9514] = 3,
    ACTIONS(9922), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9920), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9584] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10657), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [9708] = 3,
    ACTIONS(10078), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10076), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9778] = 3,
    ACTIONS(9597), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9595), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9848] = 3,
    ACTIONS(9601), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9599), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9918] = 3,
    ACTIONS(9601), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9599), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9988] = 3,
    ACTIONS(9601), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9599), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10058] = 3,
    ACTIONS(9601), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9599), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10128] = 3,
    ACTIONS(9605), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9603), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10198] = 3,
    ACTIONS(9605), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9603), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10268] = 3,
    ACTIONS(9605), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9603), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10338] = 3,
    ACTIONS(9605), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9603), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10408] = 3,
    ACTIONS(9609), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9607), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10478] = 3,
    ACTIONS(9609), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9607), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10548] = 3,
    ACTIONS(10661), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10659), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10618] = 3,
    ACTIONS(10665), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10663), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10688] = 3,
    ACTIONS(10669), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10667), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10758] = 3,
    ACTIONS(10673), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10671), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10828] = 3,
    ACTIONS(10677), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10675), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10898] = 3,
    ACTIONS(10681), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10679), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10968] = 3,
    ACTIONS(9613), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9611), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11038] = 3,
    ACTIONS(9613), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9611), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11108] = 3,
    ACTIONS(7375), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7377), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11178] = 3,
    ACTIONS(7375), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7377), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11248] = 3,
    ACTIONS(9926), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9924), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11318] = 3,
    ACTIONS(9944), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9942), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11388] = 3,
    ACTIONS(9948), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9946), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11458] = 3,
    ACTIONS(9952), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9950), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11528] = 3,
    ACTIONS(9956), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9954), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11598] = 3,
    ACTIONS(9973), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9971), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11668] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10683), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3977), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [11792] = 3,
    ACTIONS(8263), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8265), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11862] = 3,
    ACTIONS(9989), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9987), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11932] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10685), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [12056] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10687), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4015), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [12180] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10689), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [12304] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10691), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [12428] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10693), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4012), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [12552] = 3,
    ACTIONS(9822), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9820), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12622] = 3,
    ACTIONS(9507), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9505), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12692] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10695), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [12816] = 3,
    ACTIONS(9511), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9509), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12886] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10697), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4245), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [13010] = 3,
    ACTIONS(9515), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9513), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13080] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10699), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [13204] = 3,
    ACTIONS(9519), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9517), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13274] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10701), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [13398] = 3,
    ACTIONS(7575), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13468] = 3,
    ACTIONS(7575), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13538] = 3,
    ACTIONS(7575), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13608] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10703), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [13732] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10705), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4093), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [13856] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10707), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [13980] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10709), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4094), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [14104] = 3,
    ACTIONS(9523), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9521), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14174] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10711), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4202), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [14298] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10713), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [14422] = 3,
    ACTIONS(9645), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9643), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14492] = 3,
    ACTIONS(9649), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9647), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14562] = 3,
    ACTIONS(9649), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9647), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14632] = 3,
    ACTIONS(9653), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9651), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14702] = 3,
    ACTIONS(9653), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9651), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14772] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10715), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [14896] = 3,
    ACTIONS(9657), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9655), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14966] = 3,
    ACTIONS(9657), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9655), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15036] = 3,
    ACTIONS(9657), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9655), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15106] = 3,
    ACTIONS(9657), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9655), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15176] = 3,
    ACTIONS(9661), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9659), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15246] = 3,
    ACTIONS(9661), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9659), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15316] = 3,
    ACTIONS(9661), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9659), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15386] = 3,
    ACTIONS(9661), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9659), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15456] = 3,
    ACTIONS(8843), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8841), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15526] = 3,
    ACTIONS(8843), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8841), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15596] = 3,
    ACTIONS(8847), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8845), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15666] = 3,
    ACTIONS(8847), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8845), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15736] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10717), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4103), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [15860] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10719), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4104), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [15984] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10721), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4105), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [16108] = 3,
    ACTIONS(9539), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9537), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16178] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10723), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4106), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [16302] = 3,
    ACTIONS(10728), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10725), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16372] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10731), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [16496] = 4,
    ACTIONS(10736), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10738), 17,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
    ACTIONS(10733), 39,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16568] = 4,
    ACTIONS(10740), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10738), 24,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
    ACTIONS(10743), 32,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [16640] = 3,
    ACTIONS(9543), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9541), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16710] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10746), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4108), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [16834] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10748), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4109), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [16958] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10750), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4110), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [17082] = 3,
    ACTIONS(9547), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9545), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17152] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10752), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [17276] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10754), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4111), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [17400] = 3,
    ACTIONS(9669), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9667), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17470] = 3,
    ACTIONS(9669), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9667), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17540] = 3,
    ACTIONS(9669), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9667), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17610] = 3,
    ACTIONS(9669), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9667), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17680] = 3,
    ACTIONS(9673), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9671), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17750] = 3,
    ACTIONS(9673), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9671), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17820] = 3,
    ACTIONS(9673), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9671), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17890] = 3,
    ACTIONS(9673), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9671), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17960] = 3,
    ACTIONS(9677), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9675), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18030] = 3,
    ACTIONS(9681), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9679), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18100] = 3,
    ACTIONS(9681), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9679), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18170] = 3,
    ACTIONS(9681), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9679), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18240] = 3,
    ACTIONS(9681), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9679), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18310] = 3,
    ACTIONS(9685), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9683), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18380] = 3,
    ACTIONS(9685), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9683), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18450] = 3,
    ACTIONS(9685), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9683), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18520] = 3,
    ACTIONS(9685), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9683), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18590] = 3,
    ACTIONS(9589), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9587), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18660] = 3,
    ACTIONS(9593), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9591), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18730] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10756), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [18854] = 3,
    ACTIONS(9617), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9615), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18924] = 3,
    ACTIONS(7615), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7617), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18994] = 3,
    ACTIONS(7615), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7617), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19064] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10758), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [19188] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10760), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [19312] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10762), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4138), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [19436] = 4,
    ACTIONS(10764), 1,
      anon_sym_SEMI,
    ACTIONS(9733), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9735), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19508] = 3,
    ACTIONS(9739), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9737), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19578] = 3,
    ACTIONS(9739), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9737), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19648] = 5,
    ACTIONS(10768), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10772), 15,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(10770), 17,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
    ACTIONS(10766), 24,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19722] = 5,
    ACTIONS(10775), 1,
      anon_sym_COMMA,
    STATE(4100), 1,
      aux_sym_option_member_list_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(567), 15,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
      sym_string_literal,
      sym_integer,
    ACTIONS(565), 41,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      aux_sym_where_condition_token1,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [19796] = 3,
    ACTIONS(9743), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9741), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19866] = 3,
    ACTIONS(9743), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9741), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19936] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10778), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [20060] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10780), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [20184] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10782), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [20308] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10784), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [20432] = 3,
    ACTIONS(10786), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10772), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [20502] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10789), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [20626] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10791), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [20750] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10793), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [20874] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10795), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [20998] = 3,
    ACTIONS(9747), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9745), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21068] = 3,
    ACTIONS(9747), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9745), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21138] = 3,
    ACTIONS(9755), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9753), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21208] = 3,
    ACTIONS(9755), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9753), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21278] = 3,
    ACTIONS(9759), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9757), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21348] = 5,
    ACTIONS(10797), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10801), 15,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(10799), 17,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
    ACTIONS(9623), 24,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21422] = 3,
    ACTIONS(9759), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9757), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21492] = 3,
    ACTIONS(9759), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9757), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21562] = 3,
    ACTIONS(9759), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9757), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21632] = 3,
    ACTIONS(9763), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9761), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21702] = 3,
    ACTIONS(9763), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9761), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21772] = 3,
    ACTIONS(9763), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9761), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21842] = 3,
    ACTIONS(9763), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9761), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21912] = 3,
    ACTIONS(9621), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9619), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21982] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10804), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4332), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [22106] = 3,
    ACTIONS(10074), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10072), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22176] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10806), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [22300] = 3,
    ACTIONS(8696), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8694), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22370] = 3,
    ACTIONS(9625), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9623), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22440] = 4,
    ACTIONS(10810), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9348), 19,
      sym_continue_as_identifier,
      sym_preproc_close,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(10808), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [22512] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10812), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [22636] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10812), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4212), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [22760] = 3,
    ACTIONS(9567), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9565), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22830] = 4,
    ACTIONS(10814), 1,
      anon_sym_SEMI,
    ACTIONS(9567), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9565), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22902] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10816), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [23026] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10818), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4132), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [23150] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10820), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [23274] = 3,
    ACTIONS(9844), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9842), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23344] = 4,
    ACTIONS(10822), 1,
      anon_sym_SEMI,
    ACTIONS(9848), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9850), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23416] = 4,
    ACTIONS(10824), 1,
      anon_sym_SEMI,
    ACTIONS(9848), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9850), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23488] = 4,
    ACTIONS(10826), 1,
      anon_sym_SEMI,
    ACTIONS(9844), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9842), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23560] = 4,
    ACTIONS(10828), 1,
      anon_sym_SEMI,
    ACTIONS(9858), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9860), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23632] = 4,
    ACTIONS(10830), 1,
      anon_sym_SEMI,
    ACTIONS(9858), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9860), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23704] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10832), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4153), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [23828] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10834), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4154), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [23952] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10836), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [24076] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10838), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4161), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [24200] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10840), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4162), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [24324] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10842), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4163), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [24448] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10844), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4164), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [24572] = 4,
    ACTIONS(10846), 1,
      anon_sym_SEMI,
    ACTIONS(9866), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9868), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [24644] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10848), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [24768] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10850), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [24892] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10852), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4167), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [25016] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10854), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4169), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [25140] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10856), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4171), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [25264] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10858), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4172), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [25388] = 4,
    ACTIONS(10860), 1,
      anon_sym_SEMI,
    ACTIONS(9866), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9868), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [25460] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10862), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4176), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [25584] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10864), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [25708] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10866), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [25832] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10868), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [25956] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10870), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [26080] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10872), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4179), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [26204] = 4,
    ACTIONS(10874), 1,
      anon_sym_SEMI,
    ACTIONS(4373), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [26276] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10876), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [26400] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10878), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4181), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [26524] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10880), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [26648] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10880), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4184), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [26772] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10882), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [26896] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10884), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [27020] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10884), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4186), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [27144] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10886), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4318), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [27268] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10888), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4188), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [27392] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10890), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [27516] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10892), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4190), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [27640] = 3,
    ACTIONS(10894), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10801), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [27710] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10897), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [27834] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10899), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4204), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [27958] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10901), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [28082] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10903), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4206), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [28206] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10905), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4207), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [28330] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10907), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [28454] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10909), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4208), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [28578] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10911), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [28702] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10913), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4209), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [28826] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10915), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [28950] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10917), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4211), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [29074] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10919), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [29198] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10921), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4321), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [29322] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10923), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4147), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [29446] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10925), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [29570] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10925), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4217), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [29694] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10927), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4019), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [29818] = 3,
    ACTIONS(4373), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [29888] = 3,
    ACTIONS(9878), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9876), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [29958] = 3,
    ACTIONS(9878), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9876), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30028] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10929), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4216), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [30152] = 3,
    ACTIONS(9898), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9896), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30222] = 3,
    ACTIONS(9898), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9896), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30292] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10931), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [30416] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10933), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4023), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [30540] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10935), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [30664] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10937), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4222), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [30788] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10939), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [30912] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10941), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [31036] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10943), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [31160] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10945), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [31284] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10947), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4025), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [31408] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10949), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [31532] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10951), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [31656] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10953), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4226), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [31780] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10955), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4031), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [31904] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10957), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4089), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [32028] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10959), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [32152] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10961), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [32276] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10963), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4041), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [32400] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10965), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4246), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [32524] = 3,
    ACTIONS(8199), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32594] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10967), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4231), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [32718] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10969), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [32842] = 3,
    ACTIONS(8199), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32912] = 3,
    ACTIONS(8199), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32982] = 3,
    ACTIONS(8235), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8237), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [33052] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10971), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [33176] = 3,
    ACTIONS(9906), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9904), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [33246] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10973), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4248), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [33370] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10975), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4193), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [33494] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10977), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [33618] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10979), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [33742] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10981), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4253), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [33866] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10983), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4254), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [33990] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10985), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4251), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [34114] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10987), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4256), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [34238] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10989), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4257), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [34362] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10991), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4258), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [34486] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10993), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4259), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [34610] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10995), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4260), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [34734] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10997), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4261), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [34858] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(10999), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4262), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [34982] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11001), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4263), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [35106] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11003), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4542), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [35230] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11005), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4014), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [35354] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11007), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [35478] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11009), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [35602] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11011), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [35726] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11013), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [35850] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11015), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4265), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [35974] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11017), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4060), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [36098] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11019), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [36222] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11021), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4268), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [36346] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11023), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [36470] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11025), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [36594] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11027), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4271), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [36718] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11029), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [36842] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11031), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [36966] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11033), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [37090] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11035), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [37214] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11037), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [37338] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11039), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [37462] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11041), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [37586] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11043), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [37710] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11045), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4282), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [37834] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11047), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [37958] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11049), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4351), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [38082] = 3,
    ACTIONS(9981), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9979), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [38152] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11051), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [38276] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11053), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4291), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [38400] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11055), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4292), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [38524] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11057), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [38648] = 3,
    ACTIONS(9981), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9979), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [38718] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11059), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4297), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [38842] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11061), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4298), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [38966] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11063), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4299), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [39090] = 3,
    ACTIONS(9985), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9983), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [39160] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11065), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4300), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [39284] = 4,
    ACTIONS(11067), 1,
      anon_sym_SEMI,
    ACTIONS(9996), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9998), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [39356] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11069), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4302), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [39480] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11071), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4303), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [39604] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11073), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4304), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [39728] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11075), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [39852] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11077), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4305), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [39976] = 4,
    ACTIONS(11079), 1,
      anon_sym_SEMI,
    ACTIONS(9996), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9998), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [40048] = 3,
    ACTIONS(10004), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10002), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [40118] = 3,
    ACTIONS(10004), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10002), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [40188] = 4,
    ACTIONS(11081), 1,
      anon_sym_SEMI,
    ACTIONS(10008), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10010), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [40260] = 4,
    ACTIONS(11083), 1,
      anon_sym_SEMI,
    ACTIONS(10008), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10010), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [40332] = 4,
    ACTIONS(11085), 1,
      anon_sym_SEMI,
    ACTIONS(10004), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10002), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [40404] = 4,
    ACTIONS(11087), 1,
      anon_sym_SEMI,
    ACTIONS(10004), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10002), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [40476] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11089), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [40600] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11091), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [40724] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11093), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4311), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [40848] = 3,
    ACTIONS(10020), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10018), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [40918] = 3,
    ACTIONS(10020), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10018), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [40988] = 4,
    ACTIONS(11095), 1,
      anon_sym_SEMI,
    ACTIONS(10024), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10026), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [41060] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11097), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [41184] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11099), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [41308] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11101), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [41432] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11103), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [41556] = 4,
    ACTIONS(11105), 1,
      anon_sym_SEMI,
    ACTIONS(10024), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10026), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [41628] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11107), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [41752] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11109), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [41876] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11111), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [42000] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11113), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [42124] = 4,
    ACTIONS(11115), 1,
      anon_sym_SEMI,
    ACTIONS(10020), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10018), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [42196] = 4,
    ACTIONS(11117), 1,
      anon_sym_SEMI,
    ACTIONS(10020), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10018), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [42268] = 4,
    ACTIONS(11119), 1,
      anon_sym_SEMI,
    ACTIONS(10036), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10038), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [42340] = 4,
    ACTIONS(11121), 1,
      anon_sym_SEMI,
    ACTIONS(10036), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10038), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [42412] = 4,
    ACTIONS(11123), 1,
      anon_sym_SEMI,
    ACTIONS(9985), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9983), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [42484] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11125), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [42608] = 4,
    ACTIONS(11127), 1,
      anon_sym_SEMI,
    ACTIONS(10046), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10048), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [42680] = 4,
    ACTIONS(11129), 1,
      anon_sym_SEMI,
    ACTIONS(10046), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10048), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [42752] = 4,
    ACTIONS(11131), 1,
      anon_sym_SEMI,
    ACTIONS(10054), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10056), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [42824] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11133), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4322), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [42948] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11135), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4324), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [43072] = 4,
    ACTIONS(11137), 1,
      anon_sym_SEMI,
    ACTIONS(10054), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10056), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [43144] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11139), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [43268] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11141), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4391), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [43392] = 3,
    ACTIONS(11145), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11143), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [43462] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11147), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [43586] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11149), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [43710] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11151), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4327), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [43834] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11153), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [43958] = 3,
    ACTIONS(9832), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9830), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [44028] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11155), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4405), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [44152] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11157), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [44276] = 3,
    ACTIONS(4399), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4401), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [44346] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11159), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [44470] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11161), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4334), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [44594] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11163), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4335), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [44718] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11165), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [44842] = 3,
    ACTIONS(9577), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9575), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [44912] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11167), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [45036] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11169), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [45160] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11171), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4338), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [45284] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11173), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4339), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [45408] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11175), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [45532] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11177), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [45656] = 3,
    ACTIONS(9581), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9579), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [45726] = 3,
    ACTIONS(9581), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9579), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [45796] = 3,
    ACTIONS(9585), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9583), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [45866] = 3,
    ACTIONS(9585), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9583), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [45936] = 3,
    ACTIONS(8783), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8781), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [46006] = 3,
    ACTIONS(8787), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8785), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [46076] = 3,
    ACTIONS(8791), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8789), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [46146] = 3,
    ACTIONS(4213), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4215), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [46216] = 3,
    ACTIONS(8928), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8926), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [46286] = 3,
    ACTIONS(9629), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9627), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [46356] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11179), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4585), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [46480] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11181), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [46604] = 3,
    ACTIONS(10082), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10080), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [46674] = 3,
    ACTIONS(10082), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10080), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [46744] = 3,
    ACTIONS(10086), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10084), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [46814] = 3,
    ACTIONS(10086), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10084), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [46884] = 3,
    ACTIONS(10090), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10088), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [46954] = 3,
    ACTIONS(10090), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10088), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [47024] = 4,
    ACTIONS(11183), 1,
      anon_sym_SEMI,
    ACTIONS(10094), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10096), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [47096] = 4,
    ACTIONS(11185), 1,
      anon_sym_SEMI,
    ACTIONS(10094), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10096), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [47168] = 3,
    ACTIONS(10102), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10100), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [47238] = 3,
    ACTIONS(10102), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10100), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [47308] = 3,
    ACTIONS(10110), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10108), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [47378] = 3,
    ACTIONS(10110), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10108), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [47448] = 4,
    ACTIONS(11187), 1,
      anon_sym_SEMI,
    ACTIONS(9493), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9495), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [47520] = 4,
    ACTIONS(11189), 1,
      anon_sym_SEMI,
    ACTIONS(9493), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9495), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [47592] = 3,
    ACTIONS(10116), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10114), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [47662] = 3,
    ACTIONS(10116), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10114), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [47732] = 4,
    ACTIONS(11191), 1,
      anon_sym_SEMI,
    ACTIONS(10120), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10122), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [47804] = 4,
    ACTIONS(11193), 1,
      anon_sym_SEMI,
    ACTIONS(10120), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10122), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [47876] = 4,
    ACTIONS(11195), 1,
      anon_sym_SEMI,
    ACTIONS(10116), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10114), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [47948] = 4,
    ACTIONS(11197), 1,
      anon_sym_SEMI,
    ACTIONS(10116), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10114), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [48020] = 3,
    ACTIONS(10132), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10130), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [48090] = 4,
    ACTIONS(11199), 1,
      anon_sym_SEMI,
    ACTIONS(10136), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10138), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [48162] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11201), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4377), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [48286] = 4,
    ACTIONS(11203), 1,
      anon_sym_SEMI,
    ACTIONS(10136), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10138), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [48358] = 3,
    ACTIONS(9934), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9936), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [48428] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11205), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [48552] = 3,
    ACTIONS(9934), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9936), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [48622] = 4,
    ACTIONS(11207), 1,
      anon_sym_SEMI,
    ACTIONS(10144), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10146), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [48694] = 4,
    ACTIONS(11209), 1,
      anon_sym_SEMI,
    ACTIONS(10144), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10146), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [48766] = 4,
    ACTIONS(11211), 1,
      anon_sym_SEMI,
    ACTIONS(9934), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9936), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [48838] = 4,
    ACTIONS(11213), 1,
      anon_sym_SEMI,
    ACTIONS(9934), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9936), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [48910] = 3,
    ACTIONS(9503), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9501), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [48980] = 3,
    ACTIONS(9503), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9501), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [49050] = 4,
    ACTIONS(11215), 1,
      anon_sym_SEMI,
    ACTIONS(9960), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9962), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [49122] = 4,
    ACTIONS(11217), 1,
      anon_sym_SEMI,
    ACTIONS(9960), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9962), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [49194] = 4,
    ACTIONS(11219), 1,
      anon_sym_SEMI,
    ACTIONS(9503), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9501), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [49266] = 4,
    ACTIONS(11221), 1,
      anon_sym_SEMI,
    ACTIONS(9503), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9501), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [49338] = 4,
    ACTIONS(11223), 1,
      anon_sym_SEMI,
    ACTIONS(10066), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10068), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [49410] = 4,
    ACTIONS(11225), 1,
      anon_sym_SEMI,
    ACTIONS(10066), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10068), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [49482] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11227), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [49606] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11229), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4394), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [49730] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11231), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4395), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [49854] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11233), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [49978] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11235), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [50102] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11237), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4406), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [50226] = 3,
    ACTIONS(9633), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9631), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [50296] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11239), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4411), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [50420] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11241), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4412), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [50544] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11243), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4413), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [50668] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11245), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4414), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [50792] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11247), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4415), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [50916] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11249), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4416), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [51040] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11251), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4417), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [51164] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11253), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [51288] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11255), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [51412] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11257), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4421), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [51536] = 3,
    ACTIONS(4403), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4405), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [51606] = 3,
    ACTIONS(4407), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4409), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [51676] = 3,
    ACTIONS(4411), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4413), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [51746] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11259), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [51870] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11261), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [51994] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11263), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [52118] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11265), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [52242] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11267), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [52366] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11269), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [52490] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11271), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [52614] = 3,
    ACTIONS(8471), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8473), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [52684] = 3,
    ACTIONS(4379), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4381), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [52754] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11273), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4427), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [52878] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11275), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [53002] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11277), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4431), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [53126] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11279), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4432), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [53250] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11281), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4433), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [53374] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11283), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4434), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [53498] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11285), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4435), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [53622] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11287), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [53746] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11289), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4436), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [53870] = 3,
    ACTIONS(8817), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8815), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [53940] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11291), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4247), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [54064] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11293), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [54188] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11295), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [54312] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11297), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [54436] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11299), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [54560] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11301), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [54684] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11303), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [54808] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11305), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4438), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [54932] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11307), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [55056] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11309), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4440), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [55180] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11311), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [55304] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11313), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4451), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [55428] = 3,
    ACTIONS(9499), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9497), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [55498] = 3,
    ACTIONS(9499), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9497), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [55568] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11315), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4457), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [55692] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11317), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4458), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [55816] = 3,
    ACTIONS(9563), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9561), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [55886] = 3,
    ACTIONS(9563), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9561), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [55956] = 3,
    ACTIONS(9665), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9663), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [56026] = 3,
    ACTIONS(9665), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9663), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [56096] = 3,
    ACTIONS(9695), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9693), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [56166] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11319), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [56290] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11321), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4464), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [56414] = 3,
    ACTIONS(9695), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9693), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [56484] = 4,
    ACTIONS(11323), 1,
      anon_sym_SEMI,
    ACTIONS(9767), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9769), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [56556] = 4,
    ACTIONS(11325), 1,
      anon_sym_SEMI,
    ACTIONS(9767), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9769), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [56628] = 3,
    ACTIONS(9914), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9912), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [56698] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11327), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [56822] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11329), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [56946] = 3,
    ACTIONS(9914), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9912), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [57016] = 3,
    ACTIONS(9930), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9928), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [57086] = 3,
    ACTIONS(9930), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9928), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [57156] = 3,
    ACTIONS(10106), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10104), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [57226] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11331), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4469), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [57350] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11333), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [57474] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11335), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4471), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [57598] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11337), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4472), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [57722] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11339), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4473), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [57846] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11341), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4474), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [57970] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11343), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [58094] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11345), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4475), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [58218] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11347), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [58342] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11349), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [58466] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11351), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [58590] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11353), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [58714] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11355), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [58838] = 3,
    ACTIONS(10106), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10104), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [58908] = 4,
    ACTIONS(11357), 1,
      anon_sym_SEMI,
    ACTIONS(9689), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9691), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [58980] = 4,
    ACTIONS(11359), 1,
      anon_sym_SEMI,
    ACTIONS(9689), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9691), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [59052] = 3,
    ACTIONS(9705), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9703), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [59122] = 3,
    ACTIONS(9705), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9703), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [59192] = 3,
    ACTIONS(9713), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9711), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [59262] = 3,
    ACTIONS(9713), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9711), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [59332] = 4,
    ACTIONS(11361), 1,
      anon_sym_SEMI,
    ACTIONS(9717), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9719), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [59404] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11363), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4489), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [59528] = 4,
    ACTIONS(11365), 1,
      anon_sym_SEMI,
    ACTIONS(9717), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9719), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [59600] = 3,
    ACTIONS(9840), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9838), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [59670] = 3,
    ACTIONS(9840), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9838), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [59740] = 4,
    ACTIONS(11367), 1,
      anon_sym_SEMI,
    ACTIONS(9882), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9884), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [59812] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11369), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [59936] = 4,
    ACTIONS(11371), 1,
      anon_sym_SEMI,
    ACTIONS(9882), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9884), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [60008] = 4,
    ACTIONS(11373), 1,
      anon_sym_SEMI,
    ACTIONS(9840), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9838), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [60080] = 4,
    ACTIONS(11375), 1,
      anon_sym_SEMI,
    ACTIONS(9840), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9838), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [60152] = 4,
    ACTIONS(11377), 1,
      anon_sym_SEMI,
    ACTIONS(4383), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [60224] = 4,
    ACTIONS(11379), 1,
      anon_sym_SEMI,
    ACTIONS(4383), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [60296] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11381), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4496), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [60420] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11383), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [60544] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11385), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4498), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [60668] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11387), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [60792] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11389), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4536), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [60916] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11391), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4502), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [61040] = 5,
    ACTIONS(11393), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10725), 15,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(11395), 17,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
    ACTIONS(9964), 24,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [61114] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11397), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [61238] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11399), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4504), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [61362] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11401), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [61486] = 3,
    ACTIONS(4383), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [61556] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11403), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4537), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [61680] = 3,
    ACTIONS(4415), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4417), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [61750] = 3,
    ACTIONS(4419), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4421), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [61820] = 3,
    ACTIONS(4423), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4425), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [61890] = 3,
    ACTIONS(4427), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4429), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [61960] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11405), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4514), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [62084] = 3,
    ACTIONS(4431), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4433), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [62154] = 3,
    ACTIONS(4435), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4437), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [62224] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11407), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [62348] = 3,
    ACTIONS(6976), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6978), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [62418] = 3,
    ACTIONS(6976), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6978), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [62488] = 3,
    ACTIONS(7152), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [62558] = 3,
    ACTIONS(7152), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [62628] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11409), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4521), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [62752] = 3,
    ACTIONS(7152), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [62822] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11411), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [62946] = 3,
    ACTIONS(9751), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9749), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [63016] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11413), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4230), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [63140] = 3,
    ACTIONS(9637), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9635), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [63210] = 3,
    ACTIONS(9637), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9635), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [63280] = 3,
    ACTIONS(9641), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9639), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [63350] = 3,
    ACTIONS(9641), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9639), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [63420] = 3,
    ACTIONS(9709), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9707), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [63490] = 3,
    ACTIONS(9709), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9707), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [63560] = 3,
    ACTIONS(9723), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9721), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [63630] = 3,
    ACTIONS(9723), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9721), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [63700] = 3,
    ACTIONS(9729), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9727), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [63770] = 3,
    ACTIONS(9729), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9727), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [63840] = 4,
    ACTIONS(11415), 1,
      anon_sym_SEMI,
    ACTIONS(9773), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9775), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [63912] = 4,
    ACTIONS(11417), 1,
      anon_sym_SEMI,
    ACTIONS(9773), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9775), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [63984] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11419), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [64108] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11421), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [64232] = 3,
    ACTIONS(4439), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4441), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [64302] = 3,
    ACTIONS(4443), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4445), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [64372] = 3,
    ACTIONS(4447), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4449), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [64442] = 3,
    ACTIONS(4451), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4453), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [64512] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11423), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [64636] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11425), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4607), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [64760] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11427), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4608), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [64884] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11429), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4128), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [65008] = 3,
    ACTIONS(9699), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9697), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [65078] = 3,
    ACTIONS(9699), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9697), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [65148] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11431), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4551), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [65272] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11433), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4552), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [65396] = 3,
    ACTIONS(4455), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [65466] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11435), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [65590] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11437), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [65714] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11439), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [65838] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11441), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3896), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [65962] = 3,
    ACTIONS(9793), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9791), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [66032] = 3,
    ACTIONS(9797), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9795), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [66102] = 3,
    ACTIONS(9797), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9795), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [66172] = 3,
    ACTIONS(9797), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9795), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [66242] = 3,
    ACTIONS(9797), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9795), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [66312] = 3,
    ACTIONS(9810), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9808), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [66382] = 3,
    ACTIONS(9810), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9808), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [66452] = 3,
    ACTIONS(9810), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9808), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [66522] = 3,
    ACTIONS(9810), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9808), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [66592] = 3,
    ACTIONS(9814), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9812), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [66662] = 3,
    ACTIONS(9814), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9812), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [66732] = 3,
    ACTIONS(9818), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9816), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [66802] = 3,
    ACTIONS(9818), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9816), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [66872] = 3,
    ACTIONS(8795), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8793), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [66942] = 3,
    ACTIONS(8799), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [67012] = 3,
    ACTIONS(8799), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [67082] = 3,
    ACTIONS(8799), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [67152] = 3,
    ACTIONS(8803), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [67222] = 3,
    ACTIONS(8803), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [67292] = 3,
    ACTIONS(8803), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [67362] = 3,
    ACTIONS(8807), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8805), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [67432] = 3,
    ACTIONS(8811), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8809), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [67502] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11443), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3966), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [67626] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11445), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3967), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [67750] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11447), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3968), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [67874] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11449), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3969), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [67998] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11451), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3970), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [68122] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11453), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3971), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [68246] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11455), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3972), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [68370] = 30,
    ACTIONS(8722), 1,
      anon_sym_RBRACE,
    ACTIONS(8736), 1,
      sym_internal_keyword,
    ACTIONS(11457), 1,
      anon_sym_SEMI,
    ACTIONS(11460), 1,
      anon_sym_LBRACK,
    ACTIONS(11463), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(11466), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11469), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(11472), 1,
      sym_procedure_keyword,
    ACTIONS(11475), 1,
      sym_trigger_keyword,
    ACTIONS(11478), 1,
      sym_var_keyword,
    ACTIONS(11484), 1,
      sym_event_keyword,
    ACTIONS(11487), 1,
      sym_fields_keyword,
    ACTIONS(11490), 1,
      sym_keys_keyword,
    ACTIONS(11493), 1,
      sym_fieldgroups_keyword,
    ACTIONS(11496), 1,
      sym_actions_keyword,
    ACTIONS(11499), 1,
      sym_layout_keyword,
    ACTIONS(11502), 1,
      sym_dataset_keyword,
    ACTIONS(11505), 1,
      sym_elements_keyword,
    ACTIONS(11508), 1,
      sym_labels_keyword,
    ACTIONS(11511), 1,
      sym_rendering_keyword,
    ACTIONS(11514), 1,
      sym_requestpage_keyword,
    ACTIONS(11517), 1,
      sym_schema_keyword,
    ACTIONS(11520), 1,
      sym_views_keyword,
    ACTIONS(11523), 1,
      sym_property_name,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(11481), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(8719), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [68494] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11526), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [68618] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11528), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3975), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [68742] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11530), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3978), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [68866] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11532), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3980), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [68990] = 3,
    ACTIONS(9902), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9900), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [69060] = 3,
    ACTIONS(9910), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9908), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [69130] = 3,
    ACTIONS(9910), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9908), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [69200] = 3,
    ACTIONS(9940), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9938), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [69270] = 3,
    ACTIONS(9940), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9938), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [69340] = 3,
    ACTIONS(7166), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [69410] = 3,
    ACTIONS(7166), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [69480] = 3,
    ACTIONS(7166), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [69550] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11534), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4553), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [69674] = 3,
    ACTIONS(8944), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8942), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [69744] = 18,
    ACTIONS(2199), 1,
      anon_sym_COMMA,
    ACTIONS(2221), 1,
      aux_sym_basic_type_token22,
    ACTIONS(11536), 1,
      anon_sym_DASH,
    STATE(4624), 1,
      aux_sym_option_member_list_repeat2,
    STATE(4805), 1,
      sym_option_member_list,
    STATE(9302), 1,
      sym_option_member,
    ACTIONS(911), 2,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
    ACTIONS(275), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(3706), 3,
      sym_quoted_identifier,
      sym_string_literal,
      sym_integer,
    STATE(4642), 3,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
      sym_enum_keyword,
    STATE(4795), 3,
      sym_boolean,
      sym_keyword_identifier,
      sym_keyword_as_identifier,
    ACTIONS(2239), 4,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(27), 6,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
    ACTIONS(935), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(937), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
    ACTIONS(2209), 7,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(917), 9,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token48,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
  [69844] = 3,
    ACTIONS(4395), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [69914] = 3,
    ACTIONS(4395), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [69984] = 3,
    ACTIONS(7367), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7369), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [70054] = 3,
    ACTIONS(7371), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7373), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [70124] = 3,
    ACTIONS(7371), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7373), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [70194] = 3,
    ACTIONS(10797), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10799), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [70264] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11538), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4029), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [70388] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11540), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [70512] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11542), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4584), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [70636] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11544), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4035), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [70760] = 3,
    ACTIONS(11548), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11546), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [70830] = 4,
    ACTIONS(11550), 1,
      anon_sym_SEMI,
    ACTIONS(9826), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9828), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [70902] = 3,
    ACTIONS(11554), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11552), 56,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [70972] = 30,
    ACTIONS(2891), 1,
      sym_internal_keyword,
    ACTIONS(3793), 1,
      anon_sym_SEMI,
    ACTIONS(3803), 1,
      anon_sym_LBRACK,
    ACTIONS(3807), 1,
      aux_sym_enum_value_declaration_token1,
    ACTIONS(3813), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3823), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3825), 1,
      sym_procedure_keyword,
    ACTIONS(3827), 1,
      sym_trigger_keyword,
    ACTIONS(3829), 1,
      sym_var_keyword,
    ACTIONS(3833), 1,
      sym_event_keyword,
    ACTIONS(3835), 1,
      sym_fields_keyword,
    ACTIONS(3837), 1,
      sym_keys_keyword,
    ACTIONS(3839), 1,
      sym_fieldgroups_keyword,
    ACTIONS(3841), 1,
      sym_actions_keyword,
    ACTIONS(3843), 1,
      sym_layout_keyword,
    ACTIONS(3863), 1,
      sym_dataset_keyword,
    ACTIONS(3865), 1,
      sym_elements_keyword,
    ACTIONS(3867), 1,
      sym_labels_keyword,
    ACTIONS(3869), 1,
      sym_rendering_keyword,
    ACTIONS(3871), 1,
      sym_requestpage_keyword,
    ACTIONS(3873), 1,
      sym_schema_keyword,
    ACTIONS(3875), 1,
      sym_views_keyword,
    ACTIONS(3877), 1,
      sym_property_name,
    ACTIONS(11556), 1,
      anon_sym_RBRACE,
    STATE(2724), 1,
      sym_preproc_if,
    STATE(12573), 1,
      sym_procedure_modifier,
    ACTIONS(3831), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(2875), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4329), 26,
      sym__body_element,
      sym_empty_statement,
      sym_property,
      sym_fields_section,
      sym_keys_section,
      sym_fieldgroups_section,
      sym_enum_value_declaration,
      sym_labels_section,
      sym_layout_section,
      sym_modify_modification,
      sym_actions_section,
      sym_views_section,
      sym_dataset_section,
      sym_requestpage_section,
      sym_rendering_section,
      sym_elements_section,
      sym_schema_section,
      sym_assembly_declaration,
      sym_event_declaration,
      sym_procedure,
      sym_preproc_split_procedure,
      sym_trigger_declaration,
      sym_var_section,
      sym_attribute_item,
      sym_preproc_conditional,
      aux_sym_preproc_split_declaration_repeat2,
  [71096] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9481), 19,
      sym_continue_as_identifier,
      sym_preproc_close,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11558), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [71165] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4465), 19,
      sym_continue_as_identifier,
      sym_preproc_close,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(4463), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [71234] = 6,
    ACTIONS(4121), 1,
      anon_sym_SEMI,
    STATE(389), 1,
      sym_else_keyword,
    ACTIONS(8972), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8969), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(8966), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [71309] = 6,
    ACTIONS(4127), 1,
      anon_sym_SEMI,
    STATE(390), 1,
      sym_else_keyword,
    ACTIONS(8962), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8959), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(8956), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [71384] = 11,
    ACTIONS(11560), 1,
      sym_identifier,
    ACTIONS(11562), 1,
      sym_quoted_identifier,
    ACTIONS(11564), 1,
      sym_var_attribute_open,
    STATE(2425), 1,
      sym_preproc_if,
    STATE(10832), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6255), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4619), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(6257), 30,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [71469] = 11,
    ACTIONS(11560), 1,
      sym_identifier,
    ACTIONS(11562), 1,
      sym_quoted_identifier,
    ACTIONS(11564), 1,
      sym_var_attribute_open,
    STATE(2425), 1,
      sym_preproc_if,
    STATE(10832), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(6265), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4621), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(6267), 30,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [71554] = 11,
    ACTIONS(11560), 1,
      sym_identifier,
    ACTIONS(11562), 1,
      sym_quoted_identifier,
    ACTIONS(11564), 1,
      sym_var_attribute_open,
    STATE(2425), 1,
      sym_preproc_if,
    STATE(10832), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(6265), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4623), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(6267), 30,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [71639] = 11,
    ACTIONS(11566), 1,
      sym_identifier,
    ACTIONS(11569), 1,
      sym_quoted_identifier,
    ACTIONS(11572), 1,
      sym_var_attribute_open,
    STATE(2425), 1,
      sym_preproc_if,
    STATE(10832), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6239), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(6246), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4621), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(6241), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(6244), 30,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [71724] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4469), 19,
      sym_continue_as_identifier,
      sym_preproc_close,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(4467), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [71793] = 11,
    ACTIONS(11560), 1,
      sym_identifier,
    ACTIONS(11562), 1,
      sym_quoted_identifier,
    ACTIONS(11564), 1,
      sym_var_attribute_open,
    STATE(2425), 1,
      sym_preproc_if,
    STATE(10832), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(6261), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4621), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(6263), 30,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [71878] = 17,
    ACTIONS(2221), 1,
      aux_sym_basic_type_token22,
    ACTIONS(11536), 1,
      anon_sym_DASH,
    ACTIONS(11575), 1,
      anon_sym_COMMA,
    STATE(4956), 1,
      aux_sym_option_member_list_repeat2,
    STATE(9539), 1,
      sym_option_member,
    ACTIONS(911), 2,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
    ACTIONS(374), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(3706), 3,
      sym_quoted_identifier,
      sym_string_literal,
      sym_integer,
    STATE(4642), 3,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
      sym_enum_keyword,
    STATE(4795), 3,
      sym_boolean,
      sym_keyword_identifier,
      sym_keyword_as_identifier,
    ACTIONS(2239), 4,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(27), 6,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
    ACTIONS(935), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(937), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
    ACTIONS(2209), 7,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(917), 9,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token48,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
  [71975] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4810), 19,
      sym_continue_as_identifier,
      sym_preproc_close,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(4808), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [72044] = 5,
    STATE(389), 1,
      sym_else_keyword,
    ACTIONS(4129), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4121), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(4119), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [72117] = 5,
    STATE(390), 1,
      sym_else_keyword,
    ACTIONS(4129), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4127), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(4125), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [72190] = 5,
    STATE(419), 1,
      sym_else_keyword,
    ACTIONS(4129), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4147), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(4145), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [72263] = 5,
    STATE(420), 1,
      sym_else_keyword,
    ACTIONS(4129), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4151), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(4149), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [72336] = 5,
    STATE(423), 1,
      sym_else_keyword,
    ACTIONS(4129), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4155), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(4153), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [72409] = 5,
    STATE(424), 1,
      sym_else_keyword,
    ACTIONS(4129), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4159), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(4157), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [72482] = 5,
    STATE(425), 1,
      sym_else_keyword,
    ACTIONS(4129), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4163), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(4161), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [72555] = 5,
    STATE(426), 1,
      sym_else_keyword,
    ACTIONS(4129), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4167), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(4165), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [72628] = 5,
    STATE(431), 1,
      sym_else_keyword,
    ACTIONS(4129), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4171), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(4169), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [72701] = 5,
    STATE(432), 1,
      sym_else_keyword,
    ACTIONS(4129), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4133), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(4131), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [72774] = 15,
    ACTIONS(2221), 1,
      aux_sym_basic_type_token22,
    ACTIONS(11536), 1,
      anon_sym_DASH,
    STATE(4829), 1,
      sym_option_member,
    ACTIONS(911), 2,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
    ACTIONS(3706), 3,
      sym_quoted_identifier,
      sym_string_literal,
      sym_integer,
    STATE(4642), 3,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
      sym_enum_keyword,
    STATE(4795), 3,
      sym_boolean,
      sym_keyword_identifier,
      sym_keyword_as_identifier,
    ACTIONS(389), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(2239), 4,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(27), 6,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
    ACTIONS(935), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(937), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
    ACTIONS(2209), 7,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(917), 9,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token48,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
  [72866] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9155), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9153), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [72933] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9300), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9298), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [73000] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9159), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9157), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [73067] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9133), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9131), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [73134] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11577), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(5924), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [73201] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2426), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2428), 47,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [73268] = 4,
    ACTIONS(2268), 1,
      aux_sym_where_clause_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2426), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2428), 46,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [73337] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9163), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9161), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [73404] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9167), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9165), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [73471] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9324), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9322), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [73538] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9159), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9157), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [73605] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9193), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9191), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [73672] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9197), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9195), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [73739] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9205), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9203), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [73806] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9336), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9334), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [73873] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9187), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9185), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [73940] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11581), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11579), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [74007] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9312), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9310), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [74074] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9213), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9211), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [74141] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9119), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9117), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [74208] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9139), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9137), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [74275] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11585), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11583), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [74342] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9143), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9141), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [74409] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9147), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9145), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [74476] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9151), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9149), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [74543] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9316), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9314), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [74610] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9219), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9217), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [74677] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9328), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9326), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [74744] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9332), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9330), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [74811] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9143), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9141), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [74878] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9147), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9145), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [74945] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9151), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9149), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [75012] = 5,
    ACTIONS(11587), 1,
      anon_sym_COMMA,
    STATE(4669), 1,
      aux_sym_option_member_list_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(567), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
      sym_string_literal,
      sym_integer,
    ACTIONS(565), 43,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      aux_sym_where_condition_token1,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [75083] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9209), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9207), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [75150] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11592), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11590), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [75217] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9320), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9318), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [75284] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11596), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11594), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [75351] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9133), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9131), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [75418] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9125), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9123), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [75485] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11600), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11598), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [75552] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9304), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9302), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [75619] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9109), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9107), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [75686] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9300), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9298), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [75753] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9181), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9179), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [75820] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9201), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9199), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [75887] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9308), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9306), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [75954] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9304), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9302), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [76021] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9109), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9107), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [76088] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11604), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11602), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [76155] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9125), 13,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(9123), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [76222] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(7193), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3852), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [76334] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2547), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2549), 46,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [76400] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(4320), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3852), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [76512] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(6610), 1,
      sym_preproc_endif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(9129), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3852), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [76624] = 27,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(4897), 1,
      sym_preproc_elif,
    STATE(5436), 1,
      sym_preproc_else,
    STATE(7319), 1,
      sym_preproc_endif,
    STATE(8171), 1,
      aux_sym_preproc_conditional_actions_repeat1,
    ACTIONS(11612), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(11614), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4708), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [76738] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(7104), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4702), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [76850] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(6420), 1,
      sym_preproc_endif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(9129), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4694), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [76962] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(6489), 1,
      sym_preproc_endif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(9129), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3852), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [77074] = 27,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(4897), 1,
      sym_preproc_elif,
    STATE(5426), 1,
      sym_preproc_else,
    STATE(5915), 1,
      sym_preproc_endif,
    STATE(7874), 1,
      aux_sym_preproc_conditional_actions_repeat1,
    ACTIONS(11612), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(11614), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4881), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [77188] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2521), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2523), 46,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [77254] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(4320), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4698), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [77366] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(3919), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3852), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [77478] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(6382), 1,
      sym_preproc_endif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(9129), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4709), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [77590] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(4985), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3852), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [77702] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(4985), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4704), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [77814] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(7112), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3852), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [77926] = 27,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(4897), 1,
      sym_preproc_elif,
    STATE(5432), 1,
      sym_preproc_else,
    STATE(6894), 1,
      sym_preproc_endif,
    STATE(7796), 1,
      aux_sym_preproc_conditional_actions_repeat1,
    ACTIONS(11612), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(11614), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4881), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [78040] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(5006), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3852), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [78152] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(5006), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4706), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [78264] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(5023), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3852), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [78376] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(7125), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4713), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [78488] = 27,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(4897), 1,
      sym_preproc_elif,
    STATE(5439), 1,
      sym_preproc_else,
    STATE(7351), 1,
      sym_preproc_endif,
    STATE(7916), 1,
      aux_sym_preproc_conditional_actions_repeat1,
    ACTIONS(11612), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(11614), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4881), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [78602] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(6420), 1,
      sym_preproc_endif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(9129), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3852), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [78714] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(4610), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3852), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [78826] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(4610), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4689), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [78938] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2561), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2563), 46,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [79004] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(7104), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(3852), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [79116] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(6489), 1,
      sym_preproc_endif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(9129), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4690), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [79228] = 26,
    ACTIONS(2959), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(2961), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(2965), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(2967), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(2969), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(2971), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(2973), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(2975), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(2979), 1,
      sym_area_keyword,
    ACTIONS(2981), 1,
      sym_group_keyword,
    ACTIONS(2983), 1,
      sym_repeater_keyword,
    ACTIONS(2985), 1,
      sym_cuegroup_keyword,
    ACTIONS(2987), 1,
      sym_fixed_keyword,
    ACTIONS(2989), 1,
      sym_grid_keyword,
    ACTIONS(2991), 1,
      sym_part_keyword,
    ACTIONS(2993), 1,
      sym_systempart_keyword,
    ACTIONS(2995), 1,
      sym_usercontrol_keyword,
    ACTIONS(9089), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9091), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(9171), 1,
      aux_sym_where_condition_token1,
    STATE(3384), 1,
      sym_preproc_if,
    STATE(7112), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4687), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [79340] = 27,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(4897), 1,
      sym_preproc_elif,
    STATE(5430), 1,
      sym_preproc_else,
    STATE(6935), 1,
      sym_preproc_endif,
    STATE(7783), 1,
      aux_sym_preproc_conditional_actions_repeat1,
    ACTIONS(11612), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(11614), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4703), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [79454] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2543), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2545), 45,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [79519] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6978), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(6976), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79584] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7152), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79649] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7152), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79714] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7152), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79779] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7166), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79844] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7166), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79909] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7166), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79974] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7369), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7367), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80039] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7373), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7371), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80104] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7373), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7371), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80169] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7377), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7375), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80234] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7377), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7375), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80299] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7575), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80364] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7575), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80429] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7575), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80494] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7617), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7615), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80559] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7617), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7615), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80624] = 5,
    ACTIONS(11624), 1,
      anon_sym_DOT,
    STATE(4735), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2396), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2398), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      aux_sym_if_table_relation_token2,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_temporary_keyword,
  [80693] = 4,
    ACTIONS(11627), 1,
      sym_temporary_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2533), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2535), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [80760] = 4,
    ACTIONS(11629), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4373), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80827] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4373), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80892] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4381), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4379), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80957] = 4,
    ACTIONS(11631), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4383), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81024] = 4,
    ACTIONS(11633), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4383), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81091] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4383), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81156] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4395), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81221] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4395), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81286] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4401), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4399), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81351] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4405), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4403), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81416] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4409), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4407), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81481] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4413), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4411), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81546] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4417), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4415), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81611] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4421), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4419), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81676] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4425), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4423), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81741] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4429), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4427), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81806] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4433), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4431), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81871] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4437), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4435), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81936] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4441), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4439), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82001] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4445), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4443), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82066] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6978), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(6976), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82131] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4453), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4451), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82196] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4455), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82261] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(2843), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82326] = 4,
    ACTIONS(11637), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9343), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11635), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [82393] = 5,
    ACTIONS(11639), 1,
      anon_sym_DOT,
    STATE(4784), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2346), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2348), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      aux_sym_if_table_relation_token2,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_temporary_keyword,
  [82462] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2565), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2567), 45,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [82527] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4463), 11,
      sym_table_keyword,
      sym_page_keyword,
      sym_report_keyword,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_permissionset,
      anon_sym_PERMISSIONSET,
      anon_sym_Permissionset,
      anon_sym_PermissionSet,
      anon_sym_permissionSet,
    ACTIONS(4465), 42,
      anon_sym_tableextension,
      anon_sym_TABLEEXTENSION,
      anon_sym_Tableextension,
      anon_sym_TableExtension,
      anon_sym_tableExtension,
      anon_sym_pageextension,
      anon_sym_PAGEEXTENSION,
      anon_sym_Pageextension,
      anon_sym_PageExtension,
      anon_sym_pageExtension,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      anon_sym_reportextension,
      anon_sym_REPORTEXTENSION,
      anon_sym_Reportextension,
      anon_sym_ReportExtension,
      anon_sym_reportExtension,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      anon_sym_enumextension,
      anon_sym_ENUMEXTENSION,
      anon_sym_Enumextension,
      anon_sym_EnumExtension,
      anon_sym_enumExtension,
      sym_interface_keyword,
      anon_sym_permissionsetextension,
      anon_sym_PERMISSIONSETEXTENSION,
      anon_sym_Permissionsetextension,
      anon_sym_PermissionSetExtension,
      anon_sym_permissionSetExtension,
  [82592] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2517), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2519), 45,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [82657] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7361), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7359), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82722] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7541), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7539), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82787] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7545), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7543), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82852] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8237), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8235), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82917] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7807), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7805), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82982] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7811), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7809), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [83047] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7935), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7933), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [83112] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7939), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7937), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [83177] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7943), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(7941), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [83242] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8015), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8013), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [83307] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8019), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8017), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [83372] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8177), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8175), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [83437] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8213), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8211), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [83502] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2525), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2527), 45,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      aux_sym_if_table_relation_token2,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [83567] = 10,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11643), 1,
      anon_sym_STAR,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    ACTIONS(11647), 1,
      sym_integer,
    STATE(11338), 1,
      sym__namespaced_or_simple_ref,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(2428), 14,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(2426), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [83646] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2555), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2557), 45,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [83711] = 11,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11643), 1,
      anon_sym_STAR,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    ACTIONS(11649), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11651), 1,
      sym_integer,
    STATE(11156), 1,
      sym__namespaced_or_simple_ref,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(2428), 13,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(2426), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [83792] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8473), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8471), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [83857] = 5,
    ACTIONS(11639), 1,
      anon_sym_DOT,
    STATE(4735), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2442), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2444), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      aux_sym_if_table_relation_token2,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_temporary_keyword,
  [83926] = 27,
    ACTIONS(11653), 1,
      anon_sym_RBRACE,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11695), 1,
      sym_view_keyword,
    STATE(3407), 1,
      sym_preproc_if,
    STATE(10056), 2,
      sym_view_definition,
      aux_sym_addfirst_views_modification_repeat1,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4888), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [84039] = 27,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(11697), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    STATE(10061), 2,
      sym_view_definition,
      aux_sym_addfirst_views_modification_repeat1,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4889), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [84152] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8199), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [84217] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2585), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2587), 45,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_string_literal,
  [84282] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2585), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2587), 45,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_string_literal,
  [84347] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2585), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2587), 45,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_string_literal,
  [84412] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8265), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8263), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [84477] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8199), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [84542] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8199), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [84607] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4449), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4447), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [84672] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2539), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2541), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [84736] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5922), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11699), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [84800] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6140), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11701), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [84864] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6140), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11701), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [84928] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2529), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2531), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [84992] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2605), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2607), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [85056] = 6,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 41,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [85126] = 3,
    ACTIONS(9573), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9571), 50,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [85190] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2637), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2639), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [85254] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2633), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2635), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [85318] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2649), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2651), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [85382] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6158), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11705), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [85446] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6166), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11707), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [85510] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6164), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11709), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [85574] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6166), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11707), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [85638] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2396), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2398), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      aux_sym_if_table_relation_token2,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_temporary_keyword,
  [85702] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2573), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2575), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [85766] = 11,
    ACTIONS(11711), 1,
      sym_identifier,
    ACTIONS(11713), 1,
      sym_quoted_identifier,
    ACTIONS(11715), 1,
      sym_var_attribute_open,
    STATE(2423), 1,
      sym_preproc_if,
    STATE(10843), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6255), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4813), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(6257), 25,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [85846] = 11,
    ACTIONS(11711), 1,
      sym_identifier,
    ACTIONS(11713), 1,
      sym_quoted_identifier,
    ACTIONS(11715), 1,
      sym_var_attribute_open,
    STATE(2423), 1,
      sym_preproc_if,
    STATE(10843), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(6265), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4815), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(6267), 25,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [85926] = 11,
    ACTIONS(11711), 1,
      sym_identifier,
    ACTIONS(11713), 1,
      sym_quoted_identifier,
    ACTIONS(11715), 1,
      sym_var_attribute_open,
    STATE(2423), 1,
      sym_preproc_if,
    STATE(10843), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(6265), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4816), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(6267), 25,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [86006] = 11,
    ACTIONS(11717), 1,
      sym_identifier,
    ACTIONS(11720), 1,
      sym_quoted_identifier,
    ACTIONS(11723), 1,
      sym_var_attribute_open,
    STATE(2423), 1,
      sym_preproc_if,
    STATE(10843), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6239), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(6246), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4815), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(6241), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(6244), 25,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [86086] = 11,
    ACTIONS(11711), 1,
      sym_identifier,
    ACTIONS(11713), 1,
      sym_quoted_identifier,
    ACTIONS(11715), 1,
      sym_var_attribute_open,
    STATE(2423), 1,
      sym_preproc_if,
    STATE(10843), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(6261), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4815), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(6263), 25,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [86166] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2577), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2579), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [86230] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2551), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2553), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [86294] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2589), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2591), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [86358] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6172), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11726), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [86422] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6122), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11728), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [86486] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6172), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11726), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [86550] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2589), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2591), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [86614] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2597), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2599), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [86678] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2601), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2603), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [86742] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2609), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2611), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [86806] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2625), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2627), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [86870] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2629), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2631), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [86934] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2403), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2405), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [86998] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5896), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11730), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [87062] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2593), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2595), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [87126] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6160), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11732), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [87190] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9476), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(11734), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [87254] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2593), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2595), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [87318] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2593), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2595), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [87382] = 4,
    ACTIONS(11649), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2426), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2428), 43,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [87448] = 3,
    ACTIONS(9789), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9787), 50,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [87512] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2641), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2643), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [87576] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2645), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2647), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [87640] = 4,
    ACTIONS(11736), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2613), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2615), 43,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [87706] = 4,
    ACTIONS(11738), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2619), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2621), 43,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [87772] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2589), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2591), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [87836] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2581), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2583), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [87900] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2569), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2571), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [87964] = 9,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11742), 1,
      aux_sym_where_clause_token1,
    STATE(4763), 1,
      sym_argument_list,
    STATE(8500), 1,
      sym_where_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11740), 12,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_if_table_relation_token2,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [88040] = 26,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11744), 1,
      anon_sym_RBRACE,
    STATE(3374), 1,
      sym_preproc_if,
    STATE(3911), 1,
      sym_preproc_split_brace_close,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4851), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [88149] = 26,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11746), 1,
      anon_sym_RBRACE,
    STATE(3370), 1,
      sym_preproc_if,
    STATE(6582), 1,
      sym_preproc_split_brace_close,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4855), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [88258] = 5,
    ACTIONS(11753), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11748), 11,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_area_keyword,
      sym_group_keyword,
    ACTIONS(11750), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
    ACTIONS(9571), 21,
      anon_sym_SEMI,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [88325] = 26,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11755), 1,
      anon_sym_RBRACE,
    STATE(3377), 1,
      sym_preproc_if,
    STATE(7141), 1,
      sym_preproc_split_brace_close,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [88434] = 26,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11757), 1,
      anon_sym_RBRACE,
    STATE(3371), 1,
      sym_preproc_if,
    STATE(5041), 1,
      sym_preproc_split_brace_close,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [88543] = 26,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11759), 1,
      anon_sym_RBRACE,
    STATE(3374), 1,
      sym_preproc_if,
    STATE(3926), 1,
      sym_preproc_split_brace_close,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [88652] = 11,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    ACTIONS(11649), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11761), 1,
      anon_sym_STAR,
    ACTIONS(11763), 1,
      sym_integer,
    STATE(11638), 1,
      sym__namespaced_or_simple_ref,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(2428), 11,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(2426), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [88731] = 7,
    ACTIONS(11767), 1,
      anon_sym_LBRACK,
    ACTIONS(11771), 1,
      aux_sym_basic_type_token22,
    ACTIONS(9968), 4,
      sym_procedure_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11765), 11,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_area_keyword,
      sym_group_keyword,
    ACTIONS(9964), 17,
      anon_sym_SEMI,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_var_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
    ACTIONS(11773), 17,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
  [88802] = 5,
    ACTIONS(11771), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11765), 11,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_area_keyword,
      sym_group_keyword,
    ACTIONS(11773), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
    ACTIONS(9964), 21,
      anon_sym_SEMI,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [88869] = 26,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11776), 1,
      anon_sym_RBRACE,
    STATE(3370), 1,
      sym_preproc_if,
    STATE(6693), 1,
      sym_preproc_split_brace_close,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [88978] = 10,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    ACTIONS(11761), 1,
      anon_sym_STAR,
    ACTIONS(11763), 1,
      sym_integer,
    STATE(11638), 1,
      sym__namespaced_or_simple_ref,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(2428), 12,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(2426), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [89055] = 26,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11778), 1,
      anon_sym_RBRACE,
    STATE(3377), 1,
      sym_preproc_if,
    STATE(7196), 1,
      sym_preproc_split_brace_close,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4849), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [89164] = 5,
    ACTIONS(11785), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11780), 11,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_area_keyword,
      sym_group_keyword,
    ACTIONS(11782), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
    ACTIONS(9623), 21,
      anon_sym_SEMI,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [89231] = 20,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(11787), 1,
      sym_identifier,
    ACTIONS(11789), 1,
      anon_sym_SEMI,
    ACTIONS(11791), 1,
      anon_sym_COLON,
    ACTIONS(11793), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(11795), 1,
      sym_quoted_identifier,
    ACTIONS(11797), 1,
      sym_begin_keyword,
    STATE(6342), 1,
      sym__procedure_return_specification,
    STATE(6343), 1,
      sym__procedure_named_return,
    STATE(6983), 1,
      sym_interface_procedure_suffix,
    STATE(7422), 1,
      sym_preproc_if,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(4127), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10558), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11190), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10164), 3,
      sym_property_name,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(10166), 17,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [89328] = 20,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(11787), 1,
      sym_identifier,
    ACTIONS(11791), 1,
      anon_sym_COLON,
    ACTIONS(11793), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(11795), 1,
      sym_quoted_identifier,
    ACTIONS(11797), 1,
      sym_begin_keyword,
    ACTIONS(11799), 1,
      anon_sym_SEMI,
    STATE(6335), 1,
      sym__procedure_return_specification,
    STATE(6336), 1,
      sym__procedure_named_return,
    STATE(6891), 1,
      sym_interface_procedure_suffix,
    STATE(7422), 1,
      sym_preproc_if,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(4333), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10412), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11190), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10186), 3,
      sym_property_name,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(10188), 17,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [89425] = 8,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11803), 1,
      anon_sym_DOT,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11801), 13,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_if_table_relation_token2,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [89498] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5449), 13,
      sym_continue_as_identifier,
      sym_preproc_close,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(5447), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [89561] = 5,
    ACTIONS(11811), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11806), 11,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_area_keyword,
      sym_group_keyword,
    ACTIONS(11808), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
    ACTIONS(9787), 21,
      anon_sym_SEMI,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [89628] = 5,
    ACTIONS(11818), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11813), 11,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_area_keyword,
      sym_group_keyword,
    ACTIONS(11815), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
    ACTIONS(10766), 21,
      anon_sym_SEMI,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [89695] = 26,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11820), 1,
      anon_sym_RBRACE,
    STATE(3371), 1,
      sym_preproc_if,
    STATE(5016), 1,
      sym_preproc_split_brace_close,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4850), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [89804] = 23,
    ACTIONS(2270), 1,
      anon_sym_COLON,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 23,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [89906] = 9,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11803), 1,
      anon_sym_DOT,
    ACTIONS(11854), 1,
      anon_sym_EQ,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11801), 12,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(2436), 27,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [89980] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11857), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [90086] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2525), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2527), 43,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      aux_sym_if_table_relation_token2,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [90148] = 21,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2364), 3,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2366), 27,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [90246] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11859), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [90352] = 4,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 41,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [90416] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11861), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4875), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [90522] = 4,
    ACTIONS(11863), 1,
      anon_sym_LBRACE,
    ACTIONS(10378), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10374), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [90586] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11865), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [90692] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11865), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4877), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [90798] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11867), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [90904] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11869), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4879), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [91010] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11871), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [91116] = 4,
    ACTIONS(11873), 1,
      anon_sym_LBRACE,
    ACTIONS(10344), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10340), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [91180] = 21,
    ACTIONS(11875), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11878), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11881), 1,
      anon_sym_LBRACK,
    ACTIONS(11884), 1,
      aux_sym_basic_type_token22,
    ACTIONS(11887), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11890), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11893), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11896), 1,
      aux_sym_separator_action_token1,
    ACTIONS(11899), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(11902), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(11905), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(11908), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(11916), 1,
      sym_trigger_keyword,
    ACTIONS(11919), 1,
      sym_area_keyword,
    ACTIONS(11922), 1,
      sym_group_keyword,
    ACTIONS(11925), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    ACTIONS(11911), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11914), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    STATE(4881), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [91278] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11928), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [91384] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11930), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [91490] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11932), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4890), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [91596] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11934), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4891), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [91702] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11936), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4913), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [91808] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11938), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4914), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [91914] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11940), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [92020] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11942), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [92126] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11944), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [92232] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11946), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [92338] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11948), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [92444] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11950), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [92550] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11952), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4882), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [92656] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11954), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4883), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [92762] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11956), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4964), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [92868] = 21,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11958), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    STATE(4906), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [92966] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11960), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [93072] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11962), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4900), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [93178] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11964), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [93284] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11964), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4903), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [93390] = 4,
    ACTIONS(11966), 1,
      anon_sym_LBRACE,
    ACTIONS(10368), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10364), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [93454] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11968), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [93560] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11970), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4918), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [93666] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11972), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [93772] = 21,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11974), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    STATE(4881), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [93870] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11976), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4908), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [93976] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11978), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [94082] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11980), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4911), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [94188] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11982), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4912), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [94294] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11984), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [94400] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11986), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [94506] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11988), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [94612] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11990), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [94718] = 4,
    ACTIONS(11992), 1,
      anon_sym_LBRACE,
    ACTIONS(10354), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10350), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [94782] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2266), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2268), 43,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      aux_sym_if_table_relation_token2,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [94844] = 4,
    ACTIONS(11994), 1,
      anon_sym_LBRACE,
    ACTIONS(10384), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10380), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [94908] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11996), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [95014] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(11998), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [95120] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12000), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [95226] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12002), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4926), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [95332] = 26,
    ACTIONS(2270), 1,
      anon_sym_COLON,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [95440] = 5,
    ACTIONS(12010), 1,
      anon_sym_COMMA,
    STATE(4971), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(376), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(374), 40,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [95506] = 16,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2430), 5,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2432), 32,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [95594] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12012), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4868), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [95700] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12014), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [95806] = 5,
    ACTIONS(12010), 1,
      anon_sym_COMMA,
    STATE(4968), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2410), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2412), 40,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [95872] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12016), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4965), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [95978] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12018), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4957), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [96084] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12020), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4954), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [96190] = 16,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2360), 5,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2362), 32,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [96278] = 7,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2316), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2318), 39,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [96348] = 34,
    ACTIONS(2326), 1,
      anon_sym_COLON,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2328), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [96472] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12040), 9,
      sym_continue_as_identifier,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(12038), 41,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [96534] = 25,
    ACTIONS(10194), 1,
      anon_sym_RBRACE,
    ACTIONS(12042), 1,
      aux_sym_where_condition_token1,
    ACTIONS(12045), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12048), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12051), 1,
      aux_sym_basic_type_token6,
    ACTIONS(12054), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12057), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12060), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12063), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(12066), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(12069), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(12072), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(12075), 1,
      sym_area_keyword,
    ACTIONS(12078), 1,
      sym_group_keyword,
    ACTIONS(12081), 1,
      sym_repeater_keyword,
    ACTIONS(12084), 1,
      sym_cuegroup_keyword,
    ACTIONS(12087), 1,
      sym_fixed_keyword,
    ACTIONS(12090), 1,
      sym_grid_keyword,
    ACTIONS(12093), 1,
      sym_part_keyword,
    ACTIONS(12096), 1,
      sym_systempart_keyword,
    ACTIONS(12099), 1,
      sym_usercontrol_keyword,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(10229), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [96640] = 8,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 38,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [96712] = 8,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 38,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [96784] = 33,
    ACTIONS(2368), 1,
      anon_sym_COLON,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2370), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [96906] = 5,
    ACTIONS(12010), 1,
      anon_sym_COMMA,
    STATE(4927), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2354), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2356), 40,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [96972] = 8,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 38,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [97044] = 8,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 38,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [97116] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12102), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4959), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [97222] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12104), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4960), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [97328] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12106), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4892), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [97434] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12108), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4898), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [97540] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12110), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4905), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [97646] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12112), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4893), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [97752] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12114), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4919), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [97858] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12116), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4920), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [97964] = 26,
    ACTIONS(2270), 1,
      anon_sym_COLON,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [98072] = 8,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 38,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [98144] = 8,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 38,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [98216] = 8,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 38,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [98288] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12118), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [98394] = 8,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 38,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [98466] = 5,
    ACTIONS(12120), 1,
      anon_sym_COMMA,
    STATE(4956), 1,
      aux_sym_option_member_list_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(567), 7,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym_quoted_identifier,
      sym_string_literal,
      sym_integer,
    ACTIONS(565), 41,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      aux_sym_where_condition_token1,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [98532] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12123), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [98638] = 4,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2426), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2268), 13,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_if_table_relation_token2,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(2428), 30,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [98702] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12125), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [98808] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12127), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [98914] = 16,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2360), 5,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2362), 32,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [99002] = 23,
    ACTIONS(2270), 1,
      anon_sym_COLON,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 23,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [99104] = 26,
    ACTIONS(2270), 1,
      anon_sym_COLON,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [99212] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12129), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [99318] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12131), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [99424] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12118), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4871), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [99530] = 23,
    ACTIONS(2270), 1,
      anon_sym_COLON,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 23,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [99632] = 5,
    ACTIONS(12133), 1,
      anon_sym_COMMA,
    STATE(4968), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2403), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2405), 40,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [99698] = 26,
    ACTIONS(2270), 1,
      anon_sym_COLON,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [99806] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12136), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4974), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [99912] = 5,
    ACTIONS(12010), 1,
      anon_sym_COMMA,
    STATE(4968), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2354), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2356), 40,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [99978] = 26,
    ACTIONS(2270), 1,
      anon_sym_COLON,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [100086] = 26,
    ACTIONS(2270), 1,
      anon_sym_COLON,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [100194] = 25,
    ACTIONS(11655), 1,
      aux_sym_where_condition_token1,
    ACTIONS(11657), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(11659), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(11661), 1,
      aux_sym_basic_type_token6,
    ACTIONS(11663), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(11665), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11669), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(11671), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(11673), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(11675), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(11677), 1,
      sym_area_keyword,
    ACTIONS(11679), 1,
      sym_group_keyword,
    ACTIONS(11681), 1,
      sym_repeater_keyword,
    ACTIONS(11683), 1,
      sym_cuegroup_keyword,
    ACTIONS(11685), 1,
      sym_fixed_keyword,
    ACTIONS(11687), 1,
      sym_grid_keyword,
    ACTIONS(11689), 1,
      sym_part_keyword,
    ACTIONS(11691), 1,
      sym_systempart_keyword,
    ACTIONS(11693), 1,
      sym_usercontrol_keyword,
    ACTIONS(12012), 1,
      anon_sym_RBRACE,
    STATE(3407), 1,
      sym_preproc_if,
    ACTIONS(9093), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4935), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [100300] = 3,
    ACTIONS(10527), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10525), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100361] = 4,
    ACTIONS(12138), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 9,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4373), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [100424] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7541), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7539), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [100485] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4373), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [100546] = 3,
    ACTIONS(10797), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10799), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100607] = 3,
    ACTIONS(12142), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12140), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100668] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7545), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7543), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [100729] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4381), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4379), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [100790] = 4,
    ACTIONS(12144), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 9,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4383), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [100853] = 3,
    ACTIONS(10728), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10725), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100914] = 3,
    ACTIONS(11548), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11546), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100975] = 3,
    ACTIONS(10665), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10663), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101036] = 4,
    ACTIONS(12146), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 9,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4383), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [101099] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4383), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [101160] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4395), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [101221] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4395), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [101282] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4401), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4399), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [101343] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4405), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4403), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [101404] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4409), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4407), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [101465] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4413), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4411), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [101526] = 3,
    ACTIONS(12152), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12148), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101587] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4417), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4415), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [101648] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4421), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4419), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [101709] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7807), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7805), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [101770] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7811), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7809), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [101831] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7935), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7933), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [101892] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4425), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4423), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [101953] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7939), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7937), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [102014] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7943), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7941), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [102075] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8015), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8013), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [102136] = 3,
    ACTIONS(11554), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11552), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102197] = 3,
    ACTIONS(11145), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11143), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102258] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8019), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8017), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [102319] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8265), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8263), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [102380] = 3,
    ACTIONS(10479), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10477), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102441] = 3,
    ACTIONS(10483), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10481), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102502] = 3,
    ACTIONS(10487), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10485), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102563] = 3,
    ACTIONS(10491), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10489), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102624] = 3,
    ACTIONS(10495), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10493), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102685] = 3,
    ACTIONS(10499), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10497), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102746] = 3,
    ACTIONS(10503), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10501), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102807] = 3,
    ACTIONS(10507), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10505), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102868] = 3,
    ACTIONS(10511), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10509), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102929] = 3,
    ACTIONS(10515), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10513), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102990] = 3,
    ACTIONS(10519), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10517), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103051] = 3,
    ACTIONS(10523), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10521), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103112] = 3,
    ACTIONS(10531), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10529), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103173] = 3,
    ACTIONS(10535), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10533), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103234] = 3,
    ACTIONS(10539), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10537), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103295] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8177), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8175), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [103356] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4429), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4427), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [103417] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8199), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [103478] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8199), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [103539] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8199), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [103600] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8237), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8235), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [103661] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(2843), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [103722] = 6,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11803), 1,
      anon_sym_DOT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11801), 13,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_if_table_relation_token2,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [103789] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8213), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8211), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [103850] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8473), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8471), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [103911] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6978), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6976), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [103972] = 3,
    ACTIONS(12158), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12156), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104033] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7152), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [104094] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7152), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [104155] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4433), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4431), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [104216] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7152), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [104277] = 3,
    ACTIONS(10543), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10541), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104338] = 3,
    ACTIONS(10547), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10545), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104399] = 3,
    ACTIONS(10551), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10549), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104460] = 3,
    ACTIONS(10555), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10553), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104521] = 3,
    ACTIONS(10559), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10557), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104582] = 3,
    ACTIONS(10563), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10561), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104643] = 3,
    ACTIONS(10567), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10565), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104704] = 3,
    ACTIONS(10571), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10569), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104765] = 3,
    ACTIONS(10575), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10573), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104826] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4437), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4435), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [104887] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7166), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [104948] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7166), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105009] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7166), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105070] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7369), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7367), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105131] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7373), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7371), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105192] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7373), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7371), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105253] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4441), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4439), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105314] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7377), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7375), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105375] = 3,
    ACTIONS(10579), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10577), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [105436] = 3,
    ACTIONS(10583), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10581), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [105497] = 3,
    ACTIONS(10587), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10585), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [105558] = 3,
    ACTIONS(10591), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10589), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [105619] = 3,
    ACTIONS(10595), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10593), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [105680] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7377), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7375), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105741] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7575), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105802] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7575), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105863] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7575), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105924] = 3,
    ACTIONS(10669), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10667), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [105985] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7617), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7615), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [106046] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7617), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7615), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [106107] = 3,
    ACTIONS(10599), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10597), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106168] = 3,
    ACTIONS(10673), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10671), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106229] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4445), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4443), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [106290] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4449), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4447), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [106351] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4453), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4451), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [106412] = 3,
    ACTIONS(10603), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10601), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106473] = 3,
    ACTIONS(10607), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10605), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106534] = 3,
    ACTIONS(10611), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10609), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106595] = 3,
    ACTIONS(10615), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10613), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106656] = 3,
    ACTIONS(10619), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10617), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106717] = 3,
    ACTIONS(10623), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10621), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106778] = 3,
    ACTIONS(12162), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12160), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106839] = 3,
    ACTIONS(10627), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10625), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106900] = 3,
    ACTIONS(10631), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10629), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106961] = 3,
    ACTIONS(12166), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12164), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107022] = 3,
    ACTIONS(10677), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10675), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107083] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4455), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [107144] = 3,
    ACTIONS(10661), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10659), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107205] = 3,
    ACTIONS(10681), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10679), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107266] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2266), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2268), 42,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
      sym_temporary_keyword,
  [107327] = 3,
    ACTIONS(12172), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12168), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107388] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7361), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7359), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [107449] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6978), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6976), 39,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [107510] = 4,
    ACTIONS(12176), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9828), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9826), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [107572] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8819), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8821), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [107632] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8823), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8825), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [107692] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8823), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8825), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [107752] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8827), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8829), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [107812] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8833), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [107872] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8833), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [107932] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8833), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [107992] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8837), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108052] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8837), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108112] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8837), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108172] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9615), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9617), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108232] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9571), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9573), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108292] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9575), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9577), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108352] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9579), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9581), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108412] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9579), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9581), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108472] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9749), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9751), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108532] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9583), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9585), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108592] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9583), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9585), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108652] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8781), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8783), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108712] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8785), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8787), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108772] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8789), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8791), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108832] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9619), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9621), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108892] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9627), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9629), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108952] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9623), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9625), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109012] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9787), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9789), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109072] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10072), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10074), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109132] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9595), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9597), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109192] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9599), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9601), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109252] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9599), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9601), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109312] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9599), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9601), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109372] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9599), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9601), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109432] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9603), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9605), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109492] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9603), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9605), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109552] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9603), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9605), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109612] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9603), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9605), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109672] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9607), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9609), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109732] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9607), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9609), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109792] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9611), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9613), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109852] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9611), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9613), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109912] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8694), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8696), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109972] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9791), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9793), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110032] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8926), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8928), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110092] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9795), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9797), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110152] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9795), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9797), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110212] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9795), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9797), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110272] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9795), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9797), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110332] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4215), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4213), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110392] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9808), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9810), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110452] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9808), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9810), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110512] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9808), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9810), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110572] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9808), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9810), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110632] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9812), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9814), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110692] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9812), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9814), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110752] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10766), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(12178), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110812] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9643), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9645), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110872] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9647), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9649), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110932] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9647), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9649), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110992] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9651), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9653), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111052] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9651), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9653), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111112] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9655), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9657), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111172] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9655), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9657), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111232] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9655), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9657), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111292] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9655), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9657), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111352] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9659), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9661), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111412] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9659), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9661), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111472] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9816), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9818), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111532] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9659), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9661), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111592] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9659), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9661), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111652] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8841), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8843), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111712] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8841), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8843), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111772] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8845), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8847), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111832] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8845), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8847), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111892] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9816), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9818), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111952] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8793), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8795), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112012] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8799), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112072] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8799), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112132] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8799), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112192] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8803), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112252] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8803), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112312] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8803), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112372] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8805), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8807), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112432] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8809), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8811), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112492] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9667), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9669), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112552] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9667), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9669), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112612] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9667), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9669), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112672] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9667), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9669), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112732] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9671), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9673), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112792] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9671), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9673), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112852] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9671), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9673), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112912] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9671), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9673), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [112972] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9675), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9677), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113032] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9679), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9681), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113092] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9679), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9681), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113152] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9679), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9681), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113212] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9679), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9681), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113272] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9683), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9685), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113332] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9683), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9685), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113392] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9683), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9685), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113452] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9683), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9685), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113512] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8815), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8817), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113572] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9631), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9633), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113632] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9565), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9567), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113692] = 4,
    ACTIONS(12180), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9565), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9567), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113754] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9900), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9902), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113814] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9908), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9910), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113874] = 4,
    ACTIONS(12182), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9735), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9733), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113936] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9737), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9739), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [113996] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9737), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9739), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [114056] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9741), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9743), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [114116] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9741), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9743), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [114176] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9908), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9910), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [114236] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9938), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9940), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [114296] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9938), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9940), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [114356] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8942), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8944), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [114416] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9505), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9507), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [114476] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9509), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9511), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [114536] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9513), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9515), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [114596] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9517), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9519), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [114656] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9904), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9906), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [114716] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9525), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9527), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [114776] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9529), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9531), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [114836] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9529), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9531), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [114896] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9529), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9531), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [114956] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9745), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9747), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115016] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9745), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9747), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115076] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9753), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9755), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115136] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9753), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9755), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115196] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9757), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9759), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115256] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9757), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9759), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115316] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9757), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9759), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115376] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9757), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9759), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115436] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9761), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9763), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115496] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9761), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9763), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115556] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9761), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9763), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115616] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9761), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9763), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115676] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9529), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9531), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115736] = 5,
    ACTIONS(12190), 1,
      anon_sym_LBRACK,
    ACTIONS(12194), 4,
      sym_procedure_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12187), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(12184), 25,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115800] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9533), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9535), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115860] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9533), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9535), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115920] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9842), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9844), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [115980] = 4,
    ACTIONS(12198), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9850), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9848), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [116042] = 4,
    ACTIONS(12200), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9850), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9848), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [116104] = 4,
    ACTIONS(12202), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9842), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9844), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [116166] = 4,
    ACTIONS(12204), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9860), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9858), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [116228] = 4,
    ACTIONS(12206), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9860), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9858), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [116290] = 4,
    ACTIONS(12208), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9868), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9866), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [116352] = 4,
    ACTIONS(12210), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9868), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9866), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [116414] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9533), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9535), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [116474] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9533), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9535), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [116534] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9549), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9551), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [116594] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9521), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9523), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [116654] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9537), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9539), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [116714] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9876), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9878), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [116774] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9876), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9878), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [116834] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9896), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9898), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [116894] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9896), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9898), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [116954] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9979), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9981), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117014] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9979), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9981), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117074] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9983), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9985), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117134] = 4,
    ACTIONS(12212), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9998), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9996), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117196] = 4,
    ACTIONS(12214), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9998), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9996), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117258] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10002), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10004), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117318] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10002), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10004), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117378] = 4,
    ACTIONS(12216), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10010), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10008), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117440] = 4,
    ACTIONS(12218), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10010), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10008), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117502] = 4,
    ACTIONS(12220), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10002), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10004), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117564] = 4,
    ACTIONS(12222), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10002), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10004), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117626] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10018), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10020), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117686] = 4,
    ACTIONS(12224), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10026), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10024), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117748] = 4,
    ACTIONS(12226), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10026), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10024), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117810] = 4,
    ACTIONS(12228), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10018), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10020), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117872] = 4,
    ACTIONS(12230), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10018), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10020), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117934] = 4,
    ACTIONS(12232), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10038), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10036), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [117996] = 4,
    ACTIONS(12234), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10038), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10036), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [118058] = 4,
    ACTIONS(12236), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9983), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9985), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [118120] = 4,
    ACTIONS(12238), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10048), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10046), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [118182] = 4,
    ACTIONS(12240), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10048), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10046), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [118244] = 4,
    ACTIONS(12242), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10056), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10054), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [118306] = 4,
    ACTIONS(12244), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10056), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10054), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [118368] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9553), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9555), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [118428] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9541), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9543), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [118488] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10080), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10082), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [118548] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10080), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10082), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [118608] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10084), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10086), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [118668] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10084), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10086), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [118728] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10088), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10090), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [118788] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10088), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10090), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [118848] = 4,
    ACTIONS(12246), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10096), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10094), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [118910] = 4,
    ACTIONS(12248), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10096), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10094), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [118972] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10100), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10102), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [119032] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10100), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10102), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [119092] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10108), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10110), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [119152] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10108), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10110), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [119212] = 4,
    ACTIONS(12250), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9495), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9493), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [119274] = 4,
    ACTIONS(12252), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9495), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9493), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [119336] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10114), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10116), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [119396] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10114), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10116), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [119456] = 4,
    ACTIONS(12254), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10122), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10120), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [119518] = 4,
    ACTIONS(12256), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10122), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10120), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [119580] = 4,
    ACTIONS(12258), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10114), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10116), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [119642] = 4,
    ACTIONS(12260), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10114), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10116), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [119704] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10130), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10132), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [119764] = 4,
    ACTIONS(12262), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10138), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10136), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [119826] = 4,
    ACTIONS(12264), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10138), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10136), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [119888] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9936), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9934), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [119948] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9936), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9934), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120008] = 4,
    ACTIONS(12266), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10146), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10144), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120070] = 4,
    ACTIONS(12268), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10146), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10144), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120132] = 4,
    ACTIONS(12270), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9936), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9934), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120194] = 4,
    ACTIONS(12272), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9936), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9934), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120256] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9501), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9503), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120316] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9501), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9503), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120376] = 4,
    ACTIONS(12274), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9962), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9960), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120438] = 4,
    ACTIONS(12276), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9962), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9960), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120500] = 4,
    ACTIONS(12278), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9501), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9503), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120562] = 4,
    ACTIONS(12280), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9501), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9503), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120624] = 4,
    ACTIONS(12282), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10068), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10066), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120686] = 4,
    ACTIONS(12284), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10068), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10066), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120748] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9545), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9547), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120808] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9497), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9499), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120868] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9497), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9499), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120928] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9561), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9563), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [120988] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9561), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9563), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [121048] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9663), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9665), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [121108] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9663), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9665), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [121168] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9693), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9695), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [121228] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9693), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9695), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [121288] = 4,
    ACTIONS(12286), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9769), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9767), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [121350] = 4,
    ACTIONS(12288), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9769), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9767), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [121412] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9912), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9914), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [121472] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9912), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9914), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [121532] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9928), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9930), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [121592] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9928), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9930), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [121652] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10104), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10106), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [121712] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10104), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10106), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [121772] = 4,
    ACTIONS(12290), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9691), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9689), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [121834] = 4,
    ACTIONS(12292), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9691), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9689), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [121896] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9703), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9705), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [121956] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9703), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9705), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122016] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9711), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9713), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122076] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9711), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9713), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122136] = 4,
    ACTIONS(12294), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9719), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9717), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122198] = 4,
    ACTIONS(12296), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9719), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9717), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122260] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9838), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9840), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122320] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9838), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9840), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122380] = 4,
    ACTIONS(12298), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9884), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9882), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122442] = 4,
    ACTIONS(12300), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9884), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9882), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122504] = 4,
    ACTIONS(12302), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9838), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9840), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122566] = 4,
    ACTIONS(12304), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9838), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9840), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122628] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9587), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9589), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122688] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9830), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9832), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122748] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9834), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9836), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122808] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9635), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9637), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122868] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9635), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9637), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122928] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9639), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9641), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [122988] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9639), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9641), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [123048] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9707), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9709), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [123108] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9707), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9709), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [123168] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9721), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9723), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [123228] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9721), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9723), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [123288] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9727), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9729), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [123348] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9727), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9729), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [123408] = 4,
    ACTIONS(12306), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9775), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9773), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [123470] = 4,
    ACTIONS(12308), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9775), 18,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9773), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [123532] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9872), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9874), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [123592] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9892), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9894), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [123652] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9697), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9699), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [123712] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9697), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9699), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [123772] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9916), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9918), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [123832] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9920), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9922), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [123892] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9924), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9926), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [123952] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9942), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9944), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124012] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9946), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9948), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124072] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9950), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9952), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124132] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9591), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9593), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124192] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9954), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9956), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124252] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9971), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9973), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124312] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9987), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9989), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124372] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4465), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4463), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124432] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4469), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4467), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124492] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4810), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4808), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124552] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9553), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9555), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124612] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9553), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9555), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124672] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9553), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9555), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124732] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12187), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(12184), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124792] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9557), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9559), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124852] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9557), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9559), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124912] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9557), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9559), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [124972] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9557), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9559), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [125032] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8819), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(8821), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [125092] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10076), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10078), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [125152] = 7,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11803), 1,
      anon_sym_DOT,
    ACTIONS(11854), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11801), 12,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(2436), 27,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [125220] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9820), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(9822), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [125280] = 4,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5932), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2348), 13,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_if_table_relation_token2,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(5934), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [125342] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10018), 19,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(10020), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [125402] = 5,
    ACTIONS(12310), 1,
      anon_sym_DOT,
    STATE(5396), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2346), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2348), 39,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
      sym_temporary_keyword,
  [125465] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12314), 9,
      sym_continue_as_identifier,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(12312), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [125524] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12318), 9,
      sym_continue_as_identifier,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(12316), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [125583] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12322), 9,
      sym_continue_as_identifier,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(12320), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [125642] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12326), 9,
      sym_continue_as_identifier,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(12324), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [125701] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12330), 9,
      sym_continue_as_identifier,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(12328), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [125760] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12334), 9,
      sym_continue_as_identifier,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(12332), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [125819] = 5,
    ACTIONS(12310), 1,
      anon_sym_DOT,
    STATE(5402), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2442), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2444), 39,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
      sym_temporary_keyword,
  [125882] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12338), 9,
      sym_continue_as_identifier,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(12336), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [125941] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12342), 9,
      sym_continue_as_identifier,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(12340), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [126000] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12346), 9,
      sym_continue_as_identifier,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(12344), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [126059] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12350), 9,
      sym_continue_as_identifier,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(12348), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [126118] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2525), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2527), 40,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [126177] = 5,
    ACTIONS(12352), 1,
      anon_sym_DOT,
    STATE(5402), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2396), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2398), 39,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
      sym_temporary_keyword,
  [126240] = 9,
    ACTIONS(12360), 1,
      sym_var_keyword,
    STATE(7416), 1,
      sym_preproc_if,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12363), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(3546), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10500), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(12357), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12355), 32,
      sym_property_name,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [126310] = 12,
    ACTIONS(12366), 1,
      anon_sym_SEMI,
    ACTIONS(12374), 1,
      sym_var_keyword,
    STATE(3666), 1,
      sym_preproc_split_procedure_body,
    STATE(3668), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11025), 1,
      sym_preproc_conditional_var_block,
    STATE(11049), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12377), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12371), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12369), 31,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [126386] = 12,
    ACTIONS(12380), 1,
      anon_sym_SEMI,
    ACTIONS(12388), 1,
      sym_var_keyword,
    STATE(3538), 1,
      sym_preproc_split_procedure_body,
    STATE(3539), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10831), 1,
      sym_preproc_conditional_var_block,
    STATE(10854), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12391), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12385), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12383), 31,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [126462] = 13,
    ACTIONS(12394), 1,
      anon_sym_SEMI,
    ACTIONS(12405), 1,
      sym_var_keyword,
    STATE(3549), 1,
      sym_preproc_split_procedure_body,
    STATE(3550), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10513), 1,
      sym_preproc_conditional_var_block,
    STATE(10515), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12408), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12399), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12402), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12397), 21,
      sym_property_name,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [126540] = 12,
    ACTIONS(12411), 1,
      anon_sym_SEMI,
    ACTIONS(12419), 1,
      sym_var_keyword,
    STATE(3547), 1,
      sym_preproc_split_procedure_body,
    STATE(3548), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10506), 1,
      sym_preproc_conditional_var_block,
    STATE(10512), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12422), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12416), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12414), 31,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [126616] = 12,
    ACTIONS(12405), 1,
      sym_var_keyword,
    ACTIONS(12425), 1,
      anon_sym_SEMI,
    STATE(3549), 1,
      sym_preproc_split_procedure_body,
    STATE(3550), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10513), 1,
      sym_preproc_conditional_var_block,
    STATE(10515), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12408), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12399), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12397), 31,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [126692] = 13,
    ACTIONS(12380), 1,
      anon_sym_SEMI,
    ACTIONS(12388), 1,
      sym_var_keyword,
    STATE(3538), 1,
      sym_preproc_split_procedure_body,
    STATE(3539), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10831), 1,
      sym_preproc_conditional_var_block,
    STATE(10854), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12391), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12385), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12428), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12383), 21,
      sym_property_name,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [126770] = 12,
    ACTIONS(12405), 1,
      sym_var_keyword,
    ACTIONS(12431), 1,
      anon_sym_SEMI,
    STATE(3678), 1,
      sym_preproc_split_procedure_body,
    STATE(3679), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11062), 1,
      sym_preproc_conditional_var_block,
    STATE(11088), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12408), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12399), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12397), 31,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [126846] = 9,
    ACTIONS(12360), 1,
      sym_var_keyword,
    STATE(7416), 1,
      sym_preproc_if,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12363), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(3665), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(11057), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(12357), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12355), 32,
      sym_property_name,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [126916] = 13,
    ACTIONS(12419), 1,
      sym_var_keyword,
    ACTIONS(12434), 1,
      anon_sym_SEMI,
    STATE(3547), 1,
      sym_preproc_split_procedure_body,
    STATE(3548), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10506), 1,
      sym_preproc_conditional_var_block,
    STATE(10512), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12422), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12416), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12437), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12414), 21,
      sym_property_name,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [126994] = 12,
    ACTIONS(12388), 1,
      sym_var_keyword,
    ACTIONS(12440), 1,
      anon_sym_SEMI,
    STATE(3672), 1,
      sym_preproc_split_procedure_body,
    STATE(3673), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11050), 1,
      sym_preproc_conditional_var_block,
    STATE(11051), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12391), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12385), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12383), 31,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [127070] = 12,
    ACTIONS(12419), 1,
      sym_var_keyword,
    ACTIONS(12443), 1,
      anon_sym_SEMI,
    STATE(3676), 1,
      sym_preproc_split_procedure_body,
    STATE(3677), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11058), 1,
      sym_preproc_conditional_var_block,
    STATE(11061), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12422), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12416), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12414), 31,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [127146] = 13,
    ACTIONS(12366), 1,
      anon_sym_SEMI,
    ACTIONS(12374), 1,
      sym_var_keyword,
    STATE(3666), 1,
      sym_preproc_split_procedure_body,
    STATE(3668), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11025), 1,
      sym_preproc_conditional_var_block,
    STATE(11049), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12377), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12371), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12446), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12369), 21,
      sym_property_name,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [127224] = 13,
    ACTIONS(12388), 1,
      sym_var_keyword,
    ACTIONS(12440), 1,
      anon_sym_SEMI,
    STATE(3672), 1,
      sym_preproc_split_procedure_body,
    STATE(3673), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11050), 1,
      sym_preproc_conditional_var_block,
    STATE(11051), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12391), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12385), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12449), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12383), 21,
      sym_property_name,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [127302] = 13,
    ACTIONS(12419), 1,
      sym_var_keyword,
    ACTIONS(12452), 1,
      anon_sym_SEMI,
    STATE(3676), 1,
      sym_preproc_split_procedure_body,
    STATE(3677), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11058), 1,
      sym_preproc_conditional_var_block,
    STATE(11061), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12422), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12416), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12455), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12414), 21,
      sym_property_name,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [127380] = 13,
    ACTIONS(12405), 1,
      sym_var_keyword,
    ACTIONS(12458), 1,
      anon_sym_SEMI,
    STATE(3678), 1,
      sym_preproc_split_procedure_body,
    STATE(3679), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11062), 1,
      sym_preproc_conditional_var_block,
    STATE(11088), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12408), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12399), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12461), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12397), 21,
      sym_property_name,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [127458] = 13,
    ACTIONS(12374), 1,
      sym_var_keyword,
    ACTIONS(12464), 1,
      anon_sym_SEMI,
    STATE(3534), 1,
      sym_preproc_split_procedure_body,
    STATE(3535), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10789), 1,
      sym_preproc_conditional_var_block,
    STATE(10805), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12377), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12371), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12467), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12369), 21,
      sym_property_name,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [127536] = 12,
    ACTIONS(12374), 1,
      sym_var_keyword,
    ACTIONS(12464), 1,
      anon_sym_SEMI,
    STATE(3534), 1,
      sym_preproc_split_procedure_body,
    STATE(3535), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10789), 1,
      sym_preproc_conditional_var_block,
    STATE(10805), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12377), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12371), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12369), 31,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [127612] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2396), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2398), 39,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
      sym_temporary_keyword,
  [127670] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2426), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2428), 39,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [127728] = 36,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12480), 1,
      sym__assignment_operator,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    ACTIONS(12502), 1,
      anon_sym_and,
    ACTIONS(12504), 1,
      anon_sym_AND,
    ACTIONS(12506), 1,
      anon_sym_And,
    ACTIONS(12508), 1,
      anon_sym_or,
    ACTIONS(12510), 1,
      anon_sym_OR,
    ACTIONS(12512), 1,
      anon_sym_Or,
    ACTIONS(12514), 1,
      anon_sym_xor,
    ACTIONS(12516), 1,
      anon_sym_XOR,
    ACTIONS(12518), 1,
      anon_sym_Xor,
    ACTIONS(12520), 1,
      anon_sym_QMARK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(3122), 1,
      sym_to_keyword,
    STATE(3123), 1,
      sym_downto_keyword,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12522), 3,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
    ACTIONS(12524), 3,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [127851] = 36,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12480), 1,
      sym__assignment_operator,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    ACTIONS(12502), 1,
      anon_sym_and,
    ACTIONS(12504), 1,
      anon_sym_AND,
    ACTIONS(12506), 1,
      anon_sym_And,
    ACTIONS(12508), 1,
      anon_sym_or,
    ACTIONS(12510), 1,
      anon_sym_OR,
    ACTIONS(12512), 1,
      anon_sym_Or,
    ACTIONS(12514), 1,
      anon_sym_xor,
    ACTIONS(12516), 1,
      anon_sym_XOR,
    ACTIONS(12518), 1,
      anon_sym_Xor,
    ACTIONS(12520), 1,
      anon_sym_QMARK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(3106), 1,
      sym_to_keyword,
    STATE(3107), 1,
      sym_downto_keyword,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12522), 3,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
    ACTIONS(12524), 3,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [127974] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(5927), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4881), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [128069] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(5927), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(5427), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [128164] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(5961), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4881), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [128259] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(5961), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(5429), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [128354] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(5947), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4881), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [128449] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(6894), 1,
      sym_preproc_endif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(5431), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [128544] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(6951), 1,
      sym_preproc_endif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4881), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [128639] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(6951), 1,
      sym_preproc_endif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(5433), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [128734] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(6893), 1,
      sym_preproc_endif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4881), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [128829] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(6893), 1,
      sym_preproc_endif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(5435), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [128924] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(6912), 1,
      sym_preproc_endif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4881), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [129019] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(7351), 1,
      sym_preproc_endif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(5437), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [129114] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(7308), 1,
      sym_preproc_endif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4881), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [129209] = 36,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12480), 1,
      sym__assignment_operator,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    ACTIONS(12502), 1,
      anon_sym_and,
    ACTIONS(12504), 1,
      anon_sym_AND,
    ACTIONS(12506), 1,
      anon_sym_And,
    ACTIONS(12508), 1,
      anon_sym_or,
    ACTIONS(12510), 1,
      anon_sym_OR,
    ACTIONS(12512), 1,
      anon_sym_Or,
    ACTIONS(12514), 1,
      anon_sym_xor,
    ACTIONS(12516), 1,
      anon_sym_XOR,
    ACTIONS(12518), 1,
      anon_sym_Xor,
    ACTIONS(12520), 1,
      anon_sym_QMARK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(2975), 1,
      sym_to_keyword,
    STATE(2977), 1,
      sym_downto_keyword,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12522), 3,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
    ACTIONS(12524), 3,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [129332] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(7308), 1,
      sym_preproc_endif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(5440), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [129427] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(7295), 1,
      sym_preproc_endif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4881), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [129522] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(7295), 1,
      sym_preproc_endif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(5442), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [129617] = 22,
    ACTIONS(3676), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(3678), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(3680), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3682), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(3684), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(3688), 1,
      aux_sym_separator_action_token1,
    ACTIONS(3690), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(3692), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(3694), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(3696), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(3698), 1,
      sym_area_keyword,
    ACTIONS(3700), 1,
      sym_group_keyword,
    ACTIONS(11606), 1,
      anon_sym_LBRACK,
    ACTIONS(11608), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(11618), 1,
      sym_trigger_keyword,
    ACTIONS(11620), 1,
      sym_property_name,
    STATE(4716), 1,
      sym_preproc_if,
    STATE(7290), 1,
      sym_preproc_endif,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(4881), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [129712] = 36,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12480), 1,
      sym__assignment_operator,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    ACTIONS(12502), 1,
      anon_sym_and,
    ACTIONS(12504), 1,
      anon_sym_AND,
    ACTIONS(12506), 1,
      anon_sym_And,
    ACTIONS(12508), 1,
      anon_sym_or,
    ACTIONS(12510), 1,
      anon_sym_OR,
    ACTIONS(12512), 1,
      anon_sym_Or,
    ACTIONS(12514), 1,
      anon_sym_xor,
    ACTIONS(12516), 1,
      anon_sym_XOR,
    ACTIONS(12518), 1,
      anon_sym_Xor,
    ACTIONS(12520), 1,
      anon_sym_QMARK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(3024), 1,
      sym_to_keyword,
    STATE(3025), 1,
      sym_downto_keyword,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12522), 3,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
    ACTIONS(12524), 3,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [129835] = 36,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12480), 1,
      sym__assignment_operator,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    ACTIONS(12502), 1,
      anon_sym_and,
    ACTIONS(12504), 1,
      anon_sym_AND,
    ACTIONS(12506), 1,
      anon_sym_And,
    ACTIONS(12508), 1,
      anon_sym_or,
    ACTIONS(12510), 1,
      anon_sym_OR,
    ACTIONS(12512), 1,
      anon_sym_Or,
    ACTIONS(12514), 1,
      anon_sym_xor,
    ACTIONS(12516), 1,
      anon_sym_XOR,
    ACTIONS(12518), 1,
      anon_sym_Xor,
    ACTIONS(12520), 1,
      anon_sym_QMARK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(3068), 1,
      sym_to_keyword,
    STATE(3069), 1,
      sym_downto_keyword,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12522), 3,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
    ACTIONS(12524), 3,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [129958] = 36,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12480), 1,
      sym__assignment_operator,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    ACTIONS(12502), 1,
      anon_sym_and,
    ACTIONS(12504), 1,
      anon_sym_AND,
    ACTIONS(12506), 1,
      anon_sym_And,
    ACTIONS(12508), 1,
      anon_sym_or,
    ACTIONS(12510), 1,
      anon_sym_OR,
    ACTIONS(12512), 1,
      anon_sym_Or,
    ACTIONS(12514), 1,
      anon_sym_xor,
    ACTIONS(12516), 1,
      anon_sym_XOR,
    ACTIONS(12518), 1,
      anon_sym_Xor,
    ACTIONS(12520), 1,
      anon_sym_QMARK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(3091), 1,
      sym_to_keyword,
    STATE(3092), 1,
      sym_downto_keyword,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12522), 3,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
    ACTIONS(12524), 3,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [130081] = 3,
    ACTIONS(12526), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9719), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [130137] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [130191] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [130245] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8237), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [130299] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9655), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [130353] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9659), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [130407] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8473), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [130461] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6978), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [130515] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9565), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [130569] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6978), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [130623] = 3,
    ACTIONS(12528), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9565), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [130679] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9904), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [130733] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9655), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [130787] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [130841] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [130895] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [130949] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9659), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131003] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131057] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9679), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131111] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9679), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131165] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9575), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131219] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9579), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131273] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9579), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131327] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9583), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131381] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7541), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7539), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [131437] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7545), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7543), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [131493] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9583), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131547] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9627), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131601] = 3,
    ACTIONS(12530), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131657] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131711] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4381), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131765] = 3,
    ACTIONS(12532), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131821] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9631), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131875] = 3,
    ACTIONS(12534), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131931] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [131985] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [132039] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [132093] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4401), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [132147] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4405), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [132201] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4409), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [132255] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4413), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [132309] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4417), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [132363] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4421), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [132417] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4425), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [132471] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8694), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [132525] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7807), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7805), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [132581] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4429), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [132635] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7811), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7809), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [132691] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4433), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [132745] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4437), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [132799] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8781), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [132853] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8785), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [132907] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4441), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [132961] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8789), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [133015] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7935), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7933), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [133071] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7939), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7937), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [133127] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7943), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7941), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [133183] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4445), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [133237] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4449), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [133291] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4453), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [133345] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [133399] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [133453] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(2843), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [133509] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9749), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [133563] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8793), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [133617] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [133671] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [133725] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [133779] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [133833] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [133887] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [133941] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [133995] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9683), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [134049] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9683), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [134103] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9683), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [134157] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [134211] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8805), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [134265] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8809), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [134319] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8015), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8013), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [134375] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8019), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8017), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [134431] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8819), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [134485] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8819), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [134539] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8823), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [134593] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8823), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [134647] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8827), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [134701] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9683), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [134755] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9615), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [134809] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [134863] = 3,
    ACTIONS(12536), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9735), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [134919] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9737), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [134973] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9737), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135027] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9741), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135081] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135135] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9741), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135189] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9619), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135243] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9745), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135297] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9745), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135351] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9753), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135405] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9753), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135459] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135513] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9757), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135567] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9757), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135621] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9757), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135675] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135729] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9757), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135783] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135837] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9761), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135891] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9761), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135945] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [135999] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8177), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8175), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [136055] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8841), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [136109] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9761), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [136163] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8841), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [136217] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7369), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [136271] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9761), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [136325] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8845), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [136379] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8845), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [136433] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8213), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8211), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [136489] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9791), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [136543] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9795), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [136597] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9795), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [136651] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9842), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [136705] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7373), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [136759] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9795), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [136813] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9795), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [136867] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7373), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [136921] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9808), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [136975] = 3,
    ACTIONS(12538), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9850), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137031] = 3,
    ACTIONS(12540), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9850), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137087] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9808), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137141] = 3,
    ACTIONS(12542), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9842), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137197] = 3,
    ACTIONS(12544), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9860), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137253] = 3,
    ACTIONS(12546), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9860), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137309] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9808), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137363] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8815), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137417] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9808), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137471] = 3,
    ACTIONS(12548), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9868), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137527] = 3,
    ACTIONS(12550), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9868), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137583] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9876), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137637] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9876), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137691] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9896), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137745] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9896), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137799] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9599), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137853] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9603), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137907] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7377), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [137961] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12555), 5,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
    ACTIONS(12552), 39,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138017] = 6,
    ACTIONS(12557), 1,
      anon_sym_LPAREN,
    ACTIONS(12559), 1,
      anon_sym_COLON_COLON,
    STATE(5948), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [138079] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9979), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138133] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9979), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138187] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7377), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138241] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9983), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138295] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138349] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138403] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8926), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138457] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9812), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138511] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138565] = 3,
    ACTIONS(12561), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9998), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138621] = 3,
    ACTIONS(12563), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9998), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138677] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10002), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138731] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10002), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138785] = 3,
    ACTIONS(12565), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10010), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138841] = 3,
    ACTIONS(12567), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10010), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138897] = 3,
    ACTIONS(12569), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10002), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [138953] = 3,
    ACTIONS(12571), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10002), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139009] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10018), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139063] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10018), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139117] = 3,
    ACTIONS(12573), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10026), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139173] = 3,
    ACTIONS(12575), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10026), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139229] = 3,
    ACTIONS(12577), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10018), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139285] = 3,
    ACTIONS(12579), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10018), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139341] = 3,
    ACTIONS(12581), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10038), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139397] = 4,
    ACTIONS(12583), 1,
      anon_sym_DOT,
    STATE(5685), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2444), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_temporary_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139455] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9812), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139509] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9541), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139563] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9545), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139617] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9816), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139671] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9816), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139725] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9505), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139779] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9900), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139833] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9908), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139887] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9908), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139941] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9938), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [139995] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9938), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140049] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12585), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140103] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12587), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140157] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9509), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140211] = 3,
    ACTIONS(12589), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10038), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140267] = 3,
    ACTIONS(12591), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9983), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140323] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7617), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140377] = 3,
    ACTIONS(12593), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10048), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140433] = 3,
    ACTIONS(12595), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10048), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140489] = 3,
    ACTIONS(12597), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10056), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140545] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9513), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140599] = 3,
    ACTIONS(12599), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10056), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140655] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10080), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140709] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10080), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140763] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9525), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140817] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10084), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140871] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10084), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140925] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10088), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [140979] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10088), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141033] = 3,
    ACTIONS(12601), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10096), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141089] = 3,
    ACTIONS(12603), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10096), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141145] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10100), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141199] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10100), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141253] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10108), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141307] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10108), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141361] = 3,
    ACTIONS(12605), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9495), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141417] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7617), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141471] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9603), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141525] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9603), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141579] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9603), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141633] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4465), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141687] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9587), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141741] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9529), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141795] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4469), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141849] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9591), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141903] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9667), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [141957] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9529), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142011] = 3,
    ACTIONS(12607), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9495), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142067] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10114), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142121] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10114), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142175] = 3,
    ACTIONS(12609), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10122), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142231] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12611), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142285] = 4,
    ACTIONS(12583), 1,
      anon_sym_DOT,
    STATE(5617), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2348), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_temporary_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142343] = 3,
    ACTIONS(12613), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10122), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142399] = 3,
    ACTIONS(12615), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10114), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142455] = 3,
    ACTIONS(12617), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10114), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142511] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9529), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142565] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10130), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142619] = 3,
    ACTIONS(12619), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10138), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142675] = 3,
    ACTIONS(12621), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10138), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142731] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9529), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142785] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9936), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142839] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9936), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142893] = 3,
    ACTIONS(12623), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10146), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [142949] = 3,
    ACTIONS(12625), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10146), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143005] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9533), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143059] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9533), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143113] = 4,
    ACTIONS(12627), 1,
      anon_sym_DOT,
    STATE(5685), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2398), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_temporary_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143171] = 3,
    ACTIONS(12630), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9936), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143227] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9655), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143281] = 3,
    ACTIONS(12632), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9936), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143337] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9501), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143391] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9501), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143445] = 3,
    ACTIONS(12634), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9962), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143501] = 3,
    ACTIONS(12636), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9962), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143557] = 3,
    ACTIONS(12638), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9501), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143613] = 3,
    ACTIONS(12640), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9501), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143669] = 3,
    ACTIONS(12642), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10068), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143725] = 3,
    ACTIONS(12644), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10068), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143781] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143835] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9497), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143889] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9561), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143943] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9561), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [143997] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9663), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144051] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9663), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144105] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9693), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144159] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8265), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144213] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9693), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144267] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9651), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144321] = 3,
    ACTIONS(12646), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9769), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144377] = 3,
    ACTIONS(12648), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9769), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144433] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9912), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144487] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9912), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144541] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9928), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144595] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9928), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144649] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12650), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144703] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10104), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144757] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10104), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144811] = 3,
    ACTIONS(12652), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9691), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144867] = 3,
    ACTIONS(12654), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9691), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144923] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9703), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [144977] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9703), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145031] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9711), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145085] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9711), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145139] = 3,
    ACTIONS(12656), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9719), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145195] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4455), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [145251] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9838), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145305] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9838), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145359] = 3,
    ACTIONS(12658), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9884), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145415] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12660), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145469] = 3,
    ACTIONS(12663), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9884), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145525] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12665), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145579] = 3,
    ACTIONS(12667), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9838), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145635] = 3,
    ACTIONS(12669), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9838), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145691] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9623), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145745] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12671), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145799] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9635), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145853] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9635), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145907] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9639), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [145961] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9639), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146015] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9707), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146069] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12673), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146123] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9707), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146177] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9721), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146231] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9721), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146285] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9727), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146339] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9727), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146393] = 3,
    ACTIONS(12675), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9775), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146449] = 3,
    ACTIONS(12677), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9775), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146505] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9697), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146559] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9697), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146613] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9533), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146667] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9533), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146721] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2422), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2424), 37,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [146777] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9549), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146831] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9667), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146885] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2426), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2428), 37,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [146941] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9667), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [146995] = 3,
    ACTIONS(12679), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9828), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147051] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9830), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147105] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9667), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147159] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9671), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147213] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12681), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147267] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9834), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147321] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9872), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147375] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9892), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147429] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9916), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147483] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9553), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147537] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9920), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147591] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9553), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147645] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9553), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147699] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8265), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8263), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [147755] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9924), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147809] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9942), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147863] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9946), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147917] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9950), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [147971] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9954), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [148025] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12683), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [148079] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9971), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [148133] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9671), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [148187] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2414), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2416), 37,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [148243] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2418), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2420), 37,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [148299] = 12,
    ACTIONS(4848), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12685), 1,
      sym_identifier,
    ACTIONS(12687), 1,
      sym_quoted_identifier,
    STATE(10522), 1,
      sym_calc_field_reference,
    STATE(4642), 3,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
      sym_enum_keyword,
    STATE(10239), 3,
      sym_keyword_identifier,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(27), 6,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
    ACTIONS(935), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(937), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
    ACTIONS(2209), 7,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(917), 9,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token48,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
  [148373] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9987), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [148427] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9671), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [148481] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12689), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [148535] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9671), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [148589] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9675), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [148643] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9599), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [148697] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9659), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [148751] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9659), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [148805] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9607), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [148859] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9679), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [148913] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10076), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [148967] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9607), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [149021] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9611), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [149075] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9611), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [149129] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9820), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [149183] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9643), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [149237] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9647), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [149291] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9647), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [149345] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9553), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [149399] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8199), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [149455] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8199), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [149511] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8199), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [149567] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8237), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8235), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [149623] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9571), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [149677] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8473), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8471), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [149733] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6978), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6976), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [149789] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6978), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6976), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [149845] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7152), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [149901] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7152), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [149957] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7152), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [150013] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9787), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [150067] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7166), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [150123] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7166), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [150179] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7166), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [150235] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4810), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [150289] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7369), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7367), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [150345] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7373), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7371), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [150401] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7373), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7371), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [150457] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9557), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [150511] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7377), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7375), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [150567] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7377), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7375), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [150623] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9599), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [150677] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12691), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [150731] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9651), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [150785] = 4,
    ACTIONS(12693), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 9,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4373), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [150843] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7575), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [150899] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4373), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [150955] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4381), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4379), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [151011] = 4,
    ACTIONS(12695), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 9,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4383), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [151069] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10072), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [151123] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7575), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [151179] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7575), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [151235] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7617), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7615), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [151291] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7617), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7615), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [151347] = 4,
    ACTIONS(12697), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 9,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4383), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [151405] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4383), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [151461] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4395), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [151517] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4395), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [151573] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9679), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [151627] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2268), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_temporary_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [151681] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9655), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [151735] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9557), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [151789] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4215), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [151843] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9968), 5,
      anon_sym_LBRACK,
      sym_procedure_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(9964), 39,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [151899] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9557), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [151953] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4401), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4399), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [152009] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8942), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [152063] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4405), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4403), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [152119] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9557), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [152173] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12699), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [152227] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12702), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [152281] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9517), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [152335] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4409), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4407), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [152391] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4413), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4411), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [152447] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4417), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4415), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [152503] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4421), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4419), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [152559] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4425), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4423), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [152615] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9521), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [152669] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9537), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [152723] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9595), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [152777] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4429), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4427), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [152833] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9599), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [152887] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4433), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4431), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [152943] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4437), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4435), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [152999] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4441), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4439), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [153055] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4445), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4443), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [153111] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4449), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4447), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [153167] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4453), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4451), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [153223] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7361), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7359), 34,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [153279] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9497), 44,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [153333] = 8,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 32,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [153398] = 4,
    ACTIONS(12704), 1,
      anon_sym_COMMA,
    STATE(5906), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(374), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [153455] = 32,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    ACTIONS(12502), 1,
      anon_sym_and,
    ACTIONS(12504), 1,
      anon_sym_AND,
    ACTIONS(12506), 1,
      anon_sym_And,
    ACTIONS(12508), 1,
      anon_sym_or,
    ACTIONS(12510), 1,
      anon_sym_OR,
    ACTIONS(12512), 1,
      anon_sym_Or,
    ACTIONS(12514), 1,
      anon_sym_xor,
    ACTIONS(12516), 1,
      anon_sym_XOR,
    ACTIONS(12518), 1,
      anon_sym_Xor,
    ACTIONS(12520), 1,
      anon_sym_QMARK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2370), 7,
      sym__assignment_operator,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [153568] = 5,
    ACTIONS(12706), 1,
      anon_sym_COMMA,
    STATE(5891), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2410), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2412), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [153627] = 11,
    ACTIONS(4848), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12708), 1,
      sym_identifier,
    ACTIONS(12710), 1,
      sym_quoted_identifier,
    STATE(4642), 3,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
      sym_enum_keyword,
    STATE(10960), 3,
      sym_keyword_identifier,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(27), 6,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
    ACTIONS(935), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(937), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
    ACTIONS(2209), 7,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(917), 9,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token48,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
  [153698] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2398), 43,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_temporary_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [153751] = 4,
    ACTIONS(12704), 1,
      anon_sym_COMMA,
    STATE(5880), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2412), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [153808] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2521), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2523), 36,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [153863] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2547), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2549), 36,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [153918] = 4,
    ACTIONS(12712), 1,
      anon_sym_COMMA,
    STATE(5880), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2405), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [153975] = 33,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12480), 1,
      sym__assignment_operator,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    ACTIONS(12502), 1,
      anon_sym_and,
    ACTIONS(12504), 1,
      anon_sym_AND,
    ACTIONS(12506), 1,
      anon_sym_And,
    ACTIONS(12508), 1,
      anon_sym_or,
    ACTIONS(12510), 1,
      anon_sym_OR,
    ACTIONS(12512), 1,
      anon_sym_Or,
    ACTIONS(12514), 1,
      anon_sym_xor,
    ACTIONS(12516), 1,
      anon_sym_XOR,
    ACTIONS(12518), 1,
      anon_sym_Xor,
    ACTIONS(12520), 1,
      anon_sym_QMARK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2328), 6,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [154090] = 16,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2360), 4,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2362), 26,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [154171] = 7,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2316), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2318), 33,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [154234] = 8,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 32,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [154299] = 8,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 32,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [154364] = 8,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 32,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [154429] = 8,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 32,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [154494] = 8,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 32,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [154559] = 8,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 32,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [154624] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2561), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2563), 36,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [154679] = 5,
    ACTIONS(12715), 1,
      anon_sym_COMMA,
    STATE(5891), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2403), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2405), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [154738] = 16,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2360), 4,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2362), 26,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [154819] = 16,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2430), 4,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2432), 26,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [154900] = 22,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 17,
      sym__assignment_operator,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [154993] = 22,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 17,
      sym__assignment_operator,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [155086] = 22,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 17,
      sym__assignment_operator,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [155179] = 25,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    ACTIONS(12502), 1,
      anon_sym_and,
    ACTIONS(12504), 1,
      anon_sym_AND,
    ACTIONS(12506), 1,
      anon_sym_And,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 14,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [155278] = 25,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    ACTIONS(12502), 1,
      anon_sym_and,
    ACTIONS(12504), 1,
      anon_sym_AND,
    ACTIONS(12506), 1,
      anon_sym_And,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 14,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [155377] = 25,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    ACTIONS(12502), 1,
      anon_sym_and,
    ACTIONS(12504), 1,
      anon_sym_AND,
    ACTIONS(12506), 1,
      anon_sym_And,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 14,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [155476] = 25,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    ACTIONS(12502), 1,
      anon_sym_and,
    ACTIONS(12504), 1,
      anon_sym_AND,
    ACTIONS(12506), 1,
      anon_sym_And,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 14,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [155575] = 5,
    ACTIONS(12706), 1,
      anon_sym_COMMA,
    STATE(5874), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2354), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2356), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [155634] = 25,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    ACTIONS(12502), 1,
      anon_sym_and,
    ACTIONS(12504), 1,
      anon_sym_AND,
    ACTIONS(12506), 1,
      anon_sym_And,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 14,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [155733] = 25,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    ACTIONS(12502), 1,
      anon_sym_and,
    ACTIONS(12504), 1,
      anon_sym_AND,
    ACTIONS(12506), 1,
      anon_sym_And,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 14,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [155832] = 21,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12472), 1,
      anon_sym_DASH,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12476), 1,
      anon_sym_STAR,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    ACTIONS(12482), 1,
      aux_sym__expression_token1,
    ACTIONS(12484), 1,
      aux_sym__expression_token2,
    ACTIONS(12486), 1,
      anon_sym_SLASH,
    ACTIONS(12488), 1,
      anon_sym_div,
    ACTIONS(12490), 1,
      anon_sym_DIV,
    ACTIONS(12492), 1,
      anon_sym_Div,
    ACTIONS(12494), 1,
      anon_sym_mod,
    ACTIONS(12496), 1,
      anon_sym_MOD,
    ACTIONS(12498), 1,
      anon_sym_Mod,
    ACTIONS(12500), 1,
      anon_sym_PLUS,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(2364), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2366), 21,
      anon_sym_EQ,
      sym__assignment_operator,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [155923] = 5,
    ACTIONS(12706), 1,
      anon_sym_COMMA,
    STATE(5910), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(376), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(374), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [155982] = 4,
    ACTIONS(12704), 1,
      anon_sym_COMMA,
    STATE(5880), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2356), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [156039] = 4,
    ACTIONS(12704), 1,
      anon_sym_COMMA,
    STATE(5877), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2356), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [156096] = 9,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11803), 1,
      anon_sym_DOT,
    ACTIONS(11854), 1,
      anon_sym_RPAREN,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(11801), 3,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_if_table_relation_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 29,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [156163] = 4,
    ACTIONS(12718), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2426), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2428), 35,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [156220] = 5,
    ACTIONS(12706), 1,
      anon_sym_COMMA,
    STATE(5891), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2354), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2356), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [156279] = 8,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12474), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12478), 1,
      anon_sym_LBRACK,
    STATE(2896), 1,
      sym_comparison_operator,
    STATE(11174), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 32,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [156344] = 3,
    ACTIONS(12722), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12720), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [156398] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12724), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [156450] = 3,
    ACTIONS(12729), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12727), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [156504] = 3,
    ACTIONS(11785), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11780), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [156558] = 17,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6281), 1,
      sym_preproc_elif,
    STATE(6813), 1,
      sym_preproc_else,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(6845), 1,
      sym_preproc_endif,
    STATE(8173), 1,
      aux_sym_preproc_conditional_permissions_repeat1,
    STATE(5962), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(12735), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(12737), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3439), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [156640] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2555), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2557), 35,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [156694] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12743), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [156746] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2529), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2531), 35,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [156800] = 4,
    ACTIONS(12745), 1,
      sym_temporary_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2533), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2535), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [156856] = 3,
    ACTIONS(12749), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12747), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [156910] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12751), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [156962] = 6,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(12753), 1,
      anon_sym_COLON_COLON,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 32,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [157022] = 3,
    ACTIONS(12757), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12755), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [157076] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12759), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [157128] = 4,
    ACTIONS(12559), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [157184] = 3,
    ACTIONS(12763), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12761), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [157238] = 3,
    ACTIONS(12765), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11773), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [157292] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2428), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [157344] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2541), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [157396] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2551), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2553), 35,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [157450] = 10,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12768), 1,
      anon_sym_DOT,
    ACTIONS(12771), 1,
      anon_sym_RPAREN,
    ACTIONS(12774), 1,
      aux_sym_where_clause_token1,
    STATE(4763), 1,
      sym_argument_list,
    STATE(10202), 1,
      aux_sym_calc_field_reference_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 29,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [157518] = 3,
    ACTIONS(12778), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12776), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [157572] = 3,
    ACTIONS(12780), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11815), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [157626] = 3,
    ACTIONS(12785), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12783), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [157680] = 3,
    ACTIONS(12789), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12787), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [157734] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12791), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [157786] = 3,
    ACTIONS(12795), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12793), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [157840] = 3,
    ACTIONS(12799), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12797), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [157894] = 3,
    ACTIONS(12803), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12801), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [157948] = 3,
    ACTIONS(12807), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12805), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [158002] = 3,
    ACTIONS(12811), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12809), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [158056] = 3,
    ACTIONS(12815), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12813), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [158110] = 3,
    ACTIONS(12819), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12817), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [158164] = 3,
    ACTIONS(12823), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12821), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [158218] = 3,
    ACTIONS(12827), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12825), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [158272] = 3,
    ACTIONS(12831), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12829), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [158326] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2565), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2567), 35,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [158380] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2539), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2541), 35,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [158434] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [158486] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12835), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [158538] = 9,
    ACTIONS(2207), 1,
      aux_sym_where_clause_token1,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    STATE(4763), 1,
      sym_argument_list,
    STATE(11193), 1,
      sym_where_clause,
    ACTIONS(11740), 2,
      anon_sym_SEMI,
      aux_sym_if_table_relation_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [158604] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12837), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [158656] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12839), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [158708] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2405), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [158760] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12841), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [158812] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12843), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [158864] = 17,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6281), 1,
      sym_preproc_elif,
    STATE(6809), 1,
      sym_preproc_else,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(7244), 1,
      sym_preproc_endif,
    STATE(7856), 1,
      aux_sym_preproc_conditional_permissions_repeat1,
    STATE(6302), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(12735), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(12737), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3076), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [158946] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2531), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [158998] = 3,
    ACTIONS(12845), 1,
      sym_temporary_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2535), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [159052] = 3,
    ACTIONS(12849), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12847), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [159106] = 17,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6281), 1,
      sym_preproc_elif,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(6838), 1,
      sym_preproc_else,
    STATE(6882), 1,
      sym_preproc_endif,
    STATE(7788), 1,
      aux_sym_preproc_conditional_permissions_repeat1,
    STATE(6302), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(12735), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(12737), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3439), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [159188] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12851), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [159240] = 3,
    ACTIONS(12857), 3,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12854), 39,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [159294] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2543), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2545), 35,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [159348] = 3,
    ACTIONS(12859), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11750), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [159402] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2416), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [159454] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5449), 13,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(5447), 29,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [159508] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2420), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [159560] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2424), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [159612] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12862), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [159664] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2553), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [159716] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2428), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [159768] = 17,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6281), 1,
      sym_preproc_elif,
    STATE(6807), 1,
      sym_preproc_else,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(7247), 1,
      sym_preproc_endif,
    STATE(8074), 1,
      aux_sym_preproc_conditional_permissions_repeat1,
    STATE(5958), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(12735), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(12737), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3076), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [159850] = 3,
    ACTIONS(12866), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12864), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [159904] = 3,
    ACTIONS(12870), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12868), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [159958] = 3,
    ACTIONS(12874), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12872), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [160012] = 3,
    ACTIONS(12878), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12876), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [160066] = 3,
    ACTIONS(12882), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12880), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [160120] = 3,
    ACTIONS(12886), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12884), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [160174] = 3,
    ACTIONS(12890), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12888), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [160228] = 3,
    ACTIONS(12894), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12892), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [160282] = 3,
    ACTIONS(12898), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12896), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [160336] = 3,
    ACTIONS(12902), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12900), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [160390] = 3,
    ACTIONS(12904), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11782), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [160444] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2403), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2405), 35,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [160498] = 3,
    ACTIONS(12907), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11808), 41,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [160552] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2517), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2519), 35,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [160606] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12910), 42,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [160658] = 21,
    ACTIONS(12912), 1,
      anon_sym_RBRACE,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [160747] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2569), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2571), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [160800] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(12946), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [160889] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(2408), 1,
      sym_of_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12948), 3,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [161004] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(307), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [161119] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(383), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [161234] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(204), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12954), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [161349] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2637), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2639), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [161402] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(384), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [161517] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(12956), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [161606] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(8939), 1,
      sym_then_keyword,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12958), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [161721] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2649), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2651), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [161774] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(12960), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(5990), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [161863] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2625), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2627), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [161916] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2629), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2631), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [161969] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(2407), 1,
      sym_of_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12948), 3,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [162084] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(574), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [162199] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2633), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2635), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [162252] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12962), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [162303] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2609), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2611), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [162356] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(346), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [162471] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(118), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [162586] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(258), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [162701] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(259), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [162816] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(382), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [162931] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12964), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [162982] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12966), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [163033] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12968), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [163084] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(447), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [163199] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(558), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [163314] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(559), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [163429] = 4,
    ACTIONS(12971), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2613), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2615), 33,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [163484] = 16,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2360), 4,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2362), 24,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [163563] = 8,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 30,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [163626] = 33,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12993), 1,
      sym__assignment_operator,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    ACTIONS(13001), 1,
      anon_sym_and,
    ACTIONS(13003), 1,
      anon_sym_AND,
    ACTIONS(13005), 1,
      anon_sym_And,
    ACTIONS(13007), 1,
      anon_sym_or,
    ACTIONS(13009), 1,
      anon_sym_OR,
    ACTIONS(13011), 1,
      anon_sym_Or,
    ACTIONS(13013), 1,
      anon_sym_xor,
    ACTIONS(13015), 1,
      anon_sym_XOR,
    ACTIONS(13017), 1,
      anon_sym_Xor,
    ACTIONS(13019), 1,
      anon_sym_QMARK,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2328), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [163739] = 8,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 30,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [163802] = 8,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 30,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [163865] = 8,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 30,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [163928] = 8,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 30,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [163991] = 8,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 30,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [164054] = 3,
    ACTIONS(13021), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2615), 40,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [164107] = 8,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 30,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [164170] = 8,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 30,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [164233] = 3,
    ACTIONS(13023), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2621), 40,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [164286] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(415), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [164401] = 4,
    ACTIONS(13025), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2619), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2621), 33,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [164456] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2587), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [164507] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2587), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [164558] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2593), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2595), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [164611] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2587), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [164662] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2591), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [164713] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2591), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [164764] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2591), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [164815] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13027), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [164866] = 4,
    ACTIONS(13029), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2426), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2428), 33,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [164921] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(421), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [165036] = 5,
    ACTIONS(13031), 1,
      anon_sym_COMMA,
    STATE(6050), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2354), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2356), 32,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [165093] = 5,
    ACTIONS(13031), 1,
      anon_sym_COMMA,
    STATE(6070), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2354), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2356), 32,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [165150] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2593), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2595), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [165203] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2585), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2587), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [165256] = 5,
    ACTIONS(13033), 1,
      anon_sym_COMMA,
    STATE(6050), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2403), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2405), 32,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [165313] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(338), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [165428] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(308), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [165543] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(309), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [165658] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13036), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [165709] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(316), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [165824] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2585), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2587), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [165877] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(324), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [165992] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(325), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [166107] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13038), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [166196] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(250), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [166311] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(581), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [166426] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(429), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [166541] = 16,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2360), 4,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2362), 24,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [166620] = 22,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 15,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [166711] = 22,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 15,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [166802] = 22,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 15,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [166893] = 25,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    ACTIONS(13001), 1,
      anon_sym_and,
    ACTIONS(13003), 1,
      anon_sym_AND,
    ACTIONS(13005), 1,
      anon_sym_And,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 12,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [166990] = 25,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    ACTIONS(13001), 1,
      anon_sym_and,
    ACTIONS(13003), 1,
      anon_sym_AND,
    ACTIONS(13005), 1,
      anon_sym_And,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 12,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [167087] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(430), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [167202] = 5,
    ACTIONS(13031), 1,
      anon_sym_COMMA,
    STATE(6050), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2410), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2412), 32,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [167259] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(345), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [167374] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(416), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [167489] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13040), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [167578] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13042), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [167667] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(391), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [167782] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13044), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6180), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [167871] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13046), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [167960] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13048), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6102), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [168049] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2651), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [168100] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2627), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [168151] = 16,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2430), 4,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2432), 24,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [168230] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2631), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [168281] = 33,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    ACTIONS(13001), 1,
      anon_sym_and,
    ACTIONS(13003), 1,
      anon_sym_AND,
    ACTIONS(13005), 1,
      anon_sym_And,
    ACTIONS(13007), 1,
      anon_sym_or,
    ACTIONS(13009), 1,
      anon_sym_OR,
    ACTIONS(13011), 1,
      anon_sym_Or,
    ACTIONS(13013), 1,
      anon_sym_xor,
    ACTIONS(13015), 1,
      anon_sym_XOR,
    ACTIONS(13017), 1,
      anon_sym_Xor,
    ACTIONS(13019), 1,
      anon_sym_QMARK,
    ACTIONS(13050), 1,
      sym__assignment_operator,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2374), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [168394] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13052), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [168483] = 25,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    ACTIONS(13001), 1,
      anon_sym_and,
    ACTIONS(13003), 1,
      anon_sym_AND,
    ACTIONS(13005), 1,
      anon_sym_And,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 12,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [168580] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2635), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [168631] = 33,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12993), 1,
      sym__assignment_operator,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    ACTIONS(13001), 1,
      anon_sym_and,
    ACTIONS(13003), 1,
      anon_sym_AND,
    ACTIONS(13005), 1,
      anon_sym_And,
    ACTIONS(13007), 1,
      anon_sym_or,
    ACTIONS(13009), 1,
      anon_sym_OR,
    ACTIONS(13011), 1,
      anon_sym_Or,
    ACTIONS(13013), 1,
      anon_sym_xor,
    ACTIONS(13015), 1,
      anon_sym_XOR,
    ACTIONS(13017), 1,
      anon_sym_Xor,
    ACTIONS(13019), 1,
      anon_sym_QMARK,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2380), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [168744] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13054), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [168833] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(583), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [168948] = 3,
    ACTIONS(13059), 2,
      sym_dataitem_keyword,
      sym_column_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13056), 39,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [169001] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13061), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [169052] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2643), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [169103] = 11,
    ACTIONS(2541), 1,
      anon_sym_COMMA,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11801), 1,
      aux_sym_where_clause_token1,
    ACTIONS(11803), 1,
      anon_sym_DOT,
    ACTIONS(11854), 1,
      anon_sym_EQ,
    ACTIONS(13064), 1,
      anon_sym_SEMI,
    ACTIONS(13068), 1,
      anon_sym_LPAREN,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 27,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [169172] = 25,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    ACTIONS(13001), 1,
      anon_sym_and,
    ACTIONS(13003), 1,
      anon_sym_AND,
    ACTIONS(13005), 1,
      anon_sym_And,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 12,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [169269] = 25,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    ACTIONS(13001), 1,
      anon_sym_and,
    ACTIONS(13003), 1,
      anon_sym_AND,
    ACTIONS(13005), 1,
      anon_sym_And,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 12,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [169366] = 25,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    ACTIONS(13001), 1,
      anon_sym_and,
    ACTIONS(13003), 1,
      anon_sym_AND,
    ACTIONS(13005), 1,
      anon_sym_And,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 12,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [169463] = 21,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2364), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2366), 19,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [169552] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13070), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [169641] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2593), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2595), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [169694] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(274), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [169809] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(275), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [169924] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13072), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [170013] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(276), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [170128] = 32,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    ACTIONS(13001), 1,
      anon_sym_and,
    ACTIONS(13003), 1,
      anon_sym_AND,
    ACTIONS(13005), 1,
      anon_sym_And,
    ACTIONS(13007), 1,
      anon_sym_or,
    ACTIONS(13009), 1,
      anon_sym_OR,
    ACTIONS(13011), 1,
      anon_sym_Or,
    ACTIONS(13013), 1,
      anon_sym_xor,
    ACTIONS(13015), 1,
      anon_sym_XOR,
    ACTIONS(13017), 1,
      anon_sym_Xor,
    ACTIONS(13019), 1,
      anon_sym_QMARK,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2370), 5,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [170239] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(240), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [170354] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2605), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2607), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [170407] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13074), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [170496] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13076), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6200), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [170585] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13078), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6098), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [170674] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(241), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [170789] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13080), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6123), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [170878] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13082), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6073), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [170967] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13084), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6199), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [171056] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(604), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [171171] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13086), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6059), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [171260] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(605), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [171375] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13088), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6155), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [171464] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(242), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [171579] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13090), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [171630] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13092), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6131), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [171719] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13094), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [171770] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13096), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6197), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [171859] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13098), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [171948] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13100), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6084), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [172037] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13102), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6088), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [172126] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13104), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6107), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [172215] = 9,
    ACTIONS(2207), 1,
      aux_sym_where_clause_token1,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11740), 1,
      anon_sym_SEMI,
    STATE(4763), 1,
      sym_argument_list,
    STATE(11193), 1,
      sym_where_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [172280] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13106), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(5992), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [172369] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13108), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6074), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [172458] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13110), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6077), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [172547] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13112), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [172636] = 33,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12993), 1,
      sym__assignment_operator,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    ACTIONS(13001), 1,
      anon_sym_and,
    ACTIONS(13003), 1,
      anon_sym_AND,
    ACTIONS(13005), 1,
      anon_sym_And,
    ACTIONS(13007), 1,
      anon_sym_or,
    ACTIONS(13009), 1,
      anon_sym_OR,
    ACTIONS(13011), 1,
      anon_sym_Or,
    ACTIONS(13013), 1,
      anon_sym_xor,
    ACTIONS(13015), 1,
      anon_sym_XOR,
    ACTIONS(13017), 1,
      anon_sym_Xor,
    ACTIONS(13019), 1,
      anon_sym_QMARK,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2385), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [172749] = 33,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12993), 1,
      sym__assignment_operator,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    ACTIONS(13001), 1,
      anon_sym_and,
    ACTIONS(13003), 1,
      anon_sym_AND,
    ACTIONS(13005), 1,
      anon_sym_And,
    ACTIONS(13007), 1,
      anon_sym_or,
    ACTIONS(13009), 1,
      anon_sym_OR,
    ACTIONS(13011), 1,
      anon_sym_Or,
    ACTIONS(13013), 1,
      anon_sym_xor,
    ACTIONS(13015), 1,
      anon_sym_XOR,
    ACTIONS(13017), 1,
      anon_sym_Xor,
    ACTIONS(13019), 1,
      anon_sym_QMARK,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2390), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [172862] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13114), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [172913] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(582), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [173028] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(283), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [173143] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(291), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [173258] = 7,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2316), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2318), 31,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [173319] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13116), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(5999), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [173408] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2575), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [173459] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2585), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2587), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [173512] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(83), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(13118), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [173627] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(399), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [173742] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(400), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [173857] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2589), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2591), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [173910] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(2411), 1,
      sym_of_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12948), 3,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [174025] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2597), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2599), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [174078] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(584), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [174193] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(585), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [174308] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(586), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [174423] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(587), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [174538] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(86), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(13118), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [174653] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13120), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6183), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [174742] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(85), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(13118), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [174857] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13122), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [174946] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(588), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [175061] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(589), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [175176] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(590), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [175291] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(591), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [175406] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(88), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(13118), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [175521] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(592), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [175636] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(593), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [175751] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(594), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [175866] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(595), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [175981] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(89), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(13118), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [176096] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(596), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [176211] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(597), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [176326] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(598), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [176441] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(599), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [176556] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(84), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(13118), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [176671] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(600), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [176786] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(601), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [176901] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(602), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [177016] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(603), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [177131] = 33,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(12470), 1,
      anon_sym_DOT,
    ACTIONS(12973), 1,
      anon_sym_DOT_DOT,
    ACTIONS(12975), 1,
      anon_sym_STAR,
    ACTIONS(12977), 1,
      anon_sym_SLASH,
    ACTIONS(12979), 1,
      anon_sym_div,
    ACTIONS(12981), 1,
      anon_sym_DIV,
    ACTIONS(12983), 1,
      anon_sym_Div,
    ACTIONS(12985), 1,
      anon_sym_mod,
    ACTIONS(12987), 1,
      anon_sym_MOD,
    ACTIONS(12989), 1,
      anon_sym_Mod,
    ACTIONS(12991), 1,
      anon_sym_DASH,
    ACTIONS(12993), 1,
      sym__assignment_operator,
    ACTIONS(12995), 1,
      aux_sym__expression_token1,
    ACTIONS(12997), 1,
      aux_sym__expression_token2,
    ACTIONS(12999), 1,
      anon_sym_PLUS,
    ACTIONS(13001), 1,
      anon_sym_and,
    ACTIONS(13003), 1,
      anon_sym_AND,
    ACTIONS(13005), 1,
      anon_sym_And,
    ACTIONS(13007), 1,
      anon_sym_or,
    ACTIONS(13009), 1,
      anon_sym_OR,
    ACTIONS(13011), 1,
      anon_sym_Or,
    ACTIONS(13013), 1,
      anon_sym_xor,
    ACTIONS(13015), 1,
      anon_sym_XOR,
    ACTIONS(13017), 1,
      anon_sym_Xor,
    ACTIONS(13019), 1,
      anon_sym_QMARK,
    STATE(2828), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2394), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [177244] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(2410), 1,
      sym_of_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12948), 3,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [177359] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2641), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2643), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [177412] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(344), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [177527] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2579), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [177578] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13124), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [177667] = 5,
    ACTIONS(13031), 1,
      anon_sym_COMMA,
    STATE(6046), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(376), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(374), 32,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [177724] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2645), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2647), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [177777] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13126), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [177866] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2573), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2575), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [177919] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2583), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [177970] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2577), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2579), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [178023] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2571), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [178074] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2589), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2591), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [178127] = 21,
    ACTIONS(11914), 1,
      anon_sym_RBRACE,
    ACTIONS(13128), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(13131), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(13134), 1,
      anon_sym_LBRACK,
    ACTIONS(13137), 1,
      aux_sym_basic_type_token22,
    ACTIONS(13140), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(13143), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(13146), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(13149), 1,
      aux_sym_separator_action_token1,
    ACTIONS(13152), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(13155), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(13158), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(13161), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(13164), 1,
      sym_trigger_keyword,
    ACTIONS(13167), 1,
      sym_area_keyword,
    ACTIONS(13170), 1,
      sym_group_keyword,
    ACTIONS(13173), 1,
      sym_property_name,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11911), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [178216] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2589), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2591), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [178269] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2601), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2603), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [178322] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(292), 1,
      sym_do_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12952), 3,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [178437] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13176), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [178488] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13178), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [178539] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2581), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2583), 34,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      anon_sym_to,
      anon_sym_TO,
      anon_sym_To,
      anon_sym_downto,
      anon_sym_DOWNTO,
      anon_sym_Downto,
  [178592] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(372), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12950), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [178707] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13180), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [178796] = 7,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11803), 1,
      anon_sym_DOT,
    ACTIONS(11854), 1,
      anon_sym_RPAREN,
    ACTIONS(11801), 3,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_if_table_relation_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 29,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [178857] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13182), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [178946] = 21,
    ACTIONS(12914), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(12916), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(12918), 1,
      anon_sym_LBRACK,
    ACTIONS(12920), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12922), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(12924), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(12926), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(12928), 1,
      aux_sym_separator_action_token1,
    ACTIONS(12930), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(12932), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(12934), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(12936), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(12938), 1,
      sym_trigger_keyword,
    ACTIONS(12940), 1,
      sym_area_keyword,
    ACTIONS(12942), 1,
      sym_group_keyword,
    ACTIONS(12944), 1,
      sym_property_name,
    ACTIONS(13184), 1,
      anon_sym_RBRACE,
    STATE(4691), 1,
      sym_preproc_if,
    ACTIONS(11610), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6189), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [179035] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(217), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12954), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [179150] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(218), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12954), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [179265] = 34,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(219), 1,
      sym_then_keyword,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(12954), 3,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [179380] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2647), 41,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [179431] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13188), 1,
      anon_sym_RBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11085), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [179547] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13190), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10361), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [179663] = 8,
    ACTIONS(2541), 1,
      anon_sym_COMMA,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13192), 1,
      anon_sym_SEMI,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [179725] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13195), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10896), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [179841] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13197), 1,
      anon_sym_RBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10897), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [179957] = 18,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13199), 1,
      sym_identifier,
    ACTIONS(13201), 1,
      anon_sym_SEMI,
    ACTIONS(13203), 1,
      anon_sym_COLON,
    ACTIONS(13205), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13209), 1,
      sym_quoted_identifier,
    ACTIONS(13211), 1,
      sym_begin_keyword,
    STATE(7107), 1,
      sym__procedure_return_specification,
    STATE(7108), 1,
      sym__procedure_named_return,
    STATE(7453), 1,
      sym_preproc_if,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5197), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10631), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11171), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(13207), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [180039] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13213), 1,
      anon_sym_RBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10384), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [180155] = 4,
    ACTIONS(12753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 32,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [180209] = 4,
    ACTIONS(2268), 3,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_if_table_relation_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2426), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2428), 30,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [180263] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13215), 1,
      anon_sym_RBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10531), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [180379] = 18,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13199), 1,
      sym_identifier,
    ACTIONS(13203), 1,
      anon_sym_COLON,
    ACTIONS(13209), 1,
      sym_quoted_identifier,
    ACTIONS(13217), 1,
      anon_sym_SEMI,
    ACTIONS(13219), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13221), 1,
      sym_begin_keyword,
    STATE(7172), 1,
      sym__procedure_return_specification,
    STATE(7173), 1,
      sym__procedure_named_return,
    STATE(7413), 1,
      sym_preproc_if,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5830), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10596), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11171), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(10182), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [180461] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13223), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10990), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [180577] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(13225), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [180689] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13227), 1,
      anon_sym_RBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10610), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [180805] = 7,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(13229), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [180865] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13231), 1,
      anon_sym_RBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10786), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [180981] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13233), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10811), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [181097] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13235), 1,
      anon_sym_RBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10812), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [181213] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13237), 1,
      anon_sym_RBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10958), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [181329] = 18,
    ACTIONS(10168), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(10178), 1,
      sym_begin_keyword,
    ACTIONS(13199), 1,
      sym_identifier,
    ACTIONS(13203), 1,
      anon_sym_COLON,
    ACTIONS(13209), 1,
      sym_quoted_identifier,
    ACTIONS(13239), 1,
      anon_sym_SEMI,
    STATE(7137), 1,
      sym__procedure_return_specification,
    STATE(7143), 1,
      sym__procedure_named_return,
    STATE(7416), 1,
      sym_preproc_if,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(3760), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(11000), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11171), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(10182), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [181411] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13241), 1,
      anon_sym_RBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10622), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [181527] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13243), 1,
      anon_sym_RBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10970), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [181643] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13245), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10530), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [181759] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13247), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10804), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [181875] = 18,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13199), 1,
      sym_identifier,
    ACTIONS(13203), 1,
      anon_sym_COLON,
    ACTIONS(13205), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13209), 1,
      sym_quoted_identifier,
    ACTIONS(13211), 1,
      sym_begin_keyword,
    ACTIONS(13249), 1,
      anon_sym_SEMI,
    STATE(7169), 1,
      sym__procedure_return_specification,
    STATE(7170), 1,
      sym__procedure_named_return,
    STATE(7453), 1,
      sym_preproc_if,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5106), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10534), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11171), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(10190), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [181957] = 18,
    ACTIONS(10168), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(10178), 1,
      sym_begin_keyword,
    ACTIONS(13199), 1,
      sym_identifier,
    ACTIONS(13203), 1,
      anon_sym_COLON,
    ACTIONS(13209), 1,
      sym_quoted_identifier,
    ACTIONS(13251), 1,
      anon_sym_SEMI,
    STATE(7132), 1,
      sym__procedure_return_specification,
    STATE(7133), 1,
      sym__procedure_named_return,
    STATE(7416), 1,
      sym_preproc_if,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(3546), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10500), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11171), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(10190), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [182039] = 18,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13199), 1,
      sym_identifier,
    ACTIONS(13203), 1,
      anon_sym_COLON,
    ACTIONS(13209), 1,
      sym_quoted_identifier,
    ACTIONS(13219), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13221), 1,
      sym_begin_keyword,
    ACTIONS(13253), 1,
      anon_sym_SEMI,
    STATE(7150), 1,
      sym__procedure_return_specification,
    STATE(7171), 1,
      sym__procedure_named_return,
    STATE(7413), 1,
      sym_preproc_if,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5478), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10626), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11171), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(13255), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [182121] = 18,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13199), 1,
      sym_identifier,
    ACTIONS(13203), 1,
      anon_sym_COLON,
    ACTIONS(13209), 1,
      sym_quoted_identifier,
    ACTIONS(13219), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13221), 1,
      sym_begin_keyword,
    ACTIONS(13257), 1,
      anon_sym_SEMI,
    STATE(7113), 1,
      sym__procedure_return_specification,
    STATE(7115), 1,
      sym__procedure_named_return,
    STATE(7413), 1,
      sym_preproc_if,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5466), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10611), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11171), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(10190), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [182203] = 18,
    ACTIONS(10168), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(10178), 1,
      sym_begin_keyword,
    ACTIONS(13199), 1,
      sym_identifier,
    ACTIONS(13203), 1,
      anon_sym_COLON,
    ACTIONS(13209), 1,
      sym_quoted_identifier,
    ACTIONS(13259), 1,
      anon_sym_SEMI,
    STATE(7152), 1,
      sym__procedure_return_specification,
    STATE(7208), 1,
      sym__procedure_named_return,
    STATE(7416), 1,
      sym_preproc_if,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(3703), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10563), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11171), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(13207), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [182285] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13261), 1,
      anon_sym_RBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10509), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [182401] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13263), 1,
      anon_sym_RBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10953), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [182517] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13265), 1,
      anon_sym_RBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10592), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [182633] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13267), 1,
      anon_sym_RBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10798), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [182749] = 18,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13199), 1,
      sym_identifier,
    ACTIONS(13203), 1,
      anon_sym_COLON,
    ACTIONS(13205), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13209), 1,
      sym_quoted_identifier,
    ACTIONS(13211), 1,
      sym_begin_keyword,
    ACTIONS(13269), 1,
      anon_sym_SEMI,
    STATE(7175), 1,
      sym__procedure_return_specification,
    STATE(7176), 1,
      sym__procedure_named_return,
    STATE(7453), 1,
      sym_preproc_if,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5194), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10548), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11171), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(13255), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [182831] = 18,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13199), 1,
      sym_identifier,
    ACTIONS(13203), 1,
      anon_sym_COLON,
    ACTIONS(13209), 1,
      sym_quoted_identifier,
    ACTIONS(13219), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13221), 1,
      sym_begin_keyword,
    ACTIONS(13271), 1,
      anon_sym_SEMI,
    STATE(7136), 1,
      sym__procedure_return_specification,
    STATE(7142), 1,
      sym__procedure_named_return,
    STATE(7413), 1,
      sym_preproc_if,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5624), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10667), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11171), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(13207), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [182913] = 18,
    ACTIONS(10168), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(10178), 1,
      sym_begin_keyword,
    ACTIONS(13199), 1,
      sym_identifier,
    ACTIONS(13203), 1,
      anon_sym_COLON,
    ACTIONS(13209), 1,
      sym_quoted_identifier,
    ACTIONS(13273), 1,
      anon_sym_SEMI,
    STATE(7164), 1,
      sym__procedure_return_specification,
    STATE(7165), 1,
      sym__procedure_named_return,
    STATE(7416), 1,
      sym_preproc_if,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(3574), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10770), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11171), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(13255), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [182995] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13275), 1,
      anon_sym_RBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10883), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [183111] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13277), 1,
      anon_sym_RBRACK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10362), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [183227] = 18,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13199), 1,
      sym_identifier,
    ACTIONS(13203), 1,
      anon_sym_COLON,
    ACTIONS(13205), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13209), 1,
      sym_quoted_identifier,
    ACTIONS(13211), 1,
      sym_begin_keyword,
    ACTIONS(13279), 1,
      anon_sym_SEMI,
    STATE(7202), 1,
      sym__procedure_return_specification,
    STATE(7204), 1,
      sym__procedure_named_return,
    STATE(7453), 1,
      sym_preproc_if,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5119), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10511), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11171), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(10182), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [183309] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13281), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10609), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [183425] = 35,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(13283), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(10969), 1,
      aux_sym_argument_list_repeat1,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [183541] = 6,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13068), 1,
      anon_sym_LPAREN,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 29,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [183598] = 7,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13285), 1,
      anon_sym_COLON_EQ,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 8,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      sym__assignment_operator,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 27,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [183657] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10186), 39,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [183706] = 7,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13287), 1,
      anon_sym_RPAREN,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [183765] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13289), 39,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [183814] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13291), 39,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [183863] = 9,
    ACTIONS(2541), 1,
      anon_sym_COMMA,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11801), 1,
      aux_sym_where_clause_token1,
    ACTIONS(11803), 1,
      anon_sym_DOT,
    ACTIONS(11854), 1,
      anon_sym_EQ,
    ACTIONS(13064), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 27,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [183926] = 7,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13293), 1,
      anon_sym_COLON_EQ,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 8,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      sym__assignment_operator,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 27,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [183985] = 7,
    ACTIONS(2348), 1,
      aux_sym_where_clause_token1,
    ACTIONS(13295), 1,
      anon_sym_SEMI,
    ACTIONS(13299), 1,
      anon_sym_COMMA,
    ACTIONS(13302), 1,
      anon_sym_COLON,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5932), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5934), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [184044] = 7,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13304), 1,
      anon_sym_COLON_EQ,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 8,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      sym__assignment_operator,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 27,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [184103] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13306), 39,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [184152] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13308), 39,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [184201] = 7,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13310), 1,
      anon_sym_COLON_EQ,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 8,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      sym__assignment_operator,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 27,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [184260] = 7,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13312), 1,
      anon_sym_RPAREN,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [184319] = 7,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13314), 1,
      anon_sym_COLON_EQ,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 8,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      sym__assignment_operator,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 27,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [184378] = 7,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13316), 1,
      anon_sym_COLON_EQ,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 8,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      sym__assignment_operator,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 27,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [184437] = 7,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13318), 1,
      anon_sym_RPAREN,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [184496] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13320), 39,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [184545] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13323), 39,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [184594] = 7,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13325), 1,
      anon_sym_SEMI,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [184653] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10766), 39,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [184702] = 7,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13327), 1,
      anon_sym_RPAREN,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [184761] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13329), 39,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [184810] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13332), 39,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [184859] = 22,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(13335), 1,
      anon_sym_DASH,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    ACTIONS(13355), 1,
      anon_sym_PLUS,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 12,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
  [184947] = 11,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(6302), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
    ACTIONS(13357), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [185013] = 8,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 27,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [185073] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5449), 38,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [185121] = 25,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(13335), 1,
      anon_sym_DASH,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    ACTIONS(13355), 1,
      anon_sym_PLUS,
    ACTIONS(13359), 1,
      anon_sym_and,
    ACTIONS(13361), 1,
      anon_sym_AND,
    ACTIONS(13363), 1,
      anon_sym_And,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 9,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
  [185215] = 5,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13229), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [185269] = 6,
    ACTIONS(13192), 1,
      anon_sym_SEMI,
    ACTIONS(13365), 1,
      anon_sym_COMMA,
    STATE(10799), 1,
      aux_sym_caption_value_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5932), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5934), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [185325] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13368), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [185435] = 22,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(13335), 1,
      anon_sym_DASH,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    ACTIONS(13355), 1,
      anon_sym_PLUS,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 12,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
  [185523] = 22,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(13335), 1,
      anon_sym_DASH,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    ACTIONS(13355), 1,
      anon_sym_PLUS,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 12,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
  [185611] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13370), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [185721] = 11,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(6271), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
    ACTIONS(13372), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [185787] = 8,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 27,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [185847] = 33,
    ACTIONS(2374), 1,
      anon_sym_SEMI,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(13335), 1,
      anon_sym_DASH,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    ACTIONS(13355), 1,
      anon_sym_PLUS,
    ACTIONS(13359), 1,
      anon_sym_and,
    ACTIONS(13361), 1,
      anon_sym_AND,
    ACTIONS(13363), 1,
      anon_sym_And,
    ACTIONS(13374), 1,
      sym__assignment_operator,
    ACTIONS(13376), 1,
      anon_sym_or,
    ACTIONS(13378), 1,
      anon_sym_OR,
    ACTIONS(13380), 1,
      anon_sym_Or,
    ACTIONS(13382), 1,
      anon_sym_xor,
    ACTIONS(13384), 1,
      anon_sym_XOR,
    ACTIONS(13386), 1,
      anon_sym_Xor,
    ACTIONS(13388), 1,
      anon_sym_QMARK,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [185957] = 25,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(13335), 1,
      anon_sym_DASH,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    ACTIONS(13355), 1,
      anon_sym_PLUS,
    ACTIONS(13359), 1,
      anon_sym_and,
    ACTIONS(13361), 1,
      anon_sym_AND,
    ACTIONS(13363), 1,
      anon_sym_And,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 9,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
  [186051] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13390), 1,
      anon_sym_COLON,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [186161] = 25,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(13335), 1,
      anon_sym_DASH,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    ACTIONS(13355), 1,
      anon_sym_PLUS,
    ACTIONS(13359), 1,
      anon_sym_and,
    ACTIONS(13361), 1,
      anon_sym_AND,
    ACTIONS(13363), 1,
      anon_sym_And,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 9,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
  [186255] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13392), 1,
      anon_sym_COLON,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [186365] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13394), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [186475] = 16,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2360), 4,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2362), 21,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [186551] = 32,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(13335), 1,
      anon_sym_DASH,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    ACTIONS(13355), 1,
      anon_sym_PLUS,
    ACTIONS(13359), 1,
      anon_sym_and,
    ACTIONS(13361), 1,
      anon_sym_AND,
    ACTIONS(13363), 1,
      anon_sym_And,
    ACTIONS(13376), 1,
      anon_sym_or,
    ACTIONS(13378), 1,
      anon_sym_OR,
    ACTIONS(13380), 1,
      anon_sym_Or,
    ACTIONS(13382), 1,
      anon_sym_xor,
    ACTIONS(13384), 1,
      anon_sym_XOR,
    ACTIONS(13386), 1,
      anon_sym_Xor,
    ACTIONS(13388), 1,
      anon_sym_QMARK,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2370), 2,
      anon_sym_SEMI,
      sym__assignment_operator,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [186659] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13396), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [186769] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13398), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [186879] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13400), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [186989] = 25,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(13335), 1,
      anon_sym_DASH,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    ACTIONS(13355), 1,
      anon_sym_PLUS,
    ACTIONS(13359), 1,
      anon_sym_and,
    ACTIONS(13361), 1,
      anon_sym_AND,
    ACTIONS(13363), 1,
      anon_sym_And,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 9,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
  [187083] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13402), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [187193] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13404), 1,
      anon_sym_COLON,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [187303] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13406), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [187413] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [187523] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13410), 1,
      anon_sym_COLON,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [187633] = 16,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2360), 4,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2362), 21,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [187709] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13412), 1,
      anon_sym_COLON,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [187819] = 11,
    ACTIONS(13422), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(6302), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(13417), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13414), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(13425), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(13428), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
    ACTIONS(13420), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [187885] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13431), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [187995] = 8,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 27,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [188055] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13433), 1,
      anon_sym_COLON,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [188165] = 16,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2430), 4,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2432), 21,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [188241] = 25,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(13335), 1,
      anon_sym_DASH,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    ACTIONS(13355), 1,
      anon_sym_PLUS,
    ACTIONS(13359), 1,
      anon_sym_and,
    ACTIONS(13361), 1,
      anon_sym_AND,
    ACTIONS(13363), 1,
      anon_sym_And,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 9,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
  [188335] = 8,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 27,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [188395] = 33,
    ACTIONS(2328), 1,
      anon_sym_SEMI,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(13335), 1,
      anon_sym_DASH,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    ACTIONS(13355), 1,
      anon_sym_PLUS,
    ACTIONS(13359), 1,
      anon_sym_and,
    ACTIONS(13361), 1,
      anon_sym_AND,
    ACTIONS(13363), 1,
      anon_sym_And,
    ACTIONS(13374), 1,
      sym__assignment_operator,
    ACTIONS(13376), 1,
      anon_sym_or,
    ACTIONS(13378), 1,
      anon_sym_OR,
    ACTIONS(13380), 1,
      anon_sym_Or,
    ACTIONS(13382), 1,
      anon_sym_xor,
    ACTIONS(13384), 1,
      anon_sym_XOR,
    ACTIONS(13386), 1,
      anon_sym_Xor,
    ACTIONS(13388), 1,
      anon_sym_QMARK,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [188505] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13435), 1,
      anon_sym_COLON,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [188615] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13437), 1,
      anon_sym_COLON,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [188725] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13439), 1,
      anon_sym_COLON,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [188835] = 8,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 27,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [188895] = 25,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(13335), 1,
      anon_sym_DASH,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    ACTIONS(13355), 1,
      anon_sym_PLUS,
    ACTIONS(13359), 1,
      anon_sym_and,
    ACTIONS(13361), 1,
      anon_sym_AND,
    ACTIONS(13363), 1,
      anon_sym_And,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2272), 9,
      anon_sym_SEMI,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
  [188989] = 16,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2430), 4,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2432), 21,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [189065] = 8,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 27,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [189125] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13441), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [189235] = 7,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2316), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2318), 28,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [189293] = 8,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 27,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [189353] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13444), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [189463] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13446), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [189573] = 4,
    ACTIONS(2348), 3,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_if_table_relation_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5932), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5934), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [189625] = 21,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(13335), 1,
      anon_sym_DASH,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    ACTIONS(13355), 1,
      anon_sym_PLUS,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2364), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2366), 16,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
  [189711] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13448), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [189821] = 6,
    ACTIONS(5882), 1,
      anon_sym_LPAREN,
    ACTIONS(5889), 1,
      anon_sym_COLON_COLON,
    STATE(4763), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [189877] = 8,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(13337), 1,
      anon_sym_DOT_DOT,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2320), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2322), 27,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [189937] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13450), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [190047] = 33,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13452), 1,
      anon_sym_RPAREN,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [190157] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2525), 8,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      sym__assignment_operator,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2527), 30,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [190207] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2266), 8,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      sym__assignment_operator,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2268), 30,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [190257] = 4,
    ACTIONS(13229), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5932), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5934), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [190308] = 12,
    ACTIONS(12374), 1,
      sym_var_keyword,
    ACTIONS(13454), 1,
      anon_sym_SEMI,
    STATE(4556), 1,
      sym_preproc_split_procedure_body,
    STATE(4557), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(11028), 1,
      sym_preproc_conditional_var_block,
    STATE(11029), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12377), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12371), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12369), 22,
      sym_property_name,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [190375] = 12,
    ACTIONS(12388), 1,
      sym_var_keyword,
    ACTIONS(13457), 1,
      anon_sym_SEMI,
    STATE(4560), 1,
      sym_preproc_split_procedure_body,
    STATE(4561), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(11034), 1,
      sym_preproc_conditional_var_block,
    STATE(11035), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12391), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12385), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12383), 22,
      sym_property_name,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [190442] = 9,
    ACTIONS(12360), 1,
      sym_var_keyword,
    STATE(7422), 1,
      sym_preproc_if,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12363), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(4555), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(11040), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(12357), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12355), 23,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [190503] = 12,
    ACTIONS(12419), 1,
      sym_var_keyword,
    ACTIONS(13460), 1,
      anon_sym_SEMI,
    STATE(4564), 1,
      sym_preproc_split_procedure_body,
    STATE(4565), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(11047), 1,
      sym_preproc_conditional_var_block,
    STATE(11048), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12422), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12416), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12414), 22,
      sym_property_name,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [190570] = 12,
    ACTIONS(12405), 1,
      sym_var_keyword,
    ACTIONS(13463), 1,
      anon_sym_SEMI,
    STATE(4566), 1,
      sym_preproc_split_procedure_body,
    STATE(4567), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(11052), 1,
      sym_preproc_conditional_var_block,
    STATE(11053), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12408), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12399), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12397), 22,
      sym_property_name,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [190637] = 32,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13466), 1,
      anon_sym_DOT,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [190744] = 32,
    ACTIONS(5207), 1,
      anon_sym_DOT,
    ACTIONS(5209), 1,
      anon_sym_DASH,
    ACTIONS(5211), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5213), 1,
      anon_sym_STAR,
    ACTIONS(5215), 1,
      anon_sym_LBRACK,
    ACTIONS(5221), 1,
      anon_sym_SLASH,
    ACTIONS(5235), 1,
      anon_sym_PLUS,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13468), 1,
      anon_sym_div,
    ACTIONS(13470), 1,
      anon_sym_DIV,
    ACTIONS(13472), 1,
      anon_sym_Div,
    ACTIONS(13474), 1,
      anon_sym_mod,
    ACTIONS(13476), 1,
      anon_sym_MOD,
    ACTIONS(13478), 1,
      anon_sym_Mod,
    ACTIONS(13480), 1,
      anon_sym_and,
    ACTIONS(13482), 1,
      anon_sym_AND,
    ACTIONS(13484), 1,
      anon_sym_And,
    ACTIONS(13486), 1,
      anon_sym_or,
    ACTIONS(13488), 1,
      anon_sym_OR,
    ACTIONS(13490), 1,
      anon_sym_Or,
    ACTIONS(13492), 1,
      anon_sym_xor,
    ACTIONS(13494), 1,
      anon_sym_XOR,
    ACTIONS(13496), 1,
      anon_sym_Xor,
    STATE(3001), 1,
      sym_comparison_operator,
    STATE(11128), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [190851] = 32,
    ACTIONS(4949), 1,
      anon_sym_DOT,
    ACTIONS(4951), 1,
      anon_sym_DASH,
    ACTIONS(4953), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4955), 1,
      anon_sym_STAR,
    ACTIONS(4957), 1,
      anon_sym_LBRACK,
    ACTIONS(4963), 1,
      anon_sym_SLASH,
    ACTIONS(4977), 1,
      anon_sym_PLUS,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13498), 1,
      anon_sym_div,
    ACTIONS(13500), 1,
      anon_sym_DIV,
    ACTIONS(13502), 1,
      anon_sym_Div,
    ACTIONS(13504), 1,
      anon_sym_mod,
    ACTIONS(13506), 1,
      anon_sym_MOD,
    ACTIONS(13508), 1,
      anon_sym_Mod,
    ACTIONS(13510), 1,
      anon_sym_and,
    ACTIONS(13512), 1,
      anon_sym_AND,
    ACTIONS(13514), 1,
      anon_sym_And,
    ACTIONS(13516), 1,
      anon_sym_or,
    ACTIONS(13518), 1,
      anon_sym_OR,
    ACTIONS(13520), 1,
      anon_sym_Or,
    ACTIONS(13522), 1,
      anon_sym_xor,
    ACTIONS(13524), 1,
      anon_sym_XOR,
    ACTIONS(13526), 1,
      anon_sym_Xor,
    STATE(3200), 1,
      sym_comparison_operator,
    STATE(11195), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [190958] = 5,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13285), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 8,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      sym__assignment_operator,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 27,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [191011] = 9,
    ACTIONS(12360), 1,
      sym_var_keyword,
    STATE(7422), 1,
      sym_preproc_if,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12363), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(4333), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10412), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(12357), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12355), 23,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [191072] = 12,
    ACTIONS(12419), 1,
      sym_var_keyword,
    ACTIONS(13528), 1,
      anon_sym_SEMI,
    STATE(4340), 1,
      sym_preproc_split_procedure_body,
    STATE(4341), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10427), 1,
      sym_preproc_conditional_var_block,
    STATE(10429), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12422), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12416), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12414), 22,
      sym_property_name,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [191139] = 12,
    ACTIONS(12405), 1,
      sym_var_keyword,
    ACTIONS(13531), 1,
      anon_sym_SEMI,
    STATE(4342), 1,
      sym_preproc_split_procedure_body,
    STATE(4343), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10356), 1,
      sym_preproc_conditional_var_block,
    STATE(10434), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12408), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12399), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12397), 22,
      sym_property_name,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [191206] = 5,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13287), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [191259] = 32,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [191366] = 32,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13534), 1,
      anon_sym_DOT,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [191473] = 32,
    ACTIONS(11824), 1,
      anon_sym_DASH,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_STAR,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(11836), 1,
      anon_sym_SLASH,
    ACTIONS(11838), 1,
      anon_sym_div,
    ACTIONS(11840), 1,
      anon_sym_DIV,
    ACTIONS(11842), 1,
      anon_sym_Div,
    ACTIONS(11844), 1,
      anon_sym_mod,
    ACTIONS(11846), 1,
      anon_sym_MOD,
    ACTIONS(11848), 1,
      anon_sym_Mod,
    ACTIONS(11850), 1,
      anon_sym_PLUS,
    ACTIONS(12004), 1,
      anon_sym_and,
    ACTIONS(12006), 1,
      anon_sym_AND,
    ACTIONS(12008), 1,
      anon_sym_And,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12024), 1,
      anon_sym_or,
    ACTIONS(12026), 1,
      anon_sym_OR,
    ACTIONS(12028), 1,
      anon_sym_Or,
    ACTIONS(12030), 1,
      anon_sym_xor,
    ACTIONS(12032), 1,
      anon_sym_XOR,
    ACTIONS(12034), 1,
      anon_sym_Xor,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13536), 1,
      anon_sym_DOT,
    STATE(2868), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [191580] = 5,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13312), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [191633] = 5,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13327), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [191686] = 12,
    ACTIONS(12374), 1,
      sym_var_keyword,
    ACTIONS(13538), 1,
      anon_sym_SEMI,
    STATE(3922), 1,
      sym_preproc_split_procedure_body,
    STATE(3923), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10887), 1,
      sym_preproc_conditional_var_block,
    STATE(10946), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12377), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12371), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12369), 22,
      sym_property_name,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [191753] = 12,
    ACTIONS(12388), 1,
      sym_var_keyword,
    ACTIONS(13541), 1,
      anon_sym_SEMI,
    STATE(3941), 1,
      sym_preproc_split_procedure_body,
    STATE(3942), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10961), 1,
      sym_preproc_conditional_var_block,
    STATE(10962), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(12391), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(12385), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12383), 22,
      sym_property_name,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [191820] = 5,
    ACTIONS(2541), 1,
      anon_sym_COMMA,
    ACTIONS(13192), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5932), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5934), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [191873] = 5,
    ACTIONS(13544), 1,
      anon_sym_SEMI,
    ACTIONS(13547), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5932), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5934), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [191926] = 32,
    ACTIONS(3708), 1,
      anon_sym_DOT,
    ACTIONS(3710), 1,
      anon_sym_DASH,
    ACTIONS(3712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3714), 1,
      anon_sym_STAR,
    ACTIONS(3716), 1,
      anon_sym_LBRACK,
    ACTIONS(3722), 1,
      anon_sym_SLASH,
    ACTIONS(3736), 1,
      anon_sym_PLUS,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13550), 1,
      anon_sym_div,
    ACTIONS(13552), 1,
      anon_sym_DIV,
    ACTIONS(13554), 1,
      anon_sym_Div,
    ACTIONS(13556), 1,
      anon_sym_mod,
    ACTIONS(13558), 1,
      anon_sym_MOD,
    ACTIONS(13560), 1,
      anon_sym_Mod,
    ACTIONS(13562), 1,
      anon_sym_and,
    ACTIONS(13564), 1,
      anon_sym_AND,
    ACTIONS(13566), 1,
      anon_sym_And,
    ACTIONS(13568), 1,
      anon_sym_or,
    ACTIONS(13570), 1,
      anon_sym_OR,
    ACTIONS(13572), 1,
      anon_sym_Or,
    ACTIONS(13574), 1,
      anon_sym_xor,
    ACTIONS(13576), 1,
      anon_sym_XOR,
    ACTIONS(13578), 1,
      anon_sym_Xor,
    STATE(3047), 1,
      sym_comparison_operator,
    STATE(11182), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [192033] = 32,
    ACTIONS(11822), 1,
      anon_sym_DOT,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11830), 1,
      anon_sym_LBRACK,
    ACTIONS(11832), 1,
      aux_sym__expression_token1,
    ACTIONS(11834), 1,
      aux_sym__expression_token2,
    ACTIONS(12022), 1,
      sym__assignment_operator,
    ACTIONS(12036), 1,
      anon_sym_QMARK,
    ACTIONS(13335), 1,
      anon_sym_DASH,
    ACTIONS(13339), 1,
      anon_sym_STAR,
    ACTIONS(13341), 1,
      anon_sym_SLASH,
    ACTIONS(13343), 1,
      anon_sym_div,
    ACTIONS(13345), 1,
      anon_sym_DIV,
    ACTIONS(13347), 1,
      anon_sym_Div,
    ACTIONS(13349), 1,
      anon_sym_mod,
    ACTIONS(13351), 1,
      anon_sym_MOD,
    ACTIONS(13353), 1,
      anon_sym_Mod,
    ACTIONS(13355), 1,
      anon_sym_PLUS,
    ACTIONS(13359), 1,
      anon_sym_and,
    ACTIONS(13361), 1,
      anon_sym_AND,
    ACTIONS(13363), 1,
      anon_sym_And,
    ACTIONS(13376), 1,
      anon_sym_or,
    ACTIONS(13378), 1,
      anon_sym_OR,
    ACTIONS(13380), 1,
      anon_sym_Or,
    ACTIONS(13382), 1,
      anon_sym_xor,
    ACTIONS(13384), 1,
      anon_sym_XOR,
    ACTIONS(13386), 1,
      anon_sym_Xor,
    STATE(3196), 1,
      sym_comparison_operator,
    STATE(11222), 1,
      sym_in_keyword,
    ACTIONS(2306), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(11852), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(2276), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [192140] = 5,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13325), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [192193] = 5,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13318), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [192246] = 4,
    ACTIONS(13229), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [192297] = 5,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13293), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 8,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      sym__assignment_operator,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 27,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [192350] = 5,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13304), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 8,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      sym__assignment_operator,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 27,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [192403] = 5,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13310), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 8,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      sym__assignment_operator,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 27,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [192456] = 5,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13314), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 8,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      sym__assignment_operator,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 27,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [192509] = 5,
    ACTIONS(11703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13316), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 8,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      sym__assignment_operator,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 27,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [192562] = 4,
    ACTIONS(13327), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [192612] = 3,
    ACTIONS(13580), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10374), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [192660] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 36,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [192706] = 4,
    ACTIONS(13582), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5932), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5934), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [192756] = 3,
    ACTIONS(13584), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10364), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [192804] = 3,
    ACTIONS(13586), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10350), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [192852] = 3,
    ACTIONS(13588), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10340), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [192900] = 4,
    ACTIONS(13325), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [192950] = 4,
    ACTIONS(5889), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [193000] = 3,
    ACTIONS(13590), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10380), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [193048] = 4,
    ACTIONS(13318), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5932), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5934), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [193098] = 4,
    ACTIONS(13318), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [193148] = 4,
    ACTIONS(13287), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5932), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5934), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [193198] = 4,
    ACTIONS(13312), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5932), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5934), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [193248] = 4,
    ACTIONS(13312), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [193298] = 4,
    ACTIONS(13287), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2434), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2436), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [193348] = 4,
    ACTIONS(13327), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5932), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5934), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [193398] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10088), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [193443] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10799), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [193488] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12585), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [193533] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12587), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [193578] = 3,
    ACTIONS(13592), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9735), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [193625] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9737), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [193670] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9737), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [193715] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9938), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [193760] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9741), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [193805] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12699), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [193850] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9741), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [193895] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9659), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [193940] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12702), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [193985] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8265), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194030] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9525), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194075] = 4,
    ACTIONS(13594), 1,
      anon_sym_DOT,
    STATE(6396), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2398), 33,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_temporary_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194124] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10601), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [194169] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194214] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194259] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194304] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8237), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194349] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9529), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194394] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8473), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194439] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6978), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194484] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6978), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194529] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194574] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194619] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194664] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10605), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [194709] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10609), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [194754] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194799] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194844] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194889] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7369), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194934] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7373), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [194979] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7373), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195024] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10613), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [195069] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10617), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [195114] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7377), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195159] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11546), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [195204] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7377), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195249] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195294] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195339] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195384] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9529), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195429] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7617), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195474] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7617), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195519] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4465), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [195564] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4469), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [195609] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12681), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195654] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9529), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195699] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9529), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195744] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9533), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195789] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9533), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195834] = 4,
    ACTIONS(13597), 1,
      anon_sym_DOT,
    STATE(6671), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2348), 33,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_temporary_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195883] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9745), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195928] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9667), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [195973] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9745), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196018] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9753), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196063] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9753), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196108] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9757), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196153] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10076), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196198] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9757), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196243] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9757), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196288] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9757), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196333] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9761), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196378] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9761), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196423] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9761), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196468] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9761), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196513] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9533), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196558] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8694), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196603] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9533), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196648] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8781), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196693] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10621), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [196738] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8785), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196783] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8789), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196828] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9842), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196873] = 3,
    ACTIONS(13599), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9850), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196920] = 3,
    ACTIONS(13601), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9850), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [196967] = 3,
    ACTIONS(13603), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9842), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197014] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8793), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197059] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197104] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197149] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197194] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197239] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197284] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197329] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8805), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197374] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8809), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197419] = 3,
    ACTIONS(13605), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9860), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197466] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8819), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197511] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8819), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197556] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8823), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197601] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8823), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197646] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8827), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197691] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197736] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197781] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197826] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197871] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197916] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [197961] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11552), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [198006] = 3,
    ACTIONS(13607), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9860), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198053] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9820), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198098] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8841), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198143] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8841), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198188] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8845), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198233] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8845), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198278] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11143), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [198323] = 3,
    ACTIONS(13609), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9868), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198370] = 3,
    ACTIONS(13611), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9868), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198417] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9549), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198462] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10659), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [198507] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10663), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [198552] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9553), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198597] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9553), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198642] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9553), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198687] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9553), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198732] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8815), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198777] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9876), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198822] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9876), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198867] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9896), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198912] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9896), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [198957] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9557), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199002] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8926), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199047] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9659), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199092] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9667), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199137] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9667), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199182] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9595), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199227] = 3,
    ACTIONS(13613), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199274] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199319] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4381), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199364] = 3,
    ACTIONS(13615), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199411] = 3,
    ACTIONS(13617), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199458] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12671), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199503] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199548] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199593] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199638] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4401), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199683] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4405), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199728] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4409), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199773] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4413), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199818] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4417), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199863] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4421), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199908] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4425), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199953] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4429), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [199998] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4433), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200043] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4437), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200088] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4441), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200133] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4445), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200178] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4449), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200223] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4453), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200268] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200313] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9599), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200358] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9599), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200403] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10770), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [200448] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9979), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200493] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9979), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200538] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9983), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200583] = 3,
    ACTIONS(13619), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9998), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200630] = 3,
    ACTIONS(13621), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9998), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200677] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10002), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200722] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10002), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200767] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10577), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [200812] = 3,
    ACTIONS(13623), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10010), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200859] = 3,
    ACTIONS(13625), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10010), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200906] = 3,
    ACTIONS(13627), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10002), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [200953] = 3,
    ACTIONS(13629), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10002), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [201000] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9671), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [201045] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [201090] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10018), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [201135] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10018), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [201180] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10667), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [201225] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10671), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [201270] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10675), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [201315] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10679), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [201360] = 3,
    ACTIONS(13631), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10026), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [201407] = 3,
    ACTIONS(13633), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10026), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [201454] = 3,
    ACTIONS(13635), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10018), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [201501] = 3,
    ACTIONS(13637), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10018), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [201548] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10581), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [201593] = 3,
    ACTIONS(13639), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10038), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [201640] = 3,
    ACTIONS(13641), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10038), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [201687] = 3,
    ACTIONS(13643), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9983), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [201734] = 3,
    ACTIONS(13645), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10048), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [201781] = 3,
    ACTIONS(13647), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10048), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [201828] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10585), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [201873] = 3,
    ACTIONS(13649), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10056), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [201920] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9671), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [201965] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10477), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202010] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10481), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202055] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10485), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202100] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10489), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202145] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10493), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202190] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9571), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202235] = 3,
    ACTIONS(13651), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10056), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [202282] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9599), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [202327] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10589), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202372] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10497), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202417] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10593), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202462] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10501), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202507] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10505), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202552] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10509), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202597] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10513), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202642] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10517), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202687] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10521), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202732] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10625), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202777] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9787), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [202822] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12683), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [202867] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9599), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [202912] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9603), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [202957] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12691), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203002] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9603), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203047] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9659), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203092] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10529), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [203137] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9603), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203182] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10597), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [203227] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10533), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [203272] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9603), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203317] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10080), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203362] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10080), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203407] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10084), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203452] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10084), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203497] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9908), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203542] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10088), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203587] = 3,
    ACTIONS(13653), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10096), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203634] = 3,
    ACTIONS(13655), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10096), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203681] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10100), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203726] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10100), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203771] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10537), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [203816] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12611), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203861] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10108), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203906] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10108), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203951] = 3,
    ACTIONS(13657), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9495), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [203998] = 3,
    ACTIONS(13659), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9495), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204045] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10114), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204090] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10114), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204135] = 3,
    ACTIONS(13661), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10122), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204182] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12689), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204227] = 3,
    ACTIONS(13663), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10122), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204274] = 3,
    ACTIONS(13665), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10114), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204321] = 3,
    ACTIONS(13667), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10114), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204368] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10130), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204413] = 3,
    ACTIONS(13669), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10138), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204460] = 3,
    ACTIONS(13671), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10138), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204507] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9936), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204552] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9936), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204597] = 3,
    ACTIONS(13673), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10146), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204644] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12673), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204689] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9671), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204734] = 3,
    ACTIONS(13675), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10146), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204781] = 3,
    ACTIONS(13677), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9936), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204828] = 3,
    ACTIONS(13679), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9936), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204875] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9501), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204920] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9501), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [204965] = 3,
    ACTIONS(13681), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9962), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205012] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12660), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205057] = 3,
    ACTIONS(13683), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9962), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205104] = 3,
    ACTIONS(13685), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9501), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205151] = 3,
    ACTIONS(13687), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9501), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205198] = 3,
    ACTIONS(13689), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10068), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205245] = 3,
    ACTIONS(13691), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10068), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205292] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9607), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205337] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9607), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205382] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9611), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205427] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9611), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205472] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9497), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205517] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9497), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205562] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9561), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205607] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9561), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205652] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9663), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205697] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9663), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205742] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9693), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205787] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9693), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205832] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9671), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205877] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9675), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205922] = 3,
    ACTIONS(13693), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9769), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [205969] = 3,
    ACTIONS(13695), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9769), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206016] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9912), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206061] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9912), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206106] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9928), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206151] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9928), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206196] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10104), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206241] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10104), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206286] = 3,
    ACTIONS(13697), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9691), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206333] = 3,
    ACTIONS(13699), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9691), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206380] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9703), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206425] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9679), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206470] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9703), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206515] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9711), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206560] = 4,
    ACTIONS(13597), 1,
      anon_sym_DOT,
    STATE(6396), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2444), 33,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_temporary_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206609] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10629), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [206654] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9711), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206699] = 3,
    ACTIONS(13701), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9719), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206746] = 3,
    ACTIONS(13703), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9719), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206793] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9838), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206838] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10541), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [206883] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9838), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206928] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9679), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [206973] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9679), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207018] = 3,
    ACTIONS(13705), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9884), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207065] = 3,
    ACTIONS(13707), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9884), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207112] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9679), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207157] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9683), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207202] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9683), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207247] = 3,
    ACTIONS(13709), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9838), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207294] = 3,
    ACTIONS(13711), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9838), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207341] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9557), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207386] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9557), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207431] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2268), 35,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_temporary_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207476] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9571), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207521] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9557), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207566] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10545), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [207611] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10549), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [207656] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10553), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [207701] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10557), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [207746] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10561), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [207791] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9505), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207836] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9509), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207881] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9513), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207926] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9517), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [207971] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9521), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208016] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9537), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208061] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9541), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208106] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9545), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208151] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9587), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208196] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9635), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208241] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9591), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208286] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9615), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208331] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9619), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208376] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9623), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208421] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9635), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208466] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9639), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208511] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9639), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208556] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9707), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208601] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9707), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208646] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10565), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [208691] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9787), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208736] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9721), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208781] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10569), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [208826] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10573), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [208871] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9721), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208916] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9727), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [208961] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9727), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209006] = 3,
    ACTIONS(13713), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9775), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209053] = 3,
    ACTIONS(13715), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9775), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209100] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12650), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209145] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9938), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209190] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9683), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209235] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9697), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209280] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9697), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209325] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9643), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209370] = 3,
    ACTIONS(13717), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9828), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209417] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9830), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209462] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9647), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209507] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9834), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209552] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9647), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209597] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9872), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209642] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9892), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209687] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9916), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209732] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9920), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209777] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9924), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209822] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9942), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209867] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9946), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209912] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9950), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [209957] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9954), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210002] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9971), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210047] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9987), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210092] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9651), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210137] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9651), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210182] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9655), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210227] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9655), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210272] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9683), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210317] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9655), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210362] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9655), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210407] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10072), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210452] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9667), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210497] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9565), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210542] = 3,
    ACTIONS(13719), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9565), 34,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210589] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9904), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210634] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9575), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210679] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9579), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210724] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9579), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210769] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9583), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210814] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9583), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210859] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9627), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210904] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12665), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210949] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9631), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [210994] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4215), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211039] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9749), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211084] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9659), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211129] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9791), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211174] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9795), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211219] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9795), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211264] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9795), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211309] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9795), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211354] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9808), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211399] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9808), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211444] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8942), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211489] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9808), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211534] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9808), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211579] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9812), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211624] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9812), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211669] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9816), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211714] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9816), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211759] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9900), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211804] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9908), 35,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211849] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10525), 35,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [211894] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4810), 34,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [211938] = 4,
    ACTIONS(13721), 1,
      anon_sym_COMMA,
    STATE(6792), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(374), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [211986] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2398), 34,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_temporary_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [212030] = 4,
    ACTIONS(13721), 1,
      anon_sym_COMMA,
    STATE(6796), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2356), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [212078] = 11,
    ACTIONS(6257), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13723), 1,
      sym_identifier,
    ACTIONS(13725), 1,
      sym_quoted_identifier,
    ACTIONS(13727), 1,
      sym_var_attribute_open,
    STATE(2426), 1,
      sym_preproc_if,
    STATE(10800), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6794), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(6255), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [212140] = 11,
    ACTIONS(6267), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13723), 1,
      sym_identifier,
    ACTIONS(13725), 1,
      sym_quoted_identifier,
    ACTIONS(13727), 1,
      sym_var_attribute_open,
    STATE(2426), 1,
      sym_preproc_if,
    STATE(10800), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6797), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(6265), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [212202] = 11,
    ACTIONS(6267), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13723), 1,
      sym_identifier,
    ACTIONS(13725), 1,
      sym_quoted_identifier,
    ACTIONS(13727), 1,
      sym_var_attribute_open,
    STATE(2426), 1,
      sym_preproc_if,
    STATE(10800), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6798), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(6265), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [212264] = 4,
    ACTIONS(13729), 1,
      anon_sym_COMMA,
    STATE(6796), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2405), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [212312] = 11,
    ACTIONS(6244), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13732), 1,
      sym_identifier,
    ACTIONS(13735), 1,
      sym_quoted_identifier,
    ACTIONS(13738), 1,
      sym_var_attribute_open,
    STATE(2426), 1,
      sym_preproc_if,
    STATE(10800), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6246), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6797), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(6241), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(6239), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [212374] = 11,
    ACTIONS(6263), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13723), 1,
      sym_identifier,
    ACTIONS(13725), 1,
      sym_quoted_identifier,
    ACTIONS(13727), 1,
      sym_var_attribute_open,
    STATE(2426), 1,
      sym_preproc_if,
    STATE(10800), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6797), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(6261), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [212436] = 4,
    ACTIONS(13721), 1,
      anon_sym_COMMA,
    STATE(6800), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2356), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [212484] = 4,
    ACTIONS(13721), 1,
      anon_sym_COMMA,
    STATE(6796), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2412), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [212532] = 6,
    ACTIONS(13744), 1,
      anon_sym_SEMI,
    ACTIONS(13755), 1,
      sym_quoted_identifier,
    ACTIONS(13751), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13741), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(13749), 18,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_table_keyword,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [212583] = 12,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(6860), 1,
      sym_preproc_endif,
    STATE(6302), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(3439), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [212646] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2405), 33,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [212689] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12759), 33,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [212732] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12862), 33,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [212775] = 3,
    ACTIONS(13758), 1,
      sym_temporary_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2535), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [212820] = 12,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(7244), 1,
      sym_preproc_endif,
    STATE(6825), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(3076), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [212883] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2553), 33,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [212926] = 12,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(7249), 1,
      sym_preproc_endif,
    STATE(6844), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(3076), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [212989] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12724), 33,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [213032] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 6,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(2843), 27,
      aux_sym_where_condition_token1,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [213077] = 3,
    ACTIONS(2843), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 32,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [213122] = 12,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(6882), 1,
      sym_preproc_endif,
    STATE(6836), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(3439), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [213185] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12743), 33,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [213228] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12841), 33,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [213271] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12843), 33,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [213314] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 33,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [213357] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12835), 33,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [213400] = 3,
    ACTIONS(13762), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13760), 32,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_COMMA,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [213445] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12910), 33,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [213488] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2420), 33,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [213531] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12851), 33,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [213574] = 12,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(7246), 1,
      sym_preproc_endif,
    STATE(6827), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(3076), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [213637] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2541), 33,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [213680] = 12,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(7249), 1,
      sym_preproc_endif,
    STATE(6302), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(3076), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [213743] = 4,
    ACTIONS(13764), 1,
      anon_sym_COMMA,
    ACTIONS(13768), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13766), 31,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [213790] = 12,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(7250), 1,
      sym_preproc_endif,
    STATE(6302), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(3076), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [213853] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2428), 33,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [213896] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2531), 33,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [213939] = 12,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(6884), 1,
      sym_preproc_endif,
    STATE(6302), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(3439), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [214002] = 12,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(6884), 1,
      sym_preproc_endif,
    STATE(6802), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(3439), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [214065] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12791), 33,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [214108] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12837), 33,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [214151] = 5,
    ACTIONS(13770), 1,
      anon_sym_SEMI,
    ACTIONS(13777), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13774), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(13772), 21,
      sym_preproc_open,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [214200] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2416), 33,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [214243] = 12,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(6876), 1,
      sym_preproc_endif,
    STATE(6302), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(3439), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [214306] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2424), 33,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [214349] = 12,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(6876), 1,
      sym_preproc_endif,
    STATE(6830), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(3439), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [214412] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12839), 33,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [214455] = 6,
    ACTIONS(13782), 1,
      anon_sym_SEMI,
    ACTIONS(13791), 1,
      sym_quoted_identifier,
    ACTIONS(13787), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13779), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(13777), 18,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_table_keyword,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [214506] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2428), 33,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [214549] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12751), 33,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [214592] = 5,
    ACTIONS(13749), 1,
      sym_table_keyword,
    ACTIONS(13794), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13798), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(13796), 21,
      sym_preproc_open,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [214641] = 12,
    ACTIONS(3064), 1,
      sym_table_keyword,
    STATE(5916), 1,
      sym_preproc_if,
    STATE(6826), 1,
      sym_tabledata_permission,
    STATE(7246), 1,
      sym_preproc_endif,
    STATE(6302), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7697), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(3076), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12731), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [214704] = 3,
    ACTIONS(13777), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13772), 31,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [214748] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13178), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [214790] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2651), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [214832] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13176), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [214874] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12962), 32,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [214916] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13094), 32,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [214958] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13114), 32,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215000] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2587), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215042] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2587), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215084] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2587), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215126] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2591), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215168] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2627), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215210] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2631), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215252] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2591), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215294] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2591), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215336] = 3,
    ACTIONS(13803), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13801), 31,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [215380] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2575), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215422] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13036), 32,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215464] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13061), 32,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215506] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2647), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215548] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12964), 32,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215590] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13090), 32,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215632] = 3,
    ACTIONS(4463), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4465), 31,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [215676] = 3,
    ACTIONS(4467), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4469), 31,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [215720] = 3,
    ACTIONS(4808), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4810), 31,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [215764] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2583), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215806] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10766), 32,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215848] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2579), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215890] = 3,
    ACTIONS(13805), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2615), 31,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215934] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2571), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [215976] = 3,
    ACTIONS(13807), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2621), 31,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [216020] = 3,
    ACTIONS(13811), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13809), 31,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [216064] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2635), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [216106] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12966), 32,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [216148] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12968), 32,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [216190] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13027), 32,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [216232] = 3,
    ACTIONS(13813), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13420), 31,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [216276] = 3,
    ACTIONS(13749), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13796), 31,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [216320] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2643), 32,
      sym_property_name,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [216362] = 3,
    ACTIONS(13817), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13815), 31,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [216406] = 4,
    ACTIONS(4383), 1,
      aux_sym_basic_type_token22,
    ACTIONS(13819), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [216451] = 4,
    ACTIONS(4373), 1,
      aux_sym_basic_type_token22,
    ACTIONS(13821), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [216496] = 4,
    ACTIONS(4383), 1,
      aux_sym_basic_type_token22,
    ACTIONS(13823), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [216541] = 3,
    ACTIONS(12749), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12747), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [216583] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13219), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13221), 1,
      sym_begin_keyword,
    ACTIONS(13257), 1,
      anon_sym_SEMI,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(7720), 1,
      sym__procedure_return_specification,
    STATE(7733), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5466), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10611), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [216653] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13219), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13221), 1,
      sym_begin_keyword,
    ACTIONS(13271), 1,
      anon_sym_SEMI,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(7705), 1,
      sym__procedure_return_specification,
    STATE(7717), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5624), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10667), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [216723] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13289), 30,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [216763] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13205), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13211), 1,
      sym_begin_keyword,
    ACTIONS(13279), 1,
      anon_sym_SEMI,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(7637), 1,
      sym__procedure_named_return,
    STATE(7680), 1,
      sym__procedure_return_specification,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5119), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10511), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [216833] = 3,
    ACTIONS(12849), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12847), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [216875] = 3,
    ACTIONS(11785), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11780), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [216917] = 3,
    ACTIONS(4373), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [216959] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13306), 30,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [216999] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(11793), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(11797), 1,
      sym_begin_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13831), 1,
      anon_sym_SEMI,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(7684), 1,
      sym__procedure_return_specification,
    STATE(7696), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(4127), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10558), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [217069] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(11793), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(11797), 1,
      sym_begin_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13833), 1,
      anon_sym_SEMI,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(7753), 1,
      sym__procedure_return_specification,
    STATE(7754), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(4589), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(11022), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [217139] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(11793), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(11797), 1,
      sym_begin_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13835), 1,
      anon_sym_SEMI,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(7681), 1,
      sym__procedure_return_specification,
    STATE(7756), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(4397), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10651), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [217209] = 3,
    ACTIONS(12785), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12783), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217251] = 3,
    ACTIONS(12789), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12787), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217293] = 3,
    ACTIONS(12795), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12793), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217335] = 3,
    ACTIONS(12799), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12797), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217377] = 3,
    ACTIONS(12803), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12801), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217419] = 3,
    ACTIONS(11753), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11748), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217461] = 3,
    ACTIONS(12807), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12805), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217503] = 3,
    ACTIONS(12811), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12809), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217545] = 3,
    ACTIONS(12815), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12813), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217587] = 3,
    ACTIONS(12819), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12817), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217629] = 3,
    ACTIONS(12823), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12821), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217671] = 3,
    ACTIONS(12827), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12825), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217713] = 3,
    ACTIONS(12831), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12829), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217755] = 3,
    ACTIONS(8821), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8819), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217797] = 3,
    ACTIONS(8821), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8819), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217839] = 3,
    ACTIONS(8825), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8823), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217881] = 3,
    ACTIONS(8825), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8823), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217923] = 3,
    ACTIONS(8829), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8827), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [217965] = 3,
    ACTIONS(4463), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4465), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [218007] = 3,
    ACTIONS(4467), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4469), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [218049] = 3,
    ACTIONS(8833), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [218091] = 3,
    ACTIONS(8833), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [218133] = 3,
    ACTIONS(8833), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [218175] = 3,
    ACTIONS(8837), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [218217] = 3,
    ACTIONS(8837), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [218259] = 3,
    ACTIONS(8837), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [218301] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13329), 30,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [218341] = 3,
    ACTIONS(4808), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4810), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [218383] = 17,
    ACTIONS(10168), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(10178), 1,
      sym_begin_keyword,
    ACTIONS(13239), 1,
      anon_sym_SEMI,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(7759), 1,
      sym__procedure_return_specification,
    STATE(7760), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(3760), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(11000), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [218453] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13291), 30,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [218493] = 3,
    ACTIONS(4379), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4381), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [218535] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13205), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13211), 1,
      sym_begin_keyword,
    ACTIONS(13269), 1,
      anon_sym_SEMI,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(7676), 1,
      sym__procedure_return_specification,
    STATE(7765), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5194), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10548), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [218605] = 17,
    ACTIONS(10168), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(10178), 1,
      sym_begin_keyword,
    ACTIONS(13273), 1,
      anon_sym_SEMI,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(7636), 1,
      sym__procedure_named_return,
    STATE(7722), 1,
      sym__procedure_return_specification,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(3574), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10770), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [218675] = 17,
    ACTIONS(10168), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(10178), 1,
      sym_begin_keyword,
    ACTIONS(13251), 1,
      anon_sym_SEMI,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(7707), 1,
      sym__procedure_return_specification,
    STATE(7764), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(3546), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10500), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [218745] = 3,
    ACTIONS(4383), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [218787] = 3,
    ACTIONS(11818), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11813), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [218829] = 3,
    ACTIONS(8795), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8793), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [218871] = 3,
    ACTIONS(8799), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [218913] = 17,
    ACTIONS(10168), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(10178), 1,
      sym_begin_keyword,
    ACTIONS(13259), 1,
      anon_sym_SEMI,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(7669), 1,
      sym__procedure_return_specification,
    STATE(7670), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(3703), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10563), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [218983] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13320), 30,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [219023] = 3,
    ACTIONS(8843), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8841), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219065] = 3,
    ACTIONS(8944), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8942), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219107] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(11793), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(11797), 1,
      sym_begin_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13837), 1,
      anon_sym_SEMI,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(7734), 1,
      sym__procedure_return_specification,
    STATE(7736), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(4333), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10412), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [219177] = 3,
    ACTIONS(8843), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8841), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219219] = 3,
    ACTIONS(12778), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12776), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219261] = 3,
    ACTIONS(8847), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8845), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219303] = 3,
    ACTIONS(8847), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8845), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219345] = 3,
    ACTIONS(4395), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219387] = 3,
    ACTIONS(4395), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219429] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13323), 30,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [219469] = 3,
    ACTIONS(12757), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12755), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219511] = 3,
    ACTIONS(12763), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12761), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219553] = 3,
    ACTIONS(8799), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219595] = 3,
    ACTIONS(8799), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219637] = 3,
    ACTIONS(4399), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4401), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219679] = 3,
    ACTIONS(4403), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4405), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219721] = 3,
    ACTIONS(4407), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4409), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219763] = 3,
    ACTIONS(4411), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4413), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219805] = 3,
    ACTIONS(4415), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4417), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219847] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13308), 30,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [219887] = 3,
    ACTIONS(4419), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4421), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219929] = 3,
    ACTIONS(4423), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4425), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [219971] = 3,
    ACTIONS(4427), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4429), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220013] = 3,
    ACTIONS(4431), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4433), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220055] = 3,
    ACTIONS(4435), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4437), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220097] = 3,
    ACTIONS(12866), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12864), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220139] = 3,
    ACTIONS(12870), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12868), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220181] = 3,
    ACTIONS(12722), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12720), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220223] = 3,
    ACTIONS(12874), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12872), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220265] = 3,
    ACTIONS(12878), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12876), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220307] = 3,
    ACTIONS(4439), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4441), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220349] = 3,
    ACTIONS(11811), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11806), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220391] = 3,
    ACTIONS(4443), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4445), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220433] = 3,
    ACTIONS(8696), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8694), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220475] = 3,
    ACTIONS(12882), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12880), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220517] = 3,
    ACTIONS(12886), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12884), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220559] = 3,
    ACTIONS(12890), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12888), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220601] = 3,
    ACTIONS(12894), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12892), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220643] = 3,
    ACTIONS(12898), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12896), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220685] = 3,
    ACTIONS(12902), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12900), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220727] = 3,
    ACTIONS(4447), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4449), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220769] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13839), 1,
      anon_sym_SEMI,
    ACTIONS(13841), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13843), 1,
      sym_begin_keyword,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(7712), 1,
      sym__procedure_return_specification,
    STATE(7718), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(6756), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(11086), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [220839] = 3,
    ACTIONS(4451), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4453), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220881] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10186), 30,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [220921] = 3,
    ACTIONS(4455), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [220963] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13841), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13843), 1,
      sym_begin_keyword,
    ACTIONS(13845), 1,
      anon_sym_SEMI,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(7727), 1,
      sym__procedure_return_specification,
    STATE(7730), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(6768), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10379), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [221033] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13841), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13843), 1,
      sym_begin_keyword,
    ACTIONS(13847), 1,
      anon_sym_SEMI,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(7656), 1,
      sym__procedure_return_specification,
    STATE(7658), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(6761), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10364), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [221103] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13841), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13843), 1,
      sym_begin_keyword,
    ACTIONS(13849), 1,
      anon_sym_SEMI,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(7758), 1,
      sym__procedure_return_specification,
    STATE(7761), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(6786), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10413), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [221173] = 3,
    ACTIONS(8803), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [221215] = 3,
    ACTIONS(8803), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [221257] = 3,
    ACTIONS(8803), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [221299] = 3,
    ACTIONS(8783), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8781), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [221341] = 3,
    ACTIONS(8787), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8785), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [221383] = 3,
    ACTIONS(8791), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8789), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [221425] = 3,
    ACTIONS(8807), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8805), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [221467] = 3,
    ACTIONS(8811), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8809), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [221509] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13205), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13211), 1,
      sym_begin_keyword,
    ACTIONS(13249), 1,
      anon_sym_SEMI,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(7644), 1,
      sym__procedure_named_return,
    STATE(7746), 1,
      sym__procedure_return_specification,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5106), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10534), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [221579] = 3,
    ACTIONS(8928), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8926), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [221621] = 3,
    ACTIONS(2843), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [221663] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13217), 1,
      anon_sym_SEMI,
    ACTIONS(13219), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13221), 1,
      sym_begin_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(7728), 1,
      sym__procedure_return_specification,
    STATE(7741), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5830), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10596), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [221733] = 3,
    ACTIONS(8817), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8815), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [221775] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13201), 1,
      anon_sym_SEMI,
    ACTIONS(13205), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13211), 1,
      sym_begin_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(7638), 1,
      sym__procedure_named_return,
    STATE(7776), 1,
      sym__procedure_return_specification,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5197), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10631), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [221845] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13219), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13221), 1,
      sym_begin_keyword,
    ACTIONS(13253), 1,
      anon_sym_SEMI,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(7648), 1,
      sym__procedure_named_return,
    STATE(7740), 1,
      sym__procedure_return_specification,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5478), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10626), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [221915] = 3,
    ACTIONS(12729), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12727), 29,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [221957] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(11793), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(11797), 1,
      sym_begin_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13851), 1,
      anon_sym_SEMI,
    STATE(4129), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7892), 1,
      sym__procedure_return_specification,
    STATE(7893), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10605), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [222026] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(11793), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(11797), 1,
      sym_begin_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13853), 1,
      anon_sym_SEMI,
    STATE(4344), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(8084), 1,
      sym__procedure_return_specification,
    STATE(8085), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10465), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [222095] = 11,
    ACTIONS(13420), 1,
      anon_sym_SEMI,
    ACTIONS(13858), 1,
      sym_table_keyword,
    STATE(5974), 1,
      sym_preproc_if,
    STATE(7218), 1,
      sym_tabledata_permission,
    STATE(7006), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7742), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(13417), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13855), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(13425), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(13428), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [222152] = 17,
    ACTIONS(10168), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(10178), 1,
      sym_begin_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13861), 1,
      anon_sym_SEMI,
    STATE(3280), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7791), 1,
      sym__procedure_return_specification,
    STATE(7792), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10481), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [222221] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13219), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13221), 1,
      sym_begin_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13863), 1,
      anon_sym_SEMI,
    STATE(5490), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(8037), 1,
      sym__procedure_return_specification,
    STATE(8038), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10888), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [222290] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13219), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13221), 1,
      sym_begin_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13865), 1,
      anon_sym_SEMI,
    STATE(5496), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(8040), 1,
      sym__procedure_return_specification,
    STATE(8041), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10899), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [222359] = 11,
    ACTIONS(2215), 1,
      sym_table_keyword,
    ACTIONS(13867), 1,
      anon_sym_SEMI,
    STATE(5974), 1,
      sym_preproc_if,
    STATE(7218), 1,
      sym_tabledata_permission,
    STATE(7006), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(7742), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(12733), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13869), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(12739), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(12741), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [222416] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13871), 1,
      anon_sym_SEMI,
    ACTIONS(13873), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13875), 1,
      sym_begin_keyword,
    STATE(6973), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7992), 1,
      sym__procedure_return_specification,
    STATE(7993), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10600), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [222485] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13841), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13843), 1,
      sym_begin_keyword,
    ACTIONS(13877), 1,
      anon_sym_SEMI,
    STATE(6453), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(8024), 1,
      sym__procedure_return_specification,
    STATE(8025), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10814), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [222554] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13879), 1,
      anon_sym_SEMI,
    ACTIONS(13881), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13883), 1,
      sym_begin_keyword,
    STATE(7358), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7943), 1,
      sym__procedure_return_specification,
    STATE(7944), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10369), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [222623] = 17,
    ACTIONS(10168), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(10178), 1,
      sym_begin_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13885), 1,
      anon_sym_SEMI,
    STATE(3290), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7803), 1,
      sym__procedure_return_specification,
    STATE(7804), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10517), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [222692] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13881), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13883), 1,
      sym_begin_keyword,
    ACTIONS(13887), 1,
      anon_sym_SEMI,
    STATE(7349), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7938), 1,
      sym__procedure_return_specification,
    STATE(7939), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(11091), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [222761] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13205), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13211), 1,
      sym_begin_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13889), 1,
      anon_sym_SEMI,
    STATE(5133), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7872), 1,
      sym__procedure_return_specification,
    STATE(7873), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10514), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [222830] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13873), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13875), 1,
      sym_begin_keyword,
    ACTIONS(13891), 1,
      anon_sym_SEMI,
    STATE(6991), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7996), 1,
      sym__procedure_return_specification,
    STATE(7997), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10616), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [222899] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13205), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13211), 1,
      sym_begin_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13893), 1,
      anon_sym_SEMI,
    STATE(5112), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7878), 1,
      sym__procedure_return_specification,
    STATE(7879), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10539), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [222968] = 17,
    ACTIONS(10172), 1,
      sym_var_keyword,
    ACTIONS(13825), 1,
      sym_identifier,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    ACTIONS(13829), 1,
      sym_quoted_identifier,
    ACTIONS(13841), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13843), 1,
      sym_begin_keyword,
    ACTIONS(13895), 1,
      anon_sym_SEMI,
    STATE(6451), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(8021), 1,
      sym__procedure_return_specification,
    STATE(8022), 1,
      sym__procedure_named_return,
    ACTIONS(10174), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10802), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(11151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [223037] = 14,
    ACTIONS(13897), 1,
      sym_identifier,
    ACTIONS(13903), 1,
      sym_quoted_identifier,
    STATE(7209), 1,
      aux_sym_preproc_conditional_where_repeat1,
    STATE(7225), 1,
      sym_preproc_elif,
    STATE(7323), 1,
      sym_where_condition,
    STATE(7427), 1,
      sym_preproc_else,
    STATE(7745), 1,
      sym_preproc_endif,
    STATE(8148), 1,
      aux_sym_preproc_conditional_where_repeat2,
    STATE(11955), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [223099] = 14,
    ACTIONS(13905), 1,
      sym_identifier,
    ACTIONS(13907), 1,
      sym_quoted_identifier,
    STATE(7026), 1,
      aux_sym_preproc_conditional_impl_values_repeat1,
    STATE(7230), 1,
      sym_preproc_elif,
    STATE(7268), 1,
      sym_implementation_value,
    STATE(7429), 1,
      sym_preproc_else,
    STATE(7677), 1,
      sym_preproc_endif,
    STATE(8078), 1,
      aux_sym_preproc_conditional_impl_values_repeat2,
    STATE(11655), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [223161] = 14,
    ACTIONS(13909), 1,
      sym_identifier,
    ACTIONS(13911), 1,
      sym_quoted_identifier,
    STATE(7227), 1,
      sym_preproc_elif,
    STATE(7228), 1,
      aux_sym_preproc_conditional_link_values_repeat1,
    STATE(7327), 1,
      sym_link_value,
    STATE(7418), 1,
      sym_preproc_else,
    STATE(7744), 1,
      sym_preproc_endif,
    STATE(7855), 1,
      aux_sym_preproc_conditional_link_values_repeat2,
    STATE(11648), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [223223] = 3,
    ACTIONS(9573), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9571), 27,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataitem_keyword,
  [223263] = 14,
    ACTIONS(13909), 1,
      sym_identifier,
    ACTIONS(13911), 1,
      sym_quoted_identifier,
    STATE(7022), 1,
      aux_sym_preproc_conditional_link_values_repeat1,
    STATE(7227), 1,
      sym_preproc_elif,
    STATE(7327), 1,
      sym_link_value,
    STATE(7468), 1,
      sym_preproc_else,
    STATE(7695), 1,
      sym_preproc_endif,
    STATE(8072), 1,
      aux_sym_preproc_conditional_link_values_repeat2,
    STATE(11648), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [223325] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5449), 28,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [223363] = 14,
    ACTIONS(13905), 1,
      sym_identifier,
    ACTIONS(13907), 1,
      sym_quoted_identifier,
    STATE(7230), 1,
      sym_preproc_elif,
    STATE(7232), 1,
      aux_sym_preproc_conditional_impl_values_repeat1,
    STATE(7268), 1,
      sym_implementation_value,
    STATE(7455), 1,
      sym_preproc_else,
    STATE(7650), 1,
      sym_preproc_endif,
    STATE(7857), 1,
      aux_sym_preproc_conditional_impl_values_repeat2,
    STATE(11655), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [223425] = 3,
    ACTIONS(9789), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9787), 27,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataitem_keyword,
  [223465] = 14,
    ACTIONS(13897), 1,
      sym_identifier,
    ACTIONS(13903), 1,
      sym_quoted_identifier,
    STATE(7020), 1,
      aux_sym_preproc_conditional_where_repeat1,
    STATE(7225), 1,
      sym_preproc_elif,
    STATE(7323), 1,
      sym_where_condition,
    STATE(7456), 1,
      sym_preproc_else,
    STATE(7672), 1,
      sym_preproc_endif,
    STATE(8011), 1,
      aux_sym_preproc_conditional_where_repeat2,
    STATE(11955), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [223527] = 4,
    ACTIONS(13913), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4383), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4387), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [223568] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4465), 12,
      sym_preproc_close,
      anon_sym_LBRACK,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4463), 15,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_dataitem_keyword,
      sym_identifier,
  [223607] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4469), 12,
      sym_preproc_close,
      anon_sym_LBRACK,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4467), 15,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_dataitem_keyword,
      sym_identifier,
  [223646] = 4,
    ACTIONS(13915), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4383), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4387), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [223687] = 4,
    ACTIONS(13917), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4373), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4377), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [223728] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8199), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(8201), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [223766] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8017), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(8019), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [223804] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7575), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7577), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [223842] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8211), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(8213), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [223880] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7615), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7617), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [223918] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7615), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7617), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [223956] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8263), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(8265), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [223994] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6976), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(6978), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224032] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7367), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7369), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224070] = 3,
    ACTIONS(13919), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10350), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [224108] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6976), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(6978), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224146] = 3,
    ACTIONS(13921), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10374), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [224184] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7152), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7154), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224222] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4810), 12,
      sym_preproc_close,
      anon_sym_LBRACK,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(4808), 14,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_dataitem_keyword,
      sym_identifier,
  [224260] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7371), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7373), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224298] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7152), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7154), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224336] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2843), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(2841), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224374] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8175), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(8177), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224412] = 3,
    ACTIONS(13923), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10364), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [224450] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7152), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7154), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224488] = 3,
    ACTIONS(13925), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10340), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [224526] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7371), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7373), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224564] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7575), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7577), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224602] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4373), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4377), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224640] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4379), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4381), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224678] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4383), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4387), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224716] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7539), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7541), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224754] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7543), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7545), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224792] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4395), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4397), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224830] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4395), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4397), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224868] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7166), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7168), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224906] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4399), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4401), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224944] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4403), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4405), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [224982] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4407), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4409), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225020] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4411), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4413), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225058] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7805), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7807), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225096] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7809), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7811), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225134] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4415), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4417), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225172] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4419), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4421), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225210] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7166), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7168), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225248] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4423), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4425), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225286] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4427), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4429), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225324] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4431), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4433), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225362] = 3,
    ACTIONS(5447), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5449), 25,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [225400] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4435), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4437), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225438] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4439), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4441), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225476] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4443), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4445), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225514] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4447), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4449), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225552] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4451), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4453), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225590] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4455), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(4457), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225628] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7933), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7935), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225666] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7937), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7939), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225704] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7941), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7943), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225742] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8199), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(8201), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225780] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8199), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(8201), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225818] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8471), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(8473), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225856] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8235), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(8237), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225894] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7166), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7168), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [225932] = 3,
    ACTIONS(13927), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10380), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [225970] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7375), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7377), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [226008] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7375), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7377), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [226046] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7575), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7577), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [226084] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8013), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(8015), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [226122] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7359), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(7361), 16,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [226160] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10549), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [226195] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10597), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [226230] = 12,
    ACTIONS(13929), 1,
      anon_sym_SEMI,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5273), 1,
      sym_preproc_split_procedure_body,
    STATE(5375), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10742), 1,
      sym_preproc_conditional_var_block,
    STATE(10747), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13931), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [226285] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13937), 1,
      anon_sym_SEMI,
    STATE(5379), 1,
      sym_preproc_split_procedure_body,
    STATE(5380), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10748), 1,
      sym_preproc_conditional_var_block,
    STATE(10749), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13939), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [226340] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10489), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [226375] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10493), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [226410] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11546), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [226445] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13941), 1,
      anon_sym_SEMI,
    STATE(5121), 1,
      sym_preproc_split_procedure_body,
    STATE(5122), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10771), 1,
      sym_preproc_conditional_var_block,
    STATE(10772), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13943), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [226500] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13945), 1,
      anon_sym_SEMI,
    STATE(5125), 1,
      sym_preproc_split_procedure_body,
    STATE(5126), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10773), 1,
      sym_preproc_conditional_var_block,
    STATE(10774), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13947), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [226555] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13949), 1,
      anon_sym_SEMI,
    STATE(5129), 1,
      sym_preproc_split_procedure_body,
    STATE(5130), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10776), 1,
      sym_preproc_conditional_var_block,
    STATE(10777), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13951), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [226610] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13953), 1,
      anon_sym_SEMI,
    STATE(5131), 1,
      sym_preproc_split_procedure_body,
    STATE(5132), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10778), 1,
      sym_preproc_conditional_var_block,
    STATE(11114), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13955), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [226665] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10513), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [226700] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10497), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [226735] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11552), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [226770] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11143), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [226805] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13957), 1,
      anon_sym_SEMI,
    STATE(5600), 1,
      sym_preproc_split_procedure_body,
    STATE(5618), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10647), 1,
      sym_preproc_conditional_var_block,
    STATE(10650), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13959), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [226860] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10663), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [226895] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13961), 1,
      anon_sym_SEMI,
    STATE(5621), 1,
      sym_preproc_split_procedure_body,
    STATE(5622), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10652), 1,
      sym_preproc_conditional_var_block,
    STATE(10653), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13963), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [226950] = 11,
    ACTIONS(6255), 1,
      sym_begin_keyword,
    ACTIONS(6257), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13965), 1,
      sym_identifier,
    ACTIONS(13967), 1,
      sym_quoted_identifier,
    ACTIONS(13969), 1,
      sym_var_attribute_open,
    STATE(2419), 1,
      sym_preproc_if,
    STATE(10790), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7118), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [227003] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13971), 1,
      anon_sym_SEMI,
    STATE(3554), 1,
      sym_preproc_split_procedure_body,
    STATE(3555), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10936), 1,
      sym_preproc_conditional_var_block,
    STATE(10937), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13943), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [227058] = 11,
    ACTIONS(6265), 1,
      sym_begin_keyword,
    ACTIONS(6267), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13965), 1,
      sym_identifier,
    ACTIONS(13967), 1,
      sym_quoted_identifier,
    ACTIONS(13969), 1,
      sym_var_attribute_open,
    STATE(2419), 1,
      sym_preproc_if,
    STATE(10790), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7145), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [227111] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10517), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [227146] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10521), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [227181] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10667), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [227216] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13973), 1,
      anon_sym_SEMI,
    STATE(5765), 1,
      sym_preproc_split_procedure_body,
    STATE(5767), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10692), 1,
      sym_preproc_conditional_var_block,
    STATE(10693), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13931), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [227271] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13975), 1,
      anon_sym_SEMI,
    STATE(5819), 1,
      sym_preproc_split_procedure_body,
    STATE(5842), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10695), 1,
      sym_preproc_conditional_var_block,
    STATE(10696), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13939), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [227326] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10671), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [227361] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10799), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [227396] = 11,
    ACTIONS(6265), 1,
      sym_begin_keyword,
    ACTIONS(6267), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13965), 1,
      sym_identifier,
    ACTIONS(13967), 1,
      sym_quoted_identifier,
    ACTIONS(13969), 1,
      sym_var_attribute_open,
    STATE(2419), 1,
      sym_preproc_if,
    STATE(10790), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7149), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [227449] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13977), 1,
      anon_sym_SEMI,
    STATE(5786), 1,
      sym_code_block,
    STATE(5862), 1,
      sym_preproc_split_procedure_body,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10705), 1,
      sym_preproc_conditional_var_block,
    STATE(10707), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13943), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [227504] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13979), 1,
      anon_sym_SEMI,
    STATE(3666), 1,
      sym_preproc_split_procedure_body,
    STATE(3668), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11025), 1,
      sym_preproc_conditional_var_block,
    STATE(11049), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13981), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [227559] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13983), 1,
      anon_sym_SEMI,
    STATE(3672), 1,
      sym_preproc_split_procedure_body,
    STATE(3673), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11050), 1,
      sym_preproc_conditional_var_block,
    STATE(11051), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13985), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [227614] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13987), 1,
      anon_sym_SEMI,
    STATE(5185), 1,
      sym_preproc_split_procedure_body,
    STATE(5186), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10829), 1,
      sym_preproc_conditional_var_block,
    STATE(10830), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13989), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [227669] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13991), 1,
      anon_sym_SEMI,
    STATE(5189), 1,
      sym_preproc_split_procedure_body,
    STATE(5190), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10841), 1,
      sym_preproc_conditional_var_block,
    STATE(10846), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13993), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [227724] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13995), 1,
      anon_sym_SEMI,
    STATE(3676), 1,
      sym_preproc_split_procedure_body,
    STATE(3677), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11058), 1,
      sym_preproc_conditional_var_block,
    STATE(11061), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13959), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [227779] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13997), 1,
      anon_sym_SEMI,
    STATE(3678), 1,
      sym_preproc_split_procedure_body,
    STATE(3679), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11062), 1,
      sym_preproc_conditional_var_block,
    STATE(11088), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13963), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [227834] = 9,
    ACTIONS(13999), 1,
      sym_identifier,
    ACTIONS(14001), 1,
      anon_sym_COLON,
    ACTIONS(14003), 1,
      sym_quoted_identifier,
    STATE(8772), 1,
      sym__procedure_return_specification,
    STATE(8820), 1,
      sym__procedure_named_return,
    STATE(11214), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(10182), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [227883] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14005), 1,
      anon_sym_SEMI,
    STATE(5589), 1,
      sym_preproc_split_procedure_body,
    STATE(5655), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10710), 1,
      sym_preproc_conditional_var_block,
    STATE(10711), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13947), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [227938] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14007), 1,
      anon_sym_SEMI,
    STATE(5789), 1,
      sym_preproc_split_procedure_body,
    STATE(5792), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10713), 1,
      sym_preproc_conditional_var_block,
    STATE(10714), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13951), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [227993] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14009), 1,
      anon_sym_SEMI,
    STATE(3547), 1,
      sym_preproc_split_procedure_body,
    STATE(3548), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10506), 1,
      sym_preproc_conditional_var_block,
    STATE(10512), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14011), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [228048] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10675), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [228083] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10679), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [228118] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10605), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [228153] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10545), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [228188] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14013), 1,
      anon_sym_SEMI,
    STATE(5793), 1,
      sym_preproc_split_procedure_body,
    STATE(5794), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10717), 1,
      sym_preproc_conditional_var_block,
    STATE(10718), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13955), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [228243] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14015), 1,
      anon_sym_SEMI,
    STATE(3549), 1,
      sym_preproc_split_procedure_body,
    STATE(3550), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10513), 1,
      sym_preproc_conditional_var_block,
    STATE(10515), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14017), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [228298] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10525), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [228333] = 11,
    ACTIONS(6239), 1,
      sym_begin_keyword,
    ACTIONS(6244), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(14019), 1,
      sym_identifier,
    ACTIONS(14022), 1,
      sym_quoted_identifier,
    ACTIONS(14025), 1,
      sym_var_attribute_open,
    STATE(2419), 1,
      sym_preproc_if,
    STATE(10790), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6246), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7145), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(6241), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [228386] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10625), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [228421] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10541), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [228456] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14028), 1,
      anon_sym_SEMI,
    STATE(3538), 1,
      sym_preproc_split_procedure_body,
    STATE(3539), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10831), 1,
      sym_preproc_conditional_var_block,
    STATE(10854), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13939), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [228511] = 11,
    ACTIONS(6261), 1,
      sym_begin_keyword,
    ACTIONS(6263), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13965), 1,
      sym_identifier,
    ACTIONS(13967), 1,
      sym_quoted_identifier,
    ACTIONS(13969), 1,
      sym_var_attribute_open,
    STATE(2419), 1,
      sym_preproc_if,
    STATE(10790), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7145), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [228564] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14030), 1,
      anon_sym_SEMI,
    STATE(5625), 1,
      sym_preproc_split_procedure_body,
    STATE(5626), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10669), 1,
      sym_preproc_conditional_var_block,
    STATE(10670), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14032), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [228619] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14034), 1,
      anon_sym_SEMI,
    STATE(3558), 1,
      sym_preproc_split_procedure_body,
    STATE(3559), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10938), 1,
      sym_preproc_conditional_var_block,
    STATE(10939), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13947), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [228674] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14036), 1,
      anon_sym_SEMI,
    STATE(3562), 1,
      sym_preproc_split_procedure_body,
    STATE(3563), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10941), 1,
      sym_preproc_conditional_var_block,
    STATE(10942), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13951), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [228729] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10569), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [228764] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10485), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [228799] = 9,
    ACTIONS(13999), 1,
      sym_identifier,
    ACTIONS(14001), 1,
      anon_sym_COLON,
    ACTIONS(14003), 1,
      sym_quoted_identifier,
    STATE(8809), 1,
      sym__procedure_return_specification,
    STATE(8810), 1,
      sym__procedure_named_return,
    STATE(11214), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(10190), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [228848] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10501), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [228883] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10770), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [228918] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10553), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [228953] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10557), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [228988] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10561), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [229023] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10621), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [229058] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10565), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [229093] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14038), 1,
      anon_sym_SEMI,
    STATE(5136), 1,
      sym_preproc_split_procedure_body,
    STATE(5137), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10565), 1,
      sym_preproc_conditional_var_block,
    STATE(10566), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13981), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [229148] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14040), 1,
      anon_sym_SEMI,
    STATE(3705), 1,
      sym_preproc_split_procedure_body,
    STATE(3709), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10567), 1,
      sym_preproc_conditional_var_block,
    STATE(10587), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14032), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [229203] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14042), 1,
      anon_sym_SEMI,
    STATE(3714), 1,
      sym_preproc_split_procedure_body,
    STATE(3718), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10594), 1,
      sym_preproc_conditional_var_block,
    STATE(10595), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14044), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [229258] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14046), 1,
      anon_sym_SEMI,
    STATE(5141), 1,
      sym_preproc_split_procedure_body,
    STATE(5142), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10568), 1,
      sym_preproc_conditional_var_block,
    STATE(10569), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13985), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [229313] = 9,
    ACTIONS(13999), 1,
      sym_identifier,
    ACTIONS(14001), 1,
      anon_sym_COLON,
    ACTIONS(14003), 1,
      sym_quoted_identifier,
    STATE(8807), 1,
      sym__procedure_return_specification,
    STATE(8823), 1,
      sym__procedure_named_return,
    STATE(11214), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(14048), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [229362] = 9,
    ACTIONS(13999), 1,
      sym_identifier,
    ACTIONS(14001), 1,
      anon_sym_COLON,
    ACTIONS(14003), 1,
      sym_quoted_identifier,
    STATE(8779), 1,
      sym__procedure_return_specification,
    STATE(8793), 1,
      sym__procedure_named_return,
    STATE(11214), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(14050), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [229411] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14052), 1,
      anon_sym_SEMI,
    STATE(5145), 1,
      sym_preproc_split_procedure_body,
    STATE(5146), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10571), 1,
      sym_preproc_conditional_var_block,
    STATE(10572), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13959), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [229466] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14054), 1,
      anon_sym_SEMI,
    STATE(5159), 1,
      sym_preproc_split_procedure_body,
    STATE(5166), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10573), 1,
      sym_preproc_conditional_var_block,
    STATE(10574), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13963), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [229521] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14056), 1,
      anon_sym_SEMI,
    STATE(5627), 1,
      sym_preproc_split_procedure_body,
    STATE(5628), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10674), 1,
      sym_preproc_conditional_var_block,
    STATE(10675), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14044), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [229576] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14058), 1,
      anon_sym_SEMI,
    STATE(5467), 1,
      sym_preproc_split_procedure_body,
    STATE(5468), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10612), 1,
      sym_preproc_conditional_var_block,
    STATE(10613), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14011), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [229631] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14060), 1,
      anon_sym_SEMI,
    STATE(5469), 1,
      sym_preproc_split_procedure_body,
    STATE(5472), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10614), 1,
      sym_preproc_conditional_var_block,
    STATE(10615), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14017), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [229686] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14062), 1,
      anon_sym_SEMI,
    STATE(3604), 1,
      sym_preproc_split_procedure_body,
    STATE(3605), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10357), 1,
      sym_var_section,
    STATE(11092), 1,
      sym_preproc_conditional_var_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13989), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [229741] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14064), 1,
      anon_sym_SEMI,
    STATE(5198), 1,
      sym_preproc_split_procedure_body,
    STATE(5204), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10632), 1,
      sym_preproc_conditional_var_block,
    STATE(10633), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14032), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [229796] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14066), 1,
      anon_sym_SEMI,
    STATE(5205), 1,
      sym_preproc_split_procedure_body,
    STATE(5206), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10638), 1,
      sym_preproc_conditional_var_block,
    STATE(10639), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14044), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [229851] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10573), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [229886] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10609), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [229921] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10613), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [229956] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10477), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [229991] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10629), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [230026] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14068), 1,
      anon_sym_SEMI,
    STATE(3608), 1,
      sym_preproc_split_procedure_body,
    STATE(3609), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10363), 1,
      sym_preproc_conditional_var_block,
    STATE(10372), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13993), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [230081] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10529), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [230116] = 9,
    ACTIONS(13999), 1,
      sym_identifier,
    ACTIONS(14001), 1,
      anon_sym_COLON,
    ACTIONS(14003), 1,
      sym_quoted_identifier,
    STATE(8773), 1,
      sym__procedure_named_return,
    STATE(8839), 1,
      sym__procedure_return_specification,
    STATE(11214), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(13207), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [230165] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10581), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [230200] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10481), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [230235] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14070), 1,
      anon_sym_SEMI,
    STATE(3534), 1,
      sym_preproc_split_procedure_body,
    STATE(3535), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10789), 1,
      sym_preproc_conditional_var_block,
    STATE(10805), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13931), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [230290] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14072), 1,
      anon_sym_SEMI,
    STATE(5790), 1,
      sym_preproc_split_procedure_body,
    STATE(5839), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10736), 1,
      sym_preproc_conditional_var_block,
    STATE(10737), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13989), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [230345] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10617), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [230380] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10509), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [230415] = 9,
    ACTIONS(13999), 1,
      sym_identifier,
    ACTIONS(14001), 1,
      anon_sym_COLON,
    ACTIONS(14003), 1,
      sym_quoted_identifier,
    STATE(8814), 1,
      sym__procedure_return_specification,
    STATE(8816), 1,
      sym__procedure_named_return,
    STATE(11214), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(13255), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [230464] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10585), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [230499] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10537), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [230534] = 9,
    ACTIONS(13999), 1,
      sym_identifier,
    ACTIONS(14001), 1,
      anon_sym_COLON,
    ACTIONS(14003), 1,
      sym_quoted_identifier,
    STATE(8829), 1,
      sym__procedure_return_specification,
    STATE(8830), 1,
      sym__procedure_named_return,
    STATE(11214), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(14074), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [230583] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10589), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [230618] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10505), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [230653] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10659), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [230688] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10601), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [230723] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14076), 1,
      anon_sym_SEMI,
    STATE(5518), 1,
      sym_preproc_split_procedure_body,
    STATE(5519), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10739), 1,
      sym_preproc_conditional_var_block,
    STATE(10740), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13993), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [230778] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14078), 1,
      anon_sym_SEMI,
    STATE(5565), 1,
      sym_preproc_split_procedure_body,
    STATE(5566), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10641), 1,
      sym_preproc_conditional_var_block,
    STATE(10642), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13981), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [230833] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14080), 1,
      anon_sym_SEMI,
    STATE(5572), 1,
      sym_preproc_split_procedure_body,
    STATE(5575), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10644), 1,
      sym_preproc_conditional_var_block,
    STATE(10645), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13985), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [230888] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14082), 1,
      anon_sym_SEMI,
    STATE(5107), 1,
      sym_preproc_split_procedure_body,
    STATE(5108), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10535), 1,
      sym_preproc_conditional_var_block,
    STATE(10536), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14011), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [230943] = 9,
    ACTIONS(13999), 1,
      sym_identifier,
    ACTIONS(14001), 1,
      anon_sym_COLON,
    ACTIONS(14003), 1,
      sym_quoted_identifier,
    STATE(8825), 1,
      sym__procedure_return_specification,
    STATE(8828), 1,
      sym__procedure_named_return,
    STATE(11214), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(14084), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [230992] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14086), 1,
      anon_sym_SEMI,
    STATE(5110), 1,
      sym_preproc_split_procedure_body,
    STATE(5111), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10537), 1,
      sym_preproc_conditional_var_block,
    STATE(10538), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14017), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [231047] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10533), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [231082] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10577), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [231117] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10593), 25,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token6,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
  [231152] = 12,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14088), 1,
      anon_sym_SEMI,
    STATE(3564), 1,
      sym_preproc_split_procedure_body,
    STATE(3565), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10944), 1,
      sym_preproc_conditional_var_block,
    STATE(10945), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13955), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [231207] = 8,
    ACTIONS(14090), 1,
      sym_identifier,
    ACTIONS(14098), 1,
      sym_quoted_identifier,
    STATE(7209), 1,
      aux_sym_preproc_conditional_where_repeat1,
    STATE(7323), 1,
      sym_where_condition,
    STATE(11955), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14093), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(14096), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [231253] = 10,
    ACTIONS(6267), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(14101), 1,
      sym_identifier,
    ACTIONS(14103), 1,
      sym_quoted_identifier,
    ACTIONS(14105), 1,
      sym_var_attribute_open,
    STATE(2418), 1,
      sym_preproc_if,
    STATE(10820), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7220), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [231303] = 13,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14107), 1,
      anon_sym_RBRACE,
    ACTIONS(14109), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14111), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14115), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14117), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14119), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(14121), 1,
      sym_dataitem_keyword,
    STATE(7420), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7221), 10,
      sym_modify_modification,
      sym_preproc_conditional_dataset,
      sym_report_dataitem,
      sym_add_dataset_modification,
      sym_addfirst_dataset_modification,
      sym_addlast_dataset_modification,
      sym_addafter_dataset_modification,
      sym_addbefore_dataset_modification,
      sym_attribute_item,
      aux_sym_dataset_section_repeat1,
  [231359] = 8,
    ACTIONS(13897), 1,
      sym_identifier,
    ACTIONS(13903), 1,
      sym_quoted_identifier,
    STATE(7209), 1,
      aux_sym_preproc_conditional_where_repeat1,
    STATE(7323), 1,
      sym_where_condition,
    STATE(11955), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(14123), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [231405] = 13,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14109), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14111), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14115), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14117), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14119), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(14121), 1,
      sym_dataitem_keyword,
    ACTIONS(14125), 1,
      anon_sym_RBRACE,
    STATE(7420), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7229), 10,
      sym_modify_modification,
      sym_preproc_conditional_dataset,
      sym_report_dataitem,
      sym_add_dataset_modification,
      sym_addfirst_dataset_modification,
      sym_addlast_dataset_modification,
      sym_addafter_dataset_modification,
      sym_addbefore_dataset_modification,
      sym_attribute_item,
      aux_sym_dataset_section_repeat1,
  [231461] = 3,
    ACTIONS(5447), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5449), 23,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [231497] = 8,
    ACTIONS(13909), 1,
      sym_identifier,
    ACTIONS(13911), 1,
      sym_quoted_identifier,
    STATE(7228), 1,
      aux_sym_preproc_conditional_link_values_repeat1,
    STATE(7327), 1,
      sym_link_value,
    STATE(11648), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(14127), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [231543] = 8,
    ACTIONS(13905), 1,
      sym_identifier,
    ACTIONS(13907), 1,
      sym_quoted_identifier,
    STATE(7232), 1,
      aux_sym_preproc_conditional_impl_values_repeat1,
    STATE(7268), 1,
      sym_implementation_value,
    STATE(11655), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(14129), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [231589] = 13,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14109), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14111), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14115), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14117), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14119), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(14121), 1,
      sym_dataitem_keyword,
    ACTIONS(14131), 1,
      anon_sym_RBRACE,
    STATE(7420), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7219), 10,
      sym_modify_modification,
      sym_preproc_conditional_dataset,
      sym_report_dataitem,
      sym_add_dataset_modification,
      sym_addfirst_dataset_modification,
      sym_addlast_dataset_modification,
      sym_addafter_dataset_modification,
      sym_addbefore_dataset_modification,
      sym_attribute_item,
      aux_sym_dataset_section_repeat1,
  [231645] = 4,
    ACTIONS(13768), 1,
      sym_table_keyword,
    ACTIONS(14133), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13766), 22,
      sym_preproc_open,
      anon_sym_SEMI,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [231683] = 13,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14109), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14111), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14115), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14117), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14119), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(14121), 1,
      sym_dataitem_keyword,
    ACTIONS(14135), 1,
      anon_sym_RBRACE,
    STATE(7420), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7223), 10,
      sym_modify_modification,
      sym_preproc_conditional_dataset,
      sym_report_dataitem,
      sym_add_dataset_modification,
      sym_addfirst_dataset_modification,
      sym_addlast_dataset_modification,
      sym_addafter_dataset_modification,
      sym_addbefore_dataset_modification,
      sym_attribute_item,
      aux_sym_dataset_section_repeat1,
  [231739] = 10,
    ACTIONS(6244), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(14137), 1,
      sym_identifier,
    ACTIONS(14140), 1,
      sym_quoted_identifier,
    ACTIONS(14143), 1,
      sym_var_attribute_open,
    STATE(2418), 1,
      sym_preproc_if,
    STATE(10820), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6246), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7220), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(6241), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [231789] = 13,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14109), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14111), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14115), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14117), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14119), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(14121), 1,
      sym_dataitem_keyword,
    ACTIONS(14146), 1,
      anon_sym_RBRACE,
    STATE(7420), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7223), 10,
      sym_modify_modification,
      sym_preproc_conditional_dataset,
      sym_report_dataitem,
      sym_add_dataset_modification,
      sym_addfirst_dataset_modification,
      sym_addlast_dataset_modification,
      sym_addafter_dataset_modification,
      sym_addbefore_dataset_modification,
      sym_attribute_item,
      aux_sym_dataset_section_repeat1,
  [231845] = 13,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14109), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14111), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14115), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14117), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14119), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(14121), 1,
      sym_dataitem_keyword,
    ACTIONS(14148), 1,
      anon_sym_RBRACE,
    STATE(7420), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7233), 10,
      sym_modify_modification,
      sym_preproc_conditional_dataset,
      sym_report_dataitem,
      sym_add_dataset_modification,
      sym_addfirst_dataset_modification,
      sym_addlast_dataset_modification,
      sym_addafter_dataset_modification,
      sym_addbefore_dataset_modification,
      sym_attribute_item,
      aux_sym_dataset_section_repeat1,
  [231901] = 13,
    ACTIONS(14150), 1,
      anon_sym_RBRACE,
    ACTIONS(14152), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14155), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14158), 1,
      anon_sym_LBRACK,
    ACTIONS(14161), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14164), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14167), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14170), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(14176), 1,
      sym_dataitem_keyword,
    STATE(7420), 1,
      sym_preproc_if,
    ACTIONS(14173), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7223), 10,
      sym_modify_modification,
      sym_preproc_conditional_dataset,
      sym_report_dataitem,
      sym_add_dataset_modification,
      sym_addfirst_dataset_modification,
      sym_addlast_dataset_modification,
      sym_addafter_dataset_modification,
      sym_addbefore_dataset_modification,
      sym_attribute_item,
      aux_sym_dataset_section_repeat1,
  [231957] = 13,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14109), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14111), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14115), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14117), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14119), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(14121), 1,
      sym_dataitem_keyword,
    ACTIONS(14179), 1,
      anon_sym_RBRACE,
    STATE(7420), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7234), 10,
      sym_modify_modification,
      sym_preproc_conditional_dataset,
      sym_report_dataitem,
      sym_add_dataset_modification,
      sym_addfirst_dataset_modification,
      sym_addlast_dataset_modification,
      sym_addafter_dataset_modification,
      sym_addbefore_dataset_modification,
      sym_attribute_item,
      aux_sym_dataset_section_repeat1,
  [232013] = 8,
    ACTIONS(13897), 1,
      sym_identifier,
    ACTIONS(13903), 1,
      sym_quoted_identifier,
    STATE(7212), 1,
      aux_sym_preproc_conditional_where_repeat1,
    STATE(7323), 1,
      sym_where_condition,
    STATE(11955), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(14181), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [232059] = 10,
    ACTIONS(6263), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(14101), 1,
      sym_identifier,
    ACTIONS(14103), 1,
      sym_quoted_identifier,
    ACTIONS(14105), 1,
      sym_var_attribute_open,
    STATE(2418), 1,
      sym_preproc_if,
    STATE(10820), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7220), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [232109] = 8,
    ACTIONS(13909), 1,
      sym_identifier,
    ACTIONS(13911), 1,
      sym_quoted_identifier,
    STATE(7215), 1,
      aux_sym_preproc_conditional_link_values_repeat1,
    STATE(7327), 1,
      sym_link_value,
    STATE(11648), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(14183), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [232155] = 8,
    ACTIONS(14185), 1,
      sym_identifier,
    ACTIONS(14193), 1,
      sym_quoted_identifier,
    STATE(7228), 1,
      aux_sym_preproc_conditional_link_values_repeat1,
    STATE(7327), 1,
      sym_link_value,
    STATE(11648), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14188), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(14191), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [232201] = 13,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14109), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14111), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14115), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14117), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14119), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(14121), 1,
      sym_dataitem_keyword,
    ACTIONS(14196), 1,
      anon_sym_RBRACE,
    STATE(7420), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7223), 10,
      sym_modify_modification,
      sym_preproc_conditional_dataset,
      sym_report_dataitem,
      sym_add_dataset_modification,
      sym_addfirst_dataset_modification,
      sym_addlast_dataset_modification,
      sym_addafter_dataset_modification,
      sym_addbefore_dataset_modification,
      sym_attribute_item,
      aux_sym_dataset_section_repeat1,
  [232257] = 8,
    ACTIONS(13905), 1,
      sym_identifier,
    ACTIONS(13907), 1,
      sym_quoted_identifier,
    STATE(7216), 1,
      aux_sym_preproc_conditional_impl_values_repeat1,
    STATE(7268), 1,
      sym_implementation_value,
    STATE(11655), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(14198), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [232303] = 3,
    ACTIONS(13762), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13760), 23,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [232339] = 8,
    ACTIONS(14200), 1,
      sym_identifier,
    ACTIONS(14208), 1,
      sym_quoted_identifier,
    STATE(7232), 1,
      aux_sym_preproc_conditional_impl_values_repeat1,
    STATE(7268), 1,
      sym_implementation_value,
    STATE(11655), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14203), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(14206), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [232385] = 13,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14109), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14111), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14115), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14117), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14119), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(14121), 1,
      sym_dataitem_keyword,
    ACTIONS(14211), 1,
      anon_sym_RBRACE,
    STATE(7420), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7223), 10,
      sym_modify_modification,
      sym_preproc_conditional_dataset,
      sym_report_dataitem,
      sym_add_dataset_modification,
      sym_addfirst_dataset_modification,
      sym_addlast_dataset_modification,
      sym_addafter_dataset_modification,
      sym_addbefore_dataset_modification,
      sym_attribute_item,
      aux_sym_dataset_section_repeat1,
  [232441] = 13,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14109), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14111), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14115), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14117), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14119), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(14121), 1,
      sym_dataitem_keyword,
    ACTIONS(14213), 1,
      anon_sym_RBRACE,
    STATE(7420), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7223), 10,
      sym_modify_modification,
      sym_preproc_conditional_dataset,
      sym_report_dataitem,
      sym_add_dataset_modification,
      sym_addfirst_dataset_modification,
      sym_addlast_dataset_modification,
      sym_addafter_dataset_modification,
      sym_addbefore_dataset_modification,
      sym_attribute_item,
      aux_sym_dataset_section_repeat1,
  [232497] = 10,
    ACTIONS(6257), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(14101), 1,
      sym_identifier,
    ACTIONS(14103), 1,
      sym_quoted_identifier,
    ACTIONS(14105), 1,
      sym_var_attribute_open,
    STATE(2418), 1,
      sym_preproc_if,
    STATE(10820), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7210), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [232547] = 10,
    ACTIONS(6267), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(14101), 1,
      sym_identifier,
    ACTIONS(14103), 1,
      sym_quoted_identifier,
    ACTIONS(14105), 1,
      sym_var_attribute_open,
    STATE(2418), 1,
      sym_preproc_if,
    STATE(10820), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(6259), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7226), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [232597] = 3,
    ACTIONS(13813), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13420), 22,
      sym_preproc_open,
      anon_sym_SEMI,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [232632] = 4,
    ACTIONS(14215), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2266), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(2268), 13,
      sym_preproc_close,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [232669] = 4,
    ACTIONS(14217), 1,
      anon_sym_DOT,
    STATE(7243), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2348), 21,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
      sym_temporary_keyword,
  [232706] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2268), 23,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
      sym_temporary_keyword,
  [232739] = 4,
    ACTIONS(14219), 1,
      anon_sym_DOT,
    STATE(7241), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2398), 21,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
      sym_temporary_keyword,
  [232776] = 12,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(7457), 1,
      sym_preproc_elif,
    STATE(8153), 1,
      sym_preproc_else,
    STATE(8156), 1,
      aux_sym_preproc_conditional_fieldgroups_repeat2,
    STATE(9021), 1,
      sym_preproc_endif,
    ACTIONS(1547), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(1549), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    STATE(7248), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(14222), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [232829] = 4,
    ACTIONS(14217), 1,
      anon_sym_DOT,
    STATE(7241), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2444), 21,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
      sym_temporary_keyword,
  [232866] = 3,
    ACTIONS(13749), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13796), 22,
      sym_preproc_open,
      anon_sym_SEMI,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [232901] = 12,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(7457), 1,
      sym_preproc_elif,
    STATE(7702), 1,
      sym_preproc_endif,
    STATE(7794), 1,
      sym_preproc_else,
    STATE(7795), 1,
      aux_sym_preproc_conditional_fieldgroups_repeat2,
    ACTIONS(1547), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(1549), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    STATE(7469), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(1551), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [232954] = 3,
    ACTIONS(13817), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13815), 22,
      sym_preproc_open,
      anon_sym_SEMI,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [232989] = 3,
    ACTIONS(13777), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13772), 22,
      sym_preproc_open,
      anon_sym_SEMI,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [233024] = 12,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(7457), 1,
      sym_preproc_elif,
    STATE(7904), 1,
      sym_preproc_else,
    STATE(7907), 1,
      aux_sym_preproc_conditional_fieldgroups_repeat2,
    STATE(9032), 1,
      sym_preproc_endif,
    ACTIONS(1547), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(1549), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    STATE(7469), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(14222), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [233077] = 3,
    ACTIONS(13811), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13809), 22,
      sym_preproc_open,
      anon_sym_SEMI,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [233112] = 3,
    ACTIONS(13803), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13801), 22,
      sym_preproc_open,
      anon_sym_SEMI,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
  [233147] = 12,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(7457), 1,
      sym_preproc_elif,
    STATE(7747), 1,
      sym_preproc_endif,
    STATE(7781), 1,
      sym_preproc_else,
    STATE(7782), 1,
      aux_sym_preproc_conditional_fieldgroups_repeat2,
    ACTIONS(1547), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(1549), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    STATE(7245), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(1551), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [233200] = 4,
    ACTIONS(14226), 1,
      anon_sym_COMMA,
    STATE(7252), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2405), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [233236] = 4,
    ACTIONS(4383), 1,
      aux_sym_basic_type_token22,
    ACTIONS(14229), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [233272] = 4,
    ACTIONS(14233), 1,
      anon_sym_DOT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14231), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14235), 12,
      sym_preproc_close,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [233308] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2398), 22,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_DOT,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
      sym_temporary_keyword,
  [233340] = 4,
    ACTIONS(14237), 1,
      anon_sym_COMMA,
    STATE(7257), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2356), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [233376] = 4,
    ACTIONS(14237), 1,
      anon_sym_COMMA,
    STATE(7252), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2412), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [233412] = 4,
    ACTIONS(14237), 1,
      anon_sym_COMMA,
    STATE(7260), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(374), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [233448] = 4,
    ACTIONS(14233), 1,
      anon_sym_DOT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14239), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14241), 12,
      sym_preproc_close,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [233484] = 4,
    ACTIONS(14237), 1,
      anon_sym_COMMA,
    STATE(7252), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2356), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [233520] = 4,
    ACTIONS(4373), 1,
      aux_sym_basic_type_token22,
    ACTIONS(14243), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [233556] = 4,
    ACTIONS(4383), 1,
      aux_sym_basic_type_token22,
    ACTIONS(14245), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [233592] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2541), 21,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [233623] = 3,
    ACTIONS(12827), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12825), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [233656] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14247), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14249), 12,
      sym_preproc_close,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [233689] = 3,
    ACTIONS(8837), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [233722] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2428), 21,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [233753] = 4,
    ACTIONS(14253), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14251), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14255), 11,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [233788] = 3,
    ACTIONS(12815), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12813), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [233821] = 3,
    ACTIONS(4411), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4413), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [233854] = 10,
    ACTIONS(14257), 1,
      sym_identifier,
    ACTIONS(14259), 1,
      anon_sym_RPAREN,
    ACTIONS(14261), 1,
      sym_quoted_identifier,
    STATE(7028), 1,
      sym_preproc_if,
    STATE(7619), 1,
      sym_where_condition,
    STATE(7333), 2,
      sym_preproc_conditional_where,
      aux_sym_where_conditions_repeat1,
    STATE(12028), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [233901] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2416), 21,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [233932] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14263), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14265), 12,
      sym_preproc_close,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [233965] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2420), 21,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [233996] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2424), 21,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [234027] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14267), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14269), 12,
      sym_preproc_close,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [234060] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2553), 21,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [234091] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2428), 21,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [234122] = 3,
    ACTIONS(4415), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4417), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234155] = 3,
    ACTIONS(4419), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4421), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234188] = 3,
    ACTIONS(12823), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12821), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234221] = 3,
    ACTIONS(4423), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4425), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234254] = 3,
    ACTIONS(4427), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4429), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234287] = 3,
    ACTIONS(8944), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8942), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234320] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14271), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14273), 12,
      sym_preproc_close,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [234353] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14275), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14277), 12,
      sym_preproc_close,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [234386] = 10,
    ACTIONS(14257), 1,
      sym_identifier,
    ACTIONS(14261), 1,
      sym_quoted_identifier,
    STATE(7028), 1,
      sym_preproc_if,
    STATE(7619), 1,
      sym_where_condition,
    STATE(11382), 1,
      sym_where_conditions,
    STATE(7271), 2,
      sym_preproc_conditional_where,
      aux_sym_where_conditions_repeat1,
    STATE(12028), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [234433] = 10,
    ACTIONS(14257), 1,
      sym_identifier,
    ACTIONS(14261), 1,
      sym_quoted_identifier,
    STATE(7028), 1,
      sym_preproc_if,
    STATE(7619), 1,
      sym_where_condition,
    STATE(11503), 1,
      sym_where_conditions,
    STATE(7271), 2,
      sym_preproc_conditional_where,
      aux_sym_where_conditions_repeat1,
    STATE(12028), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [234480] = 3,
    ACTIONS(4431), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4433), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234513] = 3,
    ACTIONS(12831), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12829), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234546] = 3,
    ACTIONS(12866), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12864), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234579] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14279), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14281), 12,
      sym_preproc_close,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [234612] = 3,
    ACTIONS(12870), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12868), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234645] = 12,
    ACTIONS(14283), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14287), 1,
      aux_sym_modify_modification_token1,
    STATE(7546), 1,
      sym_preproc_elif,
    STATE(8149), 1,
      aux_sym_preproc_conditional_fields_repeat2,
    STATE(8711), 1,
      sym_preproc_else,
    STATE(9020), 1,
      sym_preproc_endif,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    STATE(7364), 4,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_preproc_conditional_fields_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [234696] = 3,
    ACTIONS(12849), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12847), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234729] = 3,
    ACTIONS(12722), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12720), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234762] = 3,
    ACTIONS(12874), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12872), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234795] = 3,
    ACTIONS(12878), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12876), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234828] = 3,
    ACTIONS(11811), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11806), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234861] = 3,
    ACTIONS(12882), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12880), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234894] = 3,
    ACTIONS(4435), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4437), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234927] = 3,
    ACTIONS(12886), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12884), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [234960] = 10,
    ACTIONS(14289), 1,
      sym_identifier,
    ACTIONS(14292), 1,
      anon_sym_SEMI,
    ACTIONS(14300), 1,
      sym_quoted_identifier,
    STATE(7024), 1,
      sym_preproc_if,
    STATE(7624), 1,
      sym_link_value,
    STATE(7303), 2,
      sym_preproc_conditional_link_values,
      aux_sym_link_value_list_repeat1,
    STATE(11278), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(14297), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14294), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [235007] = 3,
    ACTIONS(12757), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12755), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235040] = 3,
    ACTIONS(8821), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8819), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235073] = 3,
    ACTIONS(8821), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8819), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235106] = 3,
    ACTIONS(8817), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8815), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235139] = 3,
    ACTIONS(12763), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12761), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235172] = 3,
    ACTIONS(12890), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12888), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235205] = 3,
    ACTIONS(4439), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4441), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235238] = 3,
    ACTIONS(4443), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4445), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235271] = 3,
    ACTIONS(12894), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12892), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235304] = 3,
    ACTIONS(12898), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12896), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235337] = 3,
    ACTIONS(4447), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4449), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235370] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14303), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14305), 12,
      sym_preproc_close,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [235403] = 3,
    ACTIONS(4451), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4453), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235436] = 3,
    ACTIONS(12902), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12900), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235469] = 3,
    ACTIONS(4403), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4405), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235502] = 3,
    ACTIONS(11818), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11813), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235535] = 3,
    ACTIONS(4455), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235568] = 3,
    ACTIONS(8928), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8926), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235601] = 3,
    ACTIONS(8833), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235634] = 4,
    ACTIONS(14309), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14307), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14311), 11,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [235669] = 10,
    ACTIONS(14313), 1,
      sym_identifier,
    ACTIONS(14316), 1,
      anon_sym_SEMI,
    ACTIONS(14324), 1,
      sym_quoted_identifier,
    STATE(7021), 1,
      sym_preproc_if,
    STATE(7583), 1,
      sym_implementation_value,
    STATE(7324), 2,
      sym_preproc_conditional_impl_values,
      aux_sym_implementation_value_list_repeat1,
    STATE(11284), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(14321), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14318), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [235716] = 3,
    ACTIONS(8825), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8823), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235749] = 3,
    ACTIONS(12785), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12783), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235782] = 4,
    ACTIONS(14329), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14327), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14331), 11,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [235817] = 3,
    ACTIONS(14333), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2615), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [235850] = 3,
    ACTIONS(14335), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2621), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [235883] = 3,
    ACTIONS(8829), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8827), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235916] = 3,
    ACTIONS(12789), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12787), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235949] = 3,
    ACTIONS(12795), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12793), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [235982] = 10,
    ACTIONS(14337), 1,
      sym_identifier,
    ACTIONS(14340), 1,
      anon_sym_RPAREN,
    ACTIONS(14348), 1,
      sym_quoted_identifier,
    STATE(7028), 1,
      sym_preproc_if,
    STATE(7619), 1,
      sym_where_condition,
    STATE(7333), 2,
      sym_preproc_conditional_where,
      aux_sym_where_conditions_repeat1,
    STATE(12028), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(14345), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14342), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [236029] = 3,
    ACTIONS(8843), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8841), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236062] = 3,
    ACTIONS(12799), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12797), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236095] = 3,
    ACTIONS(12778), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12776), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236128] = 10,
    ACTIONS(14351), 1,
      sym_identifier,
    ACTIONS(14353), 1,
      anon_sym_SEMI,
    ACTIONS(14355), 1,
      sym_quoted_identifier,
    STATE(7024), 1,
      sym_preproc_if,
    STATE(7624), 1,
      sym_link_value,
    STATE(7303), 2,
      sym_preproc_conditional_link_values,
      aux_sym_link_value_list_repeat1,
    STATE(11278), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [236175] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2405), 21,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [236206] = 3,
    ACTIONS(12729), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12727), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236239] = 10,
    ACTIONS(14357), 1,
      sym_identifier,
    ACTIONS(14359), 1,
      anon_sym_SEMI,
    ACTIONS(14361), 1,
      sym_quoted_identifier,
    STATE(7021), 1,
      sym_preproc_if,
    STATE(7583), 1,
      sym_implementation_value,
    STATE(7324), 2,
      sym_preproc_conditional_impl_values,
      aux_sym_implementation_value_list_repeat1,
    STATE(11284), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [236286] = 3,
    ACTIONS(12803), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12801), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236319] = 3,
    ACTIONS(11753), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11748), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236352] = 3,
    ACTIONS(12807), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12805), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236385] = 3,
    ACTIONS(4373), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236418] = 3,
    ACTIONS(12811), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12809), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236451] = 3,
    ACTIONS(4383), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236484] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14363), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14365), 12,
      sym_preproc_close,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [236517] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2531), 21,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [236548] = 3,
    ACTIONS(8696), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8694), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236581] = 3,
    ACTIONS(14367), 1,
      sym_temporary_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2535), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [236614] = 3,
    ACTIONS(11785), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11780), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236647] = 3,
    ACTIONS(2843), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236680] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14369), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14371), 12,
      sym_preproc_close,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [236713] = 3,
    ACTIONS(12749), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12747), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236746] = 3,
    ACTIONS(4395), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236779] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14231), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14235), 12,
      sym_preproc_close,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [236812] = 3,
    ACTIONS(4395), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236845] = 3,
    ACTIONS(8783), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8781), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236878] = 3,
    ACTIONS(8787), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8785), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236911] = 3,
    ACTIONS(8791), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8789), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236944] = 3,
    ACTIONS(8837), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [236977] = 3,
    ACTIONS(4407), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4409), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237010] = 3,
    ACTIONS(8833), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237043] = 12,
    ACTIONS(14283), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14287), 1,
      aux_sym_modify_modification_token1,
    STATE(7546), 1,
      sym_preproc_elif,
    STATE(7900), 1,
      aux_sym_preproc_conditional_fields_repeat2,
    STATE(8734), 1,
      sym_preproc_else,
    STATE(9023), 1,
      sym_preproc_endif,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    STATE(7548), 4,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_preproc_conditional_fields_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [237094] = 3,
    ACTIONS(8837), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8835), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237127] = 3,
    ACTIONS(8843), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8841), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237160] = 10,
    ACTIONS(14257), 1,
      sym_identifier,
    ACTIONS(14261), 1,
      sym_quoted_identifier,
    STATE(7028), 1,
      sym_preproc_if,
    STATE(7619), 1,
      sym_where_condition,
    STATE(11951), 1,
      sym_where_conditions,
    STATE(7271), 2,
      sym_preproc_conditional_where,
      aux_sym_where_conditions_repeat1,
    STATE(12028), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [237207] = 10,
    ACTIONS(14257), 1,
      sym_identifier,
    ACTIONS(14261), 1,
      sym_quoted_identifier,
    STATE(7028), 1,
      sym_preproc_if,
    STATE(7619), 1,
      sym_where_condition,
    STATE(12074), 1,
      sym_where_conditions,
    STATE(7271), 2,
      sym_preproc_conditional_where,
      aux_sym_where_conditions_repeat1,
    STATE(12028), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [237254] = 3,
    ACTIONS(8847), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8845), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237287] = 3,
    ACTIONS(8847), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8845), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237320] = 3,
    ACTIONS(8795), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8793), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237353] = 3,
    ACTIONS(8799), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237386] = 3,
    ACTIONS(8799), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237419] = 3,
    ACTIONS(8799), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8797), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237452] = 3,
    ACTIONS(8803), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237485] = 3,
    ACTIONS(8803), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237518] = 3,
    ACTIONS(8803), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8801), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237551] = 3,
    ACTIONS(8807), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8805), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237584] = 3,
    ACTIONS(8811), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8809), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237617] = 3,
    ACTIONS(4379), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4381), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237650] = 3,
    ACTIONS(4399), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4401), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237683] = 3,
    ACTIONS(12819), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12817), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237716] = 3,
    ACTIONS(8825), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8823), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237749] = 3,
    ACTIONS(8833), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8831), 20,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_trigger_keyword,
      sym_area_keyword,
      sym_group_keyword,
  [237782] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2643), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [237812] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2571), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [237842] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13178), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [237872] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5449), 6,
      sym_preproc_close,
      anon_sym_LBRACK,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
    ACTIONS(5447), 14,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_dataitem_keyword,
      sym_identifier,
  [237904] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14373), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14191), 11,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [237936] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14375), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14206), 11,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [237968] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2651), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [237998] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2627), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [238028] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2631), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [238058] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2635), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [238088] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14377), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
    ACTIONS(14096), 11,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_quoted_identifier,
  [238120] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2583), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [238150] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13176), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [238180] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2575), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [238210] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2579), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [238240] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2587), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [238270] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2587), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [238300] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2587), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [238330] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2591), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [238360] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2591), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [238390] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2591), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [238420] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2647), 20,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [238450] = 9,
    ACTIONS(13897), 1,
      sym_identifier,
    ACTIONS(13903), 1,
      sym_quoted_identifier,
    STATE(7209), 1,
      aux_sym_preproc_conditional_where_repeat1,
    STATE(7323), 1,
      sym_where_condition,
    STATE(7671), 1,
      sym_preproc_endif,
    STATE(11955), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [238493] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14381), 1,
      anon_sym_RPAREN,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    STATE(10732), 1,
      sym_parameter,
    STATE(11662), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [238540] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14389), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(12195), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [238587] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14391), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11263), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [238634] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14393), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(12006), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [238681] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14395), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11703), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [238728] = 12,
    ACTIONS(14397), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(14401), 1,
      sym_var_keyword,
    STATE(7674), 1,
      sym_var_section,
    STATE(7970), 1,
      sym_preproc_elif,
    STATE(7971), 1,
      aux_sym_preproc_conditional_var_block_repeat1,
    STATE(8985), 1,
      sym_preproc_else,
    STATE(11132), 1,
      sym_preproc_endif,
    ACTIONS(14403), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [238777] = 9,
    ACTIONS(13897), 1,
      sym_identifier,
    ACTIONS(13903), 1,
      sym_quoted_identifier,
    STATE(7209), 1,
      aux_sym_preproc_conditional_where_repeat1,
    STATE(7323), 1,
      sym_where_condition,
    STATE(7729), 1,
      sym_preproc_endif,
    STATE(11955), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [238820] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14405), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11523), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [238867] = 12,
    ACTIONS(14401), 1,
      sym_var_keyword,
    ACTIONS(14407), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(7632), 1,
      sym_var_section,
    STATE(7970), 1,
      sym_preproc_elif,
    STATE(7971), 1,
      aux_sym_preproc_conditional_var_block_repeat1,
    STATE(8985), 1,
      sym_preproc_else,
    STATE(11132), 1,
      sym_preproc_endif,
    ACTIONS(14403), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [238916] = 9,
    ACTIONS(13909), 1,
      sym_identifier,
    ACTIONS(13911), 1,
      sym_quoted_identifier,
    STATE(7228), 1,
      aux_sym_preproc_conditional_link_values_repeat1,
    STATE(7327), 1,
      sym_link_value,
    STATE(7667), 1,
      sym_preproc_endif,
    STATE(11648), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [238959] = 9,
    ACTIONS(13909), 1,
      sym_identifier,
    ACTIONS(13911), 1,
      sym_quoted_identifier,
    STATE(7327), 1,
      sym_link_value,
    STATE(7424), 1,
      aux_sym_preproc_conditional_link_values_repeat1,
    STATE(7667), 1,
      sym_preproc_endif,
    STATE(11648), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239002] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14409), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(12207), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239049] = 11,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14411), 1,
      sym_dataitem_keyword,
    STATE(7647), 1,
      sym_preproc_elif,
    STATE(7802), 1,
      aux_sym_preproc_conditional_dataset_repeat2,
    STATE(8189), 1,
      sym_preproc_endif,
    STATE(8936), 1,
      sym_preproc_else,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    STATE(7436), 3,
      sym_report_dataitem,
      sym_attribute_item,
      aux_sym_preproc_conditional_dataset_repeat1,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [239096] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14413), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11770), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239143] = 12,
    ACTIONS(14401), 1,
      sym_var_keyword,
    ACTIONS(14415), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(7654), 1,
      sym_var_section,
    STATE(7970), 1,
      sym_preproc_elif,
    STATE(7971), 1,
      aux_sym_preproc_conditional_var_block_repeat1,
    STATE(8985), 1,
      sym_preproc_else,
    STATE(11132), 1,
      sym_preproc_endif,
    ACTIONS(14403), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [239192] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14417), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11355), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239239] = 9,
    ACTIONS(13909), 1,
      sym_identifier,
    ACTIONS(13911), 1,
      sym_quoted_identifier,
    STATE(7228), 1,
      aux_sym_preproc_conditional_link_values_repeat1,
    STATE(7327), 1,
      sym_link_value,
    STATE(7723), 1,
      sym_preproc_endif,
    STATE(11648), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239282] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14419), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11794), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239329] = 9,
    ACTIONS(13909), 1,
      sym_identifier,
    ACTIONS(13911), 1,
      sym_quoted_identifier,
    STATE(7327), 1,
      sym_link_value,
    STATE(7434), 1,
      aux_sym_preproc_conditional_link_values_repeat1,
    STATE(7723), 1,
      sym_preproc_endif,
    STATE(11648), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239372] = 9,
    ACTIONS(13897), 1,
      sym_identifier,
    ACTIONS(13903), 1,
      sym_quoted_identifier,
    STATE(7323), 1,
      sym_where_condition,
    STATE(7445), 1,
      aux_sym_preproc_conditional_where_repeat1,
    STATE(7729), 1,
      sym_preproc_endif,
    STATE(11955), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239415] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14421), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11343), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239462] = 9,
    ACTIONS(13905), 1,
      sym_identifier,
    ACTIONS(13907), 1,
      sym_quoted_identifier,
    STATE(7268), 1,
      sym_implementation_value,
    STATE(7452), 1,
      aux_sym_preproc_conditional_impl_values_repeat1,
    STATE(7650), 1,
      sym_preproc_endif,
    STATE(11655), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239505] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14423), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11349), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239552] = 11,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14425), 1,
      sym_key_keyword,
    STATE(7659), 1,
      sym_preproc_elif,
    STATE(7902), 1,
      aux_sym_preproc_conditional_keys_repeat2,
    STATE(8953), 1,
      sym_preproc_else,
    STATE(9045), 1,
      sym_preproc_endif,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    STATE(7751), 3,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_preproc_conditional_keys_repeat1,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [239599] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14427), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(12078), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239646] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14429), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(12542), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239693] = 9,
    ACTIONS(13909), 1,
      sym_identifier,
    ACTIONS(13911), 1,
      sym_quoted_identifier,
    STATE(7228), 1,
      aux_sym_preproc_conditional_link_values_repeat1,
    STATE(7327), 1,
      sym_link_value,
    STATE(7772), 1,
      sym_preproc_endif,
    STATE(11648), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239736] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14431), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(12132), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239783] = 11,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14411), 1,
      sym_dataitem_keyword,
    STATE(7647), 1,
      sym_preproc_elif,
    STATE(7937), 1,
      aux_sym_preproc_conditional_dataset_repeat2,
    STATE(8265), 1,
      sym_preproc_endif,
    STATE(8863), 1,
      sym_preproc_else,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    STATE(7719), 3,
      sym_report_dataitem,
      sym_attribute_item,
      aux_sym_preproc_conditional_dataset_repeat1,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [239830] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14433), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11354), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239877] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14435), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11356), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239924] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14437), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11428), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [239971] = 9,
    ACTIONS(13905), 1,
      sym_identifier,
    ACTIONS(13907), 1,
      sym_quoted_identifier,
    STATE(7232), 1,
      aux_sym_preproc_conditional_impl_values_repeat1,
    STATE(7268), 1,
      sym_implementation_value,
    STATE(7762), 1,
      sym_preproc_endif,
    STATE(11655), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240014] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14439), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11726), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240061] = 9,
    ACTIONS(13905), 1,
      sym_identifier,
    ACTIONS(13907), 1,
      sym_quoted_identifier,
    STATE(7268), 1,
      sym_implementation_value,
    STATE(7448), 1,
      aux_sym_preproc_conditional_impl_values_repeat1,
    STATE(7762), 1,
      sym_preproc_endif,
    STATE(11655), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240104] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14441), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(12146), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240151] = 6,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(7469), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14443), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [240188] = 9,
    ACTIONS(13897), 1,
      sym_identifier,
    ACTIONS(13903), 1,
      sym_quoted_identifier,
    STATE(7209), 1,
      aux_sym_preproc_conditional_where_repeat1,
    STATE(7323), 1,
      sym_where_condition,
    STATE(7749), 1,
      sym_preproc_endif,
    STATE(11955), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240231] = 9,
    ACTIONS(13897), 1,
      sym_identifier,
    ACTIONS(13903), 1,
      sym_quoted_identifier,
    STATE(7323), 1,
      sym_where_condition,
    STATE(7407), 1,
      aux_sym_preproc_conditional_where_repeat1,
    STATE(7749), 1,
      sym_preproc_endif,
    STATE(11955), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240274] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14445), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(12151), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240321] = 9,
    ACTIONS(13905), 1,
      sym_identifier,
    ACTIONS(13907), 1,
      sym_quoted_identifier,
    STATE(7232), 1,
      aux_sym_preproc_conditional_impl_values_repeat1,
    STATE(7268), 1,
      sym_implementation_value,
    STATE(7763), 1,
      sym_preproc_endif,
    STATE(11655), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240364] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14447), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11913), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240411] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14449), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11831), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240458] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14451), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(12083), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240505] = 9,
    ACTIONS(13905), 1,
      sym_identifier,
    ACTIONS(13907), 1,
      sym_quoted_identifier,
    STATE(7232), 1,
      aux_sym_preproc_conditional_impl_values_repeat1,
    STATE(7268), 1,
      sym_implementation_value,
    STATE(7699), 1,
      sym_preproc_endif,
    STATE(11655), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240548] = 12,
    ACTIONS(14401), 1,
      sym_var_keyword,
    ACTIONS(14453), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(7646), 1,
      sym_var_section,
    STATE(7970), 1,
      sym_preproc_elif,
    STATE(7971), 1,
      aux_sym_preproc_conditional_var_block_repeat1,
    STATE(8985), 1,
      sym_preproc_else,
    STATE(11132), 1,
      sym_preproc_endif,
    ACTIONS(14403), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [240597] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14455), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(12222), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240644] = 9,
    ACTIONS(13905), 1,
      sym_identifier,
    ACTIONS(13907), 1,
      sym_quoted_identifier,
    STATE(7268), 1,
      sym_implementation_value,
    STATE(7440), 1,
      aux_sym_preproc_conditional_impl_values_repeat1,
    STATE(7699), 1,
      sym_preproc_endif,
    STATE(11655), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240687] = 9,
    ACTIONS(13897), 1,
      sym_identifier,
    ACTIONS(13903), 1,
      sym_quoted_identifier,
    STATE(7323), 1,
      sym_where_condition,
    STATE(7414), 1,
      aux_sym_preproc_conditional_where_repeat1,
    STATE(7745), 1,
      sym_preproc_endif,
    STATE(11955), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240730] = 6,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(7444), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14457), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [240767] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14459), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(12216), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240814] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14461), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11840), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240861] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14463), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(12158), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240908] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14465), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(12570), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [240955] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14467), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(12420), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [241002] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14469), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(12185), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [241049] = 11,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14425), 1,
      sym_key_keyword,
    STATE(7659), 1,
      sym_preproc_elif,
    STATE(8152), 1,
      aux_sym_preproc_conditional_keys_repeat2,
    STATE(8949), 1,
      sym_preproc_else,
    STATE(9038), 1,
      sym_preproc_endif,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    STATE(7431), 3,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_preproc_conditional_keys_repeat1,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [241096] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14471), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(12073), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [241143] = 12,
    ACTIONS(14401), 1,
      sym_var_keyword,
    ACTIONS(14473), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(7660), 1,
      sym_var_section,
    STATE(7970), 1,
      sym_preproc_elif,
    STATE(7971), 1,
      aux_sym_preproc_conditional_var_block_repeat1,
    STATE(8985), 1,
      sym_preproc_else,
    STATE(11132), 1,
      sym_preproc_endif,
    ACTIONS(14403), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [241192] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14475), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11909), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [241239] = 9,
    ACTIONS(13909), 1,
      sym_identifier,
    ACTIONS(13911), 1,
      sym_quoted_identifier,
    STATE(7327), 1,
      sym_link_value,
    STATE(7417), 1,
      aux_sym_preproc_conditional_link_values_repeat1,
    STATE(7744), 1,
      sym_preproc_endif,
    STATE(11648), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [241282] = 6,
    ACTIONS(14482), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(7469), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(14477), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14480), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [241319] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14485), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11372), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [241366] = 11,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    ACTIONS(14487), 1,
      anon_sym_RPAREN,
    STATE(10732), 1,
      sym_parameter,
    STATE(11520), 1,
      sym_parameter_list,
    STATE(7508), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [241413] = 9,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(14489), 1,
      anon_sym_RBRACE,
    ACTIONS(14491), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14493), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14495), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14497), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14499), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7488), 11,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_addfirst_views_modification,
      sym_addlast_views_modification,
      sym_addafter_views_modification,
      sym_addbefore_views_modification,
      sym_view_definition,
      aux_sym_views_section_repeat1,
  [241455] = 4,
    ACTIONS(14501), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4383), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [241487] = 9,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(14491), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14493), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14495), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14497), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14499), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14503), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7483), 11,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_addfirst_views_modification,
      sym_addlast_views_modification,
      sym_addafter_views_modification,
      sym_addbefore_views_modification,
      sym_view_definition,
      aux_sym_views_section_repeat1,
  [241529] = 9,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(14491), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14493), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14495), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14497), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14499), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14505), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7477), 11,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_addfirst_views_modification,
      sym_addlast_views_modification,
      sym_addafter_views_modification,
      sym_addbefore_views_modification,
      sym_view_definition,
      aux_sym_views_section_repeat1,
  [241571] = 4,
    ACTIONS(14507), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4383), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [241603] = 9,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(14491), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14493), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14495), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14497), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14499), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14509), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7478), 11,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_addfirst_views_modification,
      sym_addlast_views_modification,
      sym_addafter_views_modification,
      sym_addbefore_views_modification,
      sym_view_definition,
      aux_sym_views_section_repeat1,
  [241645] = 9,
    ACTIONS(14511), 1,
      anon_sym_RBRACE,
    ACTIONS(14513), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14516), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14519), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14522), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14525), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14528), 1,
      sym_view_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7478), 11,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_addfirst_views_modification,
      sym_addlast_views_modification,
      sym_addafter_views_modification,
      sym_addbefore_views_modification,
      sym_view_definition,
      aux_sym_views_section_repeat1,
  [241687] = 9,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(14491), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14493), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14495), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14497), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14499), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14531), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7478), 11,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_addfirst_views_modification,
      sym_addlast_views_modification,
      sym_addafter_views_modification,
      sym_addbefore_views_modification,
      sym_view_definition,
      aux_sym_views_section_repeat1,
  [241729] = 4,
    ACTIONS(14533), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2268), 8,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(2266), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [241761] = 9,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(14491), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14493), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14495), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14497), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14499), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14535), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7479), 11,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_addfirst_views_modification,
      sym_addlast_views_modification,
      sym_addafter_views_modification,
      sym_addbefore_views_modification,
      sym_view_definition,
      aux_sym_views_section_repeat1,
  [241803] = 9,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(14491), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14493), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14495), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14497), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14499), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14537), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7485), 11,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_addfirst_views_modification,
      sym_addlast_views_modification,
      sym_addafter_views_modification,
      sym_addbefore_views_modification,
      sym_view_definition,
      aux_sym_views_section_repeat1,
  [241845] = 9,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(14491), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14493), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14495), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14497), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14499), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14539), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7478), 11,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_addfirst_views_modification,
      sym_addlast_views_modification,
      sym_addafter_views_modification,
      sym_addbefore_views_modification,
      sym_view_definition,
      aux_sym_views_section_repeat1,
  [241887] = 4,
    ACTIONS(14541), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4373), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [241919] = 9,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(14491), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14493), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14495), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14497), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14499), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14543), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7478), 11,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_addfirst_views_modification,
      sym_addlast_views_modification,
      sym_addafter_views_modification,
      sym_addbefore_views_modification,
      sym_view_definition,
      aux_sym_views_section_repeat1,
  [241961] = 11,
    ACTIONS(14401), 1,
      sym_var_keyword,
    STATE(7969), 1,
      sym_var_section,
    STATE(7970), 1,
      sym_preproc_elif,
    STATE(7971), 1,
      aux_sym_preproc_conditional_var_block_repeat1,
    STATE(8985), 1,
      sym_preproc_else,
    STATE(11132), 1,
      sym_preproc_endif,
    ACTIONS(14403), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [242007] = 5,
    ACTIONS(14547), 1,
      anon_sym_LBRACK,
    ACTIONS(14550), 1,
      sym_quoted_identifier,
    STATE(7487), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14545), 14,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242041] = 9,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(14491), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14493), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14495), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14497), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14499), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14552), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7478), 11,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_addfirst_views_modification,
      sym_addlast_views_modification,
      sym_addafter_views_modification,
      sym_addbefore_views_modification,
      sym_view_definition,
      aux_sym_views_section_repeat1,
  [242083] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7545), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7543), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242112] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7575), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242141] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8015), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8013), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242170] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4417), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4415), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242199] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4409), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4407), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242228] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4421), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4419), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242257] = 9,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    STATE(11118), 1,
      sym_parameter,
    STATE(7535), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [242298] = 4,
    ACTIONS(14554), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4383), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242329] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4425), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4423), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242358] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4413), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4411), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242387] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8199), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242416] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8199), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242445] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4405), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4403), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242474] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8199), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242503] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6978), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6976), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242532] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8237), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8235), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242561] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6978), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6976), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242590] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7152), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242619] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4429), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4427), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242648] = 9,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    STATE(10593), 1,
      sym_parameter,
    STATE(7487), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [242689] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8265), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8263), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242718] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2268), 8,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(2266), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242747] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4395), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242776] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4395), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242805] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7807), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7805), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242834] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7811), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7809), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242863] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7541), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7539), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242892] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4401), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4399), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242921] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8019), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8017), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242950] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4373), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [242979] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7361), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7359), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243008] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4383), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243037] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7935), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7933), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243066] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4433), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4431), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243095] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7575), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243124] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7939), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7937), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243153] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7575), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243182] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7617), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7615), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243211] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7152), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243240] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4437), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4435), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243269] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4441), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4439), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243298] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7617), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7615), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243327] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4445), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4443), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243356] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7166), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243385] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8177), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8175), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243414] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7166), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243443] = 9,
    ACTIONS(14379), 1,
      sym_identifier,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(14385), 1,
      sym_var_keyword,
    ACTIONS(14387), 1,
      sym_quoted_identifier,
    STATE(11184), 1,
      sym_parameter,
    STATE(7487), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    STATE(11358), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [243484] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7152), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243513] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4449), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4447), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243542] = 4,
    ACTIONS(14556), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4373), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243573] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7369), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7367), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243602] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7373), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7371), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243631] = 4,
    ACTIONS(14558), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4383), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243662] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7943), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7941), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243691] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4453), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4451), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243720] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4455), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243749] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7373), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7371), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243778] = 6,
    ACTIONS(14283), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14287), 1,
      aux_sym_modify_modification_token1,
    STATE(7547), 4,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_preproc_conditional_fields_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14560), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [243813] = 6,
    ACTIONS(14283), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14287), 1,
      aux_sym_modify_modification_token1,
    STATE(7548), 4,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_preproc_conditional_fields_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14562), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [243848] = 6,
    ACTIONS(14564), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14567), 1,
      anon_sym_LBRACK,
    ACTIONS(14570), 1,
      aux_sym_modify_modification_token1,
    STATE(7548), 4,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_preproc_conditional_fields_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14573), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [243883] = 4,
    ACTIONS(14575), 1,
      anon_sym_DOT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14235), 7,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14231), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243914] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7377), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7375), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243943] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8473), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8471), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [243972] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4381), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4379), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244001] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7377), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7375), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244030] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(2843), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244059] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8213), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8211), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244088] = 4,
    ACTIONS(14575), 1,
      anon_sym_DOT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14241), 7,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14239), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244119] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 7,
      sym_preproc_open,
      sym_begin_keyword,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7166), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244148] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7373), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7371), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244176] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7166), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244204] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14265), 7,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14263), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244232] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4455), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244260] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8177), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8175), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244288] = 10,
    ACTIONS(14577), 1,
      sym_identifier,
    ACTIONS(14579), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14581), 1,
      aux_sym_where_condition_token2,
    ACTIONS(14583), 1,
      aux_sym_where_condition_token3,
    ACTIONS(14587), 1,
      sym_filter_keyword,
    ACTIONS(14589), 1,
      sym_quoted_identifier,
    ACTIONS(14591), 1,
      sym_string_literal,
    STATE(7549), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14585), 7,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [244330] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14249), 7,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14247), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244358] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7152), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244386] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4421), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4419), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244414] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4425), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4423), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244442] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4429), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4427), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244470] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4395), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244498] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4373), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244526] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8015), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8013), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244554] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7166), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244582] = 3,
    ACTIONS(8942), 2,
      anon_sym_LBRACK,
      sym_quoted_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8944), 14,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_procedure_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244610] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7811), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7809), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244638] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4405), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4403), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244666] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14371), 7,
      sym_preproc_open,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14369), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244694] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4409), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4407), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244722] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8213), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8211), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244750] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4395), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244778] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14305), 7,
      sym_preproc_open,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14303), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244806] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8265), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8263), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244834] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7541), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7539), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244862] = 4,
    ACTIONS(14597), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14595), 6,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14593), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244892] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7377), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7375), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244920] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7545), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7543), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244948] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7369), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7367), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [244976] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7377), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7375), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245004] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8019), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8017), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245032] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7373), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7371), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245060] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4433), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4431), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245088] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7935), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7933), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245116] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14269), 7,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14267), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245144] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4437), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4435), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245172] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7361), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7359), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245200] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7939), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7937), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245228] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4381), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4379), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245256] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4441), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4439), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245284] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8199), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245312] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7617), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7615), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245340] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8199), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245368] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4401), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4399), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245396] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8201), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8199), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245424] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8237), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8235), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245452] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7575), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245480] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4413), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4411), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245508] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4417), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4415), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245536] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14281), 7,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14279), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245564] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7575), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245592] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4445), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4443), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245620] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8473), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8471), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245648] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7577), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7575), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245676] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14365), 7,
      sym_preproc_open,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14363), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245704] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14235), 7,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14231), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245732] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7943), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7941), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245760] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7617), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7615), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245788] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6978), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6976), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245816] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6978), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6976), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245844] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7152), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245872] = 4,
    ACTIONS(14601), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14603), 6,
      sym_preproc_open,
      anon_sym_RPAREN,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14599), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245902] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4449), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4447), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245930] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7168), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7166), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245958] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(2843), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [245986] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14273), 7,
      sym_preproc_open,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14271), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [246014] = 4,
    ACTIONS(14609), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14607), 6,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14605), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [246044] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4453), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4451), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [246072] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14277), 7,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14275), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [246100] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7807), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7805), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [246128] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7154), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(7152), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [246156] = 3,
    ACTIONS(14611), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14613), 15,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_fieldgroup_keyword,
  [246184] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 6,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(4383), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [246212] = 9,
    ACTIONS(14615), 1,
      sym_identifier,
    ACTIONS(14617), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14619), 1,
      aux_sym_where_condition_token2,
    ACTIONS(14621), 1,
      aux_sym_where_condition_token3,
    ACTIONS(14623), 1,
      sym_filter_keyword,
    ACTIONS(14625), 1,
      sym_quoted_identifier,
    STATE(7254), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 7,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [246251] = 9,
    ACTIONS(14627), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(7970), 1,
      sym_preproc_elif,
    STATE(8127), 1,
      aux_sym_preproc_conditional_var_block_repeat1,
    STATE(8992), 1,
      sym_preproc_else,
    STATE(11139), 1,
      sym_preproc_endif,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [246290] = 4,
    ACTIONS(14629), 1,
      anon_sym_DOT,
    STATE(7633), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2398), 13,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_temporary_keyword,
  [246319] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14632), 1,
      anon_sym_SEMI,
    STATE(6495), 1,
      sym_preproc_split_procedure_body,
    STATE(6496), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10435), 1,
      sym_preproc_conditional_var_block,
    STATE(10436), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [246362] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14634), 1,
      anon_sym_SEMI,
    STATE(6504), 1,
      sym_preproc_split_procedure_body,
    STATE(6688), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10437), 1,
      sym_preproc_conditional_var_block,
    STATE(10438), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [246405] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14636), 1,
      anon_sym_SEMI,
    STATE(3714), 1,
      sym_preproc_split_procedure_body,
    STATE(3718), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10594), 1,
      sym_preproc_conditional_var_block,
    STATE(10595), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [246448] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14638), 1,
      anon_sym_SEMI,
    STATE(5110), 1,
      sym_preproc_split_procedure_body,
    STATE(5111), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10537), 1,
      sym_preproc_conditional_var_block,
    STATE(10538), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [246491] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14640), 1,
      anon_sym_SEMI,
    STATE(5131), 1,
      sym_preproc_split_procedure_body,
    STATE(5132), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10778), 1,
      sym_preproc_conditional_var_block,
    STATE(11114), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [246534] = 9,
    ACTIONS(14617), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14619), 1,
      aux_sym_where_condition_token2,
    ACTIONS(14621), 1,
      aux_sym_where_condition_token3,
    ACTIONS(14623), 1,
      sym_filter_keyword,
    ACTIONS(14642), 1,
      sym_identifier,
    ACTIONS(14644), 1,
      sym_quoted_identifier,
    STATE(7259), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 7,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [246573] = 7,
    ACTIONS(14646), 1,
      sym_identifier,
    ACTIONS(14648), 1,
      sym_quoted_identifier,
    STATE(6004), 1,
      sym__namespaced_or_simple_ref,
    ACTIONS(14650), 2,
      sym_string_literal,
      sym_integer,
    STATE(5389), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4844), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [246608] = 7,
    ACTIONS(14652), 1,
      sym_identifier,
    ACTIONS(14654), 1,
      sym_quoted_identifier,
    STATE(8895), 1,
      sym__namespaced_or_simple_ref,
    ACTIONS(14656), 2,
      sym_string_literal,
      sym_integer,
    STATE(8232), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9358), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [246643] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14658), 15,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_fieldgroup_keyword,
  [246668] = 7,
    ACTIONS(14660), 1,
      sym_identifier,
    ACTIONS(14662), 1,
      sym_quoted_identifier,
    STATE(1032), 1,
      sym__namespaced_or_simple_ref,
    ACTIONS(14664), 2,
      sym_string_literal,
      sym_integer,
    STATE(957), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(283), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [246703] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14666), 1,
      anon_sym_SEMI,
    STATE(5159), 1,
      sym_preproc_split_procedure_body,
    STATE(5166), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10573), 1,
      sym_preproc_conditional_var_block,
    STATE(10574), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [246746] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14668), 1,
      anon_sym_SEMI,
    STATE(6773), 1,
      sym_preproc_split_procedure_body,
    STATE(6774), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10391), 1,
      sym_preproc_conditional_var_block,
    STATE(10392), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [246789] = 9,
    ACTIONS(14670), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(7970), 1,
      sym_preproc_elif,
    STATE(8127), 1,
      aux_sym_preproc_conditional_var_block_repeat1,
    STATE(8992), 1,
      sym_preproc_else,
    STATE(11139), 1,
      sym_preproc_endif,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [246828] = 5,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14411), 1,
      sym_dataitem_keyword,
    STATE(7701), 3,
      sym_report_dataitem,
      sym_attribute_item,
      aux_sym_preproc_conditional_dataset_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14672), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [246859] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14674), 1,
      anon_sym_SEMI,
    STATE(5627), 1,
      sym_preproc_split_procedure_body,
    STATE(5628), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10674), 1,
      sym_preproc_conditional_var_block,
    STATE(10675), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [246902] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14676), 1,
      anon_sym_SEMI,
    STATE(3983), 1,
      sym_preproc_split_procedure_body,
    STATE(3984), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10529), 1,
      sym_preproc_conditional_var_block,
    STATE(10532), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [246945] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14680), 6,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14678), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [246972] = 7,
    ACTIONS(14682), 1,
      sym_identifier,
    ACTIONS(14684), 1,
      sym_quoted_identifier,
    STATE(1142), 1,
      sym__namespaced_or_simple_ref,
    ACTIONS(14686), 2,
      sym_string_literal,
      sym_integer,
    STATE(1083), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(425), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [247007] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13991), 1,
      anon_sym_SEMI,
    STATE(5189), 1,
      sym_preproc_split_procedure_body,
    STATE(5190), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10841), 1,
      sym_preproc_conditional_var_block,
    STATE(10846), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [247050] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14688), 1,
      anon_sym_SEMI,
    STATE(6777), 1,
      sym_preproc_split_procedure_body,
    STATE(6778), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10394), 1,
      sym_preproc_conditional_var_block,
    STATE(10395), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [247093] = 9,
    ACTIONS(14690), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(7970), 1,
      sym_preproc_elif,
    STATE(8127), 1,
      aux_sym_preproc_conditional_var_block_repeat1,
    STATE(8992), 1,
      sym_preproc_else,
    STATE(11139), 1,
      sym_preproc_endif,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [247132] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14078), 1,
      anon_sym_SEMI,
    STATE(5565), 1,
      sym_preproc_split_procedure_body,
    STATE(5566), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10641), 1,
      sym_preproc_conditional_var_block,
    STATE(10642), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [247175] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14692), 1,
      anon_sym_SEMI,
    STATE(6782), 1,
      sym_preproc_split_procedure_body,
    STATE(6783), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10397), 1,
      sym_preproc_conditional_var_block,
    STATE(10398), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [247218] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14694), 15,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_fieldgroup_keyword,
  [247243] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14696), 1,
      anon_sym_SEMI,
    STATE(6784), 1,
      sym_preproc_split_procedure_body,
    STATE(6785), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10399), 1,
      sym_preproc_conditional_var_block,
    STATE(10400), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [247286] = 5,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14425), 1,
      sym_key_keyword,
    STATE(7750), 3,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_preproc_conditional_keys_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14698), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [247317] = 9,
    ACTIONS(14700), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(7970), 1,
      sym_preproc_elif,
    STATE(8127), 1,
      aux_sym_preproc_conditional_var_block_repeat1,
    STATE(8992), 1,
      sym_preproc_else,
    STATE(11139), 1,
      sym_preproc_endif,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [247356] = 4,
    ACTIONS(14702), 1,
      anon_sym_DOT,
    STATE(7678), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2348), 13,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_if_table_relation_token2,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [247385] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14704), 1,
      anon_sym_SEMI,
    STATE(4083), 1,
      sym_preproc_split_procedure_body,
    STATE(4084), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10471), 1,
      sym_preproc_conditional_var_block,
    STATE(10474), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [247428] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13971), 1,
      anon_sym_SEMI,
    STATE(3554), 1,
      sym_preproc_split_procedure_body,
    STATE(3555), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10936), 1,
      sym_preproc_conditional_var_block,
    STATE(10937), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [247471] = 8,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    ACTIONS(11647), 1,
      anon_sym_STAR,
    ACTIONS(11651), 1,
      sym_integer,
    STATE(11156), 1,
      sym__namespaced_or_simple_ref,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [247508] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14034), 1,
      anon_sym_SEMI,
    STATE(3558), 1,
      sym_preproc_split_procedure_body,
    STATE(3559), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10938), 1,
      sym_preproc_conditional_var_block,
    STATE(10939), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [247551] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14080), 1,
      anon_sym_SEMI,
    STATE(5572), 1,
      sym_preproc_split_procedure_body,
    STATE(5575), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10644), 1,
      sym_preproc_conditional_var_block,
    STATE(10645), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [247594] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14708), 6,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14706), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [247621] = 9,
    ACTIONS(14710), 1,
      anon_sym_SEMI,
    STATE(1503), 1,
      sym_preproc_elif,
    STATE(1749), 1,
      sym_preproc_else,
    STATE(7849), 1,
      aux_sym_preproc_conditional_table_relation_repeat1,
    STATE(12224), 1,
      sym_preproc_endif,
    ACTIONS(3072), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3074), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [247660] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14712), 1,
      anon_sym_SEMI,
    STATE(3562), 1,
      sym_preproc_split_procedure_body,
    STATE(3563), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10941), 1,
      sym_preproc_conditional_var_block,
    STATE(10942), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [247703] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14714), 1,
      anon_sym_SEMI,
    STATE(3564), 1,
      sym_preproc_split_procedure_body,
    STATE(3565), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10944), 1,
      sym_preproc_conditional_var_block,
    STATE(10945), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [247746] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14718), 6,
      sym_preproc_open,
      anon_sym_RPAREN,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14716), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [247773] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14722), 6,
      sym_preproc_open,
      anon_sym_RPAREN,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14720), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [247800] = 7,
    ACTIONS(14724), 1,
      sym_identifier,
    ACTIONS(14726), 1,
      sym_quoted_identifier,
    STATE(8774), 1,
      sym__namespaced_or_simple_ref,
    ACTIONS(14728), 2,
      sym_string_literal,
      sym_integer,
    STATE(7706), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [247835] = 9,
    ACTIONS(14730), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(7970), 1,
      sym_preproc_elif,
    STATE(8127), 1,
      aux_sym_preproc_conditional_var_block_repeat1,
    STATE(8992), 1,
      sym_preproc_else,
    STATE(11139), 1,
      sym_preproc_endif,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [247874] = 7,
    ACTIONS(14646), 1,
      sym_identifier,
    ACTIONS(14648), 1,
      sym_quoted_identifier,
    STATE(4828), 1,
      sym__namespaced_or_simple_ref,
    ACTIONS(14732), 2,
      sym_string_literal,
      sym_integer,
    STATE(5389), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4844), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [247909] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14734), 1,
      anon_sym_SEMI,
    STATE(5198), 1,
      sym_preproc_split_procedure_body,
    STATE(5204), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10632), 1,
      sym_preproc_conditional_var_block,
    STATE(10633), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [247952] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14738), 6,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14736), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [247979] = 4,
    ACTIONS(14702), 1,
      anon_sym_DOT,
    STATE(7738), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2444), 13,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_if_table_relation_token2,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [248008] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14740), 1,
      anon_sym_SEMI,
    STATE(6668), 1,
      sym_preproc_split_procedure_body,
    STATE(6679), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10482), 1,
      sym_preproc_conditional_var_block,
    STATE(10483), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [248051] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14742), 1,
      anon_sym_SEMI,
    STATE(5107), 1,
      sym_preproc_split_procedure_body,
    STATE(5108), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10535), 1,
      sym_preproc_conditional_var_block,
    STATE(10536), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [248094] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14744), 1,
      anon_sym_SEMI,
    STATE(4590), 1,
      sym_preproc_split_procedure_body,
    STATE(4591), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10501), 1,
      sym_preproc_conditional_var_block,
    STATE(10503), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [248137] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13977), 1,
      anon_sym_SEMI,
    STATE(5786), 1,
      sym_code_block,
    STATE(5862), 1,
      sym_preproc_split_procedure_body,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10705), 1,
      sym_preproc_conditional_var_block,
    STATE(10707), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [248180] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14005), 1,
      anon_sym_SEMI,
    STATE(5589), 1,
      sym_preproc_split_procedure_body,
    STATE(5655), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10710), 1,
      sym_preproc_conditional_var_block,
    STATE(10711), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [248223] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14746), 1,
      anon_sym_SEMI,
    STATE(4340), 1,
      sym_preproc_split_procedure_body,
    STATE(4341), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10427), 1,
      sym_preproc_conditional_var_block,
    STATE(10429), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [248266] = 7,
    ACTIONS(14748), 1,
      sym_identifier,
    ACTIONS(14750), 1,
      sym_quoted_identifier,
    STATE(1236), 1,
      sym__namespaced_or_simple_ref,
    ACTIONS(14752), 2,
      sym_string_literal,
      sym_integer,
    STATE(1193), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(834), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [248301] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14754), 1,
      anon_sym_SEMI,
    STATE(3987), 1,
      sym_preproc_split_procedure_body,
    STATE(3988), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10546), 1,
      sym_preproc_conditional_var_block,
    STATE(10549), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [248344] = 3,
    ACTIONS(8944), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8942), 14,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_key_keyword,
      sym_dataitem_keyword,
  [248371] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14756), 1,
      anon_sym_SEMI,
    STATE(6684), 1,
      sym_preproc_split_procedure_body,
    STATE(6685), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10484), 1,
      sym_preproc_conditional_var_block,
    STATE(10485), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [248414] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8942), 15,
      sym_preproc_close,
      aux_sym_where_condition_token1,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_key_keyword,
      sym_dataitem_keyword,
  [248439] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14758), 15,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_fieldgroup_keyword,
  [248464] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14760), 1,
      anon_sym_SEMI,
    STATE(3922), 1,
      sym_preproc_split_procedure_body,
    STATE(3923), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10887), 1,
      sym_preproc_conditional_var_block,
    STATE(10946), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [248507] = 7,
    ACTIONS(14762), 1,
      sym_identifier,
    ACTIONS(14764), 1,
      sym_quoted_identifier,
    STATE(7393), 1,
      sym__namespaced_or_simple_ref,
    ACTIONS(14766), 2,
      sym_string_literal,
      sym_integer,
    STATE(7239), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6601), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [248542] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14768), 1,
      anon_sym_SEMI,
    STATE(3941), 1,
      sym_preproc_split_procedure_body,
    STATE(3942), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10961), 1,
      sym_preproc_conditional_var_block,
    STATE(10962), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [248585] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14770), 1,
      anon_sym_SEMI,
    STATE(4556), 1,
      sym_preproc_split_procedure_body,
    STATE(4557), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(11028), 1,
      sym_preproc_conditional_var_block,
    STATE(11029), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [248628] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14774), 6,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14772), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [248655] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14776), 1,
      anon_sym_SEMI,
    STATE(4342), 1,
      sym_preproc_split_procedure_body,
    STATE(4343), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10356), 1,
      sym_preproc_conditional_var_block,
    STATE(10434), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [248698] = 7,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    STATE(11638), 1,
      sym__namespaced_or_simple_ref,
    ACTIONS(11763), 2,
      anon_sym_STAR,
      sym_integer,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [248733] = 7,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    STATE(4828), 1,
      sym__namespaced_or_simple_ref,
    ACTIONS(14732), 2,
      sym_string_literal,
      sym_integer,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [248768] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14780), 6,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14778), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [248795] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13979), 1,
      anon_sym_SEMI,
    STATE(3666), 1,
      sym_preproc_split_procedure_body,
    STATE(3668), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11025), 1,
      sym_preproc_conditional_var_block,
    STATE(11049), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [248838] = 5,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14411), 1,
      sym_dataitem_keyword,
    STATE(7719), 3,
      sym_report_dataitem,
      sym_attribute_item,
      aux_sym_preproc_conditional_dataset_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14782), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [248869] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14784), 15,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_fieldgroup_keyword,
  [248894] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14292), 6,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14786), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [248921] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13983), 1,
      anon_sym_SEMI,
    STATE(3672), 1,
      sym_preproc_split_procedure_body,
    STATE(3673), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11050), 1,
      sym_preproc_conditional_var_block,
    STATE(11051), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [248964] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14788), 1,
      anon_sym_SEMI,
    STATE(5789), 1,
      sym_preproc_split_procedure_body,
    STATE(5792), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10713), 1,
      sym_preproc_conditional_var_block,
    STATE(10714), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [249007] = 4,
    ACTIONS(14790), 1,
      anon_sym_DOT,
    STATE(7725), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2348), 13,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_temporary_keyword,
  [249036] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14792), 1,
      anon_sym_SEMI,
    STATE(3676), 1,
      sym_preproc_split_procedure_body,
    STATE(3677), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11058), 1,
      sym_preproc_conditional_var_block,
    STATE(11061), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [249079] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14070), 1,
      anon_sym_SEMI,
    STATE(3534), 1,
      sym_preproc_split_procedure_body,
    STATE(3535), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10789), 1,
      sym_preproc_conditional_var_block,
    STATE(10805), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [249122] = 7,
    ACTIONS(14794), 1,
      sym_identifier,
    ACTIONS(14796), 1,
      sym_quoted_identifier,
    STATE(6082), 1,
      sym__namespaced_or_simple_ref,
    ACTIONS(14798), 2,
      sym_string_literal,
      sym_integer,
    STATE(5670), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5399), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [249157] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14800), 15,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_fieldgroup_keyword,
  [249182] = 5,
    ACTIONS(14790), 1,
      anon_sym_DOT,
    ACTIONS(14802), 1,
      anon_sym_EQ,
    STATE(7725), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2348), 12,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [249213] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14804), 1,
      anon_sym_SEMI,
    STATE(6762), 1,
      sym_preproc_split_procedure_body,
    STATE(6763), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10365), 1,
      sym_preproc_conditional_var_block,
    STATE(10366), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [249256] = 11,
    ACTIONS(13929), 1,
      anon_sym_SEMI,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5273), 1,
      sym_preproc_split_procedure_body,
    STATE(5375), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10742), 1,
      sym_preproc_conditional_var_block,
    STATE(10747), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [249299] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13987), 1,
      anon_sym_SEMI,
    STATE(5185), 1,
      sym_preproc_split_procedure_body,
    STATE(5186), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10829), 1,
      sym_preproc_conditional_var_block,
    STATE(10830), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [249342] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14806), 1,
      anon_sym_SEMI,
    STATE(4079), 1,
      sym_preproc_split_procedure_body,
    STATE(4080), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10461), 1,
      sym_preproc_conditional_var_block,
    STATE(10462), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [249385] = 7,
    ACTIONS(14808), 1,
      sym_identifier,
    ACTIONS(14810), 1,
      sym_quoted_identifier,
    STATE(6857), 1,
      sym__namespaced_or_simple_ref,
    ACTIONS(14812), 2,
      sym_string_literal,
      sym_integer,
    STATE(6435), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5908), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [249420] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14814), 1,
      anon_sym_SEMI,
    STATE(5793), 1,
      sym_preproc_split_procedure_body,
    STATE(5794), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10717), 1,
      sym_preproc_conditional_var_block,
    STATE(10718), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [249463] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14816), 1,
      anon_sym_SEMI,
    STATE(6764), 1,
      sym_preproc_split_procedure_body,
    STATE(6765), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10367), 1,
      sym_preproc_conditional_var_block,
    STATE(10368), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [249506] = 5,
    ACTIONS(14818), 1,
      anon_sym_LBRACK,
    ACTIONS(14823), 1,
      sym_dataitem_keyword,
    STATE(7719), 3,
      sym_report_dataitem,
      sym_attribute_item,
      aux_sym_preproc_conditional_dataset_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14821), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [249537] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14826), 1,
      anon_sym_SEMI,
    STATE(5600), 1,
      sym_preproc_split_procedure_body,
    STATE(5618), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10647), 1,
      sym_preproc_conditional_var_block,
    STATE(10650), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [249580] = 7,
    ACTIONS(14828), 1,
      sym_identifier,
    ACTIONS(14830), 1,
      sym_quoted_identifier,
    STATE(2136), 1,
      sym__namespaced_or_simple_ref,
    ACTIONS(14832), 2,
      sym_string_literal,
      sym_integer,
    STATE(1982), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3431), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [249615] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14834), 1,
      anon_sym_SEMI,
    STATE(3705), 1,
      sym_preproc_split_procedure_body,
    STATE(3709), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10567), 1,
      sym_preproc_conditional_var_block,
    STATE(10587), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [249658] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14838), 6,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14836), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [249685] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13937), 1,
      anon_sym_SEMI,
    STATE(5379), 1,
      sym_preproc_split_procedure_body,
    STATE(5380), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10748), 1,
      sym_preproc_conditional_var_block,
    STATE(10749), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [249728] = 4,
    ACTIONS(14790), 1,
      anon_sym_DOT,
    STATE(7633), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2444), 13,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_temporary_keyword,
  [249757] = 9,
    ACTIONS(14579), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14581), 1,
      aux_sym_where_condition_token2,
    ACTIONS(14583), 1,
      aux_sym_where_condition_token3,
    ACTIONS(14587), 1,
      sym_filter_keyword,
    ACTIONS(14840), 1,
      sym_identifier,
    ACTIONS(14842), 1,
      sym_quoted_identifier,
    STATE(7556), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14585), 7,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [249796] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14844), 1,
      anon_sym_SEMI,
    STATE(6604), 1,
      sym_code_block,
    STATE(6787), 1,
      sym_preproc_split_procedure_body,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10414), 1,
      sym_preproc_conditional_var_block,
    STATE(10415), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [249839] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14846), 1,
      anon_sym_SEMI,
    STATE(5467), 1,
      sym_preproc_split_procedure_body,
    STATE(5468), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10612), 1,
      sym_preproc_conditional_var_block,
    STATE(10613), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [249882] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14850), 6,
      sym_preproc_open,
      anon_sym_RPAREN,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14848), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [249909] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14852), 1,
      anon_sym_SEMI,
    STATE(6388), 1,
      sym_code_block,
    STATE(6728), 1,
      sym_preproc_split_procedure_body,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10416), 1,
      sym_preproc_conditional_var_block,
    STATE(10417), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [249952] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13941), 1,
      anon_sym_SEMI,
    STATE(5121), 1,
      sym_preproc_split_procedure_body,
    STATE(5122), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10771), 1,
      sym_preproc_conditional_var_block,
    STATE(10772), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [249995] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14854), 15,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_fieldgroup_keyword,
  [250020] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14856), 1,
      anon_sym_SEMI,
    STATE(5621), 1,
      sym_preproc_split_procedure_body,
    STATE(5622), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10652), 1,
      sym_preproc_conditional_var_block,
    STATE(10653), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [250063] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14858), 1,
      anon_sym_SEMI,
    STATE(4564), 1,
      sym_preproc_split_procedure_body,
    STATE(4565), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(11047), 1,
      sym_preproc_conditional_var_block,
    STATE(11048), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [250106] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13973), 1,
      anon_sym_SEMI,
    STATE(5765), 1,
      sym_preproc_split_procedure_body,
    STATE(5767), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10692), 1,
      sym_preproc_conditional_var_block,
    STATE(10693), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [250149] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14860), 1,
      anon_sym_SEMI,
    STATE(4566), 1,
      sym_preproc_split_procedure_body,
    STATE(4567), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(11052), 1,
      sym_preproc_conditional_var_block,
    STATE(11053), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [250192] = 9,
    ACTIONS(14862), 1,
      anon_sym_SEMI,
    STATE(1503), 1,
      sym_preproc_elif,
    STATE(1752), 1,
      sym_preproc_else,
    STATE(7787), 1,
      aux_sym_preproc_conditional_table_relation_repeat1,
    STATE(8791), 1,
      sym_preproc_endif,
    ACTIONS(3072), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3074), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [250231] = 4,
    ACTIONS(14864), 1,
      anon_sym_DOT,
    STATE(7738), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2398), 13,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_if_table_relation_token2,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [250260] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14038), 1,
      anon_sym_SEMI,
    STATE(5136), 1,
      sym_preproc_split_procedure_body,
    STATE(5137), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10565), 1,
      sym_preproc_conditional_var_block,
    STATE(10566), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [250303] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14867), 1,
      anon_sym_SEMI,
    STATE(5625), 1,
      sym_preproc_split_procedure_body,
    STATE(5626), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10669), 1,
      sym_preproc_conditional_var_block,
    STATE(10670), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [250346] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14869), 1,
      anon_sym_SEMI,
    STATE(5469), 1,
      sym_preproc_split_procedure_body,
    STATE(5472), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10614), 1,
      sym_preproc_conditional_var_block,
    STATE(10615), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [250389] = 7,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    STATE(11338), 1,
      sym__namespaced_or_simple_ref,
    ACTIONS(11647), 2,
      anon_sym_STAR,
      sym_integer,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [250424] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14046), 1,
      anon_sym_SEMI,
    STATE(5141), 1,
      sym_preproc_split_procedure_body,
    STATE(5142), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10568), 1,
      sym_preproc_conditional_var_block,
    STATE(10569), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [250467] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14873), 6,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14871), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [250494] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14877), 6,
      sym_preproc_open,
      anon_sym_RPAREN,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14875), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [250521] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14879), 1,
      anon_sym_SEMI,
    STATE(5145), 1,
      sym_preproc_split_procedure_body,
    STATE(5146), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10571), 1,
      sym_preproc_conditional_var_block,
    STATE(10572), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [250564] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14881), 15,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_fieldgroup_keyword,
  [250589] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14883), 1,
      anon_sym_SEMI,
    STATE(6534), 1,
      sym_preproc_split_procedure_body,
    STATE(6535), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10450), 1,
      sym_preproc_conditional_var_block,
    STATE(10451), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [250632] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14887), 6,
      sym_preproc_open,
      anon_sym_RPAREN,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14885), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [250659] = 5,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14425), 1,
      sym_key_keyword,
    STATE(7751), 3,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_preproc_conditional_keys_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14889), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [250690] = 5,
    ACTIONS(14891), 1,
      anon_sym_LBRACK,
    ACTIONS(14896), 1,
      sym_key_keyword,
    STATE(7751), 3,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_preproc_conditional_keys_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14894), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [250721] = 7,
    ACTIONS(14899), 1,
      sym_identifier,
    ACTIONS(14901), 1,
      sym_quoted_identifier,
    STATE(2184), 1,
      sym__namespaced_or_simple_ref,
    ACTIONS(14903), 2,
      sym_string_literal,
      sym_integer,
    STATE(1984), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3456), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [250756] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14905), 1,
      anon_sym_SEMI,
    STATE(3991), 1,
      sym_preproc_split_procedure_body,
    STATE(3992), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10556), 1,
      sym_preproc_conditional_var_block,
    STATE(10557), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [250799] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14907), 1,
      anon_sym_SEMI,
    STATE(3999), 1,
      sym_preproc_split_procedure_body,
    STATE(4000), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10561), 1,
      sym_preproc_conditional_var_block,
    STATE(10562), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [250842] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13975), 1,
      anon_sym_SEMI,
    STATE(5819), 1,
      sym_preproc_split_procedure_body,
    STATE(5842), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10695), 1,
      sym_preproc_conditional_var_block,
    STATE(10696), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [250885] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14909), 1,
      anon_sym_SEMI,
    STATE(4592), 1,
      sym_preproc_split_procedure_body,
    STATE(4593), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10520), 1,
      sym_preproc_conditional_var_block,
    STATE(10523), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [250928] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14911), 1,
      anon_sym_SEMI,
    STATE(6591), 1,
      sym_preproc_split_procedure_body,
    STATE(6593), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10452), 1,
      sym_preproc_conditional_var_block,
    STATE(10453), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [250971] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14913), 1,
      anon_sym_SEMI,
    STATE(6643), 1,
      sym_preproc_split_procedure_body,
    STATE(6644), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10455), 1,
      sym_preproc_conditional_var_block,
    STATE(10456), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251014] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14915), 1,
      anon_sym_SEMI,
    STATE(3547), 1,
      sym_preproc_split_procedure_body,
    STATE(3548), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10506), 1,
      sym_preproc_conditional_var_block,
    STATE(10512), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251057] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14917), 1,
      anon_sym_SEMI,
    STATE(3549), 1,
      sym_preproc_split_procedure_body,
    STATE(3550), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10513), 1,
      sym_preproc_conditional_var_block,
    STATE(10515), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251100] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14919), 1,
      anon_sym_SEMI,
    STATE(6645), 1,
      sym_preproc_split_procedure_body,
    STATE(6646), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10457), 1,
      sym_preproc_conditional_var_block,
    STATE(10460), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251143] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14923), 6,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14921), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [251170] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14927), 6,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14925), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [251197] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14929), 1,
      anon_sym_SEMI,
    STATE(3678), 1,
      sym_preproc_split_procedure_body,
    STATE(3679), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11062), 1,
      sym_preproc_conditional_var_block,
    STATE(11088), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251240] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14931), 1,
      anon_sym_SEMI,
    STATE(5205), 1,
      sym_preproc_split_procedure_body,
    STATE(5206), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10638), 1,
      sym_preproc_conditional_var_block,
    STATE(10639), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251283] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14316), 6,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14933), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [251310] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(13945), 1,
      anon_sym_SEMI,
    STATE(5125), 1,
      sym_preproc_split_procedure_body,
    STATE(5126), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10773), 1,
      sym_preproc_conditional_var_block,
    STATE(10774), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251353] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14072), 1,
      anon_sym_SEMI,
    STATE(5790), 1,
      sym_preproc_split_procedure_body,
    STATE(5839), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10736), 1,
      sym_preproc_conditional_var_block,
    STATE(10737), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251396] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2398), 15,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_DOT,
      aux_sym_where_clause_token1,
      aux_sym_if_table_relation_token2,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_temporary_keyword,
  [251421] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14076), 1,
      anon_sym_SEMI,
    STATE(5518), 1,
      sym_preproc_split_procedure_body,
    STATE(5519), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10739), 1,
      sym_preproc_conditional_var_block,
    STATE(10740), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251464] = 7,
    ACTIONS(14935), 1,
      sym_identifier,
    ACTIONS(14937), 1,
      sym_quoted_identifier,
    STATE(1492), 1,
      sym__namespaced_or_simple_ref,
    ACTIONS(14939), 2,
      sym_string_literal,
      sym_integer,
    STATE(1423), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2945), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [251499] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14943), 6,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14941), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [251526] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14340), 6,
      sym_preproc_open,
      anon_sym_RPAREN,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(14945), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [251553] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14062), 1,
      anon_sym_SEMI,
    STATE(3604), 1,
      sym_preproc_split_procedure_body,
    STATE(3605), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10357), 1,
      sym_var_section,
    STATE(11092), 1,
      sym_preproc_conditional_var_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251596] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14068), 1,
      anon_sym_SEMI,
    STATE(3608), 1,
      sym_preproc_split_procedure_body,
    STATE(3609), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10363), 1,
      sym_preproc_conditional_var_block,
    STATE(10372), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251639] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14947), 1,
      anon_sym_SEMI,
    STATE(5129), 1,
      sym_preproc_split_procedure_body,
    STATE(5130), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10776), 1,
      sym_preproc_conditional_var_block,
    STATE(10777), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251682] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14949), 1,
      anon_sym_SEMI,
    STATE(4560), 1,
      sym_preproc_split_procedure_body,
    STATE(4561), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(11034), 1,
      sym_preproc_conditional_var_block,
    STATE(11035), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251725] = 11,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14028), 1,
      anon_sym_SEMI,
    STATE(3538), 1,
      sym_preproc_split_procedure_body,
    STATE(3539), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10831), 1,
      sym_preproc_conditional_var_block,
    STATE(10854), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251768] = 8,
    STATE(948), 1,
      sym_preproc_elif,
    STATE(1041), 1,
      sym_preproc_else,
    STATE(2496), 1,
      sym_preproc_endif,
    STATE(8520), 1,
      aux_sym_preproc_conditional_object_repeat1,
    ACTIONS(1547), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(1549), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251804] = 8,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(2685), 1,
      sym_preproc_else,
    STATE(3038), 1,
      sym_preproc_endif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(5512), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5514), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251840] = 7,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(7702), 1,
      sym_preproc_endif,
    STATE(7793), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(1551), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251874] = 8,
    STATE(7457), 1,
      sym_preproc_elif,
    STATE(7702), 1,
      sym_preproc_endif,
    STATE(7794), 1,
      sym_preproc_else,
    STATE(8331), 1,
      aux_sym_preproc_conditional_fieldgroups_repeat2,
    ACTIONS(1547), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(1549), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1551), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251910] = 8,
    STATE(4897), 1,
      sym_preproc_elif,
    STATE(5432), 1,
      sym_preproc_else,
    STATE(6894), 1,
      sym_preproc_endif,
    STATE(8334), 1,
      aux_sym_preproc_conditional_actions_repeat1,
    ACTIONS(11612), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(11614), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251946] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14951), 1,
      anon_sym_SEMI,
    STATE(3840), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10900), 1,
      sym_preproc_conditional_var_block,
    STATE(10905), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [251986] = 7,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(9012), 1,
      sym_preproc_endif,
    STATE(7469), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(14222), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252020] = 8,
    STATE(1503), 1,
      sym_preproc_elif,
    STATE(1756), 1,
      sym_preproc_else,
    STATE(7801), 1,
      aux_sym_preproc_conditional_table_relation_repeat1,
    STATE(8800), 1,
      sym_preproc_endif,
    ACTIONS(3072), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3074), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252056] = 8,
    STATE(1503), 1,
      sym_preproc_elif,
    STATE(1756), 1,
      sym_preproc_else,
    STATE(8449), 1,
      aux_sym_preproc_conditional_table_relation_repeat1,
    STATE(8800), 1,
      sym_preproc_endif,
    ACTIONS(3072), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3074), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252092] = 8,
    STATE(6281), 1,
      sym_preproc_elif,
    STATE(6831), 1,
      sym_preproc_else,
    STATE(6876), 1,
      sym_preproc_endif,
    STATE(8450), 1,
      aux_sym_preproc_conditional_permissions_repeat1,
    ACTIONS(12735), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(12737), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3439), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252128] = 8,
    STATE(7045), 1,
      sym_preproc_endif,
    STATE(7929), 1,
      aux_sym_preproc_split_field_repeat1,
    STATE(11157), 1,
      sym_preproc_elif,
    STATE(11166), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252164] = 8,
    STATE(3879), 1,
      sym_preproc_elif,
    STATE(4692), 1,
      sym_preproc_else,
    STATE(7125), 1,
      sym_preproc_endif,
    STATE(8349), 1,
      aux_sym_preproc_conditional_layout_repeat1,
    ACTIONS(9095), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(9097), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252200] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14955), 1,
      anon_sym_SEMI,
    STATE(3291), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10518), 1,
      sym_preproc_conditional_var_block,
    STATE(10519), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252240] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14957), 1,
      anon_sym_SEMI,
    STATE(3292), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10526), 1,
      sym_preproc_conditional_var_block,
    STATE(10544), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252280] = 7,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(7642), 1,
      sym_preproc_endif,
    STATE(7469), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(1551), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252314] = 7,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(7642), 1,
      sym_preproc_endif,
    STATE(7805), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(1551), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252348] = 8,
    STATE(7457), 1,
      sym_preproc_elif,
    STATE(7642), 1,
      sym_preproc_endif,
    STATE(7806), 1,
      sym_preproc_else,
    STATE(8331), 1,
      aux_sym_preproc_conditional_fieldgroups_repeat2,
    ACTIONS(1547), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(1549), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1551), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252384] = 8,
    STATE(4897), 1,
      sym_preproc_elif,
    STATE(5434), 1,
      sym_preproc_else,
    STATE(6951), 1,
      sym_preproc_endif,
    STATE(8334), 1,
      aux_sym_preproc_conditional_actions_repeat1,
    ACTIONS(11612), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(11614), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252420] = 7,
    ACTIONS(14652), 1,
      sym_identifier,
    ACTIONS(14654), 1,
      sym_quoted_identifier,
    ACTIONS(14959), 1,
      sym_integer,
    STATE(8841), 1,
      sym__namespaced_or_simple_ref,
    STATE(8232), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9358), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [252454] = 7,
    ACTIONS(14652), 1,
      sym_identifier,
    ACTIONS(14654), 1,
      sym_quoted_identifier,
    ACTIONS(14961), 1,
      sym_integer,
    STATE(8887), 1,
      sym__namespaced_or_simple_ref,
    STATE(8232), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9358), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [252488] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14963), 1,
      anon_sym_SEMI,
    STATE(3842), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10828), 1,
      sym_preproc_conditional_var_block,
    STATE(10875), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252528] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7416), 1,
      sym_preproc_if,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(3546), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10500), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252564] = 8,
    STATE(1503), 1,
      sym_preproc_elif,
    STATE(1763), 1,
      sym_preproc_else,
    STATE(8449), 1,
      aux_sym_preproc_conditional_table_relation_repeat1,
    STATE(8789), 1,
      sym_preproc_endif,
    ACTIONS(3072), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3074), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252600] = 8,
    STATE(7647), 1,
      sym_preproc_elif,
    STATE(8265), 1,
      sym_preproc_endif,
    STATE(8352), 1,
      aux_sym_preproc_conditional_dataset_repeat2,
    STATE(8863), 1,
      sym_preproc_else,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252636] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14965), 1,
      anon_sym_SEMI,
    STATE(3305), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10385), 1,
      sym_preproc_conditional_var_block,
    STATE(10388), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252676] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14967), 1,
      anon_sym_SEMI,
    STATE(3306), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10393), 1,
      sym_preproc_conditional_var_block,
    STATE(10419), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252716] = 7,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(7657), 1,
      sym_preproc_endif,
    STATE(7469), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(1551), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252750] = 7,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(7657), 1,
      sym_preproc_endif,
    STATE(7814), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(1551), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252784] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7416), 1,
      sym_preproc_if,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(3703), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10563), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252820] = 8,
    STATE(238), 1,
      sym_preproc_endif,
    STATE(7817), 1,
      aux_sym_preproc_split_if_statement_repeat1,
    STATE(9747), 1,
      sym_preproc_elif,
    STATE(9938), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252856] = 8,
    STATE(95), 1,
      sym_preproc_elif,
    STATE(126), 1,
      sym_preproc_else,
    STATE(1673), 1,
      sym_preproc_endif,
    STATE(8332), 1,
      aux_sym_preproc_conditional_statement_repeat1,
    ACTIONS(77), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(79), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252892] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14969), 1,
      anon_sym_SEMI,
    STATE(3825), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10756), 1,
      sym_preproc_conditional_var_block,
    STATE(10759), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252932] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7416), 1,
      sym_preproc_if,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(3665), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(11057), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [252968] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3522), 1,
      sym_preproc_split_procedure_body,
    STATE(3523), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10780), 1,
      sym_preproc_conditional_var_block,
    STATE(10781), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253008] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3526), 1,
      sym_preproc_split_procedure_body,
    STATE(3527), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10782), 1,
      sym_preproc_conditional_var_block,
    STATE(10783), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253048] = 7,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(7732), 1,
      sym_preproc_endif,
    STATE(7469), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(1551), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253082] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7422), 1,
      sym_preproc_if,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(3982), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10553), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253118] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7416), 1,
      sym_preproc_if,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(3553), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10940), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253154] = 8,
    STATE(243), 1,
      sym_preproc_endif,
    STATE(8700), 1,
      aux_sym_preproc_split_if_statement_repeat1,
    STATE(9305), 1,
      sym_preproc_else,
    STATE(9747), 1,
      sym_preproc_elif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253190] = 8,
    STATE(95), 1,
      sym_preproc_elif,
    STATE(128), 1,
      sym_preproc_else,
    STATE(1681), 1,
      sym_preproc_endif,
    STATE(8332), 1,
      aux_sym_preproc_conditional_statement_repeat1,
    ACTIONS(77), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(79), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253226] = 8,
    STATE(348), 1,
      sym_preproc_endif,
    STATE(8700), 1,
      aux_sym_preproc_split_if_statement_repeat1,
    STATE(9747), 1,
      sym_preproc_elif,
    STATE(9808), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253262] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(14971), 1,
      anon_sym_SEMI,
    STATE(4225), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10507), 1,
      sym_preproc_conditional_var_block,
    STATE(10508), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253302] = 8,
    STATE(95), 1,
      sym_preproc_elif,
    STATE(116), 1,
      sym_preproc_else,
    STATE(2383), 1,
      sym_preproc_endif,
    STATE(8332), 1,
      aux_sym_preproc_conditional_statement_repeat1,
    ACTIONS(77), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(79), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253338] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3584), 1,
      sym_preproc_split_procedure_body,
    STATE(3585), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11003), 1,
      sym_preproc_conditional_var_block,
    STATE(11008), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253378] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3588), 1,
      sym_preproc_split_procedure_body,
    STATE(3589), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11009), 1,
      sym_preproc_conditional_var_block,
    STATE(11012), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253418] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3595), 1,
      sym_preproc_split_procedure_body,
    STATE(3596), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11076), 1,
      sym_preproc_conditional_var_block,
    STATE(11083), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253458] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3599), 1,
      sym_preproc_split_procedure_body,
    STATE(3600), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(11084), 1,
      sym_preproc_conditional_var_block,
    STATE(11087), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253498] = 8,
    STATE(3449), 1,
      sym_preproc_else,
    STATE(3461), 1,
      sym_preproc_elif,
    STATE(8358), 1,
      aux_sym_preproc_split_declaration_repeat1,
    STATE(9713), 1,
      sym_preproc_endif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253534] = 8,
    STATE(2657), 1,
      sym_preproc_elif,
    STATE(2753), 1,
      sym_preproc_else,
    STATE(5851), 1,
      sym_preproc_endif,
    STATE(8417), 1,
      aux_sym_preproc_conditional_xmlport_repeat1,
    ACTIONS(5825), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5827), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253570] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3648), 1,
      sym_preproc_split_procedure_body,
    STATE(3649), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10487), 1,
      sym_preproc_conditional_var_block,
    STATE(10488), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253610] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3652), 1,
      sym_preproc_split_procedure_body,
    STATE(3653), 1,
      sym_code_block,
    STATE(7416), 1,
      sym_preproc_if,
    STATE(10489), 1,
      sym_preproc_conditional_var_block,
    STATE(10490), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253650] = 8,
    STATE(2657), 1,
      sym_preproc_elif,
    STATE(2751), 1,
      sym_preproc_else,
    STATE(5823), 1,
      sym_preproc_endif,
    STATE(8417), 1,
      aux_sym_preproc_conditional_xmlport_repeat1,
    ACTIONS(5825), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5827), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253686] = 7,
    ACTIONS(14973), 1,
      sym_identifier,
    ACTIONS(14975), 1,
      aux_sym_where_condition_token2,
    ACTIONS(14977), 1,
      sym_filter_keyword,
    ACTIONS(14979), 1,
      sym_quoted_identifier,
    STATE(11923), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [253720] = 8,
    STATE(2732), 1,
      sym_preproc_elif,
    STATE(3261), 1,
      sym_preproc_else,
    STATE(6043), 1,
      sym_preproc_endif,
    STATE(8571), 1,
      aux_sym_preproc_conditional_report_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253756] = 8,
    STATE(2680), 1,
      sym_preproc_elif,
    STATE(2790), 1,
      sym_preproc_else,
    STATE(5918), 1,
      sym_preproc_endif,
    STATE(8575), 1,
      aux_sym_preproc_conditional_query_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253792] = 8,
    STATE(262), 1,
      sym_preproc_endif,
    STATE(8628), 1,
      aux_sym_preproc_split_if_else_statement_repeat1,
    STATE(9941), 1,
      sym_preproc_elif,
    STATE(10279), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253828] = 8,
    STATE(263), 1,
      sym_preproc_endif,
    STATE(8628), 1,
      aux_sym_preproc_split_if_else_statement_repeat1,
    STATE(9941), 1,
      sym_preproc_elif,
    STATE(10280), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253864] = 8,
    STATE(2732), 1,
      sym_preproc_elif,
    STATE(3264), 1,
      sym_preproc_else,
    STATE(6134), 1,
      sym_preproc_endif,
    STATE(8571), 1,
      aux_sym_preproc_conditional_report_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253900] = 8,
    STATE(2680), 1,
      sym_preproc_elif,
    STATE(2799), 1,
      sym_preproc_else,
    STATE(5971), 1,
      sym_preproc_endif,
    STATE(8575), 1,
      aux_sym_preproc_conditional_query_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253936] = 8,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(2712), 1,
      sym_preproc_else,
    STATE(3823), 1,
      sym_preproc_endif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(5512), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5514), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [253972] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4042), 1,
      sym_preproc_split_procedure_body,
    STATE(4043), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10878), 1,
      sym_preproc_conditional_var_block,
    STATE(10879), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [254012] = 8,
    STATE(4874), 1,
      sym_preproc_endif,
    STATE(7842), 1,
      aux_sym_preproc_split_field_repeat1,
    STATE(11157), 1,
      sym_preproc_elif,
    STATE(11237), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [254048] = 8,
    STATE(3879), 1,
      sym_preproc_elif,
    STATE(4701), 1,
      sym_preproc_else,
    STATE(4979), 1,
      sym_preproc_endif,
    STATE(8349), 1,
      aux_sym_preproc_conditional_layout_repeat1,
    ACTIONS(9095), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(9097), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [254084] = 8,
    STATE(4880), 1,
      sym_preproc_endif,
    STATE(8518), 1,
      aux_sym_preproc_split_field_repeat1,
    STATE(11157), 1,
      sym_preproc_elif,
    STATE(11173), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [254120] = 8,
    STATE(3879), 1,
      sym_preproc_elif,
    STATE(4705), 1,
      sym_preproc_else,
    STATE(4985), 1,
      sym_preproc_endif,
    STATE(8349), 1,
      aux_sym_preproc_conditional_layout_repeat1,
    ACTIONS(9095), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(9097), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [254156] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4046), 1,
      sym_preproc_split_procedure_body,
    STATE(4047), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10884), 1,
      sym_preproc_conditional_var_block,
    STATE(10890), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [254196] = 7,
    ACTIONS(14981), 1,
      sym_identifier,
    ACTIONS(14983), 1,
      aux_sym_ml_value_list_token1,
    ACTIONS(14985), 1,
      sym_quoted_identifier,
    STATE(11216), 1,
      sym_ml_value_pair,
    STATE(12152), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [254230] = 8,
    STATE(948), 1,
      sym_preproc_elif,
    STATE(1048), 1,
      sym_preproc_else,
    STATE(1953), 1,
      sym_preproc_endif,
    STATE(8520), 1,
      aux_sym_preproc_conditional_object_repeat1,
    ACTIONS(1547), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(1549), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1551), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [254266] = 8,
    STATE(1503), 1,
      sym_preproc_elif,
    STATE(1753), 1,
      sym_preproc_else,
    STATE(8029), 1,
      aux_sym_preproc_conditional_table_relation_repeat1,
    STATE(11924), 1,
      sym_preproc_endif,
    ACTIONS(3072), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3074), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [254302] = 8,
    STATE(948), 1,
      sym_preproc_elif,
    STATE(1046), 1,
      sym_preproc_else,
    STATE(1959), 1,
      sym_preproc_endif,
    STATE(8520), 1,
      aux_sym_preproc_conditional_object_repeat1,
    ACTIONS(1547), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(1549), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1551), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [254338] = 8,
    STATE(1503), 1,
      sym_preproc_elif,
    STATE(1753), 1,
      sym_preproc_else,
    STATE(8449), 1,
      aux_sym_preproc_conditional_table_relation_repeat1,
    STATE(11924), 1,
      sym_preproc_endif,
    ACTIONS(3072), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3074), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [254374] = 8,
    STATE(948), 1,
      sym_preproc_elif,
    STATE(1044), 1,
      sym_preproc_else,
    STATE(1969), 1,
      sym_preproc_endif,
    STATE(8520), 1,
      aux_sym_preproc_conditional_object_repeat1,
    ACTIONS(1547), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(1549), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1551), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [254410] = 8,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14987), 1,
      anon_sym_RBRACE,
    ACTIONS(14989), 1,
      aux_sym_where_condition_token1,
    STATE(7294), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(8150), 5,
      sym_preproc_conditional_fields,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_fields_section_repeat1,
  [254446] = 7,
    ACTIONS(14794), 1,
      sym_identifier,
    ACTIONS(14796), 1,
      sym_quoted_identifier,
    ACTIONS(14991), 1,
      sym_integer,
    STATE(5960), 1,
      sym__namespaced_or_simple_ref,
    STATE(5670), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5399), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [254480] = 7,
    ACTIONS(14794), 1,
      sym_identifier,
    ACTIONS(14796), 1,
      sym_quoted_identifier,
    ACTIONS(14993), 1,
      sym_integer,
    STATE(6080), 1,
      sym__namespaced_or_simple_ref,
    STATE(5670), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5399), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [254514] = 8,
    ACTIONS(14995), 1,
      anon_sym_RBRACE,
    ACTIONS(14997), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(15001), 1,
      sym_fieldgroup_keyword,
    STATE(7242), 1,
      sym_preproc_if,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(8158), 5,
      sym_addlast_fieldgroup_modification,
      sym_addfirst_fieldgroup_modification,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_fieldgroups_section_repeat1,
  [254550] = 8,
    STATE(7227), 1,
      sym_preproc_elif,
    STATE(7426), 1,
      sym_preproc_else,
    STATE(7667), 1,
      sym_preproc_endif,
    STATE(8447), 1,
      aux_sym_preproc_conditional_link_values_repeat2,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [254586] = 8,
    STATE(6281), 1,
      sym_preproc_elif,
    STATE(6823), 1,
      sym_preproc_else,
    STATE(7249), 1,
      sym_preproc_endif,
    STATE(8450), 1,
      aux_sym_preproc_conditional_permissions_repeat1,
    ACTIONS(12735), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(12737), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3076), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [254622] = 8,
    STATE(7230), 1,
      sym_preproc_elif,
    STATE(7442), 1,
      sym_preproc_else,
    STATE(7699), 1,
      sym_preproc_endif,
    STATE(8453), 1,
      aux_sym_preproc_conditional_impl_values_repeat2,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [254658] = 4,
    ACTIONS(11742), 1,
      aux_sym_where_clause_token1,
    STATE(8500), 1,
      sym_where_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11740), 12,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_if_table_relation_token2,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [254686] = 7,
    ACTIONS(14935), 1,
      sym_identifier,
    ACTIONS(14937), 1,
      sym_quoted_identifier,
    ACTIONS(15003), 1,
      sym_integer,
    STATE(1429), 1,
      sym__namespaced_or_simple_ref,
    STATE(1423), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2945), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [254720] = 7,
    ACTIONS(14935), 1,
      sym_identifier,
    ACTIONS(14937), 1,
      sym_quoted_identifier,
    ACTIONS(15005), 1,
      sym_integer,
    STATE(1530), 1,
      sym__namespaced_or_simple_ref,
    STATE(1423), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2945), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [254754] = 8,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14989), 1,
      aux_sym_where_condition_token1,
    ACTIONS(15007), 1,
      anon_sym_RBRACE,
    STATE(7294), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7865), 5,
      sym_preproc_conditional_fields,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_fields_section_repeat1,
  [254790] = 8,
    ACTIONS(14997), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(15001), 1,
      sym_fieldgroup_keyword,
    ACTIONS(15009), 1,
      anon_sym_RBRACE,
    STATE(7242), 1,
      sym_preproc_if,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7866), 5,
      sym_addlast_fieldgroup_modification,
      sym_addfirst_fieldgroup_modification,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_fieldgroups_section_repeat1,
  [254826] = 8,
    STATE(3272), 1,
      sym_preproc_elif,
    STATE(3477), 1,
      sym_preproc_else,
    STATE(5117), 1,
      sym_preproc_endif,
    STATE(8345), 1,
      aux_sym_preproc_conditional_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [254862] = 8,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(2697), 1,
      sym_preproc_else,
    STATE(7489), 1,
      sym_preproc_endif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(5512), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5514), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [254898] = 8,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14989), 1,
      aux_sym_where_condition_token1,
    ACTIONS(15011), 1,
      anon_sym_RBRACE,
    STATE(7294), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(8150), 5,
      sym_preproc_conditional_fields,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_fields_section_repeat1,
  [254934] = 8,
    ACTIONS(14997), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(15001), 1,
      sym_fieldgroup_keyword,
    ACTIONS(15013), 1,
      anon_sym_RBRACE,
    STATE(7242), 1,
      sym_preproc_if,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(8158), 5,
      sym_addlast_fieldgroup_modification,
      sym_addfirst_fieldgroup_modification,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_fieldgroups_section_repeat1,
  [254970] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15015), 1,
      anon_sym_SEMI,
    STATE(3519), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10504), 1,
      sym_preproc_conditional_var_block,
    STATE(10505), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255010] = 8,
    STATE(3272), 1,
      sym_preproc_elif,
    STATE(3472), 1,
      sym_preproc_else,
    STATE(5371), 1,
      sym_preproc_endif,
    STATE(8345), 1,
      aux_sym_preproc_conditional_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255046] = 8,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(2699), 1,
      sym_preproc_else,
    STATE(7513), 1,
      sym_preproc_endif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(5512), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5514), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255082] = 8,
    STATE(4897), 1,
      sym_preproc_elif,
    STATE(5426), 1,
      sym_preproc_else,
    STATE(5915), 1,
      sym_preproc_endif,
    STATE(8334), 1,
      aux_sym_preproc_conditional_actions_repeat1,
    ACTIONS(11612), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(11614), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255118] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15017), 1,
      anon_sym_SEMI,
    STATE(3762), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10527), 1,
      sym_preproc_conditional_var_block,
    STATE(10528), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255158] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15019), 1,
      anon_sym_SEMI,
    STATE(5113), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10540), 1,
      sym_preproc_conditional_var_block,
    STATE(10541), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255198] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15021), 1,
      anon_sym_SEMI,
    STATE(5114), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10542), 1,
      sym_preproc_conditional_var_block,
    STATE(10543), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255238] = 8,
    STATE(4897), 1,
      sym_preproc_elif,
    STATE(5428), 1,
      sym_preproc_else,
    STATE(5927), 1,
      sym_preproc_endif,
    STATE(8334), 1,
      aux_sym_preproc_conditional_actions_repeat1,
    ACTIONS(11612), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(11614), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255274] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15023), 1,
      anon_sym_SEMI,
    STATE(3514), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10550), 1,
      sym_preproc_conditional_var_block,
    STATE(10552), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255314] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4070), 1,
      sym_preproc_split_procedure_body,
    STATE(4071), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10445), 1,
      sym_preproc_conditional_var_block,
    STATE(10446), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255354] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7453), 1,
      sym_preproc_if,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5106), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10534), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255390] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15025), 1,
      anon_sym_SEMI,
    STATE(5174), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10582), 1,
      sym_preproc_conditional_var_block,
    STATE(10583), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255430] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15027), 1,
      anon_sym_SEMI,
    STATE(5175), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10584), 1,
      sym_preproc_conditional_var_block,
    STATE(10585), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255470] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4074), 1,
      sym_preproc_split_procedure_body,
    STATE(4075), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10447), 1,
      sym_preproc_conditional_var_block,
    STATE(10448), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255510] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7453), 1,
      sym_preproc_if,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5197), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10631), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255546] = 7,
    ACTIONS(14808), 1,
      sym_identifier,
    ACTIONS(14810), 1,
      sym_quoted_identifier,
    ACTIONS(15029), 1,
      sym_integer,
    STATE(6806), 1,
      sym__namespaced_or_simple_ref,
    STATE(6435), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5908), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [255580] = 7,
    ACTIONS(14808), 1,
      sym_identifier,
    ACTIONS(14810), 1,
      sym_quoted_identifier,
    ACTIONS(15031), 1,
      sym_integer,
    STATE(6856), 1,
      sym__namespaced_or_simple_ref,
    STATE(6435), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5908), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [255614] = 8,
    STATE(272), 1,
      sym_preproc_endif,
    STATE(7895), 1,
      aux_sym_preproc_split_if_statement_repeat1,
    STATE(9366), 1,
      sym_preproc_else,
    STATE(9747), 1,
      sym_preproc_elif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255650] = 8,
    STATE(95), 1,
      sym_preproc_elif,
    STATE(149), 1,
      sym_preproc_else,
    STATE(1917), 1,
      sym_preproc_endif,
    STATE(8332), 1,
      aux_sym_preproc_conditional_statement_repeat1,
    ACTIONS(77), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(79), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255686] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15033), 1,
      anon_sym_SEMI,
    STATE(3630), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10694), 1,
      sym_preproc_conditional_var_block,
    STATE(10704), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255726] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7453), 1,
      sym_preproc_if,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5134), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10570), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255762] = 8,
    STATE(6365), 1,
      sym_preproc_endif,
    STATE(7913), 1,
      aux_sym_preproc_split_field_repeat1,
    STATE(11157), 1,
      sym_preproc_elif,
    STATE(11192), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(9129), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255798] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5214), 1,
      sym_preproc_split_procedure_body,
    STATE(5215), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10720), 1,
      sym_preproc_conditional_var_block,
    STATE(10735), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255838] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5231), 1,
      sym_preproc_split_procedure_body,
    STATE(5232), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10738), 1,
      sym_preproc_conditional_var_block,
    STATE(10741), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255878] = 8,
    STATE(3879), 1,
      sym_preproc_elif,
    STATE(4693), 1,
      sym_preproc_else,
    STATE(6382), 1,
      sym_preproc_endif,
    STATE(8349), 1,
      aux_sym_preproc_conditional_layout_repeat1,
    ACTIONS(9095), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(9097), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(9129), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255914] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15035), 1,
      anon_sym_SEMI,
    STATE(4345), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10472), 1,
      sym_preproc_conditional_var_block,
    STATE(10473), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255954] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15037), 1,
      anon_sym_SEMI,
    STATE(4346), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10475), 1,
      sym_preproc_conditional_var_block,
    STATE(10477), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [255994] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7453), 1,
      sym_preproc_if,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5120), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10775), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256030] = 8,
    STATE(277), 1,
      sym_preproc_endif,
    STATE(8700), 1,
      aux_sym_preproc_split_if_statement_repeat1,
    STATE(9368), 1,
      sym_preproc_else,
    STATE(9747), 1,
      sym_preproc_elif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256066] = 8,
    STATE(95), 1,
      sym_preproc_elif,
    STATE(102), 1,
      sym_preproc_else,
    STATE(1930), 1,
      sym_preproc_endif,
    STATE(8332), 1,
      aux_sym_preproc_conditional_statement_repeat1,
    ACTIONS(77), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(79), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256102] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5153), 1,
      sym_preproc_split_procedure_body,
    STATE(5154), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10792), 1,
      sym_preproc_conditional_var_block,
    STATE(10793), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256142] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5157), 1,
      sym_preproc_split_procedure_body,
    STATE(5158), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10796), 1,
      sym_preproc_conditional_var_block,
    STATE(10797), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256182] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15039), 1,
      anon_sym_SEMI,
    STATE(4010), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10719), 1,
      sym_preproc_conditional_var_block,
    STATE(10760), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256222] = 8,
    STATE(7546), 1,
      sym_preproc_elif,
    STATE(8479), 1,
      sym_preproc_else,
    STATE(8738), 1,
      aux_sym_preproc_conditional_fields_repeat2,
    STATE(9003), 1,
      sym_preproc_endif,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256258] = 8,
    STATE(7820), 1,
      sym_preproc_endif,
    STATE(8720), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8994), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256294] = 8,
    STATE(7659), 1,
      sym_preproc_elif,
    STATE(8762), 1,
      aux_sym_preproc_conditional_keys_repeat2,
    STATE(8852), 1,
      sym_preproc_else,
    STATE(9049), 1,
      sym_preproc_endif,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256330] = 7,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(9015), 1,
      sym_preproc_endif,
    STATE(7469), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(14222), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256364] = 7,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(9015), 1,
      sym_preproc_endif,
    STATE(8088), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(14222), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256398] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5176), 1,
      sym_preproc_split_procedure_body,
    STATE(5177), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10819), 1,
      sym_preproc_conditional_var_block,
    STATE(10822), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256438] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5180), 1,
      sym_preproc_split_procedure_body,
    STATE(5181), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10823), 1,
      sym_preproc_conditional_var_block,
    STATE(10825), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256478] = 8,
    STATE(7457), 1,
      sym_preproc_elif,
    STATE(8090), 1,
      sym_preproc_else,
    STATE(8331), 1,
      aux_sym_preproc_conditional_fieldgroups_repeat2,
    STATE(9015), 1,
      sym_preproc_endif,
    ACTIONS(1547), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(1549), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(14222), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256514] = 7,
    ACTIONS(14660), 1,
      sym_identifier,
    ACTIONS(14662), 1,
      sym_quoted_identifier,
    ACTIONS(15043), 1,
      sym_integer,
    STATE(1003), 1,
      sym__namespaced_or_simple_ref,
    STATE(957), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(283), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [256548] = 7,
    ACTIONS(14660), 1,
      sym_identifier,
    ACTIONS(14662), 1,
      sym_quoted_identifier,
    ACTIONS(15045), 1,
      sym_integer,
    STATE(1031), 1,
      sym__namespaced_or_simple_ref,
    STATE(957), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(283), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [256582] = 8,
    STATE(948), 1,
      sym_preproc_elif,
    STATE(1049), 1,
      sym_preproc_else,
    STATE(2534), 1,
      sym_preproc_endif,
    STATE(8520), 1,
      aux_sym_preproc_conditional_object_repeat1,
    ACTIONS(1547), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(1549), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256618] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5221), 1,
      sym_preproc_split_procedure_body,
    STATE(5222), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10869), 1,
      sym_preproc_conditional_var_block,
    STATE(10870), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256658] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5225), 1,
      sym_preproc_split_procedure_body,
    STATE(5226), 1,
      sym_code_block,
    STATE(7453), 1,
      sym_preproc_if,
    STATE(10871), 1,
      sym_preproc_conditional_var_block,
    STATE(10872), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256698] = 8,
    STATE(6370), 1,
      sym_preproc_endif,
    STATE(8518), 1,
      aux_sym_preproc_split_field_repeat1,
    STATE(11157), 1,
      sym_preproc_elif,
    STATE(11165), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(9129), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256734] = 8,
    STATE(3272), 1,
      sym_preproc_elif,
    STATE(3507), 1,
      sym_preproc_else,
    STATE(4011), 1,
      sym_preproc_endif,
    STATE(8345), 1,
      aux_sym_preproc_conditional_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256770] = 8,
    STATE(3879), 1,
      sym_preproc_elif,
    STATE(4714), 1,
      sym_preproc_else,
    STATE(6420), 1,
      sym_preproc_endif,
    STATE(8349), 1,
      aux_sym_preproc_conditional_layout_repeat1,
    ACTIONS(9095), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(9097), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(9129), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256806] = 8,
    STATE(4897), 1,
      sym_preproc_elif,
    STATE(5441), 1,
      sym_preproc_else,
    STATE(7308), 1,
      sym_preproc_endif,
    STATE(8334), 1,
      aux_sym_preproc_conditional_actions_repeat1,
    ACTIONS(11612), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(11614), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256842] = 8,
    STATE(295), 1,
      sym_preproc_endif,
    STATE(8628), 1,
      aux_sym_preproc_split_if_else_statement_repeat1,
    STATE(9941), 1,
      sym_preproc_elif,
    STATE(10293), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256878] = 8,
    STATE(296), 1,
      sym_preproc_endif,
    STATE(8628), 1,
      aux_sym_preproc_split_if_else_statement_repeat1,
    STATE(9941), 1,
      sym_preproc_elif,
    STATE(10294), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256914] = 8,
    STATE(3883), 1,
      sym_preproc_endif,
    STATE(7921), 1,
      aux_sym_preproc_split_field_repeat1,
    STATE(11157), 1,
      sym_preproc_elif,
    STATE(11238), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256950] = 8,
    STATE(3879), 1,
      sym_preproc_elif,
    STATE(4605), 1,
      sym_preproc_endif,
    STATE(4711), 1,
      sym_preproc_else,
    STATE(8349), 1,
      aux_sym_preproc_conditional_layout_repeat1,
    ACTIONS(9095), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(9097), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [256986] = 8,
    STATE(3872), 1,
      sym_preproc_endif,
    STATE(8518), 1,
      aux_sym_preproc_split_field_repeat1,
    STATE(11136), 1,
      sym_preproc_else,
    STATE(11157), 1,
      sym_preproc_elif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257022] = 8,
    STATE(3879), 1,
      sym_preproc_elif,
    STATE(4610), 1,
      sym_preproc_endif,
    STATE(4697), 1,
      sym_preproc_else,
    STATE(8349), 1,
      aux_sym_preproc_conditional_layout_repeat1,
    ACTIONS(9095), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(9097), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257058] = 7,
    ACTIONS(14899), 1,
      sym_identifier,
    ACTIONS(14901), 1,
      sym_quoted_identifier,
    ACTIONS(15047), 1,
      sym_integer,
    STATE(2119), 1,
      sym__namespaced_or_simple_ref,
    STATE(1984), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3456), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [257092] = 7,
    ACTIONS(14899), 1,
      sym_identifier,
    ACTIONS(14901), 1,
      sym_quoted_identifier,
    ACTIONS(15049), 1,
      sym_integer,
    STATE(2183), 1,
      sym__namespaced_or_simple_ref,
    STATE(1984), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3456), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [257126] = 8,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14989), 1,
      aux_sym_where_condition_token1,
    ACTIONS(15051), 1,
      anon_sym_RBRACE,
    STATE(7294), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7930), 5,
      sym_preproc_conditional_fields,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_fields_section_repeat1,
  [257162] = 8,
    ACTIONS(14997), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(15001), 1,
      sym_fieldgroup_keyword,
    ACTIONS(15053), 1,
      anon_sym_RBRACE,
    STATE(7242), 1,
      sym_preproc_if,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7931), 5,
      sym_addlast_fieldgroup_modification,
      sym_addfirst_fieldgroup_modification,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_fieldgroups_section_repeat1,
  [257198] = 8,
    STATE(3272), 1,
      sym_preproc_elif,
    STATE(3468), 1,
      sym_preproc_else,
    STATE(6711), 1,
      sym_preproc_endif,
    STATE(8345), 1,
      aux_sym_preproc_conditional_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257234] = 8,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(2683), 1,
      sym_preproc_else,
    STATE(7061), 1,
      sym_preproc_endif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(5512), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5514), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257270] = 8,
    STATE(7054), 1,
      sym_preproc_endif,
    STATE(8518), 1,
      aux_sym_preproc_split_field_repeat1,
    STATE(11157), 1,
      sym_preproc_elif,
    STATE(11215), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257306] = 8,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14989), 1,
      aux_sym_where_condition_token1,
    ACTIONS(15055), 1,
      anon_sym_RBRACE,
    STATE(7294), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(8150), 5,
      sym_preproc_conditional_fields,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_fields_section_repeat1,
  [257342] = 8,
    ACTIONS(14997), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(15001), 1,
      sym_fieldgroup_keyword,
    ACTIONS(15057), 1,
      anon_sym_RBRACE,
    STATE(7242), 1,
      sym_preproc_if,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(8158), 5,
      sym_addlast_fieldgroup_modification,
      sym_addfirst_fieldgroup_modification,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_fieldgroups_section_repeat1,
  [257378] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15059), 1,
      anon_sym_SEMI,
    STATE(3161), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11081), 1,
      sym_preproc_conditional_var_block,
    STATE(11082), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257418] = 8,
    STATE(3879), 1,
      sym_preproc_elif,
    STATE(4715), 1,
      sym_preproc_else,
    STATE(7104), 1,
      sym_preproc_endif,
    STATE(8349), 1,
      aux_sym_preproc_conditional_layout_repeat1,
    ACTIONS(9095), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(9097), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257454] = 8,
    STATE(3272), 1,
      sym_preproc_elif,
    STATE(3498), 1,
      sym_preproc_else,
    STATE(6748), 1,
      sym_preproc_endif,
    STATE(8345), 1,
      aux_sym_preproc_conditional_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257490] = 8,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(2665), 1,
      sym_preproc_else,
    STATE(7069), 1,
      sym_preproc_endif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(5512), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5514), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257526] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15061), 1,
      anon_sym_SEMI,
    STATE(3154), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10358), 1,
      sym_preproc_conditional_var_block,
    STATE(10359), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257566] = 8,
    STATE(7647), 1,
      sym_preproc_elif,
    STATE(8241), 1,
      sym_preproc_endif,
    STATE(8352), 1,
      aux_sym_preproc_conditional_dataset_repeat2,
    STATE(8880), 1,
      sym_preproc_else,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257602] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15063), 1,
      anon_sym_SEMI,
    STATE(7359), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10370), 1,
      sym_preproc_conditional_var_block,
    STATE(10371), 1,
      sym_var_section,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257642] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15065), 1,
      anon_sym_SEMI,
    STATE(7360), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10373), 1,
      sym_preproc_conditional_var_block,
    STATE(10374), 1,
      sym_var_section,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257682] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15067), 1,
      anon_sym_SEMI,
    STATE(3214), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10381), 1,
      sym_preproc_conditional_var_block,
    STATE(10382), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257722] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7466), 1,
      sym_preproc_if,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(6761), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10364), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257758] = 8,
    STATE(1375), 1,
      sym_preproc_elif,
    STATE(1391), 1,
      sym_preproc_else,
    STATE(5035), 1,
      sym_preproc_endif,
    STATE(8403), 1,
      aux_sym_preproc_conditional_layout_mixed_repeat2,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257794] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15069), 1,
      anon_sym_SEMI,
    STATE(7378), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10407), 1,
      sym_preproc_conditional_var_block,
    STATE(10408), 1,
      sym_var_section,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257834] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15071), 1,
      anon_sym_SEMI,
    STATE(7379), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10409), 1,
      sym_preproc_conditional_var_block,
    STATE(10410), 1,
      sym_var_section,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257874] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7466), 1,
      sym_preproc_if,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(6786), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10413), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257910] = 8,
    STATE(413), 1,
      sym_preproc_endif,
    STATE(7957), 1,
      aux_sym_preproc_split_if_statement_repeat1,
    STATE(9416), 1,
      sym_preproc_else,
    STATE(9747), 1,
      sym_preproc_elif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257946] = 8,
    STATE(95), 1,
      sym_preproc_elif,
    STATE(110), 1,
      sym_preproc_else,
    STATE(8332), 1,
      aux_sym_preproc_conditional_statement_repeat1,
    STATE(9984), 1,
      sym_preproc_endif,
    ACTIONS(77), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(79), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [257982] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15073), 1,
      anon_sym_SEMI,
    STATE(4418), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10677), 1,
      sym_preproc_conditional_var_block,
    STATE(10683), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258022] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15075), 1,
      anon_sym_SEMI,
    STATE(2912), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10422), 1,
      sym_preproc_conditional_var_block,
    STATE(10426), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258062] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7466), 1,
      sym_preproc_if,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(6772), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10396), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258098] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6402), 1,
      sym_preproc_split_procedure_body,
    STATE(6425), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10428), 1,
      sym_preproc_conditional_var_block,
    STATE(10430), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258138] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6433), 1,
      sym_preproc_split_procedure_body,
    STATE(6434), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10431), 1,
      sym_preproc_conditional_var_block,
    STATE(10432), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258178] = 8,
    STATE(3457), 1,
      sym_preproc_else,
    STATE(3461), 1,
      sym_preproc_elif,
    STATE(8358), 1,
      aux_sym_preproc_split_declaration_repeat1,
    STATE(9323), 1,
      sym_preproc_endif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258214] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7466), 1,
      sym_preproc_if,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(6509), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10454), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258250] = 8,
    STATE(3447), 1,
      sym_preproc_else,
    STATE(3461), 1,
      sym_preproc_elif,
    STATE(7826), 1,
      aux_sym_preproc_split_declaration_repeat1,
    STATE(9406), 1,
      sym_preproc_endif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258286] = 8,
    STATE(2657), 1,
      sym_preproc_elif,
    STATE(2759), 1,
      sym_preproc_else,
    STATE(6393), 1,
      sym_preproc_endif,
    STATE(8417), 1,
      aux_sym_preproc_conditional_xmlport_repeat1,
    ACTIONS(5825), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5827), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258322] = 8,
    STATE(417), 1,
      sym_preproc_endif,
    STATE(8700), 1,
      aux_sym_preproc_split_if_statement_repeat1,
    STATE(9420), 1,
      sym_preproc_else,
    STATE(9747), 1,
      sym_preproc_elif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258358] = 8,
    STATE(95), 1,
      sym_preproc_elif,
    STATE(112), 1,
      sym_preproc_else,
    STATE(8332), 1,
      aux_sym_preproc_conditional_statement_repeat1,
    STATE(10171), 1,
      sym_preproc_endif,
    ACTIONS(77), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(79), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258394] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6751), 1,
      sym_preproc_split_procedure_body,
    STATE(6752), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10467), 1,
      sym_preproc_conditional_var_block,
    STATE(10468), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258434] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6594), 1,
      sym_code_block,
    STATE(6771), 1,
      sym_preproc_split_procedure_body,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10469), 1,
      sym_preproc_conditional_var_block,
    STATE(10470), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258474] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4116), 1,
      sym_preproc_split_procedure_body,
    STATE(4118), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10951), 1,
      sym_preproc_conditional_var_block,
    STATE(10952), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258514] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6437), 1,
      sym_code_block,
    STATE(6757), 1,
      sym_preproc_split_procedure_body,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10476), 1,
      sym_preproc_conditional_var_block,
    STATE(10478), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258554] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6549), 1,
      sym_preproc_split_procedure_body,
    STATE(6569), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10479), 1,
      sym_preproc_conditional_var_block,
    STATE(10480), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258594] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4121), 1,
      sym_preproc_split_procedure_body,
    STATE(4122), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10964), 1,
      sym_preproc_conditional_var_block,
    STATE(10998), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258634] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6441), 1,
      sym_preproc_split_procedure_body,
    STATE(6443), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10492), 1,
      sym_preproc_conditional_var_block,
    STATE(10493), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258674] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6446), 1,
      sym_preproc_split_procedure_body,
    STATE(6447), 1,
      sym_code_block,
    STATE(7466), 1,
      sym_preproc_if,
    STATE(10494), 1,
      sym_preproc_conditional_var_block,
    STATE(10495), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258714] = 7,
    ACTIONS(14682), 1,
      sym_identifier,
    ACTIONS(14684), 1,
      sym_quoted_identifier,
    ACTIONS(15077), 1,
      sym_integer,
    STATE(1104), 1,
      sym__namespaced_or_simple_ref,
    STATE(1083), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(425), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [258748] = 7,
    ACTIONS(14682), 1,
      sym_identifier,
    ACTIONS(14684), 1,
      sym_quoted_identifier,
    ACTIONS(15079), 1,
      sym_integer,
    STATE(1141), 1,
      sym__namespaced_or_simple_ref,
    STATE(1083), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(425), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [258782] = 8,
    STATE(7970), 1,
      sym_preproc_elif,
    STATE(8127), 1,
      aux_sym_preproc_conditional_var_block_repeat1,
    STATE(8992), 1,
      sym_preproc_else,
    STATE(11139), 1,
      sym_preproc_endif,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258818] = 5,
    ACTIONS(14401), 1,
      sym_var_keyword,
    STATE(8914), 1,
      sym_var_section,
    ACTIONS(14403), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15081), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [258848] = 8,
    STATE(7970), 1,
      sym_preproc_elif,
    STATE(8543), 1,
      aux_sym_preproc_conditional_var_block_repeat1,
    STATE(8992), 1,
      sym_preproc_else,
    STATE(11139), 1,
      sym_preproc_endif,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258884] = 8,
    STATE(433), 1,
      sym_preproc_endif,
    STATE(8628), 1,
      aux_sym_preproc_split_if_else_statement_repeat1,
    STATE(9941), 1,
      sym_preproc_elif,
    STATE(10304), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258920] = 8,
    STATE(434), 1,
      sym_preproc_endif,
    STATE(8628), 1,
      aux_sym_preproc_split_if_else_statement_repeat1,
    STATE(9941), 1,
      sym_preproc_elif,
    STATE(10305), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [258956] = 7,
    ACTIONS(14762), 1,
      sym_identifier,
    ACTIONS(14764), 1,
      sym_quoted_identifier,
    ACTIONS(15083), 1,
      sym_integer,
    STATE(7350), 1,
      sym__namespaced_or_simple_ref,
    STATE(7239), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6601), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [258990] = 7,
    ACTIONS(14762), 1,
      sym_identifier,
    ACTIONS(14764), 1,
      sym_quoted_identifier,
    ACTIONS(15085), 1,
      sym_integer,
    STATE(7392), 1,
      sym__namespaced_or_simple_ref,
    STATE(7239), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6601), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [259024] = 8,
    STATE(2874), 1,
      sym_preproc_elif,
    STATE(3419), 1,
      sym_preproc_else,
    STATE(6896), 1,
      sym_preproc_endif,
    STATE(8371), 1,
      aux_sym_preproc_conditional_controladdin_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259060] = 8,
    STATE(1740), 1,
      sym_preproc_elif,
    STATE(2175), 1,
      sym_preproc_else,
    STATE(4641), 1,
      sym_preproc_endif,
    STATE(8081), 1,
      aux_sym_preproc_conditional_case_repeat2,
    ACTIONS(77), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(79), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259096] = 8,
    STATE(1740), 1,
      sym_preproc_elif,
    STATE(2175), 1,
      sym_preproc_else,
    STATE(4641), 1,
      sym_preproc_endif,
    STATE(8467), 1,
      aux_sym_preproc_conditional_case_repeat2,
    ACTIONS(77), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(79), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259132] = 8,
    STATE(2560), 1,
      sym_preproc_elif,
    STATE(2594), 1,
      sym_preproc_endif,
    STATE(2654), 1,
      sym_preproc_else,
    STATE(8469), 1,
      aux_sym_preproc_split_case_branch_repeat2,
    ACTIONS(5620), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5622), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259168] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7422), 1,
      sym_preproc_if,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(4333), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10412), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259204] = 8,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14989), 1,
      aux_sym_where_condition_token1,
    ACTIONS(15087), 1,
      anon_sym_RBRACE,
    STATE(7294), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7985), 5,
      sym_preproc_conditional_fields,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_fields_section_repeat1,
  [259240] = 8,
    ACTIONS(14997), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(15001), 1,
      sym_fieldgroup_keyword,
    ACTIONS(15089), 1,
      anon_sym_RBRACE,
    STATE(7242), 1,
      sym_preproc_if,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7986), 5,
      sym_addlast_fieldgroup_modification,
      sym_addfirst_fieldgroup_modification,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_fieldgroups_section_repeat1,
  [259276] = 8,
    STATE(3272), 1,
      sym_preproc_elif,
    STATE(3487), 1,
      sym_preproc_else,
    STATE(5732), 1,
      sym_preproc_endif,
    STATE(8345), 1,
      aux_sym_preproc_conditional_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259312] = 8,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(2691), 1,
      sym_preproc_else,
    STATE(7585), 1,
      sym_preproc_endif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(5512), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5514), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259348] = 8,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14989), 1,
      aux_sym_where_condition_token1,
    ACTIONS(15091), 1,
      anon_sym_RBRACE,
    STATE(7294), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(8150), 5,
      sym_preproc_conditional_fields,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_fields_section_repeat1,
  [259384] = 8,
    ACTIONS(14997), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(15001), 1,
      sym_fieldgroup_keyword,
    ACTIONS(15093), 1,
      anon_sym_RBRACE,
    STATE(7242), 1,
      sym_preproc_if,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(8158), 5,
      sym_addlast_fieldgroup_modification,
      sym_addfirst_fieldgroup_modification,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_fieldgroups_section_repeat1,
  [259420] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15095), 1,
      anon_sym_SEMI,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7509), 1,
      sym_code_block,
    STATE(10588), 1,
      sym_preproc_conditional_var_block,
    STATE(10589), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259460] = 8,
    STATE(3268), 1,
      sym_preproc_else,
    STATE(3461), 1,
      sym_preproc_elif,
    STATE(8168), 1,
      aux_sym_preproc_split_declaration_repeat1,
    STATE(12458), 1,
      sym_preproc_endif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(15099), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259496] = 8,
    STATE(3272), 1,
      sym_preproc_elif,
    STATE(3493), 1,
      sym_preproc_else,
    STATE(5781), 1,
      sym_preproc_endif,
    STATE(8345), 1,
      aux_sym_preproc_conditional_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259532] = 8,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(2693), 1,
      sym_preproc_else,
    STATE(7627), 1,
      sym_preproc_endif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(5512), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5514), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259568] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15101), 1,
      anon_sym_SEMI,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7504), 1,
      sym_code_block,
    STATE(10606), 1,
      sym_preproc_conditional_var_block,
    STATE(10607), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259608] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15103), 1,
      anon_sym_SEMI,
    STATE(6992), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10617), 1,
      sym_preproc_conditional_var_block,
    STATE(10618), 1,
      sym_var_section,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259648] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15105), 1,
      anon_sym_SEMI,
    STATE(6993), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10620), 1,
      sym_preproc_conditional_var_block,
    STATE(10621), 1,
      sym_var_section,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259688] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15107), 1,
      anon_sym_SEMI,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7551), 1,
      sym_code_block,
    STATE(10629), 1,
      sym_preproc_conditional_var_block,
    STATE(10630), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259728] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7413), 1,
      sym_preproc_if,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5466), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10611), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259764] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15109), 1,
      anon_sym_SEMI,
    STATE(6994), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10660), 1,
      sym_preproc_conditional_var_block,
    STATE(10661), 1,
      sym_var_section,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259804] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15111), 1,
      anon_sym_SEMI,
    STATE(6995), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10664), 1,
      sym_preproc_conditional_var_block,
    STATE(10665), 1,
      sym_var_section,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259844] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7413), 1,
      sym_preproc_if,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5624), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10667), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259880] = 8,
    STATE(380), 1,
      sym_preproc_endif,
    STATE(8005), 1,
      aux_sym_preproc_split_if_statement_repeat1,
    STATE(9469), 1,
      sym_preproc_else,
    STATE(9747), 1,
      sym_preproc_elif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259916] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15113), 1,
      anon_sym_SEMI,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7539), 1,
      sym_code_block,
    STATE(10684), 1,
      sym_preproc_conditional_var_block,
    STATE(10685), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259956] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7413), 1,
      sym_preproc_if,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5564), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10646), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [259992] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5660), 1,
      sym_preproc_split_procedure_body,
    STATE(5664), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10686), 1,
      sym_preproc_conditional_var_block,
    STATE(10687), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260032] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5683), 1,
      sym_preproc_split_procedure_body,
    STATE(5684), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10688), 1,
      sym_preproc_conditional_var_block,
    STATE(10691), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260072] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7413), 1,
      sym_preproc_if,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(5860), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(10712), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260108] = 8,
    STATE(385), 1,
      sym_preproc_endif,
    STATE(8700), 1,
      aux_sym_preproc_split_if_statement_repeat1,
    STATE(9471), 1,
      sym_preproc_else,
    STATE(9747), 1,
      sym_preproc_elif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260144] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5450), 1,
      sym_code_block,
    STATE(5841), 1,
      sym_preproc_split_procedure_body,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10726), 1,
      sym_preproc_conditional_var_block,
    STATE(10727), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260184] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5787), 1,
      sym_preproc_split_procedure_body,
    STATE(5788), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10728), 1,
      sym_preproc_conditional_var_block,
    STATE(10729), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260224] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5663), 1,
      sym_preproc_split_procedure_body,
    STATE(5753), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10730), 1,
      sym_preproc_conditional_var_block,
    STATE(10731), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260264] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5546), 1,
      sym_preproc_split_procedure_body,
    STATE(5547), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10743), 1,
      sym_preproc_conditional_var_block,
    STATE(10744), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260304] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5552), 1,
      sym_preproc_split_procedure_body,
    STATE(5553), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10745), 1,
      sym_preproc_conditional_var_block,
    STATE(10746), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260344] = 8,
    STATE(7225), 1,
      sym_preproc_elif,
    STATE(7427), 1,
      sym_preproc_else,
    STATE(7745), 1,
      sym_preproc_endif,
    STATE(8698), 1,
      aux_sym_preproc_conditional_where_repeat2,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260380] = 8,
    STATE(403), 1,
      sym_preproc_endif,
    STATE(8628), 1,
      aux_sym_preproc_split_if_else_statement_repeat1,
    STATE(9941), 1,
      sym_preproc_elif,
    STATE(10311), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260416] = 8,
    STATE(404), 1,
      sym_preproc_endif,
    STATE(8628), 1,
      aux_sym_preproc_split_if_else_statement_repeat1,
    STATE(9941), 1,
      sym_preproc_elif,
    STATE(10312), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260452] = 7,
    ACTIONS(14724), 1,
      sym_identifier,
    ACTIONS(14726), 1,
      sym_quoted_identifier,
    ACTIONS(15115), 1,
      sym_integer,
    STATE(8409), 1,
      sym__namespaced_or_simple_ref,
    STATE(7706), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [260486] = 7,
    ACTIONS(14724), 1,
      sym_identifier,
    ACTIONS(14726), 1,
      sym_quoted_identifier,
    ACTIONS(15117), 1,
      sym_integer,
    STATE(8808), 1,
      sym__namespaced_or_simple_ref,
    STATE(7706), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [260520] = 8,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(2704), 1,
      sym_preproc_else,
    STATE(4981), 1,
      sym_preproc_endif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(5512), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5514), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260556] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15119), 1,
      anon_sym_SEMI,
    STATE(7040), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10794), 1,
      sym_preproc_conditional_var_block,
    STATE(10795), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260596] = 8,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(2706), 1,
      sym_preproc_else,
    STATE(4998), 1,
      sym_preproc_endif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(5512), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5514), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260632] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15123), 1,
      anon_sym_SEMI,
    STATE(7090), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10809), 1,
      sym_preproc_conditional_var_block,
    STATE(10810), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260672] = 8,
    STATE(1375), 1,
      sym_preproc_elif,
    STATE(1388), 1,
      sym_preproc_else,
    STATE(5084), 1,
      sym_preproc_endif,
    STATE(8403), 1,
      aux_sym_preproc_conditional_layout_mixed_repeat2,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260708] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15125), 1,
      anon_sym_SEMI,
    STATE(6455), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10815), 1,
      sym_preproc_conditional_var_block,
    STATE(10816), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260748] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15127), 1,
      anon_sym_SEMI,
    STATE(6456), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10817), 1,
      sym_preproc_conditional_var_block,
    STATE(10818), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260788] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15129), 1,
      anon_sym_SEMI,
    STATE(7089), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10826), 1,
      sym_preproc_conditional_var_block,
    STATE(10827), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260828] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15131), 1,
      anon_sym_SEMI,
    STATE(6468), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10842), 1,
      sym_preproc_conditional_var_block,
    STATE(10845), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260868] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15133), 1,
      anon_sym_SEMI,
    STATE(6469), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10849), 1,
      sym_preproc_conditional_var_block,
    STATE(10850), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260908] = 8,
    STATE(305), 1,
      sym_preproc_endif,
    STATE(8028), 1,
      aux_sym_preproc_split_if_statement_repeat1,
    STATE(9496), 1,
      sym_preproc_else,
    STATE(9747), 1,
      sym_preproc_elif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260944] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15135), 1,
      anon_sym_SEMI,
    STATE(7042), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10855), 1,
      sym_preproc_conditional_var_block,
    STATE(10856), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [260984] = 8,
    STATE(310), 1,
      sym_preproc_endif,
    STATE(8700), 1,
      aux_sym_preproc_split_if_statement_repeat1,
    STATE(9498), 1,
      sym_preproc_else,
    STATE(9747), 1,
      sym_preproc_elif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261020] = 8,
    STATE(1503), 1,
      sym_preproc_elif,
    STATE(1760), 1,
      sym_preproc_else,
    STATE(8449), 1,
      aux_sym_preproc_conditional_table_relation_repeat1,
    STATE(12271), 1,
      sym_preproc_endif,
    ACTIONS(3072), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3074), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261056] = 8,
    STATE(328), 1,
      sym_preproc_endif,
    STATE(8628), 1,
      aux_sym_preproc_split_if_else_statement_repeat1,
    STATE(9941), 1,
      sym_preproc_elif,
    STATE(10318), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261092] = 8,
    STATE(329), 1,
      sym_preproc_endif,
    STATE(8628), 1,
      aux_sym_preproc_split_if_else_statement_repeat1,
    STATE(9941), 1,
      sym_preproc_elif,
    STATE(10319), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261128] = 8,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(2710), 1,
      sym_preproc_else,
    STATE(5471), 1,
      sym_preproc_endif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(5512), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5514), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261164] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15137), 1,
      anon_sym_SEMI,
    STATE(6394), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10881), 1,
      sym_preproc_conditional_var_block,
    STATE(10882), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261204] = 8,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(2667), 1,
      sym_preproc_else,
    STATE(5491), 1,
      sym_preproc_endif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(5512), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5514), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261240] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15139), 1,
      anon_sym_SEMI,
    STATE(6401), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10893), 1,
      sym_preproc_conditional_var_block,
    STATE(10894), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261280] = 7,
    ACTIONS(14981), 1,
      sym_identifier,
    ACTIONS(14985), 1,
      sym_quoted_identifier,
    ACTIONS(15141), 1,
      aux_sym_ml_value_list_token1,
    STATE(11216), 1,
      sym_ml_value_pair,
    STATE(12152), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [261314] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15143), 1,
      anon_sym_SEMI,
    STATE(5497), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10901), 1,
      sym_preproc_conditional_var_block,
    STATE(10902), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261354] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15145), 1,
      anon_sym_SEMI,
    STATE(5499), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10903), 1,
      sym_preproc_conditional_var_block,
    STATE(10904), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261394] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15147), 1,
      anon_sym_SEMI,
    STATE(6403), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10908), 1,
      sym_preproc_conditional_var_block,
    STATE(10909), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261434] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15149), 1,
      anon_sym_SEMI,
    STATE(5522), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10918), 1,
      sym_preproc_conditional_var_block,
    STATE(10919), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261474] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15151), 1,
      anon_sym_SEMI,
    STATE(5523), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10920), 1,
      sym_preproc_conditional_var_block,
    STATE(10921), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261514] = 8,
    STATE(2657), 1,
      sym_preproc_elif,
    STATE(2742), 1,
      sym_preproc_else,
    STATE(6592), 1,
      sym_preproc_endif,
    STATE(8417), 1,
      aux_sym_preproc_conditional_xmlport_repeat1,
    ACTIONS(5825), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5827), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261550] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15153), 1,
      anon_sym_SEMI,
    STATE(6414), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10925), 1,
      sym_preproc_conditional_var_block,
    STATE(10926), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261590] = 8,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(2671), 1,
      sym_preproc_else,
    STATE(4768), 1,
      sym_preproc_endif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(5512), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5514), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261626] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15155), 1,
      anon_sym_SEMI,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7581), 1,
      sym_code_block,
    STATE(10956), 1,
      sym_preproc_conditional_var_block,
    STATE(10957), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261666] = 8,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(2673), 1,
      sym_preproc_else,
    STATE(4770), 1,
      sym_preproc_endif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(5512), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5514), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261702] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15159), 1,
      anon_sym_SEMI,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7603), 1,
      sym_code_block,
    STATE(10967), 1,
      sym_preproc_conditional_var_block,
    STATE(10968), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261742] = 7,
    ACTIONS(15161), 1,
      sym_identifier,
    ACTIONS(15163), 1,
      aux_sym_where_condition_token2,
    ACTIONS(15165), 1,
      sym_filter_keyword,
    ACTIONS(15167), 1,
      sym_quoted_identifier,
    STATE(12384), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [261776] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15169), 1,
      anon_sym_SEMI,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7610), 1,
      sym_code_block,
    STATE(10973), 1,
      sym_preproc_conditional_var_block,
    STATE(10974), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261816] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15171), 1,
      anon_sym_SEMI,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7586), 1,
      sym_code_block,
    STATE(10982), 1,
      sym_preproc_conditional_var_block,
    STATE(10984), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261856] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15173), 1,
      anon_sym_SEMI,
    STATE(5008), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11001), 1,
      sym_preproc_conditional_var_block,
    STATE(11002), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261896] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15177), 1,
      anon_sym_SEMI,
    STATE(5029), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11006), 1,
      sym_preproc_conditional_var_block,
    STATE(11007), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261936] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15179), 1,
      anon_sym_SEMI,
    STATE(5033), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11010), 1,
      sym_preproc_conditional_var_block,
    STATE(11011), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [261976] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15181), 1,
      anon_sym_SEMI,
    STATE(5053), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11017), 1,
      sym_preproc_conditional_var_block,
    STATE(11018), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262016] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15183), 1,
      anon_sym_SEMI,
    STATE(5769), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11026), 1,
      sym_preproc_conditional_var_block,
    STATE(11027), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262056] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15187), 1,
      anon_sym_SEMI,
    STATE(5803), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11032), 1,
      sym_preproc_conditional_var_block,
    STATE(11033), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262096] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15189), 1,
      anon_sym_SEMI,
    STATE(5805), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11036), 1,
      sym_preproc_conditional_var_block,
    STATE(11037), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262136] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15191), 1,
      anon_sym_SEMI,
    STATE(5816), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11043), 1,
      sym_preproc_conditional_var_block,
    STATE(11044), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262176] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15193), 1,
      anon_sym_SEMI,
    STATE(5704), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11063), 1,
      sym_preproc_conditional_var_block,
    STATE(11064), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262216] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15195), 1,
      anon_sym_SEMI,
    STATE(5449), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11068), 1,
      sym_preproc_conditional_var_block,
    STATE(11069), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262256] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15197), 1,
      anon_sym_SEMI,
    STATE(5452), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11070), 1,
      sym_preproc_conditional_var_block,
    STATE(11071), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262296] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15199), 1,
      anon_sym_SEMI,
    STATE(5559), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11077), 1,
      sym_preproc_conditional_var_block,
    STATE(11078), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262336] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15201), 1,
      anon_sym_SEMI,
    STATE(4791), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11089), 1,
      sym_preproc_conditional_var_block,
    STATE(11090), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262376] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15205), 1,
      anon_sym_SEMI,
    STATE(4769), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11096), 1,
      sym_preproc_conditional_var_block,
    STATE(11097), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262416] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15207), 1,
      anon_sym_SEMI,
    STATE(4783), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11098), 1,
      sym_preproc_conditional_var_block,
    STATE(11099), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262456] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15209), 1,
      anon_sym_SEMI,
    STATE(4725), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11104), 1,
      sym_preproc_conditional_var_block,
    STATE(11107), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262496] = 8,
    STATE(8069), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8167), 1,
      sym_preproc_endif,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8997), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262532] = 8,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14989), 1,
      aux_sym_where_condition_token1,
    ACTIONS(15211), 1,
      anon_sym_RBRACE,
    STATE(7294), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7851), 5,
      sym_preproc_conditional_fields,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_fields_section_repeat1,
  [262568] = 8,
    STATE(7784), 1,
      sym_preproc_endif,
    STATE(8720), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8998), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262604] = 8,
    ACTIONS(14997), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(15001), 1,
      sym_fieldgroup_keyword,
    ACTIONS(15213), 1,
      anon_sym_RBRACE,
    STATE(7242), 1,
      sym_preproc_if,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7854), 5,
      sym_addlast_fieldgroup_modification,
      sym_addfirst_fieldgroup_modification,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_fieldgroups_section_repeat1,
  [262640] = 8,
    STATE(948), 1,
      sym_preproc_elif,
    STATE(1047), 1,
      sym_preproc_else,
    STATE(2522), 1,
      sym_preproc_endif,
    STATE(8520), 1,
      aux_sym_preproc_conditional_object_repeat1,
    ACTIONS(1547), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(1549), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262676] = 8,
    STATE(7227), 1,
      sym_preproc_elif,
    STATE(7418), 1,
      sym_preproc_else,
    STATE(7744), 1,
      sym_preproc_endif,
    STATE(8447), 1,
      aux_sym_preproc_conditional_link_values_repeat2,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262712] = 8,
    STATE(1503), 1,
      sym_preproc_elif,
    STATE(1749), 1,
      sym_preproc_else,
    STATE(8449), 1,
      aux_sym_preproc_conditional_table_relation_repeat1,
    STATE(12224), 1,
      sym_preproc_endif,
    ACTIONS(3072), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3074), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262748] = 8,
    STATE(6281), 1,
      sym_preproc_elif,
    STATE(6809), 1,
      sym_preproc_else,
    STATE(7244), 1,
      sym_preproc_endif,
    STATE(8450), 1,
      aux_sym_preproc_conditional_permissions_repeat1,
    ACTIONS(12735), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(12737), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3076), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262784] = 7,
    ACTIONS(15215), 1,
      sym_identifier,
    ACTIONS(15217), 1,
      aux_sym_where_condition_token2,
    ACTIONS(15219), 1,
      sym_filter_keyword,
    ACTIONS(15221), 1,
      sym_quoted_identifier,
    STATE(12218), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [262818] = 7,
    ACTIONS(14646), 1,
      sym_identifier,
    ACTIONS(14648), 1,
      sym_quoted_identifier,
    ACTIONS(15223), 1,
      sym_integer,
    STATE(5920), 1,
      sym__namespaced_or_simple_ref,
    STATE(5389), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4844), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [262852] = 7,
    ACTIONS(14646), 1,
      sym_identifier,
    ACTIONS(14648), 1,
      sym_quoted_identifier,
    ACTIONS(15225), 1,
      sym_integer,
    STATE(6003), 1,
      sym__namespaced_or_simple_ref,
    STATE(5389), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4844), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [262886] = 8,
    STATE(7230), 1,
      sym_preproc_elif,
    STATE(7455), 1,
      sym_preproc_else,
    STATE(7650), 1,
      sym_preproc_endif,
    STATE(8453), 1,
      aux_sym_preproc_conditional_impl_values_repeat2,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [262922] = 3,
    ACTIONS(15227), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15229), 13,
      sym_preproc_close,
      aux_sym_where_condition_token1,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [262948] = 7,
    ACTIONS(15231), 1,
      sym_identifier,
    ACTIONS(15233), 1,
      aux_sym_where_condition_token2,
    ACTIONS(15235), 1,
      sym_filter_keyword,
    ACTIONS(15237), 1,
      sym_quoted_identifier,
    STATE(12202), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [262982] = 8,
    STATE(1740), 1,
      sym_preproc_elif,
    STATE(2154), 1,
      sym_preproc_else,
    STATE(4685), 1,
      sym_preproc_endif,
    STATE(8467), 1,
      aux_sym_preproc_conditional_case_repeat2,
    ACTIONS(77), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(79), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263018] = 8,
    STATE(1740), 1,
      sym_preproc_elif,
    STATE(2154), 1,
      sym_preproc_else,
    STATE(4685), 1,
      sym_preproc_endif,
    STATE(8111), 1,
      aux_sym_preproc_conditional_case_repeat2,
    ACTIONS(77), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(79), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263054] = 8,
    STATE(2560), 1,
      sym_preproc_elif,
    STATE(2601), 1,
      sym_preproc_endif,
    STATE(2650), 1,
      sym_preproc_else,
    STATE(8469), 1,
      aux_sym_preproc_split_case_branch_repeat2,
    ACTIONS(5620), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5622), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263090] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15239), 1,
      anon_sym_SEMI,
    STATE(4575), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11105), 1,
      sym_preproc_conditional_var_block,
    STATE(11106), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263130] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15241), 1,
      anon_sym_SEMI,
    STATE(4576), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11108), 1,
      sym_preproc_conditional_var_block,
    STATE(11109), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263170] = 8,
    STATE(2560), 1,
      sym_preproc_elif,
    STATE(2659), 1,
      sym_preproc_else,
    STATE(4798), 1,
      sym_preproc_endif,
    STATE(8469), 1,
      aux_sym_preproc_split_case_branch_repeat2,
    ACTIONS(5620), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5622), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263206] = 8,
    STATE(7899), 1,
      sym_preproc_endif,
    STATE(7901), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8995), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263242] = 7,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(9016), 1,
      sym_preproc_endif,
    STATE(7469), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(14222), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263276] = 8,
    STATE(7867), 1,
      sym_preproc_endif,
    STATE(8091), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8999), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263312] = 7,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(9016), 1,
      sym_preproc_endif,
    STATE(7785), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(14222), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263346] = 8,
    STATE(7871), 1,
      sym_preproc_endif,
    STATE(8720), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8996), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263382] = 7,
    ACTIONS(14828), 1,
      sym_identifier,
    ACTIONS(14830), 1,
      sym_quoted_identifier,
    ACTIONS(15243), 1,
      sym_integer,
    STATE(2104), 1,
      sym__namespaced_or_simple_ref,
    STATE(1982), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3431), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [263416] = 7,
    ACTIONS(14828), 1,
      sym_identifier,
    ACTIONS(14830), 1,
      sym_quoted_identifier,
    ACTIONS(15245), 1,
      sym_integer,
    STATE(2176), 1,
      sym__namespaced_or_simple_ref,
    STATE(1982), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3431), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [263450] = 8,
    STATE(3272), 1,
      sym_preproc_elif,
    STATE(3506), 1,
      sym_preproc_else,
    STATE(4130), 1,
      sym_preproc_endif,
    STATE(8345), 1,
      aux_sym_preproc_conditional_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263486] = 8,
    STATE(2732), 1,
      sym_preproc_elif,
    STATE(3262), 1,
      sym_preproc_else,
    STATE(6880), 1,
      sym_preproc_endif,
    STATE(8571), 1,
      aux_sym_preproc_conditional_report_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263522] = 8,
    STATE(7932), 1,
      sym_preproc_endif,
    STATE(8097), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8966), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263558] = 8,
    STATE(7936), 1,
      sym_preproc_endif,
    STATE(8720), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8967), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263594] = 8,
    STATE(2680), 1,
      sym_preproc_elif,
    STATE(2776), 1,
      sym_preproc_else,
    STATE(6814), 1,
      sym_preproc_endif,
    STATE(8575), 1,
      aux_sym_preproc_conditional_query_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263630] = 7,
    ACTIONS(14646), 1,
      sym_identifier,
    ACTIONS(14648), 1,
      sym_quoted_identifier,
    ACTIONS(15247), 1,
      sym_integer,
    STATE(4736), 1,
      sym__namespaced_or_simple_ref,
    STATE(5389), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4844), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [263664] = 8,
    STATE(7987), 1,
      sym_preproc_endif,
    STATE(8102), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8968), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263700] = 7,
    ACTIONS(14646), 1,
      sym_identifier,
    ACTIONS(14648), 1,
      sym_quoted_identifier,
    ACTIONS(15249), 1,
      sym_integer,
    STATE(4827), 1,
      sym__namespaced_or_simple_ref,
    STATE(5389), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4844), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [263734] = 8,
    STATE(7991), 1,
      sym_preproc_endif,
    STATE(8720), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8969), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263770] = 8,
    STATE(8017), 1,
      sym_preproc_endif,
    STATE(8104), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8970), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263806] = 8,
    STATE(8019), 1,
      sym_preproc_endif,
    STATE(8720), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8971), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263842] = 7,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    ACTIONS(15251), 1,
      sym_integer,
    STATE(11491), 1,
      sym__namespaced_or_simple_ref,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [263876] = 8,
    STATE(572), 1,
      sym_preproc_endif,
    STATE(8628), 1,
      aux_sym_preproc_split_if_else_statement_repeat1,
    STATE(9941), 1,
      sym_preproc_elif,
    STATE(9948), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263912] = 8,
    STATE(573), 1,
      sym_preproc_endif,
    STATE(8628), 1,
      aux_sym_preproc_split_if_else_statement_repeat1,
    STATE(9941), 1,
      sym_preproc_elif,
    STATE(10090), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [263948] = 7,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    ACTIONS(15253), 1,
      sym_integer,
    STATE(12002), 1,
      sym__namespaced_or_simple_ref,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [263982] = 8,
    STATE(8033), 1,
      sym_preproc_endif,
    STATE(8110), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8972), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264018] = 8,
    STATE(8035), 1,
      sym_preproc_endif,
    STATE(8720), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8973), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264054] = 8,
    STATE(1740), 1,
      sym_preproc_elif,
    STATE(2193), 1,
      sym_preproc_else,
    STATE(4653), 1,
      sym_preproc_endif,
    STATE(8467), 1,
      aux_sym_preproc_conditional_case_repeat2,
    ACTIONS(77), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(79), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264090] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7422), 1,
      sym_preproc_if,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(4589), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(11022), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264126] = 8,
    STATE(8045), 1,
      sym_preproc_endif,
    STATE(8114), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8974), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264162] = 8,
    STATE(8047), 1,
      sym_preproc_endif,
    STATE(8720), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8975), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264198] = 8,
    STATE(2560), 1,
      sym_preproc_elif,
    STATE(2647), 1,
      sym_preproc_else,
    STATE(4808), 1,
      sym_preproc_endif,
    STATE(8469), 1,
      aux_sym_preproc_split_case_branch_repeat2,
    ACTIONS(5620), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5622), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264234] = 8,
    STATE(8051), 1,
      sym_preproc_endif,
    STATE(8117), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8976), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264270] = 8,
    STATE(8052), 1,
      sym_preproc_endif,
    STATE(8720), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8977), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264306] = 8,
    STATE(8055), 1,
      sym_preproc_endif,
    STATE(8119), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8978), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264342] = 8,
    STATE(8056), 1,
      sym_preproc_endif,
    STATE(8720), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8979), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264378] = 8,
    STATE(3448), 1,
      sym_preproc_else,
    STATE(3461), 1,
      sym_preproc_elif,
    STATE(7953), 1,
      aux_sym_preproc_split_declaration_repeat1,
    STATE(9719), 1,
      sym_preproc_endif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264414] = 8,
    STATE(8059), 1,
      sym_preproc_endif,
    STATE(8122), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8980), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264450] = 8,
    STATE(8060), 1,
      sym_preproc_endif,
    STATE(8720), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(9000), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264486] = 8,
    STATE(342), 1,
      sym_preproc_endif,
    STATE(7819), 1,
      aux_sym_preproc_split_if_statement_repeat1,
    STATE(9747), 1,
      sym_preproc_elif,
    STATE(9777), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264522] = 8,
    STATE(95), 1,
      sym_preproc_elif,
    STATE(105), 1,
      sym_preproc_else,
    STATE(2362), 1,
      sym_preproc_endif,
    STATE(8332), 1,
      aux_sym_preproc_conditional_statement_repeat1,
    ACTIONS(77), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(79), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264558] = 8,
    STATE(8063), 1,
      sym_preproc_endif,
    STATE(8126), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8982), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264594] = 8,
    STATE(8064), 1,
      sym_preproc_endif,
    STATE(8720), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    STATE(8983), 1,
      sym_preproc_else,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264630] = 8,
    STATE(7970), 1,
      sym_preproc_elif,
    STATE(8543), 1,
      aux_sym_preproc_conditional_var_block_repeat1,
    STATE(8981), 1,
      sym_preproc_else,
    STATE(11221), 1,
      sym_preproc_endif,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264666] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15255), 1,
      anon_sym_SEMI,
    STATE(4602), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10992), 1,
      sym_preproc_conditional_var_block,
    STATE(10993), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264706] = 8,
    STATE(3270), 1,
      sym_preproc_else,
    STATE(3461), 1,
      sym_preproc_elif,
    STATE(8130), 1,
      aux_sym_preproc_split_declaration_repeat1,
    STATE(12620), 1,
      sym_preproc_endif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(15099), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264742] = 8,
    STATE(3271), 1,
      sym_preproc_else,
    STATE(3461), 1,
      sym_preproc_elif,
    STATE(8358), 1,
      aux_sym_preproc_split_declaration_repeat1,
    STATE(11336), 1,
      sym_preproc_endif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(15099), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264778] = 8,
    STATE(2732), 1,
      sym_preproc_elif,
    STATE(3257), 1,
      sym_preproc_else,
    STATE(6851), 1,
      sym_preproc_endif,
    STATE(8571), 1,
      aux_sym_preproc_conditional_report_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264814] = 8,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(2677), 1,
      sym_preproc_else,
    STATE(3798), 1,
      sym_preproc_endif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(5512), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5514), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264850] = 8,
    STATE(2680), 1,
      sym_preproc_elif,
    STATE(2763), 1,
      sym_preproc_else,
    STATE(6805), 1,
      sym_preproc_endif,
    STATE(8575), 1,
      aux_sym_preproc_conditional_query_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264886] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7422), 1,
      sym_preproc_if,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(4555), 2,
      sym_preproc_split_procedure_body,
      sym_code_block,
    STATE(11040), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [264922] = 7,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    ACTIONS(15247), 1,
      sym_integer,
    STATE(4736), 1,
      sym__namespaced_or_simple_ref,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [264956] = 7,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    ACTIONS(15249), 1,
      sym_integer,
    STATE(4827), 1,
      sym__namespaced_or_simple_ref,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [264990] = 8,
    STATE(3453), 1,
      sym_preproc_else,
    STATE(3461), 1,
      sym_preproc_elif,
    STATE(8138), 1,
      aux_sym_preproc_split_declaration_repeat1,
    STATE(9607), 1,
      sym_preproc_endif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265026] = 8,
    STATE(3454), 1,
      sym_preproc_else,
    STATE(3461), 1,
      sym_preproc_elif,
    STATE(8358), 1,
      aux_sym_preproc_split_declaration_repeat1,
    STATE(9609), 1,
      sym_preproc_endif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265062] = 8,
    STATE(3455), 1,
      sym_preproc_else,
    STATE(3461), 1,
      sym_preproc_elif,
    STATE(8140), 1,
      aux_sym_preproc_split_declaration_repeat1,
    STATE(9610), 1,
      sym_preproc_endif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265098] = 8,
    STATE(3456), 1,
      sym_preproc_else,
    STATE(3461), 1,
      sym_preproc_elif,
    STATE(8358), 1,
      aux_sym_preproc_split_declaration_repeat1,
    STATE(9613), 1,
      sym_preproc_endif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265134] = 7,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    ACTIONS(15257), 1,
      sym_integer,
    STATE(11488), 1,
      sym__namespaced_or_simple_ref,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [265168] = 7,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    ACTIONS(15259), 1,
      sym_integer,
    STATE(11489), 1,
      sym__namespaced_or_simple_ref,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [265202] = 8,
    STATE(2560), 1,
      sym_preproc_elif,
    STATE(2606), 1,
      sym_preproc_endif,
    STATE(2661), 1,
      sym_preproc_else,
    STATE(8469), 1,
      aux_sym_preproc_split_case_branch_repeat2,
    ACTIONS(5620), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5622), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265238] = 8,
    STATE(2560), 1,
      sym_preproc_elif,
    STATE(2609), 1,
      sym_preproc_endif,
    STATE(2663), 1,
      sym_preproc_else,
    STATE(8469), 1,
      aux_sym_preproc_split_case_branch_repeat2,
    ACTIONS(5620), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5622), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265274] = 7,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    ACTIONS(15261), 1,
      sym_integer,
    STATE(11609), 1,
      sym__namespaced_or_simple_ref,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [265308] = 7,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    ACTIONS(15263), 1,
      sym_integer,
    STATE(11610), 1,
      sym__namespaced_or_simple_ref,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [265342] = 7,
    ACTIONS(11641), 1,
      sym_identifier,
    ACTIONS(11645), 1,
      sym_quoted_identifier,
    ACTIONS(15265), 1,
      sym_integer,
    STATE(11689), 1,
      sym__namespaced_or_simple_ref,
    STATE(4762), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [265376] = 8,
    STATE(7225), 1,
      sym_preproc_elif,
    STATE(7446), 1,
      sym_preproc_else,
    STATE(7729), 1,
      sym_preproc_endif,
    STATE(8698), 1,
      aux_sym_preproc_conditional_where_repeat2,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265412] = 8,
    STATE(7546), 1,
      sym_preproc_elif,
    STATE(8734), 1,
      sym_preproc_else,
    STATE(8738), 1,
      aux_sym_preproc_conditional_fields_repeat2,
    STATE(9023), 1,
      sym_preproc_endif,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265448] = 8,
    ACTIONS(15267), 1,
      anon_sym_RBRACE,
    ACTIONS(15269), 1,
      aux_sym_where_condition_token1,
    ACTIONS(15272), 1,
      anon_sym_LBRACK,
    ACTIONS(15275), 1,
      aux_sym_modify_modification_token1,
    STATE(7294), 1,
      sym_preproc_if,
    ACTIONS(15278), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(8150), 5,
      sym_preproc_conditional_fields,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_fields_section_repeat1,
  [265484] = 8,
    STATE(2874), 1,
      sym_preproc_elif,
    STATE(3418), 1,
      sym_preproc_else,
    STATE(6949), 1,
      sym_preproc_endif,
    STATE(8371), 1,
      aux_sym_preproc_conditional_controladdin_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265520] = 8,
    STATE(7659), 1,
      sym_preproc_elif,
    STATE(8762), 1,
      aux_sym_preproc_conditional_keys_repeat2,
    STATE(8953), 1,
      sym_preproc_else,
    STATE(9045), 1,
      sym_preproc_endif,
    ACTIONS(13899), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(13901), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265556] = 7,
    ACTIONS(14224), 1,
      sym_fieldgroup_keyword,
    STATE(7251), 1,
      sym_preproc_if,
    STATE(9032), 1,
      sym_preproc_endif,
    STATE(7903), 3,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_preproc_conditional_fieldgroups_repeat1,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(14222), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265590] = 8,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14989), 1,
      aux_sym_where_condition_token1,
    ACTIONS(15281), 1,
      anon_sym_RBRACE,
    STATE(7294), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(8165), 5,
      sym_preproc_conditional_fields,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_fields_section_repeat1,
  [265626] = 8,
    ACTIONS(14997), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(15001), 1,
      sym_fieldgroup_keyword,
    ACTIONS(15283), 1,
      anon_sym_RBRACE,
    STATE(7242), 1,
      sym_preproc_if,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(8166), 5,
      sym_addlast_fieldgroup_modification,
      sym_addfirst_fieldgroup_modification,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_fieldgroups_section_repeat1,
  [265662] = 8,
    STATE(7457), 1,
      sym_preproc_elif,
    STATE(7904), 1,
      sym_preproc_else,
    STATE(8331), 1,
      aux_sym_preproc_conditional_fieldgroups_repeat2,
    STATE(9032), 1,
      sym_preproc_endif,
    ACTIONS(1547), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(1549), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(14222), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265698] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3897), 1,
      sym_preproc_split_procedure_body,
    STATE(3898), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10602), 1,
      sym_preproc_conditional_var_block,
    STATE(10608), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265738] = 8,
    ACTIONS(15285), 1,
      anon_sym_RBRACE,
    ACTIONS(15287), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(15290), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(15296), 1,
      sym_fieldgroup_keyword,
    STATE(7242), 1,
      sym_preproc_if,
    ACTIONS(15293), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(8158), 5,
      sym_addlast_fieldgroup_modification,
      sym_addfirst_fieldgroup_modification,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_fieldgroups_section_repeat1,
  [265774] = 8,
    STATE(3272), 1,
      sym_preproc_elif,
    STATE(3508), 1,
      sym_preproc_else,
    STATE(3571), 1,
      sym_preproc_endif,
    STATE(8345), 1,
      aux_sym_preproc_conditional_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265810] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3894), 1,
      sym_preproc_split_procedure_body,
    STATE(3901), 1,
      sym_code_block,
    STATE(7422), 1,
      sym_preproc_if,
    STATE(10676), 1,
      sym_preproc_conditional_var_block,
    STATE(10680), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265850] = 7,
    ACTIONS(14748), 1,
      sym_identifier,
    ACTIONS(14750), 1,
      sym_quoted_identifier,
    ACTIONS(15299), 1,
      sym_integer,
    STATE(1202), 1,
      sym__namespaced_or_simple_ref,
    STATE(1193), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(834), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [265884] = 7,
    ACTIONS(14748), 1,
      sym_identifier,
    ACTIONS(14750), 1,
      sym_quoted_identifier,
    ACTIONS(15301), 1,
      sym_integer,
    STATE(1235), 1,
      sym__namespaced_or_simple_ref,
    STATE(1193), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(834), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [265918] = 8,
    STATE(2874), 1,
      sym_preproc_elif,
    STATE(3428), 1,
      sym_preproc_else,
    STATE(6264), 1,
      sym_preproc_endif,
    STATE(8371), 1,
      aux_sym_preproc_conditional_controladdin_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265954] = 8,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(2682), 1,
      sym_preproc_else,
    STATE(2958), 1,
      sym_preproc_endif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(5512), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(5514), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [265990] = 8,
    ACTIONS(11667), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(14989), 1,
      aux_sym_where_condition_token1,
    ACTIONS(15303), 1,
      anon_sym_RBRACE,
    STATE(7294), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(8150), 5,
      sym_preproc_conditional_fields,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_fields_section_repeat1,
  [266026] = 8,
    ACTIONS(14997), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(15001), 1,
      sym_fieldgroup_keyword,
    ACTIONS(15305), 1,
      anon_sym_RBRACE,
    STATE(7242), 1,
      sym_preproc_if,
    ACTIONS(7), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(8158), 5,
      sym_addlast_fieldgroup_modification,
      sym_addfirst_fieldgroup_modification,
      sym_preproc_conditional_fieldgroups,
      sym_fieldgroup_declaration,
      aux_sym_fieldgroups_section_repeat1,
  [266062] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    ACTIONS(15307), 1,
      anon_sym_SEMI,
    STATE(3806), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10389), 1,
      sym_preproc_conditional_var_block,
    STATE(10486), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266102] = 8,
    STATE(3256), 1,
      sym_preproc_else,
    STATE(3461), 1,
      sym_preproc_elif,
    STATE(8358), 1,
      aux_sym_preproc_split_declaration_repeat1,
    STATE(12129), 1,
      sym_preproc_endif,
    ACTIONS(119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(15099), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266138] = 8,
    STATE(3272), 1,
      sym_preproc_elif,
    STATE(3475), 1,
      sym_preproc_else,
    STATE(3729), 1,
      sym_preproc_endif,
    STATE(8345), 1,
      aux_sym_preproc_conditional_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266174] = 8,
    STATE(2874), 1,
      sym_preproc_elif,
    STATE(3396), 1,
      sym_preproc_else,
    STATE(6256), 1,
      sym_preproc_endif,
    STATE(8371), 1,
      aux_sym_preproc_conditional_controladdin_repeat1,
    ACTIONS(2877), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(2879), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266210] = 8,
    STATE(4897), 1,
      sym_preproc_elif,
    STATE(5439), 1,
      sym_preproc_else,
    STATE(7351), 1,
      sym_preproc_endif,
    STATE(8334), 1,
      aux_sym_preproc_conditional_actions_repeat1,
    ACTIONS(11612), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(11614), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266246] = 8,
    STATE(1503), 1,
      sym_preproc_elif,
    STATE(1752), 1,
      sym_preproc_else,
    STATE(8449), 1,
      aux_sym_preproc_conditional_table_relation_repeat1,
    STATE(8791), 1,
      sym_preproc_endif,
    ACTIONS(3072), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3074), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266282] = 8,
    STATE(6281), 1,
      sym_preproc_elif,
    STATE(6838), 1,
      sym_preproc_else,
    STATE(6882), 1,
      sym_preproc_endif,
    STATE(8450), 1,
      aux_sym_preproc_conditional_permissions_repeat1,
    ACTIONS(12735), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(12737), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3439), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266318] = 10,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5759), 1,
      sym_preproc_split_procedure_body,
    STATE(5777), 1,
      sym_code_block,
    STATE(7413), 1,
      sym_preproc_if,
    STATE(10733), 1,
      sym_preproc_conditional_var_block,
    STATE(10734), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266358] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4517), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10751), 1,
      sym_preproc_conditional_var_block,
    STATE(10764), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266395] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5597), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11079), 1,
      sym_preproc_conditional_var_block,
    STATE(11080), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266432] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6988), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10656), 1,
      sym_preproc_conditional_var_block,
    STATE(10657), 1,
      sym_var_section,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266469] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4792), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11093), 1,
      sym_preproc_conditional_var_block,
    STATE(11094), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266506] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6936), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10658), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266541] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3815), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10954), 1,
      sym_preproc_conditional_var_block,
    STATE(10955), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266578] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4719), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11100), 1,
      sym_preproc_conditional_var_block,
    STATE(11101), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266615] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4722), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11102), 1,
      sym_preproc_conditional_var_block,
    STATE(11103), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266652] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3290), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10517), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266687] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4730), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11110), 1,
      sym_preproc_conditional_var_block,
    STATE(11111), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266724] = 3,
    ACTIONS(15311), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15309), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [266749] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7557), 1,
      sym_code_block,
    STATE(10678), 1,
      sym_preproc_conditional_var_block,
    STATE(10679), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266786] = 3,
    ACTIONS(15315), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15313), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [266811] = 3,
    ACTIONS(15319), 4,
      anon_sym_LBRACE,
      sym_quoted_identifier,
      sym_string_literal,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15317), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [266836] = 3,
    ACTIONS(15323), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15321), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [266861] = 4,
    ACTIONS(15325), 1,
      anon_sym_COMMA,
    STATE(8203), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2356), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [266888] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3858), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10876), 1,
      sym_preproc_conditional_var_block,
    STATE(10886), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266925] = 4,
    ACTIONS(15325), 1,
      anon_sym_COMMA,
    STATE(8204), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2356), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [266952] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7363), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10439), 1,
      sym_preproc_conditional_var_block,
    STATE(10440), 1,
      sym_var_section,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [266989] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7361), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10441), 1,
      sym_preproc_conditional_var_block,
    STATE(10442), 1,
      sym_var_section,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [267026] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6920), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10697), 1,
      sym_preproc_conditional_var_block,
    STATE(10698), 1,
      sym_var_section,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [267063] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6923), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10699), 1,
      sym_preproc_conditional_var_block,
    STATE(10701), 1,
      sym_var_section,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [267100] = 3,
    ACTIONS(15329), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15327), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [267125] = 6,
    ACTIONS(15331), 1,
      sym_identifier,
    ACTIONS(15333), 1,
      sym_quoted_identifier,
    STATE(12452), 1,
      sym_field_list,
    STATE(10947), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [267156] = 6,
    ACTIONS(15331), 1,
      sym_identifier,
    ACTIONS(15333), 1,
      sym_quoted_identifier,
    STATE(12480), 1,
      sym_field_list,
    STATE(10947), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [267187] = 3,
    ACTIONS(15337), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15335), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [267212] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7525), 1,
      sym_code_block,
    STATE(10721), 1,
      sym_preproc_conditional_var_block,
    STATE(10722), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [267249] = 3,
    ACTIONS(15341), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15339), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [267274] = 4,
    ACTIONS(15343), 1,
      anon_sym_COMMA,
    STATE(8203), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2405), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [267301] = 4,
    ACTIONS(15325), 1,
      anon_sym_COMMA,
    STATE(8203), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2412), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [267328] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4569), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11054), 1,
      sym_preproc_conditional_var_block,
    STATE(11056), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [267365] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3851), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10917), 1,
      sym_preproc_conditional_var_block,
    STATE(10934), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [267402] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3775), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10668), 1,
      sym_preproc_conditional_var_block,
    STATE(10672), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [267439] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4572), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11059), 1,
      sym_preproc_conditional_var_block,
    STATE(11060), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [267476] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3961), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10994), 1,
      sym_preproc_conditional_var_block,
    STATE(10995), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [267513] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4568), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(11066), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [267548] = 6,
    ACTIONS(15346), 1,
      sym_identifier,
    ACTIONS(15348), 1,
      sym_filter_keyword,
    ACTIONS(15350), 1,
      sym_quoted_identifier,
    STATE(11939), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [267579] = 4,
    ACTIONS(15354), 1,
      anon_sym_COMMA,
    STATE(8244), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15352), 11,
      sym_preproc_close,
      anon_sym_LBRACE,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [267606] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3319), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10865), 1,
      sym_preproc_conditional_var_block,
    STATE(10866), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [267643] = 4,
    ACTIONS(15325), 1,
      anon_sym_COMMA,
    STATE(8190), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(374), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [267670] = 6,
    ACTIONS(15331), 1,
      sym_identifier,
    ACTIONS(15333), 1,
      sym_quoted_identifier,
    STATE(12093), 1,
      sym_field_list,
    STATE(10947), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [267701] = 6,
    ACTIONS(15331), 1,
      sym_identifier,
    ACTIONS(15333), 1,
      sym_quoted_identifier,
    STATE(11333), 1,
      sym_field_list,
    STATE(10947), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [267732] = 6,
    ACTIONS(15331), 1,
      sym_identifier,
    ACTIONS(15333), 1,
      sym_quoted_identifier,
    STATE(11954), 1,
      sym_field_list,
    STATE(10947), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [267763] = 6,
    ACTIONS(15331), 1,
      sym_identifier,
    ACTIONS(15333), 1,
      sym_quoted_identifier,
    STATE(11970), 1,
      sym_field_list,
    STATE(10947), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [267794] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9571), 13,
      sym_preproc_close,
      aux_sym_where_condition_token1,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [267817] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(2966), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10464), 1,
      sym_preproc_conditional_var_block,
    STATE(10466), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [267854] = 3,
    ACTIONS(15358), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15356), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [267879] = 3,
    ACTIONS(15362), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15360), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [267904] = 5,
    ACTIONS(15364), 1,
      anon_sym_LBRACE,
    ACTIONS(15368), 1,
      sym_implements_keyword,
    STATE(8783), 1,
      sym_implements_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15366), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [267933] = 3,
    ACTIONS(15372), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15370), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [267958] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5098), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10750), 1,
      sym_preproc_conditional_var_block,
    STATE(10752), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [267995] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7087), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10806), 1,
      sym_preproc_conditional_var_block,
    STATE(10807), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [268032] = 3,
    ACTIONS(15374), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13090), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [268057] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5101), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10753), 1,
      sym_preproc_conditional_var_block,
    STATE(10754), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [268094] = 3,
    ACTIONS(15378), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15376), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [268119] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6453), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10814), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [268154] = 5,
    ACTIONS(15368), 1,
      sym_implements_keyword,
    ACTIONS(15380), 1,
      anon_sym_LBRACE,
    STATE(8785), 1,
      sym_implements_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15366), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [268183] = 4,
    ACTIONS(15382), 1,
      anon_sym_DOT,
    STATE(8252), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2348), 11,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
      sym_temporary_keyword,
  [268210] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4344), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10465), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [268245] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7046), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10834), 1,
      sym_preproc_conditional_var_block,
    STATE(10835), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [268282] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15384), 13,
      sym_preproc_close,
      aux_sym_where_condition_token1,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [268305] = 3,
    ACTIONS(15388), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15386), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [268330] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6462), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10836), 1,
      sym_preproc_conditional_var_block,
    STATE(10837), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [268367] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6465), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10838), 1,
      sym_preproc_conditional_var_block,
    STATE(10839), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [268404] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6461), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10840), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [268439] = 3,
    ACTIONS(15392), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15390), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [268464] = 3,
    ACTIONS(15396), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15394), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [268489] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9787), 13,
      sym_preproc_close,
      aux_sym_where_condition_token1,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [268512] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7064), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10852), 1,
      sym_preproc_conditional_var_block,
    STATE(10853), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [268549] = 4,
    ACTIONS(15400), 1,
      anon_sym_COMMA,
    STATE(8244), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15398), 11,
      sym_preproc_close,
      anon_sym_LBRACE,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [268576] = 6,
    ACTIONS(14981), 1,
      sym_identifier,
    ACTIONS(14985), 1,
      sym_quoted_identifier,
    STATE(11216), 1,
      sym_ml_value_pair,
    STATE(12152), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [268607] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3322), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10867), 1,
      sym_preproc_conditional_var_block,
    STATE(10868), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [268644] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6476), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10857), 1,
      sym_preproc_conditional_var_block,
    STATE(10858), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [268681] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6479), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10859), 1,
      sym_preproc_conditional_var_block,
    STATE(10861), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [268718] = 3,
    ACTIONS(15405), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15403), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [268743] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7095), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10863), 1,
      sym_preproc_conditional_var_block,
    STATE(10864), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [268780] = 3,
    ACTIONS(15407), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13036), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [268805] = 4,
    ACTIONS(15382), 1,
      anon_sym_DOT,
    STATE(8324), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2444), 11,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
      sym_temporary_keyword,
  [268832] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4594), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10597), 1,
      sym_preproc_conditional_var_block,
    STATE(10619), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [268869] = 4,
    ACTIONS(15354), 1,
      anon_sym_COMMA,
    STATE(8212), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15409), 11,
      sym_preproc_close,
      anon_sym_LBRACE,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [268896] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3614), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10787), 1,
      sym_preproc_conditional_var_block,
    STATE(10788), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [268933] = 3,
    ACTIONS(15413), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15411), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [268958] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15415), 13,
      sym_preproc_close,
      aux_sym_where_condition_token1,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [268981] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5463), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11074), 1,
      sym_preproc_conditional_var_block,
    STATE(11075), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269018] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6937), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10654), 1,
      sym_preproc_conditional_var_block,
    STATE(10655), 1,
      sym_var_section,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269055] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6398), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10891), 1,
      sym_preproc_conditional_var_block,
    STATE(10892), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269092] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3143), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10779), 1,
      sym_var_section,
    STATE(11113), 1,
      sym_preproc_conditional_var_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269129] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3299), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10360), 1,
      sym_preproc_conditional_var_block,
    STATE(10375), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269166] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5496), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10899), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269201] = 5,
    ACTIONS(15417), 1,
      sym_identifier,
    ACTIONS(15419), 2,
      sym_quoted_identifier,
      sym_string_literal,
    STATE(11731), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [269230] = 3,
    ACTIONS(15423), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15421), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [269255] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5112), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10539), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269290] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7358), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10369), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269325] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6406), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10910), 1,
      sym_preproc_conditional_var_block,
    STATE(10911), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269362] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5513), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10912), 1,
      sym_preproc_conditional_var_block,
    STATE(10913), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269399] = 6,
    ACTIONS(15425), 1,
      sym_identifier,
    ACTIONS(15427), 1,
      sym_filter_keyword,
    ACTIONS(15429), 1,
      sym_quoted_identifier,
    STATE(12210), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [269430] = 6,
    ACTIONS(15431), 1,
      sym_identifier,
    ACTIONS(15433), 1,
      sym_filter_keyword,
    ACTIONS(15435), 1,
      sym_quoted_identifier,
    STATE(12306), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [269461] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5516), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10914), 1,
      sym_preproc_conditional_var_block,
    STATE(10915), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269498] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5510), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10916), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269533] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4026), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10767), 1,
      sym_preproc_conditional_var_block,
    STATE(10768), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269570] = 3,
    ACTIONS(15439), 1,
      aux_sym_add_dataset_modification_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15437), 12,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_dataitem_keyword,
  [269595] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3864), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10643), 1,
      sym_preproc_conditional_var_block,
    STATE(10659), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269632] = 6,
    ACTIONS(15441), 1,
      sym_identifier,
    ACTIONS(15443), 1,
      sym_quoted_identifier,
    STATE(11414), 1,
      sym__trigger_name,
    STATE(11168), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [269663] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6411), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10923), 1,
      sym_preproc_conditional_var_block,
    STATE(10924), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269700] = 3,
    ACTIONS(15445), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15447), 12,
      sym_preproc_close,
      anon_sym_LBRACK,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_key_keyword,
  [269725] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5533), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10927), 1,
      sym_preproc_conditional_var_block,
    STATE(10928), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269762] = 5,
    ACTIONS(15449), 1,
      sym_identifier,
    ACTIONS(15451), 2,
      sym_quoted_identifier,
      sym_string_literal,
    STATE(11437), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [269791] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5549), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10929), 1,
      sym_preproc_conditional_var_block,
    STATE(10930), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269828] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6422), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10932), 1,
      sym_preproc_conditional_var_block,
    STATE(10933), 1,
      sym_var_section,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269865] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(2870), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10386), 1,
      sym_preproc_conditional_var_block,
    STATE(10387), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269902] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(4220), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10496), 1,
      sym_preproc_conditional_var_block,
    STATE(10497), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269939] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3302), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10376), 1,
      sym_preproc_conditional_var_block,
    STATE(10378), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [269976] = 6,
    ACTIONS(15441), 1,
      sym_identifier,
    ACTIONS(15443), 1,
      sym_quoted_identifier,
    STATE(11558), 1,
      sym__trigger_name,
    STATE(11168), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [270007] = 5,
    ACTIONS(15453), 1,
      sym_identifier,
    ACTIONS(15455), 2,
      sym_quoted_identifier,
      sym_string_literal,
    STATE(11570), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [270036] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7598), 1,
      sym_code_block,
    STATE(10965), 1,
      sym_preproc_conditional_var_block,
    STATE(10966), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270073] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7372), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10401), 1,
      sym_preproc_conditional_var_block,
    STATE(10402), 1,
      sym_var_section,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270110] = 6,
    ACTIONS(15441), 1,
      sym_identifier,
    ACTIONS(15443), 1,
      sym_quoted_identifier,
    STATE(11654), 1,
      sym__trigger_name,
    STATE(11168), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [270141] = 5,
    ACTIONS(15457), 1,
      sym_identifier,
    ACTIONS(15459), 2,
      sym_quoted_identifier,
      sym_string_literal,
    STATE(11663), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [270170] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7375), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10403), 1,
      sym_preproc_conditional_var_block,
    STATE(10404), 1,
      sym_var_section,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270207] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2268), 13,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
      sym_temporary_keyword,
  [270230] = 6,
    ACTIONS(15441), 1,
      sym_identifier,
    ACTIONS(15443), 1,
      sym_quoted_identifier,
    STATE(11732), 1,
      sym__trigger_name,
    STATE(11168), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [270261] = 5,
    ACTIONS(15461), 1,
      sym_identifier,
    ACTIONS(15463), 2,
      sym_quoted_identifier,
      sym_string_literal,
    STATE(11741), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [270290] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7371), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10405), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270325] = 6,
    ACTIONS(15441), 1,
      sym_identifier,
    ACTIONS(15443), 1,
      sym_quoted_identifier,
    STATE(11774), 1,
      sym__trigger_name,
    STATE(11168), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [270356] = 6,
    ACTIONS(15441), 1,
      sym_identifier,
    ACTIONS(15443), 1,
      sym_quoted_identifier,
    STATE(11795), 1,
      sym__trigger_name,
    STATE(11168), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [270387] = 5,
    ACTIONS(15465), 1,
      anon_sym_LBRACE,
    ACTIONS(15467), 1,
      aux_sym_interface_declaration_token1,
    ACTIONS(15471), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15469), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [270416] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7618), 1,
      sym_code_block,
    STATE(10975), 1,
      sym_preproc_conditional_var_block,
    STATE(10976), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270453] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7621), 1,
      sym_code_block,
    STATE(10979), 1,
      sym_preproc_conditional_var_block,
    STATE(10980), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270490] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3646), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10559), 1,
      sym_preproc_conditional_var_block,
    STATE(10560), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270527] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7604), 1,
      sym_code_block,
    STATE(10986), 1,
      sym_preproc_conditional_var_block,
    STATE(10987), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270564] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3298), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10383), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270599] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5026), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11004), 1,
      sym_preproc_conditional_var_block,
    STATE(11005), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270636] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7499), 1,
      sym_code_block,
    STATE(10603), 1,
      sym_preproc_conditional_var_block,
    STATE(10604), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270673] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5168), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10575), 1,
      sym_preproc_conditional_var_block,
    STATE(10576), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270710] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5036), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11013), 1,
      sym_preproc_conditional_var_block,
    STATE(11014), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270747] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5050), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11015), 1,
      sym_preproc_conditional_var_block,
    STATE(11016), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270784] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(6991), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10616), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270819] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5064), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11019), 1,
      sym_preproc_conditional_var_block,
    STATE(11020), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270856] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(2876), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10420), 1,
      sym_preproc_conditional_var_block,
    STATE(10421), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270893] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5800), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11030), 1,
      sym_preproc_conditional_var_block,
    STATE(11031), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270930] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5171), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10578), 1,
      sym_preproc_conditional_var_block,
    STATE(10579), 1,
      sym_var_section,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [270967] = 8,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5167), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(10580), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [271002] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5808), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11038), 1,
      sym_preproc_conditional_var_block,
    STATE(11039), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [271039] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5812), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11041), 1,
      sym_preproc_conditional_var_block,
    STATE(11042), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [271076] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(7506), 1,
      sym_code_block,
    STATE(10636), 1,
      sym_preproc_conditional_var_block,
    STATE(10637), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [271113] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5826), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11045), 1,
      sym_preproc_conditional_var_block,
    STATE(11046), 1,
      sym_var_section,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [271150] = 6,
    ACTIONS(15473), 1,
      sym_identifier,
    ACTIONS(15475), 1,
      sym_filter_keyword,
    ACTIONS(15477), 1,
      sym_quoted_identifier,
    STATE(11269), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [271181] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5697), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11065), 1,
      sym_preproc_conditional_var_block,
    STATE(11067), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [271218] = 6,
    ACTIONS(15441), 1,
      sym_identifier,
    ACTIONS(15443), 1,
      sym_quoted_identifier,
    STATE(12234), 1,
      sym__trigger_name,
    STATE(11168), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [271249] = 4,
    ACTIONS(15479), 1,
      anon_sym_DOT,
    STATE(8324), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2398), 11,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
      sym_temporary_keyword,
  [271276] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(5459), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(11072), 1,
      sym_preproc_conditional_var_block,
    STATE(11073), 1,
      sym_var_section,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [271313] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3957), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10989), 1,
      sym_preproc_conditional_var_block,
    STATE(10991), 1,
      sym_var_section,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [271350] = 9,
    ACTIONS(13933), 1,
      sym_var_keyword,
    STATE(3756), 1,
      sym_code_block,
    STATE(7486), 1,
      sym_preproc_if,
    STATE(10524), 1,
      sym_preproc_conditional_var_block,
    STATE(10525), 1,
      sym_var_section,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(13935), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [271387] = 5,
    ACTIONS(15482), 1,
      sym_identifier,
    ACTIONS(15484), 1,
      sym_quoted_identifier,
    STATE(11950), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [271415] = 5,
    ACTIONS(15486), 1,
      sym_identifier,
    ACTIONS(15488), 1,
      sym_quoted_identifier,
    STATE(11990), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [271443] = 5,
    ACTIONS(15490), 1,
      sym_identifier,
    ACTIONS(15492), 1,
      sym_quoted_identifier,
    STATE(11387), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [271471] = 5,
    STATE(7457), 1,
      sym_preproc_elif,
    STATE(8331), 1,
      aux_sym_preproc_conditional_fieldgroups_repeat2,
    ACTIONS(15494), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14443), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [271499] = 5,
    STATE(95), 1,
      sym_preproc_elif,
    STATE(8332), 1,
      aux_sym_preproc_conditional_statement_repeat1,
    ACTIONS(15497), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15500), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [271527] = 5,
    ACTIONS(15502), 1,
      sym_identifier,
    ACTIONS(15504), 1,
      sym_quoted_identifier,
    STATE(11969), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [271555] = 5,
    STATE(4897), 1,
      sym_preproc_elif,
    STATE(8334), 1,
      aux_sym_preproc_conditional_actions_repeat1,
    ACTIONS(15506), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11974), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [271583] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15509), 12,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_if_table_relation_token2,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [271605] = 5,
    ACTIONS(15511), 1,
      sym_identifier,
    ACTIONS(15513), 1,
      sym_quoted_identifier,
    STATE(1136), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(425), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [271633] = 5,
    ACTIONS(15515), 1,
      sym_identifier,
    ACTIONS(15517), 1,
      sym_quoted_identifier,
    STATE(1113), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(425), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [271661] = 5,
    ACTIONS(15519), 1,
      sym_identifier,
    ACTIONS(15521), 1,
      sym_quoted_identifier,
    STATE(12223), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [271689] = 5,
    ACTIONS(15523), 1,
      sym_identifier,
    ACTIONS(15527), 1,
      sym_quoted_identifier,
    STATE(6329), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15525), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [271717] = 5,
    ACTIONS(15529), 1,
      sym_identifier,
    ACTIONS(15531), 1,
      sym_quoted_identifier,
    STATE(7769), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6023), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [271745] = 5,
    ACTIONS(15533), 1,
      sym_identifier,
    ACTIONS(15535), 1,
      sym_quoted_identifier,
    STATE(8853), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [271773] = 7,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(15537), 1,
      anon_sym_RBRACE,
    ACTIONS(15539), 1,
      sym_key_keyword,
    STATE(7464), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    STATE(8346), 4,
      sym_preproc_conditional_keys,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_keys_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [271805] = 5,
    ACTIONS(15541), 1,
      sym_identifier,
    ACTIONS(15543), 1,
      sym_quoted_identifier,
    STATE(12143), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [271833] = 5,
    ACTIONS(15545), 1,
      sym_identifier,
    ACTIONS(15547), 1,
      sym_quoted_identifier,
    STATE(11985), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [271861] = 5,
    STATE(3272), 1,
      sym_preproc_elif,
    STATE(8345), 1,
      aux_sym_preproc_conditional_repeat1,
    ACTIONS(15549), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8930), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [271889] = 7,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(15539), 1,
      sym_key_keyword,
    ACTIONS(15552), 1,
      anon_sym_RBRACE,
    STATE(7464), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    STATE(8714), 4,
      sym_preproc_conditional_keys,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_keys_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [271921] = 5,
    ACTIONS(15554), 1,
      sym_identifier,
    ACTIONS(15556), 1,
      sym_quoted_identifier,
    STATE(8883), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [271949] = 5,
    ACTIONS(15558), 1,
      sym_identifier,
    ACTIONS(15560), 1,
      sym_quoted_identifier,
    STATE(12231), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [271977] = 5,
    STATE(3879), 1,
      sym_preproc_elif,
    STATE(8349), 1,
      aux_sym_preproc_conditional_layout_repeat1,
    ACTIONS(15562), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10392), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [272005] = 5,
    ACTIONS(15565), 1,
      sym_identifier,
    ACTIONS(15567), 1,
      sym_quoted_identifier,
    STATE(11389), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272033] = 5,
    ACTIONS(15569), 1,
      sym_identifier,
    ACTIONS(15571), 1,
      sym_quoted_identifier,
    STATE(12180), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272061] = 5,
    STATE(7647), 1,
      sym_preproc_elif,
    STATE(8352), 1,
      aux_sym_preproc_conditional_dataset_repeat2,
    ACTIONS(15573), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14782), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [272089] = 3,
    ACTIONS(15578), 1,
      aux_sym_if_table_relation_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15576), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [272113] = 5,
    ACTIONS(15580), 1,
      sym_identifier,
    ACTIONS(15582), 1,
      sym_quoted_identifier,
    STATE(11260), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272141] = 4,
    ACTIONS(15368), 1,
      sym_implements_keyword,
    STATE(8938), 1,
      sym_implements_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15366), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [272167] = 5,
    ACTIONS(15584), 1,
      sym_identifier,
    ACTIONS(15586), 1,
      sym_quoted_identifier,
    STATE(12196), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272195] = 5,
    ACTIONS(15588), 1,
      sym_identifier,
    ACTIONS(15590), 1,
      sym_quoted_identifier,
    STATE(11230), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272223] = 5,
    STATE(3461), 1,
      sym_preproc_elif,
    STATE(8358), 1,
      aux_sym_preproc_split_declaration_repeat1,
    ACTIONS(15592), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15595), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [272251] = 5,
    ACTIONS(15597), 1,
      sym_identifier,
    ACTIONS(15599), 1,
      sym_quoted_identifier,
    STATE(12130), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272279] = 5,
    ACTIONS(15601), 1,
      sym_identifier,
    ACTIONS(15603), 1,
      sym_quoted_identifier,
    STATE(12242), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272307] = 5,
    ACTIONS(15605), 1,
      sym_identifier,
    ACTIONS(15607), 1,
      sym_quoted_identifier,
    STATE(11137), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272335] = 4,
    ACTIONS(15609), 1,
      anon_sym_COMMA,
    STATE(8382), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2356), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [272361] = 5,
    ACTIONS(15611), 1,
      sym_identifier,
    ACTIONS(15613), 1,
      sym_quoted_identifier,
    STATE(11422), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272389] = 5,
    ACTIONS(15615), 1,
      sym_identifier,
    ACTIONS(15617), 1,
      sym_quoted_identifier,
    STATE(11430), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272417] = 5,
    ACTIONS(15619), 1,
      sym_identifier,
    ACTIONS(15621), 1,
      sym_quoted_identifier,
    STATE(12579), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272445] = 4,
    ACTIONS(15609), 1,
      anon_sym_COMMA,
    STATE(8389), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2356), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [272471] = 5,
    ACTIONS(15623), 1,
      sym_identifier,
    ACTIONS(15625), 1,
      sym_quoted_identifier,
    STATE(12148), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272499] = 5,
    ACTIONS(15627), 1,
      sym_identifier,
    ACTIONS(15629), 1,
      sym_quoted_identifier,
    STATE(12567), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272527] = 5,
    ACTIONS(15631), 1,
      sym_identifier,
    ACTIONS(15633), 1,
      sym_quoted_identifier,
    STATE(10784), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272555] = 5,
    ACTIONS(15635), 1,
      sym_identifier,
    ACTIONS(15637), 1,
      sym_quoted_identifier,
    STATE(11543), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272583] = 5,
    STATE(2874), 1,
      sym_preproc_elif,
    STATE(8371), 1,
      aux_sym_preproc_conditional_controladdin_repeat1,
    ACTIONS(15639), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7763), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [272611] = 5,
    ACTIONS(15642), 1,
      sym_identifier,
    ACTIONS(15644), 1,
      sym_quoted_identifier,
    STATE(11373), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272639] = 5,
    ACTIONS(15646), 1,
      sym_identifier,
    ACTIONS(15650), 1,
      sym_quoted_identifier,
    STATE(2563), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15648), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272667] = 5,
    ACTIONS(15652), 1,
      sym_identifier,
    ACTIONS(15654), 1,
      sym_quoted_identifier,
    STATE(2542), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15648), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272695] = 5,
    ACTIONS(15656), 1,
      sym_identifier,
    ACTIONS(15658), 1,
      sym_quoted_identifier,
    STATE(1118), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(425), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272723] = 5,
    ACTIONS(15660), 1,
      sym_identifier,
    ACTIONS(15662), 1,
      sym_quoted_identifier,
    STATE(7255), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6601), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272751] = 5,
    ACTIONS(15346), 1,
      sym_identifier,
    ACTIONS(15350), 1,
      sym_quoted_identifier,
    STATE(11939), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272779] = 7,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(15539), 1,
      sym_key_keyword,
    ACTIONS(15664), 1,
      anon_sym_RBRACE,
    STATE(7464), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    STATE(8381), 4,
      sym_preproc_conditional_keys,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_keys_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [272811] = 5,
    ACTIONS(15666), 1,
      sym_identifier,
    ACTIONS(15668), 1,
      sym_quoted_identifier,
    STATE(12144), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272839] = 5,
    ACTIONS(15670), 1,
      sym_identifier,
    ACTIONS(15672), 1,
      sym_quoted_identifier,
    STATE(8300), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272867] = 7,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(15539), 1,
      sym_key_keyword,
    ACTIONS(15674), 1,
      anon_sym_RBRACE,
    STATE(7464), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    STATE(8714), 4,
      sym_preproc_conditional_keys,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_keys_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [272899] = 4,
    ACTIONS(15676), 1,
      anon_sym_COMMA,
    STATE(8382), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2405), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [272925] = 5,
    ACTIONS(15679), 1,
      sym_identifier,
    ACTIONS(15681), 1,
      sym_quoted_identifier,
    STATE(12317), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272953] = 5,
    ACTIONS(15683), 1,
      sym_identifier,
    ACTIONS(15685), 1,
      sym_quoted_identifier,
    STATE(10521), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [272981] = 5,
    ACTIONS(15687), 1,
      sym_identifier,
    ACTIONS(15689), 1,
      sym_quoted_identifier,
    STATE(12488), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273009] = 5,
    ACTIONS(15691), 1,
      sym_identifier,
    ACTIONS(15693), 1,
      sym_quoted_identifier,
    STATE(10581), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273037] = 5,
    ACTIONS(15473), 1,
      sym_identifier,
    ACTIONS(15477), 1,
      sym_quoted_identifier,
    STATE(11269), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273065] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2398), 12,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_DOT,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
      sym_temporary_keyword,
  [273087] = 4,
    ACTIONS(15609), 1,
      anon_sym_COMMA,
    STATE(8382), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2412), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [273113] = 5,
    ACTIONS(15695), 1,
      sym_identifier,
    ACTIONS(15697), 1,
      sym_quoted_identifier,
    STATE(11276), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273141] = 5,
    ACTIONS(15699), 1,
      sym_identifier,
    ACTIONS(15701), 1,
      sym_quoted_identifier,
    STATE(10590), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273169] = 5,
    ACTIONS(15703), 1,
      sym_identifier,
    ACTIONS(15705), 1,
      sym_quoted_identifier,
    STATE(4826), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273197] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2541), 12,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [273219] = 5,
    ACTIONS(15707), 1,
      sym_identifier,
    ACTIONS(15709), 1,
      sym_quoted_identifier,
    STATE(11226), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273247] = 5,
    ACTIONS(15711), 1,
      sym_identifier,
    ACTIONS(15713), 1,
      sym_quoted_identifier,
    STATE(4696), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273275] = 3,
    ACTIONS(15715), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2615), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [273299] = 3,
    ACTIONS(15717), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2621), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [273323] = 5,
    ACTIONS(15719), 1,
      sym_identifier,
    ACTIONS(15721), 1,
      sym_quoted_identifier,
    STATE(2144), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3431), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273351] = 5,
    ACTIONS(15723), 1,
      sym_identifier,
    ACTIONS(15725), 1,
      sym_quoted_identifier,
    STATE(2107), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3431), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273379] = 5,
    ACTIONS(15727), 1,
      sym_identifier,
    ACTIONS(15729), 1,
      sym_quoted_identifier,
    STATE(4869), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6023), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273407] = 5,
    ACTIONS(15731), 1,
      sym_identifier,
    ACTIONS(15733), 1,
      sym_quoted_identifier,
    STATE(1210), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(834), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273435] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2405), 12,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [273457] = 5,
    STATE(1375), 1,
      sym_preproc_elif,
    STATE(8403), 1,
      aux_sym_preproc_conditional_layout_mixed_repeat2,
    ACTIONS(15735), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3481), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [273485] = 5,
    ACTIONS(15738), 1,
      sym_identifier,
    ACTIONS(15740), 1,
      sym_quoted_identifier,
    STATE(6009), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4844), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273513] = 5,
    ACTIONS(15742), 1,
      sym_identifier,
    ACTIONS(15744), 1,
      sym_quoted_identifier,
    STATE(5878), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4844), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273541] = 5,
    ACTIONS(15746), 1,
      sym_identifier,
    ACTIONS(15748), 1,
      sym_quoted_identifier,
    STATE(2102), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3431), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273569] = 5,
    ACTIONS(15750), 1,
      sym_identifier,
    ACTIONS(15752), 1,
      sym_quoted_identifier,
    STATE(5876), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5399), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273597] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2531), 12,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [273619] = 3,
    ACTIONS(15754), 1,
      sym_temporary_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2535), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [273643] = 5,
    ACTIONS(15756), 1,
      sym_identifier,
    ACTIONS(15758), 1,
      sym_quoted_identifier,
    STATE(1027), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(283), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273671] = 5,
    ACTIONS(15760), 1,
      sym_identifier,
    ACTIONS(15762), 1,
      sym_quoted_identifier,
    STATE(999), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(283), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273699] = 5,
    ACTIONS(15764), 1,
      sym_identifier,
    ACTIONS(15766), 1,
      sym_quoted_identifier,
    STATE(12243), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273727] = 5,
    ACTIONS(15768), 1,
      sym_identifier,
    ACTIONS(15770), 1,
      sym_quoted_identifier,
    STATE(1513), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2945), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273755] = 5,
    ACTIONS(15772), 1,
      sym_identifier,
    ACTIONS(15774), 1,
      sym_quoted_identifier,
    STATE(1448), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2945), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273783] = 5,
    ACTIONS(15776), 1,
      sym_identifier,
    ACTIONS(15778), 1,
      sym_quoted_identifier,
    STATE(5401), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4844), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273811] = 5,
    ACTIONS(15780), 1,
      sym_identifier,
    ACTIONS(15782), 1,
      sym_quoted_identifier,
    STATE(1006), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(283), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273839] = 5,
    STATE(2657), 1,
      sym_preproc_elif,
    STATE(8417), 1,
      aux_sym_preproc_conditional_xmlport_repeat1,
    ACTIONS(15784), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6274), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [273867] = 5,
    ACTIONS(15787), 1,
      sym_identifier,
    ACTIONS(15789), 1,
      sym_quoted_identifier,
    STATE(8231), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273895] = 5,
    ACTIONS(15791), 1,
      sym_identifier,
    ACTIONS(15793), 1,
      sym_quoted_identifier,
    STATE(11403), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273923] = 5,
    ACTIONS(15795), 1,
      sym_identifier,
    ACTIONS(15797), 1,
      sym_quoted_identifier,
    STATE(12453), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273951] = 5,
    ACTIONS(15799), 1,
      sym_identifier,
    ACTIONS(15801), 1,
      sym_quoted_identifier,
    STATE(7292), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [273979] = 5,
    ACTIONS(15803), 1,
      sym_identifier,
    ACTIONS(15805), 1,
      sym_quoted_identifier,
    STATE(2146), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3456), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274007] = 5,
    ACTIONS(15807), 1,
      sym_identifier,
    ACTIONS(15809), 1,
      sym_quoted_identifier,
    STATE(2106), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3456), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274035] = 5,
    ACTIONS(15811), 1,
      sym_identifier,
    ACTIONS(15813), 1,
      sym_quoted_identifier,
    STATE(1436), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2945), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274063] = 5,
    ACTIONS(15815), 1,
      sym_identifier,
    ACTIONS(15817), 1,
      sym_quoted_identifier,
    STATE(1114), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(425), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274091] = 5,
    ACTIONS(15819), 1,
      sym_identifier,
    ACTIONS(15821), 1,
      sym_quoted_identifier,
    STATE(11203), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274119] = 5,
    ACTIONS(15823), 1,
      sym_identifier,
    ACTIONS(15825), 1,
      sym_quoted_identifier,
    STATE(1209), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(834), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274147] = 5,
    ACTIONS(15827), 1,
      sym_identifier,
    ACTIONS(15829), 1,
      sym_quoted_identifier,
    STATE(7607), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14585), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274175] = 5,
    ACTIONS(15703), 1,
      sym_identifier,
    ACTIONS(15705), 1,
      sym_quoted_identifier,
    STATE(4826), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4844), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274203] = 5,
    ACTIONS(15711), 1,
      sym_identifier,
    ACTIONS(15713), 1,
      sym_quoted_identifier,
    STATE(4696), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4844), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274231] = 5,
    ACTIONS(15831), 1,
      sym_identifier,
    ACTIONS(15833), 1,
      sym_quoted_identifier,
    STATE(2099), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3456), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274259] = 5,
    ACTIONS(15835), 1,
      sym_identifier,
    ACTIONS(15837), 1,
      sym_quoted_identifier,
    STATE(5421), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4844), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274287] = 5,
    ACTIONS(15839), 1,
      sym_identifier,
    ACTIONS(15841), 1,
      sym_quoted_identifier,
    STATE(12328), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274315] = 5,
    ACTIONS(15843), 1,
      sym_identifier,
    ACTIONS(15845), 1,
      sym_quoted_identifier,
    STATE(12417), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274343] = 5,
    ACTIONS(15847), 1,
      sym_identifier,
    ACTIONS(15849), 1,
      sym_quoted_identifier,
    STATE(1000), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(283), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274371] = 5,
    ACTIONS(15851), 1,
      sym_identifier,
    ACTIONS(15853), 1,
      sym_quoted_identifier,
    STATE(8388), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9358), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274399] = 5,
    ACTIONS(15855), 1,
      sym_identifier,
    ACTIONS(15857), 1,
      sym_quoted_identifier,
    STATE(2103), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3431), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274427] = 5,
    ACTIONS(15859), 1,
      sym_identifier,
    ACTIONS(15861), 1,
      sym_quoted_identifier,
    STATE(12436), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274455] = 5,
    ACTIONS(15863), 1,
      sym_identifier,
    ACTIONS(15865), 1,
      sym_quoted_identifier,
    STATE(8254), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274483] = 5,
    ACTIONS(15867), 1,
      sym_identifier,
    ACTIONS(15869), 1,
      sym_quoted_identifier,
    STATE(1443), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2945), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274511] = 5,
    ACTIONS(15871), 1,
      sym_identifier,
    ACTIONS(15873), 1,
      sym_quoted_identifier,
    STATE(12605), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274539] = 5,
    ACTIONS(15875), 1,
      sym_identifier,
    ACTIONS(15877), 1,
      sym_quoted_identifier,
    STATE(11527), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274567] = 7,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(15539), 1,
      sym_key_keyword,
    ACTIONS(15879), 1,
      anon_sym_RBRACE,
    STATE(7464), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    STATE(8714), 4,
      sym_preproc_conditional_keys,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_keys_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [274599] = 5,
    ACTIONS(15881), 1,
      sym_identifier,
    ACTIONS(15883), 1,
      sym_quoted_identifier,
    STATE(2116), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3456), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274627] = 5,
    ACTIONS(15885), 1,
      sym_identifier,
    ACTIONS(15887), 1,
      sym_quoted_identifier,
    STATE(11625), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274655] = 5,
    ACTIONS(15889), 1,
      sym_identifier,
    ACTIONS(15891), 1,
      sym_quoted_identifier,
    STATE(12069), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274683] = 5,
    STATE(7227), 1,
      sym_preproc_elif,
    STATE(8447), 1,
      aux_sym_preproc_conditional_link_values_repeat2,
    ACTIONS(15893), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14127), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [274711] = 7,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(15539), 1,
      sym_key_keyword,
    ACTIONS(15896), 1,
      anon_sym_RBRACE,
    STATE(7464), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    STATE(8443), 4,
      sym_preproc_conditional_keys,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_keys_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [274743] = 5,
    STATE(1503), 1,
      sym_preproc_elif,
    STATE(8449), 1,
      aux_sym_preproc_conditional_table_relation_repeat1,
    ACTIONS(15898), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15901), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [274771] = 5,
    STATE(6281), 1,
      sym_preproc_elif,
    STATE(8450), 1,
      aux_sym_preproc_conditional_permissions_repeat1,
    ACTIONS(15903), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13357), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [274799] = 5,
    ACTIONS(15906), 1,
      sym_identifier,
    ACTIONS(15908), 1,
      sym_quoted_identifier,
    STATE(12583), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274827] = 5,
    ACTIONS(15910), 1,
      sym_identifier,
    ACTIONS(15912), 1,
      sym_quoted_identifier,
    STATE(8223), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274855] = 5,
    STATE(7230), 1,
      sym_preproc_elif,
    STATE(8453), 1,
      aux_sym_preproc_conditional_impl_values_repeat2,
    ACTIONS(15914), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14129), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [274883] = 5,
    ACTIONS(15917), 1,
      sym_identifier,
    ACTIONS(15919), 1,
      sym_quoted_identifier,
    STATE(11752), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274911] = 5,
    ACTIONS(15921), 1,
      sym_identifier,
    ACTIONS(15923), 1,
      sym_quoted_identifier,
    STATE(12076), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274939] = 5,
    ACTIONS(15925), 1,
      sym_identifier,
    ACTIONS(15927), 1,
      sym_quoted_identifier,
    STATE(12575), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274967] = 5,
    ACTIONS(15929), 1,
      sym_identifier,
    ACTIONS(15931), 1,
      sym_quoted_identifier,
    STATE(12621), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [274995] = 5,
    ACTIONS(15933), 1,
      sym_identifier,
    ACTIONS(15935), 1,
      sym_quoted_identifier,
    STATE(11600), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275023] = 5,
    ACTIONS(15937), 1,
      sym_identifier,
    ACTIONS(15939), 1,
      sym_quoted_identifier,
    STATE(11695), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275051] = 5,
    ACTIONS(15941), 1,
      sym_identifier,
    ACTIONS(15943), 1,
      sym_quoted_identifier,
    STATE(11702), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275079] = 5,
    ACTIONS(15945), 1,
      sym_identifier,
    ACTIONS(15947), 1,
      sym_quoted_identifier,
    STATE(11714), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275107] = 7,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(15539), 1,
      sym_key_keyword,
    ACTIONS(15949), 1,
      anon_sym_RBRACE,
    STATE(7464), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    STATE(8470), 4,
      sym_preproc_conditional_keys,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_keys_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [275139] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15951), 12,
      sym_preproc_close,
      anon_sym_LBRACK,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_key_keyword,
  [275161] = 5,
    ACTIONS(15953), 1,
      sym_identifier,
    ACTIONS(15955), 1,
      sym_quoted_identifier,
    STATE(4779), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275189] = 5,
    ACTIONS(15957), 1,
      sym_identifier,
    ACTIONS(15959), 1,
      sym_quoted_identifier,
    STATE(10547), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275217] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13036), 12,
      sym_preproc_close,
      anon_sym_LBRACK,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_dataitem_keyword,
  [275239] = 5,
    STATE(1740), 1,
      sym_preproc_elif,
    STATE(8467), 1,
      aux_sym_preproc_conditional_case_repeat2,
    ACTIONS(15961), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4860), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [275267] = 5,
    ACTIONS(15964), 1,
      sym_identifier,
    ACTIONS(15966), 1,
      sym_quoted_identifier,
    STATE(11800), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275295] = 5,
    STATE(2560), 1,
      sym_preproc_elif,
    STATE(8469), 1,
      aux_sym_preproc_split_case_branch_repeat2,
    ACTIONS(15968), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15971), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [275323] = 7,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(15539), 1,
      sym_key_keyword,
    ACTIONS(15973), 1,
      anon_sym_RBRACE,
    STATE(7464), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    STATE(8714), 4,
      sym_preproc_conditional_keys,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_keys_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [275355] = 5,
    ACTIONS(15975), 1,
      sym_identifier,
    ACTIONS(15977), 1,
      sym_quoted_identifier,
    STATE(11283), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275383] = 5,
    ACTIONS(15979), 1,
      sym_identifier,
    ACTIONS(15981), 1,
      sym_quoted_identifier,
    STATE(11316), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275411] = 5,
    ACTIONS(15983), 1,
      sym_identifier,
    ACTIONS(15985), 1,
      sym_quoted_identifier,
    STATE(8798), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275439] = 5,
    ACTIONS(15987), 1,
      sym_identifier,
    ACTIONS(15989), 1,
      sym_quoted_identifier,
    STATE(11994), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275467] = 5,
    ACTIONS(15991), 1,
      sym_identifier,
    ACTIONS(15993), 1,
      sym_quoted_identifier,
    STATE(10628), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275495] = 5,
    ACTIONS(15995), 1,
      sym_identifier,
    ACTIONS(15997), 1,
      sym_quoted_identifier,
    STATE(11328), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275523] = 5,
    ACTIONS(15999), 1,
      sym_identifier,
    ACTIONS(16001), 1,
      sym_quoted_identifier,
    STATE(12027), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275551] = 7,
    ACTIONS(14283), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14287), 1,
      aux_sym_modify_modification_token1,
    STATE(9013), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    STATE(7548), 4,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_preproc_conditional_fields_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [275583] = 7,
    ACTIONS(14283), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14287), 1,
      aux_sym_modify_modification_token1,
    STATE(9013), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    STATE(8582), 4,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_preproc_conditional_fields_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [275615] = 5,
    ACTIONS(16003), 1,
      sym_identifier,
    ACTIONS(16005), 1,
      sym_quoted_identifier,
    STATE(8712), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275643] = 5,
    ACTIONS(16007), 1,
      sym_identifier,
    ACTIONS(16009), 1,
      sym_quoted_identifier,
    STATE(8799), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275671] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(16011), 12,
      sym_preproc_close,
      anon_sym_LBRACK,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_key_keyword,
  [275693] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13090), 12,
      sym_preproc_close,
      anon_sym_LBRACK,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      sym_dataitem_keyword,
  [275715] = 5,
    ACTIONS(16013), 1,
      sym_identifier,
    ACTIONS(16015), 1,
      sym_quoted_identifier,
    STATE(12654), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275743] = 5,
    ACTIONS(16017), 1,
      sym_identifier,
    ACTIONS(16019), 1,
      sym_quoted_identifier,
    STATE(1223), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(834), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275771] = 5,
    ACTIONS(16021), 1,
      sym_identifier,
    ACTIONS(16023), 1,
      sym_quoted_identifier,
    STATE(12232), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275799] = 5,
    ACTIONS(16025), 1,
      sym_identifier,
    ACTIONS(16027), 1,
      sym_quoted_identifier,
    STATE(12237), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275827] = 5,
    ACTIONS(16029), 1,
      sym_identifier,
    ACTIONS(16031), 1,
      sym_quoted_identifier,
    STATE(12239), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275855] = 5,
    ACTIONS(16033), 1,
      sym_identifier,
    ACTIONS(16035), 1,
      sym_quoted_identifier,
    STATE(12249), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275883] = 5,
    ACTIONS(16037), 1,
      sym_identifier,
    ACTIONS(16039), 1,
      sym_quoted_identifier,
    STATE(12194), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275911] = 5,
    ACTIONS(16041), 1,
      sym_identifier,
    ACTIONS(16043), 1,
      sym_quoted_identifier,
    STATE(1206), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(834), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275939] = 5,
    ACTIONS(16045), 1,
      sym_identifier,
    ACTIONS(16047), 1,
      sym_quoted_identifier,
    STATE(12126), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275967] = 5,
    ACTIONS(16049), 1,
      sym_identifier,
    ACTIONS(16051), 1,
      sym_quoted_identifier,
    STATE(12001), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [275995] = 5,
    ACTIONS(16053), 1,
      sym_identifier,
    ACTIONS(16055), 1,
      sym_quoted_identifier,
    STATE(12186), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276023] = 5,
    ACTIONS(16057), 1,
      sym_identifier,
    ACTIONS(16059), 1,
      sym_quoted_identifier,
    STATE(12036), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276051] = 5,
    ACTIONS(16061), 1,
      sym_identifier,
    ACTIONS(16063), 1,
      sym_quoted_identifier,
    STATE(11189), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276079] = 5,
    ACTIONS(16065), 1,
      sym_identifier,
    ACTIONS(16067), 1,
      sym_quoted_identifier,
    STATE(11500), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276107] = 5,
    ACTIONS(16069), 1,
      sym_identifier,
    ACTIONS(16071), 1,
      sym_quoted_identifier,
    STATE(12085), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276135] = 5,
    ACTIONS(16073), 1,
      sym_identifier,
    ACTIONS(16075), 1,
      sym_quoted_identifier,
    STATE(12092), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276163] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(16077), 12,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_if_table_relation_token2,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [276185] = 5,
    ACTIONS(16079), 1,
      sym_identifier,
    ACTIONS(16081), 1,
      sym_quoted_identifier,
    STATE(11470), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276213] = 5,
    ACTIONS(16083), 1,
      sym_identifier,
    ACTIONS(16085), 1,
      sym_quoted_identifier,
    STATE(11535), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276241] = 5,
    ACTIONS(16087), 1,
      sym_identifier,
    ACTIONS(16089), 1,
      sym_quoted_identifier,
    STATE(12137), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276269] = 5,
    ACTIONS(16091), 1,
      sym_identifier,
    ACTIONS(16093), 1,
      sym_quoted_identifier,
    STATE(12150), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276297] = 5,
    ACTIONS(16095), 1,
      sym_identifier,
    ACTIONS(16097), 1,
      sym_quoted_identifier,
    STATE(12189), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276325] = 5,
    ACTIONS(16099), 1,
      sym_identifier,
    ACTIONS(16101), 1,
      sym_quoted_identifier,
    STATE(12201), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276353] = 5,
    ACTIONS(16103), 1,
      sym_identifier,
    ACTIONS(16105), 1,
      sym_quoted_identifier,
    STATE(11473), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276381] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2416), 12,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [276403] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2420), 12,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [276425] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2424), 12,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [276447] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2553), 12,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [276469] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2428), 12,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [276491] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2428), 12,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [276513] = 5,
    ACTIONS(16107), 1,
      sym_identifier,
    ACTIONS(16109), 1,
      sym_quoted_identifier,
    STATE(12661), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276541] = 5,
    ACTIONS(15727), 1,
      sym_identifier,
    ACTIONS(15729), 1,
      sym_quoted_identifier,
    STATE(4869), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276569] = 5,
    ACTIONS(16111), 1,
      sym_identifier,
    ACTIONS(16113), 1,
      sym_quoted_identifier,
    STATE(12483), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276597] = 5,
    ACTIONS(16115), 1,
      sym_identifier,
    ACTIONS(16117), 1,
      sym_quoted_identifier,
    STATE(12410), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276625] = 5,
    STATE(8518), 1,
      aux_sym_preproc_split_field_repeat1,
    STATE(11157), 1,
      sym_preproc_elif,
    ACTIONS(16119), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(16122), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [276653] = 5,
    ACTIONS(16124), 1,
      sym_identifier,
    ACTIONS(16126), 1,
      sym_quoted_identifier,
    STATE(12164), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276681] = 5,
    STATE(948), 1,
      sym_preproc_elif,
    STATE(8520), 1,
      aux_sym_preproc_conditional_object_repeat1,
    ACTIONS(16128), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2352), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [276709] = 5,
    ACTIONS(16131), 1,
      sym_identifier,
    ACTIONS(16133), 1,
      sym_quoted_identifier,
    STATE(12522), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276737] = 5,
    ACTIONS(16135), 1,
      sym_identifier,
    ACTIONS(16137), 1,
      sym_quoted_identifier,
    STATE(12543), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276765] = 5,
    ACTIONS(16139), 1,
      sym_identifier,
    ACTIONS(16141), 1,
      sym_quoted_identifier,
    STATE(6791), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5908), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276793] = 5,
    ACTIONS(16143), 1,
      sym_identifier,
    ACTIONS(16145), 1,
      sym_quoted_identifier,
    STATE(7613), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14585), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276821] = 5,
    ACTIONS(16147), 1,
      sym_identifier,
    ACTIONS(16149), 1,
      sym_quoted_identifier,
    STATE(4810), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276849] = 5,
    ACTIONS(16151), 1,
      sym_identifier,
    ACTIONS(16153), 1,
      sym_quoted_identifier,
    STATE(7356), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276877] = 5,
    ACTIONS(16155), 1,
      sym_identifier,
    ACTIONS(16157), 1,
      sym_quoted_identifier,
    STATE(8913), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276905] = 5,
    ACTIONS(16159), 1,
      sym_identifier,
    ACTIONS(16161), 1,
      sym_quoted_identifier,
    STATE(12550), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276933] = 5,
    ACTIONS(16163), 1,
      sym_identifier,
    ACTIONS(16165), 1,
      sym_quoted_identifier,
    STATE(12334), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276961] = 5,
    ACTIONS(16167), 1,
      sym_identifier,
    ACTIONS(16169), 1,
      sym_quoted_identifier,
    STATE(11248), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [276989] = 5,
    ACTIONS(16171), 1,
      sym_identifier,
    ACTIONS(16173), 1,
      sym_quoted_identifier,
    STATE(12443), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277017] = 5,
    ACTIONS(16175), 1,
      sym_identifier,
    ACTIONS(16177), 1,
      sym_quoted_identifier,
    STATE(8355), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277045] = 5,
    ACTIONS(15529), 1,
      sym_identifier,
    ACTIONS(15531), 1,
      sym_quoted_identifier,
    STATE(7769), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277073] = 5,
    ACTIONS(16179), 1,
      sym_identifier,
    ACTIONS(16181), 1,
      sym_quoted_identifier,
    STATE(11130), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277101] = 5,
    ACTIONS(16183), 1,
      sym_identifier,
    ACTIONS(16185), 1,
      sym_quoted_identifier,
    STATE(11273), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277129] = 5,
    ACTIONS(16187), 1,
      sym_identifier,
    ACTIONS(16189), 1,
      sym_quoted_identifier,
    STATE(8780), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277157] = 5,
    ACTIONS(16191), 1,
      sym_identifier,
    ACTIONS(16193), 1,
      sym_quoted_identifier,
    STATE(8781), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277185] = 3,
    ACTIONS(2416), 3,
      anon_sym_STAR,
      sym_quoted_identifier,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2414), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [277209] = 3,
    ACTIONS(2420), 3,
      anon_sym_STAR,
      sym_quoted_identifier,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2418), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [277233] = 5,
    ACTIONS(16195), 1,
      sym_identifier,
    ACTIONS(16197), 1,
      sym_quoted_identifier,
    STATE(12021), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277261] = 5,
    ACTIONS(16199), 1,
      sym_identifier,
    ACTIONS(16201), 1,
      sym_quoted_identifier,
    STATE(8784), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277289] = 5,
    ACTIONS(16203), 1,
      sym_identifier,
    ACTIONS(16205), 1,
      sym_quoted_identifier,
    STATE(8786), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277317] = 5,
    STATE(7970), 1,
      sym_preproc_elif,
    STATE(8543), 1,
      aux_sym_preproc_conditional_var_block_repeat1,
    ACTIONS(16207), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(16210), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [277345] = 5,
    ACTIONS(16212), 1,
      sym_identifier,
    ACTIONS(16214), 1,
      sym_quoted_identifier,
    STATE(8788), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277373] = 5,
    ACTIONS(16216), 1,
      sym_identifier,
    ACTIONS(16218), 1,
      sym_quoted_identifier,
    STATE(10423), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277401] = 5,
    ACTIONS(16220), 1,
      sym_identifier,
    ACTIONS(16222), 1,
      sym_quoted_identifier,
    STATE(12582), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277429] = 5,
    ACTIONS(16224), 1,
      sym_identifier,
    ACTIONS(16226), 1,
      sym_quoted_identifier,
    STATE(12598), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277457] = 5,
    ACTIONS(16228), 1,
      sym_identifier,
    ACTIONS(16230), 1,
      sym_quoted_identifier,
    STATE(12601), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277485] = 5,
    ACTIONS(16232), 1,
      sym_identifier,
    ACTIONS(16234), 1,
      sym_quoted_identifier,
    STATE(12604), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277513] = 5,
    ACTIONS(16236), 1,
      sym_identifier,
    ACTIONS(16238), 1,
      sym_quoted_identifier,
    STATE(12607), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277541] = 5,
    ACTIONS(16240), 1,
      sym_identifier,
    ACTIONS(16242), 1,
      sym_quoted_identifier,
    STATE(12610), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277569] = 5,
    ACTIONS(16244), 1,
      sym_identifier,
    ACTIONS(16246), 1,
      sym_quoted_identifier,
    STATE(12613), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277597] = 5,
    ACTIONS(16248), 1,
      sym_identifier,
    ACTIONS(16250), 1,
      sym_quoted_identifier,
    STATE(11400), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277625] = 5,
    ACTIONS(16252), 1,
      sym_identifier,
    ACTIONS(16254), 1,
      sym_quoted_identifier,
    STATE(10424), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277653] = 5,
    ACTIONS(16256), 1,
      sym_identifier,
    ACTIONS(16258), 1,
      sym_quoted_identifier,
    STATE(12626), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277681] = 5,
    ACTIONS(16260), 1,
      sym_identifier,
    ACTIONS(16262), 1,
      sym_quoted_identifier,
    STATE(10425), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277709] = 5,
    ACTIONS(16264), 1,
      sym_identifier,
    ACTIONS(16266), 1,
      sym_quoted_identifier,
    STATE(12663), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277737] = 5,
    ACTIONS(16268), 1,
      sym_identifier,
    ACTIONS(16270), 1,
      sym_quoted_identifier,
    STATE(11164), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277765] = 5,
    ACTIONS(16272), 1,
      sym_identifier,
    ACTIONS(16274), 1,
      sym_quoted_identifier,
    STATE(12553), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277793] = 5,
    ACTIONS(16276), 1,
      sym_identifier,
    ACTIONS(16278), 1,
      sym_quoted_identifier,
    STATE(11346), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277821] = 5,
    ACTIONS(16280), 1,
      sym_identifier,
    ACTIONS(16282), 1,
      sym_quoted_identifier,
    STATE(11365), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277849] = 5,
    ACTIONS(16284), 1,
      sym_identifier,
    ACTIONS(16286), 1,
      sym_quoted_identifier,
    STATE(11366), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277877] = 5,
    ACTIONS(16288), 1,
      sym_identifier,
    ACTIONS(16290), 1,
      sym_quoted_identifier,
    STATE(11399), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277905] = 5,
    ACTIONS(16292), 1,
      sym_identifier,
    ACTIONS(16294), 1,
      sym_quoted_identifier,
    STATE(11433), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277933] = 4,
    ACTIONS(15609), 1,
      anon_sym_COMMA,
    STATE(8362), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(374), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [277959] = 5,
    ACTIONS(16296), 1,
      sym_identifier,
    ACTIONS(16298), 1,
      sym_quoted_identifier,
    STATE(11472), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [277987] = 5,
    ACTIONS(16300), 1,
      sym_identifier,
    ACTIONS(16302), 1,
      sym_quoted_identifier,
    STATE(11505), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278015] = 5,
    ACTIONS(16304), 1,
      sym_identifier,
    ACTIONS(16306), 1,
      sym_quoted_identifier,
    STATE(11507), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278043] = 5,
    ACTIONS(16308), 1,
      sym_identifier,
    ACTIONS(16310), 1,
      sym_quoted_identifier,
    STATE(11567), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278071] = 5,
    ACTIONS(15425), 1,
      sym_identifier,
    ACTIONS(15429), 1,
      sym_quoted_identifier,
    STATE(12210), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278099] = 5,
    STATE(2732), 1,
      sym_preproc_elif,
    STATE(8571), 1,
      aux_sym_preproc_conditional_report_repeat1,
    ACTIONS(16312), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6702), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [278127] = 5,
    ACTIONS(16315), 1,
      sym_identifier,
    ACTIONS(16317), 1,
      sym_quoted_identifier,
    STATE(11683), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278155] = 5,
    ACTIONS(15431), 1,
      sym_identifier,
    ACTIONS(15435), 1,
      sym_quoted_identifier,
    STATE(12306), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278183] = 5,
    STATE(2572), 1,
      sym_preproc_elif,
    STATE(8574), 1,
      aux_sym_preproc_conditional_var_repeat2,
    ACTIONS(16319), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6027), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [278211] = 5,
    STATE(2680), 1,
      sym_preproc_elif,
    STATE(8575), 1,
      aux_sym_preproc_conditional_query_repeat1,
    ACTIONS(16322), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6464), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [278239] = 5,
    ACTIONS(16325), 1,
      sym_identifier,
    ACTIONS(16327), 1,
      sym_quoted_identifier,
    STATE(12253), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278267] = 5,
    ACTIONS(16329), 1,
      sym_identifier,
    ACTIONS(16331), 1,
      sym_quoted_identifier,
    STATE(11327), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278295] = 5,
    ACTIONS(16333), 1,
      sym_identifier,
    ACTIONS(16335), 1,
      sym_quoted_identifier,
    STATE(11796), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278323] = 5,
    ACTIONS(16337), 1,
      sym_identifier,
    ACTIONS(16339), 1,
      sym_quoted_identifier,
    STATE(12127), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278351] = 5,
    ACTIONS(16341), 1,
      sym_identifier,
    ACTIONS(16343), 1,
      sym_quoted_identifier,
    STATE(8770), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278379] = 5,
    ACTIONS(16345), 1,
      sym_identifier,
    ACTIONS(16347), 1,
      sym_quoted_identifier,
    STATE(8826), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278407] = 7,
    ACTIONS(14283), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14287), 1,
      aux_sym_modify_modification_token1,
    STATE(9007), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    STATE(7548), 4,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_preproc_conditional_fields_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [278439] = 5,
    ACTIONS(16349), 1,
      sym_identifier,
    ACTIONS(16351), 1,
      sym_quoted_identifier,
    STATE(11416), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278467] = 5,
    ACTIONS(16353), 1,
      sym_identifier,
    ACTIONS(16355), 1,
      sym_quoted_identifier,
    STATE(11423), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278495] = 5,
    ACTIONS(16357), 1,
      sym_identifier,
    ACTIONS(16359), 1,
      sym_quoted_identifier,
    STATE(11425), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278523] = 5,
    ACTIONS(16361), 1,
      sym_identifier,
    ACTIONS(16363), 1,
      sym_quoted_identifier,
    STATE(11426), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278551] = 5,
    ACTIONS(16365), 1,
      sym_identifier,
    ACTIONS(16367), 1,
      sym_quoted_identifier,
    STATE(11432), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278579] = 5,
    ACTIONS(16369), 1,
      sym_identifier,
    ACTIONS(16371), 1,
      sym_quoted_identifier,
    STATE(11440), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278607] = 5,
    ACTIONS(16373), 1,
      sym_identifier,
    ACTIONS(16375), 1,
      sym_quoted_identifier,
    STATE(11441), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278635] = 5,
    ACTIONS(16377), 1,
      sym_identifier,
    ACTIONS(16379), 1,
      sym_quoted_identifier,
    STATE(11442), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278663] = 5,
    ACTIONS(16381), 1,
      sym_identifier,
    ACTIONS(16383), 1,
      sym_quoted_identifier,
    STATE(11443), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278691] = 5,
    ACTIONS(16385), 1,
      sym_identifier,
    ACTIONS(16387), 1,
      sym_quoted_identifier,
    STATE(11444), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278719] = 5,
    ACTIONS(16389), 1,
      sym_identifier,
    ACTIONS(16391), 1,
      sym_quoted_identifier,
    STATE(11445), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278747] = 5,
    ACTIONS(16393), 1,
      sym_identifier,
    ACTIONS(16395), 1,
      sym_quoted_identifier,
    STATE(11446), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278775] = 5,
    ACTIONS(16397), 1,
      sym_identifier,
    ACTIONS(16399), 1,
      sym_quoted_identifier,
    STATE(11447), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278803] = 5,
    ACTIONS(16401), 1,
      sym_identifier,
    ACTIONS(16403), 1,
      sym_quoted_identifier,
    STATE(11448), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278831] = 5,
    ACTIONS(16405), 1,
      sym_identifier,
    ACTIONS(16407), 1,
      sym_quoted_identifier,
    STATE(11449), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278859] = 5,
    ACTIONS(16409), 1,
      sym_identifier,
    ACTIONS(16411), 1,
      sym_quoted_identifier,
    STATE(11450), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278887] = 5,
    ACTIONS(16413), 1,
      sym_identifier,
    ACTIONS(16415), 1,
      sym_quoted_identifier,
    STATE(11451), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278915] = 5,
    ACTIONS(16417), 1,
      sym_identifier,
    ACTIONS(16419), 1,
      sym_quoted_identifier,
    STATE(11453), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278943] = 5,
    ACTIONS(16421), 1,
      sym_identifier,
    ACTIONS(16423), 1,
      sym_quoted_identifier,
    STATE(11454), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278971] = 5,
    ACTIONS(16425), 1,
      sym_identifier,
    ACTIONS(16427), 1,
      sym_quoted_identifier,
    STATE(11455), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [278999] = 5,
    ACTIONS(16429), 1,
      sym_identifier,
    ACTIONS(16431), 1,
      sym_quoted_identifier,
    STATE(11456), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279027] = 5,
    ACTIONS(16433), 1,
      sym_identifier,
    ACTIONS(16435), 1,
      sym_quoted_identifier,
    STATE(11457), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279055] = 5,
    ACTIONS(16437), 1,
      sym_identifier,
    ACTIONS(16439), 1,
      sym_quoted_identifier,
    STATE(11458), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279083] = 5,
    ACTIONS(16441), 1,
      sym_identifier,
    ACTIONS(16443), 1,
      sym_quoted_identifier,
    STATE(11459), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279111] = 5,
    ACTIONS(16445), 1,
      sym_identifier,
    ACTIONS(16447), 1,
      sym_quoted_identifier,
    STATE(11460), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279139] = 5,
    ACTIONS(16449), 1,
      sym_identifier,
    ACTIONS(16451), 1,
      sym_quoted_identifier,
    STATE(11461), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279167] = 5,
    ACTIONS(16453), 1,
      sym_identifier,
    ACTIONS(16455), 1,
      sym_quoted_identifier,
    STATE(11462), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279195] = 5,
    ACTIONS(16457), 1,
      sym_identifier,
    ACTIONS(16459), 1,
      sym_quoted_identifier,
    STATE(11463), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279223] = 5,
    ACTIONS(16461), 1,
      sym_identifier,
    ACTIONS(16463), 1,
      sym_quoted_identifier,
    STATE(11465), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279251] = 5,
    ACTIONS(16465), 1,
      sym_identifier,
    ACTIONS(16467), 1,
      sym_quoted_identifier,
    STATE(11466), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279279] = 5,
    ACTIONS(16469), 1,
      sym_identifier,
    ACTIONS(16471), 1,
      sym_quoted_identifier,
    STATE(11467), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279307] = 5,
    ACTIONS(16473), 1,
      sym_identifier,
    ACTIONS(16475), 1,
      sym_quoted_identifier,
    STATE(11468), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279335] = 5,
    ACTIONS(16477), 1,
      sym_identifier,
    ACTIONS(16479), 1,
      sym_quoted_identifier,
    STATE(11469), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279363] = 5,
    ACTIONS(16481), 1,
      sym_identifier,
    ACTIONS(16483), 1,
      sym_quoted_identifier,
    STATE(11176), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279391] = 5,
    ACTIONS(16485), 1,
      sym_identifier,
    ACTIONS(16487), 1,
      sym_quoted_identifier,
    STATE(11475), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279419] = 5,
    ACTIONS(16489), 1,
      sym_identifier,
    ACTIONS(16491), 1,
      sym_quoted_identifier,
    STATE(11483), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279447] = 5,
    ACTIONS(16493), 1,
      sym_identifier,
    ACTIONS(16495), 1,
      sym_quoted_identifier,
    STATE(11484), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279475] = 5,
    ACTIONS(16497), 1,
      sym_identifier,
    ACTIONS(16499), 1,
      sym_quoted_identifier,
    STATE(11485), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279503] = 5,
    ACTIONS(16501), 1,
      sym_identifier,
    ACTIONS(16503), 1,
      sym_quoted_identifier,
    STATE(11486), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279531] = 5,
    ACTIONS(16505), 1,
      sym_identifier,
    ACTIONS(16507), 1,
      sym_quoted_identifier,
    STATE(11487), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279559] = 5,
    ACTIONS(16509), 1,
      sym_identifier,
    ACTIONS(16511), 1,
      sym_quoted_identifier,
    STATE(12009), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279587] = 5,
    ACTIONS(16513), 1,
      sym_identifier,
    ACTIONS(16515), 1,
      sym_quoted_identifier,
    STATE(11516), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279615] = 5,
    ACTIONS(16517), 1,
      sym_identifier,
    ACTIONS(16519), 1,
      sym_quoted_identifier,
    STATE(11197), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279643] = 5,
    ACTIONS(16521), 1,
      sym_identifier,
    ACTIONS(16523), 1,
      sym_quoted_identifier,
    STATE(12571), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279671] = 5,
    ACTIONS(16525), 1,
      sym_identifier,
    ACTIONS(16527), 1,
      sym_quoted_identifier,
    STATE(11524), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279699] = 5,
    STATE(8628), 1,
      aux_sym_preproc_split_if_else_statement_repeat1,
    STATE(9941), 1,
      sym_preproc_elif,
    ACTIONS(16529), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(16532), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [279727] = 5,
    ACTIONS(16534), 1,
      sym_identifier,
    ACTIONS(16536), 1,
      sym_quoted_identifier,
    STATE(11207), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279755] = 5,
    ACTIONS(16538), 1,
      sym_identifier,
    ACTIONS(16540), 1,
      sym_quoted_identifier,
    STATE(11540), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279783] = 5,
    ACTIONS(16542), 1,
      sym_identifier,
    ACTIONS(16544), 1,
      sym_quoted_identifier,
    STATE(11544), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279811] = 5,
    ACTIONS(16546), 1,
      sym_identifier,
    ACTIONS(16548), 1,
      sym_quoted_identifier,
    STATE(11545), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279839] = 5,
    ACTIONS(16550), 1,
      sym_identifier,
    ACTIONS(16552), 1,
      sym_quoted_identifier,
    STATE(11560), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279867] = 5,
    ACTIONS(16554), 1,
      sym_identifier,
    ACTIONS(16556), 1,
      sym_quoted_identifier,
    STATE(11562), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279895] = 5,
    ACTIONS(16558), 1,
      sym_identifier,
    ACTIONS(16560), 1,
      sym_quoted_identifier,
    STATE(11564), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279923] = 5,
    ACTIONS(16562), 1,
      sym_identifier,
    ACTIONS(16564), 1,
      sym_quoted_identifier,
    STATE(11565), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279951] = 5,
    ACTIONS(16566), 1,
      sym_identifier,
    ACTIONS(16568), 1,
      sym_quoted_identifier,
    STATE(11569), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [279979] = 5,
    ACTIONS(16570), 1,
      sym_identifier,
    ACTIONS(16572), 1,
      sym_quoted_identifier,
    STATE(11573), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280007] = 5,
    ACTIONS(16574), 1,
      sym_identifier,
    ACTIONS(16576), 1,
      sym_quoted_identifier,
    STATE(11574), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280035] = 5,
    ACTIONS(16578), 1,
      sym_identifier,
    ACTIONS(16580), 1,
      sym_quoted_identifier,
    STATE(11575), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280063] = 5,
    ACTIONS(16582), 1,
      sym_identifier,
    ACTIONS(16584), 1,
      sym_quoted_identifier,
    STATE(11576), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280091] = 5,
    ACTIONS(16586), 1,
      sym_identifier,
    ACTIONS(16588), 1,
      sym_quoted_identifier,
    STATE(11577), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280119] = 5,
    ACTIONS(16590), 1,
      sym_identifier,
    ACTIONS(16592), 1,
      sym_quoted_identifier,
    STATE(11578), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280147] = 5,
    ACTIONS(16594), 1,
      sym_identifier,
    ACTIONS(16596), 1,
      sym_quoted_identifier,
    STATE(11579), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280175] = 5,
    ACTIONS(16598), 1,
      sym_identifier,
    ACTIONS(16600), 1,
      sym_quoted_identifier,
    STATE(11580), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280203] = 5,
    ACTIONS(16602), 1,
      sym_identifier,
    ACTIONS(16604), 1,
      sym_quoted_identifier,
    STATE(11581), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280231] = 5,
    ACTIONS(16606), 1,
      sym_identifier,
    ACTIONS(16608), 1,
      sym_quoted_identifier,
    STATE(11583), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280259] = 5,
    ACTIONS(16610), 1,
      sym_identifier,
    ACTIONS(16612), 1,
      sym_quoted_identifier,
    STATE(11584), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280287] = 5,
    ACTIONS(16614), 1,
      sym_identifier,
    ACTIONS(16616), 1,
      sym_quoted_identifier,
    STATE(11585), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280315] = 5,
    ACTIONS(16618), 1,
      sym_identifier,
    ACTIONS(16620), 1,
      sym_quoted_identifier,
    STATE(11586), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280343] = 5,
    ACTIONS(16622), 1,
      sym_identifier,
    ACTIONS(16624), 1,
      sym_quoted_identifier,
    STATE(11587), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280371] = 5,
    ACTIONS(16626), 1,
      sym_identifier,
    ACTIONS(16628), 1,
      sym_quoted_identifier,
    STATE(11588), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280399] = 5,
    ACTIONS(16630), 1,
      sym_identifier,
    ACTIONS(16632), 1,
      sym_quoted_identifier,
    STATE(11589), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280427] = 5,
    ACTIONS(16634), 1,
      sym_identifier,
    ACTIONS(16636), 1,
      sym_quoted_identifier,
    STATE(11590), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280455] = 5,
    ACTIONS(16638), 1,
      sym_identifier,
    ACTIONS(16640), 1,
      sym_quoted_identifier,
    STATE(11591), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280483] = 5,
    ACTIONS(16642), 1,
      sym_identifier,
    ACTIONS(16644), 1,
      sym_quoted_identifier,
    STATE(11592), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280511] = 5,
    ACTIONS(16646), 1,
      sym_identifier,
    ACTIONS(16648), 1,
      sym_quoted_identifier,
    STATE(11593), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280539] = 5,
    ACTIONS(16650), 1,
      sym_identifier,
    ACTIONS(16652), 1,
      sym_quoted_identifier,
    STATE(11595), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280567] = 5,
    ACTIONS(16654), 1,
      sym_identifier,
    ACTIONS(16656), 1,
      sym_quoted_identifier,
    STATE(11596), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280595] = 5,
    ACTIONS(16658), 1,
      sym_identifier,
    ACTIONS(16660), 1,
      sym_quoted_identifier,
    STATE(11597), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280623] = 5,
    ACTIONS(16662), 1,
      sym_identifier,
    ACTIONS(16664), 1,
      sym_quoted_identifier,
    STATE(11598), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280651] = 5,
    ACTIONS(16666), 1,
      sym_identifier,
    ACTIONS(16668), 1,
      sym_quoted_identifier,
    STATE(11599), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280679] = 5,
    ACTIONS(16670), 1,
      sym_identifier,
    ACTIONS(16672), 1,
      sym_quoted_identifier,
    STATE(11224), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280707] = 5,
    ACTIONS(16674), 1,
      sym_identifier,
    ACTIONS(16676), 1,
      sym_quoted_identifier,
    STATE(11605), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280735] = 5,
    ACTIONS(16678), 1,
      sym_identifier,
    ACTIONS(16680), 1,
      sym_quoted_identifier,
    STATE(11606), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280763] = 5,
    ACTIONS(16682), 1,
      sym_identifier,
    ACTIONS(16684), 1,
      sym_quoted_identifier,
    STATE(11607), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280791] = 5,
    ACTIONS(16686), 1,
      sym_identifier,
    ACTIONS(16688), 1,
      sym_quoted_identifier,
    STATE(11608), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280819] = 5,
    ACTIONS(16690), 1,
      sym_identifier,
    ACTIONS(16692), 1,
      sym_quoted_identifier,
    STATE(12010), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280847] = 5,
    ACTIONS(16694), 1,
      sym_identifier,
    ACTIONS(16696), 1,
      sym_quoted_identifier,
    STATE(11656), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280875] = 5,
    ACTIONS(16698), 1,
      sym_identifier,
    ACTIONS(16700), 1,
      sym_quoted_identifier,
    STATE(11658), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280903] = 5,
    ACTIONS(16702), 1,
      sym_identifier,
    ACTIONS(16704), 1,
      sym_quoted_identifier,
    STATE(11660), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280931] = 5,
    ACTIONS(16706), 1,
      sym_identifier,
    ACTIONS(16708), 1,
      sym_quoted_identifier,
    STATE(11666), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280959] = 5,
    ACTIONS(16710), 1,
      sym_identifier,
    ACTIONS(16712), 1,
      sym_quoted_identifier,
    STATE(11667), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [280987] = 5,
    ACTIONS(16714), 1,
      sym_identifier,
    ACTIONS(16716), 1,
      sym_quoted_identifier,
    STATE(11668), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281015] = 5,
    ACTIONS(16718), 1,
      sym_identifier,
    ACTIONS(16720), 1,
      sym_quoted_identifier,
    STATE(11669), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281043] = 5,
    ACTIONS(16722), 1,
      sym_identifier,
    ACTIONS(16724), 1,
      sym_quoted_identifier,
    STATE(11670), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281071] = 5,
    ACTIONS(16726), 1,
      sym_identifier,
    ACTIONS(16728), 1,
      sym_quoted_identifier,
    STATE(11671), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281099] = 5,
    ACTIONS(16730), 1,
      sym_identifier,
    ACTIONS(16732), 1,
      sym_quoted_identifier,
    STATE(11253), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281127] = 5,
    ACTIONS(16734), 1,
      sym_identifier,
    ACTIONS(16736), 1,
      sym_quoted_identifier,
    STATE(11673), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281155] = 5,
    ACTIONS(16738), 1,
      sym_identifier,
    ACTIONS(16740), 1,
      sym_quoted_identifier,
    STATE(11674), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281183] = 5,
    ACTIONS(16742), 1,
      sym_identifier,
    ACTIONS(16744), 1,
      sym_quoted_identifier,
    STATE(11675), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281211] = 5,
    ACTIONS(16746), 1,
      sym_identifier,
    ACTIONS(16748), 1,
      sym_quoted_identifier,
    STATE(11677), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281239] = 5,
    ACTIONS(16750), 1,
      sym_identifier,
    ACTIONS(16752), 1,
      sym_quoted_identifier,
    STATE(11678), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281267] = 5,
    ACTIONS(16754), 1,
      sym_identifier,
    ACTIONS(16756), 1,
      sym_quoted_identifier,
    STATE(11679), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281295] = 5,
    ACTIONS(16758), 1,
      sym_identifier,
    ACTIONS(16760), 1,
      sym_quoted_identifier,
    STATE(11680), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281323] = 5,
    ACTIONS(16762), 1,
      sym_identifier,
    ACTIONS(16764), 1,
      sym_quoted_identifier,
    STATE(11681), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281351] = 5,
    ACTIONS(16766), 1,
      sym_identifier,
    ACTIONS(16768), 1,
      sym_quoted_identifier,
    STATE(11686), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281379] = 5,
    ACTIONS(16770), 1,
      sym_identifier,
    ACTIONS(16772), 1,
      sym_quoted_identifier,
    STATE(11687), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281407] = 5,
    ACTIONS(16774), 1,
      sym_identifier,
    ACTIONS(16776), 1,
      sym_quoted_identifier,
    STATE(11688), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281435] = 5,
    ACTIONS(16778), 1,
      sym_identifier,
    ACTIONS(16780), 1,
      sym_quoted_identifier,
    STATE(11734), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281463] = 5,
    ACTIONS(16782), 1,
      sym_identifier,
    ACTIONS(16784), 1,
      sym_quoted_identifier,
    STATE(11736), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281491] = 5,
    ACTIONS(16786), 1,
      sym_identifier,
    ACTIONS(16788), 1,
      sym_quoted_identifier,
    STATE(11738), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281519] = 5,
    ACTIONS(16790), 1,
      sym_identifier,
    ACTIONS(16792), 1,
      sym_quoted_identifier,
    STATE(11744), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281547] = 5,
    ACTIONS(16794), 1,
      sym_identifier,
    ACTIONS(16796), 1,
      sym_quoted_identifier,
    STATE(11745), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281575] = 5,
    ACTIONS(16798), 1,
      sym_identifier,
    ACTIONS(16800), 1,
      sym_quoted_identifier,
    STATE(12618), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281603] = 5,
    ACTIONS(16802), 1,
      sym_identifier,
    ACTIONS(16804), 1,
      sym_quoted_identifier,
    STATE(8834), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281631] = 5,
    ACTIONS(16806), 1,
      sym_identifier,
    ACTIONS(16808), 1,
      sym_quoted_identifier,
    STATE(8777), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3060), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281659] = 5,
    STATE(7225), 1,
      sym_preproc_elif,
    STATE(8698), 1,
      aux_sym_preproc_conditional_where_repeat2,
    ACTIONS(16810), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14123), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [281687] = 5,
    ACTIONS(16813), 1,
      sym_identifier,
    ACTIONS(16815), 1,
      sym_quoted_identifier,
    STATE(11777), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281715] = 5,
    STATE(8700), 1,
      aux_sym_preproc_split_if_statement_repeat1,
    STATE(9747), 1,
      sym_preproc_elif,
    ACTIONS(16817), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(16820), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [281743] = 5,
    ACTIONS(16822), 1,
      sym_identifier,
    ACTIONS(16824), 1,
      sym_quoted_identifier,
    STATE(11797), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281771] = 5,
    ACTIONS(16826), 1,
      sym_identifier,
    ACTIONS(16828), 1,
      sym_quoted_identifier,
    STATE(11809), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281799] = 5,
    ACTIONS(16830), 1,
      sym_identifier,
    ACTIONS(16832), 1,
      sym_quoted_identifier,
    STATE(11820), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281827] = 5,
    ACTIONS(16834), 1,
      sym_identifier,
    ACTIONS(16836), 1,
      sym_quoted_identifier,
    STATE(11898), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281855] = 5,
    ACTIONS(16838), 1,
      sym_identifier,
    ACTIONS(16840), 1,
      sym_quoted_identifier,
    STATE(11899), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281883] = 5,
    ACTIONS(16842), 1,
      sym_identifier,
    ACTIONS(16844), 1,
      sym_quoted_identifier,
    STATE(11902), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281911] = 5,
    ACTIONS(16846), 1,
      sym_identifier,
    ACTIONS(16848), 1,
      sym_quoted_identifier,
    STATE(11903), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281939] = 5,
    ACTIONS(16850), 1,
      sym_identifier,
    ACTIONS(16852), 1,
      sym_quoted_identifier,
    STATE(11904), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281967] = 5,
    ACTIONS(16854), 1,
      sym_identifier,
    ACTIONS(16856), 1,
      sym_quoted_identifier,
    STATE(11905), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [281995] = 5,
    ACTIONS(16858), 1,
      sym_identifier,
    ACTIONS(16860), 1,
      sym_quoted_identifier,
    STATE(11906), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282023] = 7,
    ACTIONS(14283), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14287), 1,
      aux_sym_modify_modification_token1,
    STATE(9023), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    STATE(8728), 4,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_preproc_conditional_fields_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [282055] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(16862), 12,
      sym_preproc_close,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [282077] = 5,
    ACTIONS(16864), 1,
      sym_identifier,
    ACTIONS(16866), 1,
      sym_quoted_identifier,
    STATE(11404), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282105] = 7,
    ACTIONS(16868), 1,
      anon_sym_RBRACE,
    ACTIONS(16870), 1,
      anon_sym_LBRACK,
    ACTIONS(16876), 1,
      sym_key_keyword,
    STATE(7464), 1,
      sym_preproc_if,
    ACTIONS(16873), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    STATE(8714), 4,
      sym_preproc_conditional_keys,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_keys_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [282137] = 5,
    ACTIONS(16879), 1,
      sym_identifier,
    ACTIONS(16881), 1,
      sym_quoted_identifier,
    STATE(11417), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282165] = 5,
    ACTIONS(16883), 1,
      sym_identifier,
    ACTIONS(16885), 1,
      sym_quoted_identifier,
    STATE(11431), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282193] = 5,
    ACTIONS(16887), 1,
      sym_identifier,
    ACTIONS(16889), 1,
      sym_quoted_identifier,
    STATE(11471), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282221] = 5,
    ACTIONS(16891), 1,
      sym_identifier,
    ACTIONS(16893), 1,
      sym_quoted_identifier,
    STATE(12059), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282249] = 7,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(15539), 1,
      sym_key_keyword,
    ACTIONS(16895), 1,
      anon_sym_RBRACE,
    STATE(7464), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    STATE(8735), 4,
      sym_preproc_conditional_keys,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_keys_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [282281] = 5,
    STATE(8720), 1,
      aux_sym_preproc_split_procedure_repeat1,
    STATE(8965), 1,
      sym_preproc_elif,
    ACTIONS(16897), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(16900), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [282309] = 5,
    ACTIONS(16902), 1,
      sym_identifier,
    ACTIONS(16904), 1,
      sym_quoted_identifier,
    STATE(11557), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282337] = 5,
    ACTIONS(16906), 1,
      sym_identifier,
    ACTIONS(16908), 1,
      sym_quoted_identifier,
    STATE(11566), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282365] = 5,
    ACTIONS(16910), 1,
      sym_identifier,
    ACTIONS(16912), 1,
      sym_quoted_identifier,
    STATE(11568), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282393] = 5,
    ACTIONS(16914), 1,
      sym_identifier,
    ACTIONS(16916), 1,
      sym_quoted_identifier,
    STATE(11613), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282421] = 5,
    ACTIONS(16918), 1,
      sym_identifier,
    ACTIONS(16920), 1,
      sym_quoted_identifier,
    STATE(11645), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282449] = 5,
    ACTIONS(16922), 1,
      sym_identifier,
    ACTIONS(16924), 1,
      sym_quoted_identifier,
    STATE(11636), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282477] = 5,
    ACTIONS(16926), 1,
      sym_identifier,
    ACTIONS(16928), 1,
      sym_quoted_identifier,
    STATE(11653), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282505] = 7,
    ACTIONS(14283), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14287), 1,
      aux_sym_modify_modification_token1,
    STATE(9003), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    STATE(7548), 4,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_preproc_conditional_fields_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [282537] = 5,
    ACTIONS(16930), 1,
      sym_identifier,
    ACTIONS(16932), 1,
      sym_quoted_identifier,
    STATE(11693), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282565] = 5,
    ACTIONS(16934), 1,
      sym_identifier,
    ACTIONS(16936), 1,
      sym_quoted_identifier,
    STATE(11708), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282593] = 5,
    ACTIONS(16938), 1,
      sym_identifier,
    ACTIONS(16940), 1,
      sym_quoted_identifier,
    STATE(11717), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282621] = 5,
    ACTIONS(16942), 1,
      sym_identifier,
    ACTIONS(16944), 1,
      sym_quoted_identifier,
    STATE(11925), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282649] = 5,
    ACTIONS(16946), 1,
      sym_identifier,
    ACTIONS(16948), 1,
      sym_quoted_identifier,
    STATE(11927), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282677] = 7,
    ACTIONS(14283), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14287), 1,
      aux_sym_modify_modification_token1,
    STATE(9003), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    STATE(8478), 4,
      sym_field_declaration,
      sym_modify_modification,
      sym_attribute_item,
      aux_sym_preproc_conditional_fields_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [282709] = 7,
    ACTIONS(14113), 1,
      anon_sym_LBRACK,
    ACTIONS(15539), 1,
      sym_key_keyword,
    ACTIONS(16950), 1,
      anon_sym_RBRACE,
    STATE(7464), 1,
      sym_preproc_if,
    ACTIONS(10170), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    STATE(8714), 4,
      sym_preproc_conditional_keys,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_keys_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [282741] = 5,
    ACTIONS(16952), 1,
      sym_identifier,
    ACTIONS(16954), 1,
      sym_quoted_identifier,
    STATE(11930), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282769] = 5,
    ACTIONS(16956), 1,
      sym_identifier,
    ACTIONS(16958), 1,
      sym_quoted_identifier,
    STATE(12662), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282797] = 5,
    STATE(7546), 1,
      sym_preproc_elif,
    STATE(8738), 1,
      aux_sym_preproc_conditional_fields_repeat2,
    ACTIONS(16960), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14562), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [282825] = 5,
    ACTIONS(16963), 1,
      sym_identifier,
    ACTIONS(16965), 1,
      sym_quoted_identifier,
    STATE(11369), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282853] = 5,
    ACTIONS(16967), 1,
      sym_identifier,
    ACTIONS(16969), 1,
      sym_quoted_identifier,
    STATE(11262), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282881] = 5,
    ACTIONS(16971), 1,
      sym_identifier,
    ACTIONS(16973), 1,
      sym_quoted_identifier,
    STATE(11949), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282909] = 5,
    ACTIONS(16975), 1,
      sym_identifier,
    ACTIONS(16977), 1,
      sym_quoted_identifier,
    STATE(11953), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282937] = 5,
    ACTIONS(16979), 1,
      sym_identifier,
    ACTIONS(16981), 1,
      sym_quoted_identifier,
    STATE(12310), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282965] = 5,
    ACTIONS(16983), 1,
      sym_identifier,
    ACTIONS(16985), 1,
      sym_quoted_identifier,
    STATE(12311), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [282993] = 5,
    ACTIONS(16987), 1,
      sym_identifier,
    ACTIONS(16989), 1,
      sym_quoted_identifier,
    STATE(12312), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283021] = 5,
    ACTIONS(16991), 1,
      sym_identifier,
    ACTIONS(16993), 1,
      sym_quoted_identifier,
    STATE(12313), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283049] = 5,
    ACTIONS(16995), 1,
      sym_identifier,
    ACTIONS(16997), 1,
      sym_quoted_identifier,
    STATE(12314), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283077] = 5,
    ACTIONS(16999), 1,
      sym_identifier,
    ACTIONS(17001), 1,
      sym_quoted_identifier,
    STATE(12315), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283105] = 5,
    ACTIONS(17003), 1,
      sym_identifier,
    ACTIONS(17005), 1,
      sym_quoted_identifier,
    STATE(11476), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283133] = 5,
    ACTIONS(17007), 1,
      sym_identifier,
    ACTIONS(17009), 1,
      sym_quoted_identifier,
    STATE(12321), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283161] = 5,
    ACTIONS(17011), 1,
      sym_identifier,
    ACTIONS(17013), 1,
      sym_quoted_identifier,
    STATE(12332), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283189] = 5,
    ACTIONS(17015), 1,
      sym_identifier,
    ACTIONS(17017), 1,
      sym_quoted_identifier,
    STATE(12371), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283217] = 5,
    ACTIONS(17019), 1,
      sym_identifier,
    ACTIONS(17021), 1,
      sym_quoted_identifier,
    STATE(12372), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283245] = 5,
    ACTIONS(17023), 1,
      sym_identifier,
    ACTIONS(17025), 1,
      sym_quoted_identifier,
    STATE(12373), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283273] = 5,
    ACTIONS(17027), 1,
      sym_identifier,
    ACTIONS(17029), 1,
      sym_quoted_identifier,
    STATE(12374), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283301] = 5,
    ACTIONS(17031), 1,
      sym_identifier,
    ACTIONS(17033), 1,
      sym_quoted_identifier,
    STATE(12375), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283329] = 5,
    ACTIONS(17035), 1,
      sym_identifier,
    ACTIONS(17037), 1,
      sym_quoted_identifier,
    STATE(12376), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283357] = 5,
    ACTIONS(17039), 1,
      sym_identifier,
    ACTIONS(17041), 1,
      sym_quoted_identifier,
    STATE(12412), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283385] = 5,
    ACTIONS(17043), 1,
      sym_identifier,
    ACTIONS(17045), 1,
      sym_quoted_identifier,
    STATE(12413), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283413] = 5,
    ACTIONS(17047), 1,
      sym_identifier,
    ACTIONS(17049), 1,
      sym_quoted_identifier,
    STATE(12414), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283441] = 5,
    ACTIONS(17051), 1,
      sym_identifier,
    ACTIONS(17053), 1,
      sym_quoted_identifier,
    STATE(12415), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283469] = 5,
    STATE(7659), 1,
      sym_preproc_elif,
    STATE(8762), 1,
      aux_sym_preproc_conditional_keys_repeat2,
    ACTIONS(17055), 3,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14889), 7,
      sym_preproc_close,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [283497] = 5,
    ACTIONS(17058), 1,
      sym_identifier,
    ACTIONS(17060), 1,
      sym_quoted_identifier,
    STATE(11975), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283525] = 5,
    ACTIONS(17062), 1,
      sym_identifier,
    ACTIONS(17064), 1,
      sym_quoted_identifier,
    STATE(11976), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283553] = 5,
    ACTIONS(17066), 1,
      sym_identifier,
    ACTIONS(17068), 1,
      sym_quoted_identifier,
    STATE(11986), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283581] = 5,
    ACTIONS(17070), 1,
      sym_identifier,
    ACTIONS(17072), 1,
      sym_quoted_identifier,
    STATE(11989), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283609] = 5,
    ACTIONS(17074), 1,
      sym_identifier,
    ACTIONS(17076), 1,
      sym_quoted_identifier,
    STATE(11434), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2209), 8,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
  [283637] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17078), 11,
      aux_sym_area_section_token3,
      aux_sym_area_section_token5,
      aux_sym_area_section_token8,
      aux_sym_action_area_section_token1,
      aux_sym_action_area_section_token2,
      aux_sym_action_area_section_token3,
      aux_sym_action_area_section_token4,
      aux_sym_action_area_section_token5,
      aux_sym_action_area_section_token6,
      aux_sym_action_area_section_token7,
      sym_identifier,
  [283658] = 3,
    ACTIONS(17080), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [283681] = 3,
    ACTIONS(17082), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15366), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [283704] = 3,
    ACTIONS(17084), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [283727] = 3,
    ACTIONS(17086), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14011), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [283750] = 3,
    ACTIONS(17088), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13955), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [283773] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2631), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [283794] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17090), 11,
      aux_sym_area_section_token3,
      aux_sym_area_section_token5,
      aux_sym_area_section_token8,
      aux_sym_action_area_section_token1,
      aux_sym_action_area_section_token2,
      aux_sym_action_area_section_token3,
      aux_sym_action_area_section_token4,
      aux_sym_action_area_section_token5,
      aux_sym_action_area_section_token6,
      aux_sym_action_area_section_token7,
      sym_identifier,
  [283815] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2635), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [283836] = 3,
    ACTIONS(17092), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15366), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [283859] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13770), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [283880] = 3,
    ACTIONS(17094), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17096), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [283903] = 3,
    ACTIONS(17098), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17100), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [283926] = 3,
    ACTIONS(17102), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17100), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [283949] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2553), 11,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [283970] = 3,
    ACTIONS(17104), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17106), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [283993] = 3,
    ACTIONS(17108), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17100), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284016] = 3,
    ACTIONS(17110), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17106), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284039] = 3,
    ACTIONS(17112), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17100), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284062] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2428), 11,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [284083] = 3,
    ACTIONS(17114), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17100), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284106] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17116), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284127] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17118), 11,
      aux_sym_area_section_token3,
      aux_sym_area_section_token5,
      aux_sym_area_section_token8,
      aux_sym_action_area_section_token1,
      aux_sym_action_area_section_token2,
      aux_sym_action_area_section_token3,
      aux_sym_action_area_section_token4,
      aux_sym_action_area_section_token5,
      aux_sym_action_area_section_token6,
      aux_sym_action_area_section_token7,
      sym_identifier,
  [284148] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13794), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284169] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17120), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284190] = 3,
    ACTIONS(17122), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17124), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284213] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17126), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284234] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2643), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284255] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2405), 11,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [284276] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2647), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284297] = 3,
    ACTIONS(17128), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15366), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284320] = 3,
    ACTIONS(17130), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15366), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284343] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17132), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284364] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2575), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284385] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2587), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284406] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2579), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284427] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2428), 11,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [284448] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2587), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284469] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2587), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284490] = 3,
    ACTIONS(17134), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17136), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284513] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2627), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284534] = 3,
    ACTIONS(17138), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13959), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284557] = 3,
    ACTIONS(17140), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13963), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284580] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13176), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284601] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2583), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284622] = 3,
    ACTIONS(17142), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2621), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [284645] = 3,
    ACTIONS(17144), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14032), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284668] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2571), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284689] = 3,
    ACTIONS(17146), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14044), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284712] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2591), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284733] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2591), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284754] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2591), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284775] = 3,
    ACTIONS(17148), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14017), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284798] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17150), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284819] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17152), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284840] = 3,
    ACTIONS(17154), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17156), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284863] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17158), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284884] = 3,
    ACTIONS(17160), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17162), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284907] = 3,
    ACTIONS(17164), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15366), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284930] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2416), 11,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [284951] = 3,
    ACTIONS(17166), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17168), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284974] = 3,
    ACTIONS(17170), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17172), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [284997] = 3,
    ACTIONS(17174), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17176), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285020] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2420), 11,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [285041] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13178), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285062] = 3,
    ACTIONS(17180), 2,
      sym_quoted_identifier,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17178), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [285085] = 3,
    ACTIONS(17182), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15366), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285108] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2651), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285129] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2531), 11,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [285150] = 3,
    ACTIONS(17184), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15901), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285173] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2424), 11,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [285194] = 3,
    ACTIONS(17186), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13951), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285217] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 11,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285238] = 3,
    ACTIONS(17188), 1,
      sym_temporary_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2535), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [285261] = 3,
    ACTIONS(17190), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285284] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2541), 11,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_COMMA,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [285305] = 3,
    ACTIONS(17192), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2615), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [285328] = 6,
    ACTIONS(17194), 1,
      anon_sym_SEMI,
    STATE(2261), 1,
      sym_preproc_endif,
    STATE(11987), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [285356] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2571), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [285376] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17198), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285396] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17200), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285416] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17202), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285436] = 6,
    ACTIONS(17204), 1,
      anon_sym_SEMI,
    STATE(1817), 1,
      sym_preproc_endif,
    STATE(11642), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [285464] = 6,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14425), 1,
      sym_key_keyword,
    STATE(9050), 1,
      sym_preproc_endif,
    STATE(7751), 3,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_preproc_conditional_keys_repeat1,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [285492] = 6,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14425), 1,
      sym_key_keyword,
    STATE(9050), 1,
      sym_preproc_endif,
    STATE(8894), 3,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_preproc_conditional_keys_repeat1,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [285520] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17100), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285540] = 6,
    ACTIONS(17206), 1,
      anon_sym_SEMI,
    STATE(1818), 1,
      sym_preproc_endif,
    STATE(11643), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [285568] = 6,
    ACTIONS(17208), 1,
      anon_sym_SEMI,
    STATE(1819), 1,
      sym_preproc_endif,
    STATE(11646), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [285596] = 6,
    ACTIONS(17210), 1,
      anon_sym_SEMI,
    STATE(1652), 1,
      sym_preproc_endif,
    STATE(11541), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [285624] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2587), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [285644] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17212), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285664] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17214), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285684] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17216), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285704] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17218), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285724] = 6,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14411), 1,
      sym_dataitem_keyword,
    STATE(8241), 1,
      sym_preproc_endif,
    STATE(7719), 3,
      sym_report_dataitem,
      sym_attribute_item,
      aux_sym_preproc_conditional_dataset_repeat1,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [285752] = 6,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14411), 1,
      sym_dataitem_keyword,
    STATE(8241), 1,
      sym_preproc_endif,
    STATE(8878), 3,
      sym_report_dataitem,
      sym_attribute_item,
      aux_sym_preproc_conditional_dataset_repeat1,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [285780] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2643), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [285800] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2647), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [285820] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17220), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285840] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13989), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285860] = 6,
    ACTIONS(17222), 1,
      anon_sym_SEMI,
    STATE(1553), 1,
      sym_preproc_endif,
    STATE(11546), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [285888] = 6,
    ACTIONS(17224), 1,
      anon_sym_SEMI,
    STATE(1554), 1,
      sym_preproc_endif,
    STATE(11547), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [285916] = 6,
    ACTIONS(17226), 1,
      anon_sym_SEMI,
    STATE(1555), 1,
      sym_preproc_endif,
    STATE(11550), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [285944] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13993), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [285964] = 6,
    ACTIONS(17228), 1,
      anon_sym_SEMI,
    STATE(1822), 1,
      sym_preproc_endif,
    STATE(11647), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [285992] = 6,
    ACTIONS(17230), 1,
      anon_sym_SEMI,
    STATE(1559), 1,
      sym_preproc_endif,
    STATE(11551), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [286020] = 6,
    ACTIONS(17232), 1,
      anon_sym_SEMI,
    STATE(1562), 1,
      sym_preproc_endif,
    STATE(11554), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [286048] = 3,
    ACTIONS(17236), 1,
      sym_quoted_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17234), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [286070] = 6,
    ACTIONS(17238), 1,
      anon_sym_SEMI,
    STATE(2267), 1,
      sym_preproc_endif,
    STATE(12071), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [286098] = 6,
    ACTIONS(17240), 1,
      anon_sym_SEMI,
    STATE(2269), 1,
      sym_preproc_endif,
    STATE(12081), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [286126] = 6,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14411), 1,
      sym_dataitem_keyword,
    STATE(8275), 1,
      sym_preproc_endif,
    STATE(7719), 3,
      sym_report_dataitem,
      sym_attribute_item,
      aux_sym_preproc_conditional_dataset_repeat1,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [286154] = 6,
    ACTIONS(17242), 1,
      anon_sym_SEMI,
    STATE(1563), 1,
      sym_preproc_endif,
    STATE(11555), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [286182] = 6,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14411), 1,
      sym_dataitem_keyword,
    STATE(8275), 1,
      sym_preproc_endif,
    STATE(8960), 3,
      sym_report_dataitem,
      sym_attribute_item,
      aux_sym_preproc_conditional_dataset_repeat1,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [286210] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17244), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286230] = 6,
    ACTIONS(17246), 1,
      anon_sym_SEMI,
    STATE(1825), 1,
      sym_preproc_endif,
    STATE(11650), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [286258] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15469), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286278] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17248), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286298] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2651), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [286318] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17250), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286338] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2627), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [286358] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2587), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [286378] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286398] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4381), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286418] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286438] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286458] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286478] = 6,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14425), 1,
      sym_key_keyword,
    STATE(9057), 1,
      sym_preproc_endif,
    STATE(7751), 3,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_preproc_conditional_keys_repeat1,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [286506] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2631), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [286526] = 6,
    ACTIONS(17252), 1,
      anon_sym_SEMI,
    STATE(1826), 1,
      sym_preproc_endif,
    STATE(11651), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [286554] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4401), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286574] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4405), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286594] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4409), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286614] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4413), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286634] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4417), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286654] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4421), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286674] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4425), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286694] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4429), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286714] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2583), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [286734] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4437), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286754] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4441), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286774] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4445), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286794] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4449), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286814] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4453), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286834] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286854] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2587), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [286874] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15366), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286894] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(16210), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286914] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17254), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [286934] = 6,
    ACTIONS(17256), 1,
      anon_sym_SEMI,
    STATE(1833), 1,
      sym_preproc_endif,
    STATE(11652), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [286962] = 6,
    ACTIONS(17258), 1,
      anon_sym_SEMI,
    STATE(1570), 1,
      sym_preproc_endif,
    STATE(11556), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [286990] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2591), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [287010] = 3,
    ACTIONS(17262), 1,
      sym_quoted_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17260), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [287032] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4821), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [287052] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17264), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [287072] = 6,
    ACTIONS(17266), 1,
      anon_sym_SEMI,
    STATE(2389), 1,
      sym_preproc_endif,
    STATE(12572), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287100] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17268), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [287120] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2591), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [287140] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [287160] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2591), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [287180] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13981), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [287200] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13985), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [287220] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17270), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [287240] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4817), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [287260] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17272), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [287280] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13176), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [287300] = 6,
    ACTIONS(17274), 1,
      anon_sym_SEMI,
    STATE(2302), 1,
      sym_preproc_endif,
    STATE(12504), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287328] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2575), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [287348] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13178), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [287368] = 6,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14411), 1,
      sym_dataitem_keyword,
    STATE(8265), 1,
      sym_preproc_endif,
    STATE(8862), 3,
      sym_report_dataitem,
      sym_attribute_item,
      aux_sym_preproc_conditional_dataset_repeat1,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287396] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13931), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [287416] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17106), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [287436] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(257), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [287456] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13939), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [287476] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2579), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [287496] = 6,
    ACTIONS(17276), 1,
      anon_sym_SEMI,
    STATE(1811), 1,
      sym_preproc_endif,
    STATE(11640), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287524] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13943), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [287544] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13947), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [287564] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17278), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [287584] = 6,
    ACTIONS(17280), 1,
      anon_sym_SEMI,
    STATE(10346), 1,
      sym_preproc_endif,
    STATE(11718), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287612] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2635), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_var_keyword,
      sym_local_keyword,
      sym_protected_keyword,
  [287632] = 6,
    ACTIONS(17282), 1,
      anon_sym_SEMI,
    STATE(10063), 1,
      sym_preproc_endif,
    STATE(11720), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287660] = 6,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14425), 1,
      sym_key_keyword,
    STATE(9045), 1,
      sym_preproc_endif,
    STATE(8952), 3,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_preproc_conditional_keys_repeat1,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287688] = 6,
    ACTIONS(17284), 1,
      anon_sym_SEMI,
    STATE(2256), 1,
      sym_preproc_endif,
    STATE(12386), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287716] = 6,
    ACTIONS(17286), 1,
      anon_sym_SEMI,
    STATE(10064), 1,
      sym_preproc_endif,
    STATE(11721), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287744] = 6,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14425), 1,
      sym_key_keyword,
    STATE(9049), 1,
      sym_preproc_endif,
    STATE(7751), 3,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_preproc_conditional_keys_repeat1,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287772] = 6,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14425), 1,
      sym_key_keyword,
    STATE(9049), 1,
      sym_preproc_endif,
    STATE(8851), 3,
      sym_key_declaration,
      sym_attribute_item,
      aux_sym_preproc_conditional_keys_repeat1,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287800] = 6,
    ACTIONS(17288), 1,
      anon_sym_SEMI,
    STATE(10065), 1,
      sym_preproc_endif,
    STATE(11724), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287828] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17290), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [287848] = 6,
    ACTIONS(17292), 1,
      anon_sym_SEMI,
    STATE(10116), 1,
      sym_preproc_endif,
    STATE(11725), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287876] = 6,
    ACTIONS(17294), 1,
      anon_sym_SEMI,
    STATE(10133), 1,
      sym_preproc_endif,
    STATE(11728), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287904] = 6,
    ACTIONS(17296), 1,
      anon_sym_SEMI,
    STATE(10182), 1,
      sym_preproc_endif,
    STATE(11729), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287932] = 6,
    ACTIONS(17298), 1,
      anon_sym_SEMI,
    STATE(10206), 1,
      sym_preproc_endif,
    STATE(11730), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287960] = 6,
    ACTIONS(14285), 1,
      anon_sym_LBRACK,
    ACTIONS(14411), 1,
      sym_dataitem_keyword,
    STATE(8249), 1,
      sym_preproc_endif,
    STATE(7719), 3,
      sym_report_dataitem,
      sym_attribute_item,
      aux_sym_preproc_conditional_dataset_repeat1,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [287988] = 6,
    ACTIONS(17300), 1,
      anon_sym_SEMI,
    STATE(2254), 1,
      sym_preproc_endif,
    STATE(12077), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288016] = 6,
    ACTIONS(17302), 1,
      anon_sym_SEMI,
    STATE(2255), 1,
      sym_preproc_endif,
    STATE(12096), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288044] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4860), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [288064] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4433), 10,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
  [288084] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(8921), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288113] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9408), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288142] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9409), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288171] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9464), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288200] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9466), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288229] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9493), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288258] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9494), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288287] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9509), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288316] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9510), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288345] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9512), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288374] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9513), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288403] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9518), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288432] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9519), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288461] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9525), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288490] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9526), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288519] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9534), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288548] = 6,
    ACTIONS(14401), 1,
      sym_var_keyword,
    STATE(9932), 1,
      sym_var_section,
    STATE(11172), 1,
      sym_preproc_endif,
    ACTIONS(14403), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288575] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9543), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288604] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9544), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288633] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17306), 9,
      aux_sym_area_section_token1,
      aux_sym_area_section_token2,
      aux_sym_area_section_token3,
      aux_sym_area_section_token4,
      aux_sym_area_section_token5,
      aux_sym_area_section_token6,
      aux_sym_area_section_token7,
      aux_sym_area_section_token8,
      sym_identifier,
  [288652] = 6,
    ACTIONS(14401), 1,
      sym_var_keyword,
    STATE(9583), 1,
      sym_var_section,
    STATE(11139), 1,
      sym_preproc_endif,
    ACTIONS(14403), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288679] = 3,
    ACTIONS(17308), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15229), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
  [288700] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17310), 9,
      aux_sym_area_section_token1,
      aux_sym_area_section_token2,
      aux_sym_area_section_token3,
      aux_sym_area_section_token4,
      aux_sym_area_section_token5,
      aux_sym_area_section_token6,
      aux_sym_area_section_token7,
      aux_sym_area_section_token8,
      sym_identifier,
  [288719] = 3,
    ACTIONS(17312), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17314), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_fieldgroup_keyword,
  [288740] = 3,
    ACTIONS(17316), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17318), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_fieldgroup_keyword,
  [288761] = 3,
    ACTIONS(17320), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14613), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_fieldgroup_keyword,
  [288782] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17322), 9,
      aux_sym_area_section_token1,
      aux_sym_area_section_token2,
      aux_sym_area_section_token3,
      aux_sym_area_section_token4,
      aux_sym_area_section_token5,
      aux_sym_area_section_token6,
      aux_sym_area_section_token7,
      aux_sym_area_section_token8,
      sym_identifier,
  [288801] = 6,
    ACTIONS(14401), 1,
      sym_var_keyword,
    STATE(9326), 1,
      sym_var_section,
    STATE(11221), 1,
      sym_preproc_endif,
    ACTIONS(14403), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288828] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17324), 9,
      aux_sym_area_section_token1,
      aux_sym_area_section_token2,
      aux_sym_area_section_token3,
      aux_sym_area_section_token4,
      aux_sym_area_section_token5,
      aux_sym_area_section_token6,
      aux_sym_area_section_token7,
      aux_sym_area_section_token8,
      sym_identifier,
  [288847] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9333), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288876] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9690), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288905] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9357), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288934] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9897), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288963] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9904), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [288992] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9354), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [289021] = 7,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17304), 1,
      sym_procedure_keyword,
    STATE(9535), 1,
      sym__procedure_header,
    STATE(12133), 1,
      sym_procedure_modifier,
    STATE(9005), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [289050] = 6,
    ACTIONS(17326), 1,
      anon_sym_SEMI,
    ACTIONS(17328), 1,
      anon_sym_RBRACE,
    ACTIONS(17330), 1,
      aux_sym_type_declaration_token1,
    ACTIONS(17332), 1,
      sym_property_name,
    STATE(9028), 4,
      sym_empty_statement,
      sym_property,
      sym_type_declaration,
      aux_sym_assembly_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [289076] = 6,
    ACTIONS(17326), 1,
      anon_sym_SEMI,
    ACTIONS(17330), 1,
      aux_sym_type_declaration_token1,
    ACTIONS(17332), 1,
      sym_property_name,
    ACTIONS(17334), 1,
      anon_sym_RBRACE,
    STATE(9018), 4,
      sym_empty_statement,
      sym_property,
      sym_type_declaration,
      aux_sym_assembly_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [289102] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17336), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
  [289120] = 6,
    ACTIONS(17326), 1,
      anon_sym_SEMI,
    ACTIONS(17330), 1,
      aux_sym_type_declaration_token1,
    ACTIONS(17332), 1,
      sym_property_name,
    ACTIONS(17338), 1,
      anon_sym_RBRACE,
    STATE(9017), 4,
      sym_empty_statement,
      sym_property,
      sym_type_declaration,
      aux_sym_assembly_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [289146] = 6,
    ACTIONS(14383), 1,
      anon_sym_LBRACK,
    ACTIONS(17340), 1,
      sym_procedure_keyword,
    STATE(11945), 1,
      sym_procedure_modifier,
    STATE(7487), 2,
      sym_attribute_item,
      aux_sym__procedure_header_repeat1,
    ACTIONS(2891), 3,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [289172] = 6,
    ACTIONS(17326), 1,
      anon_sym_SEMI,
    ACTIONS(17330), 1,
      aux_sym_type_declaration_token1,
    ACTIONS(17332), 1,
      sym_property_name,
    ACTIONS(17342), 1,
      anon_sym_RBRACE,
    STATE(9017), 4,
      sym_empty_statement,
      sym_property,
      sym_type_declaration,
      aux_sym_assembly_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [289198] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17344), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
  [289216] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17346), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_fieldgroup_keyword,
  [289234] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17348), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_fieldgroup_keyword,
  [289252] = 3,
    ACTIONS(17350), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15447), 7,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_key_keyword,
  [289272] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14758), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_fieldgroup_keyword,
  [289290] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14854), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_fieldgroup_keyword,
  [289308] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17352), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
  [289326] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15384), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
  [289344] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14658), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_fieldgroup_keyword,
  [289362] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14694), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_fieldgroup_keyword,
  [289380] = 6,
    ACTIONS(17354), 1,
      anon_sym_SEMI,
    ACTIONS(17357), 1,
      anon_sym_RBRACE,
    ACTIONS(17359), 1,
      aux_sym_type_declaration_token1,
    ACTIONS(17362), 1,
      sym_property_name,
    STATE(9017), 4,
      sym_empty_statement,
      sym_property,
      sym_type_declaration,
      aux_sym_assembly_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [289406] = 6,
    ACTIONS(17326), 1,
      anon_sym_SEMI,
    ACTIONS(17330), 1,
      aux_sym_type_declaration_token1,
    ACTIONS(17332), 1,
      sym_property_name,
    ACTIONS(17365), 1,
      anon_sym_RBRACE,
    STATE(9017), 4,
      sym_empty_statement,
      sym_property,
      sym_type_declaration,
      aux_sym_assembly_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [289432] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_fieldgroup_keyword,
  [289450] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17367), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
  [289468] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14881), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_fieldgroup_keyword,
  [289486] = 6,
    ACTIONS(17326), 1,
      anon_sym_SEMI,
    ACTIONS(17330), 1,
      aux_sym_type_declaration_token1,
    ACTIONS(17332), 1,
      sym_property_name,
    ACTIONS(17369), 1,
      anon_sym_RBRACE,
    STATE(9004), 4,
      sym_empty_statement,
      sym_property,
      sym_type_declaration,
      aux_sym_assembly_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [289512] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17371), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
  [289530] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15415), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_where_condition_token1,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
  [289548] = 6,
    ACTIONS(17326), 1,
      anon_sym_SEMI,
    ACTIONS(17330), 1,
      aux_sym_type_declaration_token1,
    ACTIONS(17332), 1,
      sym_property_name,
    ACTIONS(17373), 1,
      anon_sym_RBRACE,
    STATE(9017), 4,
      sym_empty_statement,
      sym_property,
      sym_type_declaration,
      aux_sym_assembly_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [289574] = 6,
    ACTIONS(17326), 1,
      anon_sym_SEMI,
    ACTIONS(17330), 1,
      aux_sym_type_declaration_token1,
    ACTIONS(17332), 1,
      sym_property_name,
    ACTIONS(17375), 1,
      anon_sym_RBRACE,
    STATE(9017), 4,
      sym_empty_statement,
      sym_property,
      sym_type_declaration,
      aux_sym_assembly_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [289600] = 6,
    ACTIONS(17326), 1,
      anon_sym_SEMI,
    ACTIONS(17330), 1,
      aux_sym_type_declaration_token1,
    ACTIONS(17332), 1,
      sym_property_name,
    ACTIONS(17377), 1,
      anon_sym_RBRACE,
    STATE(9025), 4,
      sym_empty_statement,
      sym_property,
      sym_type_declaration,
      aux_sym_assembly_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [289626] = 6,
    ACTIONS(17326), 1,
      anon_sym_SEMI,
    ACTIONS(17330), 1,
      aux_sym_type_declaration_token1,
    ACTIONS(17332), 1,
      sym_property_name,
    ACTIONS(17379), 1,
      anon_sym_RBRACE,
    STATE(9017), 4,
      sym_empty_statement,
      sym_property,
      sym_type_declaration,
      aux_sym_assembly_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [289652] = 6,
    ACTIONS(17326), 1,
      anon_sym_SEMI,
    ACTIONS(17330), 1,
      aux_sym_type_declaration_token1,
    ACTIONS(17332), 1,
      sym_property_name,
    ACTIONS(17381), 1,
      anon_sym_RBRACE,
    STATE(9026), 4,
      sym_empty_statement,
      sym_property,
      sym_type_declaration,
      aux_sym_assembly_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [289678] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14800), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_fieldgroup_keyword,
  [289696] = 6,
    ACTIONS(17326), 1,
      anon_sym_SEMI,
    ACTIONS(17330), 1,
      aux_sym_type_declaration_token1,
    ACTIONS(17332), 1,
      sym_property_name,
    ACTIONS(17383), 1,
      anon_sym_RBRACE,
    STATE(9006), 4,
      sym_empty_statement,
      sym_property,
      sym_type_declaration,
      aux_sym_assembly_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [289722] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14784), 8,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_fieldgroup_keyword,
  [289740] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17385), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [289757] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17387), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [289774] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17390), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [289791] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9571), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [289808] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10659), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [289825] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17392), 7,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_key_keyword,
  [289842] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10671), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [289859] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17394), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [289876] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10675), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [289893] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10679), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [289910] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15951), 7,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_key_keyword,
  [289927] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17396), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [289944] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17398), 7,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_key_keyword,
  [289961] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17400), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [289978] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10667), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [289995] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10663), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [290012] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17402), 7,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_key_keyword,
  [290029] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17404), 7,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_key_keyword,
  [290046] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9787), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [290063] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(16011), 7,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_key_keyword,
  [290080] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17406), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [290097] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17409), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [290114] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17411), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [290131] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17413), 7,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      sym_view_keyword,
  [290148] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(17415), 7,
      sym_preproc_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_key_keyword,
  [290165] = 4,
    ACTIONS(17417), 1,
      anon_sym_SEMI,
    STATE(9973), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290185] = 4,
    ACTIONS(17419), 1,
      anon_sym_SEMI,
    STATE(2366), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290205] = 4,
    ACTIONS(17421), 1,
      anon_sym_SEMI,
    STATE(2264), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290225] = 4,
    ACTIONS(17423), 1,
      anon_sym_SEMI,
    STATE(2271), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290245] = 4,
    ACTIONS(17425), 1,
      anon_sym_SEMI,
    STATE(2232), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290265] = 4,
    ACTIONS(17427), 1,
      anon_sym_SEMI,
    STATE(12271), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290285] = 4,
    ACTIONS(17429), 1,
      anon_sym_SEMI,
    STATE(2350), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290305] = 4,
    ACTIONS(17431), 1,
      anon_sym_SEMI,
    STATE(1624), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290325] = 4,
    ACTIONS(17433), 1,
      anon_sym_SEMI,
    STATE(1870), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290345] = 4,
    ACTIONS(17435), 1,
      anon_sym_SEMI,
    STATE(2288), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290365] = 4,
    ACTIONS(17437), 1,
      anon_sym_SEMI,
    STATE(1635), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290385] = 4,
    ACTIONS(17439), 1,
      anon_sym_SEMI,
    STATE(1564), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290405] = 4,
    ACTIONS(17441), 1,
      anon_sym_SEMI,
    STATE(1827), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290425] = 4,
    ACTIONS(17443), 1,
      anon_sym_SEMI,
    STATE(1637), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290445] = 4,
    ACTIONS(17445), 1,
      anon_sym_SEMI,
    STATE(2298), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290465] = 4,
    ACTIONS(17447), 1,
      anon_sym_SEMI,
    STATE(1638), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290485] = 4,
    ACTIONS(17449), 1,
      anon_sym_SEMI,
    STATE(1643), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290505] = 4,
    ACTIONS(17451), 1,
      anon_sym_SEMI,
    STATE(1882), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290525] = 4,
    ACTIONS(17453), 1,
      anon_sym_SEMI,
    STATE(1883), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290545] = 4,
    ACTIONS(17455), 1,
      anon_sym_SEMI,
    STATE(1884), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290565] = 4,
    ACTIONS(17457), 1,
      anon_sym_SEMI,
    STATE(1606), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290585] = 4,
    ACTIONS(17459), 1,
      anon_sym_SEMI,
    STATE(1607), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290605] = 4,
    ACTIONS(17461), 1,
      anon_sym_SEMI,
    STATE(1608), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290625] = 4,
    ACTIONS(17463), 1,
      anon_sym_SEMI,
    STATE(1609), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290645] = 4,
    ACTIONS(17465), 1,
      anon_sym_SEMI,
    STATE(1611), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290665] = 4,
    ACTIONS(17467), 1,
      anon_sym_SEMI,
    STATE(1612), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290685] = 4,
    ACTIONS(17469), 1,
      anon_sym_SEMI,
    STATE(1615), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290705] = 4,
    ACTIONS(17471), 1,
      anon_sym_SEMI,
    STATE(1618), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290725] = 4,
    ACTIONS(17473), 1,
      anon_sym_SEMI,
    STATE(1889), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290745] = 4,
    ACTIONS(17475), 1,
      anon_sym_SEMI,
    STATE(1904), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290765] = 4,
    ACTIONS(17477), 1,
      anon_sym_SEMI,
    STATE(1906), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290785] = 4,
    ACTIONS(17479), 1,
      anon_sym_SEMI,
    STATE(2304), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290805] = 4,
    ACTIONS(17481), 1,
      anon_sym_SEMI,
    STATE(2343), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290825] = 4,
    ACTIONS(17483), 1,
      anon_sym_SEMI,
    STATE(1908), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290845] = 4,
    ACTIONS(17485), 1,
      anon_sym_SEMI,
    STATE(1924), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290865] = 4,
    ACTIONS(17487), 1,
      anon_sym_SEMI,
    STATE(2344), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290885] = 4,
    ACTIONS(17489), 1,
      anon_sym_SEMI,
    STATE(1823), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290905] = 4,
    ACTIONS(17491), 1,
      anon_sym_RBRACE,
    STATE(9095), 2,
      sym_xmlport_element,
      aux_sym_schema_section_repeat1,
    ACTIONS(17493), 3,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290925] = 4,
    ACTIONS(17496), 1,
      anon_sym_SEMI,
    STATE(2345), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290945] = 4,
    ACTIONS(17498), 1,
      anon_sym_SEMI,
    STATE(2375), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290965] = 4,
    ACTIONS(17500), 1,
      anon_sym_SEMI,
    STATE(1830), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [290985] = 4,
    ACTIONS(17502), 1,
      anon_sym_SEMI,
    STATE(2262), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291005] = 4,
    ACTIONS(17504), 1,
      anon_sym_SEMI,
    STATE(2312), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291025] = 4,
    ACTIONS(17506), 1,
      anon_sym_SEMI,
    STATE(1835), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291045] = 4,
    ACTIONS(17508), 1,
      anon_sym_SEMI,
    STATE(1836), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291065] = 4,
    ACTIONS(17510), 1,
      anon_sym_SEMI,
    STATE(4328), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291085] = 4,
    ACTIONS(17512), 1,
      anon_sym_SEMI,
    STATE(1837), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291105] = 4,
    ACTIONS(17514), 1,
      anon_sym_SEMI,
    STATE(1846), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291125] = 4,
    ACTIONS(17516), 1,
      anon_sym_SEMI,
    STATE(1847), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291145] = 4,
    ACTIONS(17518), 1,
      anon_sym_SEMI,
    STATE(1848), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291165] = 4,
    ACTIONS(17520), 1,
      anon_sym_SEMI,
    STATE(1849), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291185] = 4,
    ACTIONS(17522), 1,
      anon_sym_SEMI,
    STATE(1851), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291205] = 4,
    ACTIONS(17524), 1,
      anon_sym_SEMI,
    STATE(1852), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291225] = 4,
    ACTIONS(17526), 1,
      anon_sym_SEMI,
    STATE(1855), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291245] = 4,
    ACTIONS(17528), 1,
      anon_sym_SEMI,
    STATE(1858), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291265] = 4,
    ACTIONS(17530), 1,
      anon_sym_SEMI,
    STATE(2318), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291285] = 4,
    ACTIONS(17532), 1,
      anon_sym_SEMI,
    STATE(3310), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291305] = 4,
    ACTIONS(17534), 1,
      anon_sym_SEMI,
    STATE(1572), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291325] = 4,
    ACTIONS(17536), 1,
      anon_sym_SEMI,
    STATE(3862), 1,
      sym_preproc_endif,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291345] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(2841), 6,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [291361] = 4,
    ACTIONS(17538), 1,
      anon_sym_SEMI,
    STATE(2293), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291381] = 4,
    ACTIONS(17540), 1,
      anon_sym_SEMI,
    STATE(3342), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291401] = 4,
    ACTIONS(17542), 1,
      anon_sym_SEMI,
    STATE(1573), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291421] = 4,
    ACTIONS(17544), 1,
      anon_sym_RBRACE,
    STATE(9291), 2,
      sym_xmlport_element,
      aux_sym_schema_section_repeat1,
    ACTIONS(17546), 3,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291441] = 4,
    ACTIONS(17548), 1,
      anon_sym_SEMI,
    STATE(3826), 1,
      sym_preproc_endif,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291461] = 4,
    ACTIONS(17550), 1,
      anon_sym_SEMI,
    STATE(6954), 1,
      sym_preproc_endif,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291481] = 4,
    ACTIONS(17552), 1,
      anon_sym_SEMI,
    STATE(6955), 1,
      sym_preproc_endif,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291501] = 4,
    ACTIONS(17554), 1,
      anon_sym_SEMI,
    STATE(6956), 1,
      sym_preproc_endif,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291521] = 4,
    ACTIONS(17556), 1,
      anon_sym_SEMI,
    STATE(6957), 1,
      sym_preproc_endif,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291541] = 4,
    ACTIONS(17558), 1,
      anon_sym_SEMI,
    STATE(6960), 1,
      sym_preproc_endif,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291561] = 4,
    ACTIONS(17560), 1,
      anon_sym_SEMI,
    STATE(6961), 1,
      sym_preproc_endif,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291581] = 4,
    ACTIONS(17562), 1,
      anon_sym_SEMI,
    STATE(6964), 1,
      sym_preproc_endif,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291601] = 4,
    ACTIONS(17564), 1,
      anon_sym_SEMI,
    STATE(6980), 1,
      sym_preproc_endif,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291621] = 4,
    ACTIONS(17566), 1,
      anon_sym_SEMI,
    STATE(3343), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291641] = 4,
    ACTIONS(17568), 1,
      anon_sym_SEMI,
    STATE(1574), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291661] = 4,
    ACTIONS(17570), 1,
      anon_sym_SEMI,
    STATE(3015), 1,
      sym_preproc_endif,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291681] = 4,
    ACTIONS(17572), 1,
      anon_sym_SEMI,
    STATE(1560), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291701] = 4,
    ACTIONS(17574), 1,
      anon_sym_SEMI,
    STATE(1576), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291721] = 4,
    ACTIONS(17576), 1,
      anon_sym_SEMI,
    STATE(1580), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291741] = 4,
    ACTIONS(17578), 1,
      anon_sym_SEMI,
    STATE(1582), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291761] = 4,
    ACTIONS(17580), 1,
      anon_sym_SEMI,
    STATE(3312), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291781] = 4,
    ACTIONS(17582), 1,
      anon_sym_SEMI,
    STATE(1583), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291801] = 4,
    ACTIONS(17584), 1,
      anon_sym_SEMI,
    STATE(11936), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291821] = 4,
    ACTIONS(17586), 1,
      anon_sym_SEMI,
    STATE(7381), 1,
      sym_preproc_endif,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291841] = 4,
    ACTIONS(17588), 1,
      anon_sym_SEMI,
    STATE(1593), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291861] = 4,
    ACTIONS(17590), 1,
      anon_sym_SEMI,
    STATE(7516), 1,
      sym_preproc_endif,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291881] = 4,
    ACTIONS(17592), 1,
      anon_sym_SEMI,
    STATE(7501), 1,
      sym_preproc_endif,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291901] = 4,
    ACTIONS(17594), 1,
      anon_sym_SEMI,
    STATE(7493), 1,
      sym_preproc_endif,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291921] = 4,
    ACTIONS(17596), 1,
      anon_sym_SEMI,
    STATE(7498), 1,
      sym_preproc_endif,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291941] = 4,
    ACTIONS(17598), 1,
      anon_sym_SEMI,
    STATE(7494), 1,
      sym_preproc_endif,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291961] = 4,
    ACTIONS(17600), 1,
      anon_sym_SEMI,
    STATE(1594), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [291981] = 4,
    ACTIONS(17602), 1,
      anon_sym_SEMI,
    STATE(7497), 1,
      sym_preproc_endif,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292001] = 4,
    ACTIONS(17604), 1,
      anon_sym_SEMI,
    STATE(7528), 1,
      sym_preproc_endif,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292021] = 4,
    ACTIONS(17606), 1,
      anon_sym_SEMI,
    STATE(7537), 1,
      sym_preproc_endif,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292041] = 4,
    ACTIONS(17608), 1,
      anon_sym_SEMI,
    STATE(7318), 1,
      sym_preproc_endif,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292061] = 4,
    ACTIONS(17610), 1,
      anon_sym_SEMI,
    STATE(3028), 1,
      sym_preproc_endif,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292081] = 4,
    ACTIONS(17612), 1,
      anon_sym_SEMI,
    STATE(7362), 1,
      sym_preproc_endif,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292101] = 4,
    ACTIONS(17614), 1,
      anon_sym_SEMI,
    STATE(3030), 1,
      sym_preproc_endif,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292121] = 4,
    ACTIONS(17616), 1,
      anon_sym_SEMI,
    STATE(7270), 1,
      sym_preproc_endif,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292141] = 4,
    ACTIONS(17618), 1,
      anon_sym_SEMI,
    STATE(7280), 1,
      sym_preproc_endif,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292161] = 4,
    ACTIONS(17620), 1,
      anon_sym_SEMI,
    STATE(3830), 1,
      sym_preproc_endif,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292181] = 4,
    ACTIONS(17622), 1,
      anon_sym_SEMI,
    STATE(2233), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292201] = 4,
    ACTIONS(17624), 1,
      anon_sym_SEMI,
    STATE(7282), 1,
      sym_preproc_endif,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292221] = 4,
    ACTIONS(17626), 1,
      anon_sym_SEMI,
    STATE(7301), 1,
      sym_preproc_endif,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292241] = 4,
    ACTIONS(17628), 1,
      anon_sym_SEMI,
    STATE(7314), 1,
      sym_preproc_endif,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292261] = 4,
    ACTIONS(17630), 1,
      anon_sym_SEMI,
    STATE(2305), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292281] = 4,
    ACTIONS(17632), 1,
      anon_sym_SEMI,
    STATE(9417), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292301] = 4,
    ACTIONS(17634), 1,
      anon_sym_SEMI,
    STATE(9419), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292321] = 4,
    ACTIONS(17636), 1,
      anon_sym_SEMI,
    STATE(9424), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292341] = 4,
    ACTIONS(17638), 1,
      anon_sym_SEMI,
    STATE(9425), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292361] = 4,
    ACTIONS(17640), 1,
      anon_sym_SEMI,
    STATE(9427), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292381] = 4,
    ACTIONS(17642), 1,
      anon_sym_SEMI,
    STATE(9434), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292401] = 4,
    ACTIONS(17644), 1,
      anon_sym_SEMI,
    STATE(9441), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292421] = 4,
    ACTIONS(17646), 1,
      anon_sym_SEMI,
    STATE(9445), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292441] = 4,
    ACTIONS(17648), 1,
      anon_sym_SEMI,
    STATE(3031), 1,
      sym_preproc_endif,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292461] = 4,
    ACTIONS(17650), 1,
      anon_sym_SEMI,
    STATE(1863), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292481] = 4,
    ACTIONS(17652), 1,
      anon_sym_SEMI,
    STATE(2324), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292501] = 4,
    ACTIONS(17654), 1,
      anon_sym_RBRACE,
    STATE(9277), 2,
      sym_xmlport_element,
      aux_sym_schema_section_repeat1,
    ACTIONS(17546), 3,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292521] = 4,
    ACTIONS(17656), 1,
      anon_sym_SEMI,
    STATE(2325), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292541] = 4,
    ACTIONS(17658), 1,
      anon_sym_SEMI,
    STATE(2242), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292561] = 4,
    ACTIONS(17660), 1,
      anon_sym_SEMI,
    STATE(3033), 1,
      sym_preproc_endif,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292581] = 4,
    ACTIONS(17662), 1,
      anon_sym_SEMI,
    STATE(3034), 1,
      sym_preproc_endif,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292601] = 4,
    ACTIONS(17664), 1,
      anon_sym_SEMI,
    STATE(11924), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292621] = 4,
    ACTIONS(17666), 1,
      anon_sym_SEMI,
    STATE(3040), 1,
      sym_preproc_endif,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292641] = 4,
    ACTIONS(17668), 1,
      anon_sym_SEMI,
    STATE(7065), 1,
      sym_preproc_endif,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292661] = 4,
    ACTIONS(17670), 1,
      anon_sym_SEMI,
    STATE(2403), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292681] = 4,
    ACTIONS(17672), 1,
      anon_sym_SEMI,
    STATE(7066), 1,
      sym_preproc_endif,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292701] = 4,
    ACTIONS(17674), 1,
      anon_sym_SEMI,
    STATE(7067), 1,
      sym_preproc_endif,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292721] = 4,
    ACTIONS(17676), 1,
      anon_sym_SEMI,
    STATE(7068), 1,
      sym_preproc_endif,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292741] = 4,
    ACTIONS(17678), 1,
      anon_sym_SEMI,
    STATE(7072), 1,
      sym_preproc_endif,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292761] = 4,
    ACTIONS(17680), 1,
      anon_sym_SEMI,
    STATE(7074), 1,
      sym_preproc_endif,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292781] = 4,
    ACTIONS(17682), 1,
      anon_sym_SEMI,
    STATE(7078), 1,
      sym_preproc_endif,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292801] = 4,
    ACTIONS(17684), 1,
      anon_sym_SEMI,
    STATE(10077), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292821] = 4,
    ACTIONS(17686), 1,
      anon_sym_SEMI,
    STATE(4408), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292841] = 4,
    ACTIONS(17688), 1,
      anon_sym_SEMI,
    STATE(8897), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292861] = 4,
    ACTIONS(17690), 1,
      anon_sym_SEMI,
    STATE(8898), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292881] = 4,
    ACTIONS(17692), 1,
      anon_sym_SEMI,
    STATE(8899), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292901] = 4,
    ACTIONS(17694), 1,
      anon_sym_SEMI,
    STATE(8900), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292921] = 4,
    ACTIONS(17696), 1,
      anon_sym_RBRACE,
    STATE(9095), 2,
      sym_xmlport_element,
      aux_sym_schema_section_repeat1,
    ACTIONS(17546), 3,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292941] = 4,
    ACTIONS(17698), 1,
      anon_sym_SEMI,
    STATE(8902), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292961] = 4,
    ACTIONS(17700), 1,
      anon_sym_SEMI,
    STATE(8903), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [292981] = 4,
    ACTIONS(17702), 1,
      anon_sym_SEMI,
    STATE(8906), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293001] = 4,
    ACTIONS(17704), 1,
      anon_sym_SEMI,
    STATE(8909), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293021] = 4,
    ACTIONS(17706), 1,
      anon_sym_SEMI,
    STATE(6519), 1,
      sym_preproc_endif,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293041] = 4,
    ACTIONS(17708), 1,
      anon_sym_SEMI,
    STATE(6520), 1,
      sym_preproc_endif,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293061] = 4,
    ACTIONS(17710), 1,
      anon_sym_SEMI,
    STATE(6521), 1,
      sym_preproc_endif,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293081] = 4,
    ACTIONS(17712), 1,
      anon_sym_SEMI,
    STATE(6522), 1,
      sym_preproc_endif,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293101] = 4,
    ACTIONS(17714), 1,
      anon_sym_SEMI,
    STATE(6524), 1,
      sym_preproc_endif,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293121] = 4,
    ACTIONS(17716), 1,
      anon_sym_SEMI,
    STATE(6525), 1,
      sym_preproc_endif,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293141] = 4,
    ACTIONS(17718), 1,
      anon_sym_SEMI,
    STATE(6528), 1,
      sym_preproc_endif,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293161] = 4,
    ACTIONS(17720), 1,
      anon_sym_SEMI,
    STATE(6531), 1,
      sym_preproc_endif,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293181] = 4,
    ACTIONS(17722), 1,
      anon_sym_SEMI,
    STATE(11915), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293201] = 4,
    ACTIONS(17724), 1,
      anon_sym_SEMI,
    STATE(7601), 1,
      sym_preproc_endif,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293221] = 4,
    ACTIONS(17726), 1,
      anon_sym_RBRACE,
    STATE(9220), 2,
      sym_xmlport_element,
      aux_sym_schema_section_repeat1,
    ACTIONS(17546), 3,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293241] = 4,
    ACTIONS(17728), 1,
      anon_sym_SEMI,
    STATE(7575), 1,
      sym_preproc_endif,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293261] = 4,
    ACTIONS(17730), 1,
      anon_sym_SEMI,
    STATE(7577), 1,
      sym_preproc_endif,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293281] = 4,
    ACTIONS(17732), 1,
      anon_sym_SEMI,
    STATE(4409), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293301] = 4,
    ACTIONS(17734), 1,
      anon_sym_SEMI,
    STATE(7605), 1,
      sym_preproc_endif,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293321] = 4,
    ACTIONS(17736), 1,
      anon_sym_SEMI,
    STATE(1567), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293341] = 4,
    ACTIONS(17738), 1,
      anon_sym_SEMI,
    STATE(7566), 1,
      sym_preproc_endif,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293361] = 4,
    ACTIONS(17740), 1,
      anon_sym_SEMI,
    STATE(3799), 1,
      sym_preproc_endif,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293381] = 4,
    ACTIONS(17742), 1,
      anon_sym_SEMI,
    STATE(4410), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293401] = 4,
    ACTIONS(17744), 1,
      anon_sym_RBRACE,
    STATE(9095), 2,
      sym_xmlport_element,
      aux_sym_schema_section_repeat1,
    ACTIONS(17546), 3,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293421] = 4,
    ACTIONS(17746), 1,
      anon_sym_SEMI,
    STATE(7567), 1,
      sym_preproc_endif,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293441] = 4,
    ACTIONS(17748), 1,
      anon_sym_SEMI,
    STATE(7593), 1,
      sym_preproc_endif,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293461] = 4,
    ACTIONS(17750), 1,
      anon_sym_SEMI,
    STATE(7620), 1,
      sym_preproc_endif,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293481] = 4,
    ACTIONS(17752), 1,
      anon_sym_SEMI,
    STATE(4991), 1,
      sym_preproc_endif,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293501] = 4,
    ACTIONS(17754), 1,
      anon_sym_SEMI,
    STATE(4992), 1,
      sym_preproc_endif,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293521] = 4,
    ACTIONS(17756), 1,
      anon_sym_SEMI,
    STATE(4993), 1,
      sym_preproc_endif,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293541] = 4,
    ACTIONS(17758), 1,
      anon_sym_SEMI,
    STATE(3831), 1,
      sym_preproc_endif,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293561] = 4,
    ACTIONS(17760), 1,
      anon_sym_SEMI,
    STATE(4994), 1,
      sym_preproc_endif,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293581] = 4,
    ACTIONS(17762), 1,
      anon_sym_SEMI,
    STATE(4997), 1,
      sym_preproc_endif,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293601] = 4,
    ACTIONS(17764), 1,
      anon_sym_SEMI,
    STATE(5001), 1,
      sym_preproc_endif,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293621] = 4,
    ACTIONS(17766), 1,
      anon_sym_SEMI,
    STATE(8824), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293641] = 4,
    ACTIONS(17768), 1,
      anon_sym_SEMI,
    STATE(5049), 1,
      sym_preproc_endif,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293661] = 4,
    ACTIONS(17770), 1,
      anon_sym_RBRACE,
    STATE(9257), 2,
      sym_xmlport_element,
      aux_sym_schema_section_repeat1,
    ACTIONS(17546), 3,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293681] = 4,
    ACTIONS(17772), 1,
      anon_sym_SEMI,
    STATE(5073), 1,
      sym_preproc_endif,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293701] = 4,
    ACTIONS(17774), 1,
      anon_sym_SEMI,
    STATE(2368), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293721] = 4,
    ACTIONS(17776), 1,
      anon_sym_SEMI,
    STATE(5846), 1,
      sym_preproc_endif,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293741] = 4,
    ACTIONS(17778), 1,
      anon_sym_SEMI,
    STATE(5848), 1,
      sym_preproc_endif,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293761] = 4,
    ACTIONS(17780), 1,
      anon_sym_SEMI,
    STATE(8789), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293781] = 4,
    ACTIONS(17782), 1,
      anon_sym_SEMI,
    STATE(5853), 1,
      sym_preproc_endif,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293801] = 4,
    ACTIONS(17784), 1,
      anon_sym_SEMI,
    STATE(5854), 1,
      sym_preproc_endif,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293821] = 4,
    ACTIONS(17786), 1,
      anon_sym_SEMI,
    STATE(5856), 1,
      sym_preproc_endif,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293841] = 4,
    ACTIONS(17788), 1,
      anon_sym_SEMI,
    STATE(5857), 1,
      sym_preproc_endif,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293861] = 4,
    ACTIONS(17790), 1,
      anon_sym_SEMI,
    STATE(5864), 1,
      sym_preproc_endif,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293881] = 4,
    ACTIONS(17792), 1,
      anon_sym_SEMI,
    STATE(5867), 1,
      sym_preproc_endif,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293901] = 4,
    ACTIONS(17794), 1,
      anon_sym_SEMI,
    STATE(5483), 1,
      sym_preproc_endif,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293921] = 4,
    ACTIONS(17796), 1,
      anon_sym_SEMI,
    STATE(5484), 1,
      sym_preproc_endif,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293941] = 4,
    ACTIONS(17798), 1,
      anon_sym_SEMI,
    STATE(2369), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293961] = 4,
    ACTIONS(17800), 1,
      anon_sym_SEMI,
    STATE(5485), 1,
      sym_preproc_endif,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [293981] = 4,
    ACTIONS(17802), 1,
      anon_sym_SEMI,
    STATE(5486), 1,
      sym_preproc_endif,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294001] = 4,
    ACTIONS(17804), 1,
      anon_sym_SEMI,
    STATE(5488), 1,
      sym_preproc_endif,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294021] = 4,
    ACTIONS(17806), 1,
      anon_sym_SEMI,
    STATE(8822), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294041] = 4,
    ACTIONS(17808), 1,
      anon_sym_SEMI,
    STATE(5489), 1,
      sym_preproc_endif,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294061] = 4,
    ACTIONS(17810), 1,
      anon_sym_SEMI,
    STATE(5495), 1,
      sym_preproc_endif,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294081] = 4,
    ACTIONS(17812), 1,
      anon_sym_SEMI,
    STATE(5504), 1,
      sym_preproc_endif,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294101] = 4,
    ACTIONS(17814), 1,
      anon_sym_SEMI,
    STATE(1595), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294121] = 4,
    ACTIONS(17816), 1,
      anon_sym_SEMI,
    STATE(4745), 1,
      sym_preproc_endif,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294141] = 4,
    ACTIONS(17818), 1,
      anon_sym_RBRACE,
    STATE(9095), 2,
      sym_xmlport_element,
      aux_sym_schema_section_repeat1,
    ACTIONS(17546), 3,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294161] = 4,
    ACTIONS(17820), 1,
      anon_sym_SEMI,
    STATE(4746), 1,
      sym_preproc_endif,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294181] = 4,
    ACTIONS(17822), 1,
      anon_sym_SEMI,
    STATE(4747), 1,
      sym_preproc_endif,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294201] = 4,
    ACTIONS(17824), 1,
      anon_sym_SEMI,
    STATE(4748), 1,
      sym_preproc_endif,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294221] = 4,
    ACTIONS(17826), 1,
      anon_sym_SEMI,
    STATE(2306), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294241] = 4,
    ACTIONS(17828), 1,
      anon_sym_SEMI,
    STATE(4508), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294261] = 4,
    ACTIONS(17830), 1,
      anon_sym_SEMI,
    STATE(4509), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294281] = 4,
    ACTIONS(17832), 1,
      anon_sym_SEMI,
    STATE(3832), 1,
      sym_preproc_endif,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294301] = 4,
    ACTIONS(17834), 1,
      anon_sym_SEMI,
    STATE(1867), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294321] = 4,
    ACTIONS(17836), 1,
      anon_sym_SEMI,
    STATE(4513), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294341] = 4,
    ACTIONS(17838), 1,
      anon_sym_SEMI,
    STATE(4750), 1,
      sym_preproc_endif,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294361] = 4,
    ACTIONS(17840), 1,
      anon_sym_SEMI,
    STATE(4751), 1,
      sym_preproc_endif,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294381] = 4,
    ACTIONS(17842), 1,
      anon_sym_SEMI,
    STATE(4754), 1,
      sym_preproc_endif,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294401] = 4,
    ACTIONS(17844), 1,
      anon_sym_SEMI,
    STATE(4794), 1,
      sym_preproc_endif,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294421] = 4,
    ACTIONS(17846), 1,
      anon_sym_SEMI,
    STATE(1869), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294441] = 4,
    ACTIONS(17848), 1,
      anon_sym_SEMI,
    STATE(3296), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294461] = 4,
    ACTIONS(17850), 1,
      anon_sym_SEMI,
    STATE(3071), 1,
      sym_preproc_endif,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294481] = 4,
    ACTIONS(17852), 1,
      anon_sym_SEMI,
    STATE(3844), 1,
      sym_preproc_endif,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294501] = 4,
    ACTIONS(17854), 1,
      anon_sym_SEMI,
    STATE(10123), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294521] = 4,
    ACTIONS(17856), 1,
      anon_sym_RBRACE,
    STATE(9196), 2,
      sym_xmlport_element,
      aux_sym_schema_section_repeat1,
    ACTIONS(17546), 3,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294541] = 4,
    ACTIONS(17858), 1,
      anon_sym_RBRACE,
    STATE(9095), 2,
      sym_xmlport_element,
      aux_sym_schema_section_repeat1,
    ACTIONS(17546), 3,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294561] = 4,
    ACTIONS(17860), 1,
      anon_sym_SEMI,
    STATE(10198), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294581] = 4,
    ACTIONS(17862), 1,
      anon_sym_SEMI,
    STATE(10203), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294601] = 4,
    ACTIONS(17864), 1,
      anon_sym_SEMI,
    STATE(3287), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294621] = 4,
    ACTIONS(17866), 1,
      anon_sym_SEMI,
    STATE(10208), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294641] = 4,
    ACTIONS(17868), 1,
      anon_sym_SEMI,
    STATE(10209), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294661] = 4,
    ACTIONS(17870), 1,
      anon_sym_SEMI,
    STATE(10210), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294681] = 4,
    ACTIONS(17872), 1,
      anon_sym_SEMI,
    STATE(3850), 1,
      sym_preproc_endif,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294701] = 4,
    ACTIONS(17874), 1,
      anon_sym_SEMI,
    STATE(10229), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294721] = 4,
    ACTIONS(17876), 1,
      anon_sym_SEMI,
    STATE(10238), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294741] = 4,
    ACTIONS(17878), 1,
      anon_sym_SEMI,
    STATE(10241), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294761] = 4,
    ACTIONS(17880), 1,
      anon_sym_SEMI,
    STATE(10259), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294781] = 4,
    ACTIONS(17882), 1,
      anon_sym_SEMI,
    STATE(9969), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294801] = 4,
    ACTIONS(17884), 1,
      anon_sym_SEMI,
    STATE(9971), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294821] = 4,
    ACTIONS(17886), 1,
      anon_sym_RBRACE,
    STATE(9095), 2,
      sym_xmlport_element,
      aux_sym_schema_section_repeat1,
    ACTIONS(17546), 3,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294841] = 4,
    ACTIONS(17888), 1,
      anon_sym_SEMI,
    STATE(3286), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294861] = 4,
    ACTIONS(17890), 1,
      anon_sym_SEMI,
    STATE(2273), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294881] = 4,
    ACTIONS(17892), 1,
      anon_sym_SEMI,
    STATE(3293), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294901] = 4,
    ACTIONS(17894), 1,
      anon_sym_SEMI,
    STATE(9980), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294921] = 4,
    ACTIONS(17896), 1,
      anon_sym_SEMI,
    STATE(10035), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294941] = 4,
    ACTIONS(17898), 1,
      anon_sym_SEMI,
    STATE(10045), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294961] = 4,
    ACTIONS(17900), 1,
      anon_sym_SEMI,
    STATE(4540), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [294981] = 4,
    ACTIONS(17902), 1,
      anon_sym_SEMI,
    STATE(10046), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295001] = 4,
    ACTIONS(17904), 1,
      anon_sym_SEMI,
    STATE(8800), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295021] = 4,
    ACTIONS(17906), 1,
      anon_sym_SEMI,
    STATE(7081), 1,
      sym_preproc_endif,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295041] = 4,
    ACTIONS(17908), 1,
      anon_sym_COMMA,
    STATE(9582), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(374), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295060] = 3,
    STATE(347), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295077] = 3,
    STATE(4685), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295094] = 4,
    STATE(3150), 1,
      sym_if_keyword,
    STATE(9640), 1,
      sym__preproc_if_header,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295113] = 3,
    STATE(350), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295130] = 3,
    STATE(351), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295147] = 3,
    STATE(352), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295164] = 3,
    STATE(410), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295181] = 3,
    STATE(355), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295198] = 3,
    STATE(357), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295215] = 3,
    STATE(358), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295232] = 3,
    STATE(359), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295249] = 3,
    STATE(360), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295266] = 3,
    STATE(361), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295283] = 3,
    STATE(365), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295300] = 3,
    STATE(368), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295317] = 3,
    STATE(370), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295334] = 3,
    STATE(371), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295351] = 3,
    STATE(411), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295368] = 3,
    STATE(412), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295385] = 3,
    STATE(278), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295402] = 3,
    STATE(12670), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295419] = 3,
    STATE(4658), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295436] = 3,
    STATE(377), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295453] = 3,
    STATE(11172), 1,
      sym_preproc_endif,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295470] = 4,
    ACTIONS(17912), 1,
      sym_identifier,
    STATE(7030), 1,
      sym_preproc_not_expression,
    ACTIONS(17914), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295489] = 4,
    ACTIONS(17916), 1,
      sym_identifier,
    STATE(7047), 1,
      sym_preproc_not_expression,
    ACTIONS(17914), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295508] = 3,
    STATE(1828), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295525] = 3,
    STATE(4541), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295542] = 3,
    STATE(2257), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295559] = 3,
    STATE(1829), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295576] = 3,
    STATE(8128), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295593] = 4,
    ACTIONS(4147), 1,
      anon_sym_SEMI,
    STATE(312), 1,
      sym_else_keyword,
    ACTIONS(17918), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295612] = 4,
    ACTIONS(4151), 1,
      anon_sym_SEMI,
    STATE(313), 1,
      sym_else_keyword,
    ACTIONS(17918), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295631] = 4,
    ACTIONS(4121), 1,
      anon_sym_SEMI,
    STATE(339), 1,
      sym_else_keyword,
    ACTIONS(17918), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295650] = 4,
    ACTIONS(4127), 1,
      anon_sym_SEMI,
    STATE(340), 1,
      sym_else_keyword,
    ACTIONS(17918), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295669] = 3,
    STATE(1569), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295686] = 3,
    STATE(11936), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295703] = 3,
    STATE(1831), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295720] = 3,
    STATE(2371), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295737] = 3,
    STATE(1571), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295754] = 3,
    STATE(2346), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295771] = 3,
    STATE(2259), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295788] = 3,
    STATE(1832), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295805] = 3,
    STATE(3028), 1,
      sym_preproc_endif,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295822] = 3,
    STATE(1575), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295839] = 3,
    STATE(264), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295856] = 4,
    STATE(11191), 1,
      sym_boolean,
    ACTIONS(17920), 2,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
    ACTIONS(17922), 2,
      sym_string_literal,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295875] = 3,
    STATE(265), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295892] = 3,
    STATE(563), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295909] = 3,
    STATE(6454), 1,
      sym_preproc_endif,
    ACTIONS(9129), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295926] = 3,
    STATE(566), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295943] = 3,
    STATE(7875), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295960] = 3,
    STATE(568), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295977] = 3,
    STATE(569), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [295994] = 3,
    STATE(7886), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296011] = 3,
    STATE(266), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296028] = 3,
    STATE(6368), 1,
      sym_preproc_endif,
    ACTIONS(9129), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296045] = 3,
    STATE(267), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296062] = 3,
    STATE(2299), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296079] = 3,
    STATE(1577), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296096] = 3,
    STATE(2372), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296113] = 3,
    STATE(1578), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296130] = 3,
    STATE(1579), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296147] = 4,
    STATE(3150), 1,
      sym_if_keyword,
    STATE(9322), 1,
      sym__preproc_if_header,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296166] = 3,
    STATE(449), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296183] = 4,
    STATE(3150), 1,
      sym_if_keyword,
    STATE(9570), 1,
      sym__preproc_if_header,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296202] = 3,
    STATE(452), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296219] = 3,
    STATE(453), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296236] = 3,
    STATE(454), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296253] = 3,
    STATE(7161), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296270] = 3,
    STATE(306), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296287] = 3,
    STATE(459), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296304] = 3,
    STATE(461), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296321] = 3,
    STATE(462), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296338] = 3,
    STATE(463), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296355] = 3,
    STATE(464), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296372] = 3,
    STATE(465), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296389] = 3,
    STATE(469), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296406] = 3,
    STATE(472), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296423] = 3,
    STATE(474), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296440] = 3,
    STATE(475), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296457] = 3,
    STATE(1581), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296474] = 3,
    STATE(480), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296491] = 3,
    STATE(2347), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296508] = 4,
    ACTIONS(4155), 1,
      anon_sym_SEMI,
    STATE(318), 1,
      sym_else_keyword,
    ACTIONS(17918), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296527] = 4,
    ACTIONS(4159), 1,
      anon_sym_SEMI,
    STATE(319), 1,
      sym_else_keyword,
    ACTIONS(17918), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296546] = 3,
    ACTIONS(17924), 1,
      anon_sym_SEMI,
    ACTIONS(4377), 4,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296563] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4377), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [296578] = 3,
    STATE(2349), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296595] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4381), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [296610] = 3,
    ACTIONS(17926), 1,
      anon_sym_SEMI,
    ACTIONS(4387), 4,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296627] = 3,
    ACTIONS(17928), 1,
      anon_sym_SEMI,
    ACTIONS(4387), 4,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296644] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4387), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [296659] = 3,
    STATE(268), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296676] = 3,
    STATE(269), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296693] = 3,
    STATE(270), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296710] = 3,
    STATE(311), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296727] = 3,
    STATE(317), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296744] = 3,
    STATE(271), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296761] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [296776] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4397), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [296791] = 3,
    STATE(1592), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296808] = 3,
    STATE(1834), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296825] = 3,
    STATE(12068), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296842] = 3,
    STATE(3032), 1,
      sym_preproc_endif,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296859] = 3,
    STATE(7940), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296876] = 3,
    STATE(7949), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296893] = 3,
    STATE(7318), 1,
      sym_preproc_endif,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296910] = 3,
    STATE(2303), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296927] = 3,
    STATE(3036), 1,
      sym_preproc_endif,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296944] = 3,
    STATE(7279), 1,
      sym_preproc_endif,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296961] = 3,
    STATE(3037), 1,
      sym_preproc_endif,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296978] = 3,
    STATE(8792), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [296995] = 4,
    STATE(3150), 1,
      sym_if_keyword,
    STATE(9827), 1,
      sym__preproc_if_header,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297014] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4401), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [297029] = 3,
    STATE(485), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297046] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4405), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [297061] = 4,
    STATE(3150), 1,
      sym_if_keyword,
    STATE(9870), 1,
      sym__preproc_if_header,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297080] = 3,
    STATE(487), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297097] = 3,
    STATE(488), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297114] = 3,
    STATE(489), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297131] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4409), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [297146] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4413), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [297161] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4417), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [297176] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4421), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [297191] = 3,
    STATE(492), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297208] = 3,
    STATE(494), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297225] = 3,
    STATE(495), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297242] = 3,
    STATE(496), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297259] = 3,
    STATE(497), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297276] = 3,
    STATE(498), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297293] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4425), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [297308] = 3,
    STATE(502), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297325] = 3,
    STATE(505), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297342] = 3,
    STATE(507), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297359] = 3,
    STATE(508), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297376] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4429), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [297391] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4433), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [297406] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4437), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [297421] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4441), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [297436] = 3,
    STATE(513), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297453] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4445), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [297468] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4449), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [297483] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4453), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [297498] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 5,
      anon_sym_SEMI,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [297513] = 3,
    STATE(7283), 1,
      sym_preproc_endif,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297530] = 3,
    STATE(7289), 1,
      sym_preproc_endif,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297547] = 3,
    STATE(10062), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297564] = 3,
    STATE(7310), 1,
      sym_preproc_endif,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297581] = 3,
    STATE(7311), 1,
      sym_preproc_endif,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297598] = 4,
    ACTIONS(4163), 1,
      anon_sym_SEMI,
    STATE(320), 1,
      sym_else_keyword,
    ACTIONS(17918), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297617] = 4,
    ACTIONS(4167), 1,
      anon_sym_SEMI,
    STATE(321), 1,
      sym_else_keyword,
    ACTIONS(17918), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297636] = 3,
    STATE(7316), 1,
      sym_preproc_endif,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297653] = 3,
    STATE(7320), 1,
      sym_preproc_endif,
    ACTIONS(11616), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297670] = 3,
    STATE(330), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297687] = 3,
    STATE(7052), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297704] = 3,
    STATE(331), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297721] = 3,
    STATE(332), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297738] = 3,
    STATE(333), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297755] = 3,
    STATE(8824), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297772] = 3,
    STATE(334), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297789] = 3,
    STATE(7994), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297806] = 3,
    STATE(6587), 1,
      sym_preproc_endif,
    ACTIONS(9129), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297823] = 3,
    STATE(8000), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297840] = 3,
    STATE(335), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297857] = 3,
    STATE(336), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297874] = 4,
    STATE(3150), 1,
      sym_if_keyword,
    STATE(9841), 1,
      sym__preproc_if_header,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297893] = 3,
    STATE(517), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297910] = 4,
    STATE(3150), 1,
      sym_if_keyword,
    STATE(9846), 1,
      sym__preproc_if_header,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297929] = 3,
    STATE(519), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297946] = 3,
    STATE(520), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297963] = 3,
    STATE(521), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297980] = 3,
    STATE(337), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [297997] = 3,
    STATE(526), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298014] = 3,
    STATE(528), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298031] = 3,
    STATE(529), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298048] = 3,
    STATE(530), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298065] = 3,
    STATE(531), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298082] = 3,
    STATE(532), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298099] = 3,
    STATE(11281), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298116] = 3,
    STATE(536), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298133] = 3,
    STATE(539), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298150] = 3,
    STATE(541), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298167] = 3,
    STATE(542), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298184] = 3,
    STATE(547), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298201] = 3,
    STATE(914), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298218] = 4,
    ACTIONS(4171), 1,
      anon_sym_SEMI,
    STATE(326), 1,
      sym_else_keyword,
    ACTIONS(17918), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298237] = 3,
    STATE(2265), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298254] = 4,
    ACTIONS(4133), 1,
      anon_sym_SEMI,
    STATE(327), 1,
      sym_else_keyword,
    ACTIONS(17918), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298273] = 3,
    STATE(3041), 1,
      sym_preproc_endif,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298290] = 3,
    STATE(8023), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298307] = 3,
    STATE(8027), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298324] = 3,
    STATE(3062), 1,
      sym_preproc_endif,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298341] = 4,
    STATE(3150), 1,
      sym_if_keyword,
    STATE(9399), 1,
      sym__preproc_if_header,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298360] = 4,
    ACTIONS(17930), 1,
      sym_identifier,
    STATE(6918), 1,
      sym_preproc_not_expression,
    ACTIONS(17932), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298379] = 4,
    STATE(3150), 1,
      sym_if_keyword,
    STATE(9400), 1,
      sym__preproc_if_header,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298398] = 4,
    ACTIONS(17934), 1,
      sym_identifier,
    STATE(6927), 1,
      sym_preproc_not_expression,
    ACTIONS(17932), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298417] = 3,
    STATE(1861), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298434] = 3,
    STATE(3089), 1,
      sym_preproc_endif,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298451] = 3,
    STATE(10114), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298468] = 3,
    STATE(10115), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298485] = 3,
    STATE(4653), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298502] = 3,
    STATE(1596), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298519] = 3,
    STATE(297), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298536] = 3,
    STATE(298), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298553] = 3,
    STATE(10128), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298570] = 3,
    STATE(8039), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298587] = 3,
    STATE(8043), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298604] = 3,
    STATE(299), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298621] = 3,
    STATE(8049), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298638] = 3,
    STATE(8050), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298655] = 3,
    STATE(1603), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298672] = 3,
    STATE(12271), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298689] = 3,
    STATE(1621), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298706] = 4,
    ACTIONS(17908), 1,
      anon_sym_COMMA,
    STATE(9641), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(2412), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298725] = 3,
    STATE(8053), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298742] = 3,
    STATE(8054), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298759] = 3,
    STATE(3117), 1,
      sym_preproc_endif,
    ACTIONS(5568), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298776] = 3,
    STATE(1633), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298793] = 3,
    STATE(300), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298810] = 3,
    STATE(1634), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298827] = 3,
    STATE(10200), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298844] = 3,
    STATE(8057), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298861] = 3,
    STATE(8058), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298878] = 3,
    STATE(1636), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298895] = 3,
    STATE(10201), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298912] = 4,
    ACTIONS(17936), 1,
      anon_sym_SEMI,
    STATE(662), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298931] = 3,
    STATE(3342), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298948] = 3,
    STATE(10204), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298965] = 3,
    STATE(10205), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298982] = 3,
    STATE(4676), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [298999] = 3,
    STATE(8061), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299016] = 3,
    STATE(8062), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299033] = 3,
    STATE(6672), 1,
      sym_preproc_endif,
    ACTIONS(9129), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299050] = 3,
    STATE(1864), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299067] = 3,
    STATE(343), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299084] = 4,
    ACTIONS(17908), 1,
      anon_sym_COMMA,
    STATE(9517), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(2356), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299103] = 3,
    STATE(12305), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299120] = 3,
    STATE(1639), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299137] = 3,
    STATE(1640), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299154] = 3,
    STATE(8065), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299171] = 3,
    STATE(8066), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299188] = 3,
    STATE(1641), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299205] = 3,
    STATE(1642), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299222] = 3,
    STATE(10207), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299239] = 3,
    STATE(1644), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299256] = 3,
    STATE(2373), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299273] = 3,
    STATE(1865), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299290] = 3,
    STATE(1866), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299307] = 3,
    STATE(8789), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299324] = 3,
    STATE(10222), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299341] = 3,
    STATE(435), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299358] = 3,
    STATE(1607), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299375] = 3,
    STATE(436), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299392] = 3,
    STATE(437), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299409] = 3,
    STATE(1610), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299426] = 3,
    STATE(438), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299443] = 3,
    STATE(1868), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299460] = 3,
    STATE(1613), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299477] = 3,
    STATE(1614), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299494] = 3,
    STATE(10235), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299511] = 3,
    STATE(1616), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299528] = 3,
    STATE(1617), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299545] = 3,
    STATE(10236), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299562] = 3,
    STATE(1619), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299579] = 3,
    STATE(1620), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299596] = 3,
    STATE(10237), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299613] = 3,
    STATE(284), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299630] = 3,
    STATE(10240), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299647] = 3,
    STATE(2307), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299664] = 4,
    ACTIONS(17940), 1,
      sym_identifier,
    STATE(6428), 1,
      sym_preproc_not_expression,
    ACTIONS(17942), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299683] = 4,
    ACTIONS(17944), 1,
      sym_identifier,
    STATE(6789), 1,
      sym_preproc_not_expression,
    ACTIONS(17942), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299702] = 3,
    STATE(439), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299719] = 3,
    STATE(579), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299736] = 3,
    STATE(440), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299753] = 3,
    STATE(441), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299770] = 3,
    STATE(442), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299787] = 3,
    STATE(9967), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299804] = 3,
    STATE(7146), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299821] = 4,
    ACTIONS(17908), 1,
      anon_sym_COMMA,
    STATE(9641), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(2356), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299840] = 3,
    STATE(11221), 1,
      sym_preproc_endif,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299857] = 3,
    STATE(301), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299874] = 3,
    STATE(4902), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299891] = 3,
    STATE(302), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299908] = 3,
    STATE(9974), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299925] = 3,
    STATE(4917), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299942] = 3,
    STATE(2376), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299959] = 3,
    STATE(9975), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299976] = 3,
    STATE(9977), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [299993] = 3,
    STATE(10031), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300010] = 3,
    STATE(10032), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300027] = 3,
    STATE(303), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300044] = 3,
    STATE(1847), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300061] = 3,
    STATE(10044), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300078] = 3,
    STATE(606), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300095] = 3,
    STATE(1850), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300112] = 3,
    STATE(11427), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300129] = 3,
    STATE(607), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300146] = 3,
    STATE(10047), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300163] = 3,
    STATE(1853), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300180] = 3,
    STATE(1854), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300197] = 3,
    STATE(10069), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300214] = 3,
    STATE(11552), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300231] = 3,
    STATE(1856), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300248] = 3,
    STATE(11711), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300265] = 3,
    STATE(1857), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300282] = 3,
    STATE(11928), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300299] = 3,
    STATE(11932), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300316] = 3,
    STATE(10070), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300333] = 3,
    STATE(12086), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300350] = 3,
    STATE(12087), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300367] = 3,
    STATE(12131), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300384] = 3,
    STATE(12135), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300401] = 5,
    ACTIONS(17946), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(17948), 1,
      sym_var_keyword,
    STATE(11494), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300422] = 3,
    STATE(12208), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300439] = 3,
    STATE(1859), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300456] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17952), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11501), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300477] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17954), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11502), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300498] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17956), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11504), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300519] = 3,
    STATE(1860), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300536] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17958), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11512), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300557] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17960), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11513), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300578] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17962), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11514), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300599] = 3,
    STATE(10076), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300616] = 3,
    STATE(304), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300633] = 3,
    STATE(10078), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300650] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17964), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11525), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300671] = 3,
    STATE(273), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300688] = 3,
    STATE(1881), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300705] = 4,
    ACTIONS(17966), 1,
      sym_identifier,
    STATE(6867), 1,
      sym_preproc_not_expression,
    ACTIONS(17968), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300724] = 4,
    ACTIONS(17970), 1,
      sym_identifier,
    STATE(6869), 1,
      sym_preproc_not_expression,
    ACTIONS(17968), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300743] = 3,
    STATE(2281), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300760] = 3,
    STATE(4408), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300777] = 3,
    STATE(3285), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300794] = 3,
    STATE(5080), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300811] = 4,
    ACTIONS(17972), 1,
      sym_identifier,
    STATE(2750), 1,
      sym_preproc_not_expression,
    ACTIONS(17974), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300830] = 4,
    ACTIONS(17976), 1,
      sym_identifier,
    STATE(2741), 1,
      sym_preproc_not_expression,
    ACTIONS(17974), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300849] = 3,
    STATE(251), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300866] = 4,
    ACTIONS(17978), 1,
      anon_sym_COMMA,
    STATE(9641), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(2405), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300885] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17981), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11612), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300906] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17983), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11619), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300927] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17985), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11620), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300948] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17987), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11622), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300969] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17989), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11627), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [300990] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17991), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11628), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301011] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17993), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11629), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301032] = 3,
    STATE(11522), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301049] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17995), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11634), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301070] = 3,
    STATE(11937), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301087] = 3,
    STATE(5082), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301104] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17997), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11690), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301125] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(17999), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11697), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301146] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18001), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11698), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301167] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18003), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11700), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301188] = 3,
    STATE(9712), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301205] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18005), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11705), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301226] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18007), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11706), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301247] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18009), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11707), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301268] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18011), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11712), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301289] = 3,
    STATE(414), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301306] = 3,
    STATE(6955), 1,
      sym_preproc_endif,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301323] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18013), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11749), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301344] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18015), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11755), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301365] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18017), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11756), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301386] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18019), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11758), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301407] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18021), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11762), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301428] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18023), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11763), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301449] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18025), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11764), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301470] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18027), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11768), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301491] = 3,
    STATE(1885), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301508] = 3,
    STATE(6958), 1,
      sym_preproc_endif,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301525] = 3,
    STATE(1887), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301542] = 3,
    STATE(6962), 1,
      sym_preproc_endif,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301559] = 3,
    STATE(6963), 1,
      sym_preproc_endif,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301576] = 3,
    STATE(6970), 1,
      sym_preproc_endif,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301593] = 3,
    STATE(6972), 1,
      sym_preproc_endif,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301610] = 3,
    STATE(6982), 1,
      sym_preproc_endif,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301627] = 3,
    STATE(6984), 1,
      sym_preproc_endif,
    ACTIONS(11622), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301644] = 3,
    STATE(1888), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301661] = 3,
    STATE(608), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301678] = 3,
    STATE(609), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301695] = 3,
    STATE(12457), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301712] = 3,
    STATE(409), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301729] = 4,
    ACTIONS(18029), 1,
      sym_identifier,
    STATE(1731), 1,
      sym_preproc_not_expression,
    ACTIONS(18031), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301748] = 3,
    STATE(5083), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301765] = 3,
    STATE(3831), 1,
      sym_preproc_endif,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301782] = 3,
    STATE(1899), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301799] = 3,
    STATE(7948), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301816] = 3,
    STATE(1903), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301833] = 3,
    STATE(11616), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301850] = 3,
    STATE(9649), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301867] = 4,
    STATE(11143), 1,
      sym_boolean,
    ACTIONS(17920), 2,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
    ACTIONS(18033), 2,
      sym_string_literal,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301886] = 3,
    STATE(7501), 1,
      sym_preproc_endif,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301903] = 4,
    ACTIONS(18035), 1,
      sym_identifier,
    STATE(1762), 1,
      sym_preproc_not_expression,
    ACTIONS(18037), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301922] = 3,
    STATE(2315), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301939] = 3,
    STATE(7492), 1,
      sym_preproc_endif,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301956] = 5,
    ACTIONS(18039), 1,
      anon_sym_DOT,
    ACTIONS(18041), 1,
      anon_sym_EQ,
    STATE(4784), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(2348), 2,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301977] = 3,
    STATE(2364), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [301994] = 3,
    STATE(7507), 1,
      sym_preproc_endif,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302011] = 3,
    STATE(7522), 1,
      sym_preproc_endif,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302028] = 3,
    STATE(2365), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302045] = 3,
    STATE(7529), 1,
      sym_preproc_endif,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302062] = 3,
    STATE(7531), 1,
      sym_preproc_endif,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302079] = 3,
    STATE(9651), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302096] = 3,
    STATE(7543), 1,
      sym_preproc_endif,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302113] = 3,
    STATE(7544), 1,
      sym_preproc_endif,
    ACTIONS(5560), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302130] = 4,
    ACTIONS(18043), 1,
      sym_identifier,
    STATE(1622), 1,
      sym_preproc_not_expression,
    ACTIONS(18031), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302149] = 4,
    ACTIONS(18045), 1,
      sym_identifier,
    STATE(5815), 1,
      sym_preproc_not_expression,
    ACTIONS(18047), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302168] = 4,
    ACTIONS(2541), 1,
      anon_sym_COMMA,
    ACTIONS(18049), 1,
      anon_sym_SEMI,
    ACTIONS(11801), 3,
      anon_sym_DOT,
      anon_sym_EQ,
      aux_sym_where_clause_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302187] = 3,
    STATE(11649), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302204] = 3,
    STATE(11696), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302221] = 3,
    STATE(2316), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302238] = 4,
    ACTIONS(18052), 1,
      sym_identifier,
    STATE(1750), 1,
      sym_preproc_not_expression,
    ACTIONS(18037), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302257] = 3,
    STATE(3288), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302274] = 3,
    STATE(2367), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302291] = 3,
    STATE(9612), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302308] = 3,
    STATE(12110), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302325] = 3,
    STATE(2317), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302342] = 3,
    STATE(9614), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302359] = 3,
    STATE(9615), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302376] = 3,
    STATE(1905), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302393] = 3,
    STATE(3289), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302410] = 3,
    STATE(9419), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302427] = 3,
    STATE(2321), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302444] = 3,
    STATE(1913), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302461] = 3,
    STATE(9426), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302478] = 3,
    STATE(9617), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302495] = 3,
    STATE(1914), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302512] = 3,
    STATE(918), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302529] = 3,
    STATE(9439), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302546] = 3,
    STATE(9440), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302563] = 3,
    STATE(910), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302580] = 3,
    STATE(1920), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302597] = 3,
    STATE(9442), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302614] = 3,
    STATE(9444), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302631] = 3,
    STATE(934), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302648] = 3,
    STATE(3841), 1,
      sym_preproc_endif,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302665] = 3,
    STATE(9446), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302682] = 3,
    STATE(9447), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302699] = 3,
    STATE(1921), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302716] = 4,
    ACTIONS(18054), 1,
      sym_identifier,
    STATE(5658), 1,
      sym_preproc_not_expression,
    ACTIONS(18047), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302735] = 4,
    ACTIONS(18056), 1,
      sym_identifier,
    STATE(4625), 1,
      sym_preproc_not_expression,
    ACTIONS(18058), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302754] = 3,
    STATE(1816), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302771] = 3,
    STATE(1925), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302788] = 4,
    STATE(3150), 1,
      sym_if_keyword,
    STATE(8945), 1,
      sym__preproc_if_header,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302807] = 3,
    STATE(3829), 1,
      sym_preproc_endif,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302824] = 3,
    STATE(3835), 1,
      sym_preproc_endif,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302841] = 3,
    STATE(6373), 1,
      sym_preproc_endif,
    ACTIONS(9129), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302858] = 3,
    STATE(2290), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302875] = 3,
    STATE(4538), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302892] = 3,
    STATE(610), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302909] = 3,
    STATE(1552), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302926] = 3,
    STATE(7066), 1,
      sym_preproc_endif,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302943] = 3,
    STATE(2300), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302960] = 3,
    STATE(450), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302977] = 3,
    STATE(7071), 1,
      sym_preproc_endif,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [302994] = 3,
    STATE(3294), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303011] = 3,
    STATE(2370), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303028] = 3,
    STATE(7075), 1,
      sym_preproc_endif,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303045] = 3,
    STATE(7076), 1,
      sym_preproc_endif,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303062] = 3,
    STATE(378), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303079] = 3,
    STATE(7079), 1,
      sym_preproc_endif,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303096] = 3,
    STATE(7080), 1,
      sym_preproc_endif,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303113] = 3,
    STATE(3295), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303130] = 3,
    STATE(7082), 1,
      sym_preproc_endif,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303147] = 3,
    STATE(7083), 1,
      sym_preproc_endif,
    ACTIONS(5576), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303164] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18060), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11952), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303185] = 4,
    ACTIONS(18062), 1,
      sym_identifier,
    STATE(4615), 1,
      sym_preproc_not_expression,
    ACTIONS(18058), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303204] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18064), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11956), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303225] = 3,
    STATE(381), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303242] = 3,
    STATE(8898), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303259] = 3,
    STATE(455), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303276] = 3,
    STATE(611), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303293] = 3,
    STATE(8901), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303310] = 4,
    STATE(3150), 1,
      sym_if_keyword,
    STATE(9803), 1,
      sym__preproc_if_header,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303329] = 3,
    STATE(922), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303346] = 3,
    STATE(924), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303363] = 3,
    STATE(925), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303380] = 3,
    STATE(3857), 1,
      sym_preproc_endif,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303397] = 3,
    STATE(8904), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303414] = 3,
    STATE(8964), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303431] = 3,
    STATE(522), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303448] = 3,
    STATE(8907), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303465] = 3,
    STATE(8908), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303482] = 3,
    STATE(3855), 1,
      sym_preproc_endif,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303499] = 3,
    STATE(8910), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303516] = 3,
    STATE(8911), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303533] = 3,
    STATE(549), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303550] = 3,
    STATE(550), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303567] = 3,
    STATE(6520), 1,
      sym_preproc_endif,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303584] = 3,
    STATE(3880), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303601] = 3,
    STATE(3863), 1,
      sym_preproc_endif,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303618] = 3,
    STATE(6523), 1,
      sym_preproc_endif,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303635] = 3,
    STATE(1556), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303652] = 3,
    STATE(1558), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303669] = 3,
    STATE(6526), 1,
      sym_preproc_endif,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303686] = 3,
    STATE(6527), 1,
      sym_preproc_endif,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303703] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4137), 5,
      anon_sym_SEMI,
      anon_sym_LPAREN2,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
  [303718] = 3,
    STATE(6529), 1,
      sym_preproc_endif,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303735] = 3,
    STATE(6530), 1,
      sym_preproc_endif,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303752] = 3,
    STATE(443), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303769] = 3,
    STATE(6532), 1,
      sym_preproc_endif,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303786] = 3,
    STATE(928), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303803] = 3,
    STATE(930), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303820] = 3,
    STATE(931), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303837] = 4,
    STATE(3150), 1,
      sym_if_keyword,
    STATE(9901), 1,
      sym__preproc_if_header,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303856] = 3,
    STATE(6533), 1,
      sym_preproc_endif,
    ACTIONS(5869), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303873] = 3,
    STATE(612), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303890] = 3,
    STATE(7575), 1,
      sym_preproc_endif,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303907] = 3,
    STATE(551), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303924] = 3,
    STATE(7606), 1,
      sym_preproc_endif,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303941] = 3,
    STATE(445), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303958] = 3,
    STATE(552), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303975] = 3,
    STATE(7568), 1,
      sym_preproc_endif,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [303992] = 3,
    STATE(7590), 1,
      sym_preproc_endif,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304009] = 3,
    STATE(1561), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304026] = 3,
    STATE(4673), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304043] = 3,
    STATE(7597), 1,
      sym_preproc_endif,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304060] = 3,
    STATE(7609), 1,
      sym_preproc_endif,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304077] = 3,
    STATE(7625), 1,
      sym_preproc_endif,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304094] = 3,
    STATE(7561), 1,
      sym_preproc_endif,
    ACTIONS(5516), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304111] = 3,
    ACTIONS(18066), 1,
      anon_sym_LPAREN2,
    ACTIONS(4141), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304128] = 3,
    STATE(3885), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304145] = 3,
    STATE(4992), 1,
      sym_preproc_endif,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304162] = 3,
    STATE(418), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304179] = 3,
    STATE(4996), 1,
      sym_preproc_endif,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304196] = 3,
    STATE(553), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304213] = 3,
    STATE(5025), 1,
      sym_preproc_endif,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304230] = 3,
    STATE(5038), 1,
      sym_preproc_endif,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304247] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18068), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11959), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304268] = 3,
    STATE(5056), 1,
      sym_preproc_endif,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304285] = 3,
    STATE(11915), 1,
      sym_preproc_endif,
    ACTIONS(223), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304302] = 3,
    STATE(5072), 1,
      sym_preproc_endif,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304319] = 4,
    ACTIONS(18070), 1,
      sym_identifier,
    STATE(3274), 1,
      sym_preproc_not_expression,
    ACTIONS(18072), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304338] = 4,
    ACTIONS(18074), 1,
      sym_identifier,
    STATE(3504), 1,
      sym_preproc_not_expression,
    ACTIONS(18076), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304357] = 3,
    STATE(5074), 1,
      sym_preproc_endif,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304374] = 3,
    STATE(5086), 1,
      sym_preproc_endif,
    ACTIONS(5574), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304391] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18078), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11360), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304412] = 3,
    STATE(386), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304429] = 3,
    STATE(5848), 1,
      sym_preproc_endif,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304446] = 3,
    STATE(7092), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304463] = 3,
    STATE(5855), 1,
      sym_preproc_endif,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304480] = 3,
    STATE(3950), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304497] = 3,
    STATE(392), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304514] = 3,
    STATE(5861), 1,
      sym_preproc_endif,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304531] = 3,
    STATE(5863), 1,
      sym_preproc_endif,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304548] = 3,
    STATE(2342), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304565] = 3,
    STATE(5865), 1,
      sym_preproc_endif,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304582] = 3,
    STATE(5866), 1,
      sym_preproc_endif,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304599] = 3,
    STATE(3956), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304616] = 3,
    STATE(4550), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304633] = 3,
    STATE(5868), 1,
      sym_preproc_endif,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304650] = 3,
    STATE(5723), 1,
      sym_preproc_endif,
    ACTIONS(5570), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304667] = 3,
    STATE(3960), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304684] = 3,
    STATE(3297), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304701] = 3,
    STATE(5484), 1,
      sym_preproc_endif,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304718] = 3,
    STATE(1820), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304735] = 3,
    STATE(244), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304752] = 3,
    STATE(5487), 1,
      sym_preproc_endif,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304769] = 3,
    STATE(1821), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304786] = 3,
    STATE(3814), 1,
      sym_preproc_endif,
    ACTIONS(5562), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304803] = 3,
    STATE(5492), 1,
      sym_preproc_endif,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304820] = 3,
    STATE(8822), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304837] = 3,
    STATE(5494), 1,
      sym_preproc_endif,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304854] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18080), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11408), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304875] = 3,
    STATE(5498), 1,
      sym_preproc_endif,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304892] = 3,
    STATE(5503), 1,
      sym_preproc_endif,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304909] = 3,
    STATE(422), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304926] = 3,
    STATE(5505), 1,
      sym_preproc_endif,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304943] = 3,
    STATE(5506), 1,
      sym_preproc_endif,
    ACTIONS(5829), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304960] = 4,
    ACTIONS(18082), 1,
      sym_identifier,
    STATE(5372), 1,
      sym_preproc_not_expression,
    ACTIONS(18084), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304979] = 3,
    STATE(7181), 1,
      sym_preproc_endif,
    ACTIONS(1577), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [304996] = 3,
    STATE(1565), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305013] = 3,
    STATE(4746), 1,
      sym_preproc_endif,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305030] = 3,
    STATE(1566), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305047] = 4,
    ACTIONS(18086), 1,
      sym_identifier,
    STATE(5374), 1,
      sym_preproc_not_expression,
    ACTIONS(18084), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305066] = 3,
    STATE(4749), 1,
      sym_preproc_endif,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305083] = 3,
    STATE(4752), 1,
      sym_preproc_endif,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305100] = 3,
    STATE(4753), 1,
      sym_preproc_endif,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305117] = 3,
    STATE(456), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305134] = 3,
    STATE(4755), 1,
      sym_preproc_endif,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305151] = 3,
    STATE(4507), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305168] = 3,
    STATE(4756), 1,
      sym_preproc_endif,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305185] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18088), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(12655), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305206] = 3,
    STATE(4510), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305223] = 3,
    STATE(4758), 1,
      sym_preproc_endif,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305240] = 3,
    STATE(4759), 1,
      sym_preproc_endif,
    ACTIONS(5572), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305257] = 3,
    STATE(4512), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305274] = 3,
    STATE(1824), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305291] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18090), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11285), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305312] = 3,
    STATE(2233), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305329] = 3,
    STATE(913), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305346] = 3,
    STATE(4539), 1,
      sym_preproc_endif,
    ACTIONS(2881), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305363] = 3,
    STATE(1568), 1,
      sym_preproc_endif,
    ACTIONS(221), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305380] = 3,
    STATE(7799), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305397] = 4,
    ACTIONS(18092), 1,
      anon_sym_SEMI,
    STATE(836), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305416] = 3,
    STATE(2241), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305433] = 5,
    ACTIONS(17948), 1,
      sym_var_keyword,
    ACTIONS(18094), 1,
      aux_sym_preproc_split_procedure_body_token1,
    STATE(11318), 1,
      sym_var_section,
    ACTIONS(17950), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305454] = 3,
    STATE(482), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305471] = 3,
    STATE(2275), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305488] = 3,
    STATE(2276), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305505] = 3,
    STATE(7810), 1,
      sym_preproc_endif,
    ACTIONS(15041), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305522] = 3,
    STATE(3308), 1,
      sym_preproc_endif,
    ACTIONS(2977), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305539] = 4,
    ACTIONS(18096), 1,
      anon_sym_SEMI,
    STATE(841), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305558] = 3,
    STATE(2253), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305575] = 4,
    ACTIONS(18098), 1,
      sym_identifier,
    STATE(4764), 1,
      sym_preproc_not_expression,
    ACTIONS(18076), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305594] = 4,
    ACTIONS(18100), 1,
      sym_identifier,
    STATE(3332), 1,
      sym_preproc_not_expression,
    ACTIONS(18072), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305613] = 3,
    STATE(911), 1,
      sym_preproc_endif,
    ACTIONS(81), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305630] = 3,
    STATE(2279), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305647] = 3,
    STATE(239), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305664] = 4,
    ACTIONS(18102), 1,
      anon_sym_SEMI,
    STATE(846), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305683] = 3,
    STATE(2284), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305700] = 4,
    ACTIONS(18104), 1,
      anon_sym_SEMI,
    STATE(850), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305719] = 3,
    STATE(9692), 1,
      sym_preproc_endif,
    ACTIONS(3674), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305736] = 4,
    ACTIONS(18106), 1,
      anon_sym_SEMI,
    STATE(854), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305755] = 4,
    ACTIONS(18108), 1,
      anon_sym_SEMI,
    STATE(858), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305774] = 4,
    ACTIONS(18110), 1,
      anon_sym_SEMI,
    STATE(862), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305793] = 4,
    ACTIONS(18112), 1,
      anon_sym_SEMI,
    STATE(865), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305812] = 4,
    ACTIONS(18114), 1,
      anon_sym_SEMI,
    STATE(869), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305831] = 4,
    ACTIONS(18116), 1,
      anon_sym_SEMI,
    STATE(873), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305850] = 4,
    ACTIONS(18118), 1,
      anon_sym_SEMI,
    STATE(877), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305869] = 4,
    ACTIONS(18120), 1,
      anon_sym_SEMI,
    STATE(881), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305888] = 4,
    ACTIONS(18122), 1,
      anon_sym_SEMI,
    STATE(885), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305907] = 4,
    ACTIONS(18124), 1,
      anon_sym_SEMI,
    STATE(889), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305926] = 4,
    ACTIONS(18126), 1,
      anon_sym_SEMI,
    STATE(893), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305945] = 4,
    ACTIONS(18128), 1,
      anon_sym_SEMI,
    STATE(897), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305964] = 4,
    ACTIONS(18130), 1,
      anon_sym_SEMI,
    STATE(901), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [305983] = 4,
    ACTIONS(18132), 1,
      anon_sym_SEMI,
    STATE(905), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306002] = 3,
    STATE(2289), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306019] = 3,
    STATE(11170), 1,
      sym_preproc_endif,
    ACTIONS(14399), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306036] = 3,
    STATE(2291), 1,
      sym_preproc_endif,
    ACTIONS(147), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306053] = 3,
    STATE(405), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306070] = 3,
    STATE(406), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306087] = 3,
    STATE(407), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306104] = 3,
    STATE(408), 1,
      sym_preproc_endif,
    ACTIONS(123), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306121] = 4,
    STATE(3150), 1,
      sym_if_keyword,
    STATE(9860), 1,
      sym__preproc_if_header,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306140] = 4,
    ACTIONS(18134), 1,
      sym_identifier,
    STATE(1772), 1,
      sym_preproc_not_expression,
    ACTIONS(18136), 3,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306159] = 3,
    STATE(11883), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306175] = 3,
    STATE(3127), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306191] = 3,
    STATE(3141), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306207] = 2,
    ACTIONS(4648), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306221] = 3,
    STATE(9934), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306237] = 2,
    ACTIONS(4335), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306251] = 3,
    STATE(9935), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306267] = 3,
    STATE(9619), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306283] = 3,
    STATE(2919), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306299] = 2,
    ACTIONS(4339), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306313] = 2,
    ACTIONS(4343), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306327] = 3,
    STATE(9623), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306343] = 3,
    STATE(9624), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306359] = 2,
    ACTIONS(4347), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306373] = 2,
    ACTIONS(4351), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306387] = 3,
    STATE(11509), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306403] = 3,
    STATE(9629), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306419] = 3,
    STATE(9936), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306435] = 2,
    ACTIONS(12650), 4,
      anon_sym_RBRACE,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306449] = 3,
    STATE(11518), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306465] = 3,
    STATE(11519), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306481] = 4,
    ACTIONS(18140), 1,
      anon_sym_RBRACE,
    ACTIONS(18142), 1,
      sym_dataitem_keyword,
    STATE(9996), 2,
      sym_query_dataitem,
      aux_sym_elements_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306499] = 3,
    STATE(9937), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306515] = 3,
    STATE(9685), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306531] = 3,
    STATE(11526), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306547] = 3,
    STATE(9600), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306563] = 4,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(18144), 1,
      anon_sym_RBRACE,
    STATE(9991), 2,
      sym_view_definition,
      aux_sym_addfirst_views_modification_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306581] = 2,
    ACTIONS(4355), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306595] = 3,
    STATE(9309), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306611] = 2,
    ACTIONS(4359), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306625] = 3,
    STATE(9320), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306641] = 2,
    ACTIONS(4363), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306655] = 2,
    ACTIONS(4624), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306669] = 2,
    ACTIONS(4367), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306683] = 2,
    ACTIONS(4371), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306697] = 2,
    ACTIONS(4393), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306711] = 3,
    STATE(9321), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306727] = 2,
    ACTIONS(4461), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306741] = 2,
    ACTIONS(4690), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306755] = 2,
    ACTIONS(4628), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306769] = 2,
    ACTIONS(4473), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306783] = 2,
    ACTIONS(4477), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306797] = 2,
    ACTIONS(4481), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306811] = 2,
    ACTIONS(4485), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306825] = 2,
    ACTIONS(4628), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306839] = 3,
    STATE(4966), 1,
      sym_preproc_else,
    ACTIONS(15099), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306855] = 2,
    ACTIONS(4750), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306869] = 2,
    ACTIONS(4215), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306883] = 2,
    ACTIONS(4754), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306897] = 4,
    ACTIONS(18146), 1,
      sym_identifier,
    ACTIONS(18148), 1,
      anon_sym_RBRACE,
    STATE(10297), 2,
      sym_label_declaration,
      aux_sym_labels_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306915] = 2,
    ACTIONS(8815), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_type_declaration_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306929] = 4,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(18150), 1,
      anon_sym_RBRACE,
    STATE(10052), 2,
      sym_view_definition,
      aux_sym_addfirst_views_modification_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306947] = 2,
    ACTIONS(4750), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306961] = 3,
    STATE(9683), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306977] = 2,
    ACTIONS(4758), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [306991] = 2,
    ACTIONS(4762), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307005] = 4,
    ACTIONS(18152), 1,
      anon_sym_RBRACE,
    ACTIONS(18154), 1,
      sym_dataitem_keyword,
    STATE(9996), 2,
      sym_query_dataitem,
      aux_sym_elements_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307023] = 3,
    STATE(4901), 1,
      sym_preproc_else,
    ACTIONS(15099), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307039] = 2,
    ACTIONS(4758), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307053] = 2,
    ACTIONS(4766), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307067] = 2,
    ACTIONS(4694), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307081] = 2,
    ACTIONS(4690), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307095] = 3,
    STATE(9348), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307111] = 2,
    ACTIONS(4770), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307125] = 2,
    ACTIONS(4698), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307139] = 2,
    ACTIONS(4698), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307153] = 3,
    STATE(3158), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307169] = 2,
    ACTIONS(12611), 4,
      anon_sym_RBRACE,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307183] = 3,
    STATE(9350), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307199] = 3,
    STATE(9358), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307215] = 3,
    STATE(9360), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307231] = 2,
    ACTIONS(4656), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307245] = 3,
    STATE(9506), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307261] = 3,
    STATE(9507), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307277] = 3,
    STATE(9457), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307293] = 3,
    STATE(9459), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307309] = 3,
    STATE(12084), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307325] = 4,
    ACTIONS(18159), 1,
      aux_sym_where_condition_token3,
    ACTIONS(18161), 1,
      sym_filter_keyword,
    ACTIONS(18157), 2,
      aux_sym_where_condition_token1,
      aux_sym_where_condition_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307343] = 3,
    STATE(3018), 1,
      sym_in_keyword,
    ACTIONS(18163), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307359] = 2,
    ACTIONS(4489), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307373] = 2,
    ACTIONS(4493), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307387] = 3,
    STATE(9460), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307403] = 3,
    STATE(9461), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307419] = 3,
    STATE(9463), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307435] = 3,
    STATE(9467), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307451] = 3,
    STATE(12647), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307467] = 4,
    ACTIONS(18146), 1,
      sym_identifier,
    ACTIONS(18165), 1,
      anon_sym_RBRACE,
    STATE(10228), 2,
      sym_label_declaration,
      aux_sym_labels_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307485] = 2,
    ACTIONS(4497), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307499] = 3,
    STATE(9643), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307515] = 2,
    ACTIONS(4501), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307529] = 2,
    ACTIONS(4505), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307543] = 2,
    ACTIONS(4509), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307557] = 2,
    ACTIONS(4513), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307571] = 3,
    STATE(9646), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307587] = 3,
    STATE(9647), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307603] = 2,
    ACTIONS(4517), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307617] = 3,
    STATE(11626), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307633] = 3,
    STATE(9650), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307649] = 3,
    STATE(11631), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307665] = 3,
    STATE(11632), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307681] = 3,
    STATE(9468), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307697] = 3,
    STATE(11635), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307713] = 3,
    STATE(9475), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307729] = 3,
    STATE(9511), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307745] = 2,
    ACTIONS(4521), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307759] = 2,
    ACTIONS(4525), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307773] = 2,
    ACTIONS(4529), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307787] = 2,
    ACTIONS(4533), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307801] = 3,
    STATE(9886), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307817] = 3,
    STATE(9522), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307833] = 3,
    STATE(9584), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307849] = 3,
    STATE(9586), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307865] = 4,
    ACTIONS(18167), 1,
      anon_sym_RBRACE,
    ACTIONS(18169), 1,
      sym_view_keyword,
    STATE(10052), 2,
      sym_view_definition,
      aux_sym_addfirst_views_modification_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307883] = 2,
    ACTIONS(12673), 4,
      anon_sym_RBRACE,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307897] = 3,
    STATE(9594), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307913] = 3,
    STATE(9627), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307929] = 4,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(18172), 1,
      anon_sym_RBRACE,
    STATE(10052), 2,
      sym_view_definition,
      aux_sym_addfirst_views_modification_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307947] = 2,
    ACTIONS(4774), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307961] = 2,
    ACTIONS(4670), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307975] = 2,
    ACTIONS(4778), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [307989] = 2,
    ACTIONS(4774), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308003] = 4,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(18174), 1,
      anon_sym_RBRACE,
    STATE(10052), 2,
      sym_view_definition,
      aux_sym_addfirst_views_modification_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308021] = 2,
    ACTIONS(4195), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308035] = 2,
    ACTIONS(4199), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308049] = 2,
    ACTIONS(4203), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308063] = 2,
    ACTIONS(4207), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308077] = 2,
    ACTIONS(4782), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308091] = 4,
    ACTIONS(18176), 1,
      anon_sym_RBRACE,
    ACTIONS(18178), 1,
      sym_layout_keyword,
    STATE(10261), 2,
      sym_rendering_layout,
      aux_sym_rendering_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308109] = 2,
    ACTIONS(4786), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308123] = 2,
    ACTIONS(4537), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308137] = 2,
    ACTIONS(4541), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308151] = 2,
    ACTIONS(4782), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308165] = 3,
    STATE(9682), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308181] = 2,
    ACTIONS(4586), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308195] = 2,
    ACTIONS(4674), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308209] = 3,
    STATE(9654), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308225] = 2,
    ACTIONS(4545), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308239] = 2,
    ACTIONS(4549), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308253] = 2,
    ACTIONS(4553), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308267] = 3,
    STATE(9396), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308283] = 3,
    STATE(9658), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308299] = 3,
    STATE(9659), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308315] = 3,
    STATE(11704), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308331] = 3,
    STATE(9661), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308347] = 3,
    STATE(11709), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308363] = 3,
    STATE(11710), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308379] = 3,
    STATE(9397), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308395] = 3,
    STATE(11713), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308411] = 2,
    ACTIONS(4790), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308425] = 2,
    ACTIONS(4794), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308439] = 3,
    STATE(2925), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308455] = 3,
    STATE(3064), 1,
      sym_in_keyword,
    ACTIONS(18163), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308471] = 4,
    ACTIONS(18180), 1,
      anon_sym_DOT,
    STATE(10092), 1,
      aux_sym_calc_field_reference_repeat1,
    ACTIONS(18183), 2,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308489] = 2,
    ACTIONS(4702), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308503] = 2,
    ACTIONS(4590), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308517] = 2,
    ACTIONS(4798), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308531] = 2,
    ACTIONS(4802), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308545] = 2,
    ACTIONS(4191), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308559] = 3,
    ACTIONS(18185), 1,
      anon_sym_SEMI,
    ACTIONS(4596), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308575] = 2,
    ACTIONS(4179), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308589] = 3,
    STATE(9665), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308605] = 3,
    STATE(8884), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308621] = 2,
    ACTIONS(4215), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_type_declaration_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308635] = 3,
    STATE(9398), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308651] = 3,
    STATE(9668), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308667] = 3,
    STATE(9669), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308683] = 3,
    STATE(9401), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308699] = 3,
    STATE(11761), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308715] = 3,
    STATE(9671), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308731] = 3,
    STATE(11766), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308747] = 3,
    STATE(11767), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308763] = 3,
    STATE(11769), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308779] = 2,
    ACTIONS(4706), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308793] = 2,
    ACTIONS(4191), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308807] = 2,
    ACTIONS(4211), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308821] = 2,
    ACTIONS(4219), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308835] = 2,
    ACTIONS(4223), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308849] = 3,
    STATE(11787), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308865] = 3,
    STATE(11788), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308881] = 3,
    STATE(11789), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308897] = 3,
    STATE(11790), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308913] = 5,
    ACTIONS(2207), 1,
      aux_sym_where_clause_token1,
    ACTIONS(18187), 1,
      anon_sym_SEMI,
    ACTIONS(18189), 1,
      aux_sym_sorting_value_token2,
    STATE(11727), 1,
      sym_where_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308933] = 3,
    ACTIONS(18191), 1,
      anon_sym_SEMI,
    ACTIONS(4571), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308949] = 2,
    ACTIONS(4227), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308963] = 3,
    STATE(11804), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308979] = 3,
    STATE(11805), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [308995] = 3,
    STATE(11806), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309011] = 3,
    STATE(11807), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309027] = 2,
    ACTIONS(4231), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309041] = 3,
    STATE(11816), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309057] = 3,
    STATE(11817), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309073] = 3,
    STATE(11818), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309089] = 3,
    STATE(11819), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309105] = 2,
    ACTIONS(4235), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309119] = 3,
    STATE(11826), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309135] = 3,
    STATE(11827), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309151] = 3,
    STATE(11828), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309167] = 3,
    STATE(11829), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309183] = 3,
    STATE(11835), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309199] = 3,
    STATE(11836), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309215] = 3,
    STATE(11837), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309231] = 3,
    STATE(11838), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309247] = 3,
    STATE(11844), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309263] = 3,
    STATE(11845), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309279] = 3,
    STATE(11846), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309295] = 3,
    STATE(11847), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309311] = 3,
    STATE(11853), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309327] = 3,
    STATE(11854), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309343] = 3,
    STATE(11855), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309359] = 3,
    STATE(11856), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309375] = 3,
    STATE(11860), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309391] = 3,
    STATE(11861), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309407] = 3,
    STATE(11862), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309423] = 3,
    STATE(11863), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309439] = 3,
    STATE(11865), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309455] = 3,
    STATE(11866), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309471] = 3,
    STATE(11867), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309487] = 3,
    STATE(11868), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309503] = 3,
    STATE(11870), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309519] = 3,
    STATE(11871), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309535] = 3,
    STATE(11872), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309551] = 3,
    STATE(11873), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309567] = 3,
    STATE(11874), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309583] = 3,
    STATE(11875), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309599] = 3,
    STATE(11876), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309615] = 3,
    STATE(11877), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309631] = 3,
    STATE(11878), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309647] = 3,
    STATE(11879), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309663] = 2,
    ACTIONS(18193), 4,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309677] = 3,
    STATE(11881), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309693] = 3,
    STATE(11882), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309709] = 2,
    ACTIONS(4652), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309723] = 3,
    STATE(11884), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309739] = 3,
    STATE(11885), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309755] = 3,
    STATE(11886), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309771] = 3,
    STATE(11887), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309787] = 3,
    STATE(11888), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309803] = 3,
    STATE(11889), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309819] = 2,
    ACTIONS(4632), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309833] = 2,
    ACTIONS(18195), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_type_declaration_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309847] = 2,
    ACTIONS(4179), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309861] = 2,
    ACTIONS(4600), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309875] = 2,
    ACTIONS(4239), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309889] = 2,
    ACTIONS(4604), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309903] = 3,
    STATE(3090), 1,
      sym_in_keyword,
    ACTIONS(18163), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309919] = 3,
    STATE(4970), 1,
      sym_preproc_else,
    ACTIONS(15099), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309935] = 3,
    STATE(9554), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309951] = 3,
    STATE(9556), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309967] = 3,
    STATE(9557), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309983] = 2,
    ACTIONS(8926), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_type_declaration_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [309997] = 3,
    STATE(9559), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310013] = 2,
    ACTIONS(4702), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310027] = 3,
    STATE(9892), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310043] = 2,
    ACTIONS(4710), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310057] = 4,
    ACTIONS(18197), 1,
      anon_sym_RBRACE,
    ACTIONS(18199), 1,
      aux_sym_assembly_declaration_token1,
    STATE(10197), 2,
      sym_assembly_declaration,
      aux_sym_dotnet_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310075] = 2,
    ACTIONS(18201), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_type_declaration_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310089] = 2,
    ACTIONS(4714), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310103] = 4,
    ACTIONS(18199), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(18203), 1,
      anon_sym_RBRACE,
    STATE(10326), 2,
      sym_assembly_declaration,
      aux_sym_dotnet_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310121] = 2,
    ACTIONS(4243), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310135] = 2,
    ACTIONS(4710), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310149] = 2,
    ACTIONS(4247), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310163] = 2,
    ACTIONS(4251), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310177] = 4,
    ACTIONS(18205), 1,
      anon_sym_DOT,
    STATE(10092), 1,
      aux_sym_calc_field_reference_repeat1,
    ACTIONS(18207), 2,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310195] = 2,
    ACTIONS(4255), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310209] = 2,
    ACTIONS(4259), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310223] = 2,
    ACTIONS(4263), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310237] = 2,
    ACTIONS(4267), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310251] = 2,
    ACTIONS(4271), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310265] = 2,
    ACTIONS(4275), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310279] = 2,
    ACTIONS(4279), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310293] = 2,
    ACTIONS(4283), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310307] = 3,
    STATE(9753), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310323] = 3,
    STATE(9575), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310339] = 3,
    STATE(9577), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310355] = 3,
    STATE(3103), 1,
      sym_in_keyword,
    ACTIONS(18163), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310371] = 4,
    ACTIONS(18142), 1,
      sym_dataitem_keyword,
    ACTIONS(18209), 1,
      anon_sym_RBRACE,
    STATE(10246), 2,
      sym_query_dataitem,
      aux_sym_elements_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310389] = 4,
    ACTIONS(18146), 1,
      sym_identifier,
    ACTIONS(18211), 1,
      anon_sym_RBRACE,
    STATE(10247), 2,
      sym_label_declaration,
      aux_sym_labels_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310407] = 4,
    ACTIONS(18178), 1,
      sym_layout_keyword,
    ACTIONS(18213), 1,
      anon_sym_RBRACE,
    STATE(10248), 2,
      sym_rendering_layout,
      aux_sym_rendering_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310425] = 3,
    STATE(9578), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310441] = 3,
    STATE(9579), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310457] = 2,
    ACTIONS(4678), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310471] = 2,
    ACTIONS(4682), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310485] = 2,
    ACTIONS(4287), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310499] = 2,
    ACTIONS(4718), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310513] = 2,
    ACTIONS(4722), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310527] = 2,
    ACTIONS(4726), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310541] = 2,
    ACTIONS(4722), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310555] = 3,
    STATE(9775), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310571] = 4,
    ACTIONS(18215), 1,
      sym_identifier,
    ACTIONS(18218), 1,
      anon_sym_RBRACE,
    STATE(10228), 2,
      sym_label_declaration,
      aux_sym_labels_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310589] = 2,
    ACTIONS(4291), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310603] = 4,
    ACTIONS(18222), 1,
      aux_sym_where_condition_token3,
    ACTIONS(18224), 1,
      sym_filter_keyword,
    ACTIONS(18220), 2,
      aux_sym_where_condition_token1,
      aux_sym_where_condition_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310621] = 4,
    ACTIONS(2207), 1,
      aux_sym_where_clause_token1,
    STATE(11193), 1,
      sym_where_clause,
    ACTIONS(11740), 2,
      anon_sym_SEMI,
      aux_sym_if_table_relation_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310639] = 3,
    STATE(9769), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310655] = 2,
    ACTIONS(4686), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310669] = 3,
    STATE(3118), 1,
      sym_in_keyword,
    ACTIONS(18163), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310685] = 2,
    ACTIONS(4295), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310699] = 2,
    ACTIONS(4299), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310713] = 2,
    ACTIONS(4303), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310727] = 2,
    ACTIONS(4307), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310741] = 4,
    ACTIONS(18205), 1,
      anon_sym_DOT,
    STATE(10202), 1,
      aux_sym_calc_field_reference_repeat1,
    ACTIONS(12774), 2,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310759] = 2,
    ACTIONS(4311), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310773] = 2,
    ACTIONS(4315), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310787] = 4,
    ACTIONS(18142), 1,
      sym_dataitem_keyword,
    ACTIONS(18226), 1,
      anon_sym_RBRACE,
    STATE(10285), 2,
      sym_query_dataitem,
      aux_sym_elements_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310805] = 2,
    ACTIONS(4730), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310819] = 2,
    ACTIONS(4734), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310833] = 4,
    ACTIONS(18146), 1,
      sym_identifier,
    ACTIONS(18228), 1,
      anon_sym_RBRACE,
    STATE(10287), 2,
      sym_label_declaration,
      aux_sym_labels_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310851] = 4,
    ACTIONS(18142), 1,
      sym_dataitem_keyword,
    ACTIONS(18230), 1,
      anon_sym_RBRACE,
    STATE(9996), 2,
      sym_query_dataitem,
      aux_sym_elements_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310869] = 4,
    ACTIONS(18146), 1,
      sym_identifier,
    ACTIONS(18232), 1,
      anon_sym_RBRACE,
    STATE(10228), 2,
      sym_label_declaration,
      aux_sym_labels_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310887] = 4,
    ACTIONS(18178), 1,
      sym_layout_keyword,
    ACTIONS(18234), 1,
      anon_sym_RBRACE,
    STATE(10261), 2,
      sym_rendering_layout,
      aux_sym_rendering_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310905] = 5,
    ACTIONS(2207), 1,
      aux_sym_where_clause_token1,
    ACTIONS(18236), 1,
      anon_sym_SEMI,
    ACTIONS(18238), 1,
      aux_sym_sorting_value_token2,
    STATE(12177), 1,
      sym_where_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310925] = 3,
    STATE(4925), 1,
      sym_preproc_else,
    ACTIONS(15099), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310941] = 4,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(18240), 1,
      anon_sym_RBRACE,
    STATE(10353), 2,
      sym_view_definition,
      aux_sym_addfirst_views_modification_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310959] = 4,
    ACTIONS(18199), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(18242), 1,
      anon_sym_RBRACE,
    STATE(10260), 2,
      sym_assembly_declaration,
      aux_sym_dotnet_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310977] = 4,
    ACTIONS(18178), 1,
      sym_layout_keyword,
    ACTIONS(18244), 1,
      anon_sym_RBRACE,
    STATE(10288), 2,
      sym_rendering_layout,
      aux_sym_rendering_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [310995] = 2,
    ACTIONS(4730), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311009] = 2,
    ACTIONS(4738), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311023] = 2,
    ACTIONS(4742), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311037] = 2,
    ACTIONS(4746), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311051] = 4,
    ACTIONS(18178), 1,
      sym_layout_keyword,
    ACTIONS(18246), 1,
      anon_sym_RBRACE,
    STATE(10313), 2,
      sym_rendering_layout,
      aux_sym_rendering_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311069] = 2,
    ACTIONS(4319), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311083] = 4,
    ACTIONS(18199), 1,
      aux_sym_assembly_declaration_token1,
    ACTIONS(18248), 1,
      anon_sym_RBRACE,
    STATE(10326), 2,
      sym_assembly_declaration,
      aux_sym_dotnet_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311101] = 4,
    ACTIONS(18250), 1,
      anon_sym_RBRACE,
    ACTIONS(18252), 1,
      sym_layout_keyword,
    STATE(10261), 2,
      sym_rendering_layout,
      aux_sym_rendering_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311119] = 2,
    ACTIONS(4323), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311133] = 2,
    ACTIONS(12681), 4,
      anon_sym_RBRACE,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311147] = 4,
    ACTIONS(18178), 1,
      sym_layout_keyword,
    ACTIONS(18255), 1,
      anon_sym_RBRACE,
    STATE(10067), 2,
      sym_rendering_layout,
      aux_sym_rendering_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311165] = 4,
    ACTIONS(18142), 1,
      sym_dataitem_keyword,
    ACTIONS(18257), 1,
      anon_sym_RBRACE,
    STATE(10281), 2,
      sym_query_dataitem,
      aux_sym_elements_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311183] = 4,
    ACTIONS(18146), 1,
      sym_identifier,
    ACTIONS(18259), 1,
      anon_sym_RBRACE,
    STATE(10306), 2,
      sym_label_declaration,
      aux_sym_labels_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311201] = 3,
    STATE(9810), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311217] = 3,
    STATE(9597), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311233] = 4,
    ACTIONS(18178), 1,
      sym_layout_keyword,
    ACTIONS(18261), 1,
      anon_sym_RBRACE,
    STATE(10314), 2,
      sym_rendering_layout,
      aux_sym_rendering_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311251] = 3,
    STATE(9814), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311267] = 3,
    STATE(11849), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311283] = 3,
    STATE(12636), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311299] = 3,
    STATE(9840), 1,
      sym_preproc_else,
    ACTIONS(121), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311315] = 2,
    ACTIONS(4616), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311329] = 3,
    STATE(837), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311345] = 3,
    STATE(617), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311361] = 3,
    STATE(3209), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311377] = 3,
    STATE(3210), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311393] = 3,
    STATE(3211), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311409] = 3,
    STATE(3212), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311425] = 4,
    ACTIONS(18142), 1,
      sym_dataitem_keyword,
    ACTIONS(18263), 1,
      anon_sym_RBRACE,
    STATE(9996), 2,
      sym_query_dataitem,
      aux_sym_elements_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311443] = 3,
    STATE(3208), 1,
      sym_in_keyword,
    ACTIONS(18163), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311459] = 3,
    STATE(4873), 1,
      sym_preproc_else,
    ACTIONS(15099), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311475] = 2,
    ACTIONS(4620), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311489] = 4,
    ACTIONS(18142), 1,
      sym_dataitem_keyword,
    ACTIONS(18265), 1,
      anon_sym_RBRACE,
    STATE(9996), 2,
      sym_query_dataitem,
      aux_sym_elements_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311507] = 4,
    ACTIONS(18142), 1,
      sym_dataitem_keyword,
    ACTIONS(18267), 1,
      anon_sym_RBRACE,
    STATE(9961), 2,
      sym_query_dataitem,
      aux_sym_elements_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311525] = 4,
    ACTIONS(18146), 1,
      sym_identifier,
    ACTIONS(18269), 1,
      anon_sym_RBRACE,
    STATE(10228), 2,
      sym_label_declaration,
      aux_sym_labels_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311543] = 4,
    ACTIONS(18178), 1,
      sym_layout_keyword,
    ACTIONS(18271), 1,
      anon_sym_RBRACE,
    STATE(10261), 2,
      sym_rendering_layout,
      aux_sym_rendering_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311561] = 3,
    STATE(842), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311577] = 2,
    ACTIONS(4579), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311591] = 3,
    STATE(3217), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311607] = 3,
    STATE(3218), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311623] = 3,
    STATE(3219), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311639] = 3,
    STATE(3220), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311655] = 4,
    ACTIONS(18273), 1,
      anon_sym_COMMA,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(18276), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311673] = 2,
    ACTIONS(4612), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311687] = 4,
    ACTIONS(18146), 1,
      sym_identifier,
    ACTIONS(18278), 1,
      anon_sym_RBRACE,
    STATE(10228), 2,
      sym_label_declaration,
      aux_sym_labels_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311705] = 3,
    STATE(8886), 1,
      sym_else_keyword,
    ACTIONS(18138), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311721] = 2,
    ACTIONS(4636), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311735] = 3,
    STATE(4930), 1,
      sym_preproc_else,
    ACTIONS(15099), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311751] = 3,
    STATE(847), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311767] = 3,
    STATE(3223), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311783] = 3,
    STATE(3224), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311799] = 3,
    STATE(3225), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311815] = 3,
    STATE(3226), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311831] = 4,
    ACTIONS(18146), 1,
      sym_identifier,
    ACTIONS(18280), 1,
      anon_sym_RBRACE,
    STATE(10228), 2,
      sym_label_declaration,
      aux_sym_labels_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311849] = 3,
    STATE(4876), 1,
      sym_preproc_else,
    ACTIONS(15099), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311865] = 3,
    STATE(851), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311881] = 3,
    STATE(3230), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311897] = 3,
    STATE(3231), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311913] = 3,
    STATE(3232), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311929] = 3,
    STATE(3233), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311945] = 4,
    ACTIONS(18178), 1,
      sym_layout_keyword,
    ACTIONS(18282), 1,
      anon_sym_RBRACE,
    STATE(10261), 2,
      sym_rendering_layout,
      aux_sym_rendering_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311963] = 4,
    ACTIONS(18178), 1,
      sym_layout_keyword,
    ACTIONS(18284), 1,
      anon_sym_RBRACE,
    STATE(10261), 2,
      sym_rendering_layout,
      aux_sym_rendering_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311981] = 3,
    STATE(855), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [311997] = 3,
    STATE(2810), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312013] = 3,
    STATE(3236), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312029] = 3,
    STATE(3237), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312045] = 3,
    STATE(3238), 1,
      sym_if_keyword,
    ACTIONS(17910), 3,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312061] = 3,
    STATE(4899), 1,
      sym_preproc_else,
    ACTIONS(15099), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312077] = 3,
    STATE(859), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312093] = 4,
    ACTIONS(18142), 1,
      sym_dataitem_keyword,
    ACTIONS(18286), 1,
      anon_sym_RBRACE,
    STATE(10324), 2,
      sym_query_dataitem,
      aux_sym_elements_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312111] = 3,
    STATE(614), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312127] = 4,
    ACTIONS(18142), 1,
      sym_dataitem_keyword,
    ACTIONS(18288), 1,
      anon_sym_RBRACE,
    STATE(9996), 2,
      sym_query_dataitem,
      aux_sym_elements_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312145] = 3,
    STATE(866), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312161] = 4,
    ACTIONS(18290), 1,
      anon_sym_RBRACE,
    ACTIONS(18292), 1,
      aux_sym_assembly_declaration_token1,
    STATE(10326), 2,
      sym_assembly_declaration,
      aux_sym_dotnet_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312179] = 3,
    STATE(870), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312195] = 2,
    ACTIONS(4640), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312209] = 3,
    STATE(874), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312225] = 2,
    ACTIONS(4644), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312239] = 3,
    STATE(878), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312255] = 2,
    ACTIONS(4648), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312269] = 3,
    STATE(882), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312285] = 2,
    ACTIONS(4187), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312299] = 3,
    STATE(886), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312315] = 2,
    ACTIONS(4557), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312329] = 3,
    STATE(890), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312345] = 2,
    ACTIONS(4187), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312359] = 3,
    STATE(894), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312375] = 2,
    ACTIONS(4561), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312389] = 3,
    STATE(898), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312405] = 2,
    ACTIONS(4565), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312419] = 3,
    STATE(902), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312435] = 2,
    ACTIONS(4561), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312449] = 3,
    STATE(906), 1,
      sym_preproc_else,
    ACTIONS(17938), 3,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312465] = 2,
    ACTIONS(4575), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312479] = 2,
    ACTIONS(4175), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312493] = 2,
    ACTIONS(4608), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312507] = 2,
    ACTIONS(4183), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312521] = 2,
    ACTIONS(4806), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312535] = 2,
    ACTIONS(4327), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312549] = 2,
    ACTIONS(4331), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312563] = 4,
    ACTIONS(11695), 1,
      sym_view_keyword,
    ACTIONS(18295), 1,
      anon_sym_RBRACE,
    STATE(10052), 2,
      sym_view_definition,
      aux_sym_addfirst_views_modification_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312581] = 4,
    ACTIONS(18146), 1,
      sym_identifier,
    ACTIONS(18297), 1,
      anon_sym_RBRACE,
    STATE(10026), 2,
      sym_label_declaration,
      aux_sym_labels_section_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312599] = 3,
    STATE(11880), 1,
      sym_else_keyword,
    ACTIONS(17196), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312615] = 3,
    STATE(4562), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312630] = 3,
    STATE(3651), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312645] = 3,
    STATE(2871), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312660] = 3,
    STATE(2872), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312675] = 3,
    STATE(3314), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312690] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18299), 1,
      anon_sym_RPAREN,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312707] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18301), 1,
      anon_sym_RBRACK,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312724] = 3,
    STATE(3797), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312739] = 3,
    STATE(6772), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312754] = 3,
    STATE(6775), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312769] = 3,
    STATE(6776), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312784] = 3,
    STATE(6780), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312799] = 3,
    STATE(6781), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312814] = 3,
    STATE(7371), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312829] = 3,
    STATE(7373), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312844] = 3,
    STATE(7374), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312859] = 3,
    STATE(3654), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312874] = 3,
    STATE(7376), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312889] = 3,
    STATE(7377), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312904] = 3,
    STATE(3315), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312919] = 3,
    STATE(3316), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312934] = 4,
    ACTIONS(18303), 1,
      sym_identifier,
    ACTIONS(18305), 1,
      anon_sym_SEMI,
    STATE(10411), 1,
      sym_label_attribute,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312951] = 3,
    STATE(3317), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312966] = 3,
    STATE(6786), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312981] = 2,
    ACTIONS(18307), 3,
      aux_sym_interface_declaration_token2,
      sym_internal_keyword,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [312994] = 3,
    STATE(2879), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313009] = 3,
    STATE(2880), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313024] = 3,
    STATE(3318), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313039] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18309), 1,
      anon_sym_RBRACK,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313056] = 3,
    STATE(3320), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313071] = 3,
    STATE(2913), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313086] = 3,
    STATE(2914), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313101] = 3,
    STATE(3321), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313116] = 3,
    STATE(3859), 1,
      sym_code_block,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313131] = 4,
    ACTIONS(18311), 1,
      anon_sym_COMMA,
    ACTIONS(18314), 1,
      anon_sym_RPAREN,
    STATE(10390), 1,
      aux_sym_attribute_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313148] = 3,
    STATE(6431), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313163] = 3,
    STATE(6432), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313178] = 3,
    STATE(3323), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313193] = 3,
    STATE(6450), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313208] = 3,
    STATE(6452), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313223] = 3,
    STATE(6492), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313238] = 3,
    STATE(6497), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313253] = 3,
    STATE(6498), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313268] = 3,
    STATE(6689), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313283] = 3,
    STATE(6692), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313298] = 3,
    STATE(7305), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313313] = 3,
    STATE(7306), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313328] = 3,
    STATE(7325), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313343] = 3,
    STATE(7383), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313358] = 3,
    STATE(7330), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313373] = 4,
    ACTIONS(18316), 1,
      anon_sym_COMMA,
    ACTIONS(18318), 1,
      anon_sym_COLON,
    STATE(10996), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313390] = 3,
    STATE(7322), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313405] = 3,
    STATE(7384), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313420] = 3,
    STATE(7365), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313435] = 3,
    STATE(7266), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313450] = 4,
    ACTIONS(18320), 1,
      anon_sym_SEMI,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    STATE(10443), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313467] = 3,
    STATE(4555), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313482] = 3,
    STATE(6509), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313497] = 3,
    STATE(6577), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313512] = 3,
    STATE(6590), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313527] = 3,
    STATE(6596), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313542] = 3,
    STATE(6599), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313557] = 4,
    ACTIONS(15398), 1,
      anon_sym_LBRACE,
    ACTIONS(18324), 1,
      anon_sym_COMMA,
    STATE(10418), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313574] = 3,
    STATE(3324), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313589] = 3,
    STATE(2915), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313604] = 3,
    STATE(2924), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313619] = 3,
    STATE(2969), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313634] = 4,
    ACTIONS(15465), 1,
      anon_sym_LBRACE,
    ACTIONS(15467), 1,
      aux_sym_interface_declaration_token1,
    ACTIONS(15471), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313651] = 4,
    ACTIONS(15364), 1,
      anon_sym_LBRACE,
    ACTIONS(18327), 1,
      sym_implements_keyword,
    STATE(11337), 1,
      sym_implements_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313668] = 4,
    ACTIONS(15380), 1,
      anon_sym_LBRACE,
    ACTIONS(18327), 1,
      sym_implements_keyword,
    STATE(11344), 1,
      sym_implements_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313685] = 3,
    STATE(2970), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313700] = 3,
    STATE(4558), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313715] = 3,
    STATE(6735), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313730] = 3,
    STATE(4559), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313745] = 3,
    STATE(6737), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313760] = 3,
    STATE(6749), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313775] = 3,
    STATE(6750), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313790] = 4,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    ACTIONS(18329), 1,
      anon_sym_SEMI,
    STATE(10874), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313807] = 3,
    STATE(4563), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313822] = 3,
    STATE(6754), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313837] = 3,
    STATE(6755), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313852] = 3,
    STATE(6392), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313867] = 3,
    STATE(6506), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313882] = 3,
    STATE(7334), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313897] = 3,
    STATE(7366), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313912] = 3,
    STATE(7369), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313927] = 3,
    STATE(7370), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313942] = 4,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    ACTIONS(18331), 1,
      anon_sym_SEMI,
    STATE(11023), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313959] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18335), 1,
      anon_sym_RBRACK,
    STATE(10449), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313976] = 3,
    STATE(4112), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [313991] = 3,
    STATE(4113), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314006] = 3,
    STATE(4114), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314021] = 3,
    STATE(4115), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314036] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18337), 1,
      anon_sym_RBRACK,
    STATE(10999), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314053] = 3,
    STATE(6507), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314068] = 3,
    STATE(6508), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314083] = 3,
    STATE(6630), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314098] = 3,
    STATE(6655), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314113] = 3,
    STATE(6656), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314128] = 3,
    STATE(6680), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314143] = 3,
    STATE(6683), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314158] = 3,
    STATE(6729), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314173] = 4,
    ACTIONS(18339), 1,
      anon_sym_SEMI,
    ACTIONS(18342), 1,
      anon_sym_RPAREN,
    STATE(10458), 1,
      aux_sym_parameter_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314190] = 4,
    ACTIONS(18344), 1,
      anon_sym_SEMI,
    ACTIONS(18346), 1,
      anon_sym_RPAREN,
    STATE(10458), 1,
      aux_sym_parameter_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314207] = 3,
    STATE(6753), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314222] = 3,
    STATE(4119), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314237] = 3,
    STATE(4120), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314252] = 4,
    ACTIONS(15352), 1,
      anon_sym_LBRACE,
    ACTIONS(18348), 1,
      anon_sym_COMMA,
    STATE(10418), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314269] = 3,
    STATE(2979), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314284] = 3,
    STATE(4568), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314299] = 3,
    STATE(2980), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314314] = 3,
    STATE(6386), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314329] = 3,
    STATE(6387), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314344] = 3,
    STATE(6389), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314359] = 3,
    STATE(6391), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314374] = 3,
    STATE(4123), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314389] = 3,
    STATE(4570), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314404] = 3,
    STATE(4571), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314419] = 3,
    STATE(4124), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314434] = 3,
    STATE(4573), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314449] = 3,
    STATE(6436), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314464] = 3,
    STATE(4574), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314479] = 3,
    STATE(6438), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314494] = 3,
    STATE(6439), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314509] = 3,
    STATE(6440), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314524] = 3,
    STATE(3290), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314539] = 3,
    STATE(6444), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314554] = 3,
    STATE(6445), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314569] = 3,
    STATE(6448), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314584] = 3,
    STATE(6449), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314599] = 3,
    STATE(3818), 1,
      sym_code_block,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314614] = 3,
    STATE(3694), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314629] = 3,
    STATE(3700), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314644] = 3,
    STATE(3701), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314659] = 3,
    STATE(3702), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314674] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18350), 1,
      anon_sym_RBRACK,
    STATE(11112), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314691] = 3,
    STATE(6500), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314706] = 3,
    STATE(6501), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314721] = 3,
    STATE(6502), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314736] = 3,
    STATE(6503), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314751] = 3,
    STATE(4515), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314766] = 3,
    STATE(4516), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314781] = 4,
    ACTIONS(18303), 1,
      sym_identifier,
    ACTIONS(18352), 1,
      anon_sym_SEMI,
    STATE(10803), 1,
      sym_label_attribute,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314798] = 4,
    ACTIONS(2207), 1,
      aux_sym_where_clause_token1,
    ACTIONS(18354), 1,
      anon_sym_SEMI,
    STATE(11266), 1,
      sym_where_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314815] = 3,
    STATE(3665), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314830] = 3,
    STATE(3985), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314845] = 3,
    STATE(11236), 1,
      sym_boolean,
    ACTIONS(17920), 2,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314860] = 3,
    STATE(3986), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314875] = 3,
    STATE(3757), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314890] = 3,
    STATE(3758), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314905] = 3,
    STATE(3670), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314920] = 3,
    STATE(4518), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314935] = 3,
    STATE(4520), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314950] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18356), 1,
      anon_sym_RBRACK,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314967] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18358), 1,
      anon_sym_RBRACK,
    STATE(10516), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314984] = 3,
    STATE(5106), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [314999] = 3,
    STATE(3671), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315014] = 3,
    STATE(3674), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315029] = 3,
    STATE(5112), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315044] = 3,
    STATE(3675), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315059] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18360), 1,
      anon_sym_RBRACK,
    STATE(10999), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315076] = 3,
    STATE(3298), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315091] = 3,
    STATE(3300), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315106] = 3,
    STATE(3301), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315121] = 3,
    STATE(3989), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315136] = 4,
    ACTIONS(18362), 1,
      anon_sym_LBRACE,
    ACTIONS(18364), 1,
      aux_sym_interface_declaration_token1,
    ACTIONS(18366), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315153] = 4,
    ACTIONS(2207), 1,
      aux_sym_where_clause_token1,
    ACTIONS(18368), 1,
      anon_sym_RPAREN,
    STATE(12508), 1,
      sym_where_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315170] = 3,
    STATE(3990), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315185] = 3,
    STATE(3759), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315200] = 3,
    STATE(3774), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315215] = 3,
    STATE(3303), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315230] = 3,
    STATE(3623), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315245] = 3,
    STATE(3780), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315260] = 3,
    STATE(4072), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315275] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18370), 1,
      anon_sym_RPAREN,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315292] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18372), 1,
      anon_sym_RBRACK,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315309] = 3,
    STATE(4073), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315324] = 4,
    ACTIONS(18374), 1,
      anon_sym_COMMA,
    ACTIONS(18376), 1,
      anon_sym_RPAREN,
    STATE(10390), 1,
      aux_sym_attribute_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315341] = 3,
    STATE(5134), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315356] = 3,
    STATE(5138), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315371] = 3,
    STATE(5139), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315386] = 3,
    STATE(5143), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315401] = 3,
    STATE(5144), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315416] = 3,
    STATE(5167), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315431] = 3,
    STATE(5169), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315446] = 3,
    STATE(5170), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315461] = 3,
    STATE(5172), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315476] = 3,
    STATE(5173), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315491] = 3,
    STATE(3304), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315506] = 4,
    ACTIONS(18303), 1,
      sym_identifier,
    ACTIONS(18378), 1,
      anon_sym_SEMI,
    STATE(10586), 1,
      sym_label_attribute,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315523] = 3,
    STATE(4076), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315538] = 4,
    ACTIONS(18327), 1,
      sym_implements_keyword,
    ACTIONS(18380), 1,
      anon_sym_LBRACE,
    STATE(11340), 1,
      sym_implements_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315555] = 3,
    STATE(5197), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315570] = 3,
    STATE(4077), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315585] = 3,
    STATE(3624), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315600] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18382), 1,
      anon_sym_RBRACK,
    STATE(10555), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315617] = 3,
    STATE(3625), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315632] = 3,
    STATE(4078), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315647] = 4,
    ACTIONS(18384), 1,
      anon_sym_SEMI,
    ACTIONS(18386), 1,
      anon_sym_DOT,
    STATE(10554), 1,
      aux_sym_namespace_name_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315664] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18389), 1,
      anon_sym_RBRACK,
    STATE(10999), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315681] = 3,
    STATE(4081), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315696] = 3,
    STATE(4082), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315711] = 3,
    STATE(4333), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315726] = 3,
    STATE(3631), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315741] = 3,
    STATE(3655), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315756] = 3,
    STATE(4085), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315771] = 3,
    STATE(4086), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315786] = 3,
    STATE(3553), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315801] = 3,
    ACTIONS(18391), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315816] = 3,
    STATE(5216), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315831] = 3,
    STATE(5229), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315846] = 3,
    STATE(3556), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315861] = 3,
    STATE(5241), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315876] = 3,
    STATE(5242), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315891] = 3,
    STATE(5243), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315906] = 3,
    STATE(5376), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315921] = 3,
    STATE(5377), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315936] = 3,
    STATE(5381), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315951] = 3,
    STATE(5382), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315966] = 3,
    STATE(5383), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315981] = 3,
    STATE(5094), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [315996] = 2,
    ACTIONS(18393), 3,
      sym_dotnet_assembly_name,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316009] = 3,
    STATE(5095), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316024] = 3,
    STATE(5096), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316039] = 3,
    STATE(5097), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316054] = 4,
    ACTIONS(18395), 1,
      anon_sym_COMMA,
    ACTIONS(18397), 1,
      anon_sym_RPAREN,
    STATE(10758), 1,
      aux_sym_sorting_value_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316071] = 3,
    STATE(5099), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316086] = 3,
    STATE(5100), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316101] = 3,
    STATE(5102), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316116] = 3,
    STATE(5103), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316131] = 4,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    ACTIONS(18399), 1,
      anon_sym_SEMI,
    STATE(10755), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316148] = 3,
    STATE(3557), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316163] = 3,
    STATE(7500), 1,
      sym_code_block,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316178] = 3,
    STATE(7502), 1,
      sym_code_block,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316193] = 4,
    ACTIONS(18395), 1,
      anon_sym_COMMA,
    ACTIONS(18401), 1,
      anon_sym_RPAREN,
    STATE(10762), 1,
      aux_sym_sorting_value_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316210] = 4,
    ACTIONS(18344), 1,
      anon_sym_SEMI,
    ACTIONS(18403), 1,
      anon_sym_RPAREN,
    STATE(10458), 1,
      aux_sym_parameter_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316227] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18405), 1,
      anon_sym_RBRACK,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316244] = 4,
    ACTIONS(18344), 1,
      anon_sym_SEMI,
    ACTIONS(18403), 1,
      anon_sym_RPAREN,
    STATE(10459), 1,
      aux_sym_parameter_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316261] = 3,
    STATE(3560), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316276] = 3,
    STATE(3561), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316291] = 3,
    STATE(5466), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316306] = 3,
    STATE(4001), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316321] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18407), 1,
      anon_sym_RBRACK,
    STATE(10601), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316338] = 3,
    ACTIONS(18409), 1,
      anon_sym_LBRACE,
    ACTIONS(2268), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316353] = 3,
    STATE(6991), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316368] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18411), 1,
      anon_sym_RBRACK,
    STATE(10999), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316385] = 3,
    STATE(4037), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316400] = 3,
    STATE(7503), 1,
      sym_code_block,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316415] = 3,
    STATE(7505), 1,
      sym_code_block,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316430] = 3,
    STATE(4344), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316445] = 3,
    STATE(7527), 1,
      sym_code_block,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316460] = 3,
    STATE(7536), 1,
      sym_code_block,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316475] = 3,
    STATE(4038), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316490] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18413), 1,
      anon_sym_RPAREN,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316507] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18415), 1,
      anon_sym_RBRACK,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316524] = 3,
    STATE(5564), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316539] = 3,
    STATE(5569), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316554] = 3,
    STATE(5570), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316569] = 3,
    STATE(5579), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316584] = 3,
    STATE(5581), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316599] = 3,
    STATE(6936), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316614] = 3,
    STATE(6952), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316629] = 3,
    STATE(6953), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316644] = 3,
    STATE(4002), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316659] = 3,
    STATE(6989), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316674] = 3,
    STATE(6990), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316689] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18417), 1,
      anon_sym_RBRACK,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316706] = 4,
    ACTIONS(2207), 1,
      aux_sym_where_clause_token1,
    ACTIONS(18419), 1,
      anon_sym_SEMI,
    STATE(11270), 1,
      sym_where_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316723] = 4,
    ACTIONS(18303), 1,
      sym_identifier,
    ACTIONS(18421), 1,
      anon_sym_SEMI,
    STATE(10666), 1,
      sym_label_attribute,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316740] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18423), 1,
      anon_sym_RBRACK,
    STATE(10627), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316757] = 3,
    STATE(5624), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316772] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18425), 1,
      anon_sym_RBRACK,
    STATE(10999), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316789] = 4,
    ACTIONS(18327), 1,
      sym_implements_keyword,
    ACTIONS(18427), 1,
      anon_sym_LBRACE,
    STATE(12019), 1,
      sym_implements_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316806] = 3,
    STATE(7532), 1,
      sym_code_block,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316821] = 3,
    STATE(7534), 1,
      sym_code_block,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316836] = 3,
    STATE(5120), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316851] = 3,
    STATE(5123), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316866] = 3,
    STATE(5124), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316881] = 4,
    ACTIONS(18429), 1,
      aux_sym_ml_value_list_token1,
    ACTIONS(18431), 1,
      aux_sym_label_declaration_token1,
    ACTIONS(18433), 1,
      aux_sym_label_declaration_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316898] = 4,
    ACTIONS(18435), 1,
      anon_sym_SEMI,
    ACTIONS(18437), 1,
      anon_sym_COMMA,
    STATE(10935), 1,
      aux_sym_label_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316915] = 3,
    STATE(7540), 1,
      sym_code_block,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316930] = 3,
    STATE(7545), 1,
      sym_code_block,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316945] = 3,
    STATE(5127), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316960] = 3,
    STATE(5128), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316975] = 4,
    ACTIONS(18303), 1,
      sym_identifier,
    ACTIONS(18439), 1,
      anon_sym_SEMI,
    STATE(10433), 1,
      sym_label_attribute,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [316992] = 3,
    STATE(5674), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317007] = 3,
    STATE(5678), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317022] = 3,
    STATE(3848), 1,
      sym_code_block,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317037] = 3,
    STATE(5749), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317052] = 3,
    STATE(5750), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317067] = 3,
    STATE(5752), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317082] = 3,
    STATE(5768), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317097] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18441), 1,
      anon_sym_RBRACK,
    STATE(10649), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317114] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18443), 1,
      anon_sym_RBRACK,
    STATE(10999), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317131] = 3,
    STATE(5799), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317146] = 3,
    STATE(4589), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317161] = 3,
    STATE(5845), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317176] = 3,
    STATE(5849), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317191] = 3,
    STATE(6913), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317206] = 3,
    STATE(6914), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317221] = 3,
    STATE(6915), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317236] = 3,
    STATE(6916), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317251] = 3,
    STATE(6917), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317266] = 3,
    STATE(3809), 1,
      sym_code_block,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317281] = 3,
    STATE(6921), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317296] = 3,
    STATE(6922), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317311] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18445), 1,
      anon_sym_RBRACK,
    STATE(10663), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317328] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18447), 1,
      anon_sym_RBRACK,
    STATE(10999), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317345] = 3,
    STATE(6924), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317360] = 3,
    STATE(6925), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317375] = 4,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    ACTIONS(18449), 1,
      anon_sym_SEMI,
    STATE(10703), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317392] = 3,
    STATE(5860), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317407] = 3,
    STATE(3512), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317422] = 3,
    STATE(5822), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317437] = 3,
    STATE(5588), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317452] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18451), 1,
      anon_sym_RBRACK,
    STATE(10673), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317469] = 3,
    STATE(3513), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317484] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18453), 1,
      anon_sym_RBRACK,
    STATE(10999), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317501] = 3,
    STATE(5656), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317516] = 3,
    STATE(5657), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317531] = 3,
    STATE(4039), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317546] = 3,
    STATE(4595), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317561] = 3,
    STATE(7550), 1,
      sym_code_block,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317576] = 3,
    STATE(7553), 1,
      sym_code_block,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317591] = 3,
    STATE(4040), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317606] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18455), 1,
      anon_sym_RBRACK,
    STATE(10682), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317623] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18457), 1,
      anon_sym_RBRACK,
    STATE(10999), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317640] = 3,
    STATE(4596), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317655] = 3,
    STATE(7490), 1,
      sym_code_block,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317670] = 3,
    STATE(7523), 1,
      sym_code_block,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317685] = 3,
    STATE(5797), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317700] = 3,
    STATE(5798), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317715] = 3,
    STATE(5824), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317730] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18459), 1,
      anon_sym_RBRACK,
    STATE(10690), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317747] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18461), 1,
      anon_sym_RBRACK,
    STATE(10999), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317764] = 3,
    STATE(5706), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317779] = 3,
    STATE(5458), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317794] = 3,
    STATE(5687), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317809] = 3,
    STATE(3616), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317824] = 3,
    STATE(5451), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317839] = 3,
    STATE(5462), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317854] = 3,
    STATE(6940), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317869] = 3,
    STATE(6943), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317884] = 3,
    STATE(6945), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317899] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18463), 1,
      anon_sym_RBRACK,
    STATE(10702), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317916] = 3,
    STATE(6946), 1,
      sym_code_block,
    ACTIONS(13875), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317931] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18465), 1,
      anon_sym_RBRACK,
    STATE(10999), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317948] = 4,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    ACTIONS(18467), 1,
      anon_sym_SEMI,
    STATE(11023), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317965] = 3,
    STATE(3632), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317980] = 3,
    STATE(5755), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [317995] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18469), 1,
      anon_sym_RBRACK,
    STATE(10708), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318012] = 3,
    STATE(5758), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318027] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18471), 1,
      anon_sym_RBRACK,
    STATE(10999), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318044] = 4,
    ACTIONS(18374), 1,
      anon_sym_COMMA,
    ACTIONS(18473), 1,
      anon_sym_RPAREN,
    STATE(10533), 1,
      aux_sym_attribute_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318061] = 3,
    STATE(5782), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318076] = 3,
    STATE(5784), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318091] = 3,
    STATE(5785), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318106] = 3,
    STATE(5464), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318121] = 3,
    STATE(5465), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318136] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18475), 1,
      anon_sym_RBRACK,
    STATE(10716), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318153] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18477), 1,
      anon_sym_RBRACK,
    STATE(10999), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318170] = 3,
    STATE(5520), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318185] = 3,
    STATE(5531), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318200] = 3,
    STATE(4223), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318215] = 3,
    STATE(5149), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318230] = 3,
    STATE(7526), 1,
      sym_code_block,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318245] = 3,
    STATE(7530), 1,
      sym_code_block,
    ACTIONS(15097), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318260] = 2,
    ACTIONS(15509), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      aux_sym_if_table_relation_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318273] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18479), 1,
      anon_sym_RBRACK,
    STATE(10725), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318290] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18481), 1,
      anon_sym_RBRACK,
    STATE(10999), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318307] = 3,
    STATE(5535), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318322] = 3,
    STATE(5536), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318337] = 3,
    STATE(5537), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318352] = 3,
    STATE(5539), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318367] = 3,
    STATE(5541), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318382] = 3,
    STATE(5542), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318397] = 4,
    ACTIONS(18344), 1,
      anon_sym_SEMI,
    ACTIONS(18483), 1,
      anon_sym_RPAREN,
    STATE(10591), 1,
      aux_sym_parameter_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318414] = 3,
    STATE(5543), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318429] = 3,
    STATE(5544), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318444] = 3,
    STATE(5150), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318459] = 3,
    STATE(5548), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318474] = 3,
    STATE(5550), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318489] = 3,
    STATE(5151), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318504] = 3,
    STATE(5557), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318519] = 3,
    STATE(5560), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318534] = 3,
    STATE(5152), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318549] = 3,
    STATE(5155), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318564] = 3,
    STATE(5584), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318579] = 3,
    STATE(5585), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318594] = 3,
    STATE(5586), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318609] = 3,
    STATE(5587), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318624] = 3,
    STATE(5156), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318639] = 3,
    STATE(5160), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318654] = 3,
    STATE(5161), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318669] = 3,
    STATE(5162), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318684] = 3,
    STATE(4603), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318699] = 3,
    STATE(5163), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318714] = 3,
    STATE(5164), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318729] = 3,
    STATE(5165), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318744] = 4,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    ACTIONS(18485), 1,
      anon_sym_SEMI,
    STATE(11023), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318761] = 3,
    STATE(3816), 1,
      sym_code_block,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318776] = 4,
    ACTIONS(2207), 1,
      aux_sym_where_clause_token1,
    ACTIONS(18487), 1,
      anon_sym_RPAREN,
    STATE(11641), 1,
      sym_where_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318793] = 4,
    ACTIONS(18395), 1,
      anon_sym_COMMA,
    ACTIONS(18489), 1,
      anon_sym_RPAREN,
    STATE(10983), 1,
      aux_sym_sorting_value_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318810] = 3,
    STATE(3819), 1,
      sym_code_block,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318825] = 3,
    STATE(4224), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318840] = 2,
    ACTIONS(18491), 3,
      aux_sym_interface_declaration_token2,
      sym_internal_keyword,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318853] = 4,
    ACTIONS(18395), 1,
      anon_sym_COMMA,
    ACTIONS(18493), 1,
      anon_sym_RPAREN,
    STATE(10983), 1,
      aux_sym_sorting_value_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318870] = 4,
    ACTIONS(18316), 1,
      anon_sym_COMMA,
    ACTIONS(18495), 1,
      anon_sym_COLON,
    STATE(10765), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318887] = 3,
    STATE(4604), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318902] = 4,
    ACTIONS(18316), 1,
      anon_sym_COMMA,
    ACTIONS(18497), 1,
      anon_sym_COLON,
    STATE(10971), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318919] = 2,
    ACTIONS(18499), 3,
      aux_sym_interface_declaration_token2,
      sym_internal_keyword,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318932] = 3,
    STATE(4091), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318947] = 3,
    STATE(4092), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318962] = 4,
    ACTIONS(18501), 1,
      anon_sym_SEMI,
    ACTIONS(18503), 1,
      anon_sym_DOT,
    STATE(10785), 1,
      aux_sym_namespace_name_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318979] = 3,
    STATE(3703), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [318994] = 3,
    STATE(5178), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319009] = 3,
    STATE(5179), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319024] = 3,
    STATE(5182), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319039] = 3,
    STATE(5183), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319054] = 3,
    STATE(5184), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319069] = 3,
    STATE(5187), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319084] = 3,
    STATE(5188), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319099] = 3,
    STATE(5191), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319114] = 3,
    STATE(2836), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319129] = 3,
    STATE(3580), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319144] = 3,
    STATE(3581), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319159] = 3,
    STATE(3582), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319174] = 3,
    STATE(3583), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319189] = 4,
    ACTIONS(15409), 1,
      anon_sym_LBRACE,
    ACTIONS(18348), 1,
      anon_sym_COMMA,
    STATE(10463), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319206] = 4,
    ACTIONS(18503), 1,
      anon_sym_DOT,
    ACTIONS(18505), 1,
      anon_sym_SEMI,
    STATE(10554), 1,
      aux_sym_namespace_name_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319223] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18507), 1,
      anon_sym_RBRACK,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319240] = 3,
    STATE(3573), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319255] = 3,
    STATE(3576), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319270] = 3,
    STATE(3586), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319285] = 4,
    ACTIONS(18316), 1,
      anon_sym_COMMA,
    ACTIONS(18509), 1,
      anon_sym_COLON,
    STATE(10791), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319302] = 4,
    ACTIONS(18316), 1,
      anon_sym_COMMA,
    ACTIONS(18511), 1,
      anon_sym_COLON,
    STATE(10971), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319319] = 3,
    STATE(5200), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319334] = 3,
    STATE(5201), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319349] = 3,
    STATE(7088), 1,
      sym_code_block,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319364] = 3,
    STATE(7034), 1,
      sym_code_block,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319379] = 3,
    STATE(5202), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319394] = 3,
    STATE(5203), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319409] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18513), 1,
      anon_sym_RBRACK,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319426] = 4,
    ACTIONS(18515), 1,
      anon_sym_SEMI,
    ACTIONS(18517), 1,
      anon_sym_COMMA,
    STATE(10873), 1,
      aux_sym_caption_value_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319443] = 4,
    ACTIONS(18316), 1,
      anon_sym_COMMA,
    ACTIONS(18519), 1,
      anon_sym_COLON,
    STATE(10801), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319460] = 4,
    ACTIONS(18316), 1,
      anon_sym_COMMA,
    ACTIONS(18521), 1,
      anon_sym_COLON,
    STATE(10971), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319477] = 3,
    STATE(6453), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319492] = 4,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    ACTIONS(18523), 1,
      anon_sym_SEMI,
    STATE(11021), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319509] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18525), 1,
      anon_sym_RPAREN,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319526] = 3,
    STATE(3587), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319541] = 3,
    STATE(7041), 1,
      sym_code_block,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319556] = 3,
    STATE(7044), 1,
      sym_code_block,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319571] = 2,
    ACTIONS(18527), 3,
      sym_identifier,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319584] = 3,
    STATE(7049), 1,
      sym_code_block,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319599] = 3,
    STATE(7053), 1,
      sym_code_block,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319614] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18529), 1,
      anon_sym_RPAREN,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319631] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18531), 1,
      anon_sym_RBRACK,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319648] = 3,
    STATE(12221), 1,
      sym_boolean,
    ACTIONS(17920), 2,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319663] = 3,
    STATE(6461), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319678] = 3,
    STATE(6463), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319693] = 3,
    STATE(6464), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319708] = 3,
    STATE(6466), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319723] = 3,
    STATE(6467), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319738] = 3,
    STATE(5217), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319753] = 4,
    ACTIONS(18316), 1,
      anon_sym_COMMA,
    ACTIONS(18533), 1,
      anon_sym_COLON,
    STATE(10821), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319770] = 4,
    ACTIONS(18316), 1,
      anon_sym_COMMA,
    ACTIONS(18535), 1,
      anon_sym_COLON,
    STATE(10971), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319787] = 3,
    STATE(5218), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319802] = 3,
    STATE(5219), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319817] = 4,
    ACTIONS(18303), 1,
      sym_identifier,
    ACTIONS(18537), 1,
      anon_sym_SEMI,
    STATE(10851), 1,
      sym_label_attribute,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319834] = 3,
    STATE(5220), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319849] = 3,
    STATE(7073), 1,
      sym_code_block,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319864] = 3,
    STATE(7091), 1,
      sym_code_block,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319879] = 3,
    STATE(3866), 1,
      sym_code_block,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319894] = 3,
    STATE(5223), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319909] = 3,
    STATE(5224), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319924] = 3,
    STATE(3590), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319939] = 4,
    ACTIONS(18316), 1,
      anon_sym_COMMA,
    ACTIONS(18539), 1,
      anon_sym_COLON,
    STATE(10833), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319956] = 4,
    ACTIONS(18316), 1,
      anon_sym_COMMA,
    ACTIONS(18541), 1,
      anon_sym_COLON,
    STATE(10971), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319973] = 3,
    STATE(7048), 1,
      sym_code_block,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [319988] = 3,
    STATE(7055), 1,
      sym_code_block,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320003] = 3,
    STATE(6471), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320018] = 3,
    STATE(6472), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320033] = 3,
    STATE(6473), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320048] = 3,
    STATE(6474), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320063] = 3,
    STATE(6475), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320078] = 3,
    STATE(5227), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320093] = 3,
    STATE(6477), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320108] = 4,
    ACTIONS(18316), 1,
      anon_sym_COMMA,
    ACTIONS(18543), 1,
      anon_sym_COLON,
    STATE(10844), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320125] = 4,
    ACTIONS(18316), 1,
      anon_sym_COMMA,
    ACTIONS(18545), 1,
      anon_sym_COLON,
    STATE(10971), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320142] = 3,
    STATE(6478), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320157] = 3,
    STATE(5228), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320172] = 4,
    ACTIONS(18316), 1,
      anon_sym_COMMA,
    ACTIONS(18547), 1,
      anon_sym_COLON,
    STATE(10848), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320189] = 4,
    ACTIONS(18316), 1,
      anon_sym_COMMA,
    ACTIONS(18549), 1,
      anon_sym_COLON,
    STATE(10971), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320206] = 3,
    STATE(6480), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320221] = 3,
    STATE(6481), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320236] = 4,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    ACTIONS(18551), 1,
      anon_sym_SEMI,
    STATE(10862), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320253] = 3,
    STATE(7093), 1,
      sym_code_block,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320268] = 3,
    STATE(7094), 1,
      sym_code_block,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320283] = 3,
    STATE(3591), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320298] = 3,
    STATE(7056), 1,
      sym_code_block,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320313] = 3,
    STATE(7036), 1,
      sym_code_block,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320328] = 3,
    STATE(6485), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320343] = 3,
    STATE(6486), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320358] = 3,
    STATE(6487), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320373] = 2,
    ACTIONS(18553), 3,
      sym_dotnet_assembly_name,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320386] = 3,
    STATE(6488), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320401] = 4,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    ACTIONS(18555), 1,
      anon_sym_SEMI,
    STATE(11023), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320418] = 3,
    STATE(7038), 1,
      sym_code_block,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320433] = 3,
    STATE(7039), 1,
      sym_code_block,
    ACTIONS(15121), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320448] = 3,
    STATE(3326), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320463] = 3,
    STATE(3327), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320478] = 3,
    STATE(3328), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320493] = 3,
    STATE(3329), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320508] = 3,
    STATE(5246), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320523] = 3,
    STATE(5247), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320538] = 3,
    STATE(5248), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320553] = 3,
    STATE(5249), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320568] = 4,
    ACTIONS(18557), 1,
      anon_sym_SEMI,
    ACTIONS(18559), 1,
      anon_sym_COMMA,
    STATE(10873), 1,
      aux_sym_caption_value_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320585] = 4,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    ACTIONS(18562), 1,
      anon_sym_SEMI,
    STATE(11023), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320602] = 3,
    STATE(3807), 1,
      sym_code_block,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320617] = 3,
    STATE(3838), 1,
      sym_code_block,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320632] = 2,
    ACTIONS(18564), 3,
      sym_dotnet_assembly_name,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320645] = 3,
    STATE(4097), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320660] = 3,
    STATE(4098), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320675] = 4,
    ACTIONS(18566), 1,
      anon_sym_DASH,
    ACTIONS(18568), 1,
      sym_integer,
    STATE(11198), 1,
      sym__signed_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320692] = 3,
    STATE(6399), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320707] = 3,
    STATE(6400), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320722] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18570), 1,
      anon_sym_RBRACK,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320739] = 3,
    STATE(4101), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320754] = 4,
    ACTIONS(18572), 1,
      anon_sym_SEMI,
    ACTIONS(18574), 1,
      anon_sym_COMMA,
    STATE(10959), 1,
      aux_sym_signed_integer_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320771] = 3,
    STATE(3843), 1,
      sym_code_block,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320786] = 3,
    STATE(4044), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320801] = 3,
    STATE(5496), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320816] = 4,
    ACTIONS(18576), 1,
      anon_sym_SEMI,
    ACTIONS(18578), 1,
      anon_sym_COMMA,
    STATE(10981), 1,
      aux_sym_ml_value_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320833] = 3,
    STATE(4102), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320848] = 3,
    STATE(6404), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320863] = 3,
    STATE(6405), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320878] = 3,
    STATE(6407), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320893] = 3,
    STATE(6408), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320908] = 2,
    ACTIONS(18580), 3,
      sym_dotnet_assembly_name,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320921] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18582), 1,
      anon_sym_RPAREN,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320938] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18584), 1,
      anon_sym_RBRACK,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320955] = 4,
    ACTIONS(18586), 1,
      anon_sym_LPAREN,
    ACTIONS(18588), 1,
      anon_sym_RBRACK,
    STATE(11257), 1,
      sym_attribute_arguments,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320972] = 3,
    STATE(5510), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [320987] = 3,
    STATE(3801), 1,
      sym_code_block,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321002] = 3,
    STATE(5514), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321017] = 3,
    STATE(5515), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321032] = 3,
    STATE(5517), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321047] = 3,
    STATE(5521), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321062] = 3,
    STATE(3817), 1,
      sym_code_block,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321077] = 4,
    ACTIONS(18590), 1,
      anon_sym_SEMI,
    ACTIONS(18592), 1,
      anon_sym_COMMA,
    STATE(10889), 1,
      aux_sym_ml_value_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321094] = 4,
    ACTIONS(18303), 1,
      sym_identifier,
    ACTIONS(18594), 1,
      anon_sym_SEMI,
    STATE(10922), 1,
      sym_label_attribute,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321111] = 3,
    STATE(6412), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321126] = 3,
    STATE(6413), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321141] = 3,
    STATE(6415), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321156] = 3,
    STATE(6416), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321171] = 3,
    STATE(5526), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321186] = 3,
    STATE(5527), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321201] = 3,
    STATE(5528), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321216] = 3,
    STATE(5529), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321231] = 3,
    STATE(5530), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321246] = 3,
    STATE(3833), 1,
      sym_code_block,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321261] = 3,
    STATE(5538), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321276] = 3,
    STATE(5545), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321291] = 3,
    STATE(5551), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321306] = 3,
    STATE(5554), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321321] = 4,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    ACTIONS(18596), 1,
      anon_sym_SEMI,
    STATE(10931), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321338] = 3,
    STATE(6419), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321353] = 3,
    STATE(6421), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321368] = 3,
    STATE(6423), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321383] = 3,
    STATE(6424), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321398] = 3,
    STATE(5556), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321413] = 3,
    STATE(5558), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321428] = 3,
    STATE(5561), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321443] = 3,
    STATE(5562), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321458] = 4,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    ACTIONS(18598), 1,
      anon_sym_SEMI,
    STATE(11023), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321475] = 3,
    STATE(6426), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321490] = 3,
    STATE(6427), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321505] = 3,
    STATE(3836), 1,
      sym_code_block,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321520] = 4,
    ACTIONS(18600), 1,
      anon_sym_SEMI,
    ACTIONS(18602), 1,
      anon_sym_COMMA,
    STATE(10935), 1,
      aux_sym_label_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321537] = 3,
    STATE(3597), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321552] = 3,
    STATE(3598), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321567] = 3,
    STATE(3601), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321582] = 3,
    STATE(3602), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321597] = 3,
    STATE(3603), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321612] = 3,
    STATE(3606), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321627] = 3,
    STATE(3607), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321642] = 2,
    ACTIONS(18605), 3,
      sym_dotnet_assembly_name,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321655] = 3,
    STATE(3610), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321670] = 3,
    STATE(3611), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321685] = 3,
    STATE(4045), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321700] = 4,
    ACTIONS(18395), 1,
      anon_sym_COMMA,
    ACTIONS(18607), 1,
      anon_sym_RPAREN,
    STATE(11024), 1,
      aux_sym_sorting_value_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321717] = 3,
    STATE(11240), 1,
      sym_order_by_item,
    ACTIONS(2219), 2,
      aux_sym_order_by_item_token1,
      aux_sym_order_by_item_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321732] = 4,
    ACTIONS(18609), 1,
      anon_sym_SEMI,
    ACTIONS(18611), 1,
      anon_sym_COMMA,
    STATE(10950), 1,
      aux_sym_order_by_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321749] = 4,
    ACTIONS(18611), 1,
      anon_sym_COMMA,
    ACTIONS(18613), 1,
      anon_sym_SEMI,
    STATE(10988), 1,
      aux_sym_order_by_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321766] = 3,
    STATE(4197), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321781] = 3,
    STATE(4198), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321796] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18615), 1,
      anon_sym_RBRACK,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321813] = 3,
    STATE(3810), 1,
      sym_code_block,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321828] = 3,
    STATE(3811), 1,
      sym_code_block,
    ACTIONS(14953), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321843] = 3,
    STATE(7600), 1,
      sym_code_block,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321858] = 3,
    STATE(7602), 1,
      sym_code_block,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321873] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18617), 1,
      anon_sym_RBRACK,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321890] = 4,
    ACTIONS(18619), 1,
      anon_sym_SEMI,
    ACTIONS(18621), 1,
      anon_sym_COMMA,
    STATE(10959), 1,
      aux_sym_signed_integer_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321907] = 2,
    ACTIONS(18183), 3,
      anon_sym_DOT,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321920] = 3,
    STATE(4048), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321935] = 3,
    STATE(4049), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321950] = 2,
    ACTIONS(18624), 3,
      sym_dotnet_assembly_name,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321963] = 3,
    STATE(4200), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321978] = 3,
    STATE(7616), 1,
      sym_code_block,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [321993] = 3,
    STATE(7617), 1,
      sym_code_block,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322008] = 3,
    STATE(7628), 1,
      sym_code_block,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322023] = 3,
    STATE(7565), 1,
      sym_code_block,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322038] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18626), 1,
      anon_sym_RPAREN,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322055] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18628), 1,
      anon_sym_RBRACK,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322072] = 4,
    ACTIONS(18630), 1,
      anon_sym_COMMA,
    ACTIONS(18633), 1,
      anon_sym_COLON,
    STATE(10971), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322089] = 4,
    ACTIONS(18303), 1,
      sym_identifier,
    ACTIONS(18635), 1,
      anon_sym_SEMI,
    STATE(10978), 1,
      sym_label_attribute,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322106] = 3,
    STATE(7559), 1,
      sym_code_block,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322121] = 3,
    STATE(7572), 1,
      sym_code_block,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322136] = 3,
    STATE(7589), 1,
      sym_code_block,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322151] = 3,
    STATE(7558), 1,
      sym_code_block,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322166] = 2,
    ACTIONS(18637), 3,
      sym_dotnet_assembly_name,
      sym_quoted_identifier,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322179] = 4,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    ACTIONS(18639), 1,
      anon_sym_SEMI,
    STATE(10985), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322196] = 3,
    STATE(7584), 1,
      sym_code_block,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322211] = 3,
    STATE(7587), 1,
      sym_code_block,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322226] = 4,
    ACTIONS(18641), 1,
      anon_sym_SEMI,
    ACTIONS(18643), 1,
      anon_sym_COMMA,
    STATE(10981), 1,
      aux_sym_ml_value_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322243] = 3,
    STATE(7608), 1,
      sym_code_block,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322258] = 4,
    ACTIONS(18646), 1,
      anon_sym_COMMA,
    ACTIONS(18649), 1,
      anon_sym_RPAREN,
    STATE(10983), 1,
      aux_sym_sorting_value_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322275] = 3,
    STATE(7611), 1,
      sym_code_block,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322290] = 4,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    ACTIONS(18651), 1,
      anon_sym_SEMI,
    STATE(11023), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322307] = 3,
    STATE(7599), 1,
      sym_code_block,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322322] = 3,
    STATE(7615), 1,
      sym_code_block,
    ACTIONS(15157), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322337] = 4,
    ACTIONS(18653), 1,
      anon_sym_SEMI,
    ACTIONS(18655), 1,
      anon_sym_COMMA,
    STATE(10988), 1,
      aux_sym_order_by_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322354] = 3,
    STATE(4050), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322369] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18658), 1,
      anon_sym_RPAREN,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322386] = 3,
    STATE(4051), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322401] = 3,
    STATE(4027), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322416] = 3,
    STATE(4028), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322431] = 3,
    STATE(4052), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322446] = 3,
    STATE(4053), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322461] = 4,
    ACTIONS(18316), 1,
      anon_sym_COMMA,
    ACTIONS(18660), 1,
      anon_sym_COLON,
    STATE(10971), 1,
      aux_sym_variable_declaration_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322478] = 3,
    STATE(11757), 1,
      sym_boolean,
    ACTIONS(17920), 2,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322493] = 3,
    STATE(4201), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322508] = 4,
    ACTIONS(18662), 1,
      anon_sym_COMMA,
    ACTIONS(18665), 1,
      anon_sym_RBRACK,
    STATE(10999), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322525] = 3,
    STATE(3546), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322540] = 3,
    STATE(5027), 1,
      sym_code_block,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322555] = 3,
    STATE(5028), 1,
      sym_code_block,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322570] = 3,
    STATE(3638), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322585] = 3,
    STATE(5034), 1,
      sym_code_block,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322600] = 3,
    STATE(5092), 1,
      sym_code_block,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322615] = 3,
    STATE(5037), 1,
      sym_code_block,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322630] = 3,
    STATE(5039), 1,
      sym_code_block,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322645] = 3,
    STATE(3639), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322660] = 3,
    STATE(3640), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322675] = 3,
    STATE(5051), 1,
      sym_code_block,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322690] = 3,
    STATE(5052), 1,
      sym_code_block,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322705] = 3,
    STATE(3641), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322720] = 3,
    STATE(5054), 1,
      sym_code_block,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322735] = 3,
    STATE(5055), 1,
      sym_code_block,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322750] = 3,
    STATE(5057), 1,
      sym_code_block,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322765] = 3,
    STATE(5063), 1,
      sym_code_block,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322780] = 3,
    STATE(5065), 1,
      sym_code_block,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322795] = 3,
    STATE(5066), 1,
      sym_code_block,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322810] = 3,
    STATE(5068), 1,
      sym_code_block,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322825] = 3,
    STATE(5069), 1,
      sym_code_block,
    ACTIONS(15175), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322840] = 4,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    ACTIONS(18667), 1,
      anon_sym_SEMI,
    STATE(11023), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322857] = 3,
    STATE(3982), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322872] = 4,
    ACTIONS(18669), 1,
      anon_sym_SEMI,
    ACTIONS(18671), 1,
      anon_sym_COMMA,
    STATE(11023), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322889] = 4,
    ACTIONS(18395), 1,
      anon_sym_COMMA,
    ACTIONS(18674), 1,
      anon_sym_RPAREN,
    STATE(10983), 1,
      aux_sym_sorting_value_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322906] = 3,
    STATE(3524), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322921] = 3,
    STATE(5801), 1,
      sym_code_block,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322936] = 3,
    STATE(5802), 1,
      sym_code_block,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322951] = 3,
    STATE(3899), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322966] = 3,
    STATE(3900), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322981] = 3,
    STATE(5806), 1,
      sym_code_block,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [322996] = 3,
    STATE(5807), 1,
      sym_code_block,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323011] = 3,
    STATE(5809), 1,
      sym_code_block,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323026] = 3,
    STATE(5810), 1,
      sym_code_block,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323041] = 3,
    STATE(3902), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323056] = 3,
    STATE(3903), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323071] = 3,
    STATE(5813), 1,
      sym_code_block,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323086] = 3,
    STATE(5814), 1,
      sym_code_block,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323101] = 3,
    STATE(5817), 1,
      sym_code_block,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323116] = 3,
    STATE(5818), 1,
      sym_code_block,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323131] = 3,
    STATE(3921), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323146] = 3,
    STATE(5820), 1,
      sym_code_block,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323161] = 3,
    STATE(5821), 1,
      sym_code_block,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323176] = 3,
    STATE(5831), 1,
      sym_code_block,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323191] = 3,
    STATE(5832), 1,
      sym_code_block,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323206] = 3,
    STATE(5833), 1,
      sym_code_block,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323221] = 3,
    STATE(5834), 1,
      sym_code_block,
    ACTIONS(15185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323236] = 3,
    STATE(3924), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323251] = 3,
    STATE(3934), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323266] = 3,
    STATE(3525), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323281] = 3,
    STATE(3528), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323296] = 3,
    STATE(3530), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323311] = 3,
    STATE(3948), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323326] = 3,
    STATE(3949), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323341] = 3,
    STATE(3951), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323356] = 2,
    ACTIONS(18676), 3,
      aux_sym_interface_declaration_token2,
      sym_internal_keyword,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323369] = 3,
    STATE(3952), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323384] = 3,
    STATE(3533), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323399] = 3,
    STATE(3536), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323414] = 3,
    STATE(3953), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323429] = 3,
    STATE(3954), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323444] = 3,
    STATE(3537), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323459] = 3,
    STATE(3540), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323474] = 3,
    STATE(5447), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323489] = 3,
    STATE(5448), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323504] = 3,
    STATE(5453), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323519] = 3,
    STATE(3955), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323534] = 3,
    STATE(5455), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323549] = 3,
    STATE(5460), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323564] = 3,
    STATE(5461), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323579] = 3,
    STATE(5507), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323594] = 3,
    STATE(5511), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323609] = 3,
    STATE(5568), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323624] = 3,
    STATE(5571), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323639] = 3,
    STATE(5590), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323654] = 3,
    STATE(5595), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323669] = 3,
    STATE(3642), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323684] = 3,
    STATE(5598), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323699] = 3,
    STATE(5601), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323714] = 3,
    STATE(5634), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323729] = 3,
    STATE(5654), 1,
      sym_code_block,
    ACTIONS(13221), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323744] = 3,
    STATE(3145), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323759] = 3,
    STATE(3151), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323774] = 3,
    STATE(3643), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323789] = 3,
    STATE(3645), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323804] = 4,
    ACTIONS(13186), 1,
      anon_sym_COMMA,
    ACTIONS(18678), 1,
      anon_sym_RBRACK,
    STATE(10295), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323821] = 3,
    STATE(6761), 1,
      sym_code_block,
    ACTIONS(13843), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323836] = 3,
    STATE(3647), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323851] = 3,
    STATE(3541), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323866] = 3,
    STATE(4793), 1,
      sym_code_block,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323881] = 3,
    STATE(4787), 1,
      sym_code_block,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323896] = 3,
    STATE(7358), 1,
      sym_code_block,
    ACTIONS(13883), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323911] = 3,
    STATE(3650), 1,
      sym_code_block,
    ACTIONS(10178), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323926] = 3,
    STATE(4757), 1,
      sym_code_block,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323941] = 3,
    STATE(4718), 1,
      sym_code_block,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323956] = 4,
    ACTIONS(18437), 1,
      anon_sym_COMMA,
    ACTIONS(18680), 1,
      anon_sym_SEMI,
    STATE(10635), 1,
      aux_sym_label_declaration_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323973] = 3,
    STATE(4720), 1,
      sym_code_block,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [323988] = 3,
    STATE(4721), 1,
      sym_code_block,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324003] = 3,
    STATE(4723), 1,
      sym_code_block,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324018] = 3,
    STATE(4724), 1,
      sym_code_block,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324033] = 3,
    STATE(4726), 1,
      sym_code_block,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324048] = 3,
    STATE(4727), 1,
      sym_code_block,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324063] = 3,
    STATE(4728), 1,
      sym_code_block,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324078] = 3,
    STATE(4729), 1,
      sym_code_block,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324093] = 3,
    STATE(4731), 1,
      sym_code_block,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324108] = 3,
    STATE(3958), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324123] = 3,
    STATE(3959), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324138] = 3,
    STATE(4732), 1,
      sym_code_block,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324153] = 3,
    STATE(3962), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324168] = 3,
    STATE(3963), 1,
      sym_code_block,
    ACTIONS(11797), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324183] = 3,
    STATE(4733), 1,
      sym_code_block,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324198] = 3,
    STATE(4734), 1,
      sym_code_block,
    ACTIONS(15203), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324213] = 4,
    ACTIONS(18333), 1,
      anon_sym_COMMA,
    ACTIONS(18682), 1,
      anon_sym_RBRACK,
    STATE(10999), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324230] = 3,
    STATE(2830), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324245] = 3,
    STATE(5192), 1,
      sym_code_block,
    ACTIONS(13211), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324260] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(11967), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324274] = 2,
    ACTIONS(18686), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324286] = 2,
    ACTIONS(18665), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324298] = 2,
    ACTIONS(18342), 2,
      anon_sym_SEMI,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324310] = 2,
    ACTIONS(2841), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324322] = 3,
    ACTIONS(18688), 1,
      anon_sym_SEMI,
    ACTIONS(18690), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324336] = 2,
    ACTIONS(18692), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324348] = 3,
    ACTIONS(2591), 1,
      anon_sym_SEMI,
    ACTIONS(18694), 1,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324362] = 2,
    ACTIONS(18696), 2,
      anon_sym_RBRACE,
      sym_layout_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324374] = 3,
    ACTIONS(18698), 1,
      sym_procedure_keyword,
    ACTIONS(18700), 1,
      sym_var_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324388] = 2,
    ACTIONS(10076), 2,
      anon_sym_RBRACE,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324400] = 3,
    ACTIONS(18702), 1,
      sym_identifier,
    STATE(12322), 1,
      sym_namespace_name,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324414] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(12230), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324428] = 3,
    ACTIONS(614), 1,
      anon_sym_LBRACK,
    STATE(2445), 1,
      sym_list_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324442] = 2,
    ACTIONS(18704), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324454] = 3,
    ACTIONS(18706), 1,
      anon_sym_LBRACE,
    ACTIONS(18708), 1,
      aux_sym_interface_declaration_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324468] = 2,
    ACTIONS(18710), 2,
      aux_sym_sorting_value_token3,
      aux_sym_sorting_value_token4,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324480] = 2,
    ACTIONS(18712), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324492] = 3,
    ACTIONS(18702), 1,
      sym_identifier,
    STATE(12325), 1,
      sym_namespace_name,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324506] = 2,
    ACTIONS(18714), 2,
      sym_identifier,
      sym_quoted_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324518] = 2,
    ACTIONS(18716), 2,
      sym_identifier,
      sym_quoted_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324530] = 3,
    ACTIONS(18718), 1,
      aux_sym_where_condition_token1,
    STATE(9825), 1,
      sym__field_header,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324544] = 2,
    ACTIONS(16862), 2,
      anon_sym_LBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324556] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(11539), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324570] = 2,
    ACTIONS(18720), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324582] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(11528), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324596] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(12426), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324610] = 3,
    ACTIONS(18303), 1,
      sym_identifier,
    STATE(11144), 1,
      sym_label_attribute,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324624] = 2,
    ACTIONS(18722), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324636] = 2,
    ACTIONS(18669), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324648] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(11538), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324662] = 3,
    ACTIONS(18698), 1,
      sym_procedure_keyword,
    ACTIONS(18724), 1,
      sym_var_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324676] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(12236), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324690] = 3,
    ACTIONS(18698), 1,
      sym_procedure_keyword,
    ACTIONS(18726), 1,
      sym_var_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324704] = 2,
    ACTIONS(18728), 2,
      anon_sym_RBRACE,
      sym_layout_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324716] = 3,
    ACTIONS(18730), 1,
      anon_sym_LBRACE,
    ACTIONS(18732), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324730] = 3,
    ACTIONS(13827), 1,
      anon_sym_COLON,
    STATE(8935), 1,
      sym__procedure_return_specification,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324744] = 2,
    ACTIONS(18734), 2,
      sym_identifier,
      sym_quoted_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324756] = 2,
    ACTIONS(18736), 2,
      anon_sym_SEMI,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324768] = 3,
    ACTIONS(2591), 1,
      anon_sym_SEMI,
    ACTIONS(18738), 1,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324782] = 3,
    ACTIONS(18740), 1,
      anon_sym_SEMI,
    ACTIONS(18742), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324796] = 3,
    ACTIONS(18744), 1,
      anon_sym_SEMI,
    ACTIONS(18746), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324810] = 3,
    ACTIONS(18718), 1,
      aux_sym_where_condition_token1,
    STATE(8866), 1,
      sym__field_header,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324824] = 3,
    ACTIONS(18748), 1,
      anon_sym_SEMI,
    ACTIONS(18750), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324838] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(12422), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324852] = 3,
    ACTIONS(18752), 1,
      anon_sym_LBRACE,
    ACTIONS(18754), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324866] = 2,
    ACTIONS(18756), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324878] = 3,
    ACTIONS(18758), 1,
      anon_sym_LBRACE,
    ACTIONS(18760), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324892] = 3,
    ACTIONS(2591), 1,
      anon_sym_SEMI,
    ACTIONS(18762), 1,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324906] = 3,
    ACTIONS(18764), 1,
      anon_sym_LBRACE,
    ACTIONS(18766), 1,
      aux_sym_interface_declaration_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324920] = 3,
    ACTIONS(18718), 1,
      aux_sym_where_condition_token1,
    STATE(9750), 1,
      sym__field_header,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324934] = 3,
    ACTIONS(18718), 1,
      aux_sym_where_condition_token1,
    STATE(9458), 1,
      sym__field_header,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324948] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(12472), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324962] = 3,
    ACTIONS(18768), 1,
      anon_sym_LPAREN,
    ACTIONS(18770), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324976] = 2,
    ACTIONS(18772), 2,
      anon_sym_SEMI,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [324988] = 2,
    ACTIONS(18774), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325000] = 3,
    ACTIONS(13203), 1,
      anon_sym_COLON,
    STATE(7387), 1,
      sym__procedure_return_specification,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325014] = 2,
    ACTIONS(18776), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325026] = 3,
    ACTIONS(18718), 1,
      aux_sym_where_condition_token1,
    STATE(9588), 1,
      sym__field_header,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325040] = 3,
    ACTIONS(7044), 1,
      anon_sym_LBRACK,
    STATE(6099), 1,
      sym_list_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325054] = 2,
    ACTIONS(18778), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325066] = 3,
    ACTIONS(18780), 1,
      anon_sym_SEMI,
    ACTIONS(18782), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325080] = 3,
    ACTIONS(18784), 1,
      anon_sym_LBRACE,
    ACTIONS(18786), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325094] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(12381), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325108] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(12456), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325122] = 3,
    ACTIONS(18698), 1,
      sym_procedure_keyword,
    ACTIONS(18788), 1,
      sym_var_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325136] = 3,
    ACTIONS(18790), 1,
      anon_sym_LBRACE,
    ACTIONS(18792), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325150] = 3,
    ACTIONS(584), 1,
      anon_sym_LBRACK,
    STATE(1737), 1,
      sym_list_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325164] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(12012), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325178] = 2,
    ACTIONS(18794), 2,
      anon_sym_SEMI,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325190] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(12038), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325204] = 2,
    ACTIONS(18796), 2,
      sym_identifier,
      sym_quoted_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325216] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(11963), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325230] = 3,
    ACTIONS(7134), 1,
      anon_sym_LBRACK,
    STATE(2152), 1,
      sym_list_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325244] = 3,
    ACTIONS(18798), 1,
      anon_sym_SEMI,
    ACTIONS(18800), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325258] = 3,
    ACTIONS(11791), 1,
      anon_sym_COLON,
    STATE(6846), 1,
      sym__procedure_return_specification,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325272] = 2,
    ACTIONS(18802), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325284] = 3,
    ACTIONS(18718), 1,
      aux_sym_where_condition_token1,
    STATE(9359), 1,
      sym__field_header,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325298] = 2,
    ACTIONS(16077), 2,
      anon_sym_SEMI,
      aux_sym_if_table_relation_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325310] = 3,
    ACTIONS(2591), 1,
      anon_sym_SEMI,
    ACTIONS(18804), 1,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325324] = 3,
    ACTIONS(7134), 1,
      anon_sym_LBRACK,
    STATE(2156), 1,
      sym_list_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325338] = 3,
    ACTIONS(535), 1,
      anon_sym_LBRACK,
    STATE(1129), 1,
      sym_list_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325352] = 3,
    ACTIONS(18806), 1,
      anon_sym_SEMI,
    ACTIONS(18808), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325366] = 2,
    ACTIONS(18619), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325378] = 2,
    ACTIONS(12791), 2,
      anon_sym_RBRACE,
      sym_dataitem_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325390] = 2,
    ACTIONS(12759), 2,
      anon_sym_RBRACE,
      sym_dataitem_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325402] = 3,
    ACTIONS(69), 1,
      anon_sym_LBRACK,
    STATE(1025), 1,
      sym_list_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325416] = 3,
    ACTIONS(2591), 1,
      anon_sym_SEMI,
    ACTIONS(18810), 1,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325430] = 2,
    ACTIONS(18812), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325442] = 3,
    ACTIONS(18814), 1,
      anon_sym_SEMI,
    ACTIONS(18816), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325456] = 2,
    ACTIONS(18818), 2,
      aux_sym_sorting_value_token3,
      aux_sym_sorting_value_token4,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325468] = 3,
    ACTIONS(2591), 1,
      anon_sym_SEMI,
    ACTIONS(18820), 1,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325482] = 3,
    ACTIONS(18822), 1,
      anon_sym_SEMI,
    ACTIONS(18824), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325496] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(12024), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325510] = 2,
    ACTIONS(18826), 2,
      sym_identifier,
      sym_quoted_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325522] = 3,
    ACTIONS(2591), 1,
      anon_sym_SEMI,
    ACTIONS(18828), 1,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325536] = 3,
    ACTIONS(18830), 1,
      anon_sym_SEMI,
    ACTIONS(18832), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325550] = 2,
    ACTIONS(18834), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325562] = 3,
    ACTIONS(18836), 1,
      anon_sym_SEMI,
    ACTIONS(18838), 1,
      sym_property_name,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325576] = 3,
    ACTIONS(14001), 1,
      anon_sym_COLON,
    STATE(8832), 1,
      sym__procedure_return_specification,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325590] = 3,
    ACTIONS(18718), 1,
      aux_sym_where_condition_token1,
    STATE(9843), 1,
      sym__field_header,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325604] = 2,
    ACTIONS(18641), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325616] = 3,
    ACTIONS(18840), 1,
      anon_sym_SEMI,
    ACTIONS(18842), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325630] = 2,
    ACTIONS(18844), 2,
      sym_identifier,
      sym_quoted_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325642] = 3,
    ACTIONS(10162), 1,
      anon_sym_COLON,
    STATE(6194), 1,
      sym__procedure_return_specification,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325656] = 3,
    ACTIONS(18574), 1,
      anon_sym_COMMA,
    STATE(10885), 1,
      aux_sym_signed_integer_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325670] = 2,
    ACTIONS(18846), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325682] = 3,
    ACTIONS(919), 1,
      anon_sym_LBRACK,
    STATE(4831), 1,
      sym_list_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325696] = 3,
    ACTIONS(614), 1,
      anon_sym_LBRACK,
    STATE(2208), 1,
      sym_list_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325710] = 3,
    ACTIONS(18848), 1,
      anon_sym_SEMI,
    ACTIONS(18850), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325724] = 2,
    ACTIONS(18852), 2,
      sym_identifier,
      sym_quoted_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325736] = 2,
    ACTIONS(18649), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325748] = 3,
    ACTIONS(584), 1,
      anon_sym_LBRACK,
    STATE(1493), 1,
      sym_list_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325762] = 3,
    ACTIONS(18515), 1,
      anon_sym_SEMI,
    ACTIONS(18838), 1,
      sym_property_name,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325776] = 2,
    ACTIONS(18314), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325788] = 3,
    ACTIONS(18854), 1,
      anon_sym_SEMI,
    ACTIONS(18856), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325802] = 3,
    ACTIONS(18858), 1,
      anon_sym_SEMI,
    ACTIONS(18860), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325816] = 2,
    ACTIONS(9820), 2,
      anon_sym_RBRACE,
      aux_sym_assembly_declaration_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325828] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(12098), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325842] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(12102), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325856] = 3,
    ACTIONS(15576), 1,
      anon_sym_SEMI,
    ACTIONS(18862), 1,
      aux_sym_if_table_relation_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325870] = 2,
    ACTIONS(18864), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325882] = 3,
    ACTIONS(18718), 1,
      aux_sym_where_condition_token1,
    STATE(9585), 1,
      sym__field_header,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325896] = 3,
    ACTIONS(18718), 1,
      aux_sym_where_condition_token1,
    STATE(9793), 1,
      sym__field_header,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325910] = 3,
    ACTIONS(18702), 1,
      sym_identifier,
    STATE(11496), 1,
      sym_namespace_name,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325924] = 2,
    ACTIONS(18653), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325936] = 2,
    ACTIONS(18866), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325948] = 3,
    ACTIONS(18684), 1,
      sym_identifier,
    STATE(12099), 1,
      sym_attribute_content,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325962] = 3,
    ACTIONS(18702), 1,
      sym_identifier,
    STATE(11661), 1,
      sym_namespace_name,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325976] = 3,
    ACTIONS(18868), 1,
      anon_sym_SEMI,
    ACTIONS(18870), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [325990] = 2,
    ACTIONS(18872), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326002] = 3,
    ACTIONS(18698), 1,
      sym_procedure_keyword,
    ACTIONS(18874), 1,
      sym_var_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326016] = 3,
    ACTIONS(18876), 1,
      anon_sym_LBRACE,
    ACTIONS(18878), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326030] = 3,
    ACTIONS(18880), 1,
      anon_sym_SEMI,
    ACTIONS(18882), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326044] = 3,
    ACTIONS(18884), 1,
      anon_sym_SEMI,
    ACTIONS(18886), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326058] = 3,
    ACTIONS(2591), 1,
      anon_sym_SEMI,
    ACTIONS(18888), 1,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326072] = 3,
    ACTIONS(646), 1,
      anon_sym_LBRACK,
    STATE(1219), 1,
      sym_list_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326086] = 2,
    ACTIONS(18384), 2,
      anon_sym_SEMI,
      anon_sym_DOT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326098] = 2,
    ACTIONS(18890), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326109] = 2,
    ACTIONS(18892), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326120] = 2,
    ACTIONS(18894), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326131] = 2,
    ACTIONS(18896), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326142] = 2,
    ACTIONS(18898), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326153] = 2,
    ACTIONS(18900), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326164] = 2,
    ACTIONS(18902), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326175] = 2,
    ACTIONS(18904), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326186] = 2,
    ACTIONS(18906), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326197] = 2,
    ACTIONS(18908), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326208] = 2,
    ACTIONS(18910), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326219] = 2,
    ACTIONS(18912), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326230] = 2,
    ACTIONS(18914), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326241] = 2,
    ACTIONS(18916), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326252] = 2,
    ACTIONS(18918), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326263] = 2,
    ACTIONS(18920), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326274] = 2,
    ACTIONS(18922), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326285] = 2,
    ACTIONS(18354), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326296] = 2,
    ACTIONS(18924), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326307] = 2,
    ACTIONS(18926), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326318] = 2,
    ACTIONS(18928), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326329] = 2,
    ACTIONS(18930), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326340] = 2,
    ACTIONS(18932), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326351] = 2,
    ACTIONS(18934), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326362] = 2,
    ACTIONS(18936), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326373] = 2,
    ACTIONS(18938), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326384] = 2,
    ACTIONS(18940), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326395] = 2,
    ACTIONS(18942), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326406] = 2,
    ACTIONS(18944), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326417] = 2,
    ACTIONS(18946), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326428] = 2,
    ACTIONS(18948), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326439] = 2,
    ACTIONS(18950), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326450] = 2,
    ACTIONS(18952), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326461] = 2,
    ACTIONS(18954), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326472] = 2,
    ACTIONS(18956), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326483] = 2,
    ACTIONS(18958), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326494] = 2,
    ACTIONS(18960), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326505] = 2,
    ACTIONS(18962), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326516] = 2,
    ACTIONS(18964), 1,
      sym_var_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326527] = 2,
    ACTIONS(18966), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326538] = 2,
    ACTIONS(18968), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326549] = 2,
    ACTIONS(18970), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326560] = 2,
    ACTIONS(18972), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326571] = 2,
    ACTIONS(18974), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326582] = 2,
    ACTIONS(18976), 1,
      sym_var_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326593] = 2,
    ACTIONS(18978), 1,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326604] = 2,
    ACTIONS(18980), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326615] = 2,
    ACTIONS(18982), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326626] = 2,
    ACTIONS(18984), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326637] = 2,
    ACTIONS(18986), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326648] = 2,
    ACTIONS(18988), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326659] = 2,
    ACTIONS(18990), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326670] = 2,
    ACTIONS(18992), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326681] = 2,
    ACTIONS(18994), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326692] = 2,
    ACTIONS(18996), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326703] = 2,
    ACTIONS(18998), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326714] = 2,
    ACTIONS(19000), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326725] = 2,
    ACTIONS(19002), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326736] = 2,
    ACTIONS(19004), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326747] = 2,
    ACTIONS(19006), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326758] = 2,
    ACTIONS(19008), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326769] = 2,
    ACTIONS(19010), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326780] = 2,
    ACTIONS(19012), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326791] = 2,
    ACTIONS(19014), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326802] = 2,
    ACTIONS(19016), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326813] = 2,
    ACTIONS(19018), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326824] = 2,
    ACTIONS(19020), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326835] = 2,
    ACTIONS(19022), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326846] = 2,
    ACTIONS(19024), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326857] = 2,
    ACTIONS(19026), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326868] = 2,
    ACTIONS(19028), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326879] = 2,
    ACTIONS(19030), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326890] = 2,
    ACTIONS(19032), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326901] = 2,
    ACTIONS(19034), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326912] = 2,
    ACTIONS(19036), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326923] = 2,
    ACTIONS(19038), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326934] = 2,
    ACTIONS(19040), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326945] = 2,
    ACTIONS(19042), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326956] = 2,
    ACTIONS(19044), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326967] = 2,
    ACTIONS(19046), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326978] = 2,
    ACTIONS(19048), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [326989] = 2,
    ACTIONS(19050), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327000] = 2,
    ACTIONS(19052), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327011] = 2,
    ACTIONS(19054), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327022] = 2,
    ACTIONS(17104), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327033] = 2,
    ACTIONS(18746), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327044] = 2,
    ACTIONS(19056), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327055] = 2,
    ACTIONS(19058), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327066] = 2,
    ACTIONS(19060), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327077] = 2,
    ACTIONS(19062), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327088] = 2,
    ACTIONS(19064), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327099] = 2,
    ACTIONS(17110), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327110] = 2,
    ACTIONS(19066), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327121] = 2,
    ACTIONS(19068), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327132] = 2,
    ACTIONS(19070), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327143] = 2,
    ACTIONS(19072), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327154] = 2,
    ACTIONS(19074), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327165] = 2,
    ACTIONS(19076), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327176] = 2,
    ACTIONS(19078), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327187] = 2,
    ACTIONS(19080), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327198] = 2,
    ACTIONS(19082), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327209] = 2,
    ACTIONS(19084), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327220] = 2,
    ACTIONS(19086), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327231] = 2,
    ACTIONS(19088), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327242] = 2,
    ACTIONS(19090), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327253] = 2,
    ACTIONS(19092), 1,
      anon_sym_COLON,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327264] = 2,
    ACTIONS(19094), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327275] = 2,
    ACTIONS(19096), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327286] = 2,
    ACTIONS(19098), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327297] = 2,
    ACTIONS(19100), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327308] = 2,
    ACTIONS(19102), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327319] = 2,
    ACTIONS(19104), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327330] = 2,
    ACTIONS(19106), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327341] = 2,
    ACTIONS(19108), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327352] = 2,
    ACTIONS(19110), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327363] = 2,
    ACTIONS(19112), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327374] = 2,
    ACTIONS(19114), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327385] = 2,
    ACTIONS(19116), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327396] = 2,
    ACTIONS(19118), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327407] = 2,
    ACTIONS(19120), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327418] = 2,
    ACTIONS(19122), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327429] = 2,
    ACTIONS(19124), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327440] = 2,
    ACTIONS(19126), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327451] = 2,
    ACTIONS(19128), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327462] = 2,
    ACTIONS(19130), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327473] = 2,
    ACTIONS(4821), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327484] = 2,
    ACTIONS(19132), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327495] = 2,
    ACTIONS(19134), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327506] = 2,
    ACTIONS(19136), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327517] = 2,
    ACTIONS(19138), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327528] = 2,
    ACTIONS(19140), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327539] = 2,
    ACTIONS(19142), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327550] = 2,
    ACTIONS(19144), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327561] = 2,
    ACTIONS(19146), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327572] = 2,
    ACTIONS(19148), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327583] = 2,
    ACTIONS(19150), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327594] = 2,
    ACTIONS(19152), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327605] = 2,
    ACTIONS(19154), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327616] = 2,
    ACTIONS(19156), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327627] = 2,
    ACTIONS(19158), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327638] = 2,
    ACTIONS(19160), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327649] = 2,
    ACTIONS(19162), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327660] = 2,
    ACTIONS(19164), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327671] = 2,
    ACTIONS(19166), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327682] = 2,
    ACTIONS(19168), 1,
      aux_sym_preproc_split_procedure_body_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327693] = 2,
    ACTIONS(19170), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327704] = 2,
    ACTIONS(19172), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327715] = 2,
    ACTIONS(19174), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327726] = 2,
    ACTIONS(19176), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327737] = 2,
    ACTIONS(19178), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327748] = 2,
    ACTIONS(19180), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327759] = 2,
    ACTIONS(19182), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327770] = 2,
    ACTIONS(19184), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327781] = 2,
    ACTIONS(19186), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327792] = 2,
    ACTIONS(19188), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327803] = 2,
    ACTIONS(18068), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327814] = 2,
    ACTIONS(19190), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327825] = 2,
    ACTIONS(19192), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327836] = 2,
    ACTIONS(19194), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327847] = 2,
    ACTIONS(19196), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327858] = 2,
    ACTIONS(19198), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327869] = 2,
    ACTIONS(19200), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327880] = 2,
    ACTIONS(19202), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327891] = 2,
    ACTIONS(19204), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327902] = 2,
    ACTIONS(19206), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327913] = 2,
    ACTIONS(19208), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327924] = 2,
    ACTIONS(19210), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327935] = 2,
    ACTIONS(19212), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327946] = 2,
    ACTIONS(19214), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327957] = 2,
    ACTIONS(19216), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327968] = 2,
    ACTIONS(19218), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327979] = 2,
    ACTIONS(19220), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [327990] = 2,
    ACTIONS(19222), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328001] = 2,
    ACTIONS(19224), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328012] = 2,
    ACTIONS(19226), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328023] = 2,
    ACTIONS(19228), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328034] = 2,
    ACTIONS(19230), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328045] = 2,
    ACTIONS(19232), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328056] = 2,
    ACTIONS(19234), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328067] = 2,
    ACTIONS(19236), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328078] = 2,
    ACTIONS(17098), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328089] = 2,
    ACTIONS(17102), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328100] = 2,
    ACTIONS(14215), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328111] = 2,
    ACTIONS(19238), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328122] = 2,
    ACTIONS(19240), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328133] = 2,
    ACTIONS(19242), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328144] = 2,
    ACTIONS(19244), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328155] = 2,
    ACTIONS(19246), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328166] = 2,
    ACTIONS(19248), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328177] = 2,
    ACTIONS(19250), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328188] = 2,
    ACTIONS(19252), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328199] = 2,
    ACTIONS(19254), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328210] = 2,
    ACTIONS(19256), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328221] = 2,
    ACTIONS(19258), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328232] = 2,
    ACTIONS(19260), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328243] = 2,
    ACTIONS(19262), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328254] = 2,
    ACTIONS(19264), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328265] = 2,
    ACTIONS(19266), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328276] = 2,
    ACTIONS(19268), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328287] = 2,
    ACTIONS(19270), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328298] = 2,
    ACTIONS(19272), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328309] = 2,
    ACTIONS(19274), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328320] = 2,
    ACTIONS(19276), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328331] = 2,
    ACTIONS(19278), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328342] = 2,
    ACTIONS(19280), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328353] = 2,
    ACTIONS(19282), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328364] = 2,
    ACTIONS(19284), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328375] = 2,
    ACTIONS(19286), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328386] = 2,
    ACTIONS(19288), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328397] = 2,
    ACTIONS(19290), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328408] = 2,
    ACTIONS(19292), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328419] = 2,
    ACTIONS(19294), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328430] = 2,
    ACTIONS(19296), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328441] = 2,
    ACTIONS(19298), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328452] = 2,
    ACTIONS(19300), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328463] = 2,
    ACTIONS(19302), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328474] = 2,
    ACTIONS(19304), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328485] = 2,
    ACTIONS(19306), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328496] = 2,
    ACTIONS(19308), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328507] = 2,
    ACTIONS(17108), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328518] = 2,
    ACTIONS(19310), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328529] = 2,
    ACTIONS(19312), 1,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328540] = 2,
    ACTIONS(19314), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328551] = 2,
    ACTIONS(19316), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328562] = 2,
    ACTIONS(19318), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328573] = 2,
    ACTIONS(19320), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328584] = 2,
    ACTIONS(19322), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328595] = 2,
    ACTIONS(19324), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328606] = 2,
    ACTIONS(19326), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328617] = 2,
    ACTIONS(19328), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328628] = 2,
    ACTIONS(19330), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328639] = 2,
    ACTIONS(19332), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328650] = 2,
    ACTIONS(19334), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328661] = 2,
    ACTIONS(19336), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328672] = 2,
    ACTIONS(19338), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328683] = 2,
    ACTIONS(19340), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328694] = 2,
    ACTIONS(19342), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328705] = 2,
    ACTIONS(19344), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328716] = 2,
    ACTIONS(19346), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328727] = 2,
    ACTIONS(19348), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328738] = 2,
    ACTIONS(19350), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328749] = 2,
    ACTIONS(17956), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328760] = 2,
    ACTIONS(19352), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328771] = 2,
    ACTIONS(19354), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328782] = 2,
    ACTIONS(19356), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328793] = 2,
    ACTIONS(19358), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328804] = 2,
    ACTIONS(19360), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328815] = 2,
    ACTIONS(19362), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328826] = 2,
    ACTIONS(19364), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328837] = 2,
    ACTIONS(19366), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328848] = 2,
    ACTIONS(19368), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328859] = 2,
    ACTIONS(19370), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328870] = 2,
    ACTIONS(17112), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328881] = 2,
    ACTIONS(19372), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328892] = 2,
    ACTIONS(17114), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328903] = 2,
    ACTIONS(19374), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328914] = 2,
    ACTIONS(19376), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328925] = 2,
    ACTIONS(19378), 1,
      sym_permission_type,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328936] = 2,
    ACTIONS(19380), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328947] = 2,
    ACTIONS(19382), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328958] = 2,
    ACTIONS(19384), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328969] = 2,
    ACTIONS(19386), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328980] = 2,
    ACTIONS(19388), 1,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [328991] = 2,
    ACTIONS(19390), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329002] = 2,
    ACTIONS(19392), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329013] = 2,
    ACTIONS(19394), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329024] = 2,
    ACTIONS(19396), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329035] = 2,
    ACTIONS(19398), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329046] = 2,
    ACTIONS(19400), 1,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329057] = 2,
    ACTIONS(19402), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329068] = 2,
    ACTIONS(19404), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329079] = 2,
    ACTIONS(19406), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329090] = 2,
    ACTIONS(19408), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329101] = 2,
    ACTIONS(19410), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329112] = 2,
    ACTIONS(19412), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329123] = 2,
    ACTIONS(19414), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329134] = 2,
    ACTIONS(19416), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329145] = 2,
    ACTIONS(19418), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329156] = 2,
    ACTIONS(19420), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329167] = 2,
    ACTIONS(19422), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329178] = 2,
    ACTIONS(19424), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329189] = 2,
    ACTIONS(19426), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329200] = 2,
    ACTIONS(19428), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329211] = 2,
    ACTIONS(19430), 1,
      aux_sym_preproc_split_procedure_body_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329222] = 2,
    ACTIONS(19432), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329233] = 2,
    ACTIONS(19434), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329244] = 2,
    ACTIONS(19436), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329255] = 2,
    ACTIONS(19438), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329266] = 2,
    ACTIONS(19440), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329277] = 2,
    ACTIONS(19442), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329288] = 2,
    ACTIONS(19444), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329299] = 2,
    ACTIONS(19446), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329310] = 2,
    ACTIONS(19448), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329321] = 2,
    ACTIONS(19450), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329332] = 2,
    ACTIONS(19452), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329343] = 2,
    ACTIONS(19454), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329354] = 2,
    ACTIONS(13770), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329365] = 2,
    ACTIONS(19456), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329376] = 2,
    ACTIONS(19458), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329387] = 2,
    ACTIONS(19460), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329398] = 2,
    ACTIONS(19462), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329409] = 2,
    ACTIONS(19464), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329420] = 2,
    ACTIONS(19466), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329431] = 2,
    ACTIONS(19468), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329442] = 2,
    ACTIONS(19470), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329453] = 2,
    ACTIONS(19472), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329464] = 2,
    ACTIONS(19474), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329475] = 2,
    ACTIONS(19476), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329486] = 2,
    ACTIONS(19478), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329497] = 2,
    ACTIONS(19480), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329508] = 2,
    ACTIONS(19482), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329519] = 2,
    ACTIONS(19484), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329530] = 2,
    ACTIONS(19486), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329541] = 2,
    ACTIONS(19488), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329552] = 2,
    ACTIONS(19490), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329563] = 2,
    ACTIONS(19492), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329574] = 2,
    ACTIONS(19494), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329585] = 2,
    ACTIONS(19496), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329596] = 2,
    ACTIONS(19498), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329607] = 2,
    ACTIONS(19500), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329618] = 2,
    ACTIONS(19502), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329629] = 2,
    ACTIONS(19504), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329640] = 2,
    ACTIONS(19506), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329651] = 2,
    ACTIONS(19508), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329662] = 2,
    ACTIONS(19510), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329673] = 2,
    ACTIONS(19512), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329684] = 2,
    ACTIONS(19514), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329695] = 2,
    ACTIONS(19516), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329706] = 2,
    ACTIONS(19518), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329717] = 2,
    ACTIONS(19520), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329728] = 2,
    ACTIONS(19522), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329739] = 2,
    ACTIONS(19524), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329750] = 2,
    ACTIONS(19526), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329761] = 2,
    ACTIONS(19528), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329772] = 2,
    ACTIONS(19530), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329783] = 2,
    ACTIONS(19532), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329794] = 2,
    ACTIONS(19534), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329805] = 2,
    ACTIONS(19536), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329816] = 2,
    ACTIONS(19538), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329827] = 2,
    ACTIONS(19540), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329838] = 2,
    ACTIONS(19542), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329849] = 2,
    ACTIONS(19544), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329860] = 2,
    ACTIONS(19546), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329871] = 2,
    ACTIONS(19548), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329882] = 2,
    ACTIONS(19550), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329893] = 2,
    ACTIONS(19552), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329904] = 2,
    ACTIONS(19554), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329915] = 2,
    ACTIONS(19556), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329926] = 2,
    ACTIONS(19558), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329937] = 2,
    ACTIONS(19560), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329948] = 2,
    ACTIONS(19562), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329959] = 2,
    ACTIONS(19564), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329970] = 2,
    ACTIONS(19566), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329981] = 2,
    ACTIONS(19568), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [329992] = 2,
    ACTIONS(19570), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330003] = 2,
    ACTIONS(19572), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330014] = 2,
    ACTIONS(19574), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330025] = 2,
    ACTIONS(19576), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330036] = 2,
    ACTIONS(19578), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330047] = 2,
    ACTIONS(17987), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330058] = 2,
    ACTIONS(19580), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330069] = 2,
    ACTIONS(19582), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330080] = 2,
    ACTIONS(19584), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330091] = 2,
    ACTIONS(19586), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330102] = 2,
    ACTIONS(19588), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330113] = 2,
    ACTIONS(19590), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330124] = 2,
    ACTIONS(19592), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330135] = 2,
    ACTIONS(19594), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330146] = 2,
    ACTIONS(19596), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330157] = 2,
    ACTIONS(19598), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330168] = 2,
    ACTIONS(19600), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330179] = 2,
    ACTIONS(19602), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330190] = 2,
    ACTIONS(19604), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330201] = 2,
    ACTIONS(19606), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330212] = 2,
    ACTIONS(19608), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330223] = 2,
    ACTIONS(19610), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330234] = 2,
    ACTIONS(19612), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330245] = 2,
    ACTIONS(19614), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330256] = 2,
    ACTIONS(19616), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330267] = 2,
    ACTIONS(19618), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330278] = 2,
    ACTIONS(19620), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330289] = 2,
    ACTIONS(19622), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330300] = 2,
    ACTIONS(19624), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330311] = 2,
    ACTIONS(19626), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330322] = 2,
    ACTIONS(19628), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330333] = 2,
    ACTIONS(19630), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330344] = 2,
    ACTIONS(19632), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330355] = 2,
    ACTIONS(19634), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330366] = 2,
    ACTIONS(19636), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330377] = 2,
    ACTIONS(19638), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330388] = 2,
    ACTIONS(19640), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330399] = 2,
    ACTIONS(19642), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330410] = 2,
    ACTIONS(19644), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330421] = 2,
    ACTIONS(19646), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330432] = 2,
    ACTIONS(19648), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330443] = 2,
    ACTIONS(19650), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330454] = 2,
    ACTIONS(19652), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330465] = 2,
    ACTIONS(19654), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330476] = 2,
    ACTIONS(19656), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330487] = 2,
    ACTIONS(19658), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330498] = 2,
    ACTIONS(19660), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330509] = 2,
    ACTIONS(19662), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330520] = 2,
    ACTIONS(19664), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330531] = 2,
    ACTIONS(19666), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330542] = 2,
    ACTIONS(19668), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330553] = 2,
    ACTIONS(19670), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330564] = 2,
    ACTIONS(19672), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330575] = 2,
    ACTIONS(19674), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330586] = 2,
    ACTIONS(19676), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330597] = 2,
    ACTIONS(19678), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330608] = 2,
    ACTIONS(19680), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330619] = 2,
    ACTIONS(19682), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330630] = 2,
    ACTIONS(19684), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330641] = 2,
    ACTIONS(19686), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330652] = 2,
    ACTIONS(19688), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330663] = 2,
    ACTIONS(19690), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330674] = 2,
    ACTIONS(19692), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330685] = 2,
    ACTIONS(19694), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330696] = 2,
    ACTIONS(19696), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330707] = 2,
    ACTIONS(19698), 1,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330718] = 2,
    ACTIONS(19700), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330729] = 2,
    ACTIONS(19702), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330740] = 2,
    ACTIONS(19704), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330751] = 2,
    ACTIONS(19706), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330762] = 2,
    ACTIONS(19708), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330773] = 2,
    ACTIONS(19710), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330784] = 2,
    ACTIONS(19712), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330795] = 2,
    ACTIONS(19714), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330806] = 2,
    ACTIONS(19716), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330817] = 2,
    ACTIONS(19718), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330828] = 2,
    ACTIONS(19720), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330839] = 2,
    ACTIONS(18838), 1,
      sym_property_name,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330850] = 2,
    ACTIONS(19722), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330861] = 2,
    ACTIONS(19724), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330872] = 2,
    ACTIONS(19726), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330883] = 2,
    ACTIONS(19728), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330894] = 2,
    ACTIONS(19730), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330905] = 2,
    ACTIONS(18003), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330916] = 2,
    ACTIONS(19732), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330927] = 2,
    ACTIONS(19734), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330938] = 2,
    ACTIONS(19736), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330949] = 2,
    ACTIONS(19738), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330960] = 2,
    ACTIONS(19740), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330971] = 2,
    ACTIONS(19742), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330982] = 2,
    ACTIONS(19744), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [330993] = 2,
    ACTIONS(19746), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331004] = 2,
    ACTIONS(19748), 1,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331015] = 2,
    ACTIONS(19750), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331026] = 2,
    ACTIONS(19752), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331037] = 2,
    ACTIONS(19754), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331048] = 2,
    ACTIONS(19756), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331059] = 2,
    ACTIONS(19758), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331070] = 2,
    ACTIONS(19760), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331081] = 2,
    ACTIONS(19762), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331092] = 2,
    ACTIONS(19764), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331103] = 2,
    ACTIONS(19766), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331114] = 2,
    ACTIONS(19768), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331125] = 2,
    ACTIONS(19770), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331136] = 2,
    ACTIONS(19772), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331147] = 2,
    ACTIONS(19774), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331158] = 2,
    ACTIONS(19776), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331169] = 2,
    ACTIONS(19778), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331180] = 2,
    ACTIONS(19780), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331191] = 2,
    ACTIONS(19782), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331202] = 2,
    ACTIONS(19784), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331213] = 2,
    ACTIONS(19786), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331224] = 2,
    ACTIONS(19788), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331235] = 2,
    ACTIONS(19790), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331246] = 2,
    ACTIONS(19792), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331257] = 2,
    ACTIONS(19794), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331268] = 2,
    ACTIONS(19796), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331279] = 2,
    ACTIONS(19798), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331290] = 2,
    ACTIONS(19800), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331301] = 2,
    ACTIONS(19802), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331312] = 2,
    ACTIONS(19804), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331323] = 2,
    ACTIONS(19806), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331334] = 2,
    ACTIONS(19808), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331345] = 2,
    ACTIONS(19810), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331356] = 2,
    ACTIONS(19812), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331367] = 2,
    ACTIONS(19814), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331378] = 2,
    ACTIONS(19816), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331389] = 2,
    ACTIONS(19818), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331400] = 2,
    ACTIONS(19820), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331411] = 2,
    ACTIONS(19822), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331422] = 2,
    ACTIONS(19824), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331433] = 2,
    ACTIONS(19826), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331444] = 2,
    ACTIONS(19828), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331455] = 2,
    ACTIONS(19830), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331466] = 2,
    ACTIONS(19832), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331477] = 2,
    ACTIONS(19834), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331488] = 2,
    ACTIONS(19836), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331499] = 2,
    ACTIONS(19838), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331510] = 2,
    ACTIONS(19840), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331521] = 2,
    ACTIONS(14591), 1,
      sym_string_literal,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331532] = 2,
    ACTIONS(19842), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331543] = 2,
    ACTIONS(19844), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331554] = 2,
    ACTIONS(18019), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331565] = 2,
    ACTIONS(19846), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331576] = 2,
    ACTIONS(19848), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331587] = 2,
    ACTIONS(19850), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331598] = 2,
    ACTIONS(19852), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331609] = 2,
    ACTIONS(19854), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331620] = 2,
    ACTIONS(19856), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331631] = 2,
    ACTIONS(19858), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331642] = 2,
    ACTIONS(19860), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331653] = 2,
    ACTIONS(19862), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331664] = 2,
    ACTIONS(19864), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331675] = 2,
    ACTIONS(19866), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331686] = 2,
    ACTIONS(19868), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331697] = 2,
    ACTIONS(19870), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331708] = 2,
    ACTIONS(19872), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331719] = 2,
    ACTIONS(19874), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331730] = 2,
    ACTIONS(19876), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331741] = 2,
    ACTIONS(19878), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331752] = 2,
    ACTIONS(19880), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331763] = 2,
    ACTIONS(19882), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331774] = 2,
    ACTIONS(19884), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331785] = 2,
    ACTIONS(19886), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331796] = 2,
    ACTIONS(19888), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331807] = 2,
    ACTIONS(19890), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331818] = 2,
    ACTIONS(19892), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331829] = 2,
    ACTIONS(19894), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331840] = 2,
    ACTIONS(19896), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331851] = 2,
    ACTIONS(19898), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331862] = 2,
    ACTIONS(19900), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331873] = 2,
    ACTIONS(19902), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331884] = 2,
    ACTIONS(19904), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331895] = 2,
    ACTIONS(19906), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331906] = 2,
    ACTIONS(19908), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331917] = 2,
    ACTIONS(19910), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331928] = 2,
    ACTIONS(19912), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331939] = 2,
    ACTIONS(19914), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331950] = 2,
    ACTIONS(19916), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331961] = 2,
    ACTIONS(19918), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331972] = 2,
    ACTIONS(19920), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331983] = 2,
    ACTIONS(19922), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [331994] = 2,
    ACTIONS(19924), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332005] = 2,
    ACTIONS(19926), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332016] = 2,
    ACTIONS(19928), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332027] = 2,
    ACTIONS(19930), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332038] = 2,
    ACTIONS(19932), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332049] = 2,
    ACTIONS(19934), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332060] = 2,
    ACTIONS(19936), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332071] = 2,
    ACTIONS(19938), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332082] = 2,
    ACTIONS(19940), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332093] = 2,
    ACTIONS(19942), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332104] = 2,
    ACTIONS(19944), 1,
      aux_sym_preproc_split_procedure_body_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332115] = 2,
    ACTIONS(19946), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332126] = 2,
    ACTIONS(19948), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332137] = 2,
    ACTIONS(19950), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332148] = 2,
    ACTIONS(19952), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332159] = 2,
    ACTIONS(19954), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332170] = 2,
    ACTIONS(19956), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332181] = 2,
    ACTIONS(19958), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332192] = 2,
    ACTIONS(19960), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332203] = 2,
    ACTIONS(19962), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332214] = 2,
    ACTIONS(19964), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332225] = 2,
    ACTIONS(19966), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332236] = 2,
    ACTIONS(19968), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332247] = 2,
    ACTIONS(19970), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332258] = 2,
    ACTIONS(19972), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332269] = 2,
    ACTIONS(19974), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332280] = 2,
    ACTIONS(19976), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332291] = 2,
    ACTIONS(19978), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332302] = 2,
    ACTIONS(19980), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332313] = 2,
    ACTIONS(19982), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332324] = 2,
    ACTIONS(19984), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332335] = 2,
    ACTIONS(19986), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332346] = 2,
    ACTIONS(19988), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332357] = 2,
    ACTIONS(19990), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332368] = 2,
    ACTIONS(19992), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332379] = 2,
    ACTIONS(19994), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332390] = 2,
    ACTIONS(19996), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332401] = 2,
    ACTIONS(19998), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332412] = 2,
    ACTIONS(20000), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332423] = 2,
    ACTIONS(20002), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332434] = 2,
    ACTIONS(20004), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332445] = 2,
    ACTIONS(20006), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332456] = 2,
    ACTIONS(20008), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332467] = 2,
    ACTIONS(20010), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332478] = 2,
    ACTIONS(20012), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332489] = 2,
    ACTIONS(20014), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332500] = 2,
    ACTIONS(20016), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332511] = 2,
    ACTIONS(20018), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332522] = 2,
    ACTIONS(20020), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332533] = 2,
    ACTIONS(20022), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332544] = 2,
    ACTIONS(20024), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332555] = 2,
    ACTIONS(20026), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332566] = 2,
    ACTIONS(20028), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332577] = 2,
    ACTIONS(20030), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332588] = 2,
    ACTIONS(20032), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332599] = 2,
    ACTIONS(20034), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332610] = 2,
    ACTIONS(20036), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332621] = 2,
    ACTIONS(20038), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332632] = 2,
    ACTIONS(20040), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332643] = 2,
    ACTIONS(20042), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332654] = 2,
    ACTIONS(20044), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332665] = 2,
    ACTIONS(20046), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332676] = 2,
    ACTIONS(20048), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332687] = 2,
    ACTIONS(20050), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332698] = 2,
    ACTIONS(20052), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332709] = 2,
    ACTIONS(20054), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332720] = 2,
    ACTIONS(20056), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332731] = 2,
    ACTIONS(20058), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332742] = 2,
    ACTIONS(20060), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332753] = 2,
    ACTIONS(20062), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332764] = 2,
    ACTIONS(20064), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332775] = 2,
    ACTIONS(20066), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332786] = 2,
    ACTIONS(20068), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332797] = 2,
    ACTIONS(20070), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332808] = 2,
    ACTIONS(20072), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332819] = 2,
    ACTIONS(20074), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332830] = 2,
    ACTIONS(20076), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332841] = 2,
    ACTIONS(20078), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332852] = 2,
    ACTIONS(20080), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332863] = 2,
    ACTIONS(20082), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332874] = 2,
    ACTIONS(20084), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332885] = 2,
    ACTIONS(20086), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332896] = 2,
    ACTIONS(20088), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332907] = 2,
    ACTIONS(20090), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332918] = 2,
    ACTIONS(20092), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332929] = 2,
    ACTIONS(20094), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332940] = 2,
    ACTIONS(20096), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332951] = 2,
    ACTIONS(20098), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332962] = 2,
    ACTIONS(20100), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332973] = 2,
    ACTIONS(20102), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332984] = 2,
    ACTIONS(20104), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [332995] = 2,
    ACTIONS(20106), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333006] = 2,
    ACTIONS(20108), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333017] = 2,
    ACTIONS(20110), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333028] = 2,
    ACTIONS(20112), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333039] = 2,
    ACTIONS(20114), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333050] = 2,
    ACTIONS(20116), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333061] = 2,
    ACTIONS(20118), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333072] = 2,
    ACTIONS(20120), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333083] = 2,
    ACTIONS(20122), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333094] = 2,
    ACTIONS(20124), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333105] = 2,
    ACTIONS(20126), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333116] = 2,
    ACTIONS(20128), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333127] = 2,
    ACTIONS(20130), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333138] = 2,
    ACTIONS(20132), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333149] = 2,
    ACTIONS(20134), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333160] = 2,
    ACTIONS(20136), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333171] = 2,
    ACTIONS(20138), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333182] = 2,
    ACTIONS(20140), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333193] = 2,
    ACTIONS(20142), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333204] = 2,
    ACTIONS(20144), 1,
      sym_customizes_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333215] = 2,
    ACTIONS(20146), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333226] = 2,
    ACTIONS(20148), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333237] = 2,
    ACTIONS(20150), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333248] = 2,
    ACTIONS(20152), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333259] = 2,
    ACTIONS(20154), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333270] = 2,
    ACTIONS(20156), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333281] = 2,
    ACTIONS(20158), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333292] = 2,
    ACTIONS(20160), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333303] = 2,
    ACTIONS(20162), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333314] = 2,
    ACTIONS(20164), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333325] = 2,
    ACTIONS(20166), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333336] = 2,
    ACTIONS(20168), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333347] = 2,
    ACTIONS(20170), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333358] = 2,
    ACTIONS(20172), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333369] = 2,
    ACTIONS(20174), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333380] = 2,
    ACTIONS(17158), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333391] = 2,
    ACTIONS(20176), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333402] = 2,
    ACTIONS(20178), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333413] = 2,
    ACTIONS(20180), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333424] = 2,
    ACTIONS(20182), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333435] = 2,
    ACTIONS(20184), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333446] = 2,
    ACTIONS(20186), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333457] = 2,
    ACTIONS(20188), 1,
      aux_sym_preproc_split_procedure_body_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333468] = 2,
    ACTIONS(13287), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333479] = 2,
    ACTIONS(17132), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333490] = 2,
    ACTIONS(20190), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333501] = 2,
    ACTIONS(20192), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333512] = 2,
    ACTIONS(20194), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333523] = 2,
    ACTIONS(20196), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333534] = 2,
    ACTIONS(20198), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333545] = 2,
    ACTIONS(20200), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333556] = 2,
    ACTIONS(20202), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333567] = 2,
    ACTIONS(20204), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333578] = 2,
    ACTIONS(20206), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333589] = 2,
    ACTIONS(20208), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333600] = 2,
    ACTIONS(17150), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333611] = 2,
    ACTIONS(17152), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333622] = 2,
    ACTIONS(20210), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333633] = 2,
    ACTIONS(20212), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333644] = 2,
    ACTIONS(20214), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333655] = 2,
    ACTIONS(20216), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333666] = 2,
    ACTIONS(20218), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333677] = 2,
    ACTIONS(20220), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333688] = 2,
    ACTIONS(20222), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333699] = 2,
    ACTIONS(20224), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333710] = 2,
    ACTIONS(20226), 1,
      sym_procedure_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333721] = 2,
    ACTIONS(20228), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333732] = 2,
    ACTIONS(20230), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333743] = 2,
    ACTIONS(20232), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333754] = 2,
    ACTIONS(20234), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333765] = 2,
    ACTIONS(20236), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333776] = 2,
    ACTIONS(20238), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333787] = 2,
    ACTIONS(20240), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333798] = 2,
    ACTIONS(20242), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333809] = 2,
    ACTIONS(20244), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333820] = 2,
    ACTIONS(20246), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333831] = 2,
    ACTIONS(20248), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333842] = 2,
    ACTIONS(20250), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333853] = 2,
    ACTIONS(20252), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333864] = 2,
    ACTIONS(20254), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333875] = 2,
    ACTIONS(20256), 1,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333886] = 2,
    ACTIONS(20258), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333897] = 2,
    ACTIONS(20260), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333908] = 2,
    ACTIONS(20262), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333919] = 2,
    ACTIONS(20264), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333930] = 2,
    ACTIONS(20266), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333941] = 2,
    ACTIONS(20268), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333952] = 2,
    ACTIONS(20270), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333963] = 2,
    ACTIONS(20272), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333974] = 2,
    ACTIONS(20274), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333985] = 2,
    ACTIONS(20276), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [333996] = 2,
    ACTIONS(20278), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334007] = 2,
    ACTIONS(20280), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334018] = 2,
    ACTIONS(20282), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334029] = 2,
    ACTIONS(20284), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334040] = 2,
    ACTIONS(20286), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334051] = 2,
    ACTIONS(20288), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334062] = 2,
    ACTIONS(20290), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334073] = 2,
    ACTIONS(20292), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334084] = 2,
    ACTIONS(20294), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334095] = 2,
    ACTIONS(20296), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334106] = 2,
    ACTIONS(20298), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334117] = 2,
    ACTIONS(20300), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334128] = 2,
    ACTIONS(20302), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334139] = 2,
    ACTIONS(20304), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334150] = 2,
    ACTIONS(20306), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334161] = 2,
    ACTIONS(20308), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334172] = 2,
    ACTIONS(20310), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334183] = 2,
    ACTIONS(20312), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334194] = 2,
    ACTIONS(20314), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334205] = 2,
    ACTIONS(20316), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334216] = 2,
    ACTIONS(20318), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334227] = 2,
    ACTIONS(20320), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334238] = 2,
    ACTIONS(20322), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334249] = 2,
    ACTIONS(20324), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334260] = 2,
    ACTIONS(20326), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334271] = 2,
    ACTIONS(20328), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334282] = 2,
    ACTIONS(20330), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334293] = 2,
    ACTIONS(20332), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334304] = 2,
    ACTIONS(20334), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334315] = 2,
    ACTIONS(20336), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334326] = 2,
    ACTIONS(20338), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334337] = 2,
    ACTIONS(20340), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334348] = 2,
    ACTIONS(20342), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334359] = 2,
    ACTIONS(20344), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334370] = 2,
    ACTIONS(20346), 1,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334381] = 2,
    ACTIONS(20348), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334392] = 2,
    ACTIONS(20350), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334403] = 2,
    ACTIONS(20352), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334414] = 2,
    ACTIONS(20354), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334425] = 2,
    ACTIONS(20356), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334436] = 2,
    ACTIONS(20358), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334447] = 2,
    ACTIONS(20360), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334458] = 2,
    ACTIONS(20362), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334469] = 2,
    ACTIONS(20364), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334480] = 2,
    ACTIONS(20366), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334491] = 2,
    ACTIONS(20368), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334502] = 2,
    ACTIONS(20370), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334513] = 2,
    ACTIONS(20372), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334524] = 2,
    ACTIONS(20374), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334535] = 2,
    ACTIONS(20376), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334546] = 2,
    ACTIONS(20378), 1,
      anon_sym_COLON,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334557] = 2,
    ACTIONS(20380), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334568] = 2,
    ACTIONS(20382), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334579] = 2,
    ACTIONS(20384), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334590] = 2,
    ACTIONS(20386), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334601] = 2,
    ACTIONS(20388), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334612] = 2,
    ACTIONS(20390), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334623] = 2,
    ACTIONS(20392), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334634] = 2,
    ACTIONS(20394), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334645] = 2,
    ACTIONS(20396), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334656] = 2,
    ACTIONS(20398), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334667] = 2,
    ACTIONS(20400), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334678] = 2,
    ACTIONS(20402), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334689] = 2,
    ACTIONS(20404), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334700] = 2,
    ACTIONS(17290), 1,
      aux_sym_preproc_split_procedure_body_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334711] = 2,
    ACTIONS(20406), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334722] = 2,
    ACTIONS(20408), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334733] = 2,
    ACTIONS(20410), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334744] = 2,
    ACTIONS(20412), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334755] = 2,
    ACTIONS(20414), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334766] = 2,
    ACTIONS(20416), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334777] = 2,
    ACTIONS(20418), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334788] = 2,
    ACTIONS(20420), 1,
      aux_sym_preproc_split_procedure_body_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334799] = 2,
    ACTIONS(20422), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334810] = 2,
    ACTIONS(20424), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334821] = 2,
    ACTIONS(20426), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334832] = 2,
    ACTIONS(20428), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334843] = 2,
    ACTIONS(20430), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334854] = 2,
    ACTIONS(20432), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334865] = 2,
    ACTIONS(20434), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334876] = 2,
    ACTIONS(20436), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334887] = 2,
    ACTIONS(20438), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334898] = 2,
    ACTIONS(20440), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334909] = 2,
    ACTIONS(20442), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334920] = 2,
    ACTIONS(20444), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334931] = 2,
    ACTIONS(20446), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334942] = 2,
    ACTIONS(20448), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334953] = 2,
    ACTIONS(20450), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334964] = 2,
    ACTIONS(20452), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334975] = 2,
    ACTIONS(20454), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334986] = 2,
    ACTIONS(20456), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [334997] = 2,
    ACTIONS(20458), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335008] = 2,
    ACTIONS(20460), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335019] = 2,
    ACTIONS(20462), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335030] = 2,
    ACTIONS(20464), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335041] = 2,
    ACTIONS(20466), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335052] = 2,
    ACTIONS(20468), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335063] = 2,
    ACTIONS(20470), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335074] = 2,
    ACTIONS(20472), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335085] = 2,
    ACTIONS(20474), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335096] = 2,
    ACTIONS(20476), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335107] = 2,
    ACTIONS(20478), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335118] = 2,
    ACTIONS(20480), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335129] = 2,
    ACTIONS(20482), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335140] = 2,
    ACTIONS(20484), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335151] = 2,
    ACTIONS(20486), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335162] = 2,
    ACTIONS(20488), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335173] = 2,
    ACTIONS(20490), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335184] = 2,
    ACTIONS(20492), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335195] = 2,
    ACTIONS(20494), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335206] = 2,
    ACTIONS(20496), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335217] = 2,
    ACTIONS(20498), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335228] = 2,
    ACTIONS(20500), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335239] = 2,
    ACTIONS(20502), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335250] = 2,
    ACTIONS(20504), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335261] = 2,
    ACTIONS(20506), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335272] = 2,
    ACTIONS(20508), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335283] = 2,
    ACTIONS(20510), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335294] = 2,
    ACTIONS(20512), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335305] = 2,
    ACTIONS(20434), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335316] = 2,
    ACTIONS(17126), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335327] = 2,
    ACTIONS(20514), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335338] = 2,
    ACTIONS(20516), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335349] = 2,
    ACTIONS(20518), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335360] = 2,
    ACTIONS(20520), 1,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335371] = 2,
    ACTIONS(20522), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335382] = 2,
    ACTIONS(20524), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335393] = 2,
    ACTIONS(20526), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335404] = 2,
    ACTIONS(20528), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335415] = 2,
    ACTIONS(20530), 1,
      sym_permission_type,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335426] = 2,
    ACTIONS(20532), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335437] = 2,
    ACTIONS(20534), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335448] = 2,
    ACTIONS(20536), 1,
      aux_sym_preproc_split_procedure_body_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335459] = 2,
    ACTIONS(20538), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335470] = 2,
    ACTIONS(20540), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335481] = 2,
    ACTIONS(20542), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335492] = 2,
    ACTIONS(20544), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335503] = 2,
    ACTIONS(20546), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335514] = 2,
    ACTIONS(20548), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335525] = 2,
    ACTIONS(20550), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335536] = 2,
    ACTIONS(20552), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335547] = 2,
    ACTIONS(20554), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335558] = 2,
    ACTIONS(20556), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335569] = 2,
    ACTIONS(20558), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335580] = 2,
    ACTIONS(20560), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335591] = 2,
    ACTIONS(20562), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335602] = 2,
    ACTIONS(20564), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335613] = 2,
    ACTIONS(20566), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335624] = 2,
    ACTIONS(20568), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335635] = 2,
    ACTIONS(20570), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335646] = 2,
    ACTIONS(20572), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335657] = 2,
    ACTIONS(20574), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335668] = 2,
    ACTIONS(20576), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335679] = 2,
    ACTIONS(20578), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335690] = 2,
    ACTIONS(20580), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335701] = 2,
    ACTIONS(20582), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335712] = 2,
    ACTIONS(20584), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335723] = 2,
    ACTIONS(20586), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335734] = 2,
    ACTIONS(20588), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335745] = 2,
    ACTIONS(20590), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335756] = 2,
    ACTIONS(20592), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335767] = 2,
    ACTIONS(20594), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335778] = 2,
    ACTIONS(20596), 1,
      sym_procedure_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335789] = 2,
    ACTIONS(20598), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335800] = 2,
    ACTIONS(20600), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335811] = 2,
    ACTIONS(20602), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335822] = 2,
    ACTIONS(20604), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335833] = 2,
    ACTIONS(20606), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335844] = 2,
    ACTIONS(20608), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335855] = 2,
    ACTIONS(20610), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335866] = 2,
    ACTIONS(20612), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335877] = 2,
    ACTIONS(20614), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335888] = 2,
    ACTIONS(20616), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335899] = 2,
    ACTIONS(20618), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335910] = 2,
    ACTIONS(20620), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335921] = 2,
    ACTIONS(20622), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335932] = 2,
    ACTIONS(20624), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335943] = 2,
    ACTIONS(20626), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335954] = 2,
    ACTIONS(20628), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335965] = 2,
    ACTIONS(20630), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335976] = 2,
    ACTIONS(20632), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335987] = 2,
    ACTIONS(20634), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [335998] = 2,
    ACTIONS(20636), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336009] = 2,
    ACTIONS(20638), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336020] = 2,
    ACTIONS(20640), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336031] = 2,
    ACTIONS(20642), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336042] = 2,
    ACTIONS(20644), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336053] = 2,
    ACTIONS(20646), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336064] = 2,
    ACTIONS(20648), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336075] = 2,
    ACTIONS(20650), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336086] = 2,
    ACTIONS(20652), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336097] = 2,
    ACTIONS(20654), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336108] = 2,
    ACTIONS(20656), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336119] = 2,
    ACTIONS(20658), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336130] = 2,
    ACTIONS(20660), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336141] = 2,
    ACTIONS(20662), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336152] = 2,
    ACTIONS(20664), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336163] = 2,
    ACTIONS(20666), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336174] = 2,
    ACTIONS(20668), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336185] = 2,
    ACTIONS(20670), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336196] = 2,
    ACTIONS(20672), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336207] = 2,
    ACTIONS(20674), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336218] = 2,
    ACTIONS(20676), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336229] = 2,
    ACTIONS(20678), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336240] = 2,
    ACTIONS(20680), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336251] = 2,
    ACTIONS(20682), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336262] = 2,
    ACTIONS(18187), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336273] = 2,
    ACTIONS(20684), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336284] = 2,
    ACTIONS(20686), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336295] = 2,
    ACTIONS(20688), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336306] = 2,
    ACTIONS(20690), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336317] = 2,
    ACTIONS(20692), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336328] = 2,
    ACTIONS(20694), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336339] = 2,
    ACTIONS(20696), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336350] = 2,
    ACTIONS(20698), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336361] = 2,
    ACTIONS(20700), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336372] = 2,
    ACTIONS(20702), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336383] = 2,
    ACTIONS(20704), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336394] = 2,
    ACTIONS(20706), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336405] = 2,
    ACTIONS(20708), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336416] = 2,
    ACTIONS(20710), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336427] = 2,
    ACTIONS(20712), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336438] = 2,
    ACTIONS(20714), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336449] = 2,
    ACTIONS(20716), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336460] = 2,
    ACTIONS(20718), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336471] = 2,
    ACTIONS(20720), 1,
      sym_customizes_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336482] = 2,
    ACTIONS(20722), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336493] = 2,
    ACTIONS(20724), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336504] = 2,
    ACTIONS(20726), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336515] = 2,
    ACTIONS(20728), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336526] = 2,
    ACTIONS(20730), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336537] = 2,
    ACTIONS(13318), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336548] = 2,
    ACTIONS(20732), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336559] = 2,
    ACTIONS(20734), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336570] = 2,
    ACTIONS(20736), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336581] = 2,
    ACTIONS(20738), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336592] = 2,
    ACTIONS(20740), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336603] = 2,
    ACTIONS(20742), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336614] = 2,
    ACTIONS(20744), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336625] = 2,
    ACTIONS(20746), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336636] = 2,
    ACTIONS(20748), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336647] = 2,
    ACTIONS(20750), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336658] = 2,
    ACTIONS(20752), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336669] = 2,
    ACTIONS(20754), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336680] = 2,
    ACTIONS(20756), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336691] = 2,
    ACTIONS(20758), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336702] = 2,
    ACTIONS(20760), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336713] = 2,
    ACTIONS(13312), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336724] = 2,
    ACTIONS(20762), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336735] = 2,
    ACTIONS(20764), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336746] = 2,
    ACTIONS(20766), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336757] = 2,
    ACTIONS(20768), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336768] = 2,
    ACTIONS(20770), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336779] = 2,
    ACTIONS(13794), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336790] = 2,
    ACTIONS(20772), 1,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336801] = 2,
    ACTIONS(20774), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336812] = 2,
    ACTIONS(20776), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336823] = 2,
    ACTIONS(20778), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336834] = 2,
    ACTIONS(20780), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336845] = 2,
    ACTIONS(20782), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336856] = 2,
    ACTIONS(20784), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336867] = 2,
    ACTIONS(20786), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336878] = 2,
    ACTIONS(20788), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336889] = 2,
    ACTIONS(20790), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336900] = 2,
    ACTIONS(20792), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336911] = 2,
    ACTIONS(20794), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336922] = 2,
    ACTIONS(20796), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336933] = 2,
    ACTIONS(20798), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336944] = 2,
    ACTIONS(20800), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336955] = 2,
    ACTIONS(20802), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336966] = 2,
    ACTIONS(20804), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336977] = 2,
    ACTIONS(20806), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336988] = 2,
    ACTIONS(20808), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [336999] = 2,
    ACTIONS(20810), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337010] = 2,
    ACTIONS(20812), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337021] = 2,
    ACTIONS(20814), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337032] = 2,
    ACTIONS(20816), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337043] = 2,
    ACTIONS(20818), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337054] = 2,
    ACTIONS(20820), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337065] = 2,
    ACTIONS(14533), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337076] = 2,
    ACTIONS(20822), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337087] = 2,
    ACTIONS(20824), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337098] = 2,
    ACTIONS(20826), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337109] = 2,
    ACTIONS(20828), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337120] = 2,
    ACTIONS(20830), 1,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337131] = 2,
    ACTIONS(20832), 1,
      aux_sym_preproc_split_procedure_body_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337142] = 2,
    ACTIONS(20834), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337153] = 2,
    ACTIONS(20836), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337164] = 2,
    ACTIONS(20838), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337175] = 2,
    ACTIONS(20840), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337186] = 2,
    ACTIONS(20842), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337197] = 2,
    ACTIONS(20844), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337208] = 2,
    ACTIONS(20846), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337219] = 2,
    ACTIONS(20848), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337230] = 2,
    ACTIONS(20850), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337241] = 2,
    ACTIONS(20852), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337252] = 2,
    ACTIONS(20854), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337263] = 2,
    ACTIONS(20856), 1,
      sym_procedure_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337274] = 2,
    ACTIONS(20858), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337285] = 2,
    ACTIONS(20860), 1,
      sym_procedure_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337296] = 2,
    ACTIONS(17116), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337307] = 2,
    ACTIONS(20862), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337318] = 2,
    ACTIONS(20864), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337329] = 2,
    ACTIONS(20866), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337340] = 2,
    ACTIONS(20868), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337351] = 2,
    ACTIONS(20870), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337362] = 2,
    ACTIONS(20872), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337373] = 2,
    ACTIONS(20874), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337384] = 2,
    ACTIONS(20876), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337395] = 2,
    ACTIONS(20878), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337406] = 2,
    ACTIONS(20880), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337417] = 2,
    ACTIONS(20882), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337428] = 2,
    ACTIONS(20884), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337439] = 2,
    ACTIONS(20886), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337450] = 2,
    ACTIONS(20888), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337461] = 2,
    ACTIONS(20890), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337472] = 2,
    ACTIONS(20892), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337483] = 2,
    ACTIONS(20894), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337494] = 2,
    ACTIONS(20896), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337505] = 2,
    ACTIONS(20898), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337516] = 2,
    ACTIONS(20900), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337527] = 2,
    ACTIONS(20902), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337538] = 2,
    ACTIONS(20904), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337549] = 2,
    ACTIONS(20906), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337560] = 2,
    ACTIONS(20908), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337571] = 2,
    ACTIONS(20910), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337582] = 2,
    ACTIONS(20912), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337593] = 2,
    ACTIONS(20914), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337604] = 2,
    ACTIONS(20916), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337615] = 2,
    ACTIONS(20918), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337626] = 2,
    ACTIONS(20920), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337637] = 2,
    ACTIONS(20922), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337648] = 2,
    ACTIONS(20924), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337659] = 2,
    ACTIONS(20926), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337670] = 2,
    ACTIONS(20928), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337681] = 2,
    ACTIONS(20930), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337692] = 2,
    ACTIONS(20932), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337703] = 2,
    ACTIONS(20934), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337714] = 2,
    ACTIONS(20936), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337725] = 2,
    ACTIONS(20938), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337736] = 2,
    ACTIONS(20940), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337747] = 2,
    ACTIONS(20942), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337758] = 2,
    ACTIONS(20944), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337769] = 2,
    ACTIONS(20946), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337780] = 2,
    ACTIONS(20948), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337791] = 2,
    ACTIONS(20950), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337802] = 2,
    ACTIONS(20952), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337813] = 2,
    ACTIONS(20954), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337824] = 2,
    ACTIONS(20956), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337835] = 2,
    ACTIONS(20958), 1,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337846] = 2,
    ACTIONS(20960), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337857] = 2,
    ACTIONS(20962), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337868] = 2,
    ACTIONS(20964), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337879] = 2,
    ACTIONS(20966), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337890] = 2,
    ACTIONS(20968), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337901] = 2,
    ACTIONS(20970), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337912] = 2,
    ACTIONS(20972), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337923] = 2,
    ACTIONS(20974), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337934] = 2,
    ACTIONS(20976), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337945] = 2,
    ACTIONS(20978), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337956] = 2,
    ACTIONS(20980), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337967] = 2,
    ACTIONS(20982), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337978] = 2,
    ACTIONS(20984), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [337989] = 2,
    ACTIONS(20986), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338000] = 2,
    ACTIONS(20988), 1,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338011] = 2,
    ACTIONS(20990), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338022] = 2,
    ACTIONS(20992), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338033] = 2,
    ACTIONS(20994), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338044] = 2,
    ACTIONS(20996), 1,
      sym_procedure_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338055] = 2,
    ACTIONS(20998), 1,
      sym_procedure_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338066] = 2,
    ACTIONS(21000), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338077] = 2,
    ACTIONS(21002), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338088] = 2,
    ACTIONS(21004), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338099] = 2,
    ACTIONS(21006), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338110] = 2,
    ACTIONS(21008), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338121] = 2,
    ACTIONS(21010), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338132] = 2,
    ACTIONS(21012), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338143] = 2,
    ACTIONS(21014), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338154] = 2,
    ACTIONS(21016), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338165] = 2,
    ACTIONS(21018), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338176] = 2,
    ACTIONS(21020), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338187] = 2,
    ACTIONS(21022), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338198] = 2,
    ACTIONS(21024), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338209] = 2,
    ACTIONS(21026), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338220] = 2,
    ACTIONS(21028), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338231] = 2,
    ACTIONS(21030), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338242] = 2,
    ACTIONS(21032), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338253] = 2,
    ACTIONS(21034), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338264] = 2,
    ACTIONS(21036), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338275] = 2,
    ACTIONS(21038), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338286] = 2,
    ACTIONS(21040), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338297] = 2,
    ACTIONS(21042), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338308] = 2,
    ACTIONS(21044), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338319] = 2,
    ACTIONS(21046), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338330] = 2,
    ACTIONS(21048), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338341] = 2,
    ACTIONS(21050), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338352] = 2,
    ACTIONS(21052), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338363] = 2,
    ACTIONS(21054), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338374] = 2,
    ACTIONS(21056), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338385] = 2,
    ACTIONS(21058), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338396] = 2,
    ACTIONS(21060), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338407] = 2,
    ACTIONS(21062), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338418] = 2,
    ACTIONS(21064), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338429] = 2,
    ACTIONS(21066), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338440] = 2,
    ACTIONS(21068), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338451] = 2,
    ACTIONS(21070), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338462] = 2,
    ACTIONS(21072), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338473] = 2,
    ACTIONS(18698), 1,
      sym_procedure_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338484] = 2,
    ACTIONS(21074), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338495] = 2,
    ACTIONS(21076), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338506] = 2,
    ACTIONS(21078), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338517] = 2,
    ACTIONS(21080), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338528] = 2,
    ACTIONS(21082), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338539] = 2,
    ACTIONS(13327), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338550] = 2,
    ACTIONS(21084), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338561] = 2,
    ACTIONS(21086), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338572] = 2,
    ACTIONS(21088), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338583] = 2,
    ACTIONS(21090), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338594] = 2,
    ACTIONS(21092), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338605] = 2,
    ACTIONS(21094), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338616] = 2,
    ACTIONS(21096), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338627] = 2,
    ACTIONS(21098), 1,
      sym_procedure_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338638] = 2,
    ACTIONS(21100), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338649] = 2,
    ACTIONS(21102), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338660] = 2,
    ACTIONS(21104), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338671] = 2,
    ACTIONS(21106), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338682] = 2,
    ACTIONS(21108), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338693] = 2,
    ACTIONS(21110), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338704] = 2,
    ACTIONS(21112), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338715] = 2,
    ACTIONS(21114), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338726] = 2,
    ACTIONS(21116), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338737] = 2,
    ACTIONS(21118), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338748] = 2,
    ACTIONS(21120), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338759] = 2,
    ACTIONS(21122), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338770] = 2,
    ACTIONS(21124), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338781] = 2,
    ACTIONS(21126), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338792] = 2,
    ACTIONS(21128), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338803] = 2,
    ACTIONS(21130), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338814] = 2,
    ACTIONS(21132), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338825] = 2,
    ACTIONS(21134), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338836] = 2,
    ACTIONS(21136), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338847] = 2,
    ACTIONS(21138), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338858] = 2,
    ACTIONS(21140), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338869] = 2,
    ACTIONS(21142), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338880] = 2,
    ACTIONS(21144), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338891] = 2,
    ACTIONS(21146), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338902] = 2,
    ACTIONS(21148), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338913] = 2,
    ACTIONS(21150), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338924] = 2,
    ACTIONS(21152), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338935] = 2,
    ACTIONS(21154), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338946] = 2,
    ACTIONS(21156), 1,
      sym_var_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338957] = 2,
    ACTIONS(21158), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338968] = 2,
    ACTIONS(21160), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338979] = 2,
    ACTIONS(21162), 1,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [338990] = 2,
    ACTIONS(21164), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339001] = 2,
    ACTIONS(21166), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339012] = 2,
    ACTIONS(21168), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339023] = 2,
    ACTIONS(21170), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339034] = 2,
    ACTIONS(21172), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339045] = 2,
    ACTIONS(21174), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339056] = 2,
    ACTIONS(21176), 1,
      sym_procedure_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339067] = 2,
    ACTIONS(21178), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339078] = 2,
    ACTIONS(21180), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339089] = 2,
    ACTIONS(21182), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339100] = 2,
    ACTIONS(21184), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339111] = 2,
    ACTIONS(21186), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339122] = 2,
    ACTIONS(21188), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339133] = 2,
    ACTIONS(21190), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339144] = 2,
    ACTIONS(21192), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339155] = 2,
    ACTIONS(21194), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339166] = 2,
    ACTIONS(21196), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339177] = 2,
    ACTIONS(21198), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339188] = 2,
    ACTIONS(21200), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339199] = 2,
    ACTIONS(21202), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339210] = 2,
    ACTIONS(21204), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339221] = 2,
    ACTIONS(21206), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339232] = 2,
    ACTIONS(21208), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339243] = 2,
    ACTIONS(21210), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339254] = 2,
    ACTIONS(21212), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339265] = 2,
    ACTIONS(21214), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339276] = 2,
    ACTIONS(21216), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339287] = 2,
    ACTIONS(21218), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339298] = 2,
    ACTIONS(21220), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339309] = 2,
    ACTIONS(21222), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339320] = 2,
    ACTIONS(21224), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339331] = 2,
    ACTIONS(21226), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339342] = 2,
    ACTIONS(17120), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339353] = 2,
    ACTIONS(21228), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339364] = 2,
    ACTIONS(21230), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339375] = 2,
    ACTIONS(21232), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339386] = 2,
    ACTIONS(21234), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339397] = 2,
    ACTIONS(21236), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339408] = 2,
    ACTIONS(21238), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339419] = 2,
    ACTIONS(21240), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339430] = 2,
    ACTIONS(21242), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339441] = 2,
    ACTIONS(21244), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339452] = 2,
    ACTIONS(21246), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339463] = 2,
    ACTIONS(21248), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339474] = 2,
    ACTIONS(21250), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339485] = 2,
    ACTIONS(21252), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339496] = 2,
    ACTIONS(21254), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339507] = 2,
    ACTIONS(21256), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339518] = 2,
    ACTIONS(21258), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339529] = 2,
    ACTIONS(21260), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339540] = 2,
    ACTIONS(21262), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339551] = 2,
    ACTIONS(21264), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339562] = 2,
    ACTIONS(21266), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339573] = 2,
    ACTIONS(21268), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339584] = 2,
    ACTIONS(21270), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339595] = 2,
    ACTIONS(21272), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339606] = 2,
    ACTIONS(21274), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339617] = 2,
    ACTIONS(21276), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339628] = 2,
    ACTIONS(21278), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339639] = 2,
    ACTIONS(21280), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339650] = 2,
    ACTIONS(21282), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339661] = 2,
    ACTIONS(21284), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339672] = 2,
    ACTIONS(21286), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339683] = 2,
    ACTIONS(21288), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339694] = 2,
    ACTIONS(21290), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339705] = 2,
    ACTIONS(21292), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339716] = 2,
    ACTIONS(21294), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339727] = 2,
    ACTIONS(21296), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339738] = 2,
    ACTIONS(21298), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339749] = 2,
    ACTIONS(21300), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339760] = 2,
    ACTIONS(21302), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339771] = 2,
    ACTIONS(21304), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339782] = 2,
    ACTIONS(21306), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339793] = 2,
    ACTIONS(21308), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339804] = 2,
    ACTIONS(21310), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339815] = 2,
    ACTIONS(21312), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339826] = 2,
    ACTIONS(21314), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339837] = 2,
    ACTIONS(21316), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339848] = 2,
    ACTIONS(21318), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339859] = 2,
    ACTIONS(21320), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339870] = 2,
    ACTIONS(21322), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339881] = 2,
    ACTIONS(21324), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339892] = 2,
    ACTIONS(21326), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339903] = 2,
    ACTIONS(21328), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339914] = 2,
    ACTIONS(21330), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339925] = 2,
    ACTIONS(21332), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339936] = 2,
    ACTIONS(21334), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339947] = 2,
    ACTIONS(21336), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339958] = 2,
    ACTIONS(21338), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339969] = 2,
    ACTIONS(21340), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339980] = 2,
    ACTIONS(21342), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [339991] = 2,
    ACTIONS(21344), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340002] = 2,
    ACTIONS(21346), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340013] = 2,
    ACTIONS(21348), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340024] = 2,
    ACTIONS(21350), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340035] = 2,
    ACTIONS(21352), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340046] = 2,
    ACTIONS(21354), 1,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340057] = 2,
    ACTIONS(21356), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340068] = 2,
    ACTIONS(21358), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340079] = 2,
    ACTIONS(21360), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340090] = 2,
    ACTIONS(21362), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340101] = 2,
    ACTIONS(21364), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340112] = 2,
    ACTIONS(21366), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340123] = 2,
    ACTIONS(21368), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340134] = 2,
    ACTIONS(21370), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340145] = 2,
    ACTIONS(21372), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340156] = 2,
    ACTIONS(21374), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340167] = 2,
    ACTIONS(21376), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340178] = 2,
    ACTIONS(21378), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340189] = 2,
    ACTIONS(21380), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340200] = 2,
    ACTIONS(21382), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340211] = 2,
    ACTIONS(21384), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340222] = 2,
    ACTIONS(21386), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340233] = 2,
    ACTIONS(21388), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340244] = 2,
    ACTIONS(21390), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340255] = 2,
    ACTIONS(21392), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340266] = 2,
    ACTIONS(21394), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340277] = 2,
    ACTIONS(21396), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340288] = 2,
    ACTIONS(21398), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340299] = 2,
    ACTIONS(21400), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340310] = 2,
    ACTIONS(21402), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340321] = 2,
    ACTIONS(21404), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340332] = 2,
    ACTIONS(21406), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340343] = 2,
    ACTIONS(21408), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340354] = 2,
    ACTIONS(21410), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340365] = 2,
    ACTIONS(21412), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340376] = 2,
    ACTIONS(21414), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340387] = 2,
    ACTIONS(21416), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340398] = 2,
    ACTIONS(21418), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340409] = 2,
    ACTIONS(21420), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340420] = 2,
    ACTIONS(21422), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340431] = 2,
    ACTIONS(21424), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340442] = 2,
    ACTIONS(21426), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340453] = 2,
    ACTIONS(21428), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340464] = 2,
    ACTIONS(21430), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340475] = 2,
    ACTIONS(21432), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340486] = 2,
    ACTIONS(21434), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340497] = 2,
    ACTIONS(21436), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340508] = 2,
    ACTIONS(21438), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340519] = 2,
    ACTIONS(21440), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340530] = 2,
    ACTIONS(21442), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340541] = 2,
    ACTIONS(21444), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340552] = 2,
    ACTIONS(21446), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340563] = 2,
    ACTIONS(21448), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340574] = 2,
    ACTIONS(21450), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340585] = 2,
    ACTIONS(21452), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340596] = 2,
    ACTIONS(21454), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340607] = 2,
    ACTIONS(21456), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340618] = 2,
    ACTIONS(21458), 1,
      sym_procedure_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340629] = 2,
    ACTIONS(12346), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340640] = 2,
    ACTIONS(21460), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340651] = 2,
    ACTIONS(21462), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340662] = 2,
    ACTIONS(21464), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340673] = 2,
    ACTIONS(21466), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340684] = 2,
    ACTIONS(21468), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340695] = 2,
    ACTIONS(21470), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340706] = 2,
    ACTIONS(21472), 1,
      aux_sym_preproc_split_procedure_body_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340717] = 2,
    ACTIONS(21474), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340728] = 2,
    ACTIONS(21476), 1,
      sym_extends_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340739] = 2,
    ACTIONS(21478), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340750] = 2,
    ACTIONS(21480), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340761] = 2,
    ACTIONS(21482), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340772] = 2,
    ACTIONS(21484), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340783] = 2,
    ACTIONS(21486), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340794] = 2,
    ACTIONS(21488), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340805] = 2,
    ACTIONS(21490), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340816] = 2,
    ACTIONS(21492), 1,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340827] = 2,
    ACTIONS(21494), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340838] = 2,
    ACTIONS(21496), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340849] = 2,
    ACTIONS(21498), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340860] = 2,
    ACTIONS(21500), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340871] = 2,
    ACTIONS(21502), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340882] = 2,
    ACTIONS(21504), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340893] = 2,
    ACTIONS(21506), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340904] = 2,
    ACTIONS(21508), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340915] = 2,
    ACTIONS(21510), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340926] = 2,
    ACTIONS(21512), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340937] = 2,
    ACTIONS(21514), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340948] = 2,
    ACTIONS(21516), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340959] = 2,
    ACTIONS(17082), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340970] = 2,
    ACTIONS(21518), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340981] = 2,
    ACTIONS(21520), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [340992] = 2,
    ACTIONS(17164), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341003] = 2,
    ACTIONS(21522), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341014] = 2,
    ACTIONS(21524), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341025] = 2,
    ACTIONS(17182), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341036] = 2,
    ACTIONS(21526), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341047] = 2,
    ACTIONS(21528), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341058] = 2,
    ACTIONS(17092), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341069] = 2,
    ACTIONS(21530), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341080] = 2,
    ACTIONS(21532), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341091] = 2,
    ACTIONS(21534), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341102] = 2,
    ACTIONS(21536), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341113] = 2,
    ACTIONS(21538), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341124] = 2,
    ACTIONS(21540), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341135] = 2,
    ACTIONS(21542), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341146] = 2,
    ACTIONS(21544), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341157] = 2,
    ACTIONS(21546), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341168] = 2,
    ACTIONS(21548), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341179] = 2,
    ACTIONS(21550), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341190] = 2,
    ACTIONS(21552), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341201] = 2,
    ACTIONS(17128), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341212] = 2,
    ACTIONS(21554), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341223] = 2,
    ACTIONS(21556), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341234] = 2,
    ACTIONS(21558), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341245] = 2,
    ACTIONS(21560), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341256] = 2,
    ACTIONS(21562), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341267] = 2,
    ACTIONS(21564), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341278] = 2,
    ACTIONS(21566), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341289] = 2,
    ACTIONS(21568), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341300] = 2,
    ACTIONS(21570), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341311] = 2,
    ACTIONS(21572), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341322] = 2,
    ACTIONS(21574), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341333] = 2,
    ACTIONS(21576), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341344] = 2,
    ACTIONS(21578), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341355] = 2,
    ACTIONS(21580), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341366] = 2,
    ACTIONS(21582), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341377] = 2,
    ACTIONS(21584), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341388] = 2,
    ACTIONS(21586), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341399] = 2,
    ACTIONS(21588), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341410] = 2,
    ACTIONS(21590), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341421] = 2,
    ACTIONS(21592), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341432] = 2,
    ACTIONS(21594), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341443] = 2,
    ACTIONS(21596), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341454] = 2,
    ACTIONS(21598), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341465] = 2,
    ACTIONS(21600), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341476] = 2,
    ACTIONS(21602), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341487] = 2,
    ACTIONS(21604), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341498] = 2,
    ACTIONS(21606), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341509] = 2,
    ACTIONS(21608), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341520] = 2,
    ACTIONS(21610), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341531] = 2,
    ACTIONS(21612), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341542] = 2,
    ACTIONS(21614), 1,
      sym_procedure_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341553] = 2,
    ACTIONS(21616), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341564] = 2,
    ACTIONS(21618), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341575] = 2,
    ACTIONS(21620), 1,
      aux_sym_array_type_token2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341586] = 2,
    ACTIONS(21622), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341597] = 2,
    ACTIONS(21624), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341608] = 2,
    ACTIONS(17130), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341619] = 2,
    ACTIONS(21626), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341630] = 2,
    ACTIONS(21628), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341641] = 2,
    ACTIONS(21630), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341652] = 2,
    ACTIONS(21632), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341663] = 2,
    ACTIONS(21634), 1,
      sym_integer,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341674] = 2,
    ACTIONS(21636), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
  [341685] = 2,
    ACTIONS(21638), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(3868)] = 0,
  [SMALL_STATE(3869)] = 125,
  [SMALL_STATE(3870)] = 250,
  [SMALL_STATE(3871)] = 375,
  [SMALL_STATE(3872)] = 500,
  [SMALL_STATE(3873)] = 573,
  [SMALL_STATE(3874)] = 698,
  [SMALL_STATE(3875)] = 823,
  [SMALL_STATE(3876)] = 896,
  [SMALL_STATE(3877)] = 1021,
  [SMALL_STATE(3878)] = 1146,
  [SMALL_STATE(3879)] = 1271,
  [SMALL_STATE(3880)] = 1386,
  [SMALL_STATE(3881)] = 1459,
  [SMALL_STATE(3882)] = 1584,
  [SMALL_STATE(3883)] = 1709,
  [SMALL_STATE(3884)] = 1782,
  [SMALL_STATE(3885)] = 1853,
  [SMALL_STATE(3886)] = 1926,
  [SMALL_STATE(3887)] = 2051,
  [SMALL_STATE(3888)] = 2176,
  [SMALL_STATE(3889)] = 2247,
  [SMALL_STATE(3890)] = 2372,
  [SMALL_STATE(3891)] = 2487,
  [SMALL_STATE(3892)] = 2612,
  [SMALL_STATE(3893)] = 2737,
  [SMALL_STATE(3894)] = 2862,
  [SMALL_STATE(3895)] = 2932,
  [SMALL_STATE(3896)] = 3002,
  [SMALL_STATE(3897)] = 3126,
  [SMALL_STATE(3898)] = 3196,
  [SMALL_STATE(3899)] = 3266,
  [SMALL_STATE(3900)] = 3336,
  [SMALL_STATE(3901)] = 3406,
  [SMALL_STATE(3902)] = 3476,
  [SMALL_STATE(3903)] = 3546,
  [SMALL_STATE(3904)] = 3616,
  [SMALL_STATE(3905)] = 3686,
  [SMALL_STATE(3906)] = 3756,
  [SMALL_STATE(3907)] = 3826,
  [SMALL_STATE(3908)] = 3896,
  [SMALL_STATE(3909)] = 3966,
  [SMALL_STATE(3910)] = 4036,
  [SMALL_STATE(3911)] = 4106,
  [SMALL_STATE(3912)] = 4176,
  [SMALL_STATE(3913)] = 4246,
  [SMALL_STATE(3914)] = 4316,
  [SMALL_STATE(3915)] = 4386,
  [SMALL_STATE(3916)] = 4456,
  [SMALL_STATE(3917)] = 4526,
  [SMALL_STATE(3918)] = 4596,
  [SMALL_STATE(3919)] = 4666,
  [SMALL_STATE(3920)] = 4736,
  [SMALL_STATE(3921)] = 4806,
  [SMALL_STATE(3922)] = 4876,
  [SMALL_STATE(3923)] = 4946,
  [SMALL_STATE(3924)] = 5016,
  [SMALL_STATE(3925)] = 5086,
  [SMALL_STATE(3926)] = 5156,
  [SMALL_STATE(3927)] = 5226,
  [SMALL_STATE(3928)] = 5296,
  [SMALL_STATE(3929)] = 5366,
  [SMALL_STATE(3930)] = 5436,
  [SMALL_STATE(3931)] = 5506,
  [SMALL_STATE(3932)] = 5576,
  [SMALL_STATE(3933)] = 5646,
  [SMALL_STATE(3934)] = 5716,
  [SMALL_STATE(3935)] = 5786,
  [SMALL_STATE(3936)] = 5856,
  [SMALL_STATE(3937)] = 5926,
  [SMALL_STATE(3938)] = 5996,
  [SMALL_STATE(3939)] = 6066,
  [SMALL_STATE(3940)] = 6136,
  [SMALL_STATE(3941)] = 6206,
  [SMALL_STATE(3942)] = 6276,
  [SMALL_STATE(3943)] = 6346,
  [SMALL_STATE(3944)] = 6416,
  [SMALL_STATE(3945)] = 6486,
  [SMALL_STATE(3946)] = 6556,
  [SMALL_STATE(3947)] = 6626,
  [SMALL_STATE(3948)] = 6696,
  [SMALL_STATE(3949)] = 6766,
  [SMALL_STATE(3950)] = 6836,
  [SMALL_STATE(3951)] = 6906,
  [SMALL_STATE(3952)] = 6976,
  [SMALL_STATE(3953)] = 7046,
  [SMALL_STATE(3954)] = 7116,
  [SMALL_STATE(3955)] = 7186,
  [SMALL_STATE(3956)] = 7256,
  [SMALL_STATE(3957)] = 7326,
  [SMALL_STATE(3958)] = 7396,
  [SMALL_STATE(3959)] = 7466,
  [SMALL_STATE(3960)] = 7536,
  [SMALL_STATE(3961)] = 7606,
  [SMALL_STATE(3962)] = 7676,
  [SMALL_STATE(3963)] = 7746,
  [SMALL_STATE(3964)] = 7816,
  [SMALL_STATE(3965)] = 7886,
  [SMALL_STATE(3966)] = 8010,
  [SMALL_STATE(3967)] = 8134,
  [SMALL_STATE(3968)] = 8258,
  [SMALL_STATE(3969)] = 8382,
  [SMALL_STATE(3970)] = 8506,
  [SMALL_STATE(3971)] = 8630,
  [SMALL_STATE(3972)] = 8754,
  [SMALL_STATE(3973)] = 8878,
  [SMALL_STATE(3974)] = 8948,
  [SMALL_STATE(3975)] = 9072,
  [SMALL_STATE(3976)] = 9196,
  [SMALL_STATE(3977)] = 9266,
  [SMALL_STATE(3978)] = 9390,
  [SMALL_STATE(3979)] = 9514,
  [SMALL_STATE(3980)] = 9584,
  [SMALL_STATE(3981)] = 9708,
  [SMALL_STATE(3982)] = 9778,
  [SMALL_STATE(3983)] = 9848,
  [SMALL_STATE(3984)] = 9918,
  [SMALL_STATE(3985)] = 9988,
  [SMALL_STATE(3986)] = 10058,
  [SMALL_STATE(3987)] = 10128,
  [SMALL_STATE(3988)] = 10198,
  [SMALL_STATE(3989)] = 10268,
  [SMALL_STATE(3990)] = 10338,
  [SMALL_STATE(3991)] = 10408,
  [SMALL_STATE(3992)] = 10478,
  [SMALL_STATE(3993)] = 10548,
  [SMALL_STATE(3994)] = 10618,
  [SMALL_STATE(3995)] = 10688,
  [SMALL_STATE(3996)] = 10758,
  [SMALL_STATE(3997)] = 10828,
  [SMALL_STATE(3998)] = 10898,
  [SMALL_STATE(3999)] = 10968,
  [SMALL_STATE(4000)] = 11038,
  [SMALL_STATE(4001)] = 11108,
  [SMALL_STATE(4002)] = 11178,
  [SMALL_STATE(4003)] = 11248,
  [SMALL_STATE(4004)] = 11318,
  [SMALL_STATE(4005)] = 11388,
  [SMALL_STATE(4006)] = 11458,
  [SMALL_STATE(4007)] = 11528,
  [SMALL_STATE(4008)] = 11598,
  [SMALL_STATE(4009)] = 11668,
  [SMALL_STATE(4010)] = 11792,
  [SMALL_STATE(4011)] = 11862,
  [SMALL_STATE(4012)] = 11932,
  [SMALL_STATE(4013)] = 12056,
  [SMALL_STATE(4014)] = 12180,
  [SMALL_STATE(4015)] = 12304,
  [SMALL_STATE(4016)] = 12428,
  [SMALL_STATE(4017)] = 12552,
  [SMALL_STATE(4018)] = 12622,
  [SMALL_STATE(4019)] = 12692,
  [SMALL_STATE(4020)] = 12816,
  [SMALL_STATE(4021)] = 12886,
  [SMALL_STATE(4022)] = 13010,
  [SMALL_STATE(4023)] = 13080,
  [SMALL_STATE(4024)] = 13204,
  [SMALL_STATE(4025)] = 13274,
  [SMALL_STATE(4026)] = 13398,
  [SMALL_STATE(4027)] = 13468,
  [SMALL_STATE(4028)] = 13538,
  [SMALL_STATE(4029)] = 13608,
  [SMALL_STATE(4030)] = 13732,
  [SMALL_STATE(4031)] = 13856,
  [SMALL_STATE(4032)] = 13980,
  [SMALL_STATE(4033)] = 14104,
  [SMALL_STATE(4034)] = 14174,
  [SMALL_STATE(4035)] = 14298,
  [SMALL_STATE(4036)] = 14422,
  [SMALL_STATE(4037)] = 14492,
  [SMALL_STATE(4038)] = 14562,
  [SMALL_STATE(4039)] = 14632,
  [SMALL_STATE(4040)] = 14702,
  [SMALL_STATE(4041)] = 14772,
  [SMALL_STATE(4042)] = 14896,
  [SMALL_STATE(4043)] = 14966,
  [SMALL_STATE(4044)] = 15036,
  [SMALL_STATE(4045)] = 15106,
  [SMALL_STATE(4046)] = 15176,
  [SMALL_STATE(4047)] = 15246,
  [SMALL_STATE(4048)] = 15316,
  [SMALL_STATE(4049)] = 15386,
  [SMALL_STATE(4050)] = 15456,
  [SMALL_STATE(4051)] = 15526,
  [SMALL_STATE(4052)] = 15596,
  [SMALL_STATE(4053)] = 15666,
  [SMALL_STATE(4054)] = 15736,
  [SMALL_STATE(4055)] = 15860,
  [SMALL_STATE(4056)] = 15984,
  [SMALL_STATE(4057)] = 16108,
  [SMALL_STATE(4058)] = 16178,
  [SMALL_STATE(4059)] = 16302,
  [SMALL_STATE(4060)] = 16372,
  [SMALL_STATE(4061)] = 16496,
  [SMALL_STATE(4062)] = 16568,
  [SMALL_STATE(4063)] = 16640,
  [SMALL_STATE(4064)] = 16710,
  [SMALL_STATE(4065)] = 16834,
  [SMALL_STATE(4066)] = 16958,
  [SMALL_STATE(4067)] = 17082,
  [SMALL_STATE(4068)] = 17152,
  [SMALL_STATE(4069)] = 17276,
  [SMALL_STATE(4070)] = 17400,
  [SMALL_STATE(4071)] = 17470,
  [SMALL_STATE(4072)] = 17540,
  [SMALL_STATE(4073)] = 17610,
  [SMALL_STATE(4074)] = 17680,
  [SMALL_STATE(4075)] = 17750,
  [SMALL_STATE(4076)] = 17820,
  [SMALL_STATE(4077)] = 17890,
  [SMALL_STATE(4078)] = 17960,
  [SMALL_STATE(4079)] = 18030,
  [SMALL_STATE(4080)] = 18100,
  [SMALL_STATE(4081)] = 18170,
  [SMALL_STATE(4082)] = 18240,
  [SMALL_STATE(4083)] = 18310,
  [SMALL_STATE(4084)] = 18380,
  [SMALL_STATE(4085)] = 18450,
  [SMALL_STATE(4086)] = 18520,
  [SMALL_STATE(4087)] = 18590,
  [SMALL_STATE(4088)] = 18660,
  [SMALL_STATE(4089)] = 18730,
  [SMALL_STATE(4090)] = 18854,
  [SMALL_STATE(4091)] = 18924,
  [SMALL_STATE(4092)] = 18994,
  [SMALL_STATE(4093)] = 19064,
  [SMALL_STATE(4094)] = 19188,
  [SMALL_STATE(4095)] = 19312,
  [SMALL_STATE(4096)] = 19436,
  [SMALL_STATE(4097)] = 19508,
  [SMALL_STATE(4098)] = 19578,
  [SMALL_STATE(4099)] = 19648,
  [SMALL_STATE(4100)] = 19722,
  [SMALL_STATE(4101)] = 19796,
  [SMALL_STATE(4102)] = 19866,
  [SMALL_STATE(4103)] = 19936,
  [SMALL_STATE(4104)] = 20060,
  [SMALL_STATE(4105)] = 20184,
  [SMALL_STATE(4106)] = 20308,
  [SMALL_STATE(4107)] = 20432,
  [SMALL_STATE(4108)] = 20502,
  [SMALL_STATE(4109)] = 20626,
  [SMALL_STATE(4110)] = 20750,
  [SMALL_STATE(4111)] = 20874,
  [SMALL_STATE(4112)] = 20998,
  [SMALL_STATE(4113)] = 21068,
  [SMALL_STATE(4114)] = 21138,
  [SMALL_STATE(4115)] = 21208,
  [SMALL_STATE(4116)] = 21278,
  [SMALL_STATE(4117)] = 21348,
  [SMALL_STATE(4118)] = 21422,
  [SMALL_STATE(4119)] = 21492,
  [SMALL_STATE(4120)] = 21562,
  [SMALL_STATE(4121)] = 21632,
  [SMALL_STATE(4122)] = 21702,
  [SMALL_STATE(4123)] = 21772,
  [SMALL_STATE(4124)] = 21842,
  [SMALL_STATE(4125)] = 21912,
  [SMALL_STATE(4126)] = 21982,
  [SMALL_STATE(4127)] = 22106,
  [SMALL_STATE(4128)] = 22176,
  [SMALL_STATE(4129)] = 22300,
  [SMALL_STATE(4130)] = 22370,
  [SMALL_STATE(4131)] = 22440,
  [SMALL_STATE(4132)] = 22512,
  [SMALL_STATE(4133)] = 22636,
  [SMALL_STATE(4134)] = 22760,
  [SMALL_STATE(4135)] = 22830,
  [SMALL_STATE(4136)] = 22902,
  [SMALL_STATE(4137)] = 23026,
  [SMALL_STATE(4138)] = 23150,
  [SMALL_STATE(4139)] = 23274,
  [SMALL_STATE(4140)] = 23344,
  [SMALL_STATE(4141)] = 23416,
  [SMALL_STATE(4142)] = 23488,
  [SMALL_STATE(4143)] = 23560,
  [SMALL_STATE(4144)] = 23632,
  [SMALL_STATE(4145)] = 23704,
  [SMALL_STATE(4146)] = 23828,
  [SMALL_STATE(4147)] = 23952,
  [SMALL_STATE(4148)] = 24076,
  [SMALL_STATE(4149)] = 24200,
  [SMALL_STATE(4150)] = 24324,
  [SMALL_STATE(4151)] = 24448,
  [SMALL_STATE(4152)] = 24572,
  [SMALL_STATE(4153)] = 24644,
  [SMALL_STATE(4154)] = 24768,
  [SMALL_STATE(4155)] = 24892,
  [SMALL_STATE(4156)] = 25016,
  [SMALL_STATE(4157)] = 25140,
  [SMALL_STATE(4158)] = 25264,
  [SMALL_STATE(4159)] = 25388,
  [SMALL_STATE(4160)] = 25460,
  [SMALL_STATE(4161)] = 25584,
  [SMALL_STATE(4162)] = 25708,
  [SMALL_STATE(4163)] = 25832,
  [SMALL_STATE(4164)] = 25956,
  [SMALL_STATE(4165)] = 26080,
  [SMALL_STATE(4166)] = 26204,
  [SMALL_STATE(4167)] = 26276,
  [SMALL_STATE(4168)] = 26400,
  [SMALL_STATE(4169)] = 26524,
  [SMALL_STATE(4170)] = 26648,
  [SMALL_STATE(4171)] = 26772,
  [SMALL_STATE(4172)] = 26896,
  [SMALL_STATE(4173)] = 27020,
  [SMALL_STATE(4174)] = 27144,
  [SMALL_STATE(4175)] = 27268,
  [SMALL_STATE(4176)] = 27392,
  [SMALL_STATE(4177)] = 27516,
  [SMALL_STATE(4178)] = 27640,
  [SMALL_STATE(4179)] = 27710,
  [SMALL_STATE(4180)] = 27834,
  [SMALL_STATE(4181)] = 27958,
  [SMALL_STATE(4182)] = 28082,
  [SMALL_STATE(4183)] = 28206,
  [SMALL_STATE(4184)] = 28330,
  [SMALL_STATE(4185)] = 28454,
  [SMALL_STATE(4186)] = 28578,
  [SMALL_STATE(4187)] = 28702,
  [SMALL_STATE(4188)] = 28826,
  [SMALL_STATE(4189)] = 28950,
  [SMALL_STATE(4190)] = 29074,
  [SMALL_STATE(4191)] = 29198,
  [SMALL_STATE(4192)] = 29322,
  [SMALL_STATE(4193)] = 29446,
  [SMALL_STATE(4194)] = 29570,
  [SMALL_STATE(4195)] = 29694,
  [SMALL_STATE(4196)] = 29818,
  [SMALL_STATE(4197)] = 29888,
  [SMALL_STATE(4198)] = 29958,
  [SMALL_STATE(4199)] = 30028,
  [SMALL_STATE(4200)] = 30152,
  [SMALL_STATE(4201)] = 30222,
  [SMALL_STATE(4202)] = 30292,
  [SMALL_STATE(4203)] = 30416,
  [SMALL_STATE(4204)] = 30540,
  [SMALL_STATE(4205)] = 30664,
  [SMALL_STATE(4206)] = 30788,
  [SMALL_STATE(4207)] = 30912,
  [SMALL_STATE(4208)] = 31036,
  [SMALL_STATE(4209)] = 31160,
  [SMALL_STATE(4210)] = 31284,
  [SMALL_STATE(4211)] = 31408,
  [SMALL_STATE(4212)] = 31532,
  [SMALL_STATE(4213)] = 31656,
  [SMALL_STATE(4214)] = 31780,
  [SMALL_STATE(4215)] = 31904,
  [SMALL_STATE(4216)] = 32028,
  [SMALL_STATE(4217)] = 32152,
  [SMALL_STATE(4218)] = 32276,
  [SMALL_STATE(4219)] = 32400,
  [SMALL_STATE(4220)] = 32524,
  [SMALL_STATE(4221)] = 32594,
  [SMALL_STATE(4222)] = 32718,
  [SMALL_STATE(4223)] = 32842,
  [SMALL_STATE(4224)] = 32912,
  [SMALL_STATE(4225)] = 32982,
  [SMALL_STATE(4226)] = 33052,
  [SMALL_STATE(4227)] = 33176,
  [SMALL_STATE(4228)] = 33246,
  [SMALL_STATE(4229)] = 33370,
  [SMALL_STATE(4230)] = 33494,
  [SMALL_STATE(4231)] = 33618,
  [SMALL_STATE(4232)] = 33742,
  [SMALL_STATE(4233)] = 33866,
  [SMALL_STATE(4234)] = 33990,
  [SMALL_STATE(4235)] = 34114,
  [SMALL_STATE(4236)] = 34238,
  [SMALL_STATE(4237)] = 34362,
  [SMALL_STATE(4238)] = 34486,
  [SMALL_STATE(4239)] = 34610,
  [SMALL_STATE(4240)] = 34734,
  [SMALL_STATE(4241)] = 34858,
  [SMALL_STATE(4242)] = 34982,
  [SMALL_STATE(4243)] = 35106,
  [SMALL_STATE(4244)] = 35230,
  [SMALL_STATE(4245)] = 35354,
  [SMALL_STATE(4246)] = 35478,
  [SMALL_STATE(4247)] = 35602,
  [SMALL_STATE(4248)] = 35726,
  [SMALL_STATE(4249)] = 35850,
  [SMALL_STATE(4250)] = 35974,
  [SMALL_STATE(4251)] = 36098,
  [SMALL_STATE(4252)] = 36222,
  [SMALL_STATE(4253)] = 36346,
  [SMALL_STATE(4254)] = 36470,
  [SMALL_STATE(4255)] = 36594,
  [SMALL_STATE(4256)] = 36718,
  [SMALL_STATE(4257)] = 36842,
  [SMALL_STATE(4258)] = 36966,
  [SMALL_STATE(4259)] = 37090,
  [SMALL_STATE(4260)] = 37214,
  [SMALL_STATE(4261)] = 37338,
  [SMALL_STATE(4262)] = 37462,
  [SMALL_STATE(4263)] = 37586,
  [SMALL_STATE(4264)] = 37710,
  [SMALL_STATE(4265)] = 37834,
  [SMALL_STATE(4266)] = 37958,
  [SMALL_STATE(4267)] = 38082,
  [SMALL_STATE(4268)] = 38152,
  [SMALL_STATE(4269)] = 38276,
  [SMALL_STATE(4270)] = 38400,
  [SMALL_STATE(4271)] = 38524,
  [SMALL_STATE(4272)] = 38648,
  [SMALL_STATE(4273)] = 38718,
  [SMALL_STATE(4274)] = 38842,
  [SMALL_STATE(4275)] = 38966,
  [SMALL_STATE(4276)] = 39090,
  [SMALL_STATE(4277)] = 39160,
  [SMALL_STATE(4278)] = 39284,
  [SMALL_STATE(4279)] = 39356,
  [SMALL_STATE(4280)] = 39480,
  [SMALL_STATE(4281)] = 39604,
  [SMALL_STATE(4282)] = 39728,
  [SMALL_STATE(4283)] = 39852,
  [SMALL_STATE(4284)] = 39976,
  [SMALL_STATE(4285)] = 40048,
  [SMALL_STATE(4286)] = 40118,
  [SMALL_STATE(4287)] = 40188,
  [SMALL_STATE(4288)] = 40260,
  [SMALL_STATE(4289)] = 40332,
  [SMALL_STATE(4290)] = 40404,
  [SMALL_STATE(4291)] = 40476,
  [SMALL_STATE(4292)] = 40600,
  [SMALL_STATE(4293)] = 40724,
  [SMALL_STATE(4294)] = 40848,
  [SMALL_STATE(4295)] = 40918,
  [SMALL_STATE(4296)] = 40988,
  [SMALL_STATE(4297)] = 41060,
  [SMALL_STATE(4298)] = 41184,
  [SMALL_STATE(4299)] = 41308,
  [SMALL_STATE(4300)] = 41432,
  [SMALL_STATE(4301)] = 41556,
  [SMALL_STATE(4302)] = 41628,
  [SMALL_STATE(4303)] = 41752,
  [SMALL_STATE(4304)] = 41876,
  [SMALL_STATE(4305)] = 42000,
  [SMALL_STATE(4306)] = 42124,
  [SMALL_STATE(4307)] = 42196,
  [SMALL_STATE(4308)] = 42268,
  [SMALL_STATE(4309)] = 42340,
  [SMALL_STATE(4310)] = 42412,
  [SMALL_STATE(4311)] = 42484,
  [SMALL_STATE(4312)] = 42608,
  [SMALL_STATE(4313)] = 42680,
  [SMALL_STATE(4314)] = 42752,
  [SMALL_STATE(4315)] = 42824,
  [SMALL_STATE(4316)] = 42948,
  [SMALL_STATE(4317)] = 43072,
  [SMALL_STATE(4318)] = 43144,
  [SMALL_STATE(4319)] = 43268,
  [SMALL_STATE(4320)] = 43392,
  [SMALL_STATE(4321)] = 43462,
  [SMALL_STATE(4322)] = 43586,
  [SMALL_STATE(4323)] = 43710,
  [SMALL_STATE(4324)] = 43834,
  [SMALL_STATE(4325)] = 43958,
  [SMALL_STATE(4326)] = 44028,
  [SMALL_STATE(4327)] = 44152,
  [SMALL_STATE(4328)] = 44276,
  [SMALL_STATE(4329)] = 44346,
  [SMALL_STATE(4330)] = 44470,
  [SMALL_STATE(4331)] = 44594,
  [SMALL_STATE(4332)] = 44718,
  [SMALL_STATE(4333)] = 44842,
  [SMALL_STATE(4334)] = 44912,
  [SMALL_STATE(4335)] = 45036,
  [SMALL_STATE(4336)] = 45160,
  [SMALL_STATE(4337)] = 45284,
  [SMALL_STATE(4338)] = 45408,
  [SMALL_STATE(4339)] = 45532,
  [SMALL_STATE(4340)] = 45656,
  [SMALL_STATE(4341)] = 45726,
  [SMALL_STATE(4342)] = 45796,
  [SMALL_STATE(4343)] = 45866,
  [SMALL_STATE(4344)] = 45936,
  [SMALL_STATE(4345)] = 46006,
  [SMALL_STATE(4346)] = 46076,
  [SMALL_STATE(4347)] = 46146,
  [SMALL_STATE(4348)] = 46216,
  [SMALL_STATE(4349)] = 46286,
  [SMALL_STATE(4350)] = 46356,
  [SMALL_STATE(4351)] = 46480,
  [SMALL_STATE(4352)] = 46604,
  [SMALL_STATE(4353)] = 46674,
  [SMALL_STATE(4354)] = 46744,
  [SMALL_STATE(4355)] = 46814,
  [SMALL_STATE(4356)] = 46884,
  [SMALL_STATE(4357)] = 46954,
  [SMALL_STATE(4358)] = 47024,
  [SMALL_STATE(4359)] = 47096,
  [SMALL_STATE(4360)] = 47168,
  [SMALL_STATE(4361)] = 47238,
  [SMALL_STATE(4362)] = 47308,
  [SMALL_STATE(4363)] = 47378,
  [SMALL_STATE(4364)] = 47448,
  [SMALL_STATE(4365)] = 47520,
  [SMALL_STATE(4366)] = 47592,
  [SMALL_STATE(4367)] = 47662,
  [SMALL_STATE(4368)] = 47732,
  [SMALL_STATE(4369)] = 47804,
  [SMALL_STATE(4370)] = 47876,
  [SMALL_STATE(4371)] = 47948,
  [SMALL_STATE(4372)] = 48020,
  [SMALL_STATE(4373)] = 48090,
  [SMALL_STATE(4374)] = 48162,
  [SMALL_STATE(4375)] = 48286,
  [SMALL_STATE(4376)] = 48358,
  [SMALL_STATE(4377)] = 48428,
  [SMALL_STATE(4378)] = 48552,
  [SMALL_STATE(4379)] = 48622,
  [SMALL_STATE(4380)] = 48694,
  [SMALL_STATE(4381)] = 48766,
  [SMALL_STATE(4382)] = 48838,
  [SMALL_STATE(4383)] = 48910,
  [SMALL_STATE(4384)] = 48980,
  [SMALL_STATE(4385)] = 49050,
  [SMALL_STATE(4386)] = 49122,
  [SMALL_STATE(4387)] = 49194,
  [SMALL_STATE(4388)] = 49266,
  [SMALL_STATE(4389)] = 49338,
  [SMALL_STATE(4390)] = 49410,
  [SMALL_STATE(4391)] = 49482,
  [SMALL_STATE(4392)] = 49606,
  [SMALL_STATE(4393)] = 49730,
  [SMALL_STATE(4394)] = 49854,
  [SMALL_STATE(4395)] = 49978,
  [SMALL_STATE(4396)] = 50102,
  [SMALL_STATE(4397)] = 50226,
  [SMALL_STATE(4398)] = 50296,
  [SMALL_STATE(4399)] = 50420,
  [SMALL_STATE(4400)] = 50544,
  [SMALL_STATE(4401)] = 50668,
  [SMALL_STATE(4402)] = 50792,
  [SMALL_STATE(4403)] = 50916,
  [SMALL_STATE(4404)] = 51040,
  [SMALL_STATE(4405)] = 51164,
  [SMALL_STATE(4406)] = 51288,
  [SMALL_STATE(4407)] = 51412,
  [SMALL_STATE(4408)] = 51536,
  [SMALL_STATE(4409)] = 51606,
  [SMALL_STATE(4410)] = 51676,
  [SMALL_STATE(4411)] = 51746,
  [SMALL_STATE(4412)] = 51870,
  [SMALL_STATE(4413)] = 51994,
  [SMALL_STATE(4414)] = 52118,
  [SMALL_STATE(4415)] = 52242,
  [SMALL_STATE(4416)] = 52366,
  [SMALL_STATE(4417)] = 52490,
  [SMALL_STATE(4418)] = 52614,
  [SMALL_STATE(4419)] = 52684,
  [SMALL_STATE(4420)] = 52754,
  [SMALL_STATE(4421)] = 52878,
  [SMALL_STATE(4422)] = 53002,
  [SMALL_STATE(4423)] = 53126,
  [SMALL_STATE(4424)] = 53250,
  [SMALL_STATE(4425)] = 53374,
  [SMALL_STATE(4426)] = 53498,
  [SMALL_STATE(4427)] = 53622,
  [SMALL_STATE(4428)] = 53746,
  [SMALL_STATE(4429)] = 53870,
  [SMALL_STATE(4430)] = 53940,
  [SMALL_STATE(4431)] = 54064,
  [SMALL_STATE(4432)] = 54188,
  [SMALL_STATE(4433)] = 54312,
  [SMALL_STATE(4434)] = 54436,
  [SMALL_STATE(4435)] = 54560,
  [SMALL_STATE(4436)] = 54684,
  [SMALL_STATE(4437)] = 54808,
  [SMALL_STATE(4438)] = 54932,
  [SMALL_STATE(4439)] = 55056,
  [SMALL_STATE(4440)] = 55180,
  [SMALL_STATE(4441)] = 55304,
  [SMALL_STATE(4442)] = 55428,
  [SMALL_STATE(4443)] = 55498,
  [SMALL_STATE(4444)] = 55568,
  [SMALL_STATE(4445)] = 55692,
  [SMALL_STATE(4446)] = 55816,
  [SMALL_STATE(4447)] = 55886,
  [SMALL_STATE(4448)] = 55956,
  [SMALL_STATE(4449)] = 56026,
  [SMALL_STATE(4450)] = 56096,
  [SMALL_STATE(4451)] = 56166,
  [SMALL_STATE(4452)] = 56290,
  [SMALL_STATE(4453)] = 56414,
  [SMALL_STATE(4454)] = 56484,
  [SMALL_STATE(4455)] = 56556,
  [SMALL_STATE(4456)] = 56628,
  [SMALL_STATE(4457)] = 56698,
  [SMALL_STATE(4458)] = 56822,
  [SMALL_STATE(4459)] = 56946,
  [SMALL_STATE(4460)] = 57016,
  [SMALL_STATE(4461)] = 57086,
  [SMALL_STATE(4462)] = 57156,
  [SMALL_STATE(4463)] = 57226,
  [SMALL_STATE(4464)] = 57350,
  [SMALL_STATE(4465)] = 57474,
  [SMALL_STATE(4466)] = 57598,
  [SMALL_STATE(4467)] = 57722,
  [SMALL_STATE(4468)] = 57846,
  [SMALL_STATE(4469)] = 57970,
  [SMALL_STATE(4470)] = 58094,
  [SMALL_STATE(4471)] = 58218,
  [SMALL_STATE(4472)] = 58342,
  [SMALL_STATE(4473)] = 58466,
  [SMALL_STATE(4474)] = 58590,
  [SMALL_STATE(4475)] = 58714,
  [SMALL_STATE(4476)] = 58838,
  [SMALL_STATE(4477)] = 58908,
  [SMALL_STATE(4478)] = 58980,
  [SMALL_STATE(4479)] = 59052,
  [SMALL_STATE(4480)] = 59122,
  [SMALL_STATE(4481)] = 59192,
  [SMALL_STATE(4482)] = 59262,
  [SMALL_STATE(4483)] = 59332,
  [SMALL_STATE(4484)] = 59404,
  [SMALL_STATE(4485)] = 59528,
  [SMALL_STATE(4486)] = 59600,
  [SMALL_STATE(4487)] = 59670,
  [SMALL_STATE(4488)] = 59740,
  [SMALL_STATE(4489)] = 59812,
  [SMALL_STATE(4490)] = 59936,
  [SMALL_STATE(4491)] = 60008,
  [SMALL_STATE(4492)] = 60080,
  [SMALL_STATE(4493)] = 60152,
  [SMALL_STATE(4494)] = 60224,
  [SMALL_STATE(4495)] = 60296,
  [SMALL_STATE(4496)] = 60420,
  [SMALL_STATE(4497)] = 60544,
  [SMALL_STATE(4498)] = 60668,
  [SMALL_STATE(4499)] = 60792,
  [SMALL_STATE(4500)] = 60916,
  [SMALL_STATE(4501)] = 61040,
  [SMALL_STATE(4502)] = 61114,
  [SMALL_STATE(4503)] = 61238,
  [SMALL_STATE(4504)] = 61362,
  [SMALL_STATE(4505)] = 61486,
  [SMALL_STATE(4506)] = 61556,
  [SMALL_STATE(4507)] = 61680,
  [SMALL_STATE(4508)] = 61750,
  [SMALL_STATE(4509)] = 61820,
  [SMALL_STATE(4510)] = 61890,
  [SMALL_STATE(4511)] = 61960,
  [SMALL_STATE(4512)] = 62084,
  [SMALL_STATE(4513)] = 62154,
  [SMALL_STATE(4514)] = 62224,
  [SMALL_STATE(4515)] = 62348,
  [SMALL_STATE(4516)] = 62418,
  [SMALL_STATE(4517)] = 62488,
  [SMALL_STATE(4518)] = 62558,
  [SMALL_STATE(4519)] = 62628,
  [SMALL_STATE(4520)] = 62752,
  [SMALL_STATE(4521)] = 62822,
  [SMALL_STATE(4522)] = 62946,
  [SMALL_STATE(4523)] = 63016,
  [SMALL_STATE(4524)] = 63140,
  [SMALL_STATE(4525)] = 63210,
  [SMALL_STATE(4526)] = 63280,
  [SMALL_STATE(4527)] = 63350,
  [SMALL_STATE(4528)] = 63420,
  [SMALL_STATE(4529)] = 63490,
  [SMALL_STATE(4530)] = 63560,
  [SMALL_STATE(4531)] = 63630,
  [SMALL_STATE(4532)] = 63700,
  [SMALL_STATE(4533)] = 63770,
  [SMALL_STATE(4534)] = 63840,
  [SMALL_STATE(4535)] = 63912,
  [SMALL_STATE(4536)] = 63984,
  [SMALL_STATE(4537)] = 64108,
  [SMALL_STATE(4538)] = 64232,
  [SMALL_STATE(4539)] = 64302,
  [SMALL_STATE(4540)] = 64372,
  [SMALL_STATE(4541)] = 64442,
  [SMALL_STATE(4542)] = 64512,
  [SMALL_STATE(4543)] = 64636,
  [SMALL_STATE(4544)] = 64760,
  [SMALL_STATE(4545)] = 64884,
  [SMALL_STATE(4546)] = 65008,
  [SMALL_STATE(4547)] = 65078,
  [SMALL_STATE(4548)] = 65148,
  [SMALL_STATE(4549)] = 65272,
  [SMALL_STATE(4550)] = 65396,
  [SMALL_STATE(4551)] = 65466,
  [SMALL_STATE(4552)] = 65590,
  [SMALL_STATE(4553)] = 65714,
  [SMALL_STATE(4554)] = 65838,
  [SMALL_STATE(4555)] = 65962,
  [SMALL_STATE(4556)] = 66032,
  [SMALL_STATE(4557)] = 66102,
  [SMALL_STATE(4558)] = 66172,
  [SMALL_STATE(4559)] = 66242,
  [SMALL_STATE(4560)] = 66312,
  [SMALL_STATE(4561)] = 66382,
  [SMALL_STATE(4562)] = 66452,
  [SMALL_STATE(4563)] = 66522,
  [SMALL_STATE(4564)] = 66592,
  [SMALL_STATE(4565)] = 66662,
  [SMALL_STATE(4566)] = 66732,
  [SMALL_STATE(4567)] = 66802,
  [SMALL_STATE(4568)] = 66872,
  [SMALL_STATE(4569)] = 66942,
  [SMALL_STATE(4570)] = 67012,
  [SMALL_STATE(4571)] = 67082,
  [SMALL_STATE(4572)] = 67152,
  [SMALL_STATE(4573)] = 67222,
  [SMALL_STATE(4574)] = 67292,
  [SMALL_STATE(4575)] = 67362,
  [SMALL_STATE(4576)] = 67432,
  [SMALL_STATE(4577)] = 67502,
  [SMALL_STATE(4578)] = 67626,
  [SMALL_STATE(4579)] = 67750,
  [SMALL_STATE(4580)] = 67874,
  [SMALL_STATE(4581)] = 67998,
  [SMALL_STATE(4582)] = 68122,
  [SMALL_STATE(4583)] = 68246,
  [SMALL_STATE(4584)] = 68370,
  [SMALL_STATE(4585)] = 68494,
  [SMALL_STATE(4586)] = 68618,
  [SMALL_STATE(4587)] = 68742,
  [SMALL_STATE(4588)] = 68866,
  [SMALL_STATE(4589)] = 68990,
  [SMALL_STATE(4590)] = 69060,
  [SMALL_STATE(4591)] = 69130,
  [SMALL_STATE(4592)] = 69200,
  [SMALL_STATE(4593)] = 69270,
  [SMALL_STATE(4594)] = 69340,
  [SMALL_STATE(4595)] = 69410,
  [SMALL_STATE(4596)] = 69480,
  [SMALL_STATE(4597)] = 69550,
  [SMALL_STATE(4598)] = 69674,
  [SMALL_STATE(4599)] = 69744,
  [SMALL_STATE(4600)] = 69844,
  [SMALL_STATE(4601)] = 69914,
  [SMALL_STATE(4602)] = 69984,
  [SMALL_STATE(4603)] = 70054,
  [SMALL_STATE(4604)] = 70124,
  [SMALL_STATE(4605)] = 70194,
  [SMALL_STATE(4606)] = 70264,
  [SMALL_STATE(4607)] = 70388,
  [SMALL_STATE(4608)] = 70512,
  [SMALL_STATE(4609)] = 70636,
  [SMALL_STATE(4610)] = 70760,
  [SMALL_STATE(4611)] = 70830,
  [SMALL_STATE(4612)] = 70902,
  [SMALL_STATE(4613)] = 70972,
  [SMALL_STATE(4614)] = 71096,
  [SMALL_STATE(4615)] = 71165,
  [SMALL_STATE(4616)] = 71234,
  [SMALL_STATE(4617)] = 71309,
  [SMALL_STATE(4618)] = 71384,
  [SMALL_STATE(4619)] = 71469,
  [SMALL_STATE(4620)] = 71554,
  [SMALL_STATE(4621)] = 71639,
  [SMALL_STATE(4622)] = 71724,
  [SMALL_STATE(4623)] = 71793,
  [SMALL_STATE(4624)] = 71878,
  [SMALL_STATE(4625)] = 71975,
  [SMALL_STATE(4626)] = 72044,
  [SMALL_STATE(4627)] = 72117,
  [SMALL_STATE(4628)] = 72190,
  [SMALL_STATE(4629)] = 72263,
  [SMALL_STATE(4630)] = 72336,
  [SMALL_STATE(4631)] = 72409,
  [SMALL_STATE(4632)] = 72482,
  [SMALL_STATE(4633)] = 72555,
  [SMALL_STATE(4634)] = 72628,
  [SMALL_STATE(4635)] = 72701,
  [SMALL_STATE(4636)] = 72774,
  [SMALL_STATE(4637)] = 72866,
  [SMALL_STATE(4638)] = 72933,
  [SMALL_STATE(4639)] = 73000,
  [SMALL_STATE(4640)] = 73067,
  [SMALL_STATE(4641)] = 73134,
  [SMALL_STATE(4642)] = 73201,
  [SMALL_STATE(4643)] = 73268,
  [SMALL_STATE(4644)] = 73337,
  [SMALL_STATE(4645)] = 73404,
  [SMALL_STATE(4646)] = 73471,
  [SMALL_STATE(4647)] = 73538,
  [SMALL_STATE(4648)] = 73605,
  [SMALL_STATE(4649)] = 73672,
  [SMALL_STATE(4650)] = 73739,
  [SMALL_STATE(4651)] = 73806,
  [SMALL_STATE(4652)] = 73873,
  [SMALL_STATE(4653)] = 73940,
  [SMALL_STATE(4654)] = 74007,
  [SMALL_STATE(4655)] = 74074,
  [SMALL_STATE(4656)] = 74141,
  [SMALL_STATE(4657)] = 74208,
  [SMALL_STATE(4658)] = 74275,
  [SMALL_STATE(4659)] = 74342,
  [SMALL_STATE(4660)] = 74409,
  [SMALL_STATE(4661)] = 74476,
  [SMALL_STATE(4662)] = 74543,
  [SMALL_STATE(4663)] = 74610,
  [SMALL_STATE(4664)] = 74677,
  [SMALL_STATE(4665)] = 74744,
  [SMALL_STATE(4666)] = 74811,
  [SMALL_STATE(4667)] = 74878,
  [SMALL_STATE(4668)] = 74945,
  [SMALL_STATE(4669)] = 75012,
  [SMALL_STATE(4670)] = 75083,
  [SMALL_STATE(4671)] = 75150,
  [SMALL_STATE(4672)] = 75217,
  [SMALL_STATE(4673)] = 75284,
  [SMALL_STATE(4674)] = 75351,
  [SMALL_STATE(4675)] = 75418,
  [SMALL_STATE(4676)] = 75485,
  [SMALL_STATE(4677)] = 75552,
  [SMALL_STATE(4678)] = 75619,
  [SMALL_STATE(4679)] = 75686,
  [SMALL_STATE(4680)] = 75753,
  [SMALL_STATE(4681)] = 75820,
  [SMALL_STATE(4682)] = 75887,
  [SMALL_STATE(4683)] = 75954,
  [SMALL_STATE(4684)] = 76021,
  [SMALL_STATE(4685)] = 76088,
  [SMALL_STATE(4686)] = 76155,
  [SMALL_STATE(4687)] = 76222,
  [SMALL_STATE(4688)] = 76334,
  [SMALL_STATE(4689)] = 76400,
  [SMALL_STATE(4690)] = 76512,
  [SMALL_STATE(4691)] = 76624,
  [SMALL_STATE(4692)] = 76738,
  [SMALL_STATE(4693)] = 76850,
  [SMALL_STATE(4694)] = 76962,
  [SMALL_STATE(4695)] = 77074,
  [SMALL_STATE(4696)] = 77188,
  [SMALL_STATE(4697)] = 77254,
  [SMALL_STATE(4698)] = 77366,
  [SMALL_STATE(4699)] = 77478,
  [SMALL_STATE(4700)] = 77590,
  [SMALL_STATE(4701)] = 77702,
  [SMALL_STATE(4702)] = 77814,
  [SMALL_STATE(4703)] = 77926,
  [SMALL_STATE(4704)] = 78040,
  [SMALL_STATE(4705)] = 78152,
  [SMALL_STATE(4706)] = 78264,
  [SMALL_STATE(4707)] = 78376,
  [SMALL_STATE(4708)] = 78488,
  [SMALL_STATE(4709)] = 78602,
  [SMALL_STATE(4710)] = 78714,
  [SMALL_STATE(4711)] = 78826,
  [SMALL_STATE(4712)] = 78938,
  [SMALL_STATE(4713)] = 79004,
  [SMALL_STATE(4714)] = 79116,
  [SMALL_STATE(4715)] = 79228,
  [SMALL_STATE(4716)] = 79340,
  [SMALL_STATE(4717)] = 79454,
  [SMALL_STATE(4718)] = 79519,
  [SMALL_STATE(4719)] = 79584,
  [SMALL_STATE(4720)] = 79649,
  [SMALL_STATE(4721)] = 79714,
  [SMALL_STATE(4722)] = 79779,
  [SMALL_STATE(4723)] = 79844,
  [SMALL_STATE(4724)] = 79909,
  [SMALL_STATE(4725)] = 79974,
  [SMALL_STATE(4726)] = 80039,
  [SMALL_STATE(4727)] = 80104,
  [SMALL_STATE(4728)] = 80169,
  [SMALL_STATE(4729)] = 80234,
  [SMALL_STATE(4730)] = 80299,
  [SMALL_STATE(4731)] = 80364,
  [SMALL_STATE(4732)] = 80429,
  [SMALL_STATE(4733)] = 80494,
  [SMALL_STATE(4734)] = 80559,
  [SMALL_STATE(4735)] = 80624,
  [SMALL_STATE(4736)] = 80693,
  [SMALL_STATE(4737)] = 80760,
  [SMALL_STATE(4738)] = 80827,
  [SMALL_STATE(4739)] = 80892,
  [SMALL_STATE(4740)] = 80957,
  [SMALL_STATE(4741)] = 81024,
  [SMALL_STATE(4742)] = 81091,
  [SMALL_STATE(4743)] = 81156,
  [SMALL_STATE(4744)] = 81221,
  [SMALL_STATE(4745)] = 81286,
  [SMALL_STATE(4746)] = 81351,
  [SMALL_STATE(4747)] = 81416,
  [SMALL_STATE(4748)] = 81481,
  [SMALL_STATE(4749)] = 81546,
  [SMALL_STATE(4750)] = 81611,
  [SMALL_STATE(4751)] = 81676,
  [SMALL_STATE(4752)] = 81741,
  [SMALL_STATE(4753)] = 81806,
  [SMALL_STATE(4754)] = 81871,
  [SMALL_STATE(4755)] = 81936,
  [SMALL_STATE(4756)] = 82001,
  [SMALL_STATE(4757)] = 82066,
  [SMALL_STATE(4758)] = 82131,
  [SMALL_STATE(4759)] = 82196,
  [SMALL_STATE(4760)] = 82261,
  [SMALL_STATE(4761)] = 82326,
  [SMALL_STATE(4762)] = 82393,
  [SMALL_STATE(4763)] = 82462,
  [SMALL_STATE(4764)] = 82527,
  [SMALL_STATE(4765)] = 82592,
  [SMALL_STATE(4766)] = 82657,
  [SMALL_STATE(4767)] = 82722,
  [SMALL_STATE(4768)] = 82787,
  [SMALL_STATE(4769)] = 82852,
  [SMALL_STATE(4770)] = 82917,
  [SMALL_STATE(4771)] = 82982,
  [SMALL_STATE(4772)] = 83047,
  [SMALL_STATE(4773)] = 83112,
  [SMALL_STATE(4774)] = 83177,
  [SMALL_STATE(4775)] = 83242,
  [SMALL_STATE(4776)] = 83307,
  [SMALL_STATE(4777)] = 83372,
  [SMALL_STATE(4778)] = 83437,
  [SMALL_STATE(4779)] = 83502,
  [SMALL_STATE(4780)] = 83567,
  [SMALL_STATE(4781)] = 83646,
  [SMALL_STATE(4782)] = 83711,
  [SMALL_STATE(4783)] = 83792,
  [SMALL_STATE(4784)] = 83857,
  [SMALL_STATE(4785)] = 83926,
  [SMALL_STATE(4786)] = 84039,
  [SMALL_STATE(4787)] = 84152,
  [SMALL_STATE(4788)] = 84217,
  [SMALL_STATE(4789)] = 84282,
  [SMALL_STATE(4790)] = 84347,
  [SMALL_STATE(4791)] = 84412,
  [SMALL_STATE(4792)] = 84477,
  [SMALL_STATE(4793)] = 84542,
  [SMALL_STATE(4794)] = 84607,
  [SMALL_STATE(4795)] = 84672,
  [SMALL_STATE(4796)] = 84736,
  [SMALL_STATE(4797)] = 84800,
  [SMALL_STATE(4798)] = 84864,
  [SMALL_STATE(4799)] = 84928,
  [SMALL_STATE(4800)] = 84992,
  [SMALL_STATE(4801)] = 85056,
  [SMALL_STATE(4802)] = 85126,
  [SMALL_STATE(4803)] = 85190,
  [SMALL_STATE(4804)] = 85254,
  [SMALL_STATE(4805)] = 85318,
  [SMALL_STATE(4806)] = 85382,
  [SMALL_STATE(4807)] = 85446,
  [SMALL_STATE(4808)] = 85510,
  [SMALL_STATE(4809)] = 85574,
  [SMALL_STATE(4810)] = 85638,
  [SMALL_STATE(4811)] = 85702,
  [SMALL_STATE(4812)] = 85766,
  [SMALL_STATE(4813)] = 85846,
  [SMALL_STATE(4814)] = 85926,
  [SMALL_STATE(4815)] = 86006,
  [SMALL_STATE(4816)] = 86086,
  [SMALL_STATE(4817)] = 86166,
  [SMALL_STATE(4818)] = 86230,
  [SMALL_STATE(4819)] = 86294,
  [SMALL_STATE(4820)] = 86358,
  [SMALL_STATE(4821)] = 86422,
  [SMALL_STATE(4822)] = 86486,
  [SMALL_STATE(4823)] = 86550,
  [SMALL_STATE(4824)] = 86614,
  [SMALL_STATE(4825)] = 86678,
  [SMALL_STATE(4826)] = 86742,
  [SMALL_STATE(4827)] = 86806,
  [SMALL_STATE(4828)] = 86870,
  [SMALL_STATE(4829)] = 86934,
  [SMALL_STATE(4830)] = 86998,
  [SMALL_STATE(4831)] = 87062,
  [SMALL_STATE(4832)] = 87126,
  [SMALL_STATE(4833)] = 87190,
  [SMALL_STATE(4834)] = 87254,
  [SMALL_STATE(4835)] = 87318,
  [SMALL_STATE(4836)] = 87382,
  [SMALL_STATE(4837)] = 87448,
  [SMALL_STATE(4838)] = 87512,
  [SMALL_STATE(4839)] = 87576,
  [SMALL_STATE(4840)] = 87640,
  [SMALL_STATE(4841)] = 87706,
  [SMALL_STATE(4842)] = 87772,
  [SMALL_STATE(4843)] = 87836,
  [SMALL_STATE(4844)] = 87900,
  [SMALL_STATE(4845)] = 87964,
  [SMALL_STATE(4846)] = 88040,
  [SMALL_STATE(4847)] = 88149,
  [SMALL_STATE(4848)] = 88258,
  [SMALL_STATE(4849)] = 88325,
  [SMALL_STATE(4850)] = 88434,
  [SMALL_STATE(4851)] = 88543,
  [SMALL_STATE(4852)] = 88652,
  [SMALL_STATE(4853)] = 88731,
  [SMALL_STATE(4854)] = 88802,
  [SMALL_STATE(4855)] = 88869,
  [SMALL_STATE(4856)] = 88978,
  [SMALL_STATE(4857)] = 89055,
  [SMALL_STATE(4858)] = 89164,
  [SMALL_STATE(4859)] = 89231,
  [SMALL_STATE(4860)] = 89328,
  [SMALL_STATE(4861)] = 89425,
  [SMALL_STATE(4862)] = 89498,
  [SMALL_STATE(4863)] = 89561,
  [SMALL_STATE(4864)] = 89628,
  [SMALL_STATE(4865)] = 89695,
  [SMALL_STATE(4866)] = 89804,
  [SMALL_STATE(4867)] = 89906,
  [SMALL_STATE(4868)] = 89980,
  [SMALL_STATE(4869)] = 90086,
  [SMALL_STATE(4870)] = 90148,
  [SMALL_STATE(4871)] = 90246,
  [SMALL_STATE(4872)] = 90352,
  [SMALL_STATE(4873)] = 90416,
  [SMALL_STATE(4874)] = 90522,
  [SMALL_STATE(4875)] = 90586,
  [SMALL_STATE(4876)] = 90692,
  [SMALL_STATE(4877)] = 90798,
  [SMALL_STATE(4878)] = 90904,
  [SMALL_STATE(4879)] = 91010,
  [SMALL_STATE(4880)] = 91116,
  [SMALL_STATE(4881)] = 91180,
  [SMALL_STATE(4882)] = 91278,
  [SMALL_STATE(4883)] = 91384,
  [SMALL_STATE(4884)] = 91490,
  [SMALL_STATE(4885)] = 91596,
  [SMALL_STATE(4886)] = 91702,
  [SMALL_STATE(4887)] = 91808,
  [SMALL_STATE(4888)] = 91914,
  [SMALL_STATE(4889)] = 92020,
  [SMALL_STATE(4890)] = 92126,
  [SMALL_STATE(4891)] = 92232,
  [SMALL_STATE(4892)] = 92338,
  [SMALL_STATE(4893)] = 92444,
  [SMALL_STATE(4894)] = 92550,
  [SMALL_STATE(4895)] = 92656,
  [SMALL_STATE(4896)] = 92762,
  [SMALL_STATE(4897)] = 92868,
  [SMALL_STATE(4898)] = 92966,
  [SMALL_STATE(4899)] = 93072,
  [SMALL_STATE(4900)] = 93178,
  [SMALL_STATE(4901)] = 93284,
  [SMALL_STATE(4902)] = 93390,
  [SMALL_STATE(4903)] = 93454,
  [SMALL_STATE(4904)] = 93560,
  [SMALL_STATE(4905)] = 93666,
  [SMALL_STATE(4906)] = 93772,
  [SMALL_STATE(4907)] = 93870,
  [SMALL_STATE(4908)] = 93976,
  [SMALL_STATE(4909)] = 94082,
  [SMALL_STATE(4910)] = 94188,
  [SMALL_STATE(4911)] = 94294,
  [SMALL_STATE(4912)] = 94400,
  [SMALL_STATE(4913)] = 94506,
  [SMALL_STATE(4914)] = 94612,
  [SMALL_STATE(4915)] = 94718,
  [SMALL_STATE(4916)] = 94782,
  [SMALL_STATE(4917)] = 94844,
  [SMALL_STATE(4918)] = 94908,
  [SMALL_STATE(4919)] = 95014,
  [SMALL_STATE(4920)] = 95120,
  [SMALL_STATE(4921)] = 95226,
  [SMALL_STATE(4922)] = 95332,
  [SMALL_STATE(4923)] = 95440,
  [SMALL_STATE(4924)] = 95506,
  [SMALL_STATE(4925)] = 95594,
  [SMALL_STATE(4926)] = 95700,
  [SMALL_STATE(4927)] = 95806,
  [SMALL_STATE(4928)] = 95872,
  [SMALL_STATE(4929)] = 95978,
  [SMALL_STATE(4930)] = 96084,
  [SMALL_STATE(4931)] = 96190,
  [SMALL_STATE(4932)] = 96278,
  [SMALL_STATE(4933)] = 96348,
  [SMALL_STATE(4934)] = 96472,
  [SMALL_STATE(4935)] = 96534,
  [SMALL_STATE(4936)] = 96640,
  [SMALL_STATE(4937)] = 96712,
  [SMALL_STATE(4938)] = 96784,
  [SMALL_STATE(4939)] = 96906,
  [SMALL_STATE(4940)] = 96972,
  [SMALL_STATE(4941)] = 97044,
  [SMALL_STATE(4942)] = 97116,
  [SMALL_STATE(4943)] = 97222,
  [SMALL_STATE(4944)] = 97328,
  [SMALL_STATE(4945)] = 97434,
  [SMALL_STATE(4946)] = 97540,
  [SMALL_STATE(4947)] = 97646,
  [SMALL_STATE(4948)] = 97752,
  [SMALL_STATE(4949)] = 97858,
  [SMALL_STATE(4950)] = 97964,
  [SMALL_STATE(4951)] = 98072,
  [SMALL_STATE(4952)] = 98144,
  [SMALL_STATE(4953)] = 98216,
  [SMALL_STATE(4954)] = 98288,
  [SMALL_STATE(4955)] = 98394,
  [SMALL_STATE(4956)] = 98466,
  [SMALL_STATE(4957)] = 98532,
  [SMALL_STATE(4958)] = 98638,
  [SMALL_STATE(4959)] = 98702,
  [SMALL_STATE(4960)] = 98808,
  [SMALL_STATE(4961)] = 98914,
  [SMALL_STATE(4962)] = 99002,
  [SMALL_STATE(4963)] = 99104,
  [SMALL_STATE(4964)] = 99212,
  [SMALL_STATE(4965)] = 99318,
  [SMALL_STATE(4966)] = 99424,
  [SMALL_STATE(4967)] = 99530,
  [SMALL_STATE(4968)] = 99632,
  [SMALL_STATE(4969)] = 99698,
  [SMALL_STATE(4970)] = 99806,
  [SMALL_STATE(4971)] = 99912,
  [SMALL_STATE(4972)] = 99978,
  [SMALL_STATE(4973)] = 100086,
  [SMALL_STATE(4974)] = 100194,
  [SMALL_STATE(4975)] = 100300,
  [SMALL_STATE(4976)] = 100361,
  [SMALL_STATE(4977)] = 100424,
  [SMALL_STATE(4978)] = 100485,
  [SMALL_STATE(4979)] = 100546,
  [SMALL_STATE(4980)] = 100607,
  [SMALL_STATE(4981)] = 100668,
  [SMALL_STATE(4982)] = 100729,
  [SMALL_STATE(4983)] = 100790,
  [SMALL_STATE(4984)] = 100853,
  [SMALL_STATE(4985)] = 100914,
  [SMALL_STATE(4986)] = 100975,
  [SMALL_STATE(4987)] = 101036,
  [SMALL_STATE(4988)] = 101099,
  [SMALL_STATE(4989)] = 101160,
  [SMALL_STATE(4990)] = 101221,
  [SMALL_STATE(4991)] = 101282,
  [SMALL_STATE(4992)] = 101343,
  [SMALL_STATE(4993)] = 101404,
  [SMALL_STATE(4994)] = 101465,
  [SMALL_STATE(4995)] = 101526,
  [SMALL_STATE(4996)] = 101587,
  [SMALL_STATE(4997)] = 101648,
  [SMALL_STATE(4998)] = 101709,
  [SMALL_STATE(4999)] = 101770,
  [SMALL_STATE(5000)] = 101831,
  [SMALL_STATE(5001)] = 101892,
  [SMALL_STATE(5002)] = 101953,
  [SMALL_STATE(5003)] = 102014,
  [SMALL_STATE(5004)] = 102075,
  [SMALL_STATE(5005)] = 102136,
  [SMALL_STATE(5006)] = 102197,
  [SMALL_STATE(5007)] = 102258,
  [SMALL_STATE(5008)] = 102319,
  [SMALL_STATE(5009)] = 102380,
  [SMALL_STATE(5010)] = 102441,
  [SMALL_STATE(5011)] = 102502,
  [SMALL_STATE(5012)] = 102563,
  [SMALL_STATE(5013)] = 102624,
  [SMALL_STATE(5014)] = 102685,
  [SMALL_STATE(5015)] = 102746,
  [SMALL_STATE(5016)] = 102807,
  [SMALL_STATE(5017)] = 102868,
  [SMALL_STATE(5018)] = 102929,
  [SMALL_STATE(5019)] = 102990,
  [SMALL_STATE(5020)] = 103051,
  [SMALL_STATE(5021)] = 103112,
  [SMALL_STATE(5022)] = 103173,
  [SMALL_STATE(5023)] = 103234,
  [SMALL_STATE(5024)] = 103295,
  [SMALL_STATE(5025)] = 103356,
  [SMALL_STATE(5026)] = 103417,
  [SMALL_STATE(5027)] = 103478,
  [SMALL_STATE(5028)] = 103539,
  [SMALL_STATE(5029)] = 103600,
  [SMALL_STATE(5030)] = 103661,
  [SMALL_STATE(5031)] = 103722,
  [SMALL_STATE(5032)] = 103789,
  [SMALL_STATE(5033)] = 103850,
  [SMALL_STATE(5034)] = 103911,
  [SMALL_STATE(5035)] = 103972,
  [SMALL_STATE(5036)] = 104033,
  [SMALL_STATE(5037)] = 104094,
  [SMALL_STATE(5038)] = 104155,
  [SMALL_STATE(5039)] = 104216,
  [SMALL_STATE(5040)] = 104277,
  [SMALL_STATE(5041)] = 104338,
  [SMALL_STATE(5042)] = 104399,
  [SMALL_STATE(5043)] = 104460,
  [SMALL_STATE(5044)] = 104521,
  [SMALL_STATE(5045)] = 104582,
  [SMALL_STATE(5046)] = 104643,
  [SMALL_STATE(5047)] = 104704,
  [SMALL_STATE(5048)] = 104765,
  [SMALL_STATE(5049)] = 104826,
  [SMALL_STATE(5050)] = 104887,
  [SMALL_STATE(5051)] = 104948,
  [SMALL_STATE(5052)] = 105009,
  [SMALL_STATE(5053)] = 105070,
  [SMALL_STATE(5054)] = 105131,
  [SMALL_STATE(5055)] = 105192,
  [SMALL_STATE(5056)] = 105253,
  [SMALL_STATE(5057)] = 105314,
  [SMALL_STATE(5058)] = 105375,
  [SMALL_STATE(5059)] = 105436,
  [SMALL_STATE(5060)] = 105497,
  [SMALL_STATE(5061)] = 105558,
  [SMALL_STATE(5062)] = 105619,
  [SMALL_STATE(5063)] = 105680,
  [SMALL_STATE(5064)] = 105741,
  [SMALL_STATE(5065)] = 105802,
  [SMALL_STATE(5066)] = 105863,
  [SMALL_STATE(5067)] = 105924,
  [SMALL_STATE(5068)] = 105985,
  [SMALL_STATE(5069)] = 106046,
  [SMALL_STATE(5070)] = 106107,
  [SMALL_STATE(5071)] = 106168,
  [SMALL_STATE(5072)] = 106229,
  [SMALL_STATE(5073)] = 106290,
  [SMALL_STATE(5074)] = 106351,
  [SMALL_STATE(5075)] = 106412,
  [SMALL_STATE(5076)] = 106473,
  [SMALL_STATE(5077)] = 106534,
  [SMALL_STATE(5078)] = 106595,
  [SMALL_STATE(5079)] = 106656,
  [SMALL_STATE(5080)] = 106717,
  [SMALL_STATE(5081)] = 106778,
  [SMALL_STATE(5082)] = 106839,
  [SMALL_STATE(5083)] = 106900,
  [SMALL_STATE(5084)] = 106961,
  [SMALL_STATE(5085)] = 107022,
  [SMALL_STATE(5086)] = 107083,
  [SMALL_STATE(5087)] = 107144,
  [SMALL_STATE(5088)] = 107205,
  [SMALL_STATE(5089)] = 107266,
  [SMALL_STATE(5090)] = 107327,
  [SMALL_STATE(5091)] = 107388,
  [SMALL_STATE(5092)] = 107449,
  [SMALL_STATE(5093)] = 107510,
  [SMALL_STATE(5094)] = 107572,
  [SMALL_STATE(5095)] = 107632,
  [SMALL_STATE(5096)] = 107692,
  [SMALL_STATE(5097)] = 107752,
  [SMALL_STATE(5098)] = 107812,
  [SMALL_STATE(5099)] = 107872,
  [SMALL_STATE(5100)] = 107932,
  [SMALL_STATE(5101)] = 107992,
  [SMALL_STATE(5102)] = 108052,
  [SMALL_STATE(5103)] = 108112,
  [SMALL_STATE(5104)] = 108172,
  [SMALL_STATE(5105)] = 108232,
  [SMALL_STATE(5106)] = 108292,
  [SMALL_STATE(5107)] = 108352,
  [SMALL_STATE(5108)] = 108412,
  [SMALL_STATE(5109)] = 108472,
  [SMALL_STATE(5110)] = 108532,
  [SMALL_STATE(5111)] = 108592,
  [SMALL_STATE(5112)] = 108652,
  [SMALL_STATE(5113)] = 108712,
  [SMALL_STATE(5114)] = 108772,
  [SMALL_STATE(5115)] = 108832,
  [SMALL_STATE(5116)] = 108892,
  [SMALL_STATE(5117)] = 108952,
  [SMALL_STATE(5118)] = 109012,
  [SMALL_STATE(5119)] = 109072,
  [SMALL_STATE(5120)] = 109132,
  [SMALL_STATE(5121)] = 109192,
  [SMALL_STATE(5122)] = 109252,
  [SMALL_STATE(5123)] = 109312,
  [SMALL_STATE(5124)] = 109372,
  [SMALL_STATE(5125)] = 109432,
  [SMALL_STATE(5126)] = 109492,
  [SMALL_STATE(5127)] = 109552,
  [SMALL_STATE(5128)] = 109612,
  [SMALL_STATE(5129)] = 109672,
  [SMALL_STATE(5130)] = 109732,
  [SMALL_STATE(5131)] = 109792,
  [SMALL_STATE(5132)] = 109852,
  [SMALL_STATE(5133)] = 109912,
  [SMALL_STATE(5134)] = 109972,
  [SMALL_STATE(5135)] = 110032,
  [SMALL_STATE(5136)] = 110092,
  [SMALL_STATE(5137)] = 110152,
  [SMALL_STATE(5138)] = 110212,
  [SMALL_STATE(5139)] = 110272,
  [SMALL_STATE(5140)] = 110332,
  [SMALL_STATE(5141)] = 110392,
  [SMALL_STATE(5142)] = 110452,
  [SMALL_STATE(5143)] = 110512,
  [SMALL_STATE(5144)] = 110572,
  [SMALL_STATE(5145)] = 110632,
  [SMALL_STATE(5146)] = 110692,
  [SMALL_STATE(5147)] = 110752,
  [SMALL_STATE(5148)] = 110812,
  [SMALL_STATE(5149)] = 110872,
  [SMALL_STATE(5150)] = 110932,
  [SMALL_STATE(5151)] = 110992,
  [SMALL_STATE(5152)] = 111052,
  [SMALL_STATE(5153)] = 111112,
  [SMALL_STATE(5154)] = 111172,
  [SMALL_STATE(5155)] = 111232,
  [SMALL_STATE(5156)] = 111292,
  [SMALL_STATE(5157)] = 111352,
  [SMALL_STATE(5158)] = 111412,
  [SMALL_STATE(5159)] = 111472,
  [SMALL_STATE(5160)] = 111532,
  [SMALL_STATE(5161)] = 111592,
  [SMALL_STATE(5162)] = 111652,
  [SMALL_STATE(5163)] = 111712,
  [SMALL_STATE(5164)] = 111772,
  [SMALL_STATE(5165)] = 111832,
  [SMALL_STATE(5166)] = 111892,
  [SMALL_STATE(5167)] = 111952,
  [SMALL_STATE(5168)] = 112012,
  [SMALL_STATE(5169)] = 112072,
  [SMALL_STATE(5170)] = 112132,
  [SMALL_STATE(5171)] = 112192,
  [SMALL_STATE(5172)] = 112252,
  [SMALL_STATE(5173)] = 112312,
  [SMALL_STATE(5174)] = 112372,
  [SMALL_STATE(5175)] = 112432,
  [SMALL_STATE(5176)] = 112492,
  [SMALL_STATE(5177)] = 112552,
  [SMALL_STATE(5178)] = 112612,
  [SMALL_STATE(5179)] = 112672,
  [SMALL_STATE(5180)] = 112732,
  [SMALL_STATE(5181)] = 112792,
  [SMALL_STATE(5182)] = 112852,
  [SMALL_STATE(5183)] = 112912,
  [SMALL_STATE(5184)] = 112972,
  [SMALL_STATE(5185)] = 113032,
  [SMALL_STATE(5186)] = 113092,
  [SMALL_STATE(5187)] = 113152,
  [SMALL_STATE(5188)] = 113212,
  [SMALL_STATE(5189)] = 113272,
  [SMALL_STATE(5190)] = 113332,
  [SMALL_STATE(5191)] = 113392,
  [SMALL_STATE(5192)] = 113452,
  [SMALL_STATE(5193)] = 113512,
  [SMALL_STATE(5194)] = 113572,
  [SMALL_STATE(5195)] = 113632,
  [SMALL_STATE(5196)] = 113692,
  [SMALL_STATE(5197)] = 113754,
  [SMALL_STATE(5198)] = 113814,
  [SMALL_STATE(5199)] = 113874,
  [SMALL_STATE(5200)] = 113936,
  [SMALL_STATE(5201)] = 113996,
  [SMALL_STATE(5202)] = 114056,
  [SMALL_STATE(5203)] = 114116,
  [SMALL_STATE(5204)] = 114176,
  [SMALL_STATE(5205)] = 114236,
  [SMALL_STATE(5206)] = 114296,
  [SMALL_STATE(5207)] = 114356,
  [SMALL_STATE(5208)] = 114416,
  [SMALL_STATE(5209)] = 114476,
  [SMALL_STATE(5210)] = 114536,
  [SMALL_STATE(5211)] = 114596,
  [SMALL_STATE(5212)] = 114656,
  [SMALL_STATE(5213)] = 114716,
  [SMALL_STATE(5214)] = 114776,
  [SMALL_STATE(5215)] = 114836,
  [SMALL_STATE(5216)] = 114896,
  [SMALL_STATE(5217)] = 114956,
  [SMALL_STATE(5218)] = 115016,
  [SMALL_STATE(5219)] = 115076,
  [SMALL_STATE(5220)] = 115136,
  [SMALL_STATE(5221)] = 115196,
  [SMALL_STATE(5222)] = 115256,
  [SMALL_STATE(5223)] = 115316,
  [SMALL_STATE(5224)] = 115376,
  [SMALL_STATE(5225)] = 115436,
  [SMALL_STATE(5226)] = 115496,
  [SMALL_STATE(5227)] = 115556,
  [SMALL_STATE(5228)] = 115616,
  [SMALL_STATE(5229)] = 115676,
  [SMALL_STATE(5230)] = 115736,
  [SMALL_STATE(5231)] = 115800,
  [SMALL_STATE(5232)] = 115860,
  [SMALL_STATE(5233)] = 115920,
  [SMALL_STATE(5234)] = 115980,
  [SMALL_STATE(5235)] = 116042,
  [SMALL_STATE(5236)] = 116104,
  [SMALL_STATE(5237)] = 116166,
  [SMALL_STATE(5238)] = 116228,
  [SMALL_STATE(5239)] = 116290,
  [SMALL_STATE(5240)] = 116352,
  [SMALL_STATE(5241)] = 116414,
  [SMALL_STATE(5242)] = 116474,
  [SMALL_STATE(5243)] = 116534,
  [SMALL_STATE(5244)] = 116594,
  [SMALL_STATE(5245)] = 116654,
  [SMALL_STATE(5246)] = 116714,
  [SMALL_STATE(5247)] = 116774,
  [SMALL_STATE(5248)] = 116834,
  [SMALL_STATE(5249)] = 116894,
  [SMALL_STATE(5250)] = 116954,
  [SMALL_STATE(5251)] = 117014,
  [SMALL_STATE(5252)] = 117074,
  [SMALL_STATE(5253)] = 117134,
  [SMALL_STATE(5254)] = 117196,
  [SMALL_STATE(5255)] = 117258,
  [SMALL_STATE(5256)] = 117318,
  [SMALL_STATE(5257)] = 117378,
  [SMALL_STATE(5258)] = 117440,
  [SMALL_STATE(5259)] = 117502,
  [SMALL_STATE(5260)] = 117564,
  [SMALL_STATE(5261)] = 117626,
  [SMALL_STATE(5262)] = 117686,
  [SMALL_STATE(5263)] = 117748,
  [SMALL_STATE(5264)] = 117810,
  [SMALL_STATE(5265)] = 117872,
  [SMALL_STATE(5266)] = 117934,
  [SMALL_STATE(5267)] = 117996,
  [SMALL_STATE(5268)] = 118058,
  [SMALL_STATE(5269)] = 118120,
  [SMALL_STATE(5270)] = 118182,
  [SMALL_STATE(5271)] = 118244,
  [SMALL_STATE(5272)] = 118306,
  [SMALL_STATE(5273)] = 118368,
  [SMALL_STATE(5274)] = 118428,
  [SMALL_STATE(5275)] = 118488,
  [SMALL_STATE(5276)] = 118548,
  [SMALL_STATE(5277)] = 118608,
  [SMALL_STATE(5278)] = 118668,
  [SMALL_STATE(5279)] = 118728,
  [SMALL_STATE(5280)] = 118788,
  [SMALL_STATE(5281)] = 118848,
  [SMALL_STATE(5282)] = 118910,
  [SMALL_STATE(5283)] = 118972,
  [SMALL_STATE(5284)] = 119032,
  [SMALL_STATE(5285)] = 119092,
  [SMALL_STATE(5286)] = 119152,
  [SMALL_STATE(5287)] = 119212,
  [SMALL_STATE(5288)] = 119274,
  [SMALL_STATE(5289)] = 119336,
  [SMALL_STATE(5290)] = 119396,
  [SMALL_STATE(5291)] = 119456,
  [SMALL_STATE(5292)] = 119518,
  [SMALL_STATE(5293)] = 119580,
  [SMALL_STATE(5294)] = 119642,
  [SMALL_STATE(5295)] = 119704,
  [SMALL_STATE(5296)] = 119764,
  [SMALL_STATE(5297)] = 119826,
  [SMALL_STATE(5298)] = 119888,
  [SMALL_STATE(5299)] = 119948,
  [SMALL_STATE(5300)] = 120008,
  [SMALL_STATE(5301)] = 120070,
  [SMALL_STATE(5302)] = 120132,
  [SMALL_STATE(5303)] = 120194,
  [SMALL_STATE(5304)] = 120256,
  [SMALL_STATE(5305)] = 120316,
  [SMALL_STATE(5306)] = 120376,
  [SMALL_STATE(5307)] = 120438,
  [SMALL_STATE(5308)] = 120500,
  [SMALL_STATE(5309)] = 120562,
  [SMALL_STATE(5310)] = 120624,
  [SMALL_STATE(5311)] = 120686,
  [SMALL_STATE(5312)] = 120748,
  [SMALL_STATE(5313)] = 120808,
  [SMALL_STATE(5314)] = 120868,
  [SMALL_STATE(5315)] = 120928,
  [SMALL_STATE(5316)] = 120988,
  [SMALL_STATE(5317)] = 121048,
  [SMALL_STATE(5318)] = 121108,
  [SMALL_STATE(5319)] = 121168,
  [SMALL_STATE(5320)] = 121228,
  [SMALL_STATE(5321)] = 121288,
  [SMALL_STATE(5322)] = 121350,
  [SMALL_STATE(5323)] = 121412,
  [SMALL_STATE(5324)] = 121472,
  [SMALL_STATE(5325)] = 121532,
  [SMALL_STATE(5326)] = 121592,
  [SMALL_STATE(5327)] = 121652,
  [SMALL_STATE(5328)] = 121712,
  [SMALL_STATE(5329)] = 121772,
  [SMALL_STATE(5330)] = 121834,
  [SMALL_STATE(5331)] = 121896,
  [SMALL_STATE(5332)] = 121956,
  [SMALL_STATE(5333)] = 122016,
  [SMALL_STATE(5334)] = 122076,
  [SMALL_STATE(5335)] = 122136,
  [SMALL_STATE(5336)] = 122198,
  [SMALL_STATE(5337)] = 122260,
  [SMALL_STATE(5338)] = 122320,
  [SMALL_STATE(5339)] = 122380,
  [SMALL_STATE(5340)] = 122442,
  [SMALL_STATE(5341)] = 122504,
  [SMALL_STATE(5342)] = 122566,
  [SMALL_STATE(5343)] = 122628,
  [SMALL_STATE(5344)] = 122688,
  [SMALL_STATE(5345)] = 122748,
  [SMALL_STATE(5346)] = 122808,
  [SMALL_STATE(5347)] = 122868,
  [SMALL_STATE(5348)] = 122928,
  [SMALL_STATE(5349)] = 122988,
  [SMALL_STATE(5350)] = 123048,
  [SMALL_STATE(5351)] = 123108,
  [SMALL_STATE(5352)] = 123168,
  [SMALL_STATE(5353)] = 123228,
  [SMALL_STATE(5354)] = 123288,
  [SMALL_STATE(5355)] = 123348,
  [SMALL_STATE(5356)] = 123408,
  [SMALL_STATE(5357)] = 123470,
  [SMALL_STATE(5358)] = 123532,
  [SMALL_STATE(5359)] = 123592,
  [SMALL_STATE(5360)] = 123652,
  [SMALL_STATE(5361)] = 123712,
  [SMALL_STATE(5362)] = 123772,
  [SMALL_STATE(5363)] = 123832,
  [SMALL_STATE(5364)] = 123892,
  [SMALL_STATE(5365)] = 123952,
  [SMALL_STATE(5366)] = 124012,
  [SMALL_STATE(5367)] = 124072,
  [SMALL_STATE(5368)] = 124132,
  [SMALL_STATE(5369)] = 124192,
  [SMALL_STATE(5370)] = 124252,
  [SMALL_STATE(5371)] = 124312,
  [SMALL_STATE(5372)] = 124372,
  [SMALL_STATE(5373)] = 124432,
  [SMALL_STATE(5374)] = 124492,
  [SMALL_STATE(5375)] = 124552,
  [SMALL_STATE(5376)] = 124612,
  [SMALL_STATE(5377)] = 124672,
  [SMALL_STATE(5378)] = 124732,
  [SMALL_STATE(5379)] = 124792,
  [SMALL_STATE(5380)] = 124852,
  [SMALL_STATE(5381)] = 124912,
  [SMALL_STATE(5382)] = 124972,
  [SMALL_STATE(5383)] = 125032,
  [SMALL_STATE(5384)] = 125092,
  [SMALL_STATE(5385)] = 125152,
  [SMALL_STATE(5386)] = 125220,
  [SMALL_STATE(5387)] = 125280,
  [SMALL_STATE(5388)] = 125342,
  [SMALL_STATE(5389)] = 125402,
  [SMALL_STATE(5390)] = 125465,
  [SMALL_STATE(5391)] = 125524,
  [SMALL_STATE(5392)] = 125583,
  [SMALL_STATE(5393)] = 125642,
  [SMALL_STATE(5394)] = 125701,
  [SMALL_STATE(5395)] = 125760,
  [SMALL_STATE(5396)] = 125819,
  [SMALL_STATE(5397)] = 125882,
  [SMALL_STATE(5398)] = 125941,
  [SMALL_STATE(5399)] = 126000,
  [SMALL_STATE(5400)] = 126059,
  [SMALL_STATE(5401)] = 126118,
  [SMALL_STATE(5402)] = 126177,
  [SMALL_STATE(5403)] = 126240,
  [SMALL_STATE(5404)] = 126310,
  [SMALL_STATE(5405)] = 126386,
  [SMALL_STATE(5406)] = 126462,
  [SMALL_STATE(5407)] = 126540,
  [SMALL_STATE(5408)] = 126616,
  [SMALL_STATE(5409)] = 126692,
  [SMALL_STATE(5410)] = 126770,
  [SMALL_STATE(5411)] = 126846,
  [SMALL_STATE(5412)] = 126916,
  [SMALL_STATE(5413)] = 126994,
  [SMALL_STATE(5414)] = 127070,
  [SMALL_STATE(5415)] = 127146,
  [SMALL_STATE(5416)] = 127224,
  [SMALL_STATE(5417)] = 127302,
  [SMALL_STATE(5418)] = 127380,
  [SMALL_STATE(5419)] = 127458,
  [SMALL_STATE(5420)] = 127536,
  [SMALL_STATE(5421)] = 127612,
  [SMALL_STATE(5422)] = 127670,
  [SMALL_STATE(5423)] = 127728,
  [SMALL_STATE(5424)] = 127851,
  [SMALL_STATE(5425)] = 127974,
  [SMALL_STATE(5426)] = 128069,
  [SMALL_STATE(5427)] = 128164,
  [SMALL_STATE(5428)] = 128259,
  [SMALL_STATE(5429)] = 128354,
  [SMALL_STATE(5430)] = 128449,
  [SMALL_STATE(5431)] = 128544,
  [SMALL_STATE(5432)] = 128639,
  [SMALL_STATE(5433)] = 128734,
  [SMALL_STATE(5434)] = 128829,
  [SMALL_STATE(5435)] = 128924,
  [SMALL_STATE(5436)] = 129019,
  [SMALL_STATE(5437)] = 129114,
  [SMALL_STATE(5438)] = 129209,
  [SMALL_STATE(5439)] = 129332,
  [SMALL_STATE(5440)] = 129427,
  [SMALL_STATE(5441)] = 129522,
  [SMALL_STATE(5442)] = 129617,
  [SMALL_STATE(5443)] = 129712,
  [SMALL_STATE(5444)] = 129835,
  [SMALL_STATE(5445)] = 129958,
  [SMALL_STATE(5446)] = 130081,
  [SMALL_STATE(5447)] = 130137,
  [SMALL_STATE(5448)] = 130191,
  [SMALL_STATE(5449)] = 130245,
  [SMALL_STATE(5450)] = 130299,
  [SMALL_STATE(5451)] = 130353,
  [SMALL_STATE(5452)] = 130407,
  [SMALL_STATE(5453)] = 130461,
  [SMALL_STATE(5454)] = 130515,
  [SMALL_STATE(5455)] = 130569,
  [SMALL_STATE(5456)] = 130623,
  [SMALL_STATE(5457)] = 130679,
  [SMALL_STATE(5458)] = 130733,
  [SMALL_STATE(5459)] = 130787,
  [SMALL_STATE(5460)] = 130841,
  [SMALL_STATE(5461)] = 130895,
  [SMALL_STATE(5462)] = 130949,
  [SMALL_STATE(5463)] = 131003,
  [SMALL_STATE(5464)] = 131057,
  [SMALL_STATE(5465)] = 131111,
  [SMALL_STATE(5466)] = 131165,
  [SMALL_STATE(5467)] = 131219,
  [SMALL_STATE(5468)] = 131273,
  [SMALL_STATE(5469)] = 131327,
  [SMALL_STATE(5470)] = 131381,
  [SMALL_STATE(5471)] = 131437,
  [SMALL_STATE(5472)] = 131493,
  [SMALL_STATE(5473)] = 131547,
  [SMALL_STATE(5474)] = 131601,
  [SMALL_STATE(5475)] = 131657,
  [SMALL_STATE(5476)] = 131711,
  [SMALL_STATE(5477)] = 131765,
  [SMALL_STATE(5478)] = 131821,
  [SMALL_STATE(5479)] = 131875,
  [SMALL_STATE(5480)] = 131931,
  [SMALL_STATE(5481)] = 131985,
  [SMALL_STATE(5482)] = 132039,
  [SMALL_STATE(5483)] = 132093,
  [SMALL_STATE(5484)] = 132147,
  [SMALL_STATE(5485)] = 132201,
  [SMALL_STATE(5486)] = 132255,
  [SMALL_STATE(5487)] = 132309,
  [SMALL_STATE(5488)] = 132363,
  [SMALL_STATE(5489)] = 132417,
  [SMALL_STATE(5490)] = 132471,
  [SMALL_STATE(5491)] = 132525,
  [SMALL_STATE(5492)] = 132581,
  [SMALL_STATE(5493)] = 132635,
  [SMALL_STATE(5494)] = 132691,
  [SMALL_STATE(5495)] = 132745,
  [SMALL_STATE(5496)] = 132799,
  [SMALL_STATE(5497)] = 132853,
  [SMALL_STATE(5498)] = 132907,
  [SMALL_STATE(5499)] = 132961,
  [SMALL_STATE(5500)] = 133015,
  [SMALL_STATE(5501)] = 133071,
  [SMALL_STATE(5502)] = 133127,
  [SMALL_STATE(5503)] = 133183,
  [SMALL_STATE(5504)] = 133237,
  [SMALL_STATE(5505)] = 133291,
  [SMALL_STATE(5506)] = 133345,
  [SMALL_STATE(5507)] = 133399,
  [SMALL_STATE(5508)] = 133453,
  [SMALL_STATE(5509)] = 133509,
  [SMALL_STATE(5510)] = 133563,
  [SMALL_STATE(5511)] = 133617,
  [SMALL_STATE(5512)] = 133671,
  [SMALL_STATE(5513)] = 133725,
  [SMALL_STATE(5514)] = 133779,
  [SMALL_STATE(5515)] = 133833,
  [SMALL_STATE(5516)] = 133887,
  [SMALL_STATE(5517)] = 133941,
  [SMALL_STATE(5518)] = 133995,
  [SMALL_STATE(5519)] = 134049,
  [SMALL_STATE(5520)] = 134103,
  [SMALL_STATE(5521)] = 134157,
  [SMALL_STATE(5522)] = 134211,
  [SMALL_STATE(5523)] = 134265,
  [SMALL_STATE(5524)] = 134319,
  [SMALL_STATE(5525)] = 134375,
  [SMALL_STATE(5526)] = 134431,
  [SMALL_STATE(5527)] = 134485,
  [SMALL_STATE(5528)] = 134539,
  [SMALL_STATE(5529)] = 134593,
  [SMALL_STATE(5530)] = 134647,
  [SMALL_STATE(5531)] = 134701,
  [SMALL_STATE(5532)] = 134755,
  [SMALL_STATE(5533)] = 134809,
  [SMALL_STATE(5534)] = 134863,
  [SMALL_STATE(5535)] = 134919,
  [SMALL_STATE(5536)] = 134973,
  [SMALL_STATE(5537)] = 135027,
  [SMALL_STATE(5538)] = 135081,
  [SMALL_STATE(5539)] = 135135,
  [SMALL_STATE(5540)] = 135189,
  [SMALL_STATE(5541)] = 135243,
  [SMALL_STATE(5542)] = 135297,
  [SMALL_STATE(5543)] = 135351,
  [SMALL_STATE(5544)] = 135405,
  [SMALL_STATE(5545)] = 135459,
  [SMALL_STATE(5546)] = 135513,
  [SMALL_STATE(5547)] = 135567,
  [SMALL_STATE(5548)] = 135621,
  [SMALL_STATE(5549)] = 135675,
  [SMALL_STATE(5550)] = 135729,
  [SMALL_STATE(5551)] = 135783,
  [SMALL_STATE(5552)] = 135837,
  [SMALL_STATE(5553)] = 135891,
  [SMALL_STATE(5554)] = 135945,
  [SMALL_STATE(5555)] = 135999,
  [SMALL_STATE(5556)] = 136055,
  [SMALL_STATE(5557)] = 136109,
  [SMALL_STATE(5558)] = 136163,
  [SMALL_STATE(5559)] = 136217,
  [SMALL_STATE(5560)] = 136271,
  [SMALL_STATE(5561)] = 136325,
  [SMALL_STATE(5562)] = 136379,
  [SMALL_STATE(5563)] = 136433,
  [SMALL_STATE(5564)] = 136489,
  [SMALL_STATE(5565)] = 136543,
  [SMALL_STATE(5566)] = 136597,
  [SMALL_STATE(5567)] = 136651,
  [SMALL_STATE(5568)] = 136705,
  [SMALL_STATE(5569)] = 136759,
  [SMALL_STATE(5570)] = 136813,
  [SMALL_STATE(5571)] = 136867,
  [SMALL_STATE(5572)] = 136921,
  [SMALL_STATE(5573)] = 136975,
  [SMALL_STATE(5574)] = 137031,
  [SMALL_STATE(5575)] = 137087,
  [SMALL_STATE(5576)] = 137141,
  [SMALL_STATE(5577)] = 137197,
  [SMALL_STATE(5578)] = 137253,
  [SMALL_STATE(5579)] = 137309,
  [SMALL_STATE(5580)] = 137363,
  [SMALL_STATE(5581)] = 137417,
  [SMALL_STATE(5582)] = 137471,
  [SMALL_STATE(5583)] = 137527,
  [SMALL_STATE(5584)] = 137583,
  [SMALL_STATE(5585)] = 137637,
  [SMALL_STATE(5586)] = 137691,
  [SMALL_STATE(5587)] = 137745,
  [SMALL_STATE(5588)] = 137799,
  [SMALL_STATE(5589)] = 137853,
  [SMALL_STATE(5590)] = 137907,
  [SMALL_STATE(5591)] = 137961,
  [SMALL_STATE(5592)] = 138017,
  [SMALL_STATE(5593)] = 138079,
  [SMALL_STATE(5594)] = 138133,
  [SMALL_STATE(5595)] = 138187,
  [SMALL_STATE(5596)] = 138241,
  [SMALL_STATE(5597)] = 138295,
  [SMALL_STATE(5598)] = 138349,
  [SMALL_STATE(5599)] = 138403,
  [SMALL_STATE(5600)] = 138457,
  [SMALL_STATE(5601)] = 138511,
  [SMALL_STATE(5602)] = 138565,
  [SMALL_STATE(5603)] = 138621,
  [SMALL_STATE(5604)] = 138677,
  [SMALL_STATE(5605)] = 138731,
  [SMALL_STATE(5606)] = 138785,
  [SMALL_STATE(5607)] = 138841,
  [SMALL_STATE(5608)] = 138897,
  [SMALL_STATE(5609)] = 138953,
  [SMALL_STATE(5610)] = 139009,
  [SMALL_STATE(5611)] = 139063,
  [SMALL_STATE(5612)] = 139117,
  [SMALL_STATE(5613)] = 139173,
  [SMALL_STATE(5614)] = 139229,
  [SMALL_STATE(5615)] = 139285,
  [SMALL_STATE(5616)] = 139341,
  [SMALL_STATE(5617)] = 139397,
  [SMALL_STATE(5618)] = 139455,
  [SMALL_STATE(5619)] = 139509,
  [SMALL_STATE(5620)] = 139563,
  [SMALL_STATE(5621)] = 139617,
  [SMALL_STATE(5622)] = 139671,
  [SMALL_STATE(5623)] = 139725,
  [SMALL_STATE(5624)] = 139779,
  [SMALL_STATE(5625)] = 139833,
  [SMALL_STATE(5626)] = 139887,
  [SMALL_STATE(5627)] = 139941,
  [SMALL_STATE(5628)] = 139995,
  [SMALL_STATE(5629)] = 140049,
  [SMALL_STATE(5630)] = 140103,
  [SMALL_STATE(5631)] = 140157,
  [SMALL_STATE(5632)] = 140211,
  [SMALL_STATE(5633)] = 140267,
  [SMALL_STATE(5634)] = 140323,
  [SMALL_STATE(5635)] = 140377,
  [SMALL_STATE(5636)] = 140433,
  [SMALL_STATE(5637)] = 140489,
  [SMALL_STATE(5638)] = 140545,
  [SMALL_STATE(5639)] = 140599,
  [SMALL_STATE(5640)] = 140655,
  [SMALL_STATE(5641)] = 140709,
  [SMALL_STATE(5642)] = 140763,
  [SMALL_STATE(5643)] = 140817,
  [SMALL_STATE(5644)] = 140871,
  [SMALL_STATE(5645)] = 140925,
  [SMALL_STATE(5646)] = 140979,
  [SMALL_STATE(5647)] = 141033,
  [SMALL_STATE(5648)] = 141089,
  [SMALL_STATE(5649)] = 141145,
  [SMALL_STATE(5650)] = 141199,
  [SMALL_STATE(5651)] = 141253,
  [SMALL_STATE(5652)] = 141307,
  [SMALL_STATE(5653)] = 141361,
  [SMALL_STATE(5654)] = 141417,
  [SMALL_STATE(5655)] = 141471,
  [SMALL_STATE(5656)] = 141525,
  [SMALL_STATE(5657)] = 141579,
  [SMALL_STATE(5658)] = 141633,
  [SMALL_STATE(5659)] = 141687,
  [SMALL_STATE(5660)] = 141741,
  [SMALL_STATE(5661)] = 141795,
  [SMALL_STATE(5662)] = 141849,
  [SMALL_STATE(5663)] = 141903,
  [SMALL_STATE(5664)] = 141957,
  [SMALL_STATE(5665)] = 142011,
  [SMALL_STATE(5666)] = 142067,
  [SMALL_STATE(5667)] = 142121,
  [SMALL_STATE(5668)] = 142175,
  [SMALL_STATE(5669)] = 142231,
  [SMALL_STATE(5670)] = 142285,
  [SMALL_STATE(5671)] = 142343,
  [SMALL_STATE(5672)] = 142399,
  [SMALL_STATE(5673)] = 142455,
  [SMALL_STATE(5674)] = 142511,
  [SMALL_STATE(5675)] = 142565,
  [SMALL_STATE(5676)] = 142619,
  [SMALL_STATE(5677)] = 142675,
  [SMALL_STATE(5678)] = 142731,
  [SMALL_STATE(5679)] = 142785,
  [SMALL_STATE(5680)] = 142839,
  [SMALL_STATE(5681)] = 142893,
  [SMALL_STATE(5682)] = 142949,
  [SMALL_STATE(5683)] = 143005,
  [SMALL_STATE(5684)] = 143059,
  [SMALL_STATE(5685)] = 143113,
  [SMALL_STATE(5686)] = 143171,
  [SMALL_STATE(5687)] = 143227,
  [SMALL_STATE(5688)] = 143281,
  [SMALL_STATE(5689)] = 143337,
  [SMALL_STATE(5690)] = 143391,
  [SMALL_STATE(5691)] = 143445,
  [SMALL_STATE(5692)] = 143501,
  [SMALL_STATE(5693)] = 143557,
  [SMALL_STATE(5694)] = 143613,
  [SMALL_STATE(5695)] = 143669,
  [SMALL_STATE(5696)] = 143725,
  [SMALL_STATE(5697)] = 143781,
  [SMALL_STATE(5698)] = 143835,
  [SMALL_STATE(5699)] = 143889,
  [SMALL_STATE(5700)] = 143943,
  [SMALL_STATE(5701)] = 143997,
  [SMALL_STATE(5702)] = 144051,
  [SMALL_STATE(5703)] = 144105,
  [SMALL_STATE(5704)] = 144159,
  [SMALL_STATE(5705)] = 144213,
  [SMALL_STATE(5706)] = 144267,
  [SMALL_STATE(5707)] = 144321,
  [SMALL_STATE(5708)] = 144377,
  [SMALL_STATE(5709)] = 144433,
  [SMALL_STATE(5710)] = 144487,
  [SMALL_STATE(5711)] = 144541,
  [SMALL_STATE(5712)] = 144595,
  [SMALL_STATE(5713)] = 144649,
  [SMALL_STATE(5714)] = 144703,
  [SMALL_STATE(5715)] = 144757,
  [SMALL_STATE(5716)] = 144811,
  [SMALL_STATE(5717)] = 144867,
  [SMALL_STATE(5718)] = 144923,
  [SMALL_STATE(5719)] = 144977,
  [SMALL_STATE(5720)] = 145031,
  [SMALL_STATE(5721)] = 145085,
  [SMALL_STATE(5722)] = 145139,
  [SMALL_STATE(5723)] = 145195,
  [SMALL_STATE(5724)] = 145251,
  [SMALL_STATE(5725)] = 145305,
  [SMALL_STATE(5726)] = 145359,
  [SMALL_STATE(5727)] = 145415,
  [SMALL_STATE(5728)] = 145469,
  [SMALL_STATE(5729)] = 145525,
  [SMALL_STATE(5730)] = 145579,
  [SMALL_STATE(5731)] = 145635,
  [SMALL_STATE(5732)] = 145691,
  [SMALL_STATE(5733)] = 145745,
  [SMALL_STATE(5734)] = 145799,
  [SMALL_STATE(5735)] = 145853,
  [SMALL_STATE(5736)] = 145907,
  [SMALL_STATE(5737)] = 145961,
  [SMALL_STATE(5738)] = 146015,
  [SMALL_STATE(5739)] = 146069,
  [SMALL_STATE(5740)] = 146123,
  [SMALL_STATE(5741)] = 146177,
  [SMALL_STATE(5742)] = 146231,
  [SMALL_STATE(5743)] = 146285,
  [SMALL_STATE(5744)] = 146339,
  [SMALL_STATE(5745)] = 146393,
  [SMALL_STATE(5746)] = 146449,
  [SMALL_STATE(5747)] = 146505,
  [SMALL_STATE(5748)] = 146559,
  [SMALL_STATE(5749)] = 146613,
  [SMALL_STATE(5750)] = 146667,
  [SMALL_STATE(5751)] = 146721,
  [SMALL_STATE(5752)] = 146777,
  [SMALL_STATE(5753)] = 146831,
  [SMALL_STATE(5754)] = 146885,
  [SMALL_STATE(5755)] = 146941,
  [SMALL_STATE(5756)] = 146995,
  [SMALL_STATE(5757)] = 147051,
  [SMALL_STATE(5758)] = 147105,
  [SMALL_STATE(5759)] = 147159,
  [SMALL_STATE(5760)] = 147213,
  [SMALL_STATE(5761)] = 147267,
  [SMALL_STATE(5762)] = 147321,
  [SMALL_STATE(5763)] = 147375,
  [SMALL_STATE(5764)] = 147429,
  [SMALL_STATE(5765)] = 147483,
  [SMALL_STATE(5766)] = 147537,
  [SMALL_STATE(5767)] = 147591,
  [SMALL_STATE(5768)] = 147645,
  [SMALL_STATE(5769)] = 147699,
  [SMALL_STATE(5770)] = 147755,
  [SMALL_STATE(5771)] = 147809,
  [SMALL_STATE(5772)] = 147863,
  [SMALL_STATE(5773)] = 147917,
  [SMALL_STATE(5774)] = 147971,
  [SMALL_STATE(5775)] = 148025,
  [SMALL_STATE(5776)] = 148079,
  [SMALL_STATE(5777)] = 148133,
  [SMALL_STATE(5778)] = 148187,
  [SMALL_STATE(5779)] = 148243,
  [SMALL_STATE(5780)] = 148299,
  [SMALL_STATE(5781)] = 148373,
  [SMALL_STATE(5782)] = 148427,
  [SMALL_STATE(5783)] = 148481,
  [SMALL_STATE(5784)] = 148535,
  [SMALL_STATE(5785)] = 148589,
  [SMALL_STATE(5786)] = 148643,
  [SMALL_STATE(5787)] = 148697,
  [SMALL_STATE(5788)] = 148751,
  [SMALL_STATE(5789)] = 148805,
  [SMALL_STATE(5790)] = 148859,
  [SMALL_STATE(5791)] = 148913,
  [SMALL_STATE(5792)] = 148967,
  [SMALL_STATE(5793)] = 149021,
  [SMALL_STATE(5794)] = 149075,
  [SMALL_STATE(5795)] = 149129,
  [SMALL_STATE(5796)] = 149183,
  [SMALL_STATE(5797)] = 149237,
  [SMALL_STATE(5798)] = 149291,
  [SMALL_STATE(5799)] = 149345,
  [SMALL_STATE(5800)] = 149399,
  [SMALL_STATE(5801)] = 149455,
  [SMALL_STATE(5802)] = 149511,
  [SMALL_STATE(5803)] = 149567,
  [SMALL_STATE(5804)] = 149623,
  [SMALL_STATE(5805)] = 149677,
  [SMALL_STATE(5806)] = 149733,
  [SMALL_STATE(5807)] = 149789,
  [SMALL_STATE(5808)] = 149845,
  [SMALL_STATE(5809)] = 149901,
  [SMALL_STATE(5810)] = 149957,
  [SMALL_STATE(5811)] = 150013,
  [SMALL_STATE(5812)] = 150067,
  [SMALL_STATE(5813)] = 150123,
  [SMALL_STATE(5814)] = 150179,
  [SMALL_STATE(5815)] = 150235,
  [SMALL_STATE(5816)] = 150289,
  [SMALL_STATE(5817)] = 150345,
  [SMALL_STATE(5818)] = 150401,
  [SMALL_STATE(5819)] = 150457,
  [SMALL_STATE(5820)] = 150511,
  [SMALL_STATE(5821)] = 150567,
  [SMALL_STATE(5822)] = 150623,
  [SMALL_STATE(5823)] = 150677,
  [SMALL_STATE(5824)] = 150731,
  [SMALL_STATE(5825)] = 150785,
  [SMALL_STATE(5826)] = 150843,
  [SMALL_STATE(5827)] = 150899,
  [SMALL_STATE(5828)] = 150955,
  [SMALL_STATE(5829)] = 151011,
  [SMALL_STATE(5830)] = 151069,
  [SMALL_STATE(5831)] = 151123,
  [SMALL_STATE(5832)] = 151179,
  [SMALL_STATE(5833)] = 151235,
  [SMALL_STATE(5834)] = 151291,
  [SMALL_STATE(5835)] = 151347,
  [SMALL_STATE(5836)] = 151405,
  [SMALL_STATE(5837)] = 151461,
  [SMALL_STATE(5838)] = 151517,
  [SMALL_STATE(5839)] = 151573,
  [SMALL_STATE(5840)] = 151627,
  [SMALL_STATE(5841)] = 151681,
  [SMALL_STATE(5842)] = 151735,
  [SMALL_STATE(5843)] = 151789,
  [SMALL_STATE(5844)] = 151843,
  [SMALL_STATE(5845)] = 151899,
  [SMALL_STATE(5846)] = 151953,
  [SMALL_STATE(5847)] = 152009,
  [SMALL_STATE(5848)] = 152063,
  [SMALL_STATE(5849)] = 152119,
  [SMALL_STATE(5850)] = 152173,
  [SMALL_STATE(5851)] = 152227,
  [SMALL_STATE(5852)] = 152281,
  [SMALL_STATE(5853)] = 152335,
  [SMALL_STATE(5854)] = 152391,
  [SMALL_STATE(5855)] = 152447,
  [SMALL_STATE(5856)] = 152503,
  [SMALL_STATE(5857)] = 152559,
  [SMALL_STATE(5858)] = 152615,
  [SMALL_STATE(5859)] = 152669,
  [SMALL_STATE(5860)] = 152723,
  [SMALL_STATE(5861)] = 152777,
  [SMALL_STATE(5862)] = 152833,
  [SMALL_STATE(5863)] = 152887,
  [SMALL_STATE(5864)] = 152943,
  [SMALL_STATE(5865)] = 152999,
  [SMALL_STATE(5866)] = 153055,
  [SMALL_STATE(5867)] = 153111,
  [SMALL_STATE(5868)] = 153167,
  [SMALL_STATE(5869)] = 153223,
  [SMALL_STATE(5870)] = 153279,
  [SMALL_STATE(5871)] = 153333,
  [SMALL_STATE(5872)] = 153398,
  [SMALL_STATE(5873)] = 153455,
  [SMALL_STATE(5874)] = 153568,
  [SMALL_STATE(5875)] = 153627,
  [SMALL_STATE(5876)] = 153698,
  [SMALL_STATE(5877)] = 153751,
  [SMALL_STATE(5878)] = 153808,
  [SMALL_STATE(5879)] = 153863,
  [SMALL_STATE(5880)] = 153918,
  [SMALL_STATE(5881)] = 153975,
  [SMALL_STATE(5882)] = 154090,
  [SMALL_STATE(5883)] = 154171,
  [SMALL_STATE(5884)] = 154234,
  [SMALL_STATE(5885)] = 154299,
  [SMALL_STATE(5886)] = 154364,
  [SMALL_STATE(5887)] = 154429,
  [SMALL_STATE(5888)] = 154494,
  [SMALL_STATE(5889)] = 154559,
  [SMALL_STATE(5890)] = 154624,
  [SMALL_STATE(5891)] = 154679,
  [SMALL_STATE(5892)] = 154738,
  [SMALL_STATE(5893)] = 154819,
  [SMALL_STATE(5894)] = 154900,
  [SMALL_STATE(5895)] = 154993,
  [SMALL_STATE(5896)] = 155086,
  [SMALL_STATE(5897)] = 155179,
  [SMALL_STATE(5898)] = 155278,
  [SMALL_STATE(5899)] = 155377,
  [SMALL_STATE(5900)] = 155476,
  [SMALL_STATE(5901)] = 155575,
  [SMALL_STATE(5902)] = 155634,
  [SMALL_STATE(5903)] = 155733,
  [SMALL_STATE(5904)] = 155832,
  [SMALL_STATE(5905)] = 155923,
  [SMALL_STATE(5906)] = 155982,
  [SMALL_STATE(5907)] = 156039,
  [SMALL_STATE(5908)] = 156096,
  [SMALL_STATE(5909)] = 156163,
  [SMALL_STATE(5910)] = 156220,
  [SMALL_STATE(5911)] = 156279,
  [SMALL_STATE(5912)] = 156344,
  [SMALL_STATE(5913)] = 156398,
  [SMALL_STATE(5914)] = 156450,
  [SMALL_STATE(5915)] = 156504,
  [SMALL_STATE(5916)] = 156558,
  [SMALL_STATE(5917)] = 156640,
  [SMALL_STATE(5918)] = 156694,
  [SMALL_STATE(5919)] = 156746,
  [SMALL_STATE(5920)] = 156800,
  [SMALL_STATE(5921)] = 156856,
  [SMALL_STATE(5922)] = 156910,
  [SMALL_STATE(5923)] = 156962,
  [SMALL_STATE(5924)] = 157022,
  [SMALL_STATE(5925)] = 157076,
  [SMALL_STATE(5926)] = 157128,
  [SMALL_STATE(5927)] = 157184,
  [SMALL_STATE(5928)] = 157238,
  [SMALL_STATE(5929)] = 157292,
  [SMALL_STATE(5930)] = 157344,
  [SMALL_STATE(5931)] = 157396,
  [SMALL_STATE(5932)] = 157450,
  [SMALL_STATE(5933)] = 157518,
  [SMALL_STATE(5934)] = 157572,
  [SMALL_STATE(5935)] = 157626,
  [SMALL_STATE(5936)] = 157680,
  [SMALL_STATE(5937)] = 157734,
  [SMALL_STATE(5938)] = 157786,
  [SMALL_STATE(5939)] = 157840,
  [SMALL_STATE(5940)] = 157894,
  [SMALL_STATE(5941)] = 157948,
  [SMALL_STATE(5942)] = 158002,
  [SMALL_STATE(5943)] = 158056,
  [SMALL_STATE(5944)] = 158110,
  [SMALL_STATE(5945)] = 158164,
  [SMALL_STATE(5946)] = 158218,
  [SMALL_STATE(5947)] = 158272,
  [SMALL_STATE(5948)] = 158326,
  [SMALL_STATE(5949)] = 158380,
  [SMALL_STATE(5950)] = 158434,
  [SMALL_STATE(5951)] = 158486,
  [SMALL_STATE(5952)] = 158538,
  [SMALL_STATE(5953)] = 158604,
  [SMALL_STATE(5954)] = 158656,
  [SMALL_STATE(5955)] = 158708,
  [SMALL_STATE(5956)] = 158760,
  [SMALL_STATE(5957)] = 158812,
  [SMALL_STATE(5958)] = 158864,
  [SMALL_STATE(5959)] = 158946,
  [SMALL_STATE(5960)] = 158998,
  [SMALL_STATE(5961)] = 159052,
  [SMALL_STATE(5962)] = 159106,
  [SMALL_STATE(5963)] = 159188,
  [SMALL_STATE(5964)] = 159240,
  [SMALL_STATE(5965)] = 159294,
  [SMALL_STATE(5966)] = 159348,
  [SMALL_STATE(5967)] = 159402,
  [SMALL_STATE(5968)] = 159454,
  [SMALL_STATE(5969)] = 159508,
  [SMALL_STATE(5970)] = 159560,
  [SMALL_STATE(5971)] = 159612,
  [SMALL_STATE(5972)] = 159664,
  [SMALL_STATE(5973)] = 159716,
  [SMALL_STATE(5974)] = 159768,
  [SMALL_STATE(5975)] = 159850,
  [SMALL_STATE(5976)] = 159904,
  [SMALL_STATE(5977)] = 159958,
  [SMALL_STATE(5978)] = 160012,
  [SMALL_STATE(5979)] = 160066,
  [SMALL_STATE(5980)] = 160120,
  [SMALL_STATE(5981)] = 160174,
  [SMALL_STATE(5982)] = 160228,
  [SMALL_STATE(5983)] = 160282,
  [SMALL_STATE(5984)] = 160336,
  [SMALL_STATE(5985)] = 160390,
  [SMALL_STATE(5986)] = 160444,
  [SMALL_STATE(5987)] = 160498,
  [SMALL_STATE(5988)] = 160552,
  [SMALL_STATE(5989)] = 160606,
  [SMALL_STATE(5990)] = 160658,
  [SMALL_STATE(5991)] = 160747,
  [SMALL_STATE(5992)] = 160800,
  [SMALL_STATE(5993)] = 160889,
  [SMALL_STATE(5994)] = 161004,
  [SMALL_STATE(5995)] = 161119,
  [SMALL_STATE(5996)] = 161234,
  [SMALL_STATE(5997)] = 161349,
  [SMALL_STATE(5998)] = 161402,
  [SMALL_STATE(5999)] = 161517,
  [SMALL_STATE(6000)] = 161606,
  [SMALL_STATE(6001)] = 161721,
  [SMALL_STATE(6002)] = 161774,
  [SMALL_STATE(6003)] = 161863,
  [SMALL_STATE(6004)] = 161916,
  [SMALL_STATE(6005)] = 161969,
  [SMALL_STATE(6006)] = 162084,
  [SMALL_STATE(6007)] = 162199,
  [SMALL_STATE(6008)] = 162252,
  [SMALL_STATE(6009)] = 162303,
  [SMALL_STATE(6010)] = 162356,
  [SMALL_STATE(6011)] = 162471,
  [SMALL_STATE(6012)] = 162586,
  [SMALL_STATE(6013)] = 162701,
  [SMALL_STATE(6014)] = 162816,
  [SMALL_STATE(6015)] = 162931,
  [SMALL_STATE(6016)] = 162982,
  [SMALL_STATE(6017)] = 163033,
  [SMALL_STATE(6018)] = 163084,
  [SMALL_STATE(6019)] = 163199,
  [SMALL_STATE(6020)] = 163314,
  [SMALL_STATE(6021)] = 163429,
  [SMALL_STATE(6022)] = 163484,
  [SMALL_STATE(6023)] = 163563,
  [SMALL_STATE(6024)] = 163626,
  [SMALL_STATE(6025)] = 163739,
  [SMALL_STATE(6026)] = 163802,
  [SMALL_STATE(6027)] = 163865,
  [SMALL_STATE(6028)] = 163928,
  [SMALL_STATE(6029)] = 163991,
  [SMALL_STATE(6030)] = 164054,
  [SMALL_STATE(6031)] = 164107,
  [SMALL_STATE(6032)] = 164170,
  [SMALL_STATE(6033)] = 164233,
  [SMALL_STATE(6034)] = 164286,
  [SMALL_STATE(6035)] = 164401,
  [SMALL_STATE(6036)] = 164456,
  [SMALL_STATE(6037)] = 164507,
  [SMALL_STATE(6038)] = 164558,
  [SMALL_STATE(6039)] = 164611,
  [SMALL_STATE(6040)] = 164662,
  [SMALL_STATE(6041)] = 164713,
  [SMALL_STATE(6042)] = 164764,
  [SMALL_STATE(6043)] = 164815,
  [SMALL_STATE(6044)] = 164866,
  [SMALL_STATE(6045)] = 164921,
  [SMALL_STATE(6046)] = 165036,
  [SMALL_STATE(6047)] = 165093,
  [SMALL_STATE(6048)] = 165150,
  [SMALL_STATE(6049)] = 165203,
  [SMALL_STATE(6050)] = 165256,
  [SMALL_STATE(6051)] = 165313,
  [SMALL_STATE(6052)] = 165428,
  [SMALL_STATE(6053)] = 165543,
  [SMALL_STATE(6054)] = 165658,
  [SMALL_STATE(6055)] = 165709,
  [SMALL_STATE(6056)] = 165824,
  [SMALL_STATE(6057)] = 165877,
  [SMALL_STATE(6058)] = 165992,
  [SMALL_STATE(6059)] = 166107,
  [SMALL_STATE(6060)] = 166196,
  [SMALL_STATE(6061)] = 166311,
  [SMALL_STATE(6062)] = 166426,
  [SMALL_STATE(6063)] = 166541,
  [SMALL_STATE(6064)] = 166620,
  [SMALL_STATE(6065)] = 166711,
  [SMALL_STATE(6066)] = 166802,
  [SMALL_STATE(6067)] = 166893,
  [SMALL_STATE(6068)] = 166990,
  [SMALL_STATE(6069)] = 167087,
  [SMALL_STATE(6070)] = 167202,
  [SMALL_STATE(6071)] = 167259,
  [SMALL_STATE(6072)] = 167374,
  [SMALL_STATE(6073)] = 167489,
  [SMALL_STATE(6074)] = 167578,
  [SMALL_STATE(6075)] = 167667,
  [SMALL_STATE(6076)] = 167782,
  [SMALL_STATE(6077)] = 167871,
  [SMALL_STATE(6078)] = 167960,
  [SMALL_STATE(6079)] = 168049,
  [SMALL_STATE(6080)] = 168100,
  [SMALL_STATE(6081)] = 168151,
  [SMALL_STATE(6082)] = 168230,
  [SMALL_STATE(6083)] = 168281,
  [SMALL_STATE(6084)] = 168394,
  [SMALL_STATE(6085)] = 168483,
  [SMALL_STATE(6086)] = 168580,
  [SMALL_STATE(6087)] = 168631,
  [SMALL_STATE(6088)] = 168744,
  [SMALL_STATE(6089)] = 168833,
  [SMALL_STATE(6090)] = 168948,
  [SMALL_STATE(6091)] = 169001,
  [SMALL_STATE(6092)] = 169052,
  [SMALL_STATE(6093)] = 169103,
  [SMALL_STATE(6094)] = 169172,
  [SMALL_STATE(6095)] = 169269,
  [SMALL_STATE(6096)] = 169366,
  [SMALL_STATE(6097)] = 169463,
  [SMALL_STATE(6098)] = 169552,
  [SMALL_STATE(6099)] = 169641,
  [SMALL_STATE(6100)] = 169694,
  [SMALL_STATE(6101)] = 169809,
  [SMALL_STATE(6102)] = 169924,
  [SMALL_STATE(6103)] = 170013,
  [SMALL_STATE(6104)] = 170128,
  [SMALL_STATE(6105)] = 170239,
  [SMALL_STATE(6106)] = 170354,
  [SMALL_STATE(6107)] = 170407,
  [SMALL_STATE(6108)] = 170496,
  [SMALL_STATE(6109)] = 170585,
  [SMALL_STATE(6110)] = 170674,
  [SMALL_STATE(6111)] = 170789,
  [SMALL_STATE(6112)] = 170878,
  [SMALL_STATE(6113)] = 170967,
  [SMALL_STATE(6114)] = 171056,
  [SMALL_STATE(6115)] = 171171,
  [SMALL_STATE(6116)] = 171260,
  [SMALL_STATE(6117)] = 171375,
  [SMALL_STATE(6118)] = 171464,
  [SMALL_STATE(6119)] = 171579,
  [SMALL_STATE(6120)] = 171630,
  [SMALL_STATE(6121)] = 171719,
  [SMALL_STATE(6122)] = 171770,
  [SMALL_STATE(6123)] = 171859,
  [SMALL_STATE(6124)] = 171948,
  [SMALL_STATE(6125)] = 172037,
  [SMALL_STATE(6126)] = 172126,
  [SMALL_STATE(6127)] = 172215,
  [SMALL_STATE(6128)] = 172280,
  [SMALL_STATE(6129)] = 172369,
  [SMALL_STATE(6130)] = 172458,
  [SMALL_STATE(6131)] = 172547,
  [SMALL_STATE(6132)] = 172636,
  [SMALL_STATE(6133)] = 172749,
  [SMALL_STATE(6134)] = 172862,
  [SMALL_STATE(6135)] = 172913,
  [SMALL_STATE(6136)] = 173028,
  [SMALL_STATE(6137)] = 173143,
  [SMALL_STATE(6138)] = 173258,
  [SMALL_STATE(6139)] = 173319,
  [SMALL_STATE(6140)] = 173408,
  [SMALL_STATE(6141)] = 173459,
  [SMALL_STATE(6142)] = 173512,
  [SMALL_STATE(6143)] = 173627,
  [SMALL_STATE(6144)] = 173742,
  [SMALL_STATE(6145)] = 173857,
  [SMALL_STATE(6146)] = 173910,
  [SMALL_STATE(6147)] = 174025,
  [SMALL_STATE(6148)] = 174078,
  [SMALL_STATE(6149)] = 174193,
  [SMALL_STATE(6150)] = 174308,
  [SMALL_STATE(6151)] = 174423,
  [SMALL_STATE(6152)] = 174538,
  [SMALL_STATE(6153)] = 174653,
  [SMALL_STATE(6154)] = 174742,
  [SMALL_STATE(6155)] = 174857,
  [SMALL_STATE(6156)] = 174946,
  [SMALL_STATE(6157)] = 175061,
  [SMALL_STATE(6158)] = 175176,
  [SMALL_STATE(6159)] = 175291,
  [SMALL_STATE(6160)] = 175406,
  [SMALL_STATE(6161)] = 175521,
  [SMALL_STATE(6162)] = 175636,
  [SMALL_STATE(6163)] = 175751,
  [SMALL_STATE(6164)] = 175866,
  [SMALL_STATE(6165)] = 175981,
  [SMALL_STATE(6166)] = 176096,
  [SMALL_STATE(6167)] = 176211,
  [SMALL_STATE(6168)] = 176326,
  [SMALL_STATE(6169)] = 176441,
  [SMALL_STATE(6170)] = 176556,
  [SMALL_STATE(6171)] = 176671,
  [SMALL_STATE(6172)] = 176786,
  [SMALL_STATE(6173)] = 176901,
  [SMALL_STATE(6174)] = 177016,
  [SMALL_STATE(6175)] = 177131,
  [SMALL_STATE(6176)] = 177244,
  [SMALL_STATE(6177)] = 177359,
  [SMALL_STATE(6178)] = 177412,
  [SMALL_STATE(6179)] = 177527,
  [SMALL_STATE(6180)] = 177578,
  [SMALL_STATE(6181)] = 177667,
  [SMALL_STATE(6182)] = 177724,
  [SMALL_STATE(6183)] = 177777,
  [SMALL_STATE(6184)] = 177866,
  [SMALL_STATE(6185)] = 177919,
  [SMALL_STATE(6186)] = 177970,
  [SMALL_STATE(6187)] = 178023,
  [SMALL_STATE(6188)] = 178074,
  [SMALL_STATE(6189)] = 178127,
  [SMALL_STATE(6190)] = 178216,
  [SMALL_STATE(6191)] = 178269,
  [SMALL_STATE(6192)] = 178322,
  [SMALL_STATE(6193)] = 178437,
  [SMALL_STATE(6194)] = 178488,
  [SMALL_STATE(6195)] = 178539,
  [SMALL_STATE(6196)] = 178592,
  [SMALL_STATE(6197)] = 178707,
  [SMALL_STATE(6198)] = 178796,
  [SMALL_STATE(6199)] = 178857,
  [SMALL_STATE(6200)] = 178946,
  [SMALL_STATE(6201)] = 179035,
  [SMALL_STATE(6202)] = 179150,
  [SMALL_STATE(6203)] = 179265,
  [SMALL_STATE(6204)] = 179380,
  [SMALL_STATE(6205)] = 179431,
  [SMALL_STATE(6206)] = 179547,
  [SMALL_STATE(6207)] = 179663,
  [SMALL_STATE(6208)] = 179725,
  [SMALL_STATE(6209)] = 179841,
  [SMALL_STATE(6210)] = 179957,
  [SMALL_STATE(6211)] = 180039,
  [SMALL_STATE(6212)] = 180155,
  [SMALL_STATE(6213)] = 180209,
  [SMALL_STATE(6214)] = 180263,
  [SMALL_STATE(6215)] = 180379,
  [SMALL_STATE(6216)] = 180461,
  [SMALL_STATE(6217)] = 180577,
  [SMALL_STATE(6218)] = 180689,
  [SMALL_STATE(6219)] = 180805,
  [SMALL_STATE(6220)] = 180865,
  [SMALL_STATE(6221)] = 180981,
  [SMALL_STATE(6222)] = 181097,
  [SMALL_STATE(6223)] = 181213,
  [SMALL_STATE(6224)] = 181329,
  [SMALL_STATE(6225)] = 181411,
  [SMALL_STATE(6226)] = 181527,
  [SMALL_STATE(6227)] = 181643,
  [SMALL_STATE(6228)] = 181759,
  [SMALL_STATE(6229)] = 181875,
  [SMALL_STATE(6230)] = 181957,
  [SMALL_STATE(6231)] = 182039,
  [SMALL_STATE(6232)] = 182121,
  [SMALL_STATE(6233)] = 182203,
  [SMALL_STATE(6234)] = 182285,
  [SMALL_STATE(6235)] = 182401,
  [SMALL_STATE(6236)] = 182517,
  [SMALL_STATE(6237)] = 182633,
  [SMALL_STATE(6238)] = 182749,
  [SMALL_STATE(6239)] = 182831,
  [SMALL_STATE(6240)] = 182913,
  [SMALL_STATE(6241)] = 182995,
  [SMALL_STATE(6242)] = 183111,
  [SMALL_STATE(6243)] = 183227,
  [SMALL_STATE(6244)] = 183309,
  [SMALL_STATE(6245)] = 183425,
  [SMALL_STATE(6246)] = 183541,
  [SMALL_STATE(6247)] = 183598,
  [SMALL_STATE(6248)] = 183657,
  [SMALL_STATE(6249)] = 183706,
  [SMALL_STATE(6250)] = 183765,
  [SMALL_STATE(6251)] = 183814,
  [SMALL_STATE(6252)] = 183863,
  [SMALL_STATE(6253)] = 183926,
  [SMALL_STATE(6254)] = 183985,
  [SMALL_STATE(6255)] = 184044,
  [SMALL_STATE(6256)] = 184103,
  [SMALL_STATE(6257)] = 184152,
  [SMALL_STATE(6258)] = 184201,
  [SMALL_STATE(6259)] = 184260,
  [SMALL_STATE(6260)] = 184319,
  [SMALL_STATE(6261)] = 184378,
  [SMALL_STATE(6262)] = 184437,
  [SMALL_STATE(6263)] = 184496,
  [SMALL_STATE(6264)] = 184545,
  [SMALL_STATE(6265)] = 184594,
  [SMALL_STATE(6266)] = 184653,
  [SMALL_STATE(6267)] = 184702,
  [SMALL_STATE(6268)] = 184761,
  [SMALL_STATE(6269)] = 184810,
  [SMALL_STATE(6270)] = 184859,
  [SMALL_STATE(6271)] = 184947,
  [SMALL_STATE(6272)] = 185013,
  [SMALL_STATE(6273)] = 185073,
  [SMALL_STATE(6274)] = 185121,
  [SMALL_STATE(6275)] = 185215,
  [SMALL_STATE(6276)] = 185269,
  [SMALL_STATE(6277)] = 185325,
  [SMALL_STATE(6278)] = 185435,
  [SMALL_STATE(6279)] = 185523,
  [SMALL_STATE(6280)] = 185611,
  [SMALL_STATE(6281)] = 185721,
  [SMALL_STATE(6282)] = 185787,
  [SMALL_STATE(6283)] = 185847,
  [SMALL_STATE(6284)] = 185957,
  [SMALL_STATE(6285)] = 186051,
  [SMALL_STATE(6286)] = 186161,
  [SMALL_STATE(6287)] = 186255,
  [SMALL_STATE(6288)] = 186365,
  [SMALL_STATE(6289)] = 186475,
  [SMALL_STATE(6290)] = 186551,
  [SMALL_STATE(6291)] = 186659,
  [SMALL_STATE(6292)] = 186769,
  [SMALL_STATE(6293)] = 186879,
  [SMALL_STATE(6294)] = 186989,
  [SMALL_STATE(6295)] = 187083,
  [SMALL_STATE(6296)] = 187193,
  [SMALL_STATE(6297)] = 187303,
  [SMALL_STATE(6298)] = 187413,
  [SMALL_STATE(6299)] = 187523,
  [SMALL_STATE(6300)] = 187633,
  [SMALL_STATE(6301)] = 187709,
  [SMALL_STATE(6302)] = 187819,
  [SMALL_STATE(6303)] = 187885,
  [SMALL_STATE(6304)] = 187995,
  [SMALL_STATE(6305)] = 188055,
  [SMALL_STATE(6306)] = 188165,
  [SMALL_STATE(6307)] = 188241,
  [SMALL_STATE(6308)] = 188335,
  [SMALL_STATE(6309)] = 188395,
  [SMALL_STATE(6310)] = 188505,
  [SMALL_STATE(6311)] = 188615,
  [SMALL_STATE(6312)] = 188725,
  [SMALL_STATE(6313)] = 188835,
  [SMALL_STATE(6314)] = 188895,
  [SMALL_STATE(6315)] = 188989,
  [SMALL_STATE(6316)] = 189065,
  [SMALL_STATE(6317)] = 189125,
  [SMALL_STATE(6318)] = 189235,
  [SMALL_STATE(6319)] = 189293,
  [SMALL_STATE(6320)] = 189353,
  [SMALL_STATE(6321)] = 189463,
  [SMALL_STATE(6322)] = 189573,
  [SMALL_STATE(6323)] = 189625,
  [SMALL_STATE(6324)] = 189711,
  [SMALL_STATE(6325)] = 189821,
  [SMALL_STATE(6326)] = 189877,
  [SMALL_STATE(6327)] = 189937,
  [SMALL_STATE(6328)] = 190047,
  [SMALL_STATE(6329)] = 190157,
  [SMALL_STATE(6330)] = 190207,
  [SMALL_STATE(6331)] = 190257,
  [SMALL_STATE(6332)] = 190308,
  [SMALL_STATE(6333)] = 190375,
  [SMALL_STATE(6334)] = 190442,
  [SMALL_STATE(6335)] = 190503,
  [SMALL_STATE(6336)] = 190570,
  [SMALL_STATE(6337)] = 190637,
  [SMALL_STATE(6338)] = 190744,
  [SMALL_STATE(6339)] = 190851,
  [SMALL_STATE(6340)] = 190958,
  [SMALL_STATE(6341)] = 191011,
  [SMALL_STATE(6342)] = 191072,
  [SMALL_STATE(6343)] = 191139,
  [SMALL_STATE(6344)] = 191206,
  [SMALL_STATE(6345)] = 191259,
  [SMALL_STATE(6346)] = 191366,
  [SMALL_STATE(6347)] = 191473,
  [SMALL_STATE(6348)] = 191580,
  [SMALL_STATE(6349)] = 191633,
  [SMALL_STATE(6350)] = 191686,
  [SMALL_STATE(6351)] = 191753,
  [SMALL_STATE(6352)] = 191820,
  [SMALL_STATE(6353)] = 191873,
  [SMALL_STATE(6354)] = 191926,
  [SMALL_STATE(6355)] = 192033,
  [SMALL_STATE(6356)] = 192140,
  [SMALL_STATE(6357)] = 192193,
  [SMALL_STATE(6358)] = 192246,
  [SMALL_STATE(6359)] = 192297,
  [SMALL_STATE(6360)] = 192350,
  [SMALL_STATE(6361)] = 192403,
  [SMALL_STATE(6362)] = 192456,
  [SMALL_STATE(6363)] = 192509,
  [SMALL_STATE(6364)] = 192562,
  [SMALL_STATE(6365)] = 192612,
  [SMALL_STATE(6366)] = 192660,
  [SMALL_STATE(6367)] = 192706,
  [SMALL_STATE(6368)] = 192756,
  [SMALL_STATE(6369)] = 192804,
  [SMALL_STATE(6370)] = 192852,
  [SMALL_STATE(6371)] = 192900,
  [SMALL_STATE(6372)] = 192950,
  [SMALL_STATE(6373)] = 193000,
  [SMALL_STATE(6374)] = 193048,
  [SMALL_STATE(6375)] = 193098,
  [SMALL_STATE(6376)] = 193148,
  [SMALL_STATE(6377)] = 193198,
  [SMALL_STATE(6378)] = 193248,
  [SMALL_STATE(6379)] = 193298,
  [SMALL_STATE(6380)] = 193348,
  [SMALL_STATE(6381)] = 193398,
  [SMALL_STATE(6382)] = 193443,
  [SMALL_STATE(6383)] = 193488,
  [SMALL_STATE(6384)] = 193533,
  [SMALL_STATE(6385)] = 193578,
  [SMALL_STATE(6386)] = 193625,
  [SMALL_STATE(6387)] = 193670,
  [SMALL_STATE(6388)] = 193715,
  [SMALL_STATE(6389)] = 193760,
  [SMALL_STATE(6390)] = 193805,
  [SMALL_STATE(6391)] = 193850,
  [SMALL_STATE(6392)] = 193895,
  [SMALL_STATE(6393)] = 193940,
  [SMALL_STATE(6394)] = 193985,
  [SMALL_STATE(6395)] = 194030,
  [SMALL_STATE(6396)] = 194075,
  [SMALL_STATE(6397)] = 194124,
  [SMALL_STATE(6398)] = 194169,
  [SMALL_STATE(6399)] = 194214,
  [SMALL_STATE(6400)] = 194259,
  [SMALL_STATE(6401)] = 194304,
  [SMALL_STATE(6402)] = 194349,
  [SMALL_STATE(6403)] = 194394,
  [SMALL_STATE(6404)] = 194439,
  [SMALL_STATE(6405)] = 194484,
  [SMALL_STATE(6406)] = 194529,
  [SMALL_STATE(6407)] = 194574,
  [SMALL_STATE(6408)] = 194619,
  [SMALL_STATE(6409)] = 194664,
  [SMALL_STATE(6410)] = 194709,
  [SMALL_STATE(6411)] = 194754,
  [SMALL_STATE(6412)] = 194799,
  [SMALL_STATE(6413)] = 194844,
  [SMALL_STATE(6414)] = 194889,
  [SMALL_STATE(6415)] = 194934,
  [SMALL_STATE(6416)] = 194979,
  [SMALL_STATE(6417)] = 195024,
  [SMALL_STATE(6418)] = 195069,
  [SMALL_STATE(6419)] = 195114,
  [SMALL_STATE(6420)] = 195159,
  [SMALL_STATE(6421)] = 195204,
  [SMALL_STATE(6422)] = 195249,
  [SMALL_STATE(6423)] = 195294,
  [SMALL_STATE(6424)] = 195339,
  [SMALL_STATE(6425)] = 195384,
  [SMALL_STATE(6426)] = 195429,
  [SMALL_STATE(6427)] = 195474,
  [SMALL_STATE(6428)] = 195519,
  [SMALL_STATE(6429)] = 195564,
  [SMALL_STATE(6430)] = 195609,
  [SMALL_STATE(6431)] = 195654,
  [SMALL_STATE(6432)] = 195699,
  [SMALL_STATE(6433)] = 195744,
  [SMALL_STATE(6434)] = 195789,
  [SMALL_STATE(6435)] = 195834,
  [SMALL_STATE(6436)] = 195883,
  [SMALL_STATE(6437)] = 195928,
  [SMALL_STATE(6438)] = 195973,
  [SMALL_STATE(6439)] = 196018,
  [SMALL_STATE(6440)] = 196063,
  [SMALL_STATE(6441)] = 196108,
  [SMALL_STATE(6442)] = 196153,
  [SMALL_STATE(6443)] = 196198,
  [SMALL_STATE(6444)] = 196243,
  [SMALL_STATE(6445)] = 196288,
  [SMALL_STATE(6446)] = 196333,
  [SMALL_STATE(6447)] = 196378,
  [SMALL_STATE(6448)] = 196423,
  [SMALL_STATE(6449)] = 196468,
  [SMALL_STATE(6450)] = 196513,
  [SMALL_STATE(6451)] = 196558,
  [SMALL_STATE(6452)] = 196603,
  [SMALL_STATE(6453)] = 196648,
  [SMALL_STATE(6454)] = 196693,
  [SMALL_STATE(6455)] = 196738,
  [SMALL_STATE(6456)] = 196783,
  [SMALL_STATE(6457)] = 196828,
  [SMALL_STATE(6458)] = 196873,
  [SMALL_STATE(6459)] = 196920,
  [SMALL_STATE(6460)] = 196967,
  [SMALL_STATE(6461)] = 197014,
  [SMALL_STATE(6462)] = 197059,
  [SMALL_STATE(6463)] = 197104,
  [SMALL_STATE(6464)] = 197149,
  [SMALL_STATE(6465)] = 197194,
  [SMALL_STATE(6466)] = 197239,
  [SMALL_STATE(6467)] = 197284,
  [SMALL_STATE(6468)] = 197329,
  [SMALL_STATE(6469)] = 197374,
  [SMALL_STATE(6470)] = 197419,
  [SMALL_STATE(6471)] = 197466,
  [SMALL_STATE(6472)] = 197511,
  [SMALL_STATE(6473)] = 197556,
  [SMALL_STATE(6474)] = 197601,
  [SMALL_STATE(6475)] = 197646,
  [SMALL_STATE(6476)] = 197691,
  [SMALL_STATE(6477)] = 197736,
  [SMALL_STATE(6478)] = 197781,
  [SMALL_STATE(6479)] = 197826,
  [SMALL_STATE(6480)] = 197871,
  [SMALL_STATE(6481)] = 197916,
  [SMALL_STATE(6482)] = 197961,
  [SMALL_STATE(6483)] = 198006,
  [SMALL_STATE(6484)] = 198053,
  [SMALL_STATE(6485)] = 198098,
  [SMALL_STATE(6486)] = 198143,
  [SMALL_STATE(6487)] = 198188,
  [SMALL_STATE(6488)] = 198233,
  [SMALL_STATE(6489)] = 198278,
  [SMALL_STATE(6490)] = 198323,
  [SMALL_STATE(6491)] = 198370,
  [SMALL_STATE(6492)] = 198417,
  [SMALL_STATE(6493)] = 198462,
  [SMALL_STATE(6494)] = 198507,
  [SMALL_STATE(6495)] = 198552,
  [SMALL_STATE(6496)] = 198597,
  [SMALL_STATE(6497)] = 198642,
  [SMALL_STATE(6498)] = 198687,
  [SMALL_STATE(6499)] = 198732,
  [SMALL_STATE(6500)] = 198777,
  [SMALL_STATE(6501)] = 198822,
  [SMALL_STATE(6502)] = 198867,
  [SMALL_STATE(6503)] = 198912,
  [SMALL_STATE(6504)] = 198957,
  [SMALL_STATE(6505)] = 199002,
  [SMALL_STATE(6506)] = 199047,
  [SMALL_STATE(6507)] = 199092,
  [SMALL_STATE(6508)] = 199137,
  [SMALL_STATE(6509)] = 199182,
  [SMALL_STATE(6510)] = 199227,
  [SMALL_STATE(6511)] = 199274,
  [SMALL_STATE(6512)] = 199319,
  [SMALL_STATE(6513)] = 199364,
  [SMALL_STATE(6514)] = 199411,
  [SMALL_STATE(6515)] = 199458,
  [SMALL_STATE(6516)] = 199503,
  [SMALL_STATE(6517)] = 199548,
  [SMALL_STATE(6518)] = 199593,
  [SMALL_STATE(6519)] = 199638,
  [SMALL_STATE(6520)] = 199683,
  [SMALL_STATE(6521)] = 199728,
  [SMALL_STATE(6522)] = 199773,
  [SMALL_STATE(6523)] = 199818,
  [SMALL_STATE(6524)] = 199863,
  [SMALL_STATE(6525)] = 199908,
  [SMALL_STATE(6526)] = 199953,
  [SMALL_STATE(6527)] = 199998,
  [SMALL_STATE(6528)] = 200043,
  [SMALL_STATE(6529)] = 200088,
  [SMALL_STATE(6530)] = 200133,
  [SMALL_STATE(6531)] = 200178,
  [SMALL_STATE(6532)] = 200223,
  [SMALL_STATE(6533)] = 200268,
  [SMALL_STATE(6534)] = 200313,
  [SMALL_STATE(6535)] = 200358,
  [SMALL_STATE(6536)] = 200403,
  [SMALL_STATE(6537)] = 200448,
  [SMALL_STATE(6538)] = 200493,
  [SMALL_STATE(6539)] = 200538,
  [SMALL_STATE(6540)] = 200583,
  [SMALL_STATE(6541)] = 200630,
  [SMALL_STATE(6542)] = 200677,
  [SMALL_STATE(6543)] = 200722,
  [SMALL_STATE(6544)] = 200767,
  [SMALL_STATE(6545)] = 200812,
  [SMALL_STATE(6546)] = 200859,
  [SMALL_STATE(6547)] = 200906,
  [SMALL_STATE(6548)] = 200953,
  [SMALL_STATE(6549)] = 201000,
  [SMALL_STATE(6550)] = 201045,
  [SMALL_STATE(6551)] = 201090,
  [SMALL_STATE(6552)] = 201135,
  [SMALL_STATE(6553)] = 201180,
  [SMALL_STATE(6554)] = 201225,
  [SMALL_STATE(6555)] = 201270,
  [SMALL_STATE(6556)] = 201315,
  [SMALL_STATE(6557)] = 201360,
  [SMALL_STATE(6558)] = 201407,
  [SMALL_STATE(6559)] = 201454,
  [SMALL_STATE(6560)] = 201501,
  [SMALL_STATE(6561)] = 201548,
  [SMALL_STATE(6562)] = 201593,
  [SMALL_STATE(6563)] = 201640,
  [SMALL_STATE(6564)] = 201687,
  [SMALL_STATE(6565)] = 201734,
  [SMALL_STATE(6566)] = 201781,
  [SMALL_STATE(6567)] = 201828,
  [SMALL_STATE(6568)] = 201873,
  [SMALL_STATE(6569)] = 201920,
  [SMALL_STATE(6570)] = 201965,
  [SMALL_STATE(6571)] = 202010,
  [SMALL_STATE(6572)] = 202055,
  [SMALL_STATE(6573)] = 202100,
  [SMALL_STATE(6574)] = 202145,
  [SMALL_STATE(6575)] = 202190,
  [SMALL_STATE(6576)] = 202235,
  [SMALL_STATE(6577)] = 202282,
  [SMALL_STATE(6578)] = 202327,
  [SMALL_STATE(6579)] = 202372,
  [SMALL_STATE(6580)] = 202417,
  [SMALL_STATE(6581)] = 202462,
  [SMALL_STATE(6582)] = 202507,
  [SMALL_STATE(6583)] = 202552,
  [SMALL_STATE(6584)] = 202597,
  [SMALL_STATE(6585)] = 202642,
  [SMALL_STATE(6586)] = 202687,
  [SMALL_STATE(6587)] = 202732,
  [SMALL_STATE(6588)] = 202777,
  [SMALL_STATE(6589)] = 202822,
  [SMALL_STATE(6590)] = 202867,
  [SMALL_STATE(6591)] = 202912,
  [SMALL_STATE(6592)] = 202957,
  [SMALL_STATE(6593)] = 203002,
  [SMALL_STATE(6594)] = 203047,
  [SMALL_STATE(6595)] = 203092,
  [SMALL_STATE(6596)] = 203137,
  [SMALL_STATE(6597)] = 203182,
  [SMALL_STATE(6598)] = 203227,
  [SMALL_STATE(6599)] = 203272,
  [SMALL_STATE(6600)] = 203317,
  [SMALL_STATE(6601)] = 203362,
  [SMALL_STATE(6602)] = 203407,
  [SMALL_STATE(6603)] = 203452,
  [SMALL_STATE(6604)] = 203497,
  [SMALL_STATE(6605)] = 203542,
  [SMALL_STATE(6606)] = 203587,
  [SMALL_STATE(6607)] = 203634,
  [SMALL_STATE(6608)] = 203681,
  [SMALL_STATE(6609)] = 203726,
  [SMALL_STATE(6610)] = 203771,
  [SMALL_STATE(6611)] = 203816,
  [SMALL_STATE(6612)] = 203861,
  [SMALL_STATE(6613)] = 203906,
  [SMALL_STATE(6614)] = 203951,
  [SMALL_STATE(6615)] = 203998,
  [SMALL_STATE(6616)] = 204045,
  [SMALL_STATE(6617)] = 204090,
  [SMALL_STATE(6618)] = 204135,
  [SMALL_STATE(6619)] = 204182,
  [SMALL_STATE(6620)] = 204227,
  [SMALL_STATE(6621)] = 204274,
  [SMALL_STATE(6622)] = 204321,
  [SMALL_STATE(6623)] = 204368,
  [SMALL_STATE(6624)] = 204413,
  [SMALL_STATE(6625)] = 204460,
  [SMALL_STATE(6626)] = 204507,
  [SMALL_STATE(6627)] = 204552,
  [SMALL_STATE(6628)] = 204597,
  [SMALL_STATE(6629)] = 204644,
  [SMALL_STATE(6630)] = 204689,
  [SMALL_STATE(6631)] = 204734,
  [SMALL_STATE(6632)] = 204781,
  [SMALL_STATE(6633)] = 204828,
  [SMALL_STATE(6634)] = 204875,
  [SMALL_STATE(6635)] = 204920,
  [SMALL_STATE(6636)] = 204965,
  [SMALL_STATE(6637)] = 205012,
  [SMALL_STATE(6638)] = 205057,
  [SMALL_STATE(6639)] = 205104,
  [SMALL_STATE(6640)] = 205151,
  [SMALL_STATE(6641)] = 205198,
  [SMALL_STATE(6642)] = 205245,
  [SMALL_STATE(6643)] = 205292,
  [SMALL_STATE(6644)] = 205337,
  [SMALL_STATE(6645)] = 205382,
  [SMALL_STATE(6646)] = 205427,
  [SMALL_STATE(6647)] = 205472,
  [SMALL_STATE(6648)] = 205517,
  [SMALL_STATE(6649)] = 205562,
  [SMALL_STATE(6650)] = 205607,
  [SMALL_STATE(6651)] = 205652,
  [SMALL_STATE(6652)] = 205697,
  [SMALL_STATE(6653)] = 205742,
  [SMALL_STATE(6654)] = 205787,
  [SMALL_STATE(6655)] = 205832,
  [SMALL_STATE(6656)] = 205877,
  [SMALL_STATE(6657)] = 205922,
  [SMALL_STATE(6658)] = 205969,
  [SMALL_STATE(6659)] = 206016,
  [SMALL_STATE(6660)] = 206061,
  [SMALL_STATE(6661)] = 206106,
  [SMALL_STATE(6662)] = 206151,
  [SMALL_STATE(6663)] = 206196,
  [SMALL_STATE(6664)] = 206241,
  [SMALL_STATE(6665)] = 206286,
  [SMALL_STATE(6666)] = 206333,
  [SMALL_STATE(6667)] = 206380,
  [SMALL_STATE(6668)] = 206425,
  [SMALL_STATE(6669)] = 206470,
  [SMALL_STATE(6670)] = 206515,
  [SMALL_STATE(6671)] = 206560,
  [SMALL_STATE(6672)] = 206609,
  [SMALL_STATE(6673)] = 206654,
  [SMALL_STATE(6674)] = 206699,
  [SMALL_STATE(6675)] = 206746,
  [SMALL_STATE(6676)] = 206793,
  [SMALL_STATE(6677)] = 206838,
  [SMALL_STATE(6678)] = 206883,
  [SMALL_STATE(6679)] = 206928,
  [SMALL_STATE(6680)] = 206973,
  [SMALL_STATE(6681)] = 207018,
  [SMALL_STATE(6682)] = 207065,
  [SMALL_STATE(6683)] = 207112,
  [SMALL_STATE(6684)] = 207157,
  [SMALL_STATE(6685)] = 207202,
  [SMALL_STATE(6686)] = 207247,
  [SMALL_STATE(6687)] = 207294,
  [SMALL_STATE(6688)] = 207341,
  [SMALL_STATE(6689)] = 207386,
  [SMALL_STATE(6690)] = 207431,
  [SMALL_STATE(6691)] = 207476,
  [SMALL_STATE(6692)] = 207521,
  [SMALL_STATE(6693)] = 207566,
  [SMALL_STATE(6694)] = 207611,
  [SMALL_STATE(6695)] = 207656,
  [SMALL_STATE(6696)] = 207701,
  [SMALL_STATE(6697)] = 207746,
  [SMALL_STATE(6698)] = 207791,
  [SMALL_STATE(6699)] = 207836,
  [SMALL_STATE(6700)] = 207881,
  [SMALL_STATE(6701)] = 207926,
  [SMALL_STATE(6702)] = 207971,
  [SMALL_STATE(6703)] = 208016,
  [SMALL_STATE(6704)] = 208061,
  [SMALL_STATE(6705)] = 208106,
  [SMALL_STATE(6706)] = 208151,
  [SMALL_STATE(6707)] = 208196,
  [SMALL_STATE(6708)] = 208241,
  [SMALL_STATE(6709)] = 208286,
  [SMALL_STATE(6710)] = 208331,
  [SMALL_STATE(6711)] = 208376,
  [SMALL_STATE(6712)] = 208421,
  [SMALL_STATE(6713)] = 208466,
  [SMALL_STATE(6714)] = 208511,
  [SMALL_STATE(6715)] = 208556,
  [SMALL_STATE(6716)] = 208601,
  [SMALL_STATE(6717)] = 208646,
  [SMALL_STATE(6718)] = 208691,
  [SMALL_STATE(6719)] = 208736,
  [SMALL_STATE(6720)] = 208781,
  [SMALL_STATE(6721)] = 208826,
  [SMALL_STATE(6722)] = 208871,
  [SMALL_STATE(6723)] = 208916,
  [SMALL_STATE(6724)] = 208961,
  [SMALL_STATE(6725)] = 209006,
  [SMALL_STATE(6726)] = 209053,
  [SMALL_STATE(6727)] = 209100,
  [SMALL_STATE(6728)] = 209145,
  [SMALL_STATE(6729)] = 209190,
  [SMALL_STATE(6730)] = 209235,
  [SMALL_STATE(6731)] = 209280,
  [SMALL_STATE(6732)] = 209325,
  [SMALL_STATE(6733)] = 209370,
  [SMALL_STATE(6734)] = 209417,
  [SMALL_STATE(6735)] = 209462,
  [SMALL_STATE(6736)] = 209507,
  [SMALL_STATE(6737)] = 209552,
  [SMALL_STATE(6738)] = 209597,
  [SMALL_STATE(6739)] = 209642,
  [SMALL_STATE(6740)] = 209687,
  [SMALL_STATE(6741)] = 209732,
  [SMALL_STATE(6742)] = 209777,
  [SMALL_STATE(6743)] = 209822,
  [SMALL_STATE(6744)] = 209867,
  [SMALL_STATE(6745)] = 209912,
  [SMALL_STATE(6746)] = 209957,
  [SMALL_STATE(6747)] = 210002,
  [SMALL_STATE(6748)] = 210047,
  [SMALL_STATE(6749)] = 210092,
  [SMALL_STATE(6750)] = 210137,
  [SMALL_STATE(6751)] = 210182,
  [SMALL_STATE(6752)] = 210227,
  [SMALL_STATE(6753)] = 210272,
  [SMALL_STATE(6754)] = 210317,
  [SMALL_STATE(6755)] = 210362,
  [SMALL_STATE(6756)] = 210407,
  [SMALL_STATE(6757)] = 210452,
  [SMALL_STATE(6758)] = 210497,
  [SMALL_STATE(6759)] = 210542,
  [SMALL_STATE(6760)] = 210589,
  [SMALL_STATE(6761)] = 210634,
  [SMALL_STATE(6762)] = 210679,
  [SMALL_STATE(6763)] = 210724,
  [SMALL_STATE(6764)] = 210769,
  [SMALL_STATE(6765)] = 210814,
  [SMALL_STATE(6766)] = 210859,
  [SMALL_STATE(6767)] = 210904,
  [SMALL_STATE(6768)] = 210949,
  [SMALL_STATE(6769)] = 210994,
  [SMALL_STATE(6770)] = 211039,
  [SMALL_STATE(6771)] = 211084,
  [SMALL_STATE(6772)] = 211129,
  [SMALL_STATE(6773)] = 211174,
  [SMALL_STATE(6774)] = 211219,
  [SMALL_STATE(6775)] = 211264,
  [SMALL_STATE(6776)] = 211309,
  [SMALL_STATE(6777)] = 211354,
  [SMALL_STATE(6778)] = 211399,
  [SMALL_STATE(6779)] = 211444,
  [SMALL_STATE(6780)] = 211489,
  [SMALL_STATE(6781)] = 211534,
  [SMALL_STATE(6782)] = 211579,
  [SMALL_STATE(6783)] = 211624,
  [SMALL_STATE(6784)] = 211669,
  [SMALL_STATE(6785)] = 211714,
  [SMALL_STATE(6786)] = 211759,
  [SMALL_STATE(6787)] = 211804,
  [SMALL_STATE(6788)] = 211849,
  [SMALL_STATE(6789)] = 211894,
  [SMALL_STATE(6790)] = 211938,
  [SMALL_STATE(6791)] = 211986,
  [SMALL_STATE(6792)] = 212030,
  [SMALL_STATE(6793)] = 212078,
  [SMALL_STATE(6794)] = 212140,
  [SMALL_STATE(6795)] = 212202,
  [SMALL_STATE(6796)] = 212264,
  [SMALL_STATE(6797)] = 212312,
  [SMALL_STATE(6798)] = 212374,
  [SMALL_STATE(6799)] = 212436,
  [SMALL_STATE(6800)] = 212484,
  [SMALL_STATE(6801)] = 212532,
  [SMALL_STATE(6802)] = 212583,
  [SMALL_STATE(6803)] = 212646,
  [SMALL_STATE(6804)] = 212689,
  [SMALL_STATE(6805)] = 212732,
  [SMALL_STATE(6806)] = 212775,
  [SMALL_STATE(6807)] = 212820,
  [SMALL_STATE(6808)] = 212883,
  [SMALL_STATE(6809)] = 212926,
  [SMALL_STATE(6810)] = 212989,
  [SMALL_STATE(6811)] = 213032,
  [SMALL_STATE(6812)] = 213077,
  [SMALL_STATE(6813)] = 213122,
  [SMALL_STATE(6814)] = 213185,
  [SMALL_STATE(6815)] = 213228,
  [SMALL_STATE(6816)] = 213271,
  [SMALL_STATE(6817)] = 213314,
  [SMALL_STATE(6818)] = 213357,
  [SMALL_STATE(6819)] = 213400,
  [SMALL_STATE(6820)] = 213445,
  [SMALL_STATE(6821)] = 213488,
  [SMALL_STATE(6822)] = 213531,
  [SMALL_STATE(6823)] = 213574,
  [SMALL_STATE(6824)] = 213637,
  [SMALL_STATE(6825)] = 213680,
  [SMALL_STATE(6826)] = 213743,
  [SMALL_STATE(6827)] = 213790,
  [SMALL_STATE(6828)] = 213853,
  [SMALL_STATE(6829)] = 213896,
  [SMALL_STATE(6830)] = 213939,
  [SMALL_STATE(6831)] = 214002,
  [SMALL_STATE(6832)] = 214065,
  [SMALL_STATE(6833)] = 214108,
  [SMALL_STATE(6834)] = 214151,
  [SMALL_STATE(6835)] = 214200,
  [SMALL_STATE(6836)] = 214243,
  [SMALL_STATE(6837)] = 214306,
  [SMALL_STATE(6838)] = 214349,
  [SMALL_STATE(6839)] = 214412,
  [SMALL_STATE(6840)] = 214455,
  [SMALL_STATE(6841)] = 214506,
  [SMALL_STATE(6842)] = 214549,
  [SMALL_STATE(6843)] = 214592,
  [SMALL_STATE(6844)] = 214641,
  [SMALL_STATE(6845)] = 214704,
  [SMALL_STATE(6846)] = 214748,
  [SMALL_STATE(6847)] = 214790,
  [SMALL_STATE(6848)] = 214832,
  [SMALL_STATE(6849)] = 214874,
  [SMALL_STATE(6850)] = 214916,
  [SMALL_STATE(6851)] = 214958,
  [SMALL_STATE(6852)] = 215000,
  [SMALL_STATE(6853)] = 215042,
  [SMALL_STATE(6854)] = 215084,
  [SMALL_STATE(6855)] = 215126,
  [SMALL_STATE(6856)] = 215168,
  [SMALL_STATE(6857)] = 215210,
  [SMALL_STATE(6858)] = 215252,
  [SMALL_STATE(6859)] = 215294,
  [SMALL_STATE(6860)] = 215336,
  [SMALL_STATE(6861)] = 215380,
  [SMALL_STATE(6862)] = 215422,
  [SMALL_STATE(6863)] = 215464,
  [SMALL_STATE(6864)] = 215506,
  [SMALL_STATE(6865)] = 215548,
  [SMALL_STATE(6866)] = 215590,
  [SMALL_STATE(6867)] = 215632,
  [SMALL_STATE(6868)] = 215676,
  [SMALL_STATE(6869)] = 215720,
  [SMALL_STATE(6870)] = 215764,
  [SMALL_STATE(6871)] = 215806,
  [SMALL_STATE(6872)] = 215848,
  [SMALL_STATE(6873)] = 215890,
  [SMALL_STATE(6874)] = 215934,
  [SMALL_STATE(6875)] = 215976,
  [SMALL_STATE(6876)] = 216020,
  [SMALL_STATE(6877)] = 216064,
  [SMALL_STATE(6878)] = 216106,
  [SMALL_STATE(6879)] = 216148,
  [SMALL_STATE(6880)] = 216190,
  [SMALL_STATE(6881)] = 216232,
  [SMALL_STATE(6882)] = 216276,
  [SMALL_STATE(6883)] = 216320,
  [SMALL_STATE(6884)] = 216362,
  [SMALL_STATE(6885)] = 216406,
  [SMALL_STATE(6886)] = 216451,
  [SMALL_STATE(6887)] = 216496,
  [SMALL_STATE(6888)] = 216541,
  [SMALL_STATE(6889)] = 216583,
  [SMALL_STATE(6890)] = 216653,
  [SMALL_STATE(6891)] = 216723,
  [SMALL_STATE(6892)] = 216763,
  [SMALL_STATE(6893)] = 216833,
  [SMALL_STATE(6894)] = 216875,
  [SMALL_STATE(6895)] = 216917,
  [SMALL_STATE(6896)] = 216959,
  [SMALL_STATE(6897)] = 216999,
  [SMALL_STATE(6898)] = 217069,
  [SMALL_STATE(6899)] = 217139,
  [SMALL_STATE(6900)] = 217209,
  [SMALL_STATE(6901)] = 217251,
  [SMALL_STATE(6902)] = 217293,
  [SMALL_STATE(6903)] = 217335,
  [SMALL_STATE(6904)] = 217377,
  [SMALL_STATE(6905)] = 217419,
  [SMALL_STATE(6906)] = 217461,
  [SMALL_STATE(6907)] = 217503,
  [SMALL_STATE(6908)] = 217545,
  [SMALL_STATE(6909)] = 217587,
  [SMALL_STATE(6910)] = 217629,
  [SMALL_STATE(6911)] = 217671,
  [SMALL_STATE(6912)] = 217713,
  [SMALL_STATE(6913)] = 217755,
  [SMALL_STATE(6914)] = 217797,
  [SMALL_STATE(6915)] = 217839,
  [SMALL_STATE(6916)] = 217881,
  [SMALL_STATE(6917)] = 217923,
  [SMALL_STATE(6918)] = 217965,
  [SMALL_STATE(6919)] = 218007,
  [SMALL_STATE(6920)] = 218049,
  [SMALL_STATE(6921)] = 218091,
  [SMALL_STATE(6922)] = 218133,
  [SMALL_STATE(6923)] = 218175,
  [SMALL_STATE(6924)] = 218217,
  [SMALL_STATE(6925)] = 218259,
  [SMALL_STATE(6926)] = 218301,
  [SMALL_STATE(6927)] = 218341,
  [SMALL_STATE(6928)] = 218383,
  [SMALL_STATE(6929)] = 218453,
  [SMALL_STATE(6930)] = 218493,
  [SMALL_STATE(6931)] = 218535,
  [SMALL_STATE(6932)] = 218605,
  [SMALL_STATE(6933)] = 218675,
  [SMALL_STATE(6934)] = 218745,
  [SMALL_STATE(6935)] = 218787,
  [SMALL_STATE(6936)] = 218829,
  [SMALL_STATE(6937)] = 218871,
  [SMALL_STATE(6938)] = 218913,
  [SMALL_STATE(6939)] = 218983,
  [SMALL_STATE(6940)] = 219023,
  [SMALL_STATE(6941)] = 219065,
  [SMALL_STATE(6942)] = 219107,
  [SMALL_STATE(6943)] = 219177,
  [SMALL_STATE(6944)] = 219219,
  [SMALL_STATE(6945)] = 219261,
  [SMALL_STATE(6946)] = 219303,
  [SMALL_STATE(6947)] = 219345,
  [SMALL_STATE(6948)] = 219387,
  [SMALL_STATE(6949)] = 219429,
  [SMALL_STATE(6950)] = 219469,
  [SMALL_STATE(6951)] = 219511,
  [SMALL_STATE(6952)] = 219553,
  [SMALL_STATE(6953)] = 219595,
  [SMALL_STATE(6954)] = 219637,
  [SMALL_STATE(6955)] = 219679,
  [SMALL_STATE(6956)] = 219721,
  [SMALL_STATE(6957)] = 219763,
  [SMALL_STATE(6958)] = 219805,
  [SMALL_STATE(6959)] = 219847,
  [SMALL_STATE(6960)] = 219887,
  [SMALL_STATE(6961)] = 219929,
  [SMALL_STATE(6962)] = 219971,
  [SMALL_STATE(6963)] = 220013,
  [SMALL_STATE(6964)] = 220055,
  [SMALL_STATE(6965)] = 220097,
  [SMALL_STATE(6966)] = 220139,
  [SMALL_STATE(6967)] = 220181,
  [SMALL_STATE(6968)] = 220223,
  [SMALL_STATE(6969)] = 220265,
  [SMALL_STATE(6970)] = 220307,
  [SMALL_STATE(6971)] = 220349,
  [SMALL_STATE(6972)] = 220391,
  [SMALL_STATE(6973)] = 220433,
  [SMALL_STATE(6974)] = 220475,
  [SMALL_STATE(6975)] = 220517,
  [SMALL_STATE(6976)] = 220559,
  [SMALL_STATE(6977)] = 220601,
  [SMALL_STATE(6978)] = 220643,
  [SMALL_STATE(6979)] = 220685,
  [SMALL_STATE(6980)] = 220727,
  [SMALL_STATE(6981)] = 220769,
  [SMALL_STATE(6982)] = 220839,
  [SMALL_STATE(6983)] = 220881,
  [SMALL_STATE(6984)] = 220921,
  [SMALL_STATE(6985)] = 220963,
  [SMALL_STATE(6986)] = 221033,
  [SMALL_STATE(6987)] = 221103,
  [SMALL_STATE(6988)] = 221173,
  [SMALL_STATE(6989)] = 221215,
  [SMALL_STATE(6990)] = 221257,
  [SMALL_STATE(6991)] = 221299,
  [SMALL_STATE(6992)] = 221341,
  [SMALL_STATE(6993)] = 221383,
  [SMALL_STATE(6994)] = 221425,
  [SMALL_STATE(6995)] = 221467,
  [SMALL_STATE(6996)] = 221509,
  [SMALL_STATE(6997)] = 221579,
  [SMALL_STATE(6998)] = 221621,
  [SMALL_STATE(6999)] = 221663,
  [SMALL_STATE(7000)] = 221733,
  [SMALL_STATE(7001)] = 221775,
  [SMALL_STATE(7002)] = 221845,
  [SMALL_STATE(7003)] = 221915,
  [SMALL_STATE(7004)] = 221957,
  [SMALL_STATE(7005)] = 222026,
  [SMALL_STATE(7006)] = 222095,
  [SMALL_STATE(7007)] = 222152,
  [SMALL_STATE(7008)] = 222221,
  [SMALL_STATE(7009)] = 222290,
  [SMALL_STATE(7010)] = 222359,
  [SMALL_STATE(7011)] = 222416,
  [SMALL_STATE(7012)] = 222485,
  [SMALL_STATE(7013)] = 222554,
  [SMALL_STATE(7014)] = 222623,
  [SMALL_STATE(7015)] = 222692,
  [SMALL_STATE(7016)] = 222761,
  [SMALL_STATE(7017)] = 222830,
  [SMALL_STATE(7018)] = 222899,
  [SMALL_STATE(7019)] = 222968,
  [SMALL_STATE(7020)] = 223037,
  [SMALL_STATE(7021)] = 223099,
  [SMALL_STATE(7022)] = 223161,
  [SMALL_STATE(7023)] = 223223,
  [SMALL_STATE(7024)] = 223263,
  [SMALL_STATE(7025)] = 223325,
  [SMALL_STATE(7026)] = 223363,
  [SMALL_STATE(7027)] = 223425,
  [SMALL_STATE(7028)] = 223465,
  [SMALL_STATE(7029)] = 223527,
  [SMALL_STATE(7030)] = 223568,
  [SMALL_STATE(7031)] = 223607,
  [SMALL_STATE(7032)] = 223646,
  [SMALL_STATE(7033)] = 223687,
  [SMALL_STATE(7034)] = 223728,
  [SMALL_STATE(7035)] = 223766,
  [SMALL_STATE(7036)] = 223804,
  [SMALL_STATE(7037)] = 223842,
  [SMALL_STATE(7038)] = 223880,
  [SMALL_STATE(7039)] = 223918,
  [SMALL_STATE(7040)] = 223956,
  [SMALL_STATE(7041)] = 223994,
  [SMALL_STATE(7042)] = 224032,
  [SMALL_STATE(7043)] = 224070,
  [SMALL_STATE(7044)] = 224108,
  [SMALL_STATE(7045)] = 224146,
  [SMALL_STATE(7046)] = 224184,
  [SMALL_STATE(7047)] = 224222,
  [SMALL_STATE(7048)] = 224260,
  [SMALL_STATE(7049)] = 224298,
  [SMALL_STATE(7050)] = 224336,
  [SMALL_STATE(7051)] = 224374,
  [SMALL_STATE(7052)] = 224412,
  [SMALL_STATE(7053)] = 224450,
  [SMALL_STATE(7054)] = 224488,
  [SMALL_STATE(7055)] = 224526,
  [SMALL_STATE(7056)] = 224564,
  [SMALL_STATE(7057)] = 224602,
  [SMALL_STATE(7058)] = 224640,
  [SMALL_STATE(7059)] = 224678,
  [SMALL_STATE(7060)] = 224716,
  [SMALL_STATE(7061)] = 224754,
  [SMALL_STATE(7062)] = 224792,
  [SMALL_STATE(7063)] = 224830,
  [SMALL_STATE(7064)] = 224868,
  [SMALL_STATE(7065)] = 224906,
  [SMALL_STATE(7066)] = 224944,
  [SMALL_STATE(7067)] = 224982,
  [SMALL_STATE(7068)] = 225020,
  [SMALL_STATE(7069)] = 225058,
  [SMALL_STATE(7070)] = 225096,
  [SMALL_STATE(7071)] = 225134,
  [SMALL_STATE(7072)] = 225172,
  [SMALL_STATE(7073)] = 225210,
  [SMALL_STATE(7074)] = 225248,
  [SMALL_STATE(7075)] = 225286,
  [SMALL_STATE(7076)] = 225324,
  [SMALL_STATE(7077)] = 225362,
  [SMALL_STATE(7078)] = 225400,
  [SMALL_STATE(7079)] = 225438,
  [SMALL_STATE(7080)] = 225476,
  [SMALL_STATE(7081)] = 225514,
  [SMALL_STATE(7082)] = 225552,
  [SMALL_STATE(7083)] = 225590,
  [SMALL_STATE(7084)] = 225628,
  [SMALL_STATE(7085)] = 225666,
  [SMALL_STATE(7086)] = 225704,
  [SMALL_STATE(7087)] = 225742,
  [SMALL_STATE(7088)] = 225780,
  [SMALL_STATE(7089)] = 225818,
  [SMALL_STATE(7090)] = 225856,
  [SMALL_STATE(7091)] = 225894,
  [SMALL_STATE(7092)] = 225932,
  [SMALL_STATE(7093)] = 225970,
  [SMALL_STATE(7094)] = 226008,
  [SMALL_STATE(7095)] = 226046,
  [SMALL_STATE(7096)] = 226084,
  [SMALL_STATE(7097)] = 226122,
  [SMALL_STATE(7098)] = 226160,
  [SMALL_STATE(7099)] = 226195,
  [SMALL_STATE(7100)] = 226230,
  [SMALL_STATE(7101)] = 226285,
  [SMALL_STATE(7102)] = 226340,
  [SMALL_STATE(7103)] = 226375,
  [SMALL_STATE(7104)] = 226410,
  [SMALL_STATE(7105)] = 226445,
  [SMALL_STATE(7106)] = 226500,
  [SMALL_STATE(7107)] = 226555,
  [SMALL_STATE(7108)] = 226610,
  [SMALL_STATE(7109)] = 226665,
  [SMALL_STATE(7110)] = 226700,
  [SMALL_STATE(7111)] = 226735,
  [SMALL_STATE(7112)] = 226770,
  [SMALL_STATE(7113)] = 226805,
  [SMALL_STATE(7114)] = 226860,
  [SMALL_STATE(7115)] = 226895,
  [SMALL_STATE(7116)] = 226950,
  [SMALL_STATE(7117)] = 227003,
  [SMALL_STATE(7118)] = 227058,
  [SMALL_STATE(7119)] = 227111,
  [SMALL_STATE(7120)] = 227146,
  [SMALL_STATE(7121)] = 227181,
  [SMALL_STATE(7122)] = 227216,
  [SMALL_STATE(7123)] = 227271,
  [SMALL_STATE(7124)] = 227326,
  [SMALL_STATE(7125)] = 227361,
  [SMALL_STATE(7126)] = 227396,
  [SMALL_STATE(7127)] = 227449,
  [SMALL_STATE(7128)] = 227504,
  [SMALL_STATE(7129)] = 227559,
  [SMALL_STATE(7130)] = 227614,
  [SMALL_STATE(7131)] = 227669,
  [SMALL_STATE(7132)] = 227724,
  [SMALL_STATE(7133)] = 227779,
  [SMALL_STATE(7134)] = 227834,
  [SMALL_STATE(7135)] = 227883,
  [SMALL_STATE(7136)] = 227938,
  [SMALL_STATE(7137)] = 227993,
  [SMALL_STATE(7138)] = 228048,
  [SMALL_STATE(7139)] = 228083,
  [SMALL_STATE(7140)] = 228118,
  [SMALL_STATE(7141)] = 228153,
  [SMALL_STATE(7142)] = 228188,
  [SMALL_STATE(7143)] = 228243,
  [SMALL_STATE(7144)] = 228298,
  [SMALL_STATE(7145)] = 228333,
  [SMALL_STATE(7146)] = 228386,
  [SMALL_STATE(7147)] = 228421,
  [SMALL_STATE(7148)] = 228456,
  [SMALL_STATE(7149)] = 228511,
  [SMALL_STATE(7150)] = 228564,
  [SMALL_STATE(7151)] = 228619,
  [SMALL_STATE(7152)] = 228674,
  [SMALL_STATE(7153)] = 228729,
  [SMALL_STATE(7154)] = 228764,
  [SMALL_STATE(7155)] = 228799,
  [SMALL_STATE(7156)] = 228848,
  [SMALL_STATE(7157)] = 228883,
  [SMALL_STATE(7158)] = 228918,
  [SMALL_STATE(7159)] = 228953,
  [SMALL_STATE(7160)] = 228988,
  [SMALL_STATE(7161)] = 229023,
  [SMALL_STATE(7162)] = 229058,
  [SMALL_STATE(7163)] = 229093,
  [SMALL_STATE(7164)] = 229148,
  [SMALL_STATE(7165)] = 229203,
  [SMALL_STATE(7166)] = 229258,
  [SMALL_STATE(7167)] = 229313,
  [SMALL_STATE(7168)] = 229362,
  [SMALL_STATE(7169)] = 229411,
  [SMALL_STATE(7170)] = 229466,
  [SMALL_STATE(7171)] = 229521,
  [SMALL_STATE(7172)] = 229576,
  [SMALL_STATE(7173)] = 229631,
  [SMALL_STATE(7174)] = 229686,
  [SMALL_STATE(7175)] = 229741,
  [SMALL_STATE(7176)] = 229796,
  [SMALL_STATE(7177)] = 229851,
  [SMALL_STATE(7178)] = 229886,
  [SMALL_STATE(7179)] = 229921,
  [SMALL_STATE(7180)] = 229956,
  [SMALL_STATE(7181)] = 229991,
  [SMALL_STATE(7182)] = 230026,
  [SMALL_STATE(7183)] = 230081,
  [SMALL_STATE(7184)] = 230116,
  [SMALL_STATE(7185)] = 230165,
  [SMALL_STATE(7186)] = 230200,
  [SMALL_STATE(7187)] = 230235,
  [SMALL_STATE(7188)] = 230290,
  [SMALL_STATE(7189)] = 230345,
  [SMALL_STATE(7190)] = 230380,
  [SMALL_STATE(7191)] = 230415,
  [SMALL_STATE(7192)] = 230464,
  [SMALL_STATE(7193)] = 230499,
  [SMALL_STATE(7194)] = 230534,
  [SMALL_STATE(7195)] = 230583,
  [SMALL_STATE(7196)] = 230618,
  [SMALL_STATE(7197)] = 230653,
  [SMALL_STATE(7198)] = 230688,
  [SMALL_STATE(7199)] = 230723,
  [SMALL_STATE(7200)] = 230778,
  [SMALL_STATE(7201)] = 230833,
  [SMALL_STATE(7202)] = 230888,
  [SMALL_STATE(7203)] = 230943,
  [SMALL_STATE(7204)] = 230992,
  [SMALL_STATE(7205)] = 231047,
  [SMALL_STATE(7206)] = 231082,
  [SMALL_STATE(7207)] = 231117,
  [SMALL_STATE(7208)] = 231152,
  [SMALL_STATE(7209)] = 231207,
  [SMALL_STATE(7210)] = 231253,
  [SMALL_STATE(7211)] = 231303,
  [SMALL_STATE(7212)] = 231359,
  [SMALL_STATE(7213)] = 231405,
  [SMALL_STATE(7214)] = 231461,
  [SMALL_STATE(7215)] = 231497,
  [SMALL_STATE(7216)] = 231543,
  [SMALL_STATE(7217)] = 231589,
  [SMALL_STATE(7218)] = 231645,
  [SMALL_STATE(7219)] = 231683,
  [SMALL_STATE(7220)] = 231739,
  [SMALL_STATE(7221)] = 231789,
  [SMALL_STATE(7222)] = 231845,
  [SMALL_STATE(7223)] = 231901,
  [SMALL_STATE(7224)] = 231957,
  [SMALL_STATE(7225)] = 232013,
  [SMALL_STATE(7226)] = 232059,
  [SMALL_STATE(7227)] = 232109,
  [SMALL_STATE(7228)] = 232155,
  [SMALL_STATE(7229)] = 232201,
  [SMALL_STATE(7230)] = 232257,
  [SMALL_STATE(7231)] = 232303,
  [SMALL_STATE(7232)] = 232339,
  [SMALL_STATE(7233)] = 232385,
  [SMALL_STATE(7234)] = 232441,
  [SMALL_STATE(7235)] = 232497,
  [SMALL_STATE(7236)] = 232547,
  [SMALL_STATE(7237)] = 232597,
  [SMALL_STATE(7238)] = 232632,
  [SMALL_STATE(7239)] = 232669,
  [SMALL_STATE(7240)] = 232706,
  [SMALL_STATE(7241)] = 232739,
  [SMALL_STATE(7242)] = 232776,
  [SMALL_STATE(7243)] = 232829,
  [SMALL_STATE(7244)] = 232866,
  [SMALL_STATE(7245)] = 232901,
  [SMALL_STATE(7246)] = 232954,
  [SMALL_STATE(7247)] = 232989,
  [SMALL_STATE(7248)] = 233024,
  [SMALL_STATE(7249)] = 233077,
  [SMALL_STATE(7250)] = 233112,
  [SMALL_STATE(7251)] = 233147,
  [SMALL_STATE(7252)] = 233200,
  [SMALL_STATE(7253)] = 233236,
  [SMALL_STATE(7254)] = 233272,
  [SMALL_STATE(7255)] = 233308,
  [SMALL_STATE(7256)] = 233340,
  [SMALL_STATE(7257)] = 233376,
  [SMALL_STATE(7258)] = 233412,
  [SMALL_STATE(7259)] = 233448,
  [SMALL_STATE(7260)] = 233484,
  [SMALL_STATE(7261)] = 233520,
  [SMALL_STATE(7262)] = 233556,
  [SMALL_STATE(7263)] = 233592,
  [SMALL_STATE(7264)] = 233623,
  [SMALL_STATE(7265)] = 233656,
  [SMALL_STATE(7266)] = 233689,
  [SMALL_STATE(7267)] = 233722,
  [SMALL_STATE(7268)] = 233753,
  [SMALL_STATE(7269)] = 233788,
  [SMALL_STATE(7270)] = 233821,
  [SMALL_STATE(7271)] = 233854,
  [SMALL_STATE(7272)] = 233901,
  [SMALL_STATE(7273)] = 233932,
  [SMALL_STATE(7274)] = 233965,
  [SMALL_STATE(7275)] = 233996,
  [SMALL_STATE(7276)] = 234027,
  [SMALL_STATE(7277)] = 234060,
  [SMALL_STATE(7278)] = 234091,
  [SMALL_STATE(7279)] = 234122,
  [SMALL_STATE(7280)] = 234155,
  [SMALL_STATE(7281)] = 234188,
  [SMALL_STATE(7282)] = 234221,
  [SMALL_STATE(7283)] = 234254,
  [SMALL_STATE(7284)] = 234287,
  [SMALL_STATE(7285)] = 234320,
  [SMALL_STATE(7286)] = 234353,
  [SMALL_STATE(7287)] = 234386,
  [SMALL_STATE(7288)] = 234433,
  [SMALL_STATE(7289)] = 234480,
  [SMALL_STATE(7290)] = 234513,
  [SMALL_STATE(7291)] = 234546,
  [SMALL_STATE(7292)] = 234579,
  [SMALL_STATE(7293)] = 234612,
  [SMALL_STATE(7294)] = 234645,
  [SMALL_STATE(7295)] = 234696,
  [SMALL_STATE(7296)] = 234729,
  [SMALL_STATE(7297)] = 234762,
  [SMALL_STATE(7298)] = 234795,
  [SMALL_STATE(7299)] = 234828,
  [SMALL_STATE(7300)] = 234861,
  [SMALL_STATE(7301)] = 234894,
  [SMALL_STATE(7302)] = 234927,
  [SMALL_STATE(7303)] = 234960,
  [SMALL_STATE(7304)] = 235007,
  [SMALL_STATE(7305)] = 235040,
  [SMALL_STATE(7306)] = 235073,
  [SMALL_STATE(7307)] = 235106,
  [SMALL_STATE(7308)] = 235139,
  [SMALL_STATE(7309)] = 235172,
  [SMALL_STATE(7310)] = 235205,
  [SMALL_STATE(7311)] = 235238,
  [SMALL_STATE(7312)] = 235271,
  [SMALL_STATE(7313)] = 235304,
  [SMALL_STATE(7314)] = 235337,
  [SMALL_STATE(7315)] = 235370,
  [SMALL_STATE(7316)] = 235403,
  [SMALL_STATE(7317)] = 235436,
  [SMALL_STATE(7318)] = 235469,
  [SMALL_STATE(7319)] = 235502,
  [SMALL_STATE(7320)] = 235535,
  [SMALL_STATE(7321)] = 235568,
  [SMALL_STATE(7322)] = 235601,
  [SMALL_STATE(7323)] = 235634,
  [SMALL_STATE(7324)] = 235669,
  [SMALL_STATE(7325)] = 235716,
  [SMALL_STATE(7326)] = 235749,
  [SMALL_STATE(7327)] = 235782,
  [SMALL_STATE(7328)] = 235817,
  [SMALL_STATE(7329)] = 235850,
  [SMALL_STATE(7330)] = 235883,
  [SMALL_STATE(7331)] = 235916,
  [SMALL_STATE(7332)] = 235949,
  [SMALL_STATE(7333)] = 235982,
  [SMALL_STATE(7334)] = 236029,
  [SMALL_STATE(7335)] = 236062,
  [SMALL_STATE(7336)] = 236095,
  [SMALL_STATE(7337)] = 236128,
  [SMALL_STATE(7338)] = 236175,
  [SMALL_STATE(7339)] = 236206,
  [SMALL_STATE(7340)] = 236239,
  [SMALL_STATE(7341)] = 236286,
  [SMALL_STATE(7342)] = 236319,
  [SMALL_STATE(7343)] = 236352,
  [SMALL_STATE(7344)] = 236385,
  [SMALL_STATE(7345)] = 236418,
  [SMALL_STATE(7346)] = 236451,
  [SMALL_STATE(7347)] = 236484,
  [SMALL_STATE(7348)] = 236517,
  [SMALL_STATE(7349)] = 236548,
  [SMALL_STATE(7350)] = 236581,
  [SMALL_STATE(7351)] = 236614,
  [SMALL_STATE(7352)] = 236647,
  [SMALL_STATE(7353)] = 236680,
  [SMALL_STATE(7354)] = 236713,
  [SMALL_STATE(7355)] = 236746,
  [SMALL_STATE(7356)] = 236779,
  [SMALL_STATE(7357)] = 236812,
  [SMALL_STATE(7358)] = 236845,
  [SMALL_STATE(7359)] = 236878,
  [SMALL_STATE(7360)] = 236911,
  [SMALL_STATE(7361)] = 236944,
  [SMALL_STATE(7362)] = 236977,
  [SMALL_STATE(7363)] = 237010,
  [SMALL_STATE(7364)] = 237043,
  [SMALL_STATE(7365)] = 237094,
  [SMALL_STATE(7366)] = 237127,
  [SMALL_STATE(7367)] = 237160,
  [SMALL_STATE(7368)] = 237207,
  [SMALL_STATE(7369)] = 237254,
  [SMALL_STATE(7370)] = 237287,
  [SMALL_STATE(7371)] = 237320,
  [SMALL_STATE(7372)] = 237353,
  [SMALL_STATE(7373)] = 237386,
  [SMALL_STATE(7374)] = 237419,
  [SMALL_STATE(7375)] = 237452,
  [SMALL_STATE(7376)] = 237485,
  [SMALL_STATE(7377)] = 237518,
  [SMALL_STATE(7378)] = 237551,
  [SMALL_STATE(7379)] = 237584,
  [SMALL_STATE(7380)] = 237617,
  [SMALL_STATE(7381)] = 237650,
  [SMALL_STATE(7382)] = 237683,
  [SMALL_STATE(7383)] = 237716,
  [SMALL_STATE(7384)] = 237749,
  [SMALL_STATE(7385)] = 237782,
  [SMALL_STATE(7386)] = 237812,
  [SMALL_STATE(7387)] = 237842,
  [SMALL_STATE(7388)] = 237872,
  [SMALL_STATE(7389)] = 237904,
  [SMALL_STATE(7390)] = 237936,
  [SMALL_STATE(7391)] = 237968,
  [SMALL_STATE(7392)] = 237998,
  [SMALL_STATE(7393)] = 238028,
  [SMALL_STATE(7394)] = 238058,
  [SMALL_STATE(7395)] = 238088,
  [SMALL_STATE(7396)] = 238120,
  [SMALL_STATE(7397)] = 238150,
  [SMALL_STATE(7398)] = 238180,
  [SMALL_STATE(7399)] = 238210,
  [SMALL_STATE(7400)] = 238240,
  [SMALL_STATE(7401)] = 238270,
  [SMALL_STATE(7402)] = 238300,
  [SMALL_STATE(7403)] = 238330,
  [SMALL_STATE(7404)] = 238360,
  [SMALL_STATE(7405)] = 238390,
  [SMALL_STATE(7406)] = 238420,
  [SMALL_STATE(7407)] = 238450,
  [SMALL_STATE(7408)] = 238493,
  [SMALL_STATE(7409)] = 238540,
  [SMALL_STATE(7410)] = 238587,
  [SMALL_STATE(7411)] = 238634,
  [SMALL_STATE(7412)] = 238681,
  [SMALL_STATE(7413)] = 238728,
  [SMALL_STATE(7414)] = 238777,
  [SMALL_STATE(7415)] = 238820,
  [SMALL_STATE(7416)] = 238867,
  [SMALL_STATE(7417)] = 238916,
  [SMALL_STATE(7418)] = 238959,
  [SMALL_STATE(7419)] = 239002,
  [SMALL_STATE(7420)] = 239049,
  [SMALL_STATE(7421)] = 239096,
  [SMALL_STATE(7422)] = 239143,
  [SMALL_STATE(7423)] = 239192,
  [SMALL_STATE(7424)] = 239239,
  [SMALL_STATE(7425)] = 239282,
  [SMALL_STATE(7426)] = 239329,
  [SMALL_STATE(7427)] = 239372,
  [SMALL_STATE(7428)] = 239415,
  [SMALL_STATE(7429)] = 239462,
  [SMALL_STATE(7430)] = 239505,
  [SMALL_STATE(7431)] = 239552,
  [SMALL_STATE(7432)] = 239599,
  [SMALL_STATE(7433)] = 239646,
  [SMALL_STATE(7434)] = 239693,
  [SMALL_STATE(7435)] = 239736,
  [SMALL_STATE(7436)] = 239783,
  [SMALL_STATE(7437)] = 239830,
  [SMALL_STATE(7438)] = 239877,
  [SMALL_STATE(7439)] = 239924,
  [SMALL_STATE(7440)] = 239971,
  [SMALL_STATE(7441)] = 240014,
  [SMALL_STATE(7442)] = 240061,
  [SMALL_STATE(7443)] = 240104,
  [SMALL_STATE(7444)] = 240151,
  [SMALL_STATE(7445)] = 240188,
  [SMALL_STATE(7446)] = 240231,
  [SMALL_STATE(7447)] = 240274,
  [SMALL_STATE(7448)] = 240321,
  [SMALL_STATE(7449)] = 240364,
  [SMALL_STATE(7450)] = 240411,
  [SMALL_STATE(7451)] = 240458,
  [SMALL_STATE(7452)] = 240505,
  [SMALL_STATE(7453)] = 240548,
  [SMALL_STATE(7454)] = 240597,
  [SMALL_STATE(7455)] = 240644,
  [SMALL_STATE(7456)] = 240687,
  [SMALL_STATE(7457)] = 240730,
  [SMALL_STATE(7458)] = 240767,
  [SMALL_STATE(7459)] = 240814,
  [SMALL_STATE(7460)] = 240861,
  [SMALL_STATE(7461)] = 240908,
  [SMALL_STATE(7462)] = 240955,
  [SMALL_STATE(7463)] = 241002,
  [SMALL_STATE(7464)] = 241049,
  [SMALL_STATE(7465)] = 241096,
  [SMALL_STATE(7466)] = 241143,
  [SMALL_STATE(7467)] = 241192,
  [SMALL_STATE(7468)] = 241239,
  [SMALL_STATE(7469)] = 241282,
  [SMALL_STATE(7470)] = 241319,
  [SMALL_STATE(7471)] = 241366,
  [SMALL_STATE(7472)] = 241413,
  [SMALL_STATE(7473)] = 241455,
  [SMALL_STATE(7474)] = 241487,
  [SMALL_STATE(7475)] = 241529,
  [SMALL_STATE(7476)] = 241571,
  [SMALL_STATE(7477)] = 241603,
  [SMALL_STATE(7478)] = 241645,
  [SMALL_STATE(7479)] = 241687,
  [SMALL_STATE(7480)] = 241729,
  [SMALL_STATE(7481)] = 241761,
  [SMALL_STATE(7482)] = 241803,
  [SMALL_STATE(7483)] = 241845,
  [SMALL_STATE(7484)] = 241887,
  [SMALL_STATE(7485)] = 241919,
  [SMALL_STATE(7486)] = 241961,
  [SMALL_STATE(7487)] = 242007,
  [SMALL_STATE(7488)] = 242041,
  [SMALL_STATE(7489)] = 242083,
  [SMALL_STATE(7490)] = 242112,
  [SMALL_STATE(7491)] = 242141,
  [SMALL_STATE(7492)] = 242170,
  [SMALL_STATE(7493)] = 242199,
  [SMALL_STATE(7494)] = 242228,
  [SMALL_STATE(7495)] = 242257,
  [SMALL_STATE(7496)] = 242298,
  [SMALL_STATE(7497)] = 242329,
  [SMALL_STATE(7498)] = 242358,
  [SMALL_STATE(7499)] = 242387,
  [SMALL_STATE(7500)] = 242416,
  [SMALL_STATE(7501)] = 242445,
  [SMALL_STATE(7502)] = 242474,
  [SMALL_STATE(7503)] = 242503,
  [SMALL_STATE(7504)] = 242532,
  [SMALL_STATE(7505)] = 242561,
  [SMALL_STATE(7506)] = 242590,
  [SMALL_STATE(7507)] = 242619,
  [SMALL_STATE(7508)] = 242648,
  [SMALL_STATE(7509)] = 242689,
  [SMALL_STATE(7510)] = 242718,
  [SMALL_STATE(7511)] = 242747,
  [SMALL_STATE(7512)] = 242776,
  [SMALL_STATE(7513)] = 242805,
  [SMALL_STATE(7514)] = 242834,
  [SMALL_STATE(7515)] = 242863,
  [SMALL_STATE(7516)] = 242892,
  [SMALL_STATE(7517)] = 242921,
  [SMALL_STATE(7518)] = 242950,
  [SMALL_STATE(7519)] = 242979,
  [SMALL_STATE(7520)] = 243008,
  [SMALL_STATE(7521)] = 243037,
  [SMALL_STATE(7522)] = 243066,
  [SMALL_STATE(7523)] = 243095,
  [SMALL_STATE(7524)] = 243124,
  [SMALL_STATE(7525)] = 243153,
  [SMALL_STATE(7526)] = 243182,
  [SMALL_STATE(7527)] = 243211,
  [SMALL_STATE(7528)] = 243240,
  [SMALL_STATE(7529)] = 243269,
  [SMALL_STATE(7530)] = 243298,
  [SMALL_STATE(7531)] = 243327,
  [SMALL_STATE(7532)] = 243356,
  [SMALL_STATE(7533)] = 243385,
  [SMALL_STATE(7534)] = 243414,
  [SMALL_STATE(7535)] = 243443,
  [SMALL_STATE(7536)] = 243484,
  [SMALL_STATE(7537)] = 243513,
  [SMALL_STATE(7538)] = 243542,
  [SMALL_STATE(7539)] = 243573,
  [SMALL_STATE(7540)] = 243602,
  [SMALL_STATE(7541)] = 243631,
  [SMALL_STATE(7542)] = 243662,
  [SMALL_STATE(7543)] = 243691,
  [SMALL_STATE(7544)] = 243720,
  [SMALL_STATE(7545)] = 243749,
  [SMALL_STATE(7546)] = 243778,
  [SMALL_STATE(7547)] = 243813,
  [SMALL_STATE(7548)] = 243848,
  [SMALL_STATE(7549)] = 243883,
  [SMALL_STATE(7550)] = 243914,
  [SMALL_STATE(7551)] = 243943,
  [SMALL_STATE(7552)] = 243972,
  [SMALL_STATE(7553)] = 244001,
  [SMALL_STATE(7554)] = 244030,
  [SMALL_STATE(7555)] = 244059,
  [SMALL_STATE(7556)] = 244088,
  [SMALL_STATE(7557)] = 244119,
  [SMALL_STATE(7558)] = 244148,
  [SMALL_STATE(7559)] = 244176,
  [SMALL_STATE(7560)] = 244204,
  [SMALL_STATE(7561)] = 244232,
  [SMALL_STATE(7562)] = 244260,
  [SMALL_STATE(7563)] = 244288,
  [SMALL_STATE(7564)] = 244330,
  [SMALL_STATE(7565)] = 244358,
  [SMALL_STATE(7566)] = 244386,
  [SMALL_STATE(7567)] = 244414,
  [SMALL_STATE(7568)] = 244442,
  [SMALL_STATE(7569)] = 244470,
  [SMALL_STATE(7570)] = 244498,
  [SMALL_STATE(7571)] = 244526,
  [SMALL_STATE(7572)] = 244554,
  [SMALL_STATE(7573)] = 244582,
  [SMALL_STATE(7574)] = 244610,
  [SMALL_STATE(7575)] = 244638,
  [SMALL_STATE(7576)] = 244666,
  [SMALL_STATE(7577)] = 244694,
  [SMALL_STATE(7578)] = 244722,
  [SMALL_STATE(7579)] = 244750,
  [SMALL_STATE(7580)] = 244778,
  [SMALL_STATE(7581)] = 244806,
  [SMALL_STATE(7582)] = 244834,
  [SMALL_STATE(7583)] = 244862,
  [SMALL_STATE(7584)] = 244892,
  [SMALL_STATE(7585)] = 244920,
  [SMALL_STATE(7586)] = 244948,
  [SMALL_STATE(7587)] = 244976,
  [SMALL_STATE(7588)] = 245004,
  [SMALL_STATE(7589)] = 245032,
  [SMALL_STATE(7590)] = 245060,
  [SMALL_STATE(7591)] = 245088,
  [SMALL_STATE(7592)] = 245116,
  [SMALL_STATE(7593)] = 245144,
  [SMALL_STATE(7594)] = 245172,
  [SMALL_STATE(7595)] = 245200,
  [SMALL_STATE(7596)] = 245228,
  [SMALL_STATE(7597)] = 245256,
  [SMALL_STATE(7598)] = 245284,
  [SMALL_STATE(7599)] = 245312,
  [SMALL_STATE(7600)] = 245340,
  [SMALL_STATE(7601)] = 245368,
  [SMALL_STATE(7602)] = 245396,
  [SMALL_STATE(7603)] = 245424,
  [SMALL_STATE(7604)] = 245452,
  [SMALL_STATE(7605)] = 245480,
  [SMALL_STATE(7606)] = 245508,
  [SMALL_STATE(7607)] = 245536,
  [SMALL_STATE(7608)] = 245564,
  [SMALL_STATE(7609)] = 245592,
  [SMALL_STATE(7610)] = 245620,
  [SMALL_STATE(7611)] = 245648,
  [SMALL_STATE(7612)] = 245676,
  [SMALL_STATE(7613)] = 245704,
  [SMALL_STATE(7614)] = 245732,
  [SMALL_STATE(7615)] = 245760,
  [SMALL_STATE(7616)] = 245788,
  [SMALL_STATE(7617)] = 245816,
  [SMALL_STATE(7618)] = 245844,
  [SMALL_STATE(7619)] = 245872,
  [SMALL_STATE(7620)] = 245902,
  [SMALL_STATE(7621)] = 245930,
  [SMALL_STATE(7622)] = 245958,
  [SMALL_STATE(7623)] = 245986,
  [SMALL_STATE(7624)] = 246014,
  [SMALL_STATE(7625)] = 246044,
  [SMALL_STATE(7626)] = 246072,
  [SMALL_STATE(7627)] = 246100,
  [SMALL_STATE(7628)] = 246128,
  [SMALL_STATE(7629)] = 246156,
  [SMALL_STATE(7630)] = 246184,
  [SMALL_STATE(7631)] = 246212,
  [SMALL_STATE(7632)] = 246251,
  [SMALL_STATE(7633)] = 246290,
  [SMALL_STATE(7634)] = 246319,
  [SMALL_STATE(7635)] = 246362,
  [SMALL_STATE(7636)] = 246405,
  [SMALL_STATE(7637)] = 246448,
  [SMALL_STATE(7638)] = 246491,
  [SMALL_STATE(7639)] = 246534,
  [SMALL_STATE(7640)] = 246573,
  [SMALL_STATE(7641)] = 246608,
  [SMALL_STATE(7642)] = 246643,
  [SMALL_STATE(7643)] = 246668,
  [SMALL_STATE(7644)] = 246703,
  [SMALL_STATE(7645)] = 246746,
  [SMALL_STATE(7646)] = 246789,
  [SMALL_STATE(7647)] = 246828,
  [SMALL_STATE(7648)] = 246859,
  [SMALL_STATE(7649)] = 246902,
  [SMALL_STATE(7650)] = 246945,
  [SMALL_STATE(7651)] = 246972,
  [SMALL_STATE(7652)] = 247007,
  [SMALL_STATE(7653)] = 247050,
  [SMALL_STATE(7654)] = 247093,
  [SMALL_STATE(7655)] = 247132,
  [SMALL_STATE(7656)] = 247175,
  [SMALL_STATE(7657)] = 247218,
  [SMALL_STATE(7658)] = 247243,
  [SMALL_STATE(7659)] = 247286,
  [SMALL_STATE(7660)] = 247317,
  [SMALL_STATE(7661)] = 247356,
  [SMALL_STATE(7662)] = 247385,
  [SMALL_STATE(7663)] = 247428,
  [SMALL_STATE(7664)] = 247471,
  [SMALL_STATE(7665)] = 247508,
  [SMALL_STATE(7666)] = 247551,
  [SMALL_STATE(7667)] = 247594,
  [SMALL_STATE(7668)] = 247621,
  [SMALL_STATE(7669)] = 247660,
  [SMALL_STATE(7670)] = 247703,
  [SMALL_STATE(7671)] = 247746,
  [SMALL_STATE(7672)] = 247773,
  [SMALL_STATE(7673)] = 247800,
  [SMALL_STATE(7674)] = 247835,
  [SMALL_STATE(7675)] = 247874,
  [SMALL_STATE(7676)] = 247909,
  [SMALL_STATE(7677)] = 247952,
  [SMALL_STATE(7678)] = 247979,
  [SMALL_STATE(7679)] = 248008,
  [SMALL_STATE(7680)] = 248051,
  [SMALL_STATE(7681)] = 248094,
  [SMALL_STATE(7682)] = 248137,
  [SMALL_STATE(7683)] = 248180,
  [SMALL_STATE(7684)] = 248223,
  [SMALL_STATE(7685)] = 248266,
  [SMALL_STATE(7686)] = 248301,
  [SMALL_STATE(7687)] = 248344,
  [SMALL_STATE(7688)] = 248371,
  [SMALL_STATE(7689)] = 248414,
  [SMALL_STATE(7690)] = 248439,
  [SMALL_STATE(7691)] = 248464,
  [SMALL_STATE(7692)] = 248507,
  [SMALL_STATE(7693)] = 248542,
  [SMALL_STATE(7694)] = 248585,
  [SMALL_STATE(7695)] = 248628,
  [SMALL_STATE(7696)] = 248655,
  [SMALL_STATE(7697)] = 248698,
  [SMALL_STATE(7698)] = 248733,
  [SMALL_STATE(7699)] = 248768,
  [SMALL_STATE(7700)] = 248795,
  [SMALL_STATE(7701)] = 248838,
  [SMALL_STATE(7702)] = 248869,
  [SMALL_STATE(7703)] = 248894,
  [SMALL_STATE(7704)] = 248921,
  [SMALL_STATE(7705)] = 248964,
  [SMALL_STATE(7706)] = 249007,
  [SMALL_STATE(7707)] = 249036,
  [SMALL_STATE(7708)] = 249079,
  [SMALL_STATE(7709)] = 249122,
  [SMALL_STATE(7710)] = 249157,
  [SMALL_STATE(7711)] = 249182,
  [SMALL_STATE(7712)] = 249213,
  [SMALL_STATE(7713)] = 249256,
  [SMALL_STATE(7714)] = 249299,
  [SMALL_STATE(7715)] = 249342,
  [SMALL_STATE(7716)] = 249385,
  [SMALL_STATE(7717)] = 249420,
  [SMALL_STATE(7718)] = 249463,
  [SMALL_STATE(7719)] = 249506,
  [SMALL_STATE(7720)] = 249537,
  [SMALL_STATE(7721)] = 249580,
  [SMALL_STATE(7722)] = 249615,
  [SMALL_STATE(7723)] = 249658,
  [SMALL_STATE(7724)] = 249685,
  [SMALL_STATE(7725)] = 249728,
  [SMALL_STATE(7726)] = 249757,
  [SMALL_STATE(7727)] = 249796,
  [SMALL_STATE(7728)] = 249839,
  [SMALL_STATE(7729)] = 249882,
  [SMALL_STATE(7730)] = 249909,
  [SMALL_STATE(7731)] = 249952,
  [SMALL_STATE(7732)] = 249995,
  [SMALL_STATE(7733)] = 250020,
  [SMALL_STATE(7734)] = 250063,
  [SMALL_STATE(7735)] = 250106,
  [SMALL_STATE(7736)] = 250149,
  [SMALL_STATE(7737)] = 250192,
  [SMALL_STATE(7738)] = 250231,
  [SMALL_STATE(7739)] = 250260,
  [SMALL_STATE(7740)] = 250303,
  [SMALL_STATE(7741)] = 250346,
  [SMALL_STATE(7742)] = 250389,
  [SMALL_STATE(7743)] = 250424,
  [SMALL_STATE(7744)] = 250467,
  [SMALL_STATE(7745)] = 250494,
  [SMALL_STATE(7746)] = 250521,
  [SMALL_STATE(7747)] = 250564,
  [SMALL_STATE(7748)] = 250589,
  [SMALL_STATE(7749)] = 250632,
  [SMALL_STATE(7750)] = 250659,
  [SMALL_STATE(7751)] = 250690,
  [SMALL_STATE(7752)] = 250721,
  [SMALL_STATE(7753)] = 250756,
  [SMALL_STATE(7754)] = 250799,
  [SMALL_STATE(7755)] = 250842,
  [SMALL_STATE(7756)] = 250885,
  [SMALL_STATE(7757)] = 250928,
  [SMALL_STATE(7758)] = 250971,
  [SMALL_STATE(7759)] = 251014,
  [SMALL_STATE(7760)] = 251057,
  [SMALL_STATE(7761)] = 251100,
  [SMALL_STATE(7762)] = 251143,
  [SMALL_STATE(7763)] = 251170,
  [SMALL_STATE(7764)] = 251197,
  [SMALL_STATE(7765)] = 251240,
  [SMALL_STATE(7766)] = 251283,
  [SMALL_STATE(7767)] = 251310,
  [SMALL_STATE(7768)] = 251353,
  [SMALL_STATE(7769)] = 251396,
  [SMALL_STATE(7770)] = 251421,
  [SMALL_STATE(7771)] = 251464,
  [SMALL_STATE(7772)] = 251499,
  [SMALL_STATE(7773)] = 251526,
  [SMALL_STATE(7774)] = 251553,
  [SMALL_STATE(7775)] = 251596,
  [SMALL_STATE(7776)] = 251639,
  [SMALL_STATE(7777)] = 251682,
  [SMALL_STATE(7778)] = 251725,
  [SMALL_STATE(7779)] = 251768,
  [SMALL_STATE(7780)] = 251804,
  [SMALL_STATE(7781)] = 251840,
  [SMALL_STATE(7782)] = 251874,
  [SMALL_STATE(7783)] = 251910,
  [SMALL_STATE(7784)] = 251946,
  [SMALL_STATE(7785)] = 251986,
  [SMALL_STATE(7786)] = 252020,
  [SMALL_STATE(7787)] = 252056,
  [SMALL_STATE(7788)] = 252092,
  [SMALL_STATE(7789)] = 252128,
  [SMALL_STATE(7790)] = 252164,
  [SMALL_STATE(7791)] = 252200,
  [SMALL_STATE(7792)] = 252240,
  [SMALL_STATE(7793)] = 252280,
  [SMALL_STATE(7794)] = 252314,
  [SMALL_STATE(7795)] = 252348,
  [SMALL_STATE(7796)] = 252384,
  [SMALL_STATE(7797)] = 252420,
  [SMALL_STATE(7798)] = 252454,
  [SMALL_STATE(7799)] = 252488,
  [SMALL_STATE(7800)] = 252528,
  [SMALL_STATE(7801)] = 252564,
  [SMALL_STATE(7802)] = 252600,
  [SMALL_STATE(7803)] = 252636,
  [SMALL_STATE(7804)] = 252676,
  [SMALL_STATE(7805)] = 252716,
  [SMALL_STATE(7806)] = 252750,
  [SMALL_STATE(7807)] = 252784,
  [SMALL_STATE(7808)] = 252820,
  [SMALL_STATE(7809)] = 252856,
  [SMALL_STATE(7810)] = 252892,
  [SMALL_STATE(7811)] = 252932,
  [SMALL_STATE(7812)] = 252968,
  [SMALL_STATE(7813)] = 253008,
  [SMALL_STATE(7814)] = 253048,
  [SMALL_STATE(7815)] = 253082,
  [SMALL_STATE(7816)] = 253118,
  [SMALL_STATE(7817)] = 253154,
  [SMALL_STATE(7818)] = 253190,
  [SMALL_STATE(7819)] = 253226,
  [SMALL_STATE(7820)] = 253262,
  [SMALL_STATE(7821)] = 253302,
  [SMALL_STATE(7822)] = 253338,
  [SMALL_STATE(7823)] = 253378,
  [SMALL_STATE(7824)] = 253418,
  [SMALL_STATE(7825)] = 253458,
  [SMALL_STATE(7826)] = 253498,
  [SMALL_STATE(7827)] = 253534,
  [SMALL_STATE(7828)] = 253570,
  [SMALL_STATE(7829)] = 253610,
  [SMALL_STATE(7830)] = 253650,
  [SMALL_STATE(7831)] = 253686,
  [SMALL_STATE(7832)] = 253720,
  [SMALL_STATE(7833)] = 253756,
  [SMALL_STATE(7834)] = 253792,
  [SMALL_STATE(7835)] = 253828,
  [SMALL_STATE(7836)] = 253864,
  [SMALL_STATE(7837)] = 253900,
  [SMALL_STATE(7838)] = 253936,
  [SMALL_STATE(7839)] = 253972,
  [SMALL_STATE(7840)] = 254012,
  [SMALL_STATE(7841)] = 254048,
  [SMALL_STATE(7842)] = 254084,
  [SMALL_STATE(7843)] = 254120,
  [SMALL_STATE(7844)] = 254156,
  [SMALL_STATE(7845)] = 254196,
  [SMALL_STATE(7846)] = 254230,
  [SMALL_STATE(7847)] = 254266,
  [SMALL_STATE(7848)] = 254302,
  [SMALL_STATE(7849)] = 254338,
  [SMALL_STATE(7850)] = 254374,
  [SMALL_STATE(7851)] = 254410,
  [SMALL_STATE(7852)] = 254446,
  [SMALL_STATE(7853)] = 254480,
  [SMALL_STATE(7854)] = 254514,
  [SMALL_STATE(7855)] = 254550,
  [SMALL_STATE(7856)] = 254586,
  [SMALL_STATE(7857)] = 254622,
  [SMALL_STATE(7858)] = 254658,
  [SMALL_STATE(7859)] = 254686,
  [SMALL_STATE(7860)] = 254720,
  [SMALL_STATE(7861)] = 254754,
  [SMALL_STATE(7862)] = 254790,
  [SMALL_STATE(7863)] = 254826,
  [SMALL_STATE(7864)] = 254862,
  [SMALL_STATE(7865)] = 254898,
  [SMALL_STATE(7866)] = 254934,
  [SMALL_STATE(7867)] = 254970,
  [SMALL_STATE(7868)] = 255010,
  [SMALL_STATE(7869)] = 255046,
  [SMALL_STATE(7870)] = 255082,
  [SMALL_STATE(7871)] = 255118,
  [SMALL_STATE(7872)] = 255158,
  [SMALL_STATE(7873)] = 255198,
  [SMALL_STATE(7874)] = 255238,
  [SMALL_STATE(7875)] = 255274,
  [SMALL_STATE(7876)] = 255314,
  [SMALL_STATE(7877)] = 255354,
  [SMALL_STATE(7878)] = 255390,
  [SMALL_STATE(7879)] = 255430,
  [SMALL_STATE(7880)] = 255470,
  [SMALL_STATE(7881)] = 255510,
  [SMALL_STATE(7882)] = 255546,
  [SMALL_STATE(7883)] = 255580,
  [SMALL_STATE(7884)] = 255614,
  [SMALL_STATE(7885)] = 255650,
  [SMALL_STATE(7886)] = 255686,
  [SMALL_STATE(7887)] = 255726,
  [SMALL_STATE(7888)] = 255762,
  [SMALL_STATE(7889)] = 255798,
  [SMALL_STATE(7890)] = 255838,
  [SMALL_STATE(7891)] = 255878,
  [SMALL_STATE(7892)] = 255914,
  [SMALL_STATE(7893)] = 255954,
  [SMALL_STATE(7894)] = 255994,
  [SMALL_STATE(7895)] = 256030,
  [SMALL_STATE(7896)] = 256066,
  [SMALL_STATE(7897)] = 256102,
  [SMALL_STATE(7898)] = 256142,
  [SMALL_STATE(7899)] = 256182,
  [SMALL_STATE(7900)] = 256222,
  [SMALL_STATE(7901)] = 256258,
  [SMALL_STATE(7902)] = 256294,
  [SMALL_STATE(7903)] = 256330,
  [SMALL_STATE(7904)] = 256364,
  [SMALL_STATE(7905)] = 256398,
  [SMALL_STATE(7906)] = 256438,
  [SMALL_STATE(7907)] = 256478,
  [SMALL_STATE(7908)] = 256514,
  [SMALL_STATE(7909)] = 256548,
  [SMALL_STATE(7910)] = 256582,
  [SMALL_STATE(7911)] = 256618,
  [SMALL_STATE(7912)] = 256658,
  [SMALL_STATE(7913)] = 256698,
  [SMALL_STATE(7914)] = 256734,
  [SMALL_STATE(7915)] = 256770,
  [SMALL_STATE(7916)] = 256806,
  [SMALL_STATE(7917)] = 256842,
  [SMALL_STATE(7918)] = 256878,
  [SMALL_STATE(7919)] = 256914,
  [SMALL_STATE(7920)] = 256950,
  [SMALL_STATE(7921)] = 256986,
  [SMALL_STATE(7922)] = 257022,
  [SMALL_STATE(7923)] = 257058,
  [SMALL_STATE(7924)] = 257092,
  [SMALL_STATE(7925)] = 257126,
  [SMALL_STATE(7926)] = 257162,
  [SMALL_STATE(7927)] = 257198,
  [SMALL_STATE(7928)] = 257234,
  [SMALL_STATE(7929)] = 257270,
  [SMALL_STATE(7930)] = 257306,
  [SMALL_STATE(7931)] = 257342,
  [SMALL_STATE(7932)] = 257378,
  [SMALL_STATE(7933)] = 257418,
  [SMALL_STATE(7934)] = 257454,
  [SMALL_STATE(7935)] = 257490,
  [SMALL_STATE(7936)] = 257526,
  [SMALL_STATE(7937)] = 257566,
  [SMALL_STATE(7938)] = 257602,
  [SMALL_STATE(7939)] = 257642,
  [SMALL_STATE(7940)] = 257682,
  [SMALL_STATE(7941)] = 257722,
  [SMALL_STATE(7942)] = 257758,
  [SMALL_STATE(7943)] = 257794,
  [SMALL_STATE(7944)] = 257834,
  [SMALL_STATE(7945)] = 257874,
  [SMALL_STATE(7946)] = 257910,
  [SMALL_STATE(7947)] = 257946,
  [SMALL_STATE(7948)] = 257982,
  [SMALL_STATE(7949)] = 258022,
  [SMALL_STATE(7950)] = 258062,
  [SMALL_STATE(7951)] = 258098,
  [SMALL_STATE(7952)] = 258138,
  [SMALL_STATE(7953)] = 258178,
  [SMALL_STATE(7954)] = 258214,
  [SMALL_STATE(7955)] = 258250,
  [SMALL_STATE(7956)] = 258286,
  [SMALL_STATE(7957)] = 258322,
  [SMALL_STATE(7958)] = 258358,
  [SMALL_STATE(7959)] = 258394,
  [SMALL_STATE(7960)] = 258434,
  [SMALL_STATE(7961)] = 258474,
  [SMALL_STATE(7962)] = 258514,
  [SMALL_STATE(7963)] = 258554,
  [SMALL_STATE(7964)] = 258594,
  [SMALL_STATE(7965)] = 258634,
  [SMALL_STATE(7966)] = 258674,
  [SMALL_STATE(7967)] = 258714,
  [SMALL_STATE(7968)] = 258748,
  [SMALL_STATE(7969)] = 258782,
  [SMALL_STATE(7970)] = 258818,
  [SMALL_STATE(7971)] = 258848,
  [SMALL_STATE(7972)] = 258884,
  [SMALL_STATE(7973)] = 258920,
  [SMALL_STATE(7974)] = 258956,
  [SMALL_STATE(7975)] = 258990,
  [SMALL_STATE(7976)] = 259024,
  [SMALL_STATE(7977)] = 259060,
  [SMALL_STATE(7978)] = 259096,
  [SMALL_STATE(7979)] = 259132,
  [SMALL_STATE(7980)] = 259168,
  [SMALL_STATE(7981)] = 259204,
  [SMALL_STATE(7982)] = 259240,
  [SMALL_STATE(7983)] = 259276,
  [SMALL_STATE(7984)] = 259312,
  [SMALL_STATE(7985)] = 259348,
  [SMALL_STATE(7986)] = 259384,
  [SMALL_STATE(7987)] = 259420,
  [SMALL_STATE(7988)] = 259460,
  [SMALL_STATE(7989)] = 259496,
  [SMALL_STATE(7990)] = 259532,
  [SMALL_STATE(7991)] = 259568,
  [SMALL_STATE(7992)] = 259608,
  [SMALL_STATE(7993)] = 259648,
  [SMALL_STATE(7994)] = 259688,
  [SMALL_STATE(7995)] = 259728,
  [SMALL_STATE(7996)] = 259764,
  [SMALL_STATE(7997)] = 259804,
  [SMALL_STATE(7998)] = 259844,
  [SMALL_STATE(7999)] = 259880,
  [SMALL_STATE(8000)] = 259916,
  [SMALL_STATE(8001)] = 259956,
  [SMALL_STATE(8002)] = 259992,
  [SMALL_STATE(8003)] = 260032,
  [SMALL_STATE(8004)] = 260072,
  [SMALL_STATE(8005)] = 260108,
  [SMALL_STATE(8006)] = 260144,
  [SMALL_STATE(8007)] = 260184,
  [SMALL_STATE(8008)] = 260224,
  [SMALL_STATE(8009)] = 260264,
  [SMALL_STATE(8010)] = 260304,
  [SMALL_STATE(8011)] = 260344,
  [SMALL_STATE(8012)] = 260380,
  [SMALL_STATE(8013)] = 260416,
  [SMALL_STATE(8014)] = 260452,
  [SMALL_STATE(8015)] = 260486,
  [SMALL_STATE(8016)] = 260520,
  [SMALL_STATE(8017)] = 260556,
  [SMALL_STATE(8018)] = 260596,
  [SMALL_STATE(8019)] = 260632,
  [SMALL_STATE(8020)] = 260672,
  [SMALL_STATE(8021)] = 260708,
  [SMALL_STATE(8022)] = 260748,
  [SMALL_STATE(8023)] = 260788,
  [SMALL_STATE(8024)] = 260828,
  [SMALL_STATE(8025)] = 260868,
  [SMALL_STATE(8026)] = 260908,
  [SMALL_STATE(8027)] = 260944,
  [SMALL_STATE(8028)] = 260984,
  [SMALL_STATE(8029)] = 261020,
  [SMALL_STATE(8030)] = 261056,
  [SMALL_STATE(8031)] = 261092,
  [SMALL_STATE(8032)] = 261128,
  [SMALL_STATE(8033)] = 261164,
  [SMALL_STATE(8034)] = 261204,
  [SMALL_STATE(8035)] = 261240,
  [SMALL_STATE(8036)] = 261280,
  [SMALL_STATE(8037)] = 261314,
  [SMALL_STATE(8038)] = 261354,
  [SMALL_STATE(8039)] = 261394,
  [SMALL_STATE(8040)] = 261434,
  [SMALL_STATE(8041)] = 261474,
  [SMALL_STATE(8042)] = 261514,
  [SMALL_STATE(8043)] = 261550,
  [SMALL_STATE(8044)] = 261590,
  [SMALL_STATE(8045)] = 261626,
  [SMALL_STATE(8046)] = 261666,
  [SMALL_STATE(8047)] = 261702,
  [SMALL_STATE(8048)] = 261742,
  [SMALL_STATE(8049)] = 261776,
  [SMALL_STATE(8050)] = 261816,
  [SMALL_STATE(8051)] = 261856,
  [SMALL_STATE(8052)] = 261896,
  [SMALL_STATE(8053)] = 261936,
  [SMALL_STATE(8054)] = 261976,
  [SMALL_STATE(8055)] = 262016,
  [SMALL_STATE(8056)] = 262056,
  [SMALL_STATE(8057)] = 262096,
  [SMALL_STATE(8058)] = 262136,
  [SMALL_STATE(8059)] = 262176,
  [SMALL_STATE(8060)] = 262216,
  [SMALL_STATE(8061)] = 262256,
  [SMALL_STATE(8062)] = 262296,
  [SMALL_STATE(8063)] = 262336,
  [SMALL_STATE(8064)] = 262376,
  [SMALL_STATE(8065)] = 262416,
  [SMALL_STATE(8066)] = 262456,
  [SMALL_STATE(8067)] = 262496,
  [SMALL_STATE(8068)] = 262532,
  [SMALL_STATE(8069)] = 262568,
  [SMALL_STATE(8070)] = 262604,
  [SMALL_STATE(8071)] = 262640,
  [SMALL_STATE(8072)] = 262676,
  [SMALL_STATE(8073)] = 262712,
  [SMALL_STATE(8074)] = 262748,
  [SMALL_STATE(8075)] = 262784,
  [SMALL_STATE(8076)] = 262818,
  [SMALL_STATE(8077)] = 262852,
  [SMALL_STATE(8078)] = 262886,
  [SMALL_STATE(8079)] = 262922,
  [SMALL_STATE(8080)] = 262948,
  [SMALL_STATE(8081)] = 262982,
  [SMALL_STATE(8082)] = 263018,
  [SMALL_STATE(8083)] = 263054,
  [SMALL_STATE(8084)] = 263090,
  [SMALL_STATE(8085)] = 263130,
  [SMALL_STATE(8086)] = 263170,
  [SMALL_STATE(8087)] = 263206,
  [SMALL_STATE(8088)] = 263242,
  [SMALL_STATE(8089)] = 263276,
  [SMALL_STATE(8090)] = 263312,
  [SMALL_STATE(8091)] = 263346,
  [SMALL_STATE(8092)] = 263382,
  [SMALL_STATE(8093)] = 263416,
  [SMALL_STATE(8094)] = 263450,
  [SMALL_STATE(8095)] = 263486,
  [SMALL_STATE(8096)] = 263522,
  [SMALL_STATE(8097)] = 263558,
  [SMALL_STATE(8098)] = 263594,
  [SMALL_STATE(8099)] = 263630,
  [SMALL_STATE(8100)] = 263664,
  [SMALL_STATE(8101)] = 263700,
  [SMALL_STATE(8102)] = 263734,
  [SMALL_STATE(8103)] = 263770,
  [SMALL_STATE(8104)] = 263806,
  [SMALL_STATE(8105)] = 263842,
  [SMALL_STATE(8106)] = 263876,
  [SMALL_STATE(8107)] = 263912,
  [SMALL_STATE(8108)] = 263948,
  [SMALL_STATE(8109)] = 263982,
  [SMALL_STATE(8110)] = 264018,
  [SMALL_STATE(8111)] = 264054,
  [SMALL_STATE(8112)] = 264090,
  [SMALL_STATE(8113)] = 264126,
  [SMALL_STATE(8114)] = 264162,
  [SMALL_STATE(8115)] = 264198,
  [SMALL_STATE(8116)] = 264234,
  [SMALL_STATE(8117)] = 264270,
  [SMALL_STATE(8118)] = 264306,
  [SMALL_STATE(8119)] = 264342,
  [SMALL_STATE(8120)] = 264378,
  [SMALL_STATE(8121)] = 264414,
  [SMALL_STATE(8122)] = 264450,
  [SMALL_STATE(8123)] = 264486,
  [SMALL_STATE(8124)] = 264522,
  [SMALL_STATE(8125)] = 264558,
  [SMALL_STATE(8126)] = 264594,
  [SMALL_STATE(8127)] = 264630,
  [SMALL_STATE(8128)] = 264666,
  [SMALL_STATE(8129)] = 264706,
  [SMALL_STATE(8130)] = 264742,
  [SMALL_STATE(8131)] = 264778,
  [SMALL_STATE(8132)] = 264814,
  [SMALL_STATE(8133)] = 264850,
  [SMALL_STATE(8134)] = 264886,
  [SMALL_STATE(8135)] = 264922,
  [SMALL_STATE(8136)] = 264956,
  [SMALL_STATE(8137)] = 264990,
  [SMALL_STATE(8138)] = 265026,
  [SMALL_STATE(8139)] = 265062,
  [SMALL_STATE(8140)] = 265098,
  [SMALL_STATE(8141)] = 265134,
  [SMALL_STATE(8142)] = 265168,
  [SMALL_STATE(8143)] = 265202,
  [SMALL_STATE(8144)] = 265238,
  [SMALL_STATE(8145)] = 265274,
  [SMALL_STATE(8146)] = 265308,
  [SMALL_STATE(8147)] = 265342,
  [SMALL_STATE(8148)] = 265376,
  [SMALL_STATE(8149)] = 265412,
  [SMALL_STATE(8150)] = 265448,
  [SMALL_STATE(8151)] = 265484,
  [SMALL_STATE(8152)] = 265520,
  [SMALL_STATE(8153)] = 265556,
  [SMALL_STATE(8154)] = 265590,
  [SMALL_STATE(8155)] = 265626,
  [SMALL_STATE(8156)] = 265662,
  [SMALL_STATE(8157)] = 265698,
  [SMALL_STATE(8158)] = 265738,
  [SMALL_STATE(8159)] = 265774,
  [SMALL_STATE(8160)] = 265810,
  [SMALL_STATE(8161)] = 265850,
  [SMALL_STATE(8162)] = 265884,
  [SMALL_STATE(8163)] = 265918,
  [SMALL_STATE(8164)] = 265954,
  [SMALL_STATE(8165)] = 265990,
  [SMALL_STATE(8166)] = 266026,
  [SMALL_STATE(8167)] = 266062,
  [SMALL_STATE(8168)] = 266102,
  [SMALL_STATE(8169)] = 266138,
  [SMALL_STATE(8170)] = 266174,
  [SMALL_STATE(8171)] = 266210,
  [SMALL_STATE(8172)] = 266246,
  [SMALL_STATE(8173)] = 266282,
  [SMALL_STATE(8174)] = 266318,
  [SMALL_STATE(8175)] = 266358,
  [SMALL_STATE(8176)] = 266395,
  [SMALL_STATE(8177)] = 266432,
  [SMALL_STATE(8178)] = 266469,
  [SMALL_STATE(8179)] = 266506,
  [SMALL_STATE(8180)] = 266541,
  [SMALL_STATE(8181)] = 266578,
  [SMALL_STATE(8182)] = 266615,
  [SMALL_STATE(8183)] = 266652,
  [SMALL_STATE(8184)] = 266687,
  [SMALL_STATE(8185)] = 266724,
  [SMALL_STATE(8186)] = 266749,
  [SMALL_STATE(8187)] = 266786,
  [SMALL_STATE(8188)] = 266811,
  [SMALL_STATE(8189)] = 266836,
  [SMALL_STATE(8190)] = 266861,
  [SMALL_STATE(8191)] = 266888,
  [SMALL_STATE(8192)] = 266925,
  [SMALL_STATE(8193)] = 266952,
  [SMALL_STATE(8194)] = 266989,
  [SMALL_STATE(8195)] = 267026,
  [SMALL_STATE(8196)] = 267063,
  [SMALL_STATE(8197)] = 267100,
  [SMALL_STATE(8198)] = 267125,
  [SMALL_STATE(8199)] = 267156,
  [SMALL_STATE(8200)] = 267187,
  [SMALL_STATE(8201)] = 267212,
  [SMALL_STATE(8202)] = 267249,
  [SMALL_STATE(8203)] = 267274,
  [SMALL_STATE(8204)] = 267301,
  [SMALL_STATE(8205)] = 267328,
  [SMALL_STATE(8206)] = 267365,
  [SMALL_STATE(8207)] = 267402,
  [SMALL_STATE(8208)] = 267439,
  [SMALL_STATE(8209)] = 267476,
  [SMALL_STATE(8210)] = 267513,
  [SMALL_STATE(8211)] = 267548,
  [SMALL_STATE(8212)] = 267579,
  [SMALL_STATE(8213)] = 267606,
  [SMALL_STATE(8214)] = 267643,
  [SMALL_STATE(8215)] = 267670,
  [SMALL_STATE(8216)] = 267701,
  [SMALL_STATE(8217)] = 267732,
  [SMALL_STATE(8218)] = 267763,
  [SMALL_STATE(8219)] = 267794,
  [SMALL_STATE(8220)] = 267817,
  [SMALL_STATE(8221)] = 267854,
  [SMALL_STATE(8222)] = 267879,
  [SMALL_STATE(8223)] = 267904,
  [SMALL_STATE(8224)] = 267933,
  [SMALL_STATE(8225)] = 267958,
  [SMALL_STATE(8226)] = 267995,
  [SMALL_STATE(8227)] = 268032,
  [SMALL_STATE(8228)] = 268057,
  [SMALL_STATE(8229)] = 268094,
  [SMALL_STATE(8230)] = 268119,
  [SMALL_STATE(8231)] = 268154,
  [SMALL_STATE(8232)] = 268183,
  [SMALL_STATE(8233)] = 268210,
  [SMALL_STATE(8234)] = 268245,
  [SMALL_STATE(8235)] = 268282,
  [SMALL_STATE(8236)] = 268305,
  [SMALL_STATE(8237)] = 268330,
  [SMALL_STATE(8238)] = 268367,
  [SMALL_STATE(8239)] = 268404,
  [SMALL_STATE(8240)] = 268439,
  [SMALL_STATE(8241)] = 268464,
  [SMALL_STATE(8242)] = 268489,
  [SMALL_STATE(8243)] = 268512,
  [SMALL_STATE(8244)] = 268549,
  [SMALL_STATE(8245)] = 268576,
  [SMALL_STATE(8246)] = 268607,
  [SMALL_STATE(8247)] = 268644,
  [SMALL_STATE(8248)] = 268681,
  [SMALL_STATE(8249)] = 268718,
  [SMALL_STATE(8250)] = 268743,
  [SMALL_STATE(8251)] = 268780,
  [SMALL_STATE(8252)] = 268805,
  [SMALL_STATE(8253)] = 268832,
  [SMALL_STATE(8254)] = 268869,
  [SMALL_STATE(8255)] = 268896,
  [SMALL_STATE(8256)] = 268933,
  [SMALL_STATE(8257)] = 268958,
  [SMALL_STATE(8258)] = 268981,
  [SMALL_STATE(8259)] = 269018,
  [SMALL_STATE(8260)] = 269055,
  [SMALL_STATE(8261)] = 269092,
  [SMALL_STATE(8262)] = 269129,
  [SMALL_STATE(8263)] = 269166,
  [SMALL_STATE(8264)] = 269201,
  [SMALL_STATE(8265)] = 269230,
  [SMALL_STATE(8266)] = 269255,
  [SMALL_STATE(8267)] = 269290,
  [SMALL_STATE(8268)] = 269325,
  [SMALL_STATE(8269)] = 269362,
  [SMALL_STATE(8270)] = 269399,
  [SMALL_STATE(8271)] = 269430,
  [SMALL_STATE(8272)] = 269461,
  [SMALL_STATE(8273)] = 269498,
  [SMALL_STATE(8274)] = 269533,
  [SMALL_STATE(8275)] = 269570,
  [SMALL_STATE(8276)] = 269595,
  [SMALL_STATE(8277)] = 269632,
  [SMALL_STATE(8278)] = 269663,
  [SMALL_STATE(8279)] = 269700,
  [SMALL_STATE(8280)] = 269725,
  [SMALL_STATE(8281)] = 269762,
  [SMALL_STATE(8282)] = 269791,
  [SMALL_STATE(8283)] = 269828,
  [SMALL_STATE(8284)] = 269865,
  [SMALL_STATE(8285)] = 269902,
  [SMALL_STATE(8286)] = 269939,
  [SMALL_STATE(8287)] = 269976,
  [SMALL_STATE(8288)] = 270007,
  [SMALL_STATE(8289)] = 270036,
  [SMALL_STATE(8290)] = 270073,
  [SMALL_STATE(8291)] = 270110,
  [SMALL_STATE(8292)] = 270141,
  [SMALL_STATE(8293)] = 270170,
  [SMALL_STATE(8294)] = 270207,
  [SMALL_STATE(8295)] = 270230,
  [SMALL_STATE(8296)] = 270261,
  [SMALL_STATE(8297)] = 270290,
  [SMALL_STATE(8298)] = 270325,
  [SMALL_STATE(8299)] = 270356,
  [SMALL_STATE(8300)] = 270387,
  [SMALL_STATE(8301)] = 270416,
  [SMALL_STATE(8302)] = 270453,
  [SMALL_STATE(8303)] = 270490,
  [SMALL_STATE(8304)] = 270527,
  [SMALL_STATE(8305)] = 270564,
  [SMALL_STATE(8306)] = 270599,
  [SMALL_STATE(8307)] = 270636,
  [SMALL_STATE(8308)] = 270673,
  [SMALL_STATE(8309)] = 270710,
  [SMALL_STATE(8310)] = 270747,
  [SMALL_STATE(8311)] = 270784,
  [SMALL_STATE(8312)] = 270819,
  [SMALL_STATE(8313)] = 270856,
  [SMALL_STATE(8314)] = 270893,
  [SMALL_STATE(8315)] = 270930,
  [SMALL_STATE(8316)] = 270967,
  [SMALL_STATE(8317)] = 271002,
  [SMALL_STATE(8318)] = 271039,
  [SMALL_STATE(8319)] = 271076,
  [SMALL_STATE(8320)] = 271113,
  [SMALL_STATE(8321)] = 271150,
  [SMALL_STATE(8322)] = 271181,
  [SMALL_STATE(8323)] = 271218,
  [SMALL_STATE(8324)] = 271249,
  [SMALL_STATE(8325)] = 271276,
  [SMALL_STATE(8326)] = 271313,
  [SMALL_STATE(8327)] = 271350,
  [SMALL_STATE(8328)] = 271387,
  [SMALL_STATE(8329)] = 271415,
  [SMALL_STATE(8330)] = 271443,
  [SMALL_STATE(8331)] = 271471,
  [SMALL_STATE(8332)] = 271499,
  [SMALL_STATE(8333)] = 271527,
  [SMALL_STATE(8334)] = 271555,
  [SMALL_STATE(8335)] = 271583,
  [SMALL_STATE(8336)] = 271605,
  [SMALL_STATE(8337)] = 271633,
  [SMALL_STATE(8338)] = 271661,
  [SMALL_STATE(8339)] = 271689,
  [SMALL_STATE(8340)] = 271717,
  [SMALL_STATE(8341)] = 271745,
  [SMALL_STATE(8342)] = 271773,
  [SMALL_STATE(8343)] = 271805,
  [SMALL_STATE(8344)] = 271833,
  [SMALL_STATE(8345)] = 271861,
  [SMALL_STATE(8346)] = 271889,
  [SMALL_STATE(8347)] = 271921,
  [SMALL_STATE(8348)] = 271949,
  [SMALL_STATE(8349)] = 271977,
  [SMALL_STATE(8350)] = 272005,
  [SMALL_STATE(8351)] = 272033,
  [SMALL_STATE(8352)] = 272061,
  [SMALL_STATE(8353)] = 272089,
  [SMALL_STATE(8354)] = 272113,
  [SMALL_STATE(8355)] = 272141,
  [SMALL_STATE(8356)] = 272167,
  [SMALL_STATE(8357)] = 272195,
  [SMALL_STATE(8358)] = 272223,
  [SMALL_STATE(8359)] = 272251,
  [SMALL_STATE(8360)] = 272279,
  [SMALL_STATE(8361)] = 272307,
  [SMALL_STATE(8362)] = 272335,
  [SMALL_STATE(8363)] = 272361,
  [SMALL_STATE(8364)] = 272389,
  [SMALL_STATE(8365)] = 272417,
  [SMALL_STATE(8366)] = 272445,
  [SMALL_STATE(8367)] = 272471,
  [SMALL_STATE(8368)] = 272499,
  [SMALL_STATE(8369)] = 272527,
  [SMALL_STATE(8370)] = 272555,
  [SMALL_STATE(8371)] = 272583,
  [SMALL_STATE(8372)] = 272611,
  [SMALL_STATE(8373)] = 272639,
  [SMALL_STATE(8374)] = 272667,
  [SMALL_STATE(8375)] = 272695,
  [SMALL_STATE(8376)] = 272723,
  [SMALL_STATE(8377)] = 272751,
  [SMALL_STATE(8378)] = 272779,
  [SMALL_STATE(8379)] = 272811,
  [SMALL_STATE(8380)] = 272839,
  [SMALL_STATE(8381)] = 272867,
  [SMALL_STATE(8382)] = 272899,
  [SMALL_STATE(8383)] = 272925,
  [SMALL_STATE(8384)] = 272953,
  [SMALL_STATE(8385)] = 272981,
  [SMALL_STATE(8386)] = 273009,
  [SMALL_STATE(8387)] = 273037,
  [SMALL_STATE(8388)] = 273065,
  [SMALL_STATE(8389)] = 273087,
  [SMALL_STATE(8390)] = 273113,
  [SMALL_STATE(8391)] = 273141,
  [SMALL_STATE(8392)] = 273169,
  [SMALL_STATE(8393)] = 273197,
  [SMALL_STATE(8394)] = 273219,
  [SMALL_STATE(8395)] = 273247,
  [SMALL_STATE(8396)] = 273275,
  [SMALL_STATE(8397)] = 273299,
  [SMALL_STATE(8398)] = 273323,
  [SMALL_STATE(8399)] = 273351,
  [SMALL_STATE(8400)] = 273379,
  [SMALL_STATE(8401)] = 273407,
  [SMALL_STATE(8402)] = 273435,
  [SMALL_STATE(8403)] = 273457,
  [SMALL_STATE(8404)] = 273485,
  [SMALL_STATE(8405)] = 273513,
  [SMALL_STATE(8406)] = 273541,
  [SMALL_STATE(8407)] = 273569,
  [SMALL_STATE(8408)] = 273597,
  [SMALL_STATE(8409)] = 273619,
  [SMALL_STATE(8410)] = 273643,
  [SMALL_STATE(8411)] = 273671,
  [SMALL_STATE(8412)] = 273699,
  [SMALL_STATE(8413)] = 273727,
  [SMALL_STATE(8414)] = 273755,
  [SMALL_STATE(8415)] = 273783,
  [SMALL_STATE(8416)] = 273811,
  [SMALL_STATE(8417)] = 273839,
  [SMALL_STATE(8418)] = 273867,
  [SMALL_STATE(8419)] = 273895,
  [SMALL_STATE(8420)] = 273923,
  [SMALL_STATE(8421)] = 273951,
  [SMALL_STATE(8422)] = 273979,
  [SMALL_STATE(8423)] = 274007,
  [SMALL_STATE(8424)] = 274035,
  [SMALL_STATE(8425)] = 274063,
  [SMALL_STATE(8426)] = 274091,
  [SMALL_STATE(8427)] = 274119,
  [SMALL_STATE(8428)] = 274147,
  [SMALL_STATE(8429)] = 274175,
  [SMALL_STATE(8430)] = 274203,
  [SMALL_STATE(8431)] = 274231,
  [SMALL_STATE(8432)] = 274259,
  [SMALL_STATE(8433)] = 274287,
  [SMALL_STATE(8434)] = 274315,
  [SMALL_STATE(8435)] = 274343,
  [SMALL_STATE(8436)] = 274371,
  [SMALL_STATE(8437)] = 274399,
  [SMALL_STATE(8438)] = 274427,
  [SMALL_STATE(8439)] = 274455,
  [SMALL_STATE(8440)] = 274483,
  [SMALL_STATE(8441)] = 274511,
  [SMALL_STATE(8442)] = 274539,
  [SMALL_STATE(8443)] = 274567,
  [SMALL_STATE(8444)] = 274599,
  [SMALL_STATE(8445)] = 274627,
  [SMALL_STATE(8446)] = 274655,
  [SMALL_STATE(8447)] = 274683,
  [SMALL_STATE(8448)] = 274711,
  [SMALL_STATE(8449)] = 274743,
  [SMALL_STATE(8450)] = 274771,
  [SMALL_STATE(8451)] = 274799,
  [SMALL_STATE(8452)] = 274827,
  [SMALL_STATE(8453)] = 274855,
  [SMALL_STATE(8454)] = 274883,
  [SMALL_STATE(8455)] = 274911,
  [SMALL_STATE(8456)] = 274939,
  [SMALL_STATE(8457)] = 274967,
  [SMALL_STATE(8458)] = 274995,
  [SMALL_STATE(8459)] = 275023,
  [SMALL_STATE(8460)] = 275051,
  [SMALL_STATE(8461)] = 275079,
  [SMALL_STATE(8462)] = 275107,
  [SMALL_STATE(8463)] = 275139,
  [SMALL_STATE(8464)] = 275161,
  [SMALL_STATE(8465)] = 275189,
  [SMALL_STATE(8466)] = 275217,
  [SMALL_STATE(8467)] = 275239,
  [SMALL_STATE(8468)] = 275267,
  [SMALL_STATE(8469)] = 275295,
  [SMALL_STATE(8470)] = 275323,
  [SMALL_STATE(8471)] = 275355,
  [SMALL_STATE(8472)] = 275383,
  [SMALL_STATE(8473)] = 275411,
  [SMALL_STATE(8474)] = 275439,
  [SMALL_STATE(8475)] = 275467,
  [SMALL_STATE(8476)] = 275495,
  [SMALL_STATE(8477)] = 275523,
  [SMALL_STATE(8478)] = 275551,
  [SMALL_STATE(8479)] = 275583,
  [SMALL_STATE(8480)] = 275615,
  [SMALL_STATE(8481)] = 275643,
  [SMALL_STATE(8482)] = 275671,
  [SMALL_STATE(8483)] = 275693,
  [SMALL_STATE(8484)] = 275715,
  [SMALL_STATE(8485)] = 275743,
  [SMALL_STATE(8486)] = 275771,
  [SMALL_STATE(8487)] = 275799,
  [SMALL_STATE(8488)] = 275827,
  [SMALL_STATE(8489)] = 275855,
  [SMALL_STATE(8490)] = 275883,
  [SMALL_STATE(8491)] = 275911,
  [SMALL_STATE(8492)] = 275939,
  [SMALL_STATE(8493)] = 275967,
  [SMALL_STATE(8494)] = 275995,
  [SMALL_STATE(8495)] = 276023,
  [SMALL_STATE(8496)] = 276051,
  [SMALL_STATE(8497)] = 276079,
  [SMALL_STATE(8498)] = 276107,
  [SMALL_STATE(8499)] = 276135,
  [SMALL_STATE(8500)] = 276163,
  [SMALL_STATE(8501)] = 276185,
  [SMALL_STATE(8502)] = 276213,
  [SMALL_STATE(8503)] = 276241,
  [SMALL_STATE(8504)] = 276269,
  [SMALL_STATE(8505)] = 276297,
  [SMALL_STATE(8506)] = 276325,
  [SMALL_STATE(8507)] = 276353,
  [SMALL_STATE(8508)] = 276381,
  [SMALL_STATE(8509)] = 276403,
  [SMALL_STATE(8510)] = 276425,
  [SMALL_STATE(8511)] = 276447,
  [SMALL_STATE(8512)] = 276469,
  [SMALL_STATE(8513)] = 276491,
  [SMALL_STATE(8514)] = 276513,
  [SMALL_STATE(8515)] = 276541,
  [SMALL_STATE(8516)] = 276569,
  [SMALL_STATE(8517)] = 276597,
  [SMALL_STATE(8518)] = 276625,
  [SMALL_STATE(8519)] = 276653,
  [SMALL_STATE(8520)] = 276681,
  [SMALL_STATE(8521)] = 276709,
  [SMALL_STATE(8522)] = 276737,
  [SMALL_STATE(8523)] = 276765,
  [SMALL_STATE(8524)] = 276793,
  [SMALL_STATE(8525)] = 276821,
  [SMALL_STATE(8526)] = 276849,
  [SMALL_STATE(8527)] = 276877,
  [SMALL_STATE(8528)] = 276905,
  [SMALL_STATE(8529)] = 276933,
  [SMALL_STATE(8530)] = 276961,
  [SMALL_STATE(8531)] = 276989,
  [SMALL_STATE(8532)] = 277017,
  [SMALL_STATE(8533)] = 277045,
  [SMALL_STATE(8534)] = 277073,
  [SMALL_STATE(8535)] = 277101,
  [SMALL_STATE(8536)] = 277129,
  [SMALL_STATE(8537)] = 277157,
  [SMALL_STATE(8538)] = 277185,
  [SMALL_STATE(8539)] = 277209,
  [SMALL_STATE(8540)] = 277233,
  [SMALL_STATE(8541)] = 277261,
  [SMALL_STATE(8542)] = 277289,
  [SMALL_STATE(8543)] = 277317,
  [SMALL_STATE(8544)] = 277345,
  [SMALL_STATE(8545)] = 277373,
  [SMALL_STATE(8546)] = 277401,
  [SMALL_STATE(8547)] = 277429,
  [SMALL_STATE(8548)] = 277457,
  [SMALL_STATE(8549)] = 277485,
  [SMALL_STATE(8550)] = 277513,
  [SMALL_STATE(8551)] = 277541,
  [SMALL_STATE(8552)] = 277569,
  [SMALL_STATE(8553)] = 277597,
  [SMALL_STATE(8554)] = 277625,
  [SMALL_STATE(8555)] = 277653,
  [SMALL_STATE(8556)] = 277681,
  [SMALL_STATE(8557)] = 277709,
  [SMALL_STATE(8558)] = 277737,
  [SMALL_STATE(8559)] = 277765,
  [SMALL_STATE(8560)] = 277793,
  [SMALL_STATE(8561)] = 277821,
  [SMALL_STATE(8562)] = 277849,
  [SMALL_STATE(8563)] = 277877,
  [SMALL_STATE(8564)] = 277905,
  [SMALL_STATE(8565)] = 277933,
  [SMALL_STATE(8566)] = 277959,
  [SMALL_STATE(8567)] = 277987,
  [SMALL_STATE(8568)] = 278015,
  [SMALL_STATE(8569)] = 278043,
  [SMALL_STATE(8570)] = 278071,
  [SMALL_STATE(8571)] = 278099,
  [SMALL_STATE(8572)] = 278127,
  [SMALL_STATE(8573)] = 278155,
  [SMALL_STATE(8574)] = 278183,
  [SMALL_STATE(8575)] = 278211,
  [SMALL_STATE(8576)] = 278239,
  [SMALL_STATE(8577)] = 278267,
  [SMALL_STATE(8578)] = 278295,
  [SMALL_STATE(8579)] = 278323,
  [SMALL_STATE(8580)] = 278351,
  [SMALL_STATE(8581)] = 278379,
  [SMALL_STATE(8582)] = 278407,
  [SMALL_STATE(8583)] = 278439,
  [SMALL_STATE(8584)] = 278467,
  [SMALL_STATE(8585)] = 278495,
  [SMALL_STATE(8586)] = 278523,
  [SMALL_STATE(8587)] = 278551,
  [SMALL_STATE(8588)] = 278579,
  [SMALL_STATE(8589)] = 278607,
  [SMALL_STATE(8590)] = 278635,
  [SMALL_STATE(8591)] = 278663,
  [SMALL_STATE(8592)] = 278691,
  [SMALL_STATE(8593)] = 278719,
  [SMALL_STATE(8594)] = 278747,
  [SMALL_STATE(8595)] = 278775,
  [SMALL_STATE(8596)] = 278803,
  [SMALL_STATE(8597)] = 278831,
  [SMALL_STATE(8598)] = 278859,
  [SMALL_STATE(8599)] = 278887,
  [SMALL_STATE(8600)] = 278915,
  [SMALL_STATE(8601)] = 278943,
  [SMALL_STATE(8602)] = 278971,
  [SMALL_STATE(8603)] = 278999,
  [SMALL_STATE(8604)] = 279027,
  [SMALL_STATE(8605)] = 279055,
  [SMALL_STATE(8606)] = 279083,
  [SMALL_STATE(8607)] = 279111,
  [SMALL_STATE(8608)] = 279139,
  [SMALL_STATE(8609)] = 279167,
  [SMALL_STATE(8610)] = 279195,
  [SMALL_STATE(8611)] = 279223,
  [SMALL_STATE(8612)] = 279251,
  [SMALL_STATE(8613)] = 279279,
  [SMALL_STATE(8614)] = 279307,
  [SMALL_STATE(8615)] = 279335,
  [SMALL_STATE(8616)] = 279363,
  [SMALL_STATE(8617)] = 279391,
  [SMALL_STATE(8618)] = 279419,
  [SMALL_STATE(8619)] = 279447,
  [SMALL_STATE(8620)] = 279475,
  [SMALL_STATE(8621)] = 279503,
  [SMALL_STATE(8622)] = 279531,
  [SMALL_STATE(8623)] = 279559,
  [SMALL_STATE(8624)] = 279587,
  [SMALL_STATE(8625)] = 279615,
  [SMALL_STATE(8626)] = 279643,
  [SMALL_STATE(8627)] = 279671,
  [SMALL_STATE(8628)] = 279699,
  [SMALL_STATE(8629)] = 279727,
  [SMALL_STATE(8630)] = 279755,
  [SMALL_STATE(8631)] = 279783,
  [SMALL_STATE(8632)] = 279811,
  [SMALL_STATE(8633)] = 279839,
  [SMALL_STATE(8634)] = 279867,
  [SMALL_STATE(8635)] = 279895,
  [SMALL_STATE(8636)] = 279923,
  [SMALL_STATE(8637)] = 279951,
  [SMALL_STATE(8638)] = 279979,
  [SMALL_STATE(8639)] = 280007,
  [SMALL_STATE(8640)] = 280035,
  [SMALL_STATE(8641)] = 280063,
  [SMALL_STATE(8642)] = 280091,
  [SMALL_STATE(8643)] = 280119,
  [SMALL_STATE(8644)] = 280147,
  [SMALL_STATE(8645)] = 280175,
  [SMALL_STATE(8646)] = 280203,
  [SMALL_STATE(8647)] = 280231,
  [SMALL_STATE(8648)] = 280259,
  [SMALL_STATE(8649)] = 280287,
  [SMALL_STATE(8650)] = 280315,
  [SMALL_STATE(8651)] = 280343,
  [SMALL_STATE(8652)] = 280371,
  [SMALL_STATE(8653)] = 280399,
  [SMALL_STATE(8654)] = 280427,
  [SMALL_STATE(8655)] = 280455,
  [SMALL_STATE(8656)] = 280483,
  [SMALL_STATE(8657)] = 280511,
  [SMALL_STATE(8658)] = 280539,
  [SMALL_STATE(8659)] = 280567,
  [SMALL_STATE(8660)] = 280595,
  [SMALL_STATE(8661)] = 280623,
  [SMALL_STATE(8662)] = 280651,
  [SMALL_STATE(8663)] = 280679,
  [SMALL_STATE(8664)] = 280707,
  [SMALL_STATE(8665)] = 280735,
  [SMALL_STATE(8666)] = 280763,
  [SMALL_STATE(8667)] = 280791,
  [SMALL_STATE(8668)] = 280819,
  [SMALL_STATE(8669)] = 280847,
  [SMALL_STATE(8670)] = 280875,
  [SMALL_STATE(8671)] = 280903,
  [SMALL_STATE(8672)] = 280931,
  [SMALL_STATE(8673)] = 280959,
  [SMALL_STATE(8674)] = 280987,
  [SMALL_STATE(8675)] = 281015,
  [SMALL_STATE(8676)] = 281043,
  [SMALL_STATE(8677)] = 281071,
  [SMALL_STATE(8678)] = 281099,
  [SMALL_STATE(8679)] = 281127,
  [SMALL_STATE(8680)] = 281155,
  [SMALL_STATE(8681)] = 281183,
  [SMALL_STATE(8682)] = 281211,
  [SMALL_STATE(8683)] = 281239,
  [SMALL_STATE(8684)] = 281267,
  [SMALL_STATE(8685)] = 281295,
  [SMALL_STATE(8686)] = 281323,
  [SMALL_STATE(8687)] = 281351,
  [SMALL_STATE(8688)] = 281379,
  [SMALL_STATE(8689)] = 281407,
  [SMALL_STATE(8690)] = 281435,
  [SMALL_STATE(8691)] = 281463,
  [SMALL_STATE(8692)] = 281491,
  [SMALL_STATE(8693)] = 281519,
  [SMALL_STATE(8694)] = 281547,
  [SMALL_STATE(8695)] = 281575,
  [SMALL_STATE(8696)] = 281603,
  [SMALL_STATE(8697)] = 281631,
  [SMALL_STATE(8698)] = 281659,
  [SMALL_STATE(8699)] = 281687,
  [SMALL_STATE(8700)] = 281715,
  [SMALL_STATE(8701)] = 281743,
  [SMALL_STATE(8702)] = 281771,
  [SMALL_STATE(8703)] = 281799,
  [SMALL_STATE(8704)] = 281827,
  [SMALL_STATE(8705)] = 281855,
  [SMALL_STATE(8706)] = 281883,
  [SMALL_STATE(8707)] = 281911,
  [SMALL_STATE(8708)] = 281939,
  [SMALL_STATE(8709)] = 281967,
  [SMALL_STATE(8710)] = 281995,
  [SMALL_STATE(8711)] = 282023,
  [SMALL_STATE(8712)] = 282055,
  [SMALL_STATE(8713)] = 282077,
  [SMALL_STATE(8714)] = 282105,
  [SMALL_STATE(8715)] = 282137,
  [SMALL_STATE(8716)] = 282165,
  [SMALL_STATE(8717)] = 282193,
  [SMALL_STATE(8718)] = 282221,
  [SMALL_STATE(8719)] = 282249,
  [SMALL_STATE(8720)] = 282281,
  [SMALL_STATE(8721)] = 282309,
  [SMALL_STATE(8722)] = 282337,
  [SMALL_STATE(8723)] = 282365,
  [SMALL_STATE(8724)] = 282393,
  [SMALL_STATE(8725)] = 282421,
  [SMALL_STATE(8726)] = 282449,
  [SMALL_STATE(8727)] = 282477,
  [SMALL_STATE(8728)] = 282505,
  [SMALL_STATE(8729)] = 282537,
  [SMALL_STATE(8730)] = 282565,
  [SMALL_STATE(8731)] = 282593,
  [SMALL_STATE(8732)] = 282621,
  [SMALL_STATE(8733)] = 282649,
  [SMALL_STATE(8734)] = 282677,
  [SMALL_STATE(8735)] = 282709,
  [SMALL_STATE(8736)] = 282741,
  [SMALL_STATE(8737)] = 282769,
  [SMALL_STATE(8738)] = 282797,
  [SMALL_STATE(8739)] = 282825,
  [SMALL_STATE(8740)] = 282853,
  [SMALL_STATE(8741)] = 282881,
  [SMALL_STATE(8742)] = 282909,
  [SMALL_STATE(8743)] = 282937,
  [SMALL_STATE(8744)] = 282965,
  [SMALL_STATE(8745)] = 282993,
  [SMALL_STATE(8746)] = 283021,
  [SMALL_STATE(8747)] = 283049,
  [SMALL_STATE(8748)] = 283077,
  [SMALL_STATE(8749)] = 283105,
  [SMALL_STATE(8750)] = 283133,
  [SMALL_STATE(8751)] = 283161,
  [SMALL_STATE(8752)] = 283189,
  [SMALL_STATE(8753)] = 283217,
  [SMALL_STATE(8754)] = 283245,
  [SMALL_STATE(8755)] = 283273,
  [SMALL_STATE(8756)] = 283301,
  [SMALL_STATE(8757)] = 283329,
  [SMALL_STATE(8758)] = 283357,
  [SMALL_STATE(8759)] = 283385,
  [SMALL_STATE(8760)] = 283413,
  [SMALL_STATE(8761)] = 283441,
  [SMALL_STATE(8762)] = 283469,
  [SMALL_STATE(8763)] = 283497,
  [SMALL_STATE(8764)] = 283525,
  [SMALL_STATE(8765)] = 283553,
  [SMALL_STATE(8766)] = 283581,
  [SMALL_STATE(8767)] = 283609,
  [SMALL_STATE(8768)] = 283637,
  [SMALL_STATE(8769)] = 283658,
  [SMALL_STATE(8770)] = 283681,
  [SMALL_STATE(8771)] = 283704,
  [SMALL_STATE(8772)] = 283727,
  [SMALL_STATE(8773)] = 283750,
  [SMALL_STATE(8774)] = 283773,
  [SMALL_STATE(8775)] = 283794,
  [SMALL_STATE(8776)] = 283815,
  [SMALL_STATE(8777)] = 283836,
  [SMALL_STATE(8778)] = 283859,
  [SMALL_STATE(8779)] = 283880,
  [SMALL_STATE(8780)] = 283903,
  [SMALL_STATE(8781)] = 283926,
  [SMALL_STATE(8782)] = 283949,
  [SMALL_STATE(8783)] = 283970,
  [SMALL_STATE(8784)] = 283993,
  [SMALL_STATE(8785)] = 284016,
  [SMALL_STATE(8786)] = 284039,
  [SMALL_STATE(8787)] = 284062,
  [SMALL_STATE(8788)] = 284083,
  [SMALL_STATE(8789)] = 284106,
  [SMALL_STATE(8790)] = 284127,
  [SMALL_STATE(8791)] = 284148,
  [SMALL_STATE(8792)] = 284169,
  [SMALL_STATE(8793)] = 284190,
  [SMALL_STATE(8794)] = 284213,
  [SMALL_STATE(8795)] = 284234,
  [SMALL_STATE(8796)] = 284255,
  [SMALL_STATE(8797)] = 284276,
  [SMALL_STATE(8798)] = 284297,
  [SMALL_STATE(8799)] = 284320,
  [SMALL_STATE(8800)] = 284343,
  [SMALL_STATE(8801)] = 284364,
  [SMALL_STATE(8802)] = 284385,
  [SMALL_STATE(8803)] = 284406,
  [SMALL_STATE(8804)] = 284427,
  [SMALL_STATE(8805)] = 284448,
  [SMALL_STATE(8806)] = 284469,
  [SMALL_STATE(8807)] = 284490,
  [SMALL_STATE(8808)] = 284513,
  [SMALL_STATE(8809)] = 284534,
  [SMALL_STATE(8810)] = 284557,
  [SMALL_STATE(8811)] = 284580,
  [SMALL_STATE(8812)] = 284601,
  [SMALL_STATE(8813)] = 284622,
  [SMALL_STATE(8814)] = 284645,
  [SMALL_STATE(8815)] = 284668,
  [SMALL_STATE(8816)] = 284689,
  [SMALL_STATE(8817)] = 284712,
  [SMALL_STATE(8818)] = 284733,
  [SMALL_STATE(8819)] = 284754,
  [SMALL_STATE(8820)] = 284775,
  [SMALL_STATE(8821)] = 284798,
  [SMALL_STATE(8822)] = 284819,
  [SMALL_STATE(8823)] = 284840,
  [SMALL_STATE(8824)] = 284863,
  [SMALL_STATE(8825)] = 284884,
  [SMALL_STATE(8826)] = 284907,
  [SMALL_STATE(8827)] = 284930,
  [SMALL_STATE(8828)] = 284951,
  [SMALL_STATE(8829)] = 284974,
  [SMALL_STATE(8830)] = 284997,
  [SMALL_STATE(8831)] = 285020,
  [SMALL_STATE(8832)] = 285041,
  [SMALL_STATE(8833)] = 285062,
  [SMALL_STATE(8834)] = 285085,
  [SMALL_STATE(8835)] = 285108,
  [SMALL_STATE(8836)] = 285129,
  [SMALL_STATE(8837)] = 285150,
  [SMALL_STATE(8838)] = 285173,
  [SMALL_STATE(8839)] = 285194,
  [SMALL_STATE(8840)] = 285217,
  [SMALL_STATE(8841)] = 285238,
  [SMALL_STATE(8842)] = 285261,
  [SMALL_STATE(8843)] = 285284,
  [SMALL_STATE(8844)] = 285305,
  [SMALL_STATE(8845)] = 285328,
  [SMALL_STATE(8846)] = 285356,
  [SMALL_STATE(8847)] = 285376,
  [SMALL_STATE(8848)] = 285396,
  [SMALL_STATE(8849)] = 285416,
  [SMALL_STATE(8850)] = 285436,
  [SMALL_STATE(8851)] = 285464,
  [SMALL_STATE(8852)] = 285492,
  [SMALL_STATE(8853)] = 285520,
  [SMALL_STATE(8854)] = 285540,
  [SMALL_STATE(8855)] = 285568,
  [SMALL_STATE(8856)] = 285596,
  [SMALL_STATE(8857)] = 285624,
  [SMALL_STATE(8858)] = 285644,
  [SMALL_STATE(8859)] = 285664,
  [SMALL_STATE(8860)] = 285684,
  [SMALL_STATE(8861)] = 285704,
  [SMALL_STATE(8862)] = 285724,
  [SMALL_STATE(8863)] = 285752,
  [SMALL_STATE(8864)] = 285780,
  [SMALL_STATE(8865)] = 285800,
  [SMALL_STATE(8866)] = 285820,
  [SMALL_STATE(8867)] = 285840,
  [SMALL_STATE(8868)] = 285860,
  [SMALL_STATE(8869)] = 285888,
  [SMALL_STATE(8870)] = 285916,
  [SMALL_STATE(8871)] = 285944,
  [SMALL_STATE(8872)] = 285964,
  [SMALL_STATE(8873)] = 285992,
  [SMALL_STATE(8874)] = 286020,
  [SMALL_STATE(8875)] = 286048,
  [SMALL_STATE(8876)] = 286070,
  [SMALL_STATE(8877)] = 286098,
  [SMALL_STATE(8878)] = 286126,
  [SMALL_STATE(8879)] = 286154,
  [SMALL_STATE(8880)] = 286182,
  [SMALL_STATE(8881)] = 286210,
  [SMALL_STATE(8882)] = 286230,
  [SMALL_STATE(8883)] = 286258,
  [SMALL_STATE(8884)] = 286278,
  [SMALL_STATE(8885)] = 286298,
  [SMALL_STATE(8886)] = 286318,
  [SMALL_STATE(8887)] = 286338,
  [SMALL_STATE(8888)] = 286358,
  [SMALL_STATE(8889)] = 286378,
  [SMALL_STATE(8890)] = 286398,
  [SMALL_STATE(8891)] = 286418,
  [SMALL_STATE(8892)] = 286438,
  [SMALL_STATE(8893)] = 286458,
  [SMALL_STATE(8894)] = 286478,
  [SMALL_STATE(8895)] = 286506,
  [SMALL_STATE(8896)] = 286526,
  [SMALL_STATE(8897)] = 286554,
  [SMALL_STATE(8898)] = 286574,
  [SMALL_STATE(8899)] = 286594,
  [SMALL_STATE(8900)] = 286614,
  [SMALL_STATE(8901)] = 286634,
  [SMALL_STATE(8902)] = 286654,
  [SMALL_STATE(8903)] = 286674,
  [SMALL_STATE(8904)] = 286694,
  [SMALL_STATE(8905)] = 286714,
  [SMALL_STATE(8906)] = 286734,
  [SMALL_STATE(8907)] = 286754,
  [SMALL_STATE(8908)] = 286774,
  [SMALL_STATE(8909)] = 286794,
  [SMALL_STATE(8910)] = 286814,
  [SMALL_STATE(8911)] = 286834,
  [SMALL_STATE(8912)] = 286854,
  [SMALL_STATE(8913)] = 286874,
  [SMALL_STATE(8914)] = 286894,
  [SMALL_STATE(8915)] = 286914,
  [SMALL_STATE(8916)] = 286934,
  [SMALL_STATE(8917)] = 286962,
  [SMALL_STATE(8918)] = 286990,
  [SMALL_STATE(8919)] = 287010,
  [SMALL_STATE(8920)] = 287032,
  [SMALL_STATE(8921)] = 287052,
  [SMALL_STATE(8922)] = 287072,
  [SMALL_STATE(8923)] = 287100,
  [SMALL_STATE(8924)] = 287120,
  [SMALL_STATE(8925)] = 287140,
  [SMALL_STATE(8926)] = 287160,
  [SMALL_STATE(8927)] = 287180,
  [SMALL_STATE(8928)] = 287200,
  [SMALL_STATE(8929)] = 287220,
  [SMALL_STATE(8930)] = 287240,
  [SMALL_STATE(8931)] = 287260,
  [SMALL_STATE(8932)] = 287280,
  [SMALL_STATE(8933)] = 287300,
  [SMALL_STATE(8934)] = 287328,
  [SMALL_STATE(8935)] = 287348,
  [SMALL_STATE(8936)] = 287368,
  [SMALL_STATE(8937)] = 287396,
  [SMALL_STATE(8938)] = 287416,
  [SMALL_STATE(8939)] = 287436,
  [SMALL_STATE(8940)] = 287456,
  [SMALL_STATE(8941)] = 287476,
  [SMALL_STATE(8942)] = 287496,
  [SMALL_STATE(8943)] = 287524,
  [SMALL_STATE(8944)] = 287544,
  [SMALL_STATE(8945)] = 287564,
  [SMALL_STATE(8946)] = 287584,
  [SMALL_STATE(8947)] = 287612,
  [SMALL_STATE(8948)] = 287632,
  [SMALL_STATE(8949)] = 287660,
  [SMALL_STATE(8950)] = 287688,
  [SMALL_STATE(8951)] = 287716,
  [SMALL_STATE(8952)] = 287744,
  [SMALL_STATE(8953)] = 287772,
  [SMALL_STATE(8954)] = 287800,
  [SMALL_STATE(8955)] = 287828,
  [SMALL_STATE(8956)] = 287848,
  [SMALL_STATE(8957)] = 287876,
  [SMALL_STATE(8958)] = 287904,
  [SMALL_STATE(8959)] = 287932,
  [SMALL_STATE(8960)] = 287960,
  [SMALL_STATE(8961)] = 287988,
  [SMALL_STATE(8962)] = 288016,
  [SMALL_STATE(8963)] = 288044,
  [SMALL_STATE(8964)] = 288064,
  [SMALL_STATE(8965)] = 288084,
  [SMALL_STATE(8966)] = 288113,
  [SMALL_STATE(8967)] = 288142,
  [SMALL_STATE(8968)] = 288171,
  [SMALL_STATE(8969)] = 288200,
  [SMALL_STATE(8970)] = 288229,
  [SMALL_STATE(8971)] = 288258,
  [SMALL_STATE(8972)] = 288287,
  [SMALL_STATE(8973)] = 288316,
  [SMALL_STATE(8974)] = 288345,
  [SMALL_STATE(8975)] = 288374,
  [SMALL_STATE(8976)] = 288403,
  [SMALL_STATE(8977)] = 288432,
  [SMALL_STATE(8978)] = 288461,
  [SMALL_STATE(8979)] = 288490,
  [SMALL_STATE(8980)] = 288519,
  [SMALL_STATE(8981)] = 288548,
  [SMALL_STATE(8982)] = 288575,
  [SMALL_STATE(8983)] = 288604,
  [SMALL_STATE(8984)] = 288633,
  [SMALL_STATE(8985)] = 288652,
  [SMALL_STATE(8986)] = 288679,
  [SMALL_STATE(8987)] = 288700,
  [SMALL_STATE(8988)] = 288719,
  [SMALL_STATE(8989)] = 288740,
  [SMALL_STATE(8990)] = 288761,
  [SMALL_STATE(8991)] = 288782,
  [SMALL_STATE(8992)] = 288801,
  [SMALL_STATE(8993)] = 288828,
  [SMALL_STATE(8994)] = 288847,
  [SMALL_STATE(8995)] = 288876,
  [SMALL_STATE(8996)] = 288905,
  [SMALL_STATE(8997)] = 288934,
  [SMALL_STATE(8998)] = 288963,
  [SMALL_STATE(8999)] = 288992,
  [SMALL_STATE(9000)] = 289021,
  [SMALL_STATE(9001)] = 289050,
  [SMALL_STATE(9002)] = 289076,
  [SMALL_STATE(9003)] = 289102,
  [SMALL_STATE(9004)] = 289120,
  [SMALL_STATE(9005)] = 289146,
  [SMALL_STATE(9006)] = 289172,
  [SMALL_STATE(9007)] = 289198,
  [SMALL_STATE(9008)] = 289216,
  [SMALL_STATE(9009)] = 289234,
  [SMALL_STATE(9010)] = 289252,
  [SMALL_STATE(9011)] = 289272,
  [SMALL_STATE(9012)] = 289290,
  [SMALL_STATE(9013)] = 289308,
  [SMALL_STATE(9014)] = 289326,
  [SMALL_STATE(9015)] = 289344,
  [SMALL_STATE(9016)] = 289362,
  [SMALL_STATE(9017)] = 289380,
  [SMALL_STATE(9018)] = 289406,
  [SMALL_STATE(9019)] = 289432,
  [SMALL_STATE(9020)] = 289450,
  [SMALL_STATE(9021)] = 289468,
  [SMALL_STATE(9022)] = 289486,
  [SMALL_STATE(9023)] = 289512,
  [SMALL_STATE(9024)] = 289530,
  [SMALL_STATE(9025)] = 289548,
  [SMALL_STATE(9026)] = 289574,
  [SMALL_STATE(9027)] = 289600,
  [SMALL_STATE(9028)] = 289626,
  [SMALL_STATE(9029)] = 289652,
  [SMALL_STATE(9030)] = 289678,
  [SMALL_STATE(9031)] = 289696,
  [SMALL_STATE(9032)] = 289722,
  [SMALL_STATE(9033)] = 289740,
  [SMALL_STATE(9034)] = 289757,
  [SMALL_STATE(9035)] = 289774,
  [SMALL_STATE(9036)] = 289791,
  [SMALL_STATE(9037)] = 289808,
  [SMALL_STATE(9038)] = 289825,
  [SMALL_STATE(9039)] = 289842,
  [SMALL_STATE(9040)] = 289859,
  [SMALL_STATE(9041)] = 289876,
  [SMALL_STATE(9042)] = 289893,
  [SMALL_STATE(9043)] = 289910,
  [SMALL_STATE(9044)] = 289927,
  [SMALL_STATE(9045)] = 289944,
  [SMALL_STATE(9046)] = 289961,
  [SMALL_STATE(9047)] = 289978,
  [SMALL_STATE(9048)] = 289995,
  [SMALL_STATE(9049)] = 290012,
  [SMALL_STATE(9050)] = 290029,
  [SMALL_STATE(9051)] = 290046,
  [SMALL_STATE(9052)] = 290063,
  [SMALL_STATE(9053)] = 290080,
  [SMALL_STATE(9054)] = 290097,
  [SMALL_STATE(9055)] = 290114,
  [SMALL_STATE(9056)] = 290131,
  [SMALL_STATE(9057)] = 290148,
  [SMALL_STATE(9058)] = 290165,
  [SMALL_STATE(9059)] = 290185,
  [SMALL_STATE(9060)] = 290205,
  [SMALL_STATE(9061)] = 290225,
  [SMALL_STATE(9062)] = 290245,
  [SMALL_STATE(9063)] = 290265,
  [SMALL_STATE(9064)] = 290285,
  [SMALL_STATE(9065)] = 290305,
  [SMALL_STATE(9066)] = 290325,
  [SMALL_STATE(9067)] = 290345,
  [SMALL_STATE(9068)] = 290365,
  [SMALL_STATE(9069)] = 290385,
  [SMALL_STATE(9070)] = 290405,
  [SMALL_STATE(9071)] = 290425,
  [SMALL_STATE(9072)] = 290445,
  [SMALL_STATE(9073)] = 290465,
  [SMALL_STATE(9074)] = 290485,
  [SMALL_STATE(9075)] = 290505,
  [SMALL_STATE(9076)] = 290525,
  [SMALL_STATE(9077)] = 290545,
  [SMALL_STATE(9078)] = 290565,
  [SMALL_STATE(9079)] = 290585,
  [SMALL_STATE(9080)] = 290605,
  [SMALL_STATE(9081)] = 290625,
  [SMALL_STATE(9082)] = 290645,
  [SMALL_STATE(9083)] = 290665,
  [SMALL_STATE(9084)] = 290685,
  [SMALL_STATE(9085)] = 290705,
  [SMALL_STATE(9086)] = 290725,
  [SMALL_STATE(9087)] = 290745,
  [SMALL_STATE(9088)] = 290765,
  [SMALL_STATE(9089)] = 290785,
  [SMALL_STATE(9090)] = 290805,
  [SMALL_STATE(9091)] = 290825,
  [SMALL_STATE(9092)] = 290845,
  [SMALL_STATE(9093)] = 290865,
  [SMALL_STATE(9094)] = 290885,
  [SMALL_STATE(9095)] = 290905,
  [SMALL_STATE(9096)] = 290925,
  [SMALL_STATE(9097)] = 290945,
  [SMALL_STATE(9098)] = 290965,
  [SMALL_STATE(9099)] = 290985,
  [SMALL_STATE(9100)] = 291005,
  [SMALL_STATE(9101)] = 291025,
  [SMALL_STATE(9102)] = 291045,
  [SMALL_STATE(9103)] = 291065,
  [SMALL_STATE(9104)] = 291085,
  [SMALL_STATE(9105)] = 291105,
  [SMALL_STATE(9106)] = 291125,
  [SMALL_STATE(9107)] = 291145,
  [SMALL_STATE(9108)] = 291165,
  [SMALL_STATE(9109)] = 291185,
  [SMALL_STATE(9110)] = 291205,
  [SMALL_STATE(9111)] = 291225,
  [SMALL_STATE(9112)] = 291245,
  [SMALL_STATE(9113)] = 291265,
  [SMALL_STATE(9114)] = 291285,
  [SMALL_STATE(9115)] = 291305,
  [SMALL_STATE(9116)] = 291325,
  [SMALL_STATE(9117)] = 291345,
  [SMALL_STATE(9118)] = 291361,
  [SMALL_STATE(9119)] = 291381,
  [SMALL_STATE(9120)] = 291401,
  [SMALL_STATE(9121)] = 291421,
  [SMALL_STATE(9122)] = 291441,
  [SMALL_STATE(9123)] = 291461,
  [SMALL_STATE(9124)] = 291481,
  [SMALL_STATE(9125)] = 291501,
  [SMALL_STATE(9126)] = 291521,
  [SMALL_STATE(9127)] = 291541,
  [SMALL_STATE(9128)] = 291561,
  [SMALL_STATE(9129)] = 291581,
  [SMALL_STATE(9130)] = 291601,
  [SMALL_STATE(9131)] = 291621,
  [SMALL_STATE(9132)] = 291641,
  [SMALL_STATE(9133)] = 291661,
  [SMALL_STATE(9134)] = 291681,
  [SMALL_STATE(9135)] = 291701,
  [SMALL_STATE(9136)] = 291721,
  [SMALL_STATE(9137)] = 291741,
  [SMALL_STATE(9138)] = 291761,
  [SMALL_STATE(9139)] = 291781,
  [SMALL_STATE(9140)] = 291801,
  [SMALL_STATE(9141)] = 291821,
  [SMALL_STATE(9142)] = 291841,
  [SMALL_STATE(9143)] = 291861,
  [SMALL_STATE(9144)] = 291881,
  [SMALL_STATE(9145)] = 291901,
  [SMALL_STATE(9146)] = 291921,
  [SMALL_STATE(9147)] = 291941,
  [SMALL_STATE(9148)] = 291961,
  [SMALL_STATE(9149)] = 291981,
  [SMALL_STATE(9150)] = 292001,
  [SMALL_STATE(9151)] = 292021,
  [SMALL_STATE(9152)] = 292041,
  [SMALL_STATE(9153)] = 292061,
  [SMALL_STATE(9154)] = 292081,
  [SMALL_STATE(9155)] = 292101,
  [SMALL_STATE(9156)] = 292121,
  [SMALL_STATE(9157)] = 292141,
  [SMALL_STATE(9158)] = 292161,
  [SMALL_STATE(9159)] = 292181,
  [SMALL_STATE(9160)] = 292201,
  [SMALL_STATE(9161)] = 292221,
  [SMALL_STATE(9162)] = 292241,
  [SMALL_STATE(9163)] = 292261,
  [SMALL_STATE(9164)] = 292281,
  [SMALL_STATE(9165)] = 292301,
  [SMALL_STATE(9166)] = 292321,
  [SMALL_STATE(9167)] = 292341,
  [SMALL_STATE(9168)] = 292361,
  [SMALL_STATE(9169)] = 292381,
  [SMALL_STATE(9170)] = 292401,
  [SMALL_STATE(9171)] = 292421,
  [SMALL_STATE(9172)] = 292441,
  [SMALL_STATE(9173)] = 292461,
  [SMALL_STATE(9174)] = 292481,
  [SMALL_STATE(9175)] = 292501,
  [SMALL_STATE(9176)] = 292521,
  [SMALL_STATE(9177)] = 292541,
  [SMALL_STATE(9178)] = 292561,
  [SMALL_STATE(9179)] = 292581,
  [SMALL_STATE(9180)] = 292601,
  [SMALL_STATE(9181)] = 292621,
  [SMALL_STATE(9182)] = 292641,
  [SMALL_STATE(9183)] = 292661,
  [SMALL_STATE(9184)] = 292681,
  [SMALL_STATE(9185)] = 292701,
  [SMALL_STATE(9186)] = 292721,
  [SMALL_STATE(9187)] = 292741,
  [SMALL_STATE(9188)] = 292761,
  [SMALL_STATE(9189)] = 292781,
  [SMALL_STATE(9190)] = 292801,
  [SMALL_STATE(9191)] = 292821,
  [SMALL_STATE(9192)] = 292841,
  [SMALL_STATE(9193)] = 292861,
  [SMALL_STATE(9194)] = 292881,
  [SMALL_STATE(9195)] = 292901,
  [SMALL_STATE(9196)] = 292921,
  [SMALL_STATE(9197)] = 292941,
  [SMALL_STATE(9198)] = 292961,
  [SMALL_STATE(9199)] = 292981,
  [SMALL_STATE(9200)] = 293001,
  [SMALL_STATE(9201)] = 293021,
  [SMALL_STATE(9202)] = 293041,
  [SMALL_STATE(9203)] = 293061,
  [SMALL_STATE(9204)] = 293081,
  [SMALL_STATE(9205)] = 293101,
  [SMALL_STATE(9206)] = 293121,
  [SMALL_STATE(9207)] = 293141,
  [SMALL_STATE(9208)] = 293161,
  [SMALL_STATE(9209)] = 293181,
  [SMALL_STATE(9210)] = 293201,
  [SMALL_STATE(9211)] = 293221,
  [SMALL_STATE(9212)] = 293241,
  [SMALL_STATE(9213)] = 293261,
  [SMALL_STATE(9214)] = 293281,
  [SMALL_STATE(9215)] = 293301,
  [SMALL_STATE(9216)] = 293321,
  [SMALL_STATE(9217)] = 293341,
  [SMALL_STATE(9218)] = 293361,
  [SMALL_STATE(9219)] = 293381,
  [SMALL_STATE(9220)] = 293401,
  [SMALL_STATE(9221)] = 293421,
  [SMALL_STATE(9222)] = 293441,
  [SMALL_STATE(9223)] = 293461,
  [SMALL_STATE(9224)] = 293481,
  [SMALL_STATE(9225)] = 293501,
  [SMALL_STATE(9226)] = 293521,
  [SMALL_STATE(9227)] = 293541,
  [SMALL_STATE(9228)] = 293561,
  [SMALL_STATE(9229)] = 293581,
  [SMALL_STATE(9230)] = 293601,
  [SMALL_STATE(9231)] = 293621,
  [SMALL_STATE(9232)] = 293641,
  [SMALL_STATE(9233)] = 293661,
  [SMALL_STATE(9234)] = 293681,
  [SMALL_STATE(9235)] = 293701,
  [SMALL_STATE(9236)] = 293721,
  [SMALL_STATE(9237)] = 293741,
  [SMALL_STATE(9238)] = 293761,
  [SMALL_STATE(9239)] = 293781,
  [SMALL_STATE(9240)] = 293801,
  [SMALL_STATE(9241)] = 293821,
  [SMALL_STATE(9242)] = 293841,
  [SMALL_STATE(9243)] = 293861,
  [SMALL_STATE(9244)] = 293881,
  [SMALL_STATE(9245)] = 293901,
  [SMALL_STATE(9246)] = 293921,
  [SMALL_STATE(9247)] = 293941,
  [SMALL_STATE(9248)] = 293961,
  [SMALL_STATE(9249)] = 293981,
  [SMALL_STATE(9250)] = 294001,
  [SMALL_STATE(9251)] = 294021,
  [SMALL_STATE(9252)] = 294041,
  [SMALL_STATE(9253)] = 294061,
  [SMALL_STATE(9254)] = 294081,
  [SMALL_STATE(9255)] = 294101,
  [SMALL_STATE(9256)] = 294121,
  [SMALL_STATE(9257)] = 294141,
  [SMALL_STATE(9258)] = 294161,
  [SMALL_STATE(9259)] = 294181,
  [SMALL_STATE(9260)] = 294201,
  [SMALL_STATE(9261)] = 294221,
  [SMALL_STATE(9262)] = 294241,
  [SMALL_STATE(9263)] = 294261,
  [SMALL_STATE(9264)] = 294281,
  [SMALL_STATE(9265)] = 294301,
  [SMALL_STATE(9266)] = 294321,
  [SMALL_STATE(9267)] = 294341,
  [SMALL_STATE(9268)] = 294361,
  [SMALL_STATE(9269)] = 294381,
  [SMALL_STATE(9270)] = 294401,
  [SMALL_STATE(9271)] = 294421,
  [SMALL_STATE(9272)] = 294441,
  [SMALL_STATE(9273)] = 294461,
  [SMALL_STATE(9274)] = 294481,
  [SMALL_STATE(9275)] = 294501,
  [SMALL_STATE(9276)] = 294521,
  [SMALL_STATE(9277)] = 294541,
  [SMALL_STATE(9278)] = 294561,
  [SMALL_STATE(9279)] = 294581,
  [SMALL_STATE(9280)] = 294601,
  [SMALL_STATE(9281)] = 294621,
  [SMALL_STATE(9282)] = 294641,
  [SMALL_STATE(9283)] = 294661,
  [SMALL_STATE(9284)] = 294681,
  [SMALL_STATE(9285)] = 294701,
  [SMALL_STATE(9286)] = 294721,
  [SMALL_STATE(9287)] = 294741,
  [SMALL_STATE(9288)] = 294761,
  [SMALL_STATE(9289)] = 294781,
  [SMALL_STATE(9290)] = 294801,
  [SMALL_STATE(9291)] = 294821,
  [SMALL_STATE(9292)] = 294841,
  [SMALL_STATE(9293)] = 294861,
  [SMALL_STATE(9294)] = 294881,
  [SMALL_STATE(9295)] = 294901,
  [SMALL_STATE(9296)] = 294921,
  [SMALL_STATE(9297)] = 294941,
  [SMALL_STATE(9298)] = 294961,
  [SMALL_STATE(9299)] = 294981,
  [SMALL_STATE(9300)] = 295001,
  [SMALL_STATE(9301)] = 295021,
  [SMALL_STATE(9302)] = 295041,
  [SMALL_STATE(9303)] = 295060,
  [SMALL_STATE(9304)] = 295077,
  [SMALL_STATE(9305)] = 295094,
  [SMALL_STATE(9306)] = 295113,
  [SMALL_STATE(9307)] = 295130,
  [SMALL_STATE(9308)] = 295147,
  [SMALL_STATE(9309)] = 295164,
  [SMALL_STATE(9310)] = 295181,
  [SMALL_STATE(9311)] = 295198,
  [SMALL_STATE(9312)] = 295215,
  [SMALL_STATE(9313)] = 295232,
  [SMALL_STATE(9314)] = 295249,
  [SMALL_STATE(9315)] = 295266,
  [SMALL_STATE(9316)] = 295283,
  [SMALL_STATE(9317)] = 295300,
  [SMALL_STATE(9318)] = 295317,
  [SMALL_STATE(9319)] = 295334,
  [SMALL_STATE(9320)] = 295351,
  [SMALL_STATE(9321)] = 295368,
  [SMALL_STATE(9322)] = 295385,
  [SMALL_STATE(9323)] = 295402,
  [SMALL_STATE(9324)] = 295419,
  [SMALL_STATE(9325)] = 295436,
  [SMALL_STATE(9326)] = 295453,
  [SMALL_STATE(9327)] = 295470,
  [SMALL_STATE(9328)] = 295489,
  [SMALL_STATE(9329)] = 295508,
  [SMALL_STATE(9330)] = 295525,
  [SMALL_STATE(9331)] = 295542,
  [SMALL_STATE(9332)] = 295559,
  [SMALL_STATE(9333)] = 295576,
  [SMALL_STATE(9334)] = 295593,
  [SMALL_STATE(9335)] = 295612,
  [SMALL_STATE(9336)] = 295631,
  [SMALL_STATE(9337)] = 295650,
  [SMALL_STATE(9338)] = 295669,
  [SMALL_STATE(9339)] = 295686,
  [SMALL_STATE(9340)] = 295703,
  [SMALL_STATE(9341)] = 295720,
  [SMALL_STATE(9342)] = 295737,
  [SMALL_STATE(9343)] = 295754,
  [SMALL_STATE(9344)] = 295771,
  [SMALL_STATE(9345)] = 295788,
  [SMALL_STATE(9346)] = 295805,
  [SMALL_STATE(9347)] = 295822,
  [SMALL_STATE(9348)] = 295839,
  [SMALL_STATE(9349)] = 295856,
  [SMALL_STATE(9350)] = 295875,
  [SMALL_STATE(9351)] = 295892,
  [SMALL_STATE(9352)] = 295909,
  [SMALL_STATE(9353)] = 295926,
  [SMALL_STATE(9354)] = 295943,
  [SMALL_STATE(9355)] = 295960,
  [SMALL_STATE(9356)] = 295977,
  [SMALL_STATE(9357)] = 295994,
  [SMALL_STATE(9358)] = 296011,
  [SMALL_STATE(9359)] = 296028,
  [SMALL_STATE(9360)] = 296045,
  [SMALL_STATE(9361)] = 296062,
  [SMALL_STATE(9362)] = 296079,
  [SMALL_STATE(9363)] = 296096,
  [SMALL_STATE(9364)] = 296113,
  [SMALL_STATE(9365)] = 296130,
  [SMALL_STATE(9366)] = 296147,
  [SMALL_STATE(9367)] = 296166,
  [SMALL_STATE(9368)] = 296183,
  [SMALL_STATE(9369)] = 296202,
  [SMALL_STATE(9370)] = 296219,
  [SMALL_STATE(9371)] = 296236,
  [SMALL_STATE(9372)] = 296253,
  [SMALL_STATE(9373)] = 296270,
  [SMALL_STATE(9374)] = 296287,
  [SMALL_STATE(9375)] = 296304,
  [SMALL_STATE(9376)] = 296321,
  [SMALL_STATE(9377)] = 296338,
  [SMALL_STATE(9378)] = 296355,
  [SMALL_STATE(9379)] = 296372,
  [SMALL_STATE(9380)] = 296389,
  [SMALL_STATE(9381)] = 296406,
  [SMALL_STATE(9382)] = 296423,
  [SMALL_STATE(9383)] = 296440,
  [SMALL_STATE(9384)] = 296457,
  [SMALL_STATE(9385)] = 296474,
  [SMALL_STATE(9386)] = 296491,
  [SMALL_STATE(9387)] = 296508,
  [SMALL_STATE(9388)] = 296527,
  [SMALL_STATE(9389)] = 296546,
  [SMALL_STATE(9390)] = 296563,
  [SMALL_STATE(9391)] = 296578,
  [SMALL_STATE(9392)] = 296595,
  [SMALL_STATE(9393)] = 296610,
  [SMALL_STATE(9394)] = 296627,
  [SMALL_STATE(9395)] = 296644,
  [SMALL_STATE(9396)] = 296659,
  [SMALL_STATE(9397)] = 296676,
  [SMALL_STATE(9398)] = 296693,
  [SMALL_STATE(9399)] = 296710,
  [SMALL_STATE(9400)] = 296727,
  [SMALL_STATE(9401)] = 296744,
  [SMALL_STATE(9402)] = 296761,
  [SMALL_STATE(9403)] = 296776,
  [SMALL_STATE(9404)] = 296791,
  [SMALL_STATE(9405)] = 296808,
  [SMALL_STATE(9406)] = 296825,
  [SMALL_STATE(9407)] = 296842,
  [SMALL_STATE(9408)] = 296859,
  [SMALL_STATE(9409)] = 296876,
  [SMALL_STATE(9410)] = 296893,
  [SMALL_STATE(9411)] = 296910,
  [SMALL_STATE(9412)] = 296927,
  [SMALL_STATE(9413)] = 296944,
  [SMALL_STATE(9414)] = 296961,
  [SMALL_STATE(9415)] = 296978,
  [SMALL_STATE(9416)] = 296995,
  [SMALL_STATE(9417)] = 297014,
  [SMALL_STATE(9418)] = 297029,
  [SMALL_STATE(9419)] = 297046,
  [SMALL_STATE(9420)] = 297061,
  [SMALL_STATE(9421)] = 297080,
  [SMALL_STATE(9422)] = 297097,
  [SMALL_STATE(9423)] = 297114,
  [SMALL_STATE(9424)] = 297131,
  [SMALL_STATE(9425)] = 297146,
  [SMALL_STATE(9426)] = 297161,
  [SMALL_STATE(9427)] = 297176,
  [SMALL_STATE(9428)] = 297191,
  [SMALL_STATE(9429)] = 297208,
  [SMALL_STATE(9430)] = 297225,
  [SMALL_STATE(9431)] = 297242,
  [SMALL_STATE(9432)] = 297259,
  [SMALL_STATE(9433)] = 297276,
  [SMALL_STATE(9434)] = 297293,
  [SMALL_STATE(9435)] = 297308,
  [SMALL_STATE(9436)] = 297325,
  [SMALL_STATE(9437)] = 297342,
  [SMALL_STATE(9438)] = 297359,
  [SMALL_STATE(9439)] = 297376,
  [SMALL_STATE(9440)] = 297391,
  [SMALL_STATE(9441)] = 297406,
  [SMALL_STATE(9442)] = 297421,
  [SMALL_STATE(9443)] = 297436,
  [SMALL_STATE(9444)] = 297453,
  [SMALL_STATE(9445)] = 297468,
  [SMALL_STATE(9446)] = 297483,
  [SMALL_STATE(9447)] = 297498,
  [SMALL_STATE(9448)] = 297513,
  [SMALL_STATE(9449)] = 297530,
  [SMALL_STATE(9450)] = 297547,
  [SMALL_STATE(9451)] = 297564,
  [SMALL_STATE(9452)] = 297581,
  [SMALL_STATE(9453)] = 297598,
  [SMALL_STATE(9454)] = 297617,
  [SMALL_STATE(9455)] = 297636,
  [SMALL_STATE(9456)] = 297653,
  [SMALL_STATE(9457)] = 297670,
  [SMALL_STATE(9458)] = 297687,
  [SMALL_STATE(9459)] = 297704,
  [SMALL_STATE(9460)] = 297721,
  [SMALL_STATE(9461)] = 297738,
  [SMALL_STATE(9462)] = 297755,
  [SMALL_STATE(9463)] = 297772,
  [SMALL_STATE(9464)] = 297789,
  [SMALL_STATE(9465)] = 297806,
  [SMALL_STATE(9466)] = 297823,
  [SMALL_STATE(9467)] = 297840,
  [SMALL_STATE(9468)] = 297857,
  [SMALL_STATE(9469)] = 297874,
  [SMALL_STATE(9470)] = 297893,
  [SMALL_STATE(9471)] = 297910,
  [SMALL_STATE(9472)] = 297929,
  [SMALL_STATE(9473)] = 297946,
  [SMALL_STATE(9474)] = 297963,
  [SMALL_STATE(9475)] = 297980,
  [SMALL_STATE(9476)] = 297997,
  [SMALL_STATE(9477)] = 298014,
  [SMALL_STATE(9478)] = 298031,
  [SMALL_STATE(9479)] = 298048,
  [SMALL_STATE(9480)] = 298065,
  [SMALL_STATE(9481)] = 298082,
  [SMALL_STATE(9482)] = 298099,
  [SMALL_STATE(9483)] = 298116,
  [SMALL_STATE(9484)] = 298133,
  [SMALL_STATE(9485)] = 298150,
  [SMALL_STATE(9486)] = 298167,
  [SMALL_STATE(9487)] = 298184,
  [SMALL_STATE(9488)] = 298201,
  [SMALL_STATE(9489)] = 298218,
  [SMALL_STATE(9490)] = 298237,
  [SMALL_STATE(9491)] = 298254,
  [SMALL_STATE(9492)] = 298273,
  [SMALL_STATE(9493)] = 298290,
  [SMALL_STATE(9494)] = 298307,
  [SMALL_STATE(9495)] = 298324,
  [SMALL_STATE(9496)] = 298341,
  [SMALL_STATE(9497)] = 298360,
  [SMALL_STATE(9498)] = 298379,
  [SMALL_STATE(9499)] = 298398,
  [SMALL_STATE(9500)] = 298417,
  [SMALL_STATE(9501)] = 298434,
  [SMALL_STATE(9502)] = 298451,
  [SMALL_STATE(9503)] = 298468,
  [SMALL_STATE(9504)] = 298485,
  [SMALL_STATE(9505)] = 298502,
  [SMALL_STATE(9506)] = 298519,
  [SMALL_STATE(9507)] = 298536,
  [SMALL_STATE(9508)] = 298553,
  [SMALL_STATE(9509)] = 298570,
  [SMALL_STATE(9510)] = 298587,
  [SMALL_STATE(9511)] = 298604,
  [SMALL_STATE(9512)] = 298621,
  [SMALL_STATE(9513)] = 298638,
  [SMALL_STATE(9514)] = 298655,
  [SMALL_STATE(9515)] = 298672,
  [SMALL_STATE(9516)] = 298689,
  [SMALL_STATE(9517)] = 298706,
  [SMALL_STATE(9518)] = 298725,
  [SMALL_STATE(9519)] = 298742,
  [SMALL_STATE(9520)] = 298759,
  [SMALL_STATE(9521)] = 298776,
  [SMALL_STATE(9522)] = 298793,
  [SMALL_STATE(9523)] = 298810,
  [SMALL_STATE(9524)] = 298827,
  [SMALL_STATE(9525)] = 298844,
  [SMALL_STATE(9526)] = 298861,
  [SMALL_STATE(9527)] = 298878,
  [SMALL_STATE(9528)] = 298895,
  [SMALL_STATE(9529)] = 298912,
  [SMALL_STATE(9530)] = 298931,
  [SMALL_STATE(9531)] = 298948,
  [SMALL_STATE(9532)] = 298965,
  [SMALL_STATE(9533)] = 298982,
  [SMALL_STATE(9534)] = 298999,
  [SMALL_STATE(9535)] = 299016,
  [SMALL_STATE(9536)] = 299033,
  [SMALL_STATE(9537)] = 299050,
  [SMALL_STATE(9538)] = 299067,
  [SMALL_STATE(9539)] = 299084,
  [SMALL_STATE(9540)] = 299103,
  [SMALL_STATE(9541)] = 299120,
  [SMALL_STATE(9542)] = 299137,
  [SMALL_STATE(9543)] = 299154,
  [SMALL_STATE(9544)] = 299171,
  [SMALL_STATE(9545)] = 299188,
  [SMALL_STATE(9546)] = 299205,
  [SMALL_STATE(9547)] = 299222,
  [SMALL_STATE(9548)] = 299239,
  [SMALL_STATE(9549)] = 299256,
  [SMALL_STATE(9550)] = 299273,
  [SMALL_STATE(9551)] = 299290,
  [SMALL_STATE(9552)] = 299307,
  [SMALL_STATE(9553)] = 299324,
  [SMALL_STATE(9554)] = 299341,
  [SMALL_STATE(9555)] = 299358,
  [SMALL_STATE(9556)] = 299375,
  [SMALL_STATE(9557)] = 299392,
  [SMALL_STATE(9558)] = 299409,
  [SMALL_STATE(9559)] = 299426,
  [SMALL_STATE(9560)] = 299443,
  [SMALL_STATE(9561)] = 299460,
  [SMALL_STATE(9562)] = 299477,
  [SMALL_STATE(9563)] = 299494,
  [SMALL_STATE(9564)] = 299511,
  [SMALL_STATE(9565)] = 299528,
  [SMALL_STATE(9566)] = 299545,
  [SMALL_STATE(9567)] = 299562,
  [SMALL_STATE(9568)] = 299579,
  [SMALL_STATE(9569)] = 299596,
  [SMALL_STATE(9570)] = 299613,
  [SMALL_STATE(9571)] = 299630,
  [SMALL_STATE(9572)] = 299647,
  [SMALL_STATE(9573)] = 299664,
  [SMALL_STATE(9574)] = 299683,
  [SMALL_STATE(9575)] = 299702,
  [SMALL_STATE(9576)] = 299719,
  [SMALL_STATE(9577)] = 299736,
  [SMALL_STATE(9578)] = 299753,
  [SMALL_STATE(9579)] = 299770,
  [SMALL_STATE(9580)] = 299787,
  [SMALL_STATE(9581)] = 299804,
  [SMALL_STATE(9582)] = 299821,
  [SMALL_STATE(9583)] = 299840,
  [SMALL_STATE(9584)] = 299857,
  [SMALL_STATE(9585)] = 299874,
  [SMALL_STATE(9586)] = 299891,
  [SMALL_STATE(9587)] = 299908,
  [SMALL_STATE(9588)] = 299925,
  [SMALL_STATE(9589)] = 299942,
  [SMALL_STATE(9590)] = 299959,
  [SMALL_STATE(9591)] = 299976,
  [SMALL_STATE(9592)] = 299993,
  [SMALL_STATE(9593)] = 300010,
  [SMALL_STATE(9594)] = 300027,
  [SMALL_STATE(9595)] = 300044,
  [SMALL_STATE(9596)] = 300061,
  [SMALL_STATE(9597)] = 300078,
  [SMALL_STATE(9598)] = 300095,
  [SMALL_STATE(9599)] = 300112,
  [SMALL_STATE(9600)] = 300129,
  [SMALL_STATE(9601)] = 300146,
  [SMALL_STATE(9602)] = 300163,
  [SMALL_STATE(9603)] = 300180,
  [SMALL_STATE(9604)] = 300197,
  [SMALL_STATE(9605)] = 300214,
  [SMALL_STATE(9606)] = 300231,
  [SMALL_STATE(9607)] = 300248,
  [SMALL_STATE(9608)] = 300265,
  [SMALL_STATE(9609)] = 300282,
  [SMALL_STATE(9610)] = 300299,
  [SMALL_STATE(9611)] = 300316,
  [SMALL_STATE(9612)] = 300333,
  [SMALL_STATE(9613)] = 300350,
  [SMALL_STATE(9614)] = 300367,
  [SMALL_STATE(9615)] = 300384,
  [SMALL_STATE(9616)] = 300401,
  [SMALL_STATE(9617)] = 300422,
  [SMALL_STATE(9618)] = 300439,
  [SMALL_STATE(9619)] = 300456,
  [SMALL_STATE(9620)] = 300477,
  [SMALL_STATE(9621)] = 300498,
  [SMALL_STATE(9622)] = 300519,
  [SMALL_STATE(9623)] = 300536,
  [SMALL_STATE(9624)] = 300557,
  [SMALL_STATE(9625)] = 300578,
  [SMALL_STATE(9626)] = 300599,
  [SMALL_STATE(9627)] = 300616,
  [SMALL_STATE(9628)] = 300633,
  [SMALL_STATE(9629)] = 300650,
  [SMALL_STATE(9630)] = 300671,
  [SMALL_STATE(9631)] = 300688,
  [SMALL_STATE(9632)] = 300705,
  [SMALL_STATE(9633)] = 300724,
  [SMALL_STATE(9634)] = 300743,
  [SMALL_STATE(9635)] = 300760,
  [SMALL_STATE(9636)] = 300777,
  [SMALL_STATE(9637)] = 300794,
  [SMALL_STATE(9638)] = 300811,
  [SMALL_STATE(9639)] = 300830,
  [SMALL_STATE(9640)] = 300849,
  [SMALL_STATE(9641)] = 300866,
  [SMALL_STATE(9642)] = 300885,
  [SMALL_STATE(9643)] = 300906,
  [SMALL_STATE(9644)] = 300927,
  [SMALL_STATE(9645)] = 300948,
  [SMALL_STATE(9646)] = 300969,
  [SMALL_STATE(9647)] = 300990,
  [SMALL_STATE(9648)] = 301011,
  [SMALL_STATE(9649)] = 301032,
  [SMALL_STATE(9650)] = 301049,
  [SMALL_STATE(9651)] = 301070,
  [SMALL_STATE(9652)] = 301087,
  [SMALL_STATE(9653)] = 301104,
  [SMALL_STATE(9654)] = 301125,
  [SMALL_STATE(9655)] = 301146,
  [SMALL_STATE(9656)] = 301167,
  [SMALL_STATE(9657)] = 301188,
  [SMALL_STATE(9658)] = 301205,
  [SMALL_STATE(9659)] = 301226,
  [SMALL_STATE(9660)] = 301247,
  [SMALL_STATE(9661)] = 301268,
  [SMALL_STATE(9662)] = 301289,
  [SMALL_STATE(9663)] = 301306,
  [SMALL_STATE(9664)] = 301323,
  [SMALL_STATE(9665)] = 301344,
  [SMALL_STATE(9666)] = 301365,
  [SMALL_STATE(9667)] = 301386,
  [SMALL_STATE(9668)] = 301407,
  [SMALL_STATE(9669)] = 301428,
  [SMALL_STATE(9670)] = 301449,
  [SMALL_STATE(9671)] = 301470,
  [SMALL_STATE(9672)] = 301491,
  [SMALL_STATE(9673)] = 301508,
  [SMALL_STATE(9674)] = 301525,
  [SMALL_STATE(9675)] = 301542,
  [SMALL_STATE(9676)] = 301559,
  [SMALL_STATE(9677)] = 301576,
  [SMALL_STATE(9678)] = 301593,
  [SMALL_STATE(9679)] = 301610,
  [SMALL_STATE(9680)] = 301627,
  [SMALL_STATE(9681)] = 301644,
  [SMALL_STATE(9682)] = 301661,
  [SMALL_STATE(9683)] = 301678,
  [SMALL_STATE(9684)] = 301695,
  [SMALL_STATE(9685)] = 301712,
  [SMALL_STATE(9686)] = 301729,
  [SMALL_STATE(9687)] = 301748,
  [SMALL_STATE(9688)] = 301765,
  [SMALL_STATE(9689)] = 301782,
  [SMALL_STATE(9690)] = 301799,
  [SMALL_STATE(9691)] = 301816,
  [SMALL_STATE(9692)] = 301833,
  [SMALL_STATE(9693)] = 301850,
  [SMALL_STATE(9694)] = 301867,
  [SMALL_STATE(9695)] = 301886,
  [SMALL_STATE(9696)] = 301903,
  [SMALL_STATE(9697)] = 301922,
  [SMALL_STATE(9698)] = 301939,
  [SMALL_STATE(9699)] = 301956,
  [SMALL_STATE(9700)] = 301977,
  [SMALL_STATE(9701)] = 301994,
  [SMALL_STATE(9702)] = 302011,
  [SMALL_STATE(9703)] = 302028,
  [SMALL_STATE(9704)] = 302045,
  [SMALL_STATE(9705)] = 302062,
  [SMALL_STATE(9706)] = 302079,
  [SMALL_STATE(9707)] = 302096,
  [SMALL_STATE(9708)] = 302113,
  [SMALL_STATE(9709)] = 302130,
  [SMALL_STATE(9710)] = 302149,
  [SMALL_STATE(9711)] = 302168,
  [SMALL_STATE(9712)] = 302187,
  [SMALL_STATE(9713)] = 302204,
  [SMALL_STATE(9714)] = 302221,
  [SMALL_STATE(9715)] = 302238,
  [SMALL_STATE(9716)] = 302257,
  [SMALL_STATE(9717)] = 302274,
  [SMALL_STATE(9718)] = 302291,
  [SMALL_STATE(9719)] = 302308,
  [SMALL_STATE(9720)] = 302325,
  [SMALL_STATE(9721)] = 302342,
  [SMALL_STATE(9722)] = 302359,
  [SMALL_STATE(9723)] = 302376,
  [SMALL_STATE(9724)] = 302393,
  [SMALL_STATE(9725)] = 302410,
  [SMALL_STATE(9726)] = 302427,
  [SMALL_STATE(9727)] = 302444,
  [SMALL_STATE(9728)] = 302461,
  [SMALL_STATE(9729)] = 302478,
  [SMALL_STATE(9730)] = 302495,
  [SMALL_STATE(9731)] = 302512,
  [SMALL_STATE(9732)] = 302529,
  [SMALL_STATE(9733)] = 302546,
  [SMALL_STATE(9734)] = 302563,
  [SMALL_STATE(9735)] = 302580,
  [SMALL_STATE(9736)] = 302597,
  [SMALL_STATE(9737)] = 302614,
  [SMALL_STATE(9738)] = 302631,
  [SMALL_STATE(9739)] = 302648,
  [SMALL_STATE(9740)] = 302665,
  [SMALL_STATE(9741)] = 302682,
  [SMALL_STATE(9742)] = 302699,
  [SMALL_STATE(9743)] = 302716,
  [SMALL_STATE(9744)] = 302735,
  [SMALL_STATE(9745)] = 302754,
  [SMALL_STATE(9746)] = 302771,
  [SMALL_STATE(9747)] = 302788,
  [SMALL_STATE(9748)] = 302807,
  [SMALL_STATE(9749)] = 302824,
  [SMALL_STATE(9750)] = 302841,
  [SMALL_STATE(9751)] = 302858,
  [SMALL_STATE(9752)] = 302875,
  [SMALL_STATE(9753)] = 302892,
  [SMALL_STATE(9754)] = 302909,
  [SMALL_STATE(9755)] = 302926,
  [SMALL_STATE(9756)] = 302943,
  [SMALL_STATE(9757)] = 302960,
  [SMALL_STATE(9758)] = 302977,
  [SMALL_STATE(9759)] = 302994,
  [SMALL_STATE(9760)] = 303011,
  [SMALL_STATE(9761)] = 303028,
  [SMALL_STATE(9762)] = 303045,
  [SMALL_STATE(9763)] = 303062,
  [SMALL_STATE(9764)] = 303079,
  [SMALL_STATE(9765)] = 303096,
  [SMALL_STATE(9766)] = 303113,
  [SMALL_STATE(9767)] = 303130,
  [SMALL_STATE(9768)] = 303147,
  [SMALL_STATE(9769)] = 303164,
  [SMALL_STATE(9770)] = 303185,
  [SMALL_STATE(9771)] = 303204,
  [SMALL_STATE(9772)] = 303225,
  [SMALL_STATE(9773)] = 303242,
  [SMALL_STATE(9774)] = 303259,
  [SMALL_STATE(9775)] = 303276,
  [SMALL_STATE(9776)] = 303293,
  [SMALL_STATE(9777)] = 303310,
  [SMALL_STATE(9778)] = 303329,
  [SMALL_STATE(9779)] = 303346,
  [SMALL_STATE(9780)] = 303363,
  [SMALL_STATE(9781)] = 303380,
  [SMALL_STATE(9782)] = 303397,
  [SMALL_STATE(9783)] = 303414,
  [SMALL_STATE(9784)] = 303431,
  [SMALL_STATE(9785)] = 303448,
  [SMALL_STATE(9786)] = 303465,
  [SMALL_STATE(9787)] = 303482,
  [SMALL_STATE(9788)] = 303499,
  [SMALL_STATE(9789)] = 303516,
  [SMALL_STATE(9790)] = 303533,
  [SMALL_STATE(9791)] = 303550,
  [SMALL_STATE(9792)] = 303567,
  [SMALL_STATE(9793)] = 303584,
  [SMALL_STATE(9794)] = 303601,
  [SMALL_STATE(9795)] = 303618,
  [SMALL_STATE(9796)] = 303635,
  [SMALL_STATE(9797)] = 303652,
  [SMALL_STATE(9798)] = 303669,
  [SMALL_STATE(9799)] = 303686,
  [SMALL_STATE(9800)] = 303703,
  [SMALL_STATE(9801)] = 303718,
  [SMALL_STATE(9802)] = 303735,
  [SMALL_STATE(9803)] = 303752,
  [SMALL_STATE(9804)] = 303769,
  [SMALL_STATE(9805)] = 303786,
  [SMALL_STATE(9806)] = 303803,
  [SMALL_STATE(9807)] = 303820,
  [SMALL_STATE(9808)] = 303837,
  [SMALL_STATE(9809)] = 303856,
  [SMALL_STATE(9810)] = 303873,
  [SMALL_STATE(9811)] = 303890,
  [SMALL_STATE(9812)] = 303907,
  [SMALL_STATE(9813)] = 303924,
  [SMALL_STATE(9814)] = 303941,
  [SMALL_STATE(9815)] = 303958,
  [SMALL_STATE(9816)] = 303975,
  [SMALL_STATE(9817)] = 303992,
  [SMALL_STATE(9818)] = 304009,
  [SMALL_STATE(9819)] = 304026,
  [SMALL_STATE(9820)] = 304043,
  [SMALL_STATE(9821)] = 304060,
  [SMALL_STATE(9822)] = 304077,
  [SMALL_STATE(9823)] = 304094,
  [SMALL_STATE(9824)] = 304111,
  [SMALL_STATE(9825)] = 304128,
  [SMALL_STATE(9826)] = 304145,
  [SMALL_STATE(9827)] = 304162,
  [SMALL_STATE(9828)] = 304179,
  [SMALL_STATE(9829)] = 304196,
  [SMALL_STATE(9830)] = 304213,
  [SMALL_STATE(9831)] = 304230,
  [SMALL_STATE(9832)] = 304247,
  [SMALL_STATE(9833)] = 304268,
  [SMALL_STATE(9834)] = 304285,
  [SMALL_STATE(9835)] = 304302,
  [SMALL_STATE(9836)] = 304319,
  [SMALL_STATE(9837)] = 304338,
  [SMALL_STATE(9838)] = 304357,
  [SMALL_STATE(9839)] = 304374,
  [SMALL_STATE(9840)] = 304391,
  [SMALL_STATE(9841)] = 304412,
  [SMALL_STATE(9842)] = 304429,
  [SMALL_STATE(9843)] = 304446,
  [SMALL_STATE(9844)] = 304463,
  [SMALL_STATE(9845)] = 304480,
  [SMALL_STATE(9846)] = 304497,
  [SMALL_STATE(9847)] = 304514,
  [SMALL_STATE(9848)] = 304531,
  [SMALL_STATE(9849)] = 304548,
  [SMALL_STATE(9850)] = 304565,
  [SMALL_STATE(9851)] = 304582,
  [SMALL_STATE(9852)] = 304599,
  [SMALL_STATE(9853)] = 304616,
  [SMALL_STATE(9854)] = 304633,
  [SMALL_STATE(9855)] = 304650,
  [SMALL_STATE(9856)] = 304667,
  [SMALL_STATE(9857)] = 304684,
  [SMALL_STATE(9858)] = 304701,
  [SMALL_STATE(9859)] = 304718,
  [SMALL_STATE(9860)] = 304735,
  [SMALL_STATE(9861)] = 304752,
  [SMALL_STATE(9862)] = 304769,
  [SMALL_STATE(9863)] = 304786,
  [SMALL_STATE(9864)] = 304803,
  [SMALL_STATE(9865)] = 304820,
  [SMALL_STATE(9866)] = 304837,
  [SMALL_STATE(9867)] = 304854,
  [SMALL_STATE(9868)] = 304875,
  [SMALL_STATE(9869)] = 304892,
  [SMALL_STATE(9870)] = 304909,
  [SMALL_STATE(9871)] = 304926,
  [SMALL_STATE(9872)] = 304943,
  [SMALL_STATE(9873)] = 304960,
  [SMALL_STATE(9874)] = 304979,
  [SMALL_STATE(9875)] = 304996,
  [SMALL_STATE(9876)] = 305013,
  [SMALL_STATE(9877)] = 305030,
  [SMALL_STATE(9878)] = 305047,
  [SMALL_STATE(9879)] = 305066,
  [SMALL_STATE(9880)] = 305083,
  [SMALL_STATE(9881)] = 305100,
  [SMALL_STATE(9882)] = 305117,
  [SMALL_STATE(9883)] = 305134,
  [SMALL_STATE(9884)] = 305151,
  [SMALL_STATE(9885)] = 305168,
  [SMALL_STATE(9886)] = 305185,
  [SMALL_STATE(9887)] = 305206,
  [SMALL_STATE(9888)] = 305223,
  [SMALL_STATE(9889)] = 305240,
  [SMALL_STATE(9890)] = 305257,
  [SMALL_STATE(9891)] = 305274,
  [SMALL_STATE(9892)] = 305291,
  [SMALL_STATE(9893)] = 305312,
  [SMALL_STATE(9894)] = 305329,
  [SMALL_STATE(9895)] = 305346,
  [SMALL_STATE(9896)] = 305363,
  [SMALL_STATE(9897)] = 305380,
  [SMALL_STATE(9898)] = 305397,
  [SMALL_STATE(9899)] = 305416,
  [SMALL_STATE(9900)] = 305433,
  [SMALL_STATE(9901)] = 305454,
  [SMALL_STATE(9902)] = 305471,
  [SMALL_STATE(9903)] = 305488,
  [SMALL_STATE(9904)] = 305505,
  [SMALL_STATE(9905)] = 305522,
  [SMALL_STATE(9906)] = 305539,
  [SMALL_STATE(9907)] = 305558,
  [SMALL_STATE(9908)] = 305575,
  [SMALL_STATE(9909)] = 305594,
  [SMALL_STATE(9910)] = 305613,
  [SMALL_STATE(9911)] = 305630,
  [SMALL_STATE(9912)] = 305647,
  [SMALL_STATE(9913)] = 305664,
  [SMALL_STATE(9914)] = 305683,
  [SMALL_STATE(9915)] = 305700,
  [SMALL_STATE(9916)] = 305719,
  [SMALL_STATE(9917)] = 305736,
  [SMALL_STATE(9918)] = 305755,
  [SMALL_STATE(9919)] = 305774,
  [SMALL_STATE(9920)] = 305793,
  [SMALL_STATE(9921)] = 305812,
  [SMALL_STATE(9922)] = 305831,
  [SMALL_STATE(9923)] = 305850,
  [SMALL_STATE(9924)] = 305869,
  [SMALL_STATE(9925)] = 305888,
  [SMALL_STATE(9926)] = 305907,
  [SMALL_STATE(9927)] = 305926,
  [SMALL_STATE(9928)] = 305945,
  [SMALL_STATE(9929)] = 305964,
  [SMALL_STATE(9930)] = 305983,
  [SMALL_STATE(9931)] = 306002,
  [SMALL_STATE(9932)] = 306019,
  [SMALL_STATE(9933)] = 306036,
  [SMALL_STATE(9934)] = 306053,
  [SMALL_STATE(9935)] = 306070,
  [SMALL_STATE(9936)] = 306087,
  [SMALL_STATE(9937)] = 306104,
  [SMALL_STATE(9938)] = 306121,
  [SMALL_STATE(9939)] = 306140,
  [SMALL_STATE(9940)] = 306159,
  [SMALL_STATE(9941)] = 306175,
  [SMALL_STATE(9942)] = 306191,
  [SMALL_STATE(9943)] = 306207,
  [SMALL_STATE(9944)] = 306221,
  [SMALL_STATE(9945)] = 306237,
  [SMALL_STATE(9946)] = 306251,
  [SMALL_STATE(9947)] = 306267,
  [SMALL_STATE(9948)] = 306283,
  [SMALL_STATE(9949)] = 306299,
  [SMALL_STATE(9950)] = 306313,
  [SMALL_STATE(9951)] = 306327,
  [SMALL_STATE(9952)] = 306343,
  [SMALL_STATE(9953)] = 306359,
  [SMALL_STATE(9954)] = 306373,
  [SMALL_STATE(9955)] = 306387,
  [SMALL_STATE(9956)] = 306403,
  [SMALL_STATE(9957)] = 306419,
  [SMALL_STATE(9958)] = 306435,
  [SMALL_STATE(9959)] = 306449,
  [SMALL_STATE(9960)] = 306465,
  [SMALL_STATE(9961)] = 306481,
  [SMALL_STATE(9962)] = 306499,
  [SMALL_STATE(9963)] = 306515,
  [SMALL_STATE(9964)] = 306531,
  [SMALL_STATE(9965)] = 306547,
  [SMALL_STATE(9966)] = 306563,
  [SMALL_STATE(9967)] = 306581,
  [SMALL_STATE(9968)] = 306595,
  [SMALL_STATE(9969)] = 306611,
  [SMALL_STATE(9970)] = 306625,
  [SMALL_STATE(9971)] = 306641,
  [SMALL_STATE(9972)] = 306655,
  [SMALL_STATE(9973)] = 306669,
  [SMALL_STATE(9974)] = 306683,
  [SMALL_STATE(9975)] = 306697,
  [SMALL_STATE(9976)] = 306711,
  [SMALL_STATE(9977)] = 306727,
  [SMALL_STATE(9978)] = 306741,
  [SMALL_STATE(9979)] = 306755,
  [SMALL_STATE(9980)] = 306769,
  [SMALL_STATE(9981)] = 306783,
  [SMALL_STATE(9982)] = 306797,
  [SMALL_STATE(9983)] = 306811,
  [SMALL_STATE(9984)] = 306825,
  [SMALL_STATE(9985)] = 306839,
  [SMALL_STATE(9986)] = 306855,
  [SMALL_STATE(9987)] = 306869,
  [SMALL_STATE(9988)] = 306883,
  [SMALL_STATE(9989)] = 306897,
  [SMALL_STATE(9990)] = 306915,
  [SMALL_STATE(9991)] = 306929,
  [SMALL_STATE(9992)] = 306947,
  [SMALL_STATE(9993)] = 306961,
  [SMALL_STATE(9994)] = 306977,
  [SMALL_STATE(9995)] = 306991,
  [SMALL_STATE(9996)] = 307005,
  [SMALL_STATE(9997)] = 307023,
  [SMALL_STATE(9998)] = 307039,
  [SMALL_STATE(9999)] = 307053,
  [SMALL_STATE(10000)] = 307067,
  [SMALL_STATE(10001)] = 307081,
  [SMALL_STATE(10002)] = 307095,
  [SMALL_STATE(10003)] = 307111,
  [SMALL_STATE(10004)] = 307125,
  [SMALL_STATE(10005)] = 307139,
  [SMALL_STATE(10006)] = 307153,
  [SMALL_STATE(10007)] = 307169,
  [SMALL_STATE(10008)] = 307183,
  [SMALL_STATE(10009)] = 307199,
  [SMALL_STATE(10010)] = 307215,
  [SMALL_STATE(10011)] = 307231,
  [SMALL_STATE(10012)] = 307245,
  [SMALL_STATE(10013)] = 307261,
  [SMALL_STATE(10014)] = 307277,
  [SMALL_STATE(10015)] = 307293,
  [SMALL_STATE(10016)] = 307309,
  [SMALL_STATE(10017)] = 307325,
  [SMALL_STATE(10018)] = 307343,
  [SMALL_STATE(10019)] = 307359,
  [SMALL_STATE(10020)] = 307373,
  [SMALL_STATE(10021)] = 307387,
  [SMALL_STATE(10022)] = 307403,
  [SMALL_STATE(10023)] = 307419,
  [SMALL_STATE(10024)] = 307435,
  [SMALL_STATE(10025)] = 307451,
  [SMALL_STATE(10026)] = 307467,
  [SMALL_STATE(10027)] = 307485,
  [SMALL_STATE(10028)] = 307499,
  [SMALL_STATE(10029)] = 307515,
  [SMALL_STATE(10030)] = 307529,
  [SMALL_STATE(10031)] = 307543,
  [SMALL_STATE(10032)] = 307557,
  [SMALL_STATE(10033)] = 307571,
  [SMALL_STATE(10034)] = 307587,
  [SMALL_STATE(10035)] = 307603,
  [SMALL_STATE(10036)] = 307617,
  [SMALL_STATE(10037)] = 307633,
  [SMALL_STATE(10038)] = 307649,
  [SMALL_STATE(10039)] = 307665,
  [SMALL_STATE(10040)] = 307681,
  [SMALL_STATE(10041)] = 307697,
  [SMALL_STATE(10042)] = 307713,
  [SMALL_STATE(10043)] = 307729,
  [SMALL_STATE(10044)] = 307745,
  [SMALL_STATE(10045)] = 307759,
  [SMALL_STATE(10046)] = 307773,
  [SMALL_STATE(10047)] = 307787,
  [SMALL_STATE(10048)] = 307801,
  [SMALL_STATE(10049)] = 307817,
  [SMALL_STATE(10050)] = 307833,
  [SMALL_STATE(10051)] = 307849,
  [SMALL_STATE(10052)] = 307865,
  [SMALL_STATE(10053)] = 307883,
  [SMALL_STATE(10054)] = 307897,
  [SMALL_STATE(10055)] = 307913,
  [SMALL_STATE(10056)] = 307929,
  [SMALL_STATE(10057)] = 307947,
  [SMALL_STATE(10058)] = 307961,
  [SMALL_STATE(10059)] = 307975,
  [SMALL_STATE(10060)] = 307989,
  [SMALL_STATE(10061)] = 308003,
  [SMALL_STATE(10062)] = 308021,
  [SMALL_STATE(10063)] = 308035,
  [SMALL_STATE(10064)] = 308049,
  [SMALL_STATE(10065)] = 308063,
  [SMALL_STATE(10066)] = 308077,
  [SMALL_STATE(10067)] = 308091,
  [SMALL_STATE(10068)] = 308109,
  [SMALL_STATE(10069)] = 308123,
  [SMALL_STATE(10070)] = 308137,
  [SMALL_STATE(10071)] = 308151,
  [SMALL_STATE(10072)] = 308165,
  [SMALL_STATE(10073)] = 308181,
  [SMALL_STATE(10074)] = 308195,
  [SMALL_STATE(10075)] = 308209,
  [SMALL_STATE(10076)] = 308225,
  [SMALL_STATE(10077)] = 308239,
  [SMALL_STATE(10078)] = 308253,
  [SMALL_STATE(10079)] = 308267,
  [SMALL_STATE(10080)] = 308283,
  [SMALL_STATE(10081)] = 308299,
  [SMALL_STATE(10082)] = 308315,
  [SMALL_STATE(10083)] = 308331,
  [SMALL_STATE(10084)] = 308347,
  [SMALL_STATE(10085)] = 308363,
  [SMALL_STATE(10086)] = 308379,
  [SMALL_STATE(10087)] = 308395,
  [SMALL_STATE(10088)] = 308411,
  [SMALL_STATE(10089)] = 308425,
  [SMALL_STATE(10090)] = 308439,
  [SMALL_STATE(10091)] = 308455,
  [SMALL_STATE(10092)] = 308471,
  [SMALL_STATE(10093)] = 308489,
  [SMALL_STATE(10094)] = 308503,
  [SMALL_STATE(10095)] = 308517,
  [SMALL_STATE(10096)] = 308531,
  [SMALL_STATE(10097)] = 308545,
  [SMALL_STATE(10098)] = 308559,
  [SMALL_STATE(10099)] = 308575,
  [SMALL_STATE(10100)] = 308589,
  [SMALL_STATE(10101)] = 308605,
  [SMALL_STATE(10102)] = 308621,
  [SMALL_STATE(10103)] = 308635,
  [SMALL_STATE(10104)] = 308651,
  [SMALL_STATE(10105)] = 308667,
  [SMALL_STATE(10106)] = 308683,
  [SMALL_STATE(10107)] = 308699,
  [SMALL_STATE(10108)] = 308715,
  [SMALL_STATE(10109)] = 308731,
  [SMALL_STATE(10110)] = 308747,
  [SMALL_STATE(10111)] = 308763,
  [SMALL_STATE(10112)] = 308779,
  [SMALL_STATE(10113)] = 308793,
  [SMALL_STATE(10114)] = 308807,
  [SMALL_STATE(10115)] = 308821,
  [SMALL_STATE(10116)] = 308835,
  [SMALL_STATE(10117)] = 308849,
  [SMALL_STATE(10118)] = 308865,
  [SMALL_STATE(10119)] = 308881,
  [SMALL_STATE(10120)] = 308897,
  [SMALL_STATE(10121)] = 308913,
  [SMALL_STATE(10122)] = 308933,
  [SMALL_STATE(10123)] = 308949,
  [SMALL_STATE(10124)] = 308963,
  [SMALL_STATE(10125)] = 308979,
  [SMALL_STATE(10126)] = 308995,
  [SMALL_STATE(10127)] = 309011,
  [SMALL_STATE(10128)] = 309027,
  [SMALL_STATE(10129)] = 309041,
  [SMALL_STATE(10130)] = 309057,
  [SMALL_STATE(10131)] = 309073,
  [SMALL_STATE(10132)] = 309089,
  [SMALL_STATE(10133)] = 309105,
  [SMALL_STATE(10134)] = 309119,
  [SMALL_STATE(10135)] = 309135,
  [SMALL_STATE(10136)] = 309151,
  [SMALL_STATE(10137)] = 309167,
  [SMALL_STATE(10138)] = 309183,
  [SMALL_STATE(10139)] = 309199,
  [SMALL_STATE(10140)] = 309215,
  [SMALL_STATE(10141)] = 309231,
  [SMALL_STATE(10142)] = 309247,
  [SMALL_STATE(10143)] = 309263,
  [SMALL_STATE(10144)] = 309279,
  [SMALL_STATE(10145)] = 309295,
  [SMALL_STATE(10146)] = 309311,
  [SMALL_STATE(10147)] = 309327,
  [SMALL_STATE(10148)] = 309343,
  [SMALL_STATE(10149)] = 309359,
  [SMALL_STATE(10150)] = 309375,
  [SMALL_STATE(10151)] = 309391,
  [SMALL_STATE(10152)] = 309407,
  [SMALL_STATE(10153)] = 309423,
  [SMALL_STATE(10154)] = 309439,
  [SMALL_STATE(10155)] = 309455,
  [SMALL_STATE(10156)] = 309471,
  [SMALL_STATE(10157)] = 309487,
  [SMALL_STATE(10158)] = 309503,
  [SMALL_STATE(10159)] = 309519,
  [SMALL_STATE(10160)] = 309535,
  [SMALL_STATE(10161)] = 309551,
  [SMALL_STATE(10162)] = 309567,
  [SMALL_STATE(10163)] = 309583,
  [SMALL_STATE(10164)] = 309599,
  [SMALL_STATE(10165)] = 309615,
  [SMALL_STATE(10166)] = 309631,
  [SMALL_STATE(10167)] = 309647,
  [SMALL_STATE(10168)] = 309663,
  [SMALL_STATE(10169)] = 309677,
  [SMALL_STATE(10170)] = 309693,
  [SMALL_STATE(10171)] = 309709,
  [SMALL_STATE(10172)] = 309723,
  [SMALL_STATE(10173)] = 309739,
  [SMALL_STATE(10174)] = 309755,
  [SMALL_STATE(10175)] = 309771,
  [SMALL_STATE(10176)] = 309787,
  [SMALL_STATE(10177)] = 309803,
  [SMALL_STATE(10178)] = 309819,
  [SMALL_STATE(10179)] = 309833,
  [SMALL_STATE(10180)] = 309847,
  [SMALL_STATE(10181)] = 309861,
  [SMALL_STATE(10182)] = 309875,
  [SMALL_STATE(10183)] = 309889,
  [SMALL_STATE(10184)] = 309903,
  [SMALL_STATE(10185)] = 309919,
  [SMALL_STATE(10186)] = 309935,
  [SMALL_STATE(10187)] = 309951,
  [SMALL_STATE(10188)] = 309967,
  [SMALL_STATE(10189)] = 309983,
  [SMALL_STATE(10190)] = 309997,
  [SMALL_STATE(10191)] = 310013,
  [SMALL_STATE(10192)] = 310027,
  [SMALL_STATE(10193)] = 310043,
  [SMALL_STATE(10194)] = 310057,
  [SMALL_STATE(10195)] = 310075,
  [SMALL_STATE(10196)] = 310089,
  [SMALL_STATE(10197)] = 310103,
  [SMALL_STATE(10198)] = 310121,
  [SMALL_STATE(10199)] = 310135,
  [SMALL_STATE(10200)] = 310149,
  [SMALL_STATE(10201)] = 310163,
  [SMALL_STATE(10202)] = 310177,
  [SMALL_STATE(10203)] = 310195,
  [SMALL_STATE(10204)] = 310209,
  [SMALL_STATE(10205)] = 310223,
  [SMALL_STATE(10206)] = 310237,
  [SMALL_STATE(10207)] = 310251,
  [SMALL_STATE(10208)] = 310265,
  [SMALL_STATE(10209)] = 310279,
  [SMALL_STATE(10210)] = 310293,
  [SMALL_STATE(10211)] = 310307,
  [SMALL_STATE(10212)] = 310323,
  [SMALL_STATE(10213)] = 310339,
  [SMALL_STATE(10214)] = 310355,
  [SMALL_STATE(10215)] = 310371,
  [SMALL_STATE(10216)] = 310389,
  [SMALL_STATE(10217)] = 310407,
  [SMALL_STATE(10218)] = 310425,
  [SMALL_STATE(10219)] = 310441,
  [SMALL_STATE(10220)] = 310457,
  [SMALL_STATE(10221)] = 310471,
  [SMALL_STATE(10222)] = 310485,
  [SMALL_STATE(10223)] = 310499,
  [SMALL_STATE(10224)] = 310513,
  [SMALL_STATE(10225)] = 310527,
  [SMALL_STATE(10226)] = 310541,
  [SMALL_STATE(10227)] = 310555,
  [SMALL_STATE(10228)] = 310571,
  [SMALL_STATE(10229)] = 310589,
  [SMALL_STATE(10230)] = 310603,
  [SMALL_STATE(10231)] = 310621,
  [SMALL_STATE(10232)] = 310639,
  [SMALL_STATE(10233)] = 310655,
  [SMALL_STATE(10234)] = 310669,
  [SMALL_STATE(10235)] = 310685,
  [SMALL_STATE(10236)] = 310699,
  [SMALL_STATE(10237)] = 310713,
  [SMALL_STATE(10238)] = 310727,
  [SMALL_STATE(10239)] = 310741,
  [SMALL_STATE(10240)] = 310759,
  [SMALL_STATE(10241)] = 310773,
  [SMALL_STATE(10242)] = 310787,
  [SMALL_STATE(10243)] = 310805,
  [SMALL_STATE(10244)] = 310819,
  [SMALL_STATE(10245)] = 310833,
  [SMALL_STATE(10246)] = 310851,
  [SMALL_STATE(10247)] = 310869,
  [SMALL_STATE(10248)] = 310887,
  [SMALL_STATE(10249)] = 310905,
  [SMALL_STATE(10250)] = 310925,
  [SMALL_STATE(10251)] = 310941,
  [SMALL_STATE(10252)] = 310959,
  [SMALL_STATE(10253)] = 310977,
  [SMALL_STATE(10254)] = 310995,
  [SMALL_STATE(10255)] = 311009,
  [SMALL_STATE(10256)] = 311023,
  [SMALL_STATE(10257)] = 311037,
  [SMALL_STATE(10258)] = 311051,
  [SMALL_STATE(10259)] = 311069,
  [SMALL_STATE(10260)] = 311083,
  [SMALL_STATE(10261)] = 311101,
  [SMALL_STATE(10262)] = 311119,
  [SMALL_STATE(10263)] = 311133,
  [SMALL_STATE(10264)] = 311147,
  [SMALL_STATE(10265)] = 311165,
  [SMALL_STATE(10266)] = 311183,
  [SMALL_STATE(10267)] = 311201,
  [SMALL_STATE(10268)] = 311217,
  [SMALL_STATE(10269)] = 311233,
  [SMALL_STATE(10270)] = 311251,
  [SMALL_STATE(10271)] = 311267,
  [SMALL_STATE(10272)] = 311283,
  [SMALL_STATE(10273)] = 311299,
  [SMALL_STATE(10274)] = 311315,
  [SMALL_STATE(10275)] = 311329,
  [SMALL_STATE(10276)] = 311345,
  [SMALL_STATE(10277)] = 311361,
  [SMALL_STATE(10278)] = 311377,
  [SMALL_STATE(10279)] = 311393,
  [SMALL_STATE(10280)] = 311409,
  [SMALL_STATE(10281)] = 311425,
  [SMALL_STATE(10282)] = 311443,
  [SMALL_STATE(10283)] = 311459,
  [SMALL_STATE(10284)] = 311475,
  [SMALL_STATE(10285)] = 311489,
  [SMALL_STATE(10286)] = 311507,
  [SMALL_STATE(10287)] = 311525,
  [SMALL_STATE(10288)] = 311543,
  [SMALL_STATE(10289)] = 311561,
  [SMALL_STATE(10290)] = 311577,
  [SMALL_STATE(10291)] = 311591,
  [SMALL_STATE(10292)] = 311607,
  [SMALL_STATE(10293)] = 311623,
  [SMALL_STATE(10294)] = 311639,
  [SMALL_STATE(10295)] = 311655,
  [SMALL_STATE(10296)] = 311673,
  [SMALL_STATE(10297)] = 311687,
  [SMALL_STATE(10298)] = 311705,
  [SMALL_STATE(10299)] = 311721,
  [SMALL_STATE(10300)] = 311735,
  [SMALL_STATE(10301)] = 311751,
  [SMALL_STATE(10302)] = 311767,
  [SMALL_STATE(10303)] = 311783,
  [SMALL_STATE(10304)] = 311799,
  [SMALL_STATE(10305)] = 311815,
  [SMALL_STATE(10306)] = 311831,
  [SMALL_STATE(10307)] = 311849,
  [SMALL_STATE(10308)] = 311865,
  [SMALL_STATE(10309)] = 311881,
  [SMALL_STATE(10310)] = 311897,
  [SMALL_STATE(10311)] = 311913,
  [SMALL_STATE(10312)] = 311929,
  [SMALL_STATE(10313)] = 311945,
  [SMALL_STATE(10314)] = 311963,
  [SMALL_STATE(10315)] = 311981,
  [SMALL_STATE(10316)] = 311997,
  [SMALL_STATE(10317)] = 312013,
  [SMALL_STATE(10318)] = 312029,
  [SMALL_STATE(10319)] = 312045,
  [SMALL_STATE(10320)] = 312061,
  [SMALL_STATE(10321)] = 312077,
  [SMALL_STATE(10322)] = 312093,
  [SMALL_STATE(10323)] = 312111,
  [SMALL_STATE(10324)] = 312127,
  [SMALL_STATE(10325)] = 312145,
  [SMALL_STATE(10326)] = 312161,
  [SMALL_STATE(10327)] = 312179,
  [SMALL_STATE(10328)] = 312195,
  [SMALL_STATE(10329)] = 312209,
  [SMALL_STATE(10330)] = 312225,
  [SMALL_STATE(10331)] = 312239,
  [SMALL_STATE(10332)] = 312255,
  [SMALL_STATE(10333)] = 312269,
  [SMALL_STATE(10334)] = 312285,
  [SMALL_STATE(10335)] = 312299,
  [SMALL_STATE(10336)] = 312315,
  [SMALL_STATE(10337)] = 312329,
  [SMALL_STATE(10338)] = 312345,
  [SMALL_STATE(10339)] = 312359,
  [SMALL_STATE(10340)] = 312375,
  [SMALL_STATE(10341)] = 312389,
  [SMALL_STATE(10342)] = 312405,
  [SMALL_STATE(10343)] = 312419,
  [SMALL_STATE(10344)] = 312435,
  [SMALL_STATE(10345)] = 312449,
  [SMALL_STATE(10346)] = 312465,
  [SMALL_STATE(10347)] = 312479,
  [SMALL_STATE(10348)] = 312493,
  [SMALL_STATE(10349)] = 312507,
  [SMALL_STATE(10350)] = 312521,
  [SMALL_STATE(10351)] = 312535,
  [SMALL_STATE(10352)] = 312549,
  [SMALL_STATE(10353)] = 312563,
  [SMALL_STATE(10354)] = 312581,
  [SMALL_STATE(10355)] = 312599,
  [SMALL_STATE(10356)] = 312615,
  [SMALL_STATE(10357)] = 312630,
  [SMALL_STATE(10358)] = 312645,
  [SMALL_STATE(10359)] = 312660,
  [SMALL_STATE(10360)] = 312675,
  [SMALL_STATE(10361)] = 312690,
  [SMALL_STATE(10362)] = 312707,
  [SMALL_STATE(10363)] = 312724,
  [SMALL_STATE(10364)] = 312739,
  [SMALL_STATE(10365)] = 312754,
  [SMALL_STATE(10366)] = 312769,
  [SMALL_STATE(10367)] = 312784,
  [SMALL_STATE(10368)] = 312799,
  [SMALL_STATE(10369)] = 312814,
  [SMALL_STATE(10370)] = 312829,
  [SMALL_STATE(10371)] = 312844,
  [SMALL_STATE(10372)] = 312859,
  [SMALL_STATE(10373)] = 312874,
  [SMALL_STATE(10374)] = 312889,
  [SMALL_STATE(10375)] = 312904,
  [SMALL_STATE(10376)] = 312919,
  [SMALL_STATE(10377)] = 312934,
  [SMALL_STATE(10378)] = 312951,
  [SMALL_STATE(10379)] = 312966,
  [SMALL_STATE(10380)] = 312981,
  [SMALL_STATE(10381)] = 312994,
  [SMALL_STATE(10382)] = 313009,
  [SMALL_STATE(10383)] = 313024,
  [SMALL_STATE(10384)] = 313039,
  [SMALL_STATE(10385)] = 313056,
  [SMALL_STATE(10386)] = 313071,
  [SMALL_STATE(10387)] = 313086,
  [SMALL_STATE(10388)] = 313101,
  [SMALL_STATE(10389)] = 313116,
  [SMALL_STATE(10390)] = 313131,
  [SMALL_STATE(10391)] = 313148,
  [SMALL_STATE(10392)] = 313163,
  [SMALL_STATE(10393)] = 313178,
  [SMALL_STATE(10394)] = 313193,
  [SMALL_STATE(10395)] = 313208,
  [SMALL_STATE(10396)] = 313223,
  [SMALL_STATE(10397)] = 313238,
  [SMALL_STATE(10398)] = 313253,
  [SMALL_STATE(10399)] = 313268,
  [SMALL_STATE(10400)] = 313283,
  [SMALL_STATE(10401)] = 313298,
  [SMALL_STATE(10402)] = 313313,
  [SMALL_STATE(10403)] = 313328,
  [SMALL_STATE(10404)] = 313343,
  [SMALL_STATE(10405)] = 313358,
  [SMALL_STATE(10406)] = 313373,
  [SMALL_STATE(10407)] = 313390,
  [SMALL_STATE(10408)] = 313405,
  [SMALL_STATE(10409)] = 313420,
  [SMALL_STATE(10410)] = 313435,
  [SMALL_STATE(10411)] = 313450,
  [SMALL_STATE(10412)] = 313467,
  [SMALL_STATE(10413)] = 313482,
  [SMALL_STATE(10414)] = 313497,
  [SMALL_STATE(10415)] = 313512,
  [SMALL_STATE(10416)] = 313527,
  [SMALL_STATE(10417)] = 313542,
  [SMALL_STATE(10418)] = 313557,
  [SMALL_STATE(10419)] = 313574,
  [SMALL_STATE(10420)] = 313589,
  [SMALL_STATE(10421)] = 313604,
  [SMALL_STATE(10422)] = 313619,
  [SMALL_STATE(10423)] = 313634,
  [SMALL_STATE(10424)] = 313651,
  [SMALL_STATE(10425)] = 313668,
  [SMALL_STATE(10426)] = 313685,
  [SMALL_STATE(10427)] = 313700,
  [SMALL_STATE(10428)] = 313715,
  [SMALL_STATE(10429)] = 313730,
  [SMALL_STATE(10430)] = 313745,
  [SMALL_STATE(10431)] = 313760,
  [SMALL_STATE(10432)] = 313775,
  [SMALL_STATE(10433)] = 313790,
  [SMALL_STATE(10434)] = 313807,
  [SMALL_STATE(10435)] = 313822,
  [SMALL_STATE(10436)] = 313837,
  [SMALL_STATE(10437)] = 313852,
  [SMALL_STATE(10438)] = 313867,
  [SMALL_STATE(10439)] = 313882,
  [SMALL_STATE(10440)] = 313897,
  [SMALL_STATE(10441)] = 313912,
  [SMALL_STATE(10442)] = 313927,
  [SMALL_STATE(10443)] = 313942,
  [SMALL_STATE(10444)] = 313959,
  [SMALL_STATE(10445)] = 313976,
  [SMALL_STATE(10446)] = 313991,
  [SMALL_STATE(10447)] = 314006,
  [SMALL_STATE(10448)] = 314021,
  [SMALL_STATE(10449)] = 314036,
  [SMALL_STATE(10450)] = 314053,
  [SMALL_STATE(10451)] = 314068,
  [SMALL_STATE(10452)] = 314083,
  [SMALL_STATE(10453)] = 314098,
  [SMALL_STATE(10454)] = 314113,
  [SMALL_STATE(10455)] = 314128,
  [SMALL_STATE(10456)] = 314143,
  [SMALL_STATE(10457)] = 314158,
  [SMALL_STATE(10458)] = 314173,
  [SMALL_STATE(10459)] = 314190,
  [SMALL_STATE(10460)] = 314207,
  [SMALL_STATE(10461)] = 314222,
  [SMALL_STATE(10462)] = 314237,
  [SMALL_STATE(10463)] = 314252,
  [SMALL_STATE(10464)] = 314269,
  [SMALL_STATE(10465)] = 314284,
  [SMALL_STATE(10466)] = 314299,
  [SMALL_STATE(10467)] = 314314,
  [SMALL_STATE(10468)] = 314329,
  [SMALL_STATE(10469)] = 314344,
  [SMALL_STATE(10470)] = 314359,
  [SMALL_STATE(10471)] = 314374,
  [SMALL_STATE(10472)] = 314389,
  [SMALL_STATE(10473)] = 314404,
  [SMALL_STATE(10474)] = 314419,
  [SMALL_STATE(10475)] = 314434,
  [SMALL_STATE(10476)] = 314449,
  [SMALL_STATE(10477)] = 314464,
  [SMALL_STATE(10478)] = 314479,
  [SMALL_STATE(10479)] = 314494,
  [SMALL_STATE(10480)] = 314509,
  [SMALL_STATE(10481)] = 314524,
  [SMALL_STATE(10482)] = 314539,
  [SMALL_STATE(10483)] = 314554,
  [SMALL_STATE(10484)] = 314569,
  [SMALL_STATE(10485)] = 314584,
  [SMALL_STATE(10486)] = 314599,
  [SMALL_STATE(10487)] = 314614,
  [SMALL_STATE(10488)] = 314629,
  [SMALL_STATE(10489)] = 314644,
  [SMALL_STATE(10490)] = 314659,
  [SMALL_STATE(10491)] = 314674,
  [SMALL_STATE(10492)] = 314691,
  [SMALL_STATE(10493)] = 314706,
  [SMALL_STATE(10494)] = 314721,
  [SMALL_STATE(10495)] = 314736,
  [SMALL_STATE(10496)] = 314751,
  [SMALL_STATE(10497)] = 314766,
  [SMALL_STATE(10498)] = 314781,
  [SMALL_STATE(10499)] = 314798,
  [SMALL_STATE(10500)] = 314815,
  [SMALL_STATE(10501)] = 314830,
  [SMALL_STATE(10502)] = 314845,
  [SMALL_STATE(10503)] = 314860,
  [SMALL_STATE(10504)] = 314875,
  [SMALL_STATE(10505)] = 314890,
  [SMALL_STATE(10506)] = 314905,
  [SMALL_STATE(10507)] = 314920,
  [SMALL_STATE(10508)] = 314935,
  [SMALL_STATE(10509)] = 314950,
  [SMALL_STATE(10510)] = 314967,
  [SMALL_STATE(10511)] = 314984,
  [SMALL_STATE(10512)] = 314999,
  [SMALL_STATE(10513)] = 315014,
  [SMALL_STATE(10514)] = 315029,
  [SMALL_STATE(10515)] = 315044,
  [SMALL_STATE(10516)] = 315059,
  [SMALL_STATE(10517)] = 315076,
  [SMALL_STATE(10518)] = 315091,
  [SMALL_STATE(10519)] = 315106,
  [SMALL_STATE(10520)] = 315121,
  [SMALL_STATE(10521)] = 315136,
  [SMALL_STATE(10522)] = 315153,
  [SMALL_STATE(10523)] = 315170,
  [SMALL_STATE(10524)] = 315185,
  [SMALL_STATE(10525)] = 315200,
  [SMALL_STATE(10526)] = 315215,
  [SMALL_STATE(10527)] = 315230,
  [SMALL_STATE(10528)] = 315245,
  [SMALL_STATE(10529)] = 315260,
  [SMALL_STATE(10530)] = 315275,
  [SMALL_STATE(10531)] = 315292,
  [SMALL_STATE(10532)] = 315309,
  [SMALL_STATE(10533)] = 315324,
  [SMALL_STATE(10534)] = 315341,
  [SMALL_STATE(10535)] = 315356,
  [SMALL_STATE(10536)] = 315371,
  [SMALL_STATE(10537)] = 315386,
  [SMALL_STATE(10538)] = 315401,
  [SMALL_STATE(10539)] = 315416,
  [SMALL_STATE(10540)] = 315431,
  [SMALL_STATE(10541)] = 315446,
  [SMALL_STATE(10542)] = 315461,
  [SMALL_STATE(10543)] = 315476,
  [SMALL_STATE(10544)] = 315491,
  [SMALL_STATE(10545)] = 315506,
  [SMALL_STATE(10546)] = 315523,
  [SMALL_STATE(10547)] = 315538,
  [SMALL_STATE(10548)] = 315555,
  [SMALL_STATE(10549)] = 315570,
  [SMALL_STATE(10550)] = 315585,
  [SMALL_STATE(10551)] = 315600,
  [SMALL_STATE(10552)] = 315617,
  [SMALL_STATE(10553)] = 315632,
  [SMALL_STATE(10554)] = 315647,
  [SMALL_STATE(10555)] = 315664,
  [SMALL_STATE(10556)] = 315681,
  [SMALL_STATE(10557)] = 315696,
  [SMALL_STATE(10558)] = 315711,
  [SMALL_STATE(10559)] = 315726,
  [SMALL_STATE(10560)] = 315741,
  [SMALL_STATE(10561)] = 315756,
  [SMALL_STATE(10562)] = 315771,
  [SMALL_STATE(10563)] = 315786,
  [SMALL_STATE(10564)] = 315801,
  [SMALL_STATE(10565)] = 315816,
  [SMALL_STATE(10566)] = 315831,
  [SMALL_STATE(10567)] = 315846,
  [SMALL_STATE(10568)] = 315861,
  [SMALL_STATE(10569)] = 315876,
  [SMALL_STATE(10570)] = 315891,
  [SMALL_STATE(10571)] = 315906,
  [SMALL_STATE(10572)] = 315921,
  [SMALL_STATE(10573)] = 315936,
  [SMALL_STATE(10574)] = 315951,
  [SMALL_STATE(10575)] = 315966,
  [SMALL_STATE(10576)] = 315981,
  [SMALL_STATE(10577)] = 315996,
  [SMALL_STATE(10578)] = 316009,
  [SMALL_STATE(10579)] = 316024,
  [SMALL_STATE(10580)] = 316039,
  [SMALL_STATE(10581)] = 316054,
  [SMALL_STATE(10582)] = 316071,
  [SMALL_STATE(10583)] = 316086,
  [SMALL_STATE(10584)] = 316101,
  [SMALL_STATE(10585)] = 316116,
  [SMALL_STATE(10586)] = 316131,
  [SMALL_STATE(10587)] = 316148,
  [SMALL_STATE(10588)] = 316163,
  [SMALL_STATE(10589)] = 316178,
  [SMALL_STATE(10590)] = 316193,
  [SMALL_STATE(10591)] = 316210,
  [SMALL_STATE(10592)] = 316227,
  [SMALL_STATE(10593)] = 316244,
  [SMALL_STATE(10594)] = 316261,
  [SMALL_STATE(10595)] = 316276,
  [SMALL_STATE(10596)] = 316291,
  [SMALL_STATE(10597)] = 316306,
  [SMALL_STATE(10598)] = 316321,
  [SMALL_STATE(10599)] = 316338,
  [SMALL_STATE(10600)] = 316353,
  [SMALL_STATE(10601)] = 316368,
  [SMALL_STATE(10602)] = 316385,
  [SMALL_STATE(10603)] = 316400,
  [SMALL_STATE(10604)] = 316415,
  [SMALL_STATE(10605)] = 316430,
  [SMALL_STATE(10606)] = 316445,
  [SMALL_STATE(10607)] = 316460,
  [SMALL_STATE(10608)] = 316475,
  [SMALL_STATE(10609)] = 316490,
  [SMALL_STATE(10610)] = 316507,
  [SMALL_STATE(10611)] = 316524,
  [SMALL_STATE(10612)] = 316539,
  [SMALL_STATE(10613)] = 316554,
  [SMALL_STATE(10614)] = 316569,
  [SMALL_STATE(10615)] = 316584,
  [SMALL_STATE(10616)] = 316599,
  [SMALL_STATE(10617)] = 316614,
  [SMALL_STATE(10618)] = 316629,
  [SMALL_STATE(10619)] = 316644,
  [SMALL_STATE(10620)] = 316659,
  [SMALL_STATE(10621)] = 316674,
  [SMALL_STATE(10622)] = 316689,
  [SMALL_STATE(10623)] = 316706,
  [SMALL_STATE(10624)] = 316723,
  [SMALL_STATE(10625)] = 316740,
  [SMALL_STATE(10626)] = 316757,
  [SMALL_STATE(10627)] = 316772,
  [SMALL_STATE(10628)] = 316789,
  [SMALL_STATE(10629)] = 316806,
  [SMALL_STATE(10630)] = 316821,
  [SMALL_STATE(10631)] = 316836,
  [SMALL_STATE(10632)] = 316851,
  [SMALL_STATE(10633)] = 316866,
  [SMALL_STATE(10634)] = 316881,
  [SMALL_STATE(10635)] = 316898,
  [SMALL_STATE(10636)] = 316915,
  [SMALL_STATE(10637)] = 316930,
  [SMALL_STATE(10638)] = 316945,
  [SMALL_STATE(10639)] = 316960,
  [SMALL_STATE(10640)] = 316975,
  [SMALL_STATE(10641)] = 316992,
  [SMALL_STATE(10642)] = 317007,
  [SMALL_STATE(10643)] = 317022,
  [SMALL_STATE(10644)] = 317037,
  [SMALL_STATE(10645)] = 317052,
  [SMALL_STATE(10646)] = 317067,
  [SMALL_STATE(10647)] = 317082,
  [SMALL_STATE(10648)] = 317097,
  [SMALL_STATE(10649)] = 317114,
  [SMALL_STATE(10650)] = 317131,
  [SMALL_STATE(10651)] = 317146,
  [SMALL_STATE(10652)] = 317161,
  [SMALL_STATE(10653)] = 317176,
  [SMALL_STATE(10654)] = 317191,
  [SMALL_STATE(10655)] = 317206,
  [SMALL_STATE(10656)] = 317221,
  [SMALL_STATE(10657)] = 317236,
  [SMALL_STATE(10658)] = 317251,
  [SMALL_STATE(10659)] = 317266,
  [SMALL_STATE(10660)] = 317281,
  [SMALL_STATE(10661)] = 317296,
  [SMALL_STATE(10662)] = 317311,
  [SMALL_STATE(10663)] = 317328,
  [SMALL_STATE(10664)] = 317345,
  [SMALL_STATE(10665)] = 317360,
  [SMALL_STATE(10666)] = 317375,
  [SMALL_STATE(10667)] = 317392,
  [SMALL_STATE(10668)] = 317407,
  [SMALL_STATE(10669)] = 317422,
  [SMALL_STATE(10670)] = 317437,
  [SMALL_STATE(10671)] = 317452,
  [SMALL_STATE(10672)] = 317469,
  [SMALL_STATE(10673)] = 317484,
  [SMALL_STATE(10674)] = 317501,
  [SMALL_STATE(10675)] = 317516,
  [SMALL_STATE(10676)] = 317531,
  [SMALL_STATE(10677)] = 317546,
  [SMALL_STATE(10678)] = 317561,
  [SMALL_STATE(10679)] = 317576,
  [SMALL_STATE(10680)] = 317591,
  [SMALL_STATE(10681)] = 317606,
  [SMALL_STATE(10682)] = 317623,
  [SMALL_STATE(10683)] = 317640,
  [SMALL_STATE(10684)] = 317655,
  [SMALL_STATE(10685)] = 317670,
  [SMALL_STATE(10686)] = 317685,
  [SMALL_STATE(10687)] = 317700,
  [SMALL_STATE(10688)] = 317715,
  [SMALL_STATE(10689)] = 317730,
  [SMALL_STATE(10690)] = 317747,
  [SMALL_STATE(10691)] = 317764,
  [SMALL_STATE(10692)] = 317779,
  [SMALL_STATE(10693)] = 317794,
  [SMALL_STATE(10694)] = 317809,
  [SMALL_STATE(10695)] = 317824,
  [SMALL_STATE(10696)] = 317839,
  [SMALL_STATE(10697)] = 317854,
  [SMALL_STATE(10698)] = 317869,
  [SMALL_STATE(10699)] = 317884,
  [SMALL_STATE(10700)] = 317899,
  [SMALL_STATE(10701)] = 317916,
  [SMALL_STATE(10702)] = 317931,
  [SMALL_STATE(10703)] = 317948,
  [SMALL_STATE(10704)] = 317965,
  [SMALL_STATE(10705)] = 317980,
  [SMALL_STATE(10706)] = 317995,
  [SMALL_STATE(10707)] = 318012,
  [SMALL_STATE(10708)] = 318027,
  [SMALL_STATE(10709)] = 318044,
  [SMALL_STATE(10710)] = 318061,
  [SMALL_STATE(10711)] = 318076,
  [SMALL_STATE(10712)] = 318091,
  [SMALL_STATE(10713)] = 318106,
  [SMALL_STATE(10714)] = 318121,
  [SMALL_STATE(10715)] = 318136,
  [SMALL_STATE(10716)] = 318153,
  [SMALL_STATE(10717)] = 318170,
  [SMALL_STATE(10718)] = 318185,
  [SMALL_STATE(10719)] = 318200,
  [SMALL_STATE(10720)] = 318215,
  [SMALL_STATE(10721)] = 318230,
  [SMALL_STATE(10722)] = 318245,
  [SMALL_STATE(10723)] = 318260,
  [SMALL_STATE(10724)] = 318273,
  [SMALL_STATE(10725)] = 318290,
  [SMALL_STATE(10726)] = 318307,
  [SMALL_STATE(10727)] = 318322,
  [SMALL_STATE(10728)] = 318337,
  [SMALL_STATE(10729)] = 318352,
  [SMALL_STATE(10730)] = 318367,
  [SMALL_STATE(10731)] = 318382,
  [SMALL_STATE(10732)] = 318397,
  [SMALL_STATE(10733)] = 318414,
  [SMALL_STATE(10734)] = 318429,
  [SMALL_STATE(10735)] = 318444,
  [SMALL_STATE(10736)] = 318459,
  [SMALL_STATE(10737)] = 318474,
  [SMALL_STATE(10738)] = 318489,
  [SMALL_STATE(10739)] = 318504,
  [SMALL_STATE(10740)] = 318519,
  [SMALL_STATE(10741)] = 318534,
  [SMALL_STATE(10742)] = 318549,
  [SMALL_STATE(10743)] = 318564,
  [SMALL_STATE(10744)] = 318579,
  [SMALL_STATE(10745)] = 318594,
  [SMALL_STATE(10746)] = 318609,
  [SMALL_STATE(10747)] = 318624,
  [SMALL_STATE(10748)] = 318639,
  [SMALL_STATE(10749)] = 318654,
  [SMALL_STATE(10750)] = 318669,
  [SMALL_STATE(10751)] = 318684,
  [SMALL_STATE(10752)] = 318699,
  [SMALL_STATE(10753)] = 318714,
  [SMALL_STATE(10754)] = 318729,
  [SMALL_STATE(10755)] = 318744,
  [SMALL_STATE(10756)] = 318761,
  [SMALL_STATE(10757)] = 318776,
  [SMALL_STATE(10758)] = 318793,
  [SMALL_STATE(10759)] = 318810,
  [SMALL_STATE(10760)] = 318825,
  [SMALL_STATE(10761)] = 318840,
  [SMALL_STATE(10762)] = 318853,
  [SMALL_STATE(10763)] = 318870,
  [SMALL_STATE(10764)] = 318887,
  [SMALL_STATE(10765)] = 318902,
  [SMALL_STATE(10766)] = 318919,
  [SMALL_STATE(10767)] = 318932,
  [SMALL_STATE(10768)] = 318947,
  [SMALL_STATE(10769)] = 318962,
  [SMALL_STATE(10770)] = 318979,
  [SMALL_STATE(10771)] = 318994,
  [SMALL_STATE(10772)] = 319009,
  [SMALL_STATE(10773)] = 319024,
  [SMALL_STATE(10774)] = 319039,
  [SMALL_STATE(10775)] = 319054,
  [SMALL_STATE(10776)] = 319069,
  [SMALL_STATE(10777)] = 319084,
  [SMALL_STATE(10778)] = 319099,
  [SMALL_STATE(10779)] = 319114,
  [SMALL_STATE(10780)] = 319129,
  [SMALL_STATE(10781)] = 319144,
  [SMALL_STATE(10782)] = 319159,
  [SMALL_STATE(10783)] = 319174,
  [SMALL_STATE(10784)] = 319189,
  [SMALL_STATE(10785)] = 319206,
  [SMALL_STATE(10786)] = 319223,
  [SMALL_STATE(10787)] = 319240,
  [SMALL_STATE(10788)] = 319255,
  [SMALL_STATE(10789)] = 319270,
  [SMALL_STATE(10790)] = 319285,
  [SMALL_STATE(10791)] = 319302,
  [SMALL_STATE(10792)] = 319319,
  [SMALL_STATE(10793)] = 319334,
  [SMALL_STATE(10794)] = 319349,
  [SMALL_STATE(10795)] = 319364,
  [SMALL_STATE(10796)] = 319379,
  [SMALL_STATE(10797)] = 319394,
  [SMALL_STATE(10798)] = 319409,
  [SMALL_STATE(10799)] = 319426,
  [SMALL_STATE(10800)] = 319443,
  [SMALL_STATE(10801)] = 319460,
  [SMALL_STATE(10802)] = 319477,
  [SMALL_STATE(10803)] = 319492,
  [SMALL_STATE(10804)] = 319509,
  [SMALL_STATE(10805)] = 319526,
  [SMALL_STATE(10806)] = 319541,
  [SMALL_STATE(10807)] = 319556,
  [SMALL_STATE(10808)] = 319571,
  [SMALL_STATE(10809)] = 319584,
  [SMALL_STATE(10810)] = 319599,
  [SMALL_STATE(10811)] = 319614,
  [SMALL_STATE(10812)] = 319631,
  [SMALL_STATE(10813)] = 319648,
  [SMALL_STATE(10814)] = 319663,
  [SMALL_STATE(10815)] = 319678,
  [SMALL_STATE(10816)] = 319693,
  [SMALL_STATE(10817)] = 319708,
  [SMALL_STATE(10818)] = 319723,
  [SMALL_STATE(10819)] = 319738,
  [SMALL_STATE(10820)] = 319753,
  [SMALL_STATE(10821)] = 319770,
  [SMALL_STATE(10822)] = 319787,
  [SMALL_STATE(10823)] = 319802,
  [SMALL_STATE(10824)] = 319817,
  [SMALL_STATE(10825)] = 319834,
  [SMALL_STATE(10826)] = 319849,
  [SMALL_STATE(10827)] = 319864,
  [SMALL_STATE(10828)] = 319879,
  [SMALL_STATE(10829)] = 319894,
  [SMALL_STATE(10830)] = 319909,
  [SMALL_STATE(10831)] = 319924,
  [SMALL_STATE(10832)] = 319939,
  [SMALL_STATE(10833)] = 319956,
  [SMALL_STATE(10834)] = 319973,
  [SMALL_STATE(10835)] = 319988,
  [SMALL_STATE(10836)] = 320003,
  [SMALL_STATE(10837)] = 320018,
  [SMALL_STATE(10838)] = 320033,
  [SMALL_STATE(10839)] = 320048,
  [SMALL_STATE(10840)] = 320063,
  [SMALL_STATE(10841)] = 320078,
  [SMALL_STATE(10842)] = 320093,
  [SMALL_STATE(10843)] = 320108,
  [SMALL_STATE(10844)] = 320125,
  [SMALL_STATE(10845)] = 320142,
  [SMALL_STATE(10846)] = 320157,
  [SMALL_STATE(10847)] = 320172,
  [SMALL_STATE(10848)] = 320189,
  [SMALL_STATE(10849)] = 320206,
  [SMALL_STATE(10850)] = 320221,
  [SMALL_STATE(10851)] = 320236,
  [SMALL_STATE(10852)] = 320253,
  [SMALL_STATE(10853)] = 320268,
  [SMALL_STATE(10854)] = 320283,
  [SMALL_STATE(10855)] = 320298,
  [SMALL_STATE(10856)] = 320313,
  [SMALL_STATE(10857)] = 320328,
  [SMALL_STATE(10858)] = 320343,
  [SMALL_STATE(10859)] = 320358,
  [SMALL_STATE(10860)] = 320373,
  [SMALL_STATE(10861)] = 320386,
  [SMALL_STATE(10862)] = 320401,
  [SMALL_STATE(10863)] = 320418,
  [SMALL_STATE(10864)] = 320433,
  [SMALL_STATE(10865)] = 320448,
  [SMALL_STATE(10866)] = 320463,
  [SMALL_STATE(10867)] = 320478,
  [SMALL_STATE(10868)] = 320493,
  [SMALL_STATE(10869)] = 320508,
  [SMALL_STATE(10870)] = 320523,
  [SMALL_STATE(10871)] = 320538,
  [SMALL_STATE(10872)] = 320553,
  [SMALL_STATE(10873)] = 320568,
  [SMALL_STATE(10874)] = 320585,
  [SMALL_STATE(10875)] = 320602,
  [SMALL_STATE(10876)] = 320617,
  [SMALL_STATE(10877)] = 320632,
  [SMALL_STATE(10878)] = 320645,
  [SMALL_STATE(10879)] = 320660,
  [SMALL_STATE(10880)] = 320675,
  [SMALL_STATE(10881)] = 320692,
  [SMALL_STATE(10882)] = 320707,
  [SMALL_STATE(10883)] = 320722,
  [SMALL_STATE(10884)] = 320739,
  [SMALL_STATE(10885)] = 320754,
  [SMALL_STATE(10886)] = 320771,
  [SMALL_STATE(10887)] = 320786,
  [SMALL_STATE(10888)] = 320801,
  [SMALL_STATE(10889)] = 320816,
  [SMALL_STATE(10890)] = 320833,
  [SMALL_STATE(10891)] = 320848,
  [SMALL_STATE(10892)] = 320863,
  [SMALL_STATE(10893)] = 320878,
  [SMALL_STATE(10894)] = 320893,
  [SMALL_STATE(10895)] = 320908,
  [SMALL_STATE(10896)] = 320921,
  [SMALL_STATE(10897)] = 320938,
  [SMALL_STATE(10898)] = 320955,
  [SMALL_STATE(10899)] = 320972,
  [SMALL_STATE(10900)] = 320987,
  [SMALL_STATE(10901)] = 321002,
  [SMALL_STATE(10902)] = 321017,
  [SMALL_STATE(10903)] = 321032,
  [SMALL_STATE(10904)] = 321047,
  [SMALL_STATE(10905)] = 321062,
  [SMALL_STATE(10906)] = 321077,
  [SMALL_STATE(10907)] = 321094,
  [SMALL_STATE(10908)] = 321111,
  [SMALL_STATE(10909)] = 321126,
  [SMALL_STATE(10910)] = 321141,
  [SMALL_STATE(10911)] = 321156,
  [SMALL_STATE(10912)] = 321171,
  [SMALL_STATE(10913)] = 321186,
  [SMALL_STATE(10914)] = 321201,
  [SMALL_STATE(10915)] = 321216,
  [SMALL_STATE(10916)] = 321231,
  [SMALL_STATE(10917)] = 321246,
  [SMALL_STATE(10918)] = 321261,
  [SMALL_STATE(10919)] = 321276,
  [SMALL_STATE(10920)] = 321291,
  [SMALL_STATE(10921)] = 321306,
  [SMALL_STATE(10922)] = 321321,
  [SMALL_STATE(10923)] = 321338,
  [SMALL_STATE(10924)] = 321353,
  [SMALL_STATE(10925)] = 321368,
  [SMALL_STATE(10926)] = 321383,
  [SMALL_STATE(10927)] = 321398,
  [SMALL_STATE(10928)] = 321413,
  [SMALL_STATE(10929)] = 321428,
  [SMALL_STATE(10930)] = 321443,
  [SMALL_STATE(10931)] = 321458,
  [SMALL_STATE(10932)] = 321475,
  [SMALL_STATE(10933)] = 321490,
  [SMALL_STATE(10934)] = 321505,
  [SMALL_STATE(10935)] = 321520,
  [SMALL_STATE(10936)] = 321537,
  [SMALL_STATE(10937)] = 321552,
  [SMALL_STATE(10938)] = 321567,
  [SMALL_STATE(10939)] = 321582,
  [SMALL_STATE(10940)] = 321597,
  [SMALL_STATE(10941)] = 321612,
  [SMALL_STATE(10942)] = 321627,
  [SMALL_STATE(10943)] = 321642,
  [SMALL_STATE(10944)] = 321655,
  [SMALL_STATE(10945)] = 321670,
  [SMALL_STATE(10946)] = 321685,
  [SMALL_STATE(10947)] = 321700,
  [SMALL_STATE(10948)] = 321717,
  [SMALL_STATE(10949)] = 321732,
  [SMALL_STATE(10950)] = 321749,
  [SMALL_STATE(10951)] = 321766,
  [SMALL_STATE(10952)] = 321781,
  [SMALL_STATE(10953)] = 321796,
  [SMALL_STATE(10954)] = 321813,
  [SMALL_STATE(10955)] = 321828,
  [SMALL_STATE(10956)] = 321843,
  [SMALL_STATE(10957)] = 321858,
  [SMALL_STATE(10958)] = 321873,
  [SMALL_STATE(10959)] = 321890,
  [SMALL_STATE(10960)] = 321907,
  [SMALL_STATE(10961)] = 321920,
  [SMALL_STATE(10962)] = 321935,
  [SMALL_STATE(10963)] = 321950,
  [SMALL_STATE(10964)] = 321963,
  [SMALL_STATE(10965)] = 321978,
  [SMALL_STATE(10966)] = 321993,
  [SMALL_STATE(10967)] = 322008,
  [SMALL_STATE(10968)] = 322023,
  [SMALL_STATE(10969)] = 322038,
  [SMALL_STATE(10970)] = 322055,
  [SMALL_STATE(10971)] = 322072,
  [SMALL_STATE(10972)] = 322089,
  [SMALL_STATE(10973)] = 322106,
  [SMALL_STATE(10974)] = 322121,
  [SMALL_STATE(10975)] = 322136,
  [SMALL_STATE(10976)] = 322151,
  [SMALL_STATE(10977)] = 322166,
  [SMALL_STATE(10978)] = 322179,
  [SMALL_STATE(10979)] = 322196,
  [SMALL_STATE(10980)] = 322211,
  [SMALL_STATE(10981)] = 322226,
  [SMALL_STATE(10982)] = 322243,
  [SMALL_STATE(10983)] = 322258,
  [SMALL_STATE(10984)] = 322275,
  [SMALL_STATE(10985)] = 322290,
  [SMALL_STATE(10986)] = 322307,
  [SMALL_STATE(10987)] = 322322,
  [SMALL_STATE(10988)] = 322337,
  [SMALL_STATE(10989)] = 322354,
  [SMALL_STATE(10990)] = 322369,
  [SMALL_STATE(10991)] = 322386,
  [SMALL_STATE(10992)] = 322401,
  [SMALL_STATE(10993)] = 322416,
  [SMALL_STATE(10994)] = 322431,
  [SMALL_STATE(10995)] = 322446,
  [SMALL_STATE(10996)] = 322461,
  [SMALL_STATE(10997)] = 322478,
  [SMALL_STATE(10998)] = 322493,
  [SMALL_STATE(10999)] = 322508,
  [SMALL_STATE(11000)] = 322525,
  [SMALL_STATE(11001)] = 322540,
  [SMALL_STATE(11002)] = 322555,
  [SMALL_STATE(11003)] = 322570,
  [SMALL_STATE(11004)] = 322585,
  [SMALL_STATE(11005)] = 322600,
  [SMALL_STATE(11006)] = 322615,
  [SMALL_STATE(11007)] = 322630,
  [SMALL_STATE(11008)] = 322645,
  [SMALL_STATE(11009)] = 322660,
  [SMALL_STATE(11010)] = 322675,
  [SMALL_STATE(11011)] = 322690,
  [SMALL_STATE(11012)] = 322705,
  [SMALL_STATE(11013)] = 322720,
  [SMALL_STATE(11014)] = 322735,
  [SMALL_STATE(11015)] = 322750,
  [SMALL_STATE(11016)] = 322765,
  [SMALL_STATE(11017)] = 322780,
  [SMALL_STATE(11018)] = 322795,
  [SMALL_STATE(11019)] = 322810,
  [SMALL_STATE(11020)] = 322825,
  [SMALL_STATE(11021)] = 322840,
  [SMALL_STATE(11022)] = 322857,
  [SMALL_STATE(11023)] = 322872,
  [SMALL_STATE(11024)] = 322889,
  [SMALL_STATE(11025)] = 322906,
  [SMALL_STATE(11026)] = 322921,
  [SMALL_STATE(11027)] = 322936,
  [SMALL_STATE(11028)] = 322951,
  [SMALL_STATE(11029)] = 322966,
  [SMALL_STATE(11030)] = 322981,
  [SMALL_STATE(11031)] = 322996,
  [SMALL_STATE(11032)] = 323011,
  [SMALL_STATE(11033)] = 323026,
  [SMALL_STATE(11034)] = 323041,
  [SMALL_STATE(11035)] = 323056,
  [SMALL_STATE(11036)] = 323071,
  [SMALL_STATE(11037)] = 323086,
  [SMALL_STATE(11038)] = 323101,
  [SMALL_STATE(11039)] = 323116,
  [SMALL_STATE(11040)] = 323131,
  [SMALL_STATE(11041)] = 323146,
  [SMALL_STATE(11042)] = 323161,
  [SMALL_STATE(11043)] = 323176,
  [SMALL_STATE(11044)] = 323191,
  [SMALL_STATE(11045)] = 323206,
  [SMALL_STATE(11046)] = 323221,
  [SMALL_STATE(11047)] = 323236,
  [SMALL_STATE(11048)] = 323251,
  [SMALL_STATE(11049)] = 323266,
  [SMALL_STATE(11050)] = 323281,
  [SMALL_STATE(11051)] = 323296,
  [SMALL_STATE(11052)] = 323311,
  [SMALL_STATE(11053)] = 323326,
  [SMALL_STATE(11054)] = 323341,
  [SMALL_STATE(11055)] = 323356,
  [SMALL_STATE(11056)] = 323369,
  [SMALL_STATE(11057)] = 323384,
  [SMALL_STATE(11058)] = 323399,
  [SMALL_STATE(11059)] = 323414,
  [SMALL_STATE(11060)] = 323429,
  [SMALL_STATE(11061)] = 323444,
  [SMALL_STATE(11062)] = 323459,
  [SMALL_STATE(11063)] = 323474,
  [SMALL_STATE(11064)] = 323489,
  [SMALL_STATE(11065)] = 323504,
  [SMALL_STATE(11066)] = 323519,
  [SMALL_STATE(11067)] = 323534,
  [SMALL_STATE(11068)] = 323549,
  [SMALL_STATE(11069)] = 323564,
  [SMALL_STATE(11070)] = 323579,
  [SMALL_STATE(11071)] = 323594,
  [SMALL_STATE(11072)] = 323609,
  [SMALL_STATE(11073)] = 323624,
  [SMALL_STATE(11074)] = 323639,
  [SMALL_STATE(11075)] = 323654,
  [SMALL_STATE(11076)] = 323669,
  [SMALL_STATE(11077)] = 323684,
  [SMALL_STATE(11078)] = 323699,
  [SMALL_STATE(11079)] = 323714,
  [SMALL_STATE(11080)] = 323729,
  [SMALL_STATE(11081)] = 323744,
  [SMALL_STATE(11082)] = 323759,
  [SMALL_STATE(11083)] = 323774,
  [SMALL_STATE(11084)] = 323789,
  [SMALL_STATE(11085)] = 323804,
  [SMALL_STATE(11086)] = 323821,
  [SMALL_STATE(11087)] = 323836,
  [SMALL_STATE(11088)] = 323851,
  [SMALL_STATE(11089)] = 323866,
  [SMALL_STATE(11090)] = 323881,
  [SMALL_STATE(11091)] = 323896,
  [SMALL_STATE(11092)] = 323911,
  [SMALL_STATE(11093)] = 323926,
  [SMALL_STATE(11094)] = 323941,
  [SMALL_STATE(11095)] = 323956,
  [SMALL_STATE(11096)] = 323973,
  [SMALL_STATE(11097)] = 323988,
  [SMALL_STATE(11098)] = 324003,
  [SMALL_STATE(11099)] = 324018,
  [SMALL_STATE(11100)] = 324033,
  [SMALL_STATE(11101)] = 324048,
  [SMALL_STATE(11102)] = 324063,
  [SMALL_STATE(11103)] = 324078,
  [SMALL_STATE(11104)] = 324093,
  [SMALL_STATE(11105)] = 324108,
  [SMALL_STATE(11106)] = 324123,
  [SMALL_STATE(11107)] = 324138,
  [SMALL_STATE(11108)] = 324153,
  [SMALL_STATE(11109)] = 324168,
  [SMALL_STATE(11110)] = 324183,
  [SMALL_STATE(11111)] = 324198,
  [SMALL_STATE(11112)] = 324213,
  [SMALL_STATE(11113)] = 324230,
  [SMALL_STATE(11114)] = 324245,
  [SMALL_STATE(11115)] = 324260,
  [SMALL_STATE(11116)] = 324274,
  [SMALL_STATE(11117)] = 324286,
  [SMALL_STATE(11118)] = 324298,
  [SMALL_STATE(11119)] = 324310,
  [SMALL_STATE(11120)] = 324322,
  [SMALL_STATE(11121)] = 324336,
  [SMALL_STATE(11122)] = 324348,
  [SMALL_STATE(11123)] = 324362,
  [SMALL_STATE(11124)] = 324374,
  [SMALL_STATE(11125)] = 324388,
  [SMALL_STATE(11126)] = 324400,
  [SMALL_STATE(11127)] = 324414,
  [SMALL_STATE(11128)] = 324428,
  [SMALL_STATE(11129)] = 324442,
  [SMALL_STATE(11130)] = 324454,
  [SMALL_STATE(11131)] = 324468,
  [SMALL_STATE(11132)] = 324480,
  [SMALL_STATE(11133)] = 324492,
  [SMALL_STATE(11134)] = 324506,
  [SMALL_STATE(11135)] = 324518,
  [SMALL_STATE(11136)] = 324530,
  [SMALL_STATE(11137)] = 324544,
  [SMALL_STATE(11138)] = 324556,
  [SMALL_STATE(11139)] = 324570,
  [SMALL_STATE(11140)] = 324582,
  [SMALL_STATE(11141)] = 324596,
  [SMALL_STATE(11142)] = 324610,
  [SMALL_STATE(11143)] = 324624,
  [SMALL_STATE(11144)] = 324636,
  [SMALL_STATE(11145)] = 324648,
  [SMALL_STATE(11146)] = 324662,
  [SMALL_STATE(11147)] = 324676,
  [SMALL_STATE(11148)] = 324690,
  [SMALL_STATE(11149)] = 324704,
  [SMALL_STATE(11150)] = 324716,
  [SMALL_STATE(11151)] = 324730,
  [SMALL_STATE(11152)] = 324744,
  [SMALL_STATE(11153)] = 324756,
  [SMALL_STATE(11154)] = 324768,
  [SMALL_STATE(11155)] = 324782,
  [SMALL_STATE(11156)] = 324796,
  [SMALL_STATE(11157)] = 324810,
  [SMALL_STATE(11158)] = 324824,
  [SMALL_STATE(11159)] = 324838,
  [SMALL_STATE(11160)] = 324852,
  [SMALL_STATE(11161)] = 324866,
  [SMALL_STATE(11162)] = 324878,
  [SMALL_STATE(11163)] = 324892,
  [SMALL_STATE(11164)] = 324906,
  [SMALL_STATE(11165)] = 324920,
  [SMALL_STATE(11166)] = 324934,
  [SMALL_STATE(11167)] = 324948,
  [SMALL_STATE(11168)] = 324962,
  [SMALL_STATE(11169)] = 324976,
  [SMALL_STATE(11170)] = 324988,
  [SMALL_STATE(11171)] = 325000,
  [SMALL_STATE(11172)] = 325014,
  [SMALL_STATE(11173)] = 325026,
  [SMALL_STATE(11174)] = 325040,
  [SMALL_STATE(11175)] = 325054,
  [SMALL_STATE(11176)] = 325066,
  [SMALL_STATE(11177)] = 325080,
  [SMALL_STATE(11178)] = 325094,
  [SMALL_STATE(11179)] = 325108,
  [SMALL_STATE(11180)] = 325122,
  [SMALL_STATE(11181)] = 325136,
  [SMALL_STATE(11182)] = 325150,
  [SMALL_STATE(11183)] = 325164,
  [SMALL_STATE(11184)] = 325178,
  [SMALL_STATE(11185)] = 325190,
  [SMALL_STATE(11186)] = 325204,
  [SMALL_STATE(11187)] = 325216,
  [SMALL_STATE(11188)] = 325230,
  [SMALL_STATE(11189)] = 325244,
  [SMALL_STATE(11190)] = 325258,
  [SMALL_STATE(11191)] = 325272,
  [SMALL_STATE(11192)] = 325284,
  [SMALL_STATE(11193)] = 325298,
  [SMALL_STATE(11194)] = 325310,
  [SMALL_STATE(11195)] = 325324,
  [SMALL_STATE(11196)] = 325338,
  [SMALL_STATE(11197)] = 325352,
  [SMALL_STATE(11198)] = 325366,
  [SMALL_STATE(11199)] = 325378,
  [SMALL_STATE(11200)] = 325390,
  [SMALL_STATE(11201)] = 325402,
  [SMALL_STATE(11202)] = 325416,
  [SMALL_STATE(11203)] = 325430,
  [SMALL_STATE(11204)] = 325442,
  [SMALL_STATE(11205)] = 325456,
  [SMALL_STATE(11206)] = 325468,
  [SMALL_STATE(11207)] = 325482,
  [SMALL_STATE(11208)] = 325496,
  [SMALL_STATE(11209)] = 325510,
  [SMALL_STATE(11210)] = 325522,
  [SMALL_STATE(11211)] = 325536,
  [SMALL_STATE(11212)] = 325550,
  [SMALL_STATE(11213)] = 325562,
  [SMALL_STATE(11214)] = 325576,
  [SMALL_STATE(11215)] = 325590,
  [SMALL_STATE(11216)] = 325604,
  [SMALL_STATE(11217)] = 325616,
  [SMALL_STATE(11218)] = 325630,
  [SMALL_STATE(11219)] = 325642,
  [SMALL_STATE(11220)] = 325656,
  [SMALL_STATE(11221)] = 325670,
  [SMALL_STATE(11222)] = 325682,
  [SMALL_STATE(11223)] = 325696,
  [SMALL_STATE(11224)] = 325710,
  [SMALL_STATE(11225)] = 325724,
  [SMALL_STATE(11226)] = 325736,
  [SMALL_STATE(11227)] = 325748,
  [SMALL_STATE(11228)] = 325762,
  [SMALL_STATE(11229)] = 325776,
  [SMALL_STATE(11230)] = 325788,
  [SMALL_STATE(11231)] = 325802,
  [SMALL_STATE(11232)] = 325816,
  [SMALL_STATE(11233)] = 325828,
  [SMALL_STATE(11234)] = 325842,
  [SMALL_STATE(11235)] = 325856,
  [SMALL_STATE(11236)] = 325870,
  [SMALL_STATE(11237)] = 325882,
  [SMALL_STATE(11238)] = 325896,
  [SMALL_STATE(11239)] = 325910,
  [SMALL_STATE(11240)] = 325924,
  [SMALL_STATE(11241)] = 325936,
  [SMALL_STATE(11242)] = 325948,
  [SMALL_STATE(11243)] = 325962,
  [SMALL_STATE(11244)] = 325976,
  [SMALL_STATE(11245)] = 325990,
  [SMALL_STATE(11246)] = 326002,
  [SMALL_STATE(11247)] = 326016,
  [SMALL_STATE(11248)] = 326030,
  [SMALL_STATE(11249)] = 326044,
  [SMALL_STATE(11250)] = 326058,
  [SMALL_STATE(11251)] = 326072,
  [SMALL_STATE(11252)] = 326086,
  [SMALL_STATE(11253)] = 326098,
  [SMALL_STATE(11254)] = 326109,
  [SMALL_STATE(11255)] = 326120,
  [SMALL_STATE(11256)] = 326131,
  [SMALL_STATE(11257)] = 326142,
  [SMALL_STATE(11258)] = 326153,
  [SMALL_STATE(11259)] = 326164,
  [SMALL_STATE(11260)] = 326175,
  [SMALL_STATE(11261)] = 326186,
  [SMALL_STATE(11262)] = 326197,
  [SMALL_STATE(11263)] = 326208,
  [SMALL_STATE(11264)] = 326219,
  [SMALL_STATE(11265)] = 326230,
  [SMALL_STATE(11266)] = 326241,
  [SMALL_STATE(11267)] = 326252,
  [SMALL_STATE(11268)] = 326263,
  [SMALL_STATE(11269)] = 326274,
  [SMALL_STATE(11270)] = 326285,
  [SMALL_STATE(11271)] = 326296,
  [SMALL_STATE(11272)] = 326307,
  [SMALL_STATE(11273)] = 326318,
  [SMALL_STATE(11274)] = 326329,
  [SMALL_STATE(11275)] = 326340,
  [SMALL_STATE(11276)] = 326351,
  [SMALL_STATE(11277)] = 326362,
  [SMALL_STATE(11278)] = 326373,
  [SMALL_STATE(11279)] = 326384,
  [SMALL_STATE(11280)] = 326395,
  [SMALL_STATE(11281)] = 326406,
  [SMALL_STATE(11282)] = 326417,
  [SMALL_STATE(11283)] = 326428,
  [SMALL_STATE(11284)] = 326439,
  [SMALL_STATE(11285)] = 326450,
  [SMALL_STATE(11286)] = 326461,
  [SMALL_STATE(11287)] = 326472,
  [SMALL_STATE(11288)] = 326483,
  [SMALL_STATE(11289)] = 326494,
  [SMALL_STATE(11290)] = 326505,
  [SMALL_STATE(11291)] = 326516,
  [SMALL_STATE(11292)] = 326527,
  [SMALL_STATE(11293)] = 326538,
  [SMALL_STATE(11294)] = 326549,
  [SMALL_STATE(11295)] = 326560,
  [SMALL_STATE(11296)] = 326571,
  [SMALL_STATE(11297)] = 326582,
  [SMALL_STATE(11298)] = 326593,
  [SMALL_STATE(11299)] = 326604,
  [SMALL_STATE(11300)] = 326615,
  [SMALL_STATE(11301)] = 326626,
  [SMALL_STATE(11302)] = 326637,
  [SMALL_STATE(11303)] = 326648,
  [SMALL_STATE(11304)] = 326659,
  [SMALL_STATE(11305)] = 326670,
  [SMALL_STATE(11306)] = 326681,
  [SMALL_STATE(11307)] = 326692,
  [SMALL_STATE(11308)] = 326703,
  [SMALL_STATE(11309)] = 326714,
  [SMALL_STATE(11310)] = 326725,
  [SMALL_STATE(11311)] = 326736,
  [SMALL_STATE(11312)] = 326747,
  [SMALL_STATE(11313)] = 326758,
  [SMALL_STATE(11314)] = 326769,
  [SMALL_STATE(11315)] = 326780,
  [SMALL_STATE(11316)] = 326791,
  [SMALL_STATE(11317)] = 326802,
  [SMALL_STATE(11318)] = 326813,
  [SMALL_STATE(11319)] = 326824,
  [SMALL_STATE(11320)] = 326835,
  [SMALL_STATE(11321)] = 326846,
  [SMALL_STATE(11322)] = 326857,
  [SMALL_STATE(11323)] = 326868,
  [SMALL_STATE(11324)] = 326879,
  [SMALL_STATE(11325)] = 326890,
  [SMALL_STATE(11326)] = 326901,
  [SMALL_STATE(11327)] = 326912,
  [SMALL_STATE(11328)] = 326923,
  [SMALL_STATE(11329)] = 326934,
  [SMALL_STATE(11330)] = 326945,
  [SMALL_STATE(11331)] = 326956,
  [SMALL_STATE(11332)] = 326967,
  [SMALL_STATE(11333)] = 326978,
  [SMALL_STATE(11334)] = 326989,
  [SMALL_STATE(11335)] = 327000,
  [SMALL_STATE(11336)] = 327011,
  [SMALL_STATE(11337)] = 327022,
  [SMALL_STATE(11338)] = 327033,
  [SMALL_STATE(11339)] = 327044,
  [SMALL_STATE(11340)] = 327055,
  [SMALL_STATE(11341)] = 327066,
  [SMALL_STATE(11342)] = 327077,
  [SMALL_STATE(11343)] = 327088,
  [SMALL_STATE(11344)] = 327099,
  [SMALL_STATE(11345)] = 327110,
  [SMALL_STATE(11346)] = 327121,
  [SMALL_STATE(11347)] = 327132,
  [SMALL_STATE(11348)] = 327143,
  [SMALL_STATE(11349)] = 327154,
  [SMALL_STATE(11350)] = 327165,
  [SMALL_STATE(11351)] = 327176,
  [SMALL_STATE(11352)] = 327187,
  [SMALL_STATE(11353)] = 327198,
  [SMALL_STATE(11354)] = 327209,
  [SMALL_STATE(11355)] = 327220,
  [SMALL_STATE(11356)] = 327231,
  [SMALL_STATE(11357)] = 327242,
  [SMALL_STATE(11358)] = 327253,
  [SMALL_STATE(11359)] = 327264,
  [SMALL_STATE(11360)] = 327275,
  [SMALL_STATE(11361)] = 327286,
  [SMALL_STATE(11362)] = 327297,
  [SMALL_STATE(11363)] = 327308,
  [SMALL_STATE(11364)] = 327319,
  [SMALL_STATE(11365)] = 327330,
  [SMALL_STATE(11366)] = 327341,
  [SMALL_STATE(11367)] = 327352,
  [SMALL_STATE(11368)] = 327363,
  [SMALL_STATE(11369)] = 327374,
  [SMALL_STATE(11370)] = 327385,
  [SMALL_STATE(11371)] = 327396,
  [SMALL_STATE(11372)] = 327407,
  [SMALL_STATE(11373)] = 327418,
  [SMALL_STATE(11374)] = 327429,
  [SMALL_STATE(11375)] = 327440,
  [SMALL_STATE(11376)] = 327451,
  [SMALL_STATE(11377)] = 327462,
  [SMALL_STATE(11378)] = 327473,
  [SMALL_STATE(11379)] = 327484,
  [SMALL_STATE(11380)] = 327495,
  [SMALL_STATE(11381)] = 327506,
  [SMALL_STATE(11382)] = 327517,
  [SMALL_STATE(11383)] = 327528,
  [SMALL_STATE(11384)] = 327539,
  [SMALL_STATE(11385)] = 327550,
  [SMALL_STATE(11386)] = 327561,
  [SMALL_STATE(11387)] = 327572,
  [SMALL_STATE(11388)] = 327583,
  [SMALL_STATE(11389)] = 327594,
  [SMALL_STATE(11390)] = 327605,
  [SMALL_STATE(11391)] = 327616,
  [SMALL_STATE(11392)] = 327627,
  [SMALL_STATE(11393)] = 327638,
  [SMALL_STATE(11394)] = 327649,
  [SMALL_STATE(11395)] = 327660,
  [SMALL_STATE(11396)] = 327671,
  [SMALL_STATE(11397)] = 327682,
  [SMALL_STATE(11398)] = 327693,
  [SMALL_STATE(11399)] = 327704,
  [SMALL_STATE(11400)] = 327715,
  [SMALL_STATE(11401)] = 327726,
  [SMALL_STATE(11402)] = 327737,
  [SMALL_STATE(11403)] = 327748,
  [SMALL_STATE(11404)] = 327759,
  [SMALL_STATE(11405)] = 327770,
  [SMALL_STATE(11406)] = 327781,
  [SMALL_STATE(11407)] = 327792,
  [SMALL_STATE(11408)] = 327803,
  [SMALL_STATE(11409)] = 327814,
  [SMALL_STATE(11410)] = 327825,
  [SMALL_STATE(11411)] = 327836,
  [SMALL_STATE(11412)] = 327847,
  [SMALL_STATE(11413)] = 327858,
  [SMALL_STATE(11414)] = 327869,
  [SMALL_STATE(11415)] = 327880,
  [SMALL_STATE(11416)] = 327891,
  [SMALL_STATE(11417)] = 327902,
  [SMALL_STATE(11418)] = 327913,
  [SMALL_STATE(11419)] = 327924,
  [SMALL_STATE(11420)] = 327935,
  [SMALL_STATE(11421)] = 327946,
  [SMALL_STATE(11422)] = 327957,
  [SMALL_STATE(11423)] = 327968,
  [SMALL_STATE(11424)] = 327979,
  [SMALL_STATE(11425)] = 327990,
  [SMALL_STATE(11426)] = 328001,
  [SMALL_STATE(11427)] = 328012,
  [SMALL_STATE(11428)] = 328023,
  [SMALL_STATE(11429)] = 328034,
  [SMALL_STATE(11430)] = 328045,
  [SMALL_STATE(11431)] = 328056,
  [SMALL_STATE(11432)] = 328067,
  [SMALL_STATE(11433)] = 328078,
  [SMALL_STATE(11434)] = 328089,
  [SMALL_STATE(11435)] = 328100,
  [SMALL_STATE(11436)] = 328111,
  [SMALL_STATE(11437)] = 328122,
  [SMALL_STATE(11438)] = 328133,
  [SMALL_STATE(11439)] = 328144,
  [SMALL_STATE(11440)] = 328155,
  [SMALL_STATE(11441)] = 328166,
  [SMALL_STATE(11442)] = 328177,
  [SMALL_STATE(11443)] = 328188,
  [SMALL_STATE(11444)] = 328199,
  [SMALL_STATE(11445)] = 328210,
  [SMALL_STATE(11446)] = 328221,
  [SMALL_STATE(11447)] = 328232,
  [SMALL_STATE(11448)] = 328243,
  [SMALL_STATE(11449)] = 328254,
  [SMALL_STATE(11450)] = 328265,
  [SMALL_STATE(11451)] = 328276,
  [SMALL_STATE(11452)] = 328287,
  [SMALL_STATE(11453)] = 328298,
  [SMALL_STATE(11454)] = 328309,
  [SMALL_STATE(11455)] = 328320,
  [SMALL_STATE(11456)] = 328331,
  [SMALL_STATE(11457)] = 328342,
  [SMALL_STATE(11458)] = 328353,
  [SMALL_STATE(11459)] = 328364,
  [SMALL_STATE(11460)] = 328375,
  [SMALL_STATE(11461)] = 328386,
  [SMALL_STATE(11462)] = 328397,
  [SMALL_STATE(11463)] = 328408,
  [SMALL_STATE(11464)] = 328419,
  [SMALL_STATE(11465)] = 328430,
  [SMALL_STATE(11466)] = 328441,
  [SMALL_STATE(11467)] = 328452,
  [SMALL_STATE(11468)] = 328463,
  [SMALL_STATE(11469)] = 328474,
  [SMALL_STATE(11470)] = 328485,
  [SMALL_STATE(11471)] = 328496,
  [SMALL_STATE(11472)] = 328507,
  [SMALL_STATE(11473)] = 328518,
  [SMALL_STATE(11474)] = 328529,
  [SMALL_STATE(11475)] = 328540,
  [SMALL_STATE(11476)] = 328551,
  [SMALL_STATE(11477)] = 328562,
  [SMALL_STATE(11478)] = 328573,
  [SMALL_STATE(11479)] = 328584,
  [SMALL_STATE(11480)] = 328595,
  [SMALL_STATE(11481)] = 328606,
  [SMALL_STATE(11482)] = 328617,
  [SMALL_STATE(11483)] = 328628,
  [SMALL_STATE(11484)] = 328639,
  [SMALL_STATE(11485)] = 328650,
  [SMALL_STATE(11486)] = 328661,
  [SMALL_STATE(11487)] = 328672,
  [SMALL_STATE(11488)] = 328683,
  [SMALL_STATE(11489)] = 328694,
  [SMALL_STATE(11490)] = 328705,
  [SMALL_STATE(11491)] = 328716,
  [SMALL_STATE(11492)] = 328727,
  [SMALL_STATE(11493)] = 328738,
  [SMALL_STATE(11494)] = 328749,
  [SMALL_STATE(11495)] = 328760,
  [SMALL_STATE(11496)] = 328771,
  [SMALL_STATE(11497)] = 328782,
  [SMALL_STATE(11498)] = 328793,
  [SMALL_STATE(11499)] = 328804,
  [SMALL_STATE(11500)] = 328815,
  [SMALL_STATE(11501)] = 328826,
  [SMALL_STATE(11502)] = 328837,
  [SMALL_STATE(11503)] = 328848,
  [SMALL_STATE(11504)] = 328859,
  [SMALL_STATE(11505)] = 328870,
  [SMALL_STATE(11506)] = 328881,
  [SMALL_STATE(11507)] = 328892,
  [SMALL_STATE(11508)] = 328903,
  [SMALL_STATE(11509)] = 328914,
  [SMALL_STATE(11510)] = 328925,
  [SMALL_STATE(11511)] = 328936,
  [SMALL_STATE(11512)] = 328947,
  [SMALL_STATE(11513)] = 328958,
  [SMALL_STATE(11514)] = 328969,
  [SMALL_STATE(11515)] = 328980,
  [SMALL_STATE(11516)] = 328991,
  [SMALL_STATE(11517)] = 329002,
  [SMALL_STATE(11518)] = 329013,
  [SMALL_STATE(11519)] = 329024,
  [SMALL_STATE(11520)] = 329035,
  [SMALL_STATE(11521)] = 329046,
  [SMALL_STATE(11522)] = 329057,
  [SMALL_STATE(11523)] = 329068,
  [SMALL_STATE(11524)] = 329079,
  [SMALL_STATE(11525)] = 329090,
  [SMALL_STATE(11526)] = 329101,
  [SMALL_STATE(11527)] = 329112,
  [SMALL_STATE(11528)] = 329123,
  [SMALL_STATE(11529)] = 329134,
  [SMALL_STATE(11530)] = 329145,
  [SMALL_STATE(11531)] = 329156,
  [SMALL_STATE(11532)] = 329167,
  [SMALL_STATE(11533)] = 329178,
  [SMALL_STATE(11534)] = 329189,
  [SMALL_STATE(11535)] = 329200,
  [SMALL_STATE(11536)] = 329211,
  [SMALL_STATE(11537)] = 329222,
  [SMALL_STATE(11538)] = 329233,
  [SMALL_STATE(11539)] = 329244,
  [SMALL_STATE(11540)] = 329255,
  [SMALL_STATE(11541)] = 329266,
  [SMALL_STATE(11542)] = 329277,
  [SMALL_STATE(11543)] = 329288,
  [SMALL_STATE(11544)] = 329299,
  [SMALL_STATE(11545)] = 329310,
  [SMALL_STATE(11546)] = 329321,
  [SMALL_STATE(11547)] = 329332,
  [SMALL_STATE(11548)] = 329343,
  [SMALL_STATE(11549)] = 329354,
  [SMALL_STATE(11550)] = 329365,
  [SMALL_STATE(11551)] = 329376,
  [SMALL_STATE(11552)] = 329387,
  [SMALL_STATE(11553)] = 329398,
  [SMALL_STATE(11554)] = 329409,
  [SMALL_STATE(11555)] = 329420,
  [SMALL_STATE(11556)] = 329431,
  [SMALL_STATE(11557)] = 329442,
  [SMALL_STATE(11558)] = 329453,
  [SMALL_STATE(11559)] = 329464,
  [SMALL_STATE(11560)] = 329475,
  [SMALL_STATE(11561)] = 329486,
  [SMALL_STATE(11562)] = 329497,
  [SMALL_STATE(11563)] = 329508,
  [SMALL_STATE(11564)] = 329519,
  [SMALL_STATE(11565)] = 329530,
  [SMALL_STATE(11566)] = 329541,
  [SMALL_STATE(11567)] = 329552,
  [SMALL_STATE(11568)] = 329563,
  [SMALL_STATE(11569)] = 329574,
  [SMALL_STATE(11570)] = 329585,
  [SMALL_STATE(11571)] = 329596,
  [SMALL_STATE(11572)] = 329607,
  [SMALL_STATE(11573)] = 329618,
  [SMALL_STATE(11574)] = 329629,
  [SMALL_STATE(11575)] = 329640,
  [SMALL_STATE(11576)] = 329651,
  [SMALL_STATE(11577)] = 329662,
  [SMALL_STATE(11578)] = 329673,
  [SMALL_STATE(11579)] = 329684,
  [SMALL_STATE(11580)] = 329695,
  [SMALL_STATE(11581)] = 329706,
  [SMALL_STATE(11582)] = 329717,
  [SMALL_STATE(11583)] = 329728,
  [SMALL_STATE(11584)] = 329739,
  [SMALL_STATE(11585)] = 329750,
  [SMALL_STATE(11586)] = 329761,
  [SMALL_STATE(11587)] = 329772,
  [SMALL_STATE(11588)] = 329783,
  [SMALL_STATE(11589)] = 329794,
  [SMALL_STATE(11590)] = 329805,
  [SMALL_STATE(11591)] = 329816,
  [SMALL_STATE(11592)] = 329827,
  [SMALL_STATE(11593)] = 329838,
  [SMALL_STATE(11594)] = 329849,
  [SMALL_STATE(11595)] = 329860,
  [SMALL_STATE(11596)] = 329871,
  [SMALL_STATE(11597)] = 329882,
  [SMALL_STATE(11598)] = 329893,
  [SMALL_STATE(11599)] = 329904,
  [SMALL_STATE(11600)] = 329915,
  [SMALL_STATE(11601)] = 329926,
  [SMALL_STATE(11602)] = 329937,
  [SMALL_STATE(11603)] = 329948,
  [SMALL_STATE(11604)] = 329959,
  [SMALL_STATE(11605)] = 329970,
  [SMALL_STATE(11606)] = 329981,
  [SMALL_STATE(11607)] = 329992,
  [SMALL_STATE(11608)] = 330003,
  [SMALL_STATE(11609)] = 330014,
  [SMALL_STATE(11610)] = 330025,
  [SMALL_STATE(11611)] = 330036,
  [SMALL_STATE(11612)] = 330047,
  [SMALL_STATE(11613)] = 330058,
  [SMALL_STATE(11614)] = 330069,
  [SMALL_STATE(11615)] = 330080,
  [SMALL_STATE(11616)] = 330091,
  [SMALL_STATE(11617)] = 330102,
  [SMALL_STATE(11618)] = 330113,
  [SMALL_STATE(11619)] = 330124,
  [SMALL_STATE(11620)] = 330135,
  [SMALL_STATE(11621)] = 330146,
  [SMALL_STATE(11622)] = 330157,
  [SMALL_STATE(11623)] = 330168,
  [SMALL_STATE(11624)] = 330179,
  [SMALL_STATE(11625)] = 330190,
  [SMALL_STATE(11626)] = 330201,
  [SMALL_STATE(11627)] = 330212,
  [SMALL_STATE(11628)] = 330223,
  [SMALL_STATE(11629)] = 330234,
  [SMALL_STATE(11630)] = 330245,
  [SMALL_STATE(11631)] = 330256,
  [SMALL_STATE(11632)] = 330267,
  [SMALL_STATE(11633)] = 330278,
  [SMALL_STATE(11634)] = 330289,
  [SMALL_STATE(11635)] = 330300,
  [SMALL_STATE(11636)] = 330311,
  [SMALL_STATE(11637)] = 330322,
  [SMALL_STATE(11638)] = 330333,
  [SMALL_STATE(11639)] = 330344,
  [SMALL_STATE(11640)] = 330355,
  [SMALL_STATE(11641)] = 330366,
  [SMALL_STATE(11642)] = 330377,
  [SMALL_STATE(11643)] = 330388,
  [SMALL_STATE(11644)] = 330399,
  [SMALL_STATE(11645)] = 330410,
  [SMALL_STATE(11646)] = 330421,
  [SMALL_STATE(11647)] = 330432,
  [SMALL_STATE(11648)] = 330443,
  [SMALL_STATE(11649)] = 330454,
  [SMALL_STATE(11650)] = 330465,
  [SMALL_STATE(11651)] = 330476,
  [SMALL_STATE(11652)] = 330487,
  [SMALL_STATE(11653)] = 330498,
  [SMALL_STATE(11654)] = 330509,
  [SMALL_STATE(11655)] = 330520,
  [SMALL_STATE(11656)] = 330531,
  [SMALL_STATE(11657)] = 330542,
  [SMALL_STATE(11658)] = 330553,
  [SMALL_STATE(11659)] = 330564,
  [SMALL_STATE(11660)] = 330575,
  [SMALL_STATE(11661)] = 330586,
  [SMALL_STATE(11662)] = 330597,
  [SMALL_STATE(11663)] = 330608,
  [SMALL_STATE(11664)] = 330619,
  [SMALL_STATE(11665)] = 330630,
  [SMALL_STATE(11666)] = 330641,
  [SMALL_STATE(11667)] = 330652,
  [SMALL_STATE(11668)] = 330663,
  [SMALL_STATE(11669)] = 330674,
  [SMALL_STATE(11670)] = 330685,
  [SMALL_STATE(11671)] = 330696,
  [SMALL_STATE(11672)] = 330707,
  [SMALL_STATE(11673)] = 330718,
  [SMALL_STATE(11674)] = 330729,
  [SMALL_STATE(11675)] = 330740,
  [SMALL_STATE(11676)] = 330751,
  [SMALL_STATE(11677)] = 330762,
  [SMALL_STATE(11678)] = 330773,
  [SMALL_STATE(11679)] = 330784,
  [SMALL_STATE(11680)] = 330795,
  [SMALL_STATE(11681)] = 330806,
  [SMALL_STATE(11682)] = 330817,
  [SMALL_STATE(11683)] = 330828,
  [SMALL_STATE(11684)] = 330839,
  [SMALL_STATE(11685)] = 330850,
  [SMALL_STATE(11686)] = 330861,
  [SMALL_STATE(11687)] = 330872,
  [SMALL_STATE(11688)] = 330883,
  [SMALL_STATE(11689)] = 330894,
  [SMALL_STATE(11690)] = 330905,
  [SMALL_STATE(11691)] = 330916,
  [SMALL_STATE(11692)] = 330927,
  [SMALL_STATE(11693)] = 330938,
  [SMALL_STATE(11694)] = 330949,
  [SMALL_STATE(11695)] = 330960,
  [SMALL_STATE(11696)] = 330971,
  [SMALL_STATE(11697)] = 330982,
  [SMALL_STATE(11698)] = 330993,
  [SMALL_STATE(11699)] = 331004,
  [SMALL_STATE(11700)] = 331015,
  [SMALL_STATE(11701)] = 331026,
  [SMALL_STATE(11702)] = 331037,
  [SMALL_STATE(11703)] = 331048,
  [SMALL_STATE(11704)] = 331059,
  [SMALL_STATE(11705)] = 331070,
  [SMALL_STATE(11706)] = 331081,
  [SMALL_STATE(11707)] = 331092,
  [SMALL_STATE(11708)] = 331103,
  [SMALL_STATE(11709)] = 331114,
  [SMALL_STATE(11710)] = 331125,
  [SMALL_STATE(11711)] = 331136,
  [SMALL_STATE(11712)] = 331147,
  [SMALL_STATE(11713)] = 331158,
  [SMALL_STATE(11714)] = 331169,
  [SMALL_STATE(11715)] = 331180,
  [SMALL_STATE(11716)] = 331191,
  [SMALL_STATE(11717)] = 331202,
  [SMALL_STATE(11718)] = 331213,
  [SMALL_STATE(11719)] = 331224,
  [SMALL_STATE(11720)] = 331235,
  [SMALL_STATE(11721)] = 331246,
  [SMALL_STATE(11722)] = 331257,
  [SMALL_STATE(11723)] = 331268,
  [SMALL_STATE(11724)] = 331279,
  [SMALL_STATE(11725)] = 331290,
  [SMALL_STATE(11726)] = 331301,
  [SMALL_STATE(11727)] = 331312,
  [SMALL_STATE(11728)] = 331323,
  [SMALL_STATE(11729)] = 331334,
  [SMALL_STATE(11730)] = 331345,
  [SMALL_STATE(11731)] = 331356,
  [SMALL_STATE(11732)] = 331367,
  [SMALL_STATE(11733)] = 331378,
  [SMALL_STATE(11734)] = 331389,
  [SMALL_STATE(11735)] = 331400,
  [SMALL_STATE(11736)] = 331411,
  [SMALL_STATE(11737)] = 331422,
  [SMALL_STATE(11738)] = 331433,
  [SMALL_STATE(11739)] = 331444,
  [SMALL_STATE(11740)] = 331455,
  [SMALL_STATE(11741)] = 331466,
  [SMALL_STATE(11742)] = 331477,
  [SMALL_STATE(11743)] = 331488,
  [SMALL_STATE(11744)] = 331499,
  [SMALL_STATE(11745)] = 331510,
  [SMALL_STATE(11746)] = 331521,
  [SMALL_STATE(11747)] = 331532,
  [SMALL_STATE(11748)] = 331543,
  [SMALL_STATE(11749)] = 331554,
  [SMALL_STATE(11750)] = 331565,
  [SMALL_STATE(11751)] = 331576,
  [SMALL_STATE(11752)] = 331587,
  [SMALL_STATE(11753)] = 331598,
  [SMALL_STATE(11754)] = 331609,
  [SMALL_STATE(11755)] = 331620,
  [SMALL_STATE(11756)] = 331631,
  [SMALL_STATE(11757)] = 331642,
  [SMALL_STATE(11758)] = 331653,
  [SMALL_STATE(11759)] = 331664,
  [SMALL_STATE(11760)] = 331675,
  [SMALL_STATE(11761)] = 331686,
  [SMALL_STATE(11762)] = 331697,
  [SMALL_STATE(11763)] = 331708,
  [SMALL_STATE(11764)] = 331719,
  [SMALL_STATE(11765)] = 331730,
  [SMALL_STATE(11766)] = 331741,
  [SMALL_STATE(11767)] = 331752,
  [SMALL_STATE(11768)] = 331763,
  [SMALL_STATE(11769)] = 331774,
  [SMALL_STATE(11770)] = 331785,
  [SMALL_STATE(11771)] = 331796,
  [SMALL_STATE(11772)] = 331807,
  [SMALL_STATE(11773)] = 331818,
  [SMALL_STATE(11774)] = 331829,
  [SMALL_STATE(11775)] = 331840,
  [SMALL_STATE(11776)] = 331851,
  [SMALL_STATE(11777)] = 331862,
  [SMALL_STATE(11778)] = 331873,
  [SMALL_STATE(11779)] = 331884,
  [SMALL_STATE(11780)] = 331895,
  [SMALL_STATE(11781)] = 331906,
  [SMALL_STATE(11782)] = 331917,
  [SMALL_STATE(11783)] = 331928,
  [SMALL_STATE(11784)] = 331939,
  [SMALL_STATE(11785)] = 331950,
  [SMALL_STATE(11786)] = 331961,
  [SMALL_STATE(11787)] = 331972,
  [SMALL_STATE(11788)] = 331983,
  [SMALL_STATE(11789)] = 331994,
  [SMALL_STATE(11790)] = 332005,
  [SMALL_STATE(11791)] = 332016,
  [SMALL_STATE(11792)] = 332027,
  [SMALL_STATE(11793)] = 332038,
  [SMALL_STATE(11794)] = 332049,
  [SMALL_STATE(11795)] = 332060,
  [SMALL_STATE(11796)] = 332071,
  [SMALL_STATE(11797)] = 332082,
  [SMALL_STATE(11798)] = 332093,
  [SMALL_STATE(11799)] = 332104,
  [SMALL_STATE(11800)] = 332115,
  [SMALL_STATE(11801)] = 332126,
  [SMALL_STATE(11802)] = 332137,
  [SMALL_STATE(11803)] = 332148,
  [SMALL_STATE(11804)] = 332159,
  [SMALL_STATE(11805)] = 332170,
  [SMALL_STATE(11806)] = 332181,
  [SMALL_STATE(11807)] = 332192,
  [SMALL_STATE(11808)] = 332203,
  [SMALL_STATE(11809)] = 332214,
  [SMALL_STATE(11810)] = 332225,
  [SMALL_STATE(11811)] = 332236,
  [SMALL_STATE(11812)] = 332247,
  [SMALL_STATE(11813)] = 332258,
  [SMALL_STATE(11814)] = 332269,
  [SMALL_STATE(11815)] = 332280,
  [SMALL_STATE(11816)] = 332291,
  [SMALL_STATE(11817)] = 332302,
  [SMALL_STATE(11818)] = 332313,
  [SMALL_STATE(11819)] = 332324,
  [SMALL_STATE(11820)] = 332335,
  [SMALL_STATE(11821)] = 332346,
  [SMALL_STATE(11822)] = 332357,
  [SMALL_STATE(11823)] = 332368,
  [SMALL_STATE(11824)] = 332379,
  [SMALL_STATE(11825)] = 332390,
  [SMALL_STATE(11826)] = 332401,
  [SMALL_STATE(11827)] = 332412,
  [SMALL_STATE(11828)] = 332423,
  [SMALL_STATE(11829)] = 332434,
  [SMALL_STATE(11830)] = 332445,
  [SMALL_STATE(11831)] = 332456,
  [SMALL_STATE(11832)] = 332467,
  [SMALL_STATE(11833)] = 332478,
  [SMALL_STATE(11834)] = 332489,
  [SMALL_STATE(11835)] = 332500,
  [SMALL_STATE(11836)] = 332511,
  [SMALL_STATE(11837)] = 332522,
  [SMALL_STATE(11838)] = 332533,
  [SMALL_STATE(11839)] = 332544,
  [SMALL_STATE(11840)] = 332555,
  [SMALL_STATE(11841)] = 332566,
  [SMALL_STATE(11842)] = 332577,
  [SMALL_STATE(11843)] = 332588,
  [SMALL_STATE(11844)] = 332599,
  [SMALL_STATE(11845)] = 332610,
  [SMALL_STATE(11846)] = 332621,
  [SMALL_STATE(11847)] = 332632,
  [SMALL_STATE(11848)] = 332643,
  [SMALL_STATE(11849)] = 332654,
  [SMALL_STATE(11850)] = 332665,
  [SMALL_STATE(11851)] = 332676,
  [SMALL_STATE(11852)] = 332687,
  [SMALL_STATE(11853)] = 332698,
  [SMALL_STATE(11854)] = 332709,
  [SMALL_STATE(11855)] = 332720,
  [SMALL_STATE(11856)] = 332731,
  [SMALL_STATE(11857)] = 332742,
  [SMALL_STATE(11858)] = 332753,
  [SMALL_STATE(11859)] = 332764,
  [SMALL_STATE(11860)] = 332775,
  [SMALL_STATE(11861)] = 332786,
  [SMALL_STATE(11862)] = 332797,
  [SMALL_STATE(11863)] = 332808,
  [SMALL_STATE(11864)] = 332819,
  [SMALL_STATE(11865)] = 332830,
  [SMALL_STATE(11866)] = 332841,
  [SMALL_STATE(11867)] = 332852,
  [SMALL_STATE(11868)] = 332863,
  [SMALL_STATE(11869)] = 332874,
  [SMALL_STATE(11870)] = 332885,
  [SMALL_STATE(11871)] = 332896,
  [SMALL_STATE(11872)] = 332907,
  [SMALL_STATE(11873)] = 332918,
  [SMALL_STATE(11874)] = 332929,
  [SMALL_STATE(11875)] = 332940,
  [SMALL_STATE(11876)] = 332951,
  [SMALL_STATE(11877)] = 332962,
  [SMALL_STATE(11878)] = 332973,
  [SMALL_STATE(11879)] = 332984,
  [SMALL_STATE(11880)] = 332995,
  [SMALL_STATE(11881)] = 333006,
  [SMALL_STATE(11882)] = 333017,
  [SMALL_STATE(11883)] = 333028,
  [SMALL_STATE(11884)] = 333039,
  [SMALL_STATE(11885)] = 333050,
  [SMALL_STATE(11886)] = 333061,
  [SMALL_STATE(11887)] = 333072,
  [SMALL_STATE(11888)] = 333083,
  [SMALL_STATE(11889)] = 333094,
  [SMALL_STATE(11890)] = 333105,
  [SMALL_STATE(11891)] = 333116,
  [SMALL_STATE(11892)] = 333127,
  [SMALL_STATE(11893)] = 333138,
  [SMALL_STATE(11894)] = 333149,
  [SMALL_STATE(11895)] = 333160,
  [SMALL_STATE(11896)] = 333171,
  [SMALL_STATE(11897)] = 333182,
  [SMALL_STATE(11898)] = 333193,
  [SMALL_STATE(11899)] = 333204,
  [SMALL_STATE(11900)] = 333215,
  [SMALL_STATE(11901)] = 333226,
  [SMALL_STATE(11902)] = 333237,
  [SMALL_STATE(11903)] = 333248,
  [SMALL_STATE(11904)] = 333259,
  [SMALL_STATE(11905)] = 333270,
  [SMALL_STATE(11906)] = 333281,
  [SMALL_STATE(11907)] = 333292,
  [SMALL_STATE(11908)] = 333303,
  [SMALL_STATE(11909)] = 333314,
  [SMALL_STATE(11910)] = 333325,
  [SMALL_STATE(11911)] = 333336,
  [SMALL_STATE(11912)] = 333347,
  [SMALL_STATE(11913)] = 333358,
  [SMALL_STATE(11914)] = 333369,
  [SMALL_STATE(11915)] = 333380,
  [SMALL_STATE(11916)] = 333391,
  [SMALL_STATE(11917)] = 333402,
  [SMALL_STATE(11918)] = 333413,
  [SMALL_STATE(11919)] = 333424,
  [SMALL_STATE(11920)] = 333435,
  [SMALL_STATE(11921)] = 333446,
  [SMALL_STATE(11922)] = 333457,
  [SMALL_STATE(11923)] = 333468,
  [SMALL_STATE(11924)] = 333479,
  [SMALL_STATE(11925)] = 333490,
  [SMALL_STATE(11926)] = 333501,
  [SMALL_STATE(11927)] = 333512,
  [SMALL_STATE(11928)] = 333523,
  [SMALL_STATE(11929)] = 333534,
  [SMALL_STATE(11930)] = 333545,
  [SMALL_STATE(11931)] = 333556,
  [SMALL_STATE(11932)] = 333567,
  [SMALL_STATE(11933)] = 333578,
  [SMALL_STATE(11934)] = 333589,
  [SMALL_STATE(11935)] = 333600,
  [SMALL_STATE(11936)] = 333611,
  [SMALL_STATE(11937)] = 333622,
  [SMALL_STATE(11938)] = 333633,
  [SMALL_STATE(11939)] = 333644,
  [SMALL_STATE(11940)] = 333655,
  [SMALL_STATE(11941)] = 333666,
  [SMALL_STATE(11942)] = 333677,
  [SMALL_STATE(11943)] = 333688,
  [SMALL_STATE(11944)] = 333699,
  [SMALL_STATE(11945)] = 333710,
  [SMALL_STATE(11946)] = 333721,
  [SMALL_STATE(11947)] = 333732,
  [SMALL_STATE(11948)] = 333743,
  [SMALL_STATE(11949)] = 333754,
  [SMALL_STATE(11950)] = 333765,
  [SMALL_STATE(11951)] = 333776,
  [SMALL_STATE(11952)] = 333787,
  [SMALL_STATE(11953)] = 333798,
  [SMALL_STATE(11954)] = 333809,
  [SMALL_STATE(11955)] = 333820,
  [SMALL_STATE(11956)] = 333831,
  [SMALL_STATE(11957)] = 333842,
  [SMALL_STATE(11958)] = 333853,
  [SMALL_STATE(11959)] = 333864,
  [SMALL_STATE(11960)] = 333875,
  [SMALL_STATE(11961)] = 333886,
  [SMALL_STATE(11962)] = 333897,
  [SMALL_STATE(11963)] = 333908,
  [SMALL_STATE(11964)] = 333919,
  [SMALL_STATE(11965)] = 333930,
  [SMALL_STATE(11966)] = 333941,
  [SMALL_STATE(11967)] = 333952,
  [SMALL_STATE(11968)] = 333963,
  [SMALL_STATE(11969)] = 333974,
  [SMALL_STATE(11970)] = 333985,
  [SMALL_STATE(11971)] = 333996,
  [SMALL_STATE(11972)] = 334007,
  [SMALL_STATE(11973)] = 334018,
  [SMALL_STATE(11974)] = 334029,
  [SMALL_STATE(11975)] = 334040,
  [SMALL_STATE(11976)] = 334051,
  [SMALL_STATE(11977)] = 334062,
  [SMALL_STATE(11978)] = 334073,
  [SMALL_STATE(11979)] = 334084,
  [SMALL_STATE(11980)] = 334095,
  [SMALL_STATE(11981)] = 334106,
  [SMALL_STATE(11982)] = 334117,
  [SMALL_STATE(11983)] = 334128,
  [SMALL_STATE(11984)] = 334139,
  [SMALL_STATE(11985)] = 334150,
  [SMALL_STATE(11986)] = 334161,
  [SMALL_STATE(11987)] = 334172,
  [SMALL_STATE(11988)] = 334183,
  [SMALL_STATE(11989)] = 334194,
  [SMALL_STATE(11990)] = 334205,
  [SMALL_STATE(11991)] = 334216,
  [SMALL_STATE(11992)] = 334227,
  [SMALL_STATE(11993)] = 334238,
  [SMALL_STATE(11994)] = 334249,
  [SMALL_STATE(11995)] = 334260,
  [SMALL_STATE(11996)] = 334271,
  [SMALL_STATE(11997)] = 334282,
  [SMALL_STATE(11998)] = 334293,
  [SMALL_STATE(11999)] = 334304,
  [SMALL_STATE(12000)] = 334315,
  [SMALL_STATE(12001)] = 334326,
  [SMALL_STATE(12002)] = 334337,
  [SMALL_STATE(12003)] = 334348,
  [SMALL_STATE(12004)] = 334359,
  [SMALL_STATE(12005)] = 334370,
  [SMALL_STATE(12006)] = 334381,
  [SMALL_STATE(12007)] = 334392,
  [SMALL_STATE(12008)] = 334403,
  [SMALL_STATE(12009)] = 334414,
  [SMALL_STATE(12010)] = 334425,
  [SMALL_STATE(12011)] = 334436,
  [SMALL_STATE(12012)] = 334447,
  [SMALL_STATE(12013)] = 334458,
  [SMALL_STATE(12014)] = 334469,
  [SMALL_STATE(12015)] = 334480,
  [SMALL_STATE(12016)] = 334491,
  [SMALL_STATE(12017)] = 334502,
  [SMALL_STATE(12018)] = 334513,
  [SMALL_STATE(12019)] = 334524,
  [SMALL_STATE(12020)] = 334535,
  [SMALL_STATE(12021)] = 334546,
  [SMALL_STATE(12022)] = 334557,
  [SMALL_STATE(12023)] = 334568,
  [SMALL_STATE(12024)] = 334579,
  [SMALL_STATE(12025)] = 334590,
  [SMALL_STATE(12026)] = 334601,
  [SMALL_STATE(12027)] = 334612,
  [SMALL_STATE(12028)] = 334623,
  [SMALL_STATE(12029)] = 334634,
  [SMALL_STATE(12030)] = 334645,
  [SMALL_STATE(12031)] = 334656,
  [SMALL_STATE(12032)] = 334667,
  [SMALL_STATE(12033)] = 334678,
  [SMALL_STATE(12034)] = 334689,
  [SMALL_STATE(12035)] = 334700,
  [SMALL_STATE(12036)] = 334711,
  [SMALL_STATE(12037)] = 334722,
  [SMALL_STATE(12038)] = 334733,
  [SMALL_STATE(12039)] = 334744,
  [SMALL_STATE(12040)] = 334755,
  [SMALL_STATE(12041)] = 334766,
  [SMALL_STATE(12042)] = 334777,
  [SMALL_STATE(12043)] = 334788,
  [SMALL_STATE(12044)] = 334799,
  [SMALL_STATE(12045)] = 334810,
  [SMALL_STATE(12046)] = 334821,
  [SMALL_STATE(12047)] = 334832,
  [SMALL_STATE(12048)] = 334843,
  [SMALL_STATE(12049)] = 334854,
  [SMALL_STATE(12050)] = 334865,
  [SMALL_STATE(12051)] = 334876,
  [SMALL_STATE(12052)] = 334887,
  [SMALL_STATE(12053)] = 334898,
  [SMALL_STATE(12054)] = 334909,
  [SMALL_STATE(12055)] = 334920,
  [SMALL_STATE(12056)] = 334931,
  [SMALL_STATE(12057)] = 334942,
  [SMALL_STATE(12058)] = 334953,
  [SMALL_STATE(12059)] = 334964,
  [SMALL_STATE(12060)] = 334975,
  [SMALL_STATE(12061)] = 334986,
  [SMALL_STATE(12062)] = 334997,
  [SMALL_STATE(12063)] = 335008,
  [SMALL_STATE(12064)] = 335019,
  [SMALL_STATE(12065)] = 335030,
  [SMALL_STATE(12066)] = 335041,
  [SMALL_STATE(12067)] = 335052,
  [SMALL_STATE(12068)] = 335063,
  [SMALL_STATE(12069)] = 335074,
  [SMALL_STATE(12070)] = 335085,
  [SMALL_STATE(12071)] = 335096,
  [SMALL_STATE(12072)] = 335107,
  [SMALL_STATE(12073)] = 335118,
  [SMALL_STATE(12074)] = 335129,
  [SMALL_STATE(12075)] = 335140,
  [SMALL_STATE(12076)] = 335151,
  [SMALL_STATE(12077)] = 335162,
  [SMALL_STATE(12078)] = 335173,
  [SMALL_STATE(12079)] = 335184,
  [SMALL_STATE(12080)] = 335195,
  [SMALL_STATE(12081)] = 335206,
  [SMALL_STATE(12082)] = 335217,
  [SMALL_STATE(12083)] = 335228,
  [SMALL_STATE(12084)] = 335239,
  [SMALL_STATE(12085)] = 335250,
  [SMALL_STATE(12086)] = 335261,
  [SMALL_STATE(12087)] = 335272,
  [SMALL_STATE(12088)] = 335283,
  [SMALL_STATE(12089)] = 335294,
  [SMALL_STATE(12090)] = 335305,
  [SMALL_STATE(12091)] = 335316,
  [SMALL_STATE(12092)] = 335327,
  [SMALL_STATE(12093)] = 335338,
  [SMALL_STATE(12094)] = 335349,
  [SMALL_STATE(12095)] = 335360,
  [SMALL_STATE(12096)] = 335371,
  [SMALL_STATE(12097)] = 335382,
  [SMALL_STATE(12098)] = 335393,
  [SMALL_STATE(12099)] = 335404,
  [SMALL_STATE(12100)] = 335415,
  [SMALL_STATE(12101)] = 335426,
  [SMALL_STATE(12102)] = 335437,
  [SMALL_STATE(12103)] = 335448,
  [SMALL_STATE(12104)] = 335459,
  [SMALL_STATE(12105)] = 335470,
  [SMALL_STATE(12106)] = 335481,
  [SMALL_STATE(12107)] = 335492,
  [SMALL_STATE(12108)] = 335503,
  [SMALL_STATE(12109)] = 335514,
  [SMALL_STATE(12110)] = 335525,
  [SMALL_STATE(12111)] = 335536,
  [SMALL_STATE(12112)] = 335547,
  [SMALL_STATE(12113)] = 335558,
  [SMALL_STATE(12114)] = 335569,
  [SMALL_STATE(12115)] = 335580,
  [SMALL_STATE(12116)] = 335591,
  [SMALL_STATE(12117)] = 335602,
  [SMALL_STATE(12118)] = 335613,
  [SMALL_STATE(12119)] = 335624,
  [SMALL_STATE(12120)] = 335635,
  [SMALL_STATE(12121)] = 335646,
  [SMALL_STATE(12122)] = 335657,
  [SMALL_STATE(12123)] = 335668,
  [SMALL_STATE(12124)] = 335679,
  [SMALL_STATE(12125)] = 335690,
  [SMALL_STATE(12126)] = 335701,
  [SMALL_STATE(12127)] = 335712,
  [SMALL_STATE(12128)] = 335723,
  [SMALL_STATE(12129)] = 335734,
  [SMALL_STATE(12130)] = 335745,
  [SMALL_STATE(12131)] = 335756,
  [SMALL_STATE(12132)] = 335767,
  [SMALL_STATE(12133)] = 335778,
  [SMALL_STATE(12134)] = 335789,
  [SMALL_STATE(12135)] = 335800,
  [SMALL_STATE(12136)] = 335811,
  [SMALL_STATE(12137)] = 335822,
  [SMALL_STATE(12138)] = 335833,
  [SMALL_STATE(12139)] = 335844,
  [SMALL_STATE(12140)] = 335855,
  [SMALL_STATE(12141)] = 335866,
  [SMALL_STATE(12142)] = 335877,
  [SMALL_STATE(12143)] = 335888,
  [SMALL_STATE(12144)] = 335899,
  [SMALL_STATE(12145)] = 335910,
  [SMALL_STATE(12146)] = 335921,
  [SMALL_STATE(12147)] = 335932,
  [SMALL_STATE(12148)] = 335943,
  [SMALL_STATE(12149)] = 335954,
  [SMALL_STATE(12150)] = 335965,
  [SMALL_STATE(12151)] = 335976,
  [SMALL_STATE(12152)] = 335987,
  [SMALL_STATE(12153)] = 335998,
  [SMALL_STATE(12154)] = 336009,
  [SMALL_STATE(12155)] = 336020,
  [SMALL_STATE(12156)] = 336031,
  [SMALL_STATE(12157)] = 336042,
  [SMALL_STATE(12158)] = 336053,
  [SMALL_STATE(12159)] = 336064,
  [SMALL_STATE(12160)] = 336075,
  [SMALL_STATE(12161)] = 336086,
  [SMALL_STATE(12162)] = 336097,
  [SMALL_STATE(12163)] = 336108,
  [SMALL_STATE(12164)] = 336119,
  [SMALL_STATE(12165)] = 336130,
  [SMALL_STATE(12166)] = 336141,
  [SMALL_STATE(12167)] = 336152,
  [SMALL_STATE(12168)] = 336163,
  [SMALL_STATE(12169)] = 336174,
  [SMALL_STATE(12170)] = 336185,
  [SMALL_STATE(12171)] = 336196,
  [SMALL_STATE(12172)] = 336207,
  [SMALL_STATE(12173)] = 336218,
  [SMALL_STATE(12174)] = 336229,
  [SMALL_STATE(12175)] = 336240,
  [SMALL_STATE(12176)] = 336251,
  [SMALL_STATE(12177)] = 336262,
  [SMALL_STATE(12178)] = 336273,
  [SMALL_STATE(12179)] = 336284,
  [SMALL_STATE(12180)] = 336295,
  [SMALL_STATE(12181)] = 336306,
  [SMALL_STATE(12182)] = 336317,
  [SMALL_STATE(12183)] = 336328,
  [SMALL_STATE(12184)] = 336339,
  [SMALL_STATE(12185)] = 336350,
  [SMALL_STATE(12186)] = 336361,
  [SMALL_STATE(12187)] = 336372,
  [SMALL_STATE(12188)] = 336383,
  [SMALL_STATE(12189)] = 336394,
  [SMALL_STATE(12190)] = 336405,
  [SMALL_STATE(12191)] = 336416,
  [SMALL_STATE(12192)] = 336427,
  [SMALL_STATE(12193)] = 336438,
  [SMALL_STATE(12194)] = 336449,
  [SMALL_STATE(12195)] = 336460,
  [SMALL_STATE(12196)] = 336471,
  [SMALL_STATE(12197)] = 336482,
  [SMALL_STATE(12198)] = 336493,
  [SMALL_STATE(12199)] = 336504,
  [SMALL_STATE(12200)] = 336515,
  [SMALL_STATE(12201)] = 336526,
  [SMALL_STATE(12202)] = 336537,
  [SMALL_STATE(12203)] = 336548,
  [SMALL_STATE(12204)] = 336559,
  [SMALL_STATE(12205)] = 336570,
  [SMALL_STATE(12206)] = 336581,
  [SMALL_STATE(12207)] = 336592,
  [SMALL_STATE(12208)] = 336603,
  [SMALL_STATE(12209)] = 336614,
  [SMALL_STATE(12210)] = 336625,
  [SMALL_STATE(12211)] = 336636,
  [SMALL_STATE(12212)] = 336647,
  [SMALL_STATE(12213)] = 336658,
  [SMALL_STATE(12214)] = 336669,
  [SMALL_STATE(12215)] = 336680,
  [SMALL_STATE(12216)] = 336691,
  [SMALL_STATE(12217)] = 336702,
  [SMALL_STATE(12218)] = 336713,
  [SMALL_STATE(12219)] = 336724,
  [SMALL_STATE(12220)] = 336735,
  [SMALL_STATE(12221)] = 336746,
  [SMALL_STATE(12222)] = 336757,
  [SMALL_STATE(12223)] = 336768,
  [SMALL_STATE(12224)] = 336779,
  [SMALL_STATE(12225)] = 336790,
  [SMALL_STATE(12226)] = 336801,
  [SMALL_STATE(12227)] = 336812,
  [SMALL_STATE(12228)] = 336823,
  [SMALL_STATE(12229)] = 336834,
  [SMALL_STATE(12230)] = 336845,
  [SMALL_STATE(12231)] = 336856,
  [SMALL_STATE(12232)] = 336867,
  [SMALL_STATE(12233)] = 336878,
  [SMALL_STATE(12234)] = 336889,
  [SMALL_STATE(12235)] = 336900,
  [SMALL_STATE(12236)] = 336911,
  [SMALL_STATE(12237)] = 336922,
  [SMALL_STATE(12238)] = 336933,
  [SMALL_STATE(12239)] = 336944,
  [SMALL_STATE(12240)] = 336955,
  [SMALL_STATE(12241)] = 336966,
  [SMALL_STATE(12242)] = 336977,
  [SMALL_STATE(12243)] = 336988,
  [SMALL_STATE(12244)] = 336999,
  [SMALL_STATE(12245)] = 337010,
  [SMALL_STATE(12246)] = 337021,
  [SMALL_STATE(12247)] = 337032,
  [SMALL_STATE(12248)] = 337043,
  [SMALL_STATE(12249)] = 337054,
  [SMALL_STATE(12250)] = 337065,
  [SMALL_STATE(12251)] = 337076,
  [SMALL_STATE(12252)] = 337087,
  [SMALL_STATE(12253)] = 337098,
  [SMALL_STATE(12254)] = 337109,
  [SMALL_STATE(12255)] = 337120,
  [SMALL_STATE(12256)] = 337131,
  [SMALL_STATE(12257)] = 337142,
  [SMALL_STATE(12258)] = 337153,
  [SMALL_STATE(12259)] = 337164,
  [SMALL_STATE(12260)] = 337175,
  [SMALL_STATE(12261)] = 337186,
  [SMALL_STATE(12262)] = 337197,
  [SMALL_STATE(12263)] = 337208,
  [SMALL_STATE(12264)] = 337219,
  [SMALL_STATE(12265)] = 337230,
  [SMALL_STATE(12266)] = 337241,
  [SMALL_STATE(12267)] = 337252,
  [SMALL_STATE(12268)] = 337263,
  [SMALL_STATE(12269)] = 337274,
  [SMALL_STATE(12270)] = 337285,
  [SMALL_STATE(12271)] = 337296,
  [SMALL_STATE(12272)] = 337307,
  [SMALL_STATE(12273)] = 337318,
  [SMALL_STATE(12274)] = 337329,
  [SMALL_STATE(12275)] = 337340,
  [SMALL_STATE(12276)] = 337351,
  [SMALL_STATE(12277)] = 337362,
  [SMALL_STATE(12278)] = 337373,
  [SMALL_STATE(12279)] = 337384,
  [SMALL_STATE(12280)] = 337395,
  [SMALL_STATE(12281)] = 337406,
  [SMALL_STATE(12282)] = 337417,
  [SMALL_STATE(12283)] = 337428,
  [SMALL_STATE(12284)] = 337439,
  [SMALL_STATE(12285)] = 337450,
  [SMALL_STATE(12286)] = 337461,
  [SMALL_STATE(12287)] = 337472,
  [SMALL_STATE(12288)] = 337483,
  [SMALL_STATE(12289)] = 337494,
  [SMALL_STATE(12290)] = 337505,
  [SMALL_STATE(12291)] = 337516,
  [SMALL_STATE(12292)] = 337527,
  [SMALL_STATE(12293)] = 337538,
  [SMALL_STATE(12294)] = 337549,
  [SMALL_STATE(12295)] = 337560,
  [SMALL_STATE(12296)] = 337571,
  [SMALL_STATE(12297)] = 337582,
  [SMALL_STATE(12298)] = 337593,
  [SMALL_STATE(12299)] = 337604,
  [SMALL_STATE(12300)] = 337615,
  [SMALL_STATE(12301)] = 337626,
  [SMALL_STATE(12302)] = 337637,
  [SMALL_STATE(12303)] = 337648,
  [SMALL_STATE(12304)] = 337659,
  [SMALL_STATE(12305)] = 337670,
  [SMALL_STATE(12306)] = 337681,
  [SMALL_STATE(12307)] = 337692,
  [SMALL_STATE(12308)] = 337703,
  [SMALL_STATE(12309)] = 337714,
  [SMALL_STATE(12310)] = 337725,
  [SMALL_STATE(12311)] = 337736,
  [SMALL_STATE(12312)] = 337747,
  [SMALL_STATE(12313)] = 337758,
  [SMALL_STATE(12314)] = 337769,
  [SMALL_STATE(12315)] = 337780,
  [SMALL_STATE(12316)] = 337791,
  [SMALL_STATE(12317)] = 337802,
  [SMALL_STATE(12318)] = 337813,
  [SMALL_STATE(12319)] = 337824,
  [SMALL_STATE(12320)] = 337835,
  [SMALL_STATE(12321)] = 337846,
  [SMALL_STATE(12322)] = 337857,
  [SMALL_STATE(12323)] = 337868,
  [SMALL_STATE(12324)] = 337879,
  [SMALL_STATE(12325)] = 337890,
  [SMALL_STATE(12326)] = 337901,
  [SMALL_STATE(12327)] = 337912,
  [SMALL_STATE(12328)] = 337923,
  [SMALL_STATE(12329)] = 337934,
  [SMALL_STATE(12330)] = 337945,
  [SMALL_STATE(12331)] = 337956,
  [SMALL_STATE(12332)] = 337967,
  [SMALL_STATE(12333)] = 337978,
  [SMALL_STATE(12334)] = 337989,
  [SMALL_STATE(12335)] = 338000,
  [SMALL_STATE(12336)] = 338011,
  [SMALL_STATE(12337)] = 338022,
  [SMALL_STATE(12338)] = 338033,
  [SMALL_STATE(12339)] = 338044,
  [SMALL_STATE(12340)] = 338055,
  [SMALL_STATE(12341)] = 338066,
  [SMALL_STATE(12342)] = 338077,
  [SMALL_STATE(12343)] = 338088,
  [SMALL_STATE(12344)] = 338099,
  [SMALL_STATE(12345)] = 338110,
  [SMALL_STATE(12346)] = 338121,
  [SMALL_STATE(12347)] = 338132,
  [SMALL_STATE(12348)] = 338143,
  [SMALL_STATE(12349)] = 338154,
  [SMALL_STATE(12350)] = 338165,
  [SMALL_STATE(12351)] = 338176,
  [SMALL_STATE(12352)] = 338187,
  [SMALL_STATE(12353)] = 338198,
  [SMALL_STATE(12354)] = 338209,
  [SMALL_STATE(12355)] = 338220,
  [SMALL_STATE(12356)] = 338231,
  [SMALL_STATE(12357)] = 338242,
  [SMALL_STATE(12358)] = 338253,
  [SMALL_STATE(12359)] = 338264,
  [SMALL_STATE(12360)] = 338275,
  [SMALL_STATE(12361)] = 338286,
  [SMALL_STATE(12362)] = 338297,
  [SMALL_STATE(12363)] = 338308,
  [SMALL_STATE(12364)] = 338319,
  [SMALL_STATE(12365)] = 338330,
  [SMALL_STATE(12366)] = 338341,
  [SMALL_STATE(12367)] = 338352,
  [SMALL_STATE(12368)] = 338363,
  [SMALL_STATE(12369)] = 338374,
  [SMALL_STATE(12370)] = 338385,
  [SMALL_STATE(12371)] = 338396,
  [SMALL_STATE(12372)] = 338407,
  [SMALL_STATE(12373)] = 338418,
  [SMALL_STATE(12374)] = 338429,
  [SMALL_STATE(12375)] = 338440,
  [SMALL_STATE(12376)] = 338451,
  [SMALL_STATE(12377)] = 338462,
  [SMALL_STATE(12378)] = 338473,
  [SMALL_STATE(12379)] = 338484,
  [SMALL_STATE(12380)] = 338495,
  [SMALL_STATE(12381)] = 338506,
  [SMALL_STATE(12382)] = 338517,
  [SMALL_STATE(12383)] = 338528,
  [SMALL_STATE(12384)] = 338539,
  [SMALL_STATE(12385)] = 338550,
  [SMALL_STATE(12386)] = 338561,
  [SMALL_STATE(12387)] = 338572,
  [SMALL_STATE(12388)] = 338583,
  [SMALL_STATE(12389)] = 338594,
  [SMALL_STATE(12390)] = 338605,
  [SMALL_STATE(12391)] = 338616,
  [SMALL_STATE(12392)] = 338627,
  [SMALL_STATE(12393)] = 338638,
  [SMALL_STATE(12394)] = 338649,
  [SMALL_STATE(12395)] = 338660,
  [SMALL_STATE(12396)] = 338671,
  [SMALL_STATE(12397)] = 338682,
  [SMALL_STATE(12398)] = 338693,
  [SMALL_STATE(12399)] = 338704,
  [SMALL_STATE(12400)] = 338715,
  [SMALL_STATE(12401)] = 338726,
  [SMALL_STATE(12402)] = 338737,
  [SMALL_STATE(12403)] = 338748,
  [SMALL_STATE(12404)] = 338759,
  [SMALL_STATE(12405)] = 338770,
  [SMALL_STATE(12406)] = 338781,
  [SMALL_STATE(12407)] = 338792,
  [SMALL_STATE(12408)] = 338803,
  [SMALL_STATE(12409)] = 338814,
  [SMALL_STATE(12410)] = 338825,
  [SMALL_STATE(12411)] = 338836,
  [SMALL_STATE(12412)] = 338847,
  [SMALL_STATE(12413)] = 338858,
  [SMALL_STATE(12414)] = 338869,
  [SMALL_STATE(12415)] = 338880,
  [SMALL_STATE(12416)] = 338891,
  [SMALL_STATE(12417)] = 338902,
  [SMALL_STATE(12418)] = 338913,
  [SMALL_STATE(12419)] = 338924,
  [SMALL_STATE(12420)] = 338935,
  [SMALL_STATE(12421)] = 338946,
  [SMALL_STATE(12422)] = 338957,
  [SMALL_STATE(12423)] = 338968,
  [SMALL_STATE(12424)] = 338979,
  [SMALL_STATE(12425)] = 338990,
  [SMALL_STATE(12426)] = 339001,
  [SMALL_STATE(12427)] = 339012,
  [SMALL_STATE(12428)] = 339023,
  [SMALL_STATE(12429)] = 339034,
  [SMALL_STATE(12430)] = 339045,
  [SMALL_STATE(12431)] = 339056,
  [SMALL_STATE(12432)] = 339067,
  [SMALL_STATE(12433)] = 339078,
  [SMALL_STATE(12434)] = 339089,
  [SMALL_STATE(12435)] = 339100,
  [SMALL_STATE(12436)] = 339111,
  [SMALL_STATE(12437)] = 339122,
  [SMALL_STATE(12438)] = 339133,
  [SMALL_STATE(12439)] = 339144,
  [SMALL_STATE(12440)] = 339155,
  [SMALL_STATE(12441)] = 339166,
  [SMALL_STATE(12442)] = 339177,
  [SMALL_STATE(12443)] = 339188,
  [SMALL_STATE(12444)] = 339199,
  [SMALL_STATE(12445)] = 339210,
  [SMALL_STATE(12446)] = 339221,
  [SMALL_STATE(12447)] = 339232,
  [SMALL_STATE(12448)] = 339243,
  [SMALL_STATE(12449)] = 339254,
  [SMALL_STATE(12450)] = 339265,
  [SMALL_STATE(12451)] = 339276,
  [SMALL_STATE(12452)] = 339287,
  [SMALL_STATE(12453)] = 339298,
  [SMALL_STATE(12454)] = 339309,
  [SMALL_STATE(12455)] = 339320,
  [SMALL_STATE(12456)] = 339331,
  [SMALL_STATE(12457)] = 339342,
  [SMALL_STATE(12458)] = 339353,
  [SMALL_STATE(12459)] = 339364,
  [SMALL_STATE(12460)] = 339375,
  [SMALL_STATE(12461)] = 339386,
  [SMALL_STATE(12462)] = 339397,
  [SMALL_STATE(12463)] = 339408,
  [SMALL_STATE(12464)] = 339419,
  [SMALL_STATE(12465)] = 339430,
  [SMALL_STATE(12466)] = 339441,
  [SMALL_STATE(12467)] = 339452,
  [SMALL_STATE(12468)] = 339463,
  [SMALL_STATE(12469)] = 339474,
  [SMALL_STATE(12470)] = 339485,
  [SMALL_STATE(12471)] = 339496,
  [SMALL_STATE(12472)] = 339507,
  [SMALL_STATE(12473)] = 339518,
  [SMALL_STATE(12474)] = 339529,
  [SMALL_STATE(12475)] = 339540,
  [SMALL_STATE(12476)] = 339551,
  [SMALL_STATE(12477)] = 339562,
  [SMALL_STATE(12478)] = 339573,
  [SMALL_STATE(12479)] = 339584,
  [SMALL_STATE(12480)] = 339595,
  [SMALL_STATE(12481)] = 339606,
  [SMALL_STATE(12482)] = 339617,
  [SMALL_STATE(12483)] = 339628,
  [SMALL_STATE(12484)] = 339639,
  [SMALL_STATE(12485)] = 339650,
  [SMALL_STATE(12486)] = 339661,
  [SMALL_STATE(12487)] = 339672,
  [SMALL_STATE(12488)] = 339683,
  [SMALL_STATE(12489)] = 339694,
  [SMALL_STATE(12490)] = 339705,
  [SMALL_STATE(12491)] = 339716,
  [SMALL_STATE(12492)] = 339727,
  [SMALL_STATE(12493)] = 339738,
  [SMALL_STATE(12494)] = 339749,
  [SMALL_STATE(12495)] = 339760,
  [SMALL_STATE(12496)] = 339771,
  [SMALL_STATE(12497)] = 339782,
  [SMALL_STATE(12498)] = 339793,
  [SMALL_STATE(12499)] = 339804,
  [SMALL_STATE(12500)] = 339815,
  [SMALL_STATE(12501)] = 339826,
  [SMALL_STATE(12502)] = 339837,
  [SMALL_STATE(12503)] = 339848,
  [SMALL_STATE(12504)] = 339859,
  [SMALL_STATE(12505)] = 339870,
  [SMALL_STATE(12506)] = 339881,
  [SMALL_STATE(12507)] = 339892,
  [SMALL_STATE(12508)] = 339903,
  [SMALL_STATE(12509)] = 339914,
  [SMALL_STATE(12510)] = 339925,
  [SMALL_STATE(12511)] = 339936,
  [SMALL_STATE(12512)] = 339947,
  [SMALL_STATE(12513)] = 339958,
  [SMALL_STATE(12514)] = 339969,
  [SMALL_STATE(12515)] = 339980,
  [SMALL_STATE(12516)] = 339991,
  [SMALL_STATE(12517)] = 340002,
  [SMALL_STATE(12518)] = 340013,
  [SMALL_STATE(12519)] = 340024,
  [SMALL_STATE(12520)] = 340035,
  [SMALL_STATE(12521)] = 340046,
  [SMALL_STATE(12522)] = 340057,
  [SMALL_STATE(12523)] = 340068,
  [SMALL_STATE(12524)] = 340079,
  [SMALL_STATE(12525)] = 340090,
  [SMALL_STATE(12526)] = 340101,
  [SMALL_STATE(12527)] = 340112,
  [SMALL_STATE(12528)] = 340123,
  [SMALL_STATE(12529)] = 340134,
  [SMALL_STATE(12530)] = 340145,
  [SMALL_STATE(12531)] = 340156,
  [SMALL_STATE(12532)] = 340167,
  [SMALL_STATE(12533)] = 340178,
  [SMALL_STATE(12534)] = 340189,
  [SMALL_STATE(12535)] = 340200,
  [SMALL_STATE(12536)] = 340211,
  [SMALL_STATE(12537)] = 340222,
  [SMALL_STATE(12538)] = 340233,
  [SMALL_STATE(12539)] = 340244,
  [SMALL_STATE(12540)] = 340255,
  [SMALL_STATE(12541)] = 340266,
  [SMALL_STATE(12542)] = 340277,
  [SMALL_STATE(12543)] = 340288,
  [SMALL_STATE(12544)] = 340299,
  [SMALL_STATE(12545)] = 340310,
  [SMALL_STATE(12546)] = 340321,
  [SMALL_STATE(12547)] = 340332,
  [SMALL_STATE(12548)] = 340343,
  [SMALL_STATE(12549)] = 340354,
  [SMALL_STATE(12550)] = 340365,
  [SMALL_STATE(12551)] = 340376,
  [SMALL_STATE(12552)] = 340387,
  [SMALL_STATE(12553)] = 340398,
  [SMALL_STATE(12554)] = 340409,
  [SMALL_STATE(12555)] = 340420,
  [SMALL_STATE(12556)] = 340431,
  [SMALL_STATE(12557)] = 340442,
  [SMALL_STATE(12558)] = 340453,
  [SMALL_STATE(12559)] = 340464,
  [SMALL_STATE(12560)] = 340475,
  [SMALL_STATE(12561)] = 340486,
  [SMALL_STATE(12562)] = 340497,
  [SMALL_STATE(12563)] = 340508,
  [SMALL_STATE(12564)] = 340519,
  [SMALL_STATE(12565)] = 340530,
  [SMALL_STATE(12566)] = 340541,
  [SMALL_STATE(12567)] = 340552,
  [SMALL_STATE(12568)] = 340563,
  [SMALL_STATE(12569)] = 340574,
  [SMALL_STATE(12570)] = 340585,
  [SMALL_STATE(12571)] = 340596,
  [SMALL_STATE(12572)] = 340607,
  [SMALL_STATE(12573)] = 340618,
  [SMALL_STATE(12574)] = 340629,
  [SMALL_STATE(12575)] = 340640,
  [SMALL_STATE(12576)] = 340651,
  [SMALL_STATE(12577)] = 340662,
  [SMALL_STATE(12578)] = 340673,
  [SMALL_STATE(12579)] = 340684,
  [SMALL_STATE(12580)] = 340695,
  [SMALL_STATE(12581)] = 340706,
  [SMALL_STATE(12582)] = 340717,
  [SMALL_STATE(12583)] = 340728,
  [SMALL_STATE(12584)] = 340739,
  [SMALL_STATE(12585)] = 340750,
  [SMALL_STATE(12586)] = 340761,
  [SMALL_STATE(12587)] = 340772,
  [SMALL_STATE(12588)] = 340783,
  [SMALL_STATE(12589)] = 340794,
  [SMALL_STATE(12590)] = 340805,
  [SMALL_STATE(12591)] = 340816,
  [SMALL_STATE(12592)] = 340827,
  [SMALL_STATE(12593)] = 340838,
  [SMALL_STATE(12594)] = 340849,
  [SMALL_STATE(12595)] = 340860,
  [SMALL_STATE(12596)] = 340871,
  [SMALL_STATE(12597)] = 340882,
  [SMALL_STATE(12598)] = 340893,
  [SMALL_STATE(12599)] = 340904,
  [SMALL_STATE(12600)] = 340915,
  [SMALL_STATE(12601)] = 340926,
  [SMALL_STATE(12602)] = 340937,
  [SMALL_STATE(12603)] = 340948,
  [SMALL_STATE(12604)] = 340959,
  [SMALL_STATE(12605)] = 340970,
  [SMALL_STATE(12606)] = 340981,
  [SMALL_STATE(12607)] = 340992,
  [SMALL_STATE(12608)] = 341003,
  [SMALL_STATE(12609)] = 341014,
  [SMALL_STATE(12610)] = 341025,
  [SMALL_STATE(12611)] = 341036,
  [SMALL_STATE(12612)] = 341047,
  [SMALL_STATE(12613)] = 341058,
  [SMALL_STATE(12614)] = 341069,
  [SMALL_STATE(12615)] = 341080,
  [SMALL_STATE(12616)] = 341091,
  [SMALL_STATE(12617)] = 341102,
  [SMALL_STATE(12618)] = 341113,
  [SMALL_STATE(12619)] = 341124,
  [SMALL_STATE(12620)] = 341135,
  [SMALL_STATE(12621)] = 341146,
  [SMALL_STATE(12622)] = 341157,
  [SMALL_STATE(12623)] = 341168,
  [SMALL_STATE(12624)] = 341179,
  [SMALL_STATE(12625)] = 341190,
  [SMALL_STATE(12626)] = 341201,
  [SMALL_STATE(12627)] = 341212,
  [SMALL_STATE(12628)] = 341223,
  [SMALL_STATE(12629)] = 341234,
  [SMALL_STATE(12630)] = 341245,
  [SMALL_STATE(12631)] = 341256,
  [SMALL_STATE(12632)] = 341267,
  [SMALL_STATE(12633)] = 341278,
  [SMALL_STATE(12634)] = 341289,
  [SMALL_STATE(12635)] = 341300,
  [SMALL_STATE(12636)] = 341311,
  [SMALL_STATE(12637)] = 341322,
  [SMALL_STATE(12638)] = 341333,
  [SMALL_STATE(12639)] = 341344,
  [SMALL_STATE(12640)] = 341355,
  [SMALL_STATE(12641)] = 341366,
  [SMALL_STATE(12642)] = 341377,
  [SMALL_STATE(12643)] = 341388,
  [SMALL_STATE(12644)] = 341399,
  [SMALL_STATE(12645)] = 341410,
  [SMALL_STATE(12646)] = 341421,
  [SMALL_STATE(12647)] = 341432,
  [SMALL_STATE(12648)] = 341443,
  [SMALL_STATE(12649)] = 341454,
  [SMALL_STATE(12650)] = 341465,
  [SMALL_STATE(12651)] = 341476,
  [SMALL_STATE(12652)] = 341487,
  [SMALL_STATE(12653)] = 341498,
  [SMALL_STATE(12654)] = 341509,
  [SMALL_STATE(12655)] = 341520,
  [SMALL_STATE(12656)] = 341531,
  [SMALL_STATE(12657)] = 341542,
  [SMALL_STATE(12658)] = 341553,
  [SMALL_STATE(12659)] = 341564,
  [SMALL_STATE(12660)] = 341575,
  [SMALL_STATE(12661)] = 341586,
  [SMALL_STATE(12662)] = 341597,
  [SMALL_STATE(12663)] = 341608,
  [SMALL_STATE(12664)] = 341619,
  [SMALL_STATE(12665)] = 341630,
  [SMALL_STATE(12666)] = 341641,
  [SMALL_STATE(12667)] = 341652,
  [SMALL_STATE(12668)] = 341663,
  [SMALL_STATE(12669)] = 341674,
  [SMALL_STATE(12670)] = 341685,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9696),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11694),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12500),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12333),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12377),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3353),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11995),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11363),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12588),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3362),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3350),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3350),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12048),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8384),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8833),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8188),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8445),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8875),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12531),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11293),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8535),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8919),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11239),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11243),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(993),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1557),
  [59] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2934),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1009),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(979),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3053),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(991),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2766),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9216),
  [73] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9709),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2934),
  [77] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9686),
  [79] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2216),
  [81] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1748),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1011),
  [85] = {.entry = {.count = 1, .reusable = true}}, SHIFT(979),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5400),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5394),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5390),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11134),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5392),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2421),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1536),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1657),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1658),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5393),
  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1155),
  [109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(988),
  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(989),
  [113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(990),
  [115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(176),
  [119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9837),
  [121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3437),
  [123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2442),
  [125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9488),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8922),
  [131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8962),
  [133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8950),
  [135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9099),
  [137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8877),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9118),
  [141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9738),
  [143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9780),
  [145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9807),
  [147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2404),
  [149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9929),
  [151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8856),
  [153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8869),
  [155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8870),
  [157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9134),
  [159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9930),
  [161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9529),
  [163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8942),
  [165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8854),
  [167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8855),
  [169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9094),
  [171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8896),
  [173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9098),
  [175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8946),
  [177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8951),
  [179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8954),
  [181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9275),
  [183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8958),
  [185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9279),
  [187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9898),
  [189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9906),
  [191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9913),
  [193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9915),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9917),
  [197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9918),
  [199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9919),
  [201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9920),
  [203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9921),
  [205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9922),
  [207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9923),
  [209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9924),
  [211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9925),
  [213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9926),
  [215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9927),
  [217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9928),
  [219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8879),
  [221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1650),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9117),
  [225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8917),
  [227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8916),
  [229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8882),
  [231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8961),
  [233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8956),
  [235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8850),
  [237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8948),
  [239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8845),
  [241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8957),
  [243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8876),
  [245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8959),
  [247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8872),
  [249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8933),
  [251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8873),
  [253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8868),
  [255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8874),
  [257] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__preproc_if_header, 3, 0, 106),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9731),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9805),
  [263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9778),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9910),
  [267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(191),
  [269] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_else_branch, 1, 0, 0),
  [271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1005),
  [275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_type, 1, 0, 0),
  [277] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option_type, 1, 0, 0),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11981),
  [283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(951),
  [285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1004),
  [287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [289] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(993),
  [292] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1557),
  [295] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(2934),
  [298] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1009),
  [301] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(979),
  [304] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(3053),
  [307] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(991),
  [310] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(2766),
  [313] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52),
  [315] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(9709),
  [318] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(2934),
  [321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52),
  [323] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1011),
  [326] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(979),
  [329] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(5400),
  [332] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(5394),
  [335] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(5390),
  [338] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(11134),
  [341] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(5392),
  [344] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(2421),
  [347] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1536),
  [350] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1657),
  [353] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1658),
  [356] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(5393),
  [359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1155),
  [362] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(988),
  [365] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(989),
  [368] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(990),
  [371] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1012),
  [374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_member_list, 1, 0, 0),
  [376] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option_member_list, 1, 0, 0),
  [378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [380] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_statement_repeat1, 2, 0, 29),
  [382] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_else_branch, 2, 0, 29),
  [384] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_statement_repeat1, 1, 0, 0),
  [386] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1005),
  [389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0),
  [391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0),
  [393] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(11981),
  [396] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1009),
  [399] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(991),
  [402] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1004),
  [405] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(988),
  [408] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(989),
  [411] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(990),
  [414] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1005),
  [417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1092),
  [419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12114),
  [423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1101),
  [425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1042),
  [427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1050),
  [429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1119),
  [431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1079),
  [433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1080),
  [435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1081),
  [437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1092),
  [439] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1085),
  [442] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1791),
  [445] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(3049),
  [448] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1101),
  [451] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1078),
  [454] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(3083),
  [457] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1050),
  [460] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(2777),
  [463] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(3049),
  [466] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1106),
  [469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1078),
  [472] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1768),
  [475] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1900),
  [478] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1901),
  [481] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1247),
  [484] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1079),
  [487] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1080),
  [490] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1081),
  [493] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1126),
  [496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [498] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1092),
  [501] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(12114),
  [504] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1101),
  [507] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1050),
  [510] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1119),
  [513] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1079),
  [516] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1080),
  [519] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1081),
  [522] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1092),
  [525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1085),
  [527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1791),
  [529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3049),
  [531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1078),
  [533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3083),
  [535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2777),
  [537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3049),
  [539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1106),
  [541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1768),
  [545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1900),
  [547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1901),
  [549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1247),
  [551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1126),
  [553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(181),
  [555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5391),
  [559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(187),
  [561] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_else_branch, 1, 0, 0),
  [563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [565] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat2, 2, 0, 0),
  [567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat2, 2, 0, 0),
  [569] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat2, 2, 0, 0), SHIFT_REPEAT(167),
  [572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1400),
  [574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2961),
  [576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1496),
  [578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1524),
  [580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3126),
  [582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1440),
  [584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2802),
  [586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2961),
  [588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1446),
  [590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1524),
  [592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2181),
  [594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1437),
  [596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1438),
  [598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1439),
  [600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1484),
  [602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2047),
  [604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2888),
  [606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2159),
  [608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2157),
  [610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3097),
  [612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2098),
  [614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2765),
  [616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2888),
  [618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2134),
  [620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2157),
  [622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2554),
  [624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2095),
  [626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2096),
  [628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2097),
  [630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2115),
  [632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1169),
  [634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2287),
  [636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2907),
  [638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1211),
  [640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1161),
  [642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3005),
  [644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1157),
  [646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2801),
  [648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7261),
  [650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9939),
  [652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2907),
  [654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1208),
  [656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1161),
  [658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2226),
  [660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2260),
  [662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2263),
  [664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1365),
  [666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1197),
  [668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1198),
  [670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1199),
  [672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1205),
  [674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7261),
  [676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7253),
  [678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7262),
  [680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3228),
  [682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3222),
  [684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1597),
  [686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1597),
  [688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3827),
  [690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3827),
  [692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1601),
  [694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1600),
  [696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3853),
  [698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3849),
  [700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1838),
  [702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1838),
  [704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1842),
  [706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1841),
  [708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6886),
  [710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6886),
  [712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6885),
  [714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6887),
  [716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7484),
  [718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7484),
  [720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7476),
  [722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7473),
  [724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9389),
  [726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9389),
  [728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9394),
  [730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9393),
  [732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7033),
  [734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7033),
  [736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7032),
  [738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7029),
  [740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8842),
  [742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8842),
  [744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8771),
  [746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8769),
  [748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6510),
  [750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6510),
  [752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6514),
  [754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6513),
  [756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7538),
  [758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7538),
  [760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7496),
  [762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7541),
  [764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4976),
  [766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4976),
  [768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4987),
  [770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4983),
  [772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5825),
  [774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5825),
  [776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9894),
  [778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5474),
  [780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5474),
  [782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5479),
  [784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5477),
  [786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4737),
  [788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4737),
  [790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4741),
  [792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4740),
  [794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4166),
  [796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4166),
  [798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3125),
  [800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3125),
  [802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9734),
  [804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9779),
  [806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9806),
  [808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2393),
  [810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2393),
  [812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3339),
  [814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3339),
  [816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3283),
  [818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3275),
  [820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2401),
  [822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2400),
  [824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4494),
  [826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4493),
  [828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1212),
  [830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12075),
  [834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1153),
  [836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1203),
  [838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1212),
  [840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5835),
  [842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5829),
  [844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(227),
  [846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [848] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1169),
  [851] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(2287),
  [854] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(2907),
  [857] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1211),
  [860] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1161),
  [863] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(3005),
  [866] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1157),
  [869] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(2801),
  [872] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(2907),
  [875] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1208),
  [878] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1161),
  [881] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(2226),
  [884] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(2260),
  [887] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(2263),
  [890] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1365),
  [893] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1197),
  [896] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1198),
  [899] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1199),
  [902] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 2, 0, 52), SHIFT_REPEAT(1205),
  [905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5923),
  [907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9987),
  [909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3216),
  [911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4818),
  [913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6083),
  [915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2875),
  [917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4642),
  [919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2808),
  [921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3216),
  [923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6044),
  [925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6083),
  [927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9800),
  [929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10073),
  [931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10094),
  [933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2643),
  [935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3353),
  [937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3362),
  [939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6212),
  [941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3637),
  [945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3637),
  [947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3687),
  [949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3686),
  [951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3688),
  [953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3688),
  [955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3690),
  [957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3689),
  [959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3692),
  [961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3691),
  [963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3732),
  [965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3731),
  [967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3736),
  [969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3735),
  [971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3738),
  [973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3737),
  [975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3742),
  [977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3741),
  [979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3744),
  [981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3743),
  [983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3746),
  [985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3745),
  [987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3747),
  [989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3747),
  [991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3749),
  [993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3748),
  [995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3751),
  [997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3750),
  [999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3772),
  [1001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3771),
  [1003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3783),
  [1005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3509),
  [1007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3787),
  [1009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3786),
  [1011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3789),
  [1013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3788),
  [1015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3792),
  [1017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3791),
  [1019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3796),
  [1021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3795),
  [1023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3713),
  [1025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3724),
  [1027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3725),
  [1029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3721),
  [1031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3753),
  [1033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3752),
  [1035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3755),
  [1037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3754),
  [1039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3660),
  [1041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3657),
  [1043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3618),
  [1045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3612),
  [1047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3634),
  [1049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3628),
  [1051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3696),
  [1053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3695),
  [1055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3698),
  [1057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3697),
  [1059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4096),
  [1061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4096),
  [1063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3659),
  [1065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3658),
  [1067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4141),
  [1069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4140),
  [1071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5199),
  [1073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5199),
  [1075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4142),
  [1077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4142),
  [1079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5235),
  [1081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5234),
  [1083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5236),
  [1085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5236),
  [1087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5238),
  [1089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5237),
  [1091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5240),
  [1093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5239),
  [1095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4144),
  [1097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4143),
  [1099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4159),
  [1101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4152),
  [1103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5254),
  [1105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5253),
  [1107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5258),
  [1109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5257),
  [1111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5260),
  [1113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5259),
  [1115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5263),
  [1117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5262),
  [1119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5265),
  [1121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5264),
  [1123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5267),
  [1125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5266),
  [1127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5268),
  [1129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5268),
  [1131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5270),
  [1133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5269),
  [1135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5272),
  [1137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5271),
  [1139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5282),
  [1141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5281),
  [1143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5288),
  [1145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5287),
  [1147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5292),
  [1149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5291),
  [1151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5294),
  [1153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5293),
  [1155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5297),
  [1157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5296),
  [1159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5301),
  [1161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5300),
  [1163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5303),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5302),
  [1167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5307),
  [1169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5306),
  [1171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5309),
  [1173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5308),
  [1175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5311),
  [1177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5310),
  [1179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5322),
  [1181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5321),
  [1183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5330),
  [1185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5329),
  [1187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5336),
  [1189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5335),
  [1191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5340),
  [1193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5339),
  [1195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5342),
  [1197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5341),
  [1199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5357),
  [1201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5356),
  [1203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6385),
  [1205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6385),
  [1207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6459),
  [1209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6458),
  [1211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6460),
  [1213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6460),
  [1215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6483),
  [1217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6470),
  [1219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6491),
  [1221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6490),
  [1223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6541),
  [1225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6540),
  [1227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6546),
  [1229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6545),
  [1231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6548),
  [1233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6547),
  [1235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6558),
  [1237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6557),
  [1239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6560),
  [1241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6559),
  [1243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6563),
  [1245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6562),
  [1247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6564),
  [1249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6564),
  [1251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6566),
  [1253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6565),
  [1255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6576),
  [1257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6568),
  [1259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6607),
  [1261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6606),
  [1263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6615),
  [1265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6614),
  [1267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6620),
  [1269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6618),
  [1271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6622),
  [1273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6621),
  [1275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6625),
  [1277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6624),
  [1279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6631),
  [1281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6628),
  [1283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6633),
  [1285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6632),
  [1287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6638),
  [1289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6636),
  [1291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6640),
  [1293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6639),
  [1295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6642),
  [1297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6641),
  [1299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6658),
  [1301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6657),
  [1303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6666),
  [1305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6665),
  [1307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6675),
  [1309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6674),
  [1311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6682),
  [1313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6681),
  [1315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6687),
  [1317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6686),
  [1319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6726),
  [1321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6725),
  [1323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4284),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4278),
  [1327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4288),
  [1329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4287),
  [1331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5534),
  [1333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5534),
  [1335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5574),
  [1337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5573),
  [1339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5576),
  [1341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5576),
  [1343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5578),
  [1345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5577),
  [1347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5583),
  [1349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5582),
  [1351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4290),
  [1353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4289),
  [1355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4301),
  [1357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4296),
  [1359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5603),
  [1361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5602),
  [1363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5607),
  [1365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5606),
  [1367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5609),
  [1369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5608),
  [1371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5613),
  [1373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5612),
  [1375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5615),
  [1377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5614),
  [1379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5632),
  [1381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5616),
  [1383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5633),
  [1385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5633),
  [1387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5636),
  [1389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5635),
  [1391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5639),
  [1393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5637),
  [1395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5648),
  [1397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5647),
  [1399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5665),
  [1401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5653),
  [1403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5671),
  [1405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5668),
  [1407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5673),
  [1409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5672),
  [1411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5677),
  [1413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5676),
  [1415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5682),
  [1417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5681),
  [1419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5688),
  [1421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5686),
  [1423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5692),
  [1425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5691),
  [1427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5694),
  [1429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5693),
  [1431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5696),
  [1433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5695),
  [1435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5708),
  [1437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5707),
  [1439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5717),
  [1441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5716),
  [1443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5446),
  [1445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5722),
  [1447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5728),
  [1449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5726),
  [1451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5731),
  [1453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5730),
  [1455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5746),
  [1457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5745),
  [1459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4307),
  [1461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4306),
  [1463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4309),
  [1465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4308),
  [1467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4310),
  [1469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4310),
  [1471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4313),
  [1473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4312),
  [1475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4317),
  [1477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4314),
  [1479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4359),
  [1481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4358),
  [1483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4365),
  [1485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4364),
  [1487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4369),
  [1489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4368),
  [1491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4371),
  [1493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4370),
  [1495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4375),
  [1497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4373),
  [1499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4380),
  [1501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4379),
  [1503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4382),
  [1505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4381),
  [1507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4386),
  [1509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4385),
  [1511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4388),
  [1513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4387),
  [1515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4390),
  [1517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4389),
  [1519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4455),
  [1521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4454),
  [1523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4478),
  [1525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4477),
  [1527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4485),
  [1529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4483),
  [1531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4490),
  [1533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4488),
  [1535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4492),
  [1537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4491),
  [1539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4535),
  [1541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4534),
  [1543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10130),
  [1545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9097),
  [1547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9715),
  [1549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2274),
  [1551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1886),
  [1553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11256),
  [1555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11347),
  [1557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12018),
  [1559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12030),
  [1561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8380),
  [1563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8546),
  [1565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8547),
  [1567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11126),
  [1569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11133),
  [1571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10271),
  [1573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10272),
  [1575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10016),
  [1577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1244),
  [1579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_else_branch, 2, 0, 29),
  [1581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9103),
  [1583] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1212),
  [1586] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(12075),
  [1589] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1211),
  [1592] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1157),
  [1595] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1203),
  [1598] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1197),
  [1601] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1198),
  [1604] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1199),
  [1607] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1212),
  [1610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9191),
  [1612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9214),
  [1614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9219),
  [1616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9262),
  [1618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9263),
  [1620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9122),
  [1622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9227),
  [1624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9158),
  [1626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9218),
  [1628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9266),
  [1630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9264),
  [1632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9274),
  [1634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9284),
  [1636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9116),
  [1638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9069),
  [1640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9115),
  [1642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9120),
  [1644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9132),
  [1646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9135),
  [1648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9136),
  [1650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9137),
  [1652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9139),
  [1654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9142),
  [1656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9148),
  [1658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9255),
  [1660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9065),
  [1662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9068),
  [1664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9071),
  [1666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9073),
  [1668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9074),
  [1670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9114),
  [1672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9119),
  [1674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9131),
  [1676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9138),
  [1678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9292),
  [1680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9280),
  [1682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9294),
  [1684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9272),
  [1686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10025),
  [1688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9298),
  [1690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9070),
  [1692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9101),
  [1694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9102),
  [1696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9104),
  [1698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9173),
  [1700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9265),
  [1702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9271),
  [1704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9066),
  [1706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9075),
  [1708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9076),
  [1710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9077),
  [1712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9086),
  [1714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9087),
  [1716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9088),
  [1718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9091),
  [1720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9092),
  [1722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9153),
  [1724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9155),
  [1726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9172),
  [1728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9178),
  [1730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9179),
  [1732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9181),
  [1734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9273),
  [1736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9293),
  [1738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9278),
  [1740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9281),
  [1742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9282),
  [1744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9283),
  [1746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9285),
  [1748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9286),
  [1750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9287),
  [1752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9288),
  [1754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9289),
  [1756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9290),
  [1758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9058),
  [1760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9295),
  [1762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9296),
  [1764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9297),
  [1766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9299),
  [1768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9190),
  [1770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9072),
  [1772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9159),
  [1774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9177),
  [1776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9183),
  [1778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9060),
  [1780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9061),
  [1782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9062),
  [1784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9067),
  [1786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9141),
  [1788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9152),
  [1790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9154),
  [1792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9156),
  [1794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9157),
  [1796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9160),
  [1798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9161),
  [1800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9162),
  [1802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9078),
  [1804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9079),
  [1806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9080),
  [1808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9081),
  [1810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9082),
  [1812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9083),
  [1814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9084),
  [1816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9085),
  [1818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9105),
  [1820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9106),
  [1822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9107),
  [1824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9108),
  [1826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9109),
  [1828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9110),
  [1830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9111),
  [1832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9112),
  [1834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9123),
  [1836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9124),
  [1838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9125),
  [1840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9126),
  [1842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9127),
  [1844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9128),
  [1846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9129),
  [1848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9130),
  [1850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9143),
  [1852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9144),
  [1854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9145),
  [1856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9146),
  [1858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9147),
  [1860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9149),
  [1862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9150),
  [1864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9151),
  [1866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9164),
  [1868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9165),
  [1870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9166),
  [1872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9167),
  [1874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9168),
  [1876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9169),
  [1878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9170),
  [1880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9171),
  [1882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9182),
  [1884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9184),
  [1886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9185),
  [1888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9186),
  [1890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9187),
  [1892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9188),
  [1894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9189),
  [1896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9301),
  [1898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9192),
  [1900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9193),
  [1902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9194),
  [1904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9195),
  [1906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9197),
  [1908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9198),
  [1910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9199),
  [1912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9200),
  [1914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9201),
  [1916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9202),
  [1918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9203),
  [1920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9204),
  [1922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9205),
  [1924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9206),
  [1926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9207),
  [1928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9208),
  [1930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9210),
  [1932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9212),
  [1934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9213),
  [1936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9215),
  [1938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9217),
  [1940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9221),
  [1942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9222),
  [1944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9223),
  [1946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9224),
  [1948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9225),
  [1950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9226),
  [1952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9228),
  [1954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9229),
  [1956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9230),
  [1958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9232),
  [1960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9234),
  [1962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9236),
  [1964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9237),
  [1966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9239),
  [1968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9240),
  [1970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9241),
  [1972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9242),
  [1974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9243),
  [1976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9244),
  [1978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9245),
  [1980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9246),
  [1982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9248),
  [1984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9249),
  [1986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9250),
  [1988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9252),
  [1990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9253),
  [1992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9254),
  [1994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9256),
  [1996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9258),
  [1998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9259),
  [2000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9260),
  [2002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9267),
  [2004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9268),
  [2006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9269),
  [2008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9270),
  [2010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9089),
  [2012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9163),
  [2014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9261),
  [2016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9100),
  [2018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9113),
  [2020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9174),
  [2022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9176),
  [2024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9090),
  [2026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9093),
  [2028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9096),
  [2030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9064),
  [2032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9059),
  [2034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9955),
  [2036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9959),
  [2038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9960),
  [2040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9964),
  [2042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9235),
  [2044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10036),
  [2046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10038),
  [2048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10039),
  [2050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10041),
  [2052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9247),
  [2054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10082),
  [2056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10084),
  [2058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10085),
  [2060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10087),
  [2062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10107),
  [2064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10109),
  [2066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10110),
  [2068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10111),
  [2070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10117),
  [2072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10118),
  [2074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10119),
  [2076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10120),
  [2078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10124),
  [2080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10125),
  [2082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10126),
  [2084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10127),
  [2086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10129),
  [2088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10131),
  [2090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10132),
  [2092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10134),
  [2094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10135),
  [2096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10136),
  [2098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10137),
  [2100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10138),
  [2102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10139),
  [2104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10140),
  [2106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10141),
  [2108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10142),
  [2110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10143),
  [2112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10144),
  [2114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10145),
  [2116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10146),
  [2118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10147),
  [2120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10148),
  [2122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10149),
  [2124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10150),
  [2126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10151),
  [2128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10152),
  [2130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10153),
  [2132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10154),
  [2134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10155),
  [2136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10156),
  [2138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10157),
  [2140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10158),
  [2142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10159),
  [2144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10160),
  [2146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10161),
  [2148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10162),
  [2150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10163),
  [2152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10164),
  [2154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10165),
  [2156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10166),
  [2158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10167),
  [2160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10355),
  [2162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10169),
  [2164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10170),
  [2166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9940),
  [2168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10172),
  [2170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10173),
  [2172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10174),
  [2174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10175),
  [2176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10176),
  [2178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10177),
  [2180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9133),
  [2182] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat2, 2, 0, 0), SHIFT_REPEAT(917),
  [2185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11890),
  [2187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11891),
  [2189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11892),
  [2191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11893),
  [2193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8545),
  [2195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6093),
  [2197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4429),
  [2199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4624),
  [2201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2805),
  [2203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6367),
  [2205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11958),
  [2207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12105),
  [2209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3884),
  [2211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12156),
  [2213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12425),
  [2215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7742),
  [2217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4780),
  [2219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11395),
  [2221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4643),
  [2223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9638),
  [2225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3142),
  [2227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4836),
  [2229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3142),
  [2231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6367),
  [2233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6355),
  [2235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7664),
  [2237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4782),
  [2239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4795),
  [2241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6252),
  [2243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6276),
  [2245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6254),
  [2247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6499),
  [2249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5580),
  [2251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5193),
  [2253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9990),
  [2255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3311),
  [2257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7307),
  [2259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_object_repeat1, 1, 0, 0),
  [2261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7000),
  [2263] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat2, 2, 0, 0), SHIFT_REPEAT(950),
  [2266] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_keyword_as_identifier, 1, 0, 0),
  [2268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_keyword_as_identifier, 1, 0, 0),
  [2270] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_logical_expression, 3, 0, 34),
  [2272] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_logical_expression, 3, 0, 34),
  [2274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8435),
  [2276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5395),
  [2278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3048),
  [2280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3050),
  [2282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3051),
  [2284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3054),
  [2286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1312),
  [2288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1313),
  [2290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3063),
  [2292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3066),
  [2294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3067),
  [2296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3070),
  [2298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3077),
  [2300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3078),
  [2302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3079),
  [2304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3080),
  [2306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5395),
  [2308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3093),
  [2310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3094),
  [2312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3104),
  [2314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12574),
  [2316] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_expression, 3, 0, 35),
  [2318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_expression, 3, 0, 35),
  [2320] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_multiplicative_expression, 3, 0, 34),
  [2322] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multiplicative_expression, 3, 0, 34),
  [2324] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_object_repeat1, 3, 0, 0),
  [2326] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expression, 3, 1, 34),
  [2328] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, 1, 34),
  [2330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3052),
  [2332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3105),
  [2334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3108),
  [2336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3109),
  [2338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3110),
  [2340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3120),
  [2342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3121),
  [2344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3055),
  [2346] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__namespaced_or_simple_ref, 1, 0, 0),
  [2348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__namespaced_or_simple_ref, 1, 0, 0),
  [2350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8416),
  [2352] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_object_repeat1, 2, 0, 0),
  [2354] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option_member_list, 2, 0, 0),
  [2356] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_member_list, 2, 0, 0),
  [2358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [2360] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_additive_expression, 3, 0, 34),
  [2362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_additive_expression, 3, 0, 34),
  [2364] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comparison_expression, 3, 0, 34),
  [2366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comparison_expression, 3, 0, 34),
  [2368] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ternary_expression, 5, 0, 69),
  [2370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ternary_expression, 5, 0, 69),
  [2372] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression_statement, 1, 0, 45),
  [2374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression_statement, 1, 0, 45),
  [2376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2908),
  [2378] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_asserterror_statement, 2, 0, 64),
  [2380] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_asserterror_statement, 2, 0, 64),
  [2382] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_assignment_statement, 3, 10, 34), REDUCE(sym_assignment_expression, 3, 1, 34),
  [2385] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_assignment_statement, 3, 10, 34), REDUCE(sym_assignment_expression, 3, 1, 34),
  [2388] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_repeat_statement, 3, 0, 82),
  [2390] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeat_statement, 3, 0, 82),
  [2392] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_repeat_statement, 4, 0, 112),
  [2394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeat_statement, 4, 0, 112),
  [2396] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__namespaced_or_simple_ref_repeat1, 2, 0, 0),
  [2398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__namespaced_or_simple_ref_repeat1, 2, 0, 0),
  [2400] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__namespaced_or_simple_ref_repeat1, 2, 0, 0), SHIFT_REPEAT(8416),
  [2403] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0),
  [2405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0),
  [2407] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0), SHIFT_REPEAT(96),
  [2410] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option_member_list, 3, 0, 0),
  [2412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_member_list, 3, 0, 0),
  [2414] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_codeunit_keyword, 1, 0, 0),
  [2416] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_codeunit_keyword, 1, 0, 0),
  [2418] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_xmlport_keyword, 1, 0, 0),
  [2420] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_xmlport_keyword, 1, 0, 0),
  [2422] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_keyword, 1, 0, 0),
  [2424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_keyword, 1, 0, 0),
  [2426] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_keyword_identifier, 1, 0, 0),
  [2428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_keyword_identifier, 1, 0, 0),
  [2430] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 19),
  [2432] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 19),
  [2434] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [2436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [2438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2770),
  [2440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8411),
  [2442] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__namespaced_or_simple_ref, 2, 0, 0),
  [2444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__namespaced_or_simple_ref, 2, 0, 0),
  [2446] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(9696),
  [2449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [2451] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(11890),
  [2454] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(12500),
  [2457] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(11891),
  [2460] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(12377),
  [2463] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(3353),
  [2466] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(11892),
  [2469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(11363),
  [2472] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(11893),
  [2475] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(3362),
  [2478] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(3350),
  [2481] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(3350),
  [2484] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(12048),
  [2487] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(8545),
  [2490] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(8833),
  [2493] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(8188),
  [2496] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(8546),
  [2499] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(8875),
  [2502] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(12531),
  [2505] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(11293),
  [2508] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(8547),
  [2511] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(8919),
  [2514] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(11133),
  [2517] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 2, 0, 0),
  [2519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 2, 0, 0),
  [2521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_enum_value, 3, 0, 31),
  [2523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_enum_value, 3, 0, 31),
  [2525] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_expression, 3, 0, 33),
  [2527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_expression, 3, 0, 33),
  [2529] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option_member, 2, 0, 0),
  [2531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_member, 2, 0, 0),
  [2533] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_type, 2, 0, 42),
  [2535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_type, 2, 0, 42),
  [2537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1033),
  [2539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option_member, 1, 0, 0),
  [2541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_member, 1, 0, 0),
  [2543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 3, 0, 29),
  [2545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 3, 0, 29),
  [2547] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_expression, 4, 0, 54),
  [2549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_expression, 4, 0, 54),
  [2551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean, 1, 0, 0),
  [2553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean, 1, 0, 0),
  [2555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 4, 0, 51),
  [2557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 4, 0, 51),
  [2559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8410),
  [2561] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_expression, 5, 0, 68),
  [2563] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_expression, 5, 0, 68),
  [2565] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 2, 0, 20),
  [2567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 2, 0, 20),
  [2569] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dictionary_type, 7, 0, 135),
  [2571] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary_type, 7, 0, 135),
  [2573] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_type, 5, 0, 91),
  [2575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_type, 5, 0, 91),
  [2577] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type, 6, 0, 123),
  [2579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type, 6, 0, 123),
  [2581] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type, 7, 0, 134),
  [2583] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type, 7, 0, 134),
  [2585] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_basic_type, 1, 0, 0),
  [2587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_basic_type, 1, 0, 0),
  [2589] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_specification, 1, 0, 0),
  [2591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_specification, 1, 0, 0),
  [2593] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 3, 0, 36),
  [2595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 3, 0, 36),
  [2597] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 29),
  [2599] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 29),
  [2601] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_literal, 3, 0, 29),
  [2603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_literal, 3, 0, 29),
  [2605] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_literal, 4, 0, 51),
  [2607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_literal, 4, 0, 51),
  [2609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_database_reference, 3, 0, 30),
  [2611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_database_reference, 3, 0, 30),
  [2613] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_text_type, 1, 0, 0),
  [2615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_text_type, 1, 0, 0),
  [2617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12552),
  [2619] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_code_type, 1, 0, 0),
  [2621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_code_type, 1, 0, 0),
  [2623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12554),
  [2625] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_reference_type, 2, 0, 43),
  [2627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_reference_type, 2, 0, 43),
  [2629] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dotnet_type, 2, 0, 42),
  [2631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dotnet_type, 2, 0, 42),
  [2633] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_type, 3, 0, 42),
  [2635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_type, 3, 0, 42),
  [2637] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_literal, 2, 0, 0),
  [2639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_literal, 2, 0, 0),
  [2641] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_text_type, 4, 0, 75),
  [2643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_text_type, 4, 0, 75),
  [2645] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_code_type, 4, 0, 75),
  [2647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_code_type, 4, 0, 75),
  [2649] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option_type, 2, 0, 0),
  [2651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_type, 2, 0, 0),
  [2653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8375),
  [2655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2882),
  [2657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3084),
  [2659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2897),
  [2661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2905),
  [2663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2964),
  [2665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2974),
  [2667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2978),
  [2669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2981),
  [2671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2982),
  [2673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2983),
  [2675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3201),
  [2677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1286),
  [2679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1295),
  [2681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2985),
  [2683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2995),
  [2685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3006),
  [2687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3011),
  [2689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3014),
  [2691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3016),
  [2693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3017),
  [2695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3021),
  [2697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3027),
  [2699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3042),
  [2701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3085),
  [2703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [2705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2901),
  [2707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8425),
  [2709] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__namespaced_or_simple_ref_repeat1, 2, 0, 0), SHIFT_REPEAT(8425),
  [2712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2838),
  [2714] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0), SHIFT_REPEAT(100),
  [2717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2771),
  [2719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8337),
  [2721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1143),
  [2723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8336),
  [2725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12616),
  [2727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12617),
  [2729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8427),
  [2731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2936),
  [2733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3007),
  [2735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_asserterror_statement, 1, 0, 0),
  [2737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(980),
  [2739] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_asserterror_statement, 1, 0, 0),
  [2741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(980),
  [2743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2935),
  [2745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2937),
  [2747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [2749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1302),
  [2751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2939),
  [2753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2940),
  [2755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2941),
  [2757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2942),
  [2759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2943),
  [2761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2944),
  [2763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2945),
  [2765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2946),
  [2767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2947),
  [2769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2948),
  [2771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2949),
  [2773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2950),
  [2775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2951),
  [2777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2952),
  [2779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2953),
  [2781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2954),
  [2783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2955),
  [2785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3008),
  [2787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2938),
  [2789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 2, 0, 0),
  [2791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [2793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3003),
  [2795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8401),
  [2797] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0), SHIFT_REPEAT(623),
  [2800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [2802] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__namespaced_or_simple_ref_repeat1, 2, 0, 0), SHIFT_REPEAT(8401),
  [2805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2807),
  [2807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8491),
  [2809] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(11694),
  [2812] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(12333),
  [2815] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(11995),
  [2818] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(12588),
  [2821] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(8384),
  [2824] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(8445),
  [2827] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(8535),
  [2830] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(11243),
  [2833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1237),
  [2835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8485),
  [2837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12155),
  [2839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12157),
  [2841] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_endif, 1, 0, 0),
  [2843] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_endif, 1, 0, 0),
  [2845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3569),
  [2847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12304),
  [2849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12395),
  [2851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12396),
  [2853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11159),
  [2855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12397),
  [2857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12627),
  [2859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12398),
  [2861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12399),
  [2863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12267),
  [2865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12400),
  [2867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12401),
  [2869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12402),
  [2871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12403),
  [2873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12337),
  [2875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9836),
  [2877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9909),
  [2879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3594),
  [2881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3888),
  [2883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8472),
  [2885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8277),
  [2887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2627),
  [2889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11148),
  [2891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12378),
  [2893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8563),
  [2895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11274),
  [2897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11277),
  [2899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11280),
  [2901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11282),
  [2903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11287),
  [2905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12404),
  [2907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12405),
  [2909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12406),
  [2911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12407),
  [2913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12408),
  [2915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12409),
  [2917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12649),
  [2919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12650),
  [2921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12651),
  [2923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11288),
  [2925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11292),
  [2927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11294),
  [2929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11296),
  [2931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11303),
  [2933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11326),
  [2935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11329),
  [2937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12667),
  [2939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1498),
  [2941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [2943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12595),
  [2945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1425),
  [2947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1514),
  [2949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1498),
  [2951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1091),
  [2953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [2955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1368),
  [2957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11317),
  [2959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12287),
  [2961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12288),
  [2963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12289),
  [2965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12290),
  [2967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12291),
  [2969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12292),
  [2971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12293),
  [2973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12294),
  [2975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12295),
  [2977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3267),
  [2979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12296),
  [2981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12297),
  [2983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12298),
  [2985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12299),
  [2987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12300),
  [2989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12301),
  [2991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12630),
  [2993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12631),
  [2995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12632),
  [2997] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1498),
  [3000] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(12595),
  [3003] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1496),
  [3006] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1440),
  [3009] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1514),
  [3012] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1437),
  [3015] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1438),
  [3018] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1439),
  [3021] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(1498),
  [3024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4842),
  [3026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4840),
  [3028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4841),
  [3030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4599),
  [3032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8135),
  [3034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8136),
  [3036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11617),
  [3038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11618),
  [3040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11633),
  [3042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4788),
  [3044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4789),
  [3046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4790),
  [3048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8833),
  [3050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8188),
  [3052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4842),
  [3054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4867),
  [3056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2829),
  [3058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6346),
  [3060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3372),
  [3062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11420),
  [3064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7697),
  [3066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4856),
  [3068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4958),
  [3070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2829),
  [3072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9639),
  [3074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3369),
  [3076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6811),
  [3078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6346),
  [3080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4852),
  [3082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5385),
  [3084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5387),
  [3086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6855),
  [3088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6873),
  [3090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6875),
  [3092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2551),
  [3094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7882),
  [3096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7883),
  [3098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12022),
  [3100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11921),
  [3102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12529),
  [3104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6852),
  [3106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6853),
  [3108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6854),
  [3110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6855),
  [3112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1231),
  [3114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1226),
  [3116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1243),
  [3118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(235),
  [3120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8161),
  [3122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8162),
  [3124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12166),
  [3126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12140),
  [3128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12578),
  [3130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1228),
  [3132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1229),
  [3134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1230),
  [3136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1231),
  [3138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6040),
  [3140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6030),
  [3142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6033),
  [3144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2094),
  [3146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7852),
  [3148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7853),
  [3150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12182),
  [3152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12167),
  [3154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12586),
  [3156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6036),
  [3158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6037),
  [3160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6039),
  [3162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6040),
  [3164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8918),
  [3166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8844),
  [3168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8813),
  [3170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3463),
  [3172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7797),
  [3174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7798),
  [3176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12088),
  [3178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12023),
  [3180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12548),
  [3182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8857),
  [3184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8888),
  [3186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8912),
  [3188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8918),
  [3190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1036),
  [3192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1029),
  [3194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1030),
  [3196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(90),
  [3198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7908),
  [3200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7909),
  [3202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12190),
  [3204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12183),
  [3206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12594),
  [3208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1019),
  [3210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1028),
  [3212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1023),
  [3214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [3216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1146),
  [3218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1131),
  [3220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1139),
  [3222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(97),
  [3224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7967),
  [3226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7968),
  [3228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12198),
  [3230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12191),
  [3232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12597),
  [3234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1128),
  [3236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1137),
  [3238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1140),
  [3240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1146),
  [3242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1395),
  [3244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11920),
  [3246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2206),
  [3248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2195),
  [3250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2196),
  [3252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1369),
  [3254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8092),
  [3256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8093),
  [3258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12219),
  [3260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12213),
  [3262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12606),
  [3264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2199),
  [3266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2201),
  [3268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2205),
  [3270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2206),
  [3272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7403),
  [3274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7328),
  [3276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7329),
  [3278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2725),
  [3280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7974),
  [3282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7975),
  [3284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12139),
  [3286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12089),
  [3288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12564),
  [3290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7400),
  [3292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7401),
  [3294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7402),
  [3296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7403),
  [3298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1507),
  [3300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1500),
  [3302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1501),
  [3304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1246),
  [3306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7859),
  [3308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7860),
  [3310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12226),
  [3312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12220),
  [3314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12609),
  [3316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1502),
  [3318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1505),
  [3320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1506),
  [3322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1507),
  [3324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6145),
  [3326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6021),
  [3328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6035),
  [3330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1739),
  [3332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8076),
  [3334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8077),
  [3336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12212),
  [3338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12206),
  [3340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12603),
  [3342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6049),
  [3344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6056),
  [3346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6141),
  [3348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6145),
  [3350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8817),
  [3352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8396),
  [3354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8397),
  [3356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3363),
  [3358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8014),
  [3360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8015),
  [3362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12205),
  [3364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12199),
  [3366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12600),
  [3368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8802),
  [3370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8805),
  [3372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8806),
  [3374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8817),
  [3376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2169),
  [3378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2161),
  [3380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2164),
  [3382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1372),
  [3384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7923),
  [3386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7924),
  [3388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12233),
  [3390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12227),
  [3392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12612),
  [3394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2166),
  [3396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2167),
  [3398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2168),
  [3400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2169),
  [3402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1892),
  [3404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8099),
  [3406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8101),
  [3408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12238),
  [3410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1165),
  [3412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [3414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12394),
  [3416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8583),
  [3418] = {.entry = {.count = 3, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_repeat1, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_layout_repeat1, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat2, 1, 0, 0),
  [3422] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat2, 2, 0, 0), SHIFT_REPEAT(1368),
  [3425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2179),
  [3427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1376),
  [3429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12532),
  [3431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1983),
  [3433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2202),
  [3435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2179),
  [3437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4861),
  [3439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6812),
  [3441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5031),
  [3443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12286),
  [3445] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_repeat1, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_layout_repeat1, 1, 0, 0),
  [3448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2155),
  [3450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1373),
  [3452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11798),
  [3454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2200),
  [3456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1999),
  [3458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2124),
  [3460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2153),
  [3462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2121),
  [3464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2122),
  [3466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2123),
  [3468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2155),
  [3470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1428),
  [3472] = {.entry = {.count = 4, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_link_values_repeat2, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_table_relation_repeat1, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_permissions_repeat1, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_impl_values_repeat2, 1, 0, 0),
  [3477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat2, 1, 0, 0),
  [3479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1424),
  [3481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat2, 2, 0, 0),
  [3483] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(3569),
  [3486] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12394),
  [3489] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12395),
  [3492] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12396),
  [3495] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(11159),
  [3498] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12397),
  [3501] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12627),
  [3504] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12398),
  [3507] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12399),
  [3510] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12267),
  [3513] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12400),
  [3516] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12401),
  [3519] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12402),
  [3522] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12403),
  [3525] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12337),
  [3528] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(9836),
  [3531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0),
  [3533] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(8583),
  [3536] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(8277),
  [3539] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(2627),
  [3542] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(11148),
  [3545] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12378),
  [3548] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(8563),
  [3551] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(11274),
  [3554] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(11277),
  [3557] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(11280),
  [3560] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(11282),
  [3563] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(11287),
  [3566] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12404),
  [3569] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12405),
  [3572] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12406),
  [3575] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12407),
  [3578] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12408),
  [3581] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12409),
  [3584] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12649),
  [3587] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12650),
  [3590] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12651),
  [3593] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(11288),
  [3596] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(11292),
  [3599] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(11294),
  [3602] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(11296),
  [3605] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(11303),
  [3608] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(11326),
  [3611] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(11329),
  [3614] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 2, 0, 0), SHIFT_REPEAT(12667),
  [3617] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(2155),
  [3620] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(11798),
  [3623] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(2200),
  [3626] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(2124),
  [3629] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(2153),
  [3632] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(2121),
  [3635] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(2122),
  [3638] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(2123),
  [3641] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(2155),
  [3644] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(2179),
  [3647] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(12532),
  [3650] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(2159),
  [3653] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(2098),
  [3656] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(2202),
  [3659] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(2095),
  [3662] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(2096),
  [3665] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(2097),
  [3668] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(2179),
  [3671] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_table_relation_repeat1, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_permissions_repeat1, 1, 0, 0),
  [3674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8840),
  [3676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12275),
  [3678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12276),
  [3680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12277),
  [3682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12278),
  [3684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12279),
  [3686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12323),
  [3688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11181),
  [3690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12629),
  [3692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12281),
  [3694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12282),
  [3696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12283),
  [3698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12284),
  [3700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12285),
  [3702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1397),
  [3704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11295),
  [3706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4795),
  [3708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8424),
  [3710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2987),
  [3712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2988),
  [3714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2989),
  [3716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3128),
  [3718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1319),
  [3720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1364),
  [3722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2990),
  [3724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2991),
  [3726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2992),
  [3728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2993),
  [3730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2994),
  [3732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2997),
  [3734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2998),
  [3736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3000),
  [3738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3002),
  [3740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3020),
  [3742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3022),
  [3744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1654),
  [3746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1684),
  [3748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1741),
  [3750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9770),
  [3752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1741),
  [3754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1736),
  [3756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1734),
  [3758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6354),
  [3760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2784),
  [3762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8414),
  [3764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3165),
  [3766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3023),
  [3768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3026),
  [3770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3043),
  [3772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3044),
  [3774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3045),
  [3776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3046),
  [3778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3129),
  [3780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8440),
  [3782] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat2, 2, 0, 0), SHIFT_REPEAT(1424),
  [3785] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__namespaced_or_simple_ref_repeat1, 2, 0, 0), SHIFT_REPEAT(8440),
  [3788] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat2, 2, 0, 0), SHIFT_REPEAT(1428),
  [3791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1515),
  [3793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4347),
  [3795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7160),
  [3797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12352),
  [3799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12353),
  [3801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12354),
  [3803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11242),
  [3805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12355),
  [3807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12482),
  [3809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12356),
  [3811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12357),
  [3813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12545),
  [3815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12358),
  [3817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12359),
  [3819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12360),
  [3821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12361),
  [3823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12266),
  [3825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8494),
  [3827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8323),
  [3829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3253),
  [3831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11124),
  [3833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8383),
  [3835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11402),
  [3837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11410),
  [3839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12203),
  [3841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12217),
  [3843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12241),
  [3845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12362),
  [3847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12363),
  [3849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12364),
  [3851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12365),
  [3853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12366),
  [3855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12367),
  [3857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12641),
  [3859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12642),
  [3861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12643),
  [3863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12263),
  [3865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12326),
  [3867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12477),
  [3869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12491),
  [3871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12498),
  [3873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12507),
  [3875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12515),
  [3877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12502),
  [3879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7162),
  [3881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1251),
  [3883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7098),
  [3885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8413),
  [3887] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1251),
  [3890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7159),
  [3892] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(4347),
  [3895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0),
  [3897] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12352),
  [3900] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12353),
  [3903] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12354),
  [3906] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11242),
  [3909] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12355),
  [3912] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12482),
  [3915] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12356),
  [3918] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12357),
  [3921] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12545),
  [3924] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12358),
  [3927] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12359),
  [3930] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12360),
  [3933] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12361),
  [3936] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12266),
  [3939] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(9836),
  [3942] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(8494),
  [3945] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(8323),
  [3948] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(3253),
  [3951] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11124),
  [3954] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12378),
  [3957] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(8383),
  [3960] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11402),
  [3963] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11410),
  [3966] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12203),
  [3969] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12217),
  [3972] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12241),
  [3975] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12362),
  [3978] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12363),
  [3981] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12364),
  [3984] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12365),
  [3987] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12366),
  [3990] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12367),
  [3993] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12641),
  [3996] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12642),
  [3999] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12643),
  [4002] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12263),
  [4005] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12326),
  [4008] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12477),
  [4011] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12491),
  [4014] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12498),
  [4017] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12507),
  [4020] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12515),
  [4023] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12502),
  [4026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6583),
  [4028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6584),
  [4030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6585),
  [4032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7158),
  [4034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6788),
  [4036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6694),
  [4038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6695),
  [4040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6696),
  [4042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6697),
  [4044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6717),
  [4046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5017),
  [4048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5018),
  [4050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5019),
  [4052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5020),
  [4054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4975),
  [4056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5042),
  [4058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5043),
  [4060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5044),
  [4062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5045),
  [4064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5046),
  [4066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3912),
  [4068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3913),
  [4070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3914),
  [4072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3915),
  [4074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3916),
  [4076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3927),
  [4078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3928),
  [4080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3929),
  [4082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3930),
  [4084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3931),
  [4086] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(11295),
  [4089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7190),
  [4091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7109),
  [4093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7119),
  [4095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7120),
  [4097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7144),
  [4099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6586),
  [4101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11307),
  [4103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11308),
  [4105] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_table_relation_repeat1, 1, 0, 0),
  [4107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2406),
  [4109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2430),
  [4111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2430),
  [4113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2416),
  [4115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6338),
  [4117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2930),
  [4119] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 107),
  [4121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 107),
  [4123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1735),
  [4125] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 108),
  [4127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 108),
  [4129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2427),
  [4131] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 7, 0, 161),
  [4133] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 7, 0, 161),
  [4135] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exit_keyword, 1, 0, 0),
  [4137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exit_keyword, 1, 0, 0),
  [4139] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exit_statement, 1, 0, 0),
  [4141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exit_statement, 1, 0, 0),
  [4143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2783),
  [4145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 4, 0, 103),
  [4147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 4, 0, 103),
  [4149] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 4, 0, 104),
  [4151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 4, 0, 104),
  [4153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 5, 0, 128),
  [4155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 5, 0, 128),
  [4157] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 5, 0, 129),
  [4159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 5, 0, 129),
  [4161] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 6, 0, 141),
  [4163] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 6, 0, 141),
  [4165] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 6, 0, 142),
  [4167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 6, 0, 142),
  [4169] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 7, 0, 160),
  [4171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 7, 0, 160),
  [4173] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 9, 0, 201),
  [4175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 9, 0, 201),
  [4177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 187),
  [4179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 187),
  [4181] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 9, 0, 203),
  [4183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 9, 0, 203),
  [4185] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 9, 0, 197),
  [4187] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 9, 0, 197),
  [4189] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 186),
  [4191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 186),
  [4193] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 10, 0, 82),
  [4195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 10, 0, 82),
  [4197] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 10, 0, 216),
  [4199] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 10, 0, 216),
  [4201] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 10, 0, 217),
  [4203] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 10, 0, 217),
  [4205] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 10, 0, 112),
  [4207] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 10, 0, 112),
  [4209] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 11, 0, 216),
  [4211] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 11, 0, 216),
  [4213] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_empty_statement, 1, 0, 0),
  [4215] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_empty_statement, 1, 0, 0),
  [4217] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 11, 0, 217),
  [4219] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 11, 0, 217),
  [4221] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 11, 0, 230),
  [4223] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 11, 0, 230),
  [4225] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_fragmented_else_tail, 5, 0, 0),
  [4227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_fragmented_else_tail, 5, 0, 0),
  [4229] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 11, 0, 112),
  [4231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 11, 0, 112),
  [4233] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 11, 0, 231),
  [4235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 11, 0, 231),
  [4237] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 11, 0, 232),
  [4239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 11, 0, 232),
  [4241] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 12, 0, 82),
  [4243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 12, 0, 82),
  [4245] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 12, 0, 230),
  [4247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 12, 0, 230),
  [4249] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_fragmented_else_tail, 6, 0, 0),
  [4251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_fragmented_else_tail, 6, 0, 0),
  [4253] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_fragmented_else_tail, 6, 0, 101),
  [4255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_fragmented_else_tail, 6, 0, 101),
  [4257] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 12, 0, 231),
  [4259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 12, 0, 231),
  [4261] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 12, 0, 232),
  [4263] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 12, 0, 232),
  [4265] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 12, 0, 239),
  [4267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 12, 0, 239),
  [4269] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 13, 0, 82),
  [4271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 13, 0, 82),
  [4273] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 13, 0, 244),
  [4275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 13, 0, 244),
  [4277] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 13, 0, 216),
  [4279] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 13, 0, 216),
  [4281] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 13, 0, 217),
  [4283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 13, 0, 217),
  [4285] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_fragmented_else_tail, 7, 0, 101),
  [4287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_fragmented_else_tail, 7, 0, 101),
  [4289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 13, 0, 112),
  [4291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 13, 0, 112),
  [4293] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 13, 0, 239),
  [4295] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 13, 0, 239),
  [4297] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 244),
  [4299] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 244),
  [4301] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 216),
  [4303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 216),
  [4305] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 245),
  [4307] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 245),
  [4309] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 217),
  [4311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 217),
  [4313] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 246),
  [4315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 246),
  [4317] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 230),
  [4319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 230),
  [4321] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 14, 0, 247),
  [4323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 14, 0, 247),
  [4325] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 14, 0, 248),
  [4327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 14, 0, 248),
  [4329] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 14, 0, 249),
  [4331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 14, 0, 249),
  [4333] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 14, 0, 250),
  [4335] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 14, 0, 250),
  [4337] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 14, 0, 251),
  [4339] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 14, 0, 251),
  [4341] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 14, 0, 252),
  [4343] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 14, 0, 252),
  [4345] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 14, 0, 253),
  [4347] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 14, 0, 253),
  [4349] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 14, 0, 254),
  [4351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 14, 0, 254),
  [4353] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 112),
  [4355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 112),
  [4357] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 255),
  [4359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 255),
  [4361] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 231),
  [4363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 231),
  [4365] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 232),
  [4367] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 14, 0, 232),
  [4369] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 245),
  [4371] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 245),
  [4373] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_code_block, 2, 0, 0),
  [4375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1599),
  [4377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_code_block, 2, 0, 0),
  [4379] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_code_block, 3, 0, 0),
  [4381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_code_block, 3, 0, 0),
  [4383] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_code_block, 3, 0, 29),
  [4385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1604),
  [4387] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_code_block, 3, 0, 29),
  [4389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1605),
  [4391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 246),
  [4393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 246),
  [4395] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_code_block, 4, 0, 29),
  [4397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_code_block, 4, 0, 29),
  [4399] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_code_block_end, 8, 0, 0),
  [4401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_code_block_end, 8, 0, 0),
  [4403] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_code_block_end, 9, 0, 0),
  [4405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_code_block_end, 9, 0, 0),
  [4407] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_code_block_end, 9, 0, 168),
  [4409] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_code_block_end, 9, 0, 168),
  [4411] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_code_block_end, 9, 0, 173),
  [4413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_code_block_end, 9, 0, 173),
  [4415] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_code_block_end, 10, 0, 0),
  [4417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_code_block_end, 10, 0, 0),
  [4419] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_code_block_end, 10, 0, 192),
  [4421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_code_block_end, 10, 0, 192),
  [4423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_code_block_end, 10, 0, 124),
  [4425] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_code_block_end, 10, 0, 124),
  [4427] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_code_block_end, 10, 0, 168),
  [4429] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_code_block_end, 10, 0, 168),
  [4431] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_code_block_end, 10, 0, 173),
  [4433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_code_block_end, 10, 0, 173),
  [4435] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_code_block_end, 10, 0, 194),
  [4437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_code_block_end, 10, 0, 194),
  [4439] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_code_block_end, 11, 0, 192),
  [4441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_code_block_end, 11, 0, 192),
  [4443] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_code_block_end, 11, 0, 124),
  [4445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_code_block_end, 11, 0, 124),
  [4447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_code_block_end, 11, 0, 229),
  [4449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_code_block_end, 11, 0, 229),
  [4451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_code_block_end, 11, 0, 194),
  [4453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_code_block_end, 11, 0, 194),
  [4455] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_code_block_end, 12, 0, 229),
  [4457] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_code_block_end, 12, 0, 229),
  [4459] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 230),
  [4461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 230),
  [4463] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 2, 0, 1),
  [4465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 2, 0, 1),
  [4467] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_not_expression, 2, 0, 0),
  [4469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_not_expression, 2, 0, 0),
  [4471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 256),
  [4473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 256),
  [4475] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 15, 0, 257),
  [4477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 15, 0, 257),
  [4479] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 15, 0, 258),
  [4481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 15, 0, 258),
  [4483] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 15, 0, 259),
  [4485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 15, 0, 259),
  [4487] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 15, 0, 260),
  [4489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 15, 0, 260),
  [4491] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 15, 0, 261),
  [4493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 15, 0, 261),
  [4495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 15, 0, 262),
  [4497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 15, 0, 262),
  [4499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 15, 0, 263),
  [4501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 15, 0, 263),
  [4503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 15, 0, 264),
  [4505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 15, 0, 264),
  [4507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 255),
  [4509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 255),
  [4511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 231),
  [4513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 231),
  [4515] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 265),
  [4517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 265),
  [4519] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 232),
  [4521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 232),
  [4523] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 266),
  [4525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 266),
  [4527] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 239),
  [4529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 15, 0, 239),
  [4531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 16, 0, 256),
  [4533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 16, 0, 256),
  [4535] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 16, 0, 265),
  [4537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 16, 0, 265),
  [4539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 16, 0, 266),
  [4541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 16, 0, 266),
  [4543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 16, 0, 239),
  [4545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 16, 0, 239),
  [4547] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 16, 0, 267),
  [4549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 16, 0, 267),
  [4551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 17, 0, 267),
  [4553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 17, 0, 267),
  [4555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 9, 0, 198),
  [4557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 9, 0, 198),
  [4559] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 9, 0, 199),
  [4561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 9, 0, 199),
  [4563] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 9, 0, 200),
  [4565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 9, 0, 200),
  [4567] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement, 1, 0, 45),
  [4569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1653),
  [4571] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement, 1, 0, 45),
  [4573] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_then_begin, 9, 0, 82),
  [4575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_then_begin, 9, 0, 82),
  [4577] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement, 2, 0, 45),
  [4579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement, 2, 0, 45),
  [4581] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat2, 2, 0, 0), SHIFT_REPEAT(1654),
  [4584] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_keyword, 1, 0, 0),
  [4586] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_keyword, 1, 0, 0),
  [4588] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_keyword, 1, 0, 0),
  [4590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_keyword, 1, 0, 0),
  [4592] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement, 1, 0, 0),
  [4594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1665),
  [4596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement, 1, 0, 0),
  [4598] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 1, 0, 0),
  [4600] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 1, 0, 0),
  [4602] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 1, 0, 0),
  [4604] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 1, 0, 0),
  [4606] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 9, 0, 202),
  [4608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 9, 0, 202),
  [4610] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_asserterror_statement, 2, 0, 63),
  [4612] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_asserterror_statement, 2, 0, 63),
  [4614] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement, 2, 0, 0),
  [4616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement, 2, 0, 0),
  [4618] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_statement, 2, 0, 0),
  [4620] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_statement, 2, 0, 0),
  [4622] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_statement, 3, 0, 0),
  [4624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_statement, 3, 0, 0),
  [4626] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_statement, 3, 0, 29),
  [4628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_statement, 3, 0, 29),
  [4630] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exit_statement, 3, 0, 0),
  [4632] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exit_statement, 3, 0, 0),
  [4634] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_statement, 4, 0, 101),
  [4636] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_statement, 4, 0, 101),
  [4638] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_guarded_statement, 4, 0, 103),
  [4640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_guarded_statement, 4, 0, 103),
  [4642] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_guarded_statement, 4, 0, 104),
  [4644] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_guarded_statement, 4, 0, 104),
  [4646] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_statement, 4, 0, 29),
  [4648] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_statement, 4, 0, 29),
  [4650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_statement, 4, 0, 51),
  [4652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_statement, 4, 0, 51),
  [4654] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 4, 0, 109),
  [4656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 4, 0, 109),
  [4658] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__single_pattern, 1, 0, 0),
  [4660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__single_pattern, 1, 0, 0),
  [4662] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__single_pattern, 1, 0, 0), REDUCE(sym__expression, 1, 0, 0),
  [4665] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__single_pattern, 1, 0, 0), REDUCE(sym__expression, 1, 0, 0),
  [4668] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 4, 0, 110),
  [4670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 4, 0, 110),
  [4672] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 4, 0, 111),
  [4674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 4, 0, 111),
  [4676] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exit_statement, 4, 0, 113),
  [4678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exit_statement, 4, 0, 113),
  [4680] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with_statement, 4, 0, 114),
  [4682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_statement, 4, 0, 114),
  [4684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with_statement, 4, 0, 115),
  [4686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_statement, 4, 0, 115),
  [4688] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_statement, 5, 0, 76),
  [4690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_statement, 5, 0, 76),
  [4692] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_statement, 5, 0, 51),
  [4694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_statement, 5, 0, 51),
  [4696] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 5, 0, 109),
  [4698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 5, 0, 109),
  [4700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 6, 0, 143),
  [4702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 6, 0, 143),
  [4704] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 6, 0, 144),
  [4706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 6, 0, 144),
  [4708] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 6, 0, 145),
  [4710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 6, 0, 145),
  [4712] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 6, 0, 146),
  [4714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 6, 0, 146),
  [4716] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_statement, 6, 0, 97),
  [4718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_statement, 6, 0, 97),
  [4720] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 147),
  [4722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 147),
  [4724] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 148),
  [4726] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 148),
  [4728] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 149),
  [4730] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 149),
  [4732] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 150),
  [4734] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 150),
  [4736] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 6, 0, 109),
  [4738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 6, 0, 109),
  [4740] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreach_statement, 6, 0, 154),
  [4742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreach_statement, 6, 0, 154),
  [4744] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreach_statement, 6, 0, 155),
  [4746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreach_statement, 6, 0, 155),
  [4748] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 7, 0, 162),
  [4750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 7, 0, 162),
  [4752] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 7, 0, 163),
  [4754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 7, 0, 163),
  [4756] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 7, 0, 164),
  [4758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 7, 0, 164),
  [4760] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 7, 0, 165),
  [4762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 7, 0, 165),
  [4764] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 7, 0, 166),
  [4766] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 7, 0, 166),
  [4768] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 7, 0, 167),
  [4770] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 7, 0, 167),
  [4772] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 8, 0, 174),
  [4774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 8, 0, 174),
  [4776] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 8, 0, 175),
  [4778] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 8, 0, 175),
  [4780] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 8, 0, 176),
  [4782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 8, 0, 176),
  [4784] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_statement, 8, 0, 177),
  [4786] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_statement, 8, 0, 177),
  [4788] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 8, 0, 178),
  [4790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 8, 0, 178),
  [4792] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 8, 0, 179),
  [4794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 8, 0, 179),
  [4796] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 8, 0, 181),
  [4798] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 8, 0, 181),
  [4800] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 8, 0, 182),
  [4802] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 8, 0, 182),
  [4804] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_if_else_statement, 9, 0, 204),
  [4806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_if_else_statement, 9, 0, 204),
  [4808] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elif, 2, 0, 1),
  [4810] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif, 2, 0, 1),
  [4812] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_case_repeat2, 1, 0, 0), REDUCE(aux_sym_preproc_split_case_branch_repeat2, 1, 0, 0),
  [4815] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_then_keyword, 1, 0, 0),
  [4817] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_then_keyword, 1, 0, 0),
  [4819] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_keyword, 1, 0, 0),
  [4821] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_keyword, 1, 0, 0),
  [4823] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__single_pattern, 3, 0, 36),
  [4825] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__single_pattern, 3, 0, 36),
  [4827] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__single_pattern, 3, 0, 36), REDUCE(sym__expression, 3, 0, 36),
  [4830] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__single_pattern, 3, 0, 36), REDUCE(sym__expression, 3, 0, 36),
  [4833] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_repeat1, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_actions_repeat1, 1, 0, 0),
  [4836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5949),
  [4838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1769),
  [4840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12433),
  [4842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5931),
  [4844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5089),
  [4846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5754),
  [4848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5422),
  [4850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5778),
  [4852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5779),
  [4854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5751),
  [4856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5949),
  [4858] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_case_repeat2, 1, 0, 0),
  [4860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_case_repeat2, 2, 0, 0),
  [4862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2778),
  [4864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1766),
  [4866] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__statement, 2, 0, 45), REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 45),
  [4869] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__statement, 2, 0, 45), REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 45),
  [4872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2415),
  [4874] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 1, 0, 45),
  [4876] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_body_repeat1, 1, 0, 45),
  [4878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1840),
  [4880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1844),
  [4882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1845),
  [4884] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(12433),
  [4887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2016),
  [4889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1911),
  [4891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1934),
  [4893] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0), SHIFT_REPEAT(2406),
  [4896] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0), SHIFT_REPEAT(2888),
  [4899] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0), SHIFT_REPEAT(2159),
  [4902] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0), SHIFT_REPEAT(2430),
  [4905] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0), SHIFT_REPEAT(3097),
  [4908] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0), SHIFT_REPEAT(2098),
  [4911] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0), SHIFT_REPEAT(2808),
  [4914] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0), SHIFT_REPEAT(9770),
  [4917] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0), SHIFT_REPEAT(2888),
  [4920] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0),
  [4922] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0), SHIFT_REPEAT(2134),
  [4925] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0), SHIFT_REPEAT(2430),
  [4928] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0),
  [4930] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0), SHIFT_REPEAT(2095),
  [4933] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0), SHIFT_REPEAT(2096),
  [4936] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0), SHIFT_REPEAT(2097),
  [4939] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0), SHIFT_REPEAT(2416),
  [4942] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_case_repeat1, 2, 0, 0), SHIFT_REPEAT(6338),
  [4945] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 8, 0, 47),
  [4947] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 8, 0, 47),
  [4949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8431),
  [4951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3168),
  [4953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3171),
  [4955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3172),
  [4957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3133),
  [4959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1360),
  [4961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1361),
  [4963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3174),
  [4965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3175),
  [4967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3176),
  [4969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3179),
  [4971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3180),
  [4973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3182),
  [4975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3184),
  [4977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3185),
  [4979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3186),
  [4981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3187),
  [4983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3188),
  [4985] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_object, 2, 0, 0),
  [4987] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_object, 2, 0, 0),
  [4989] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_declaration, 3, 0, 2),
  [4991] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_declaration, 3, 0, 2),
  [4993] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_statement, 3, 0, 3),
  [4995] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_statement, 3, 0, 3),
  [4997] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_object, 3, 0, 0),
  [4999] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_object, 3, 0, 0),
  [5001] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dotnet_declaration, 3, 0, 0),
  [5003] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dotnet_declaration, 3, 0, 0),
  [5005] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 4, 0, 4),
  [5007] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 4, 0, 4),
  [5009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_profile_declaration, 4, 0, 4),
  [5011] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_profile_declaration, 4, 0, 4),
  [5013] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_entitlement_declaration, 4, 0, 4),
  [5015] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_entitlement_declaration, 4, 0, 4),
  [5017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_object, 4, 0, 0),
  [5019] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_object, 4, 0, 0),
  [5021] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_controladdin_declaration, 4, 0, 4),
  [5023] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_controladdin_declaration, 4, 0, 4),
  [5025] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dotnet_declaration, 4, 0, 0),
  [5027] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dotnet_declaration, 4, 0, 0),
  [5029] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_declaration, 5, 0, 5),
  [5031] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table_declaration, 5, 0, 5),
  [5033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_page_declaration, 5, 0, 5),
  [5035] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_page_declaration, 5, 0, 5),
  [5037] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_report_declaration, 5, 0, 5),
  [5039] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_report_declaration, 5, 0, 5),
  [5041] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_query_declaration, 5, 0, 5),
  [5043] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_query_declaration, 5, 0, 5),
  [5045] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 5, 0, 4),
  [5047] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 5, 0, 4),
  [5049] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_profile_declaration, 5, 0, 4),
  [5051] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_profile_declaration, 5, 0, 4),
  [5053] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_entitlement_declaration, 5, 0, 4),
  [5055] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_entitlement_declaration, 5, 0, 4),
  [5057] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_object, 5, 0, 0),
  [5059] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_object, 5, 0, 0),
  [5061] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 5, 0, 6),
  [5063] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 5, 0, 6),
  [5065] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_codeunit_declaration, 5, 0, 5),
  [5067] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_codeunit_declaration, 5, 0, 5),
  [5069] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_xmlport_declaration, 5, 0, 5),
  [5071] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_xmlport_declaration, 5, 0, 5),
  [5073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 5, 0, 5),
  [5075] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 5, 0, 5),
  [5077] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_controladdin_declaration, 5, 0, 4),
  [5079] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_controladdin_declaration, 5, 0, 4),
  [5081] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_permissionset_declaration, 5, 0, 5),
  [5083] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_permissionset_declaration, 5, 0, 5),
  [5085] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_declaration, 6, 0, 5),
  [5087] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table_declaration, 6, 0, 5),
  [5089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_page_declaration, 6, 0, 5),
  [5091] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_page_declaration, 6, 0, 5),
  [5093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8437),
  [5095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8444),
  [5097] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_report_declaration, 6, 0, 5),
  [5099] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_report_declaration, 6, 0, 5),
  [5101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_query_declaration, 6, 0, 5),
  [5103] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_query_declaration, 6, 0, 5),
  [5105] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 6, 0, 13),
  [5107] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 6, 0, 13),
  [5109] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_object, 6, 0, 0),
  [5111] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_object, 6, 0, 0),
  [5113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 6, 0, 6),
  [5115] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 6, 0, 6),
  [5117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 6, 0, 14),
  [5119] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 6, 0, 14),
  [5121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_codeunit_declaration, 6, 0, 5),
  [5123] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_codeunit_declaration, 6, 0, 5),
  [5125] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_xmlport_declaration, 6, 0, 5),
  [5127] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_xmlport_declaration, 6, 0, 5),
  [5129] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 6, 0, 5),
  [5131] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 6, 0, 5),
  [5133] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_profileextension_declaration, 6, 0, 17),
  [5135] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_profileextension_declaration, 6, 0, 17),
  [5137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_permissionset_declaration, 6, 0, 5),
  [5139] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_permissionset_declaration, 6, 0, 5),
  [5141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pagecustomization_declaration, 6, 0, 18),
  [5143] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pagecustomization_declaration, 6, 0, 18),
  [5145] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__namespaced_or_simple_ref_repeat1, 2, 0, 0), SHIFT_REPEAT(8437),
  [5148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 7, 0, 26),
  [5150] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 7, 0, 26),
  [5152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 7, 0, 13),
  [5154] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 7, 0, 13),
  [5156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_object, 7, 0, 0),
  [5158] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_object, 7, 0, 0),
  [5160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 7, 0, 27),
  [5162] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 7, 0, 27),
  [5164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 7, 0, 14),
  [5166] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 7, 0, 14),
  [5168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tableextension_declaration, 7, 0, 15),
  [5170] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tableextension_declaration, 7, 0, 15),
  [5172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pageextension_declaration, 7, 0, 15),
  [5174] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pageextension_declaration, 7, 0, 15),
  [5176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_codeunit_declaration, 7, 0, 5),
  [5178] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_codeunit_declaration, 7, 0, 5),
  [5180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reportextension_declaration, 7, 0, 15),
  [5182] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_reportextension_declaration, 7, 0, 15),
  [5184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 7, 0, 5),
  [5186] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 7, 0, 5),
  [5188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumextension_declaration, 7, 0, 15),
  [5190] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enumextension_declaration, 7, 0, 15),
  [5192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_profileextension_declaration, 7, 0, 17),
  [5194] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_profileextension_declaration, 7, 0, 17),
  [5196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_permissionsetextension_declaration, 7, 0, 15),
  [5198] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_permissionsetextension_declaration, 7, 0, 15),
  [5200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pagecustomization_declaration, 7, 0, 18),
  [5202] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pagecustomization_declaration, 7, 0, 18),
  [5204] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__namespaced_or_simple_ref_repeat1, 2, 0, 0), SHIFT_REPEAT(8444),
  [5207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8406),
  [5209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2918),
  [5211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2920),
  [5213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2921),
  [5215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3098),
  [5217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1314),
  [5219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1311),
  [5221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2926),
  [5223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2927),
  [5225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2928),
  [5227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2929),
  [5229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2933),
  [5231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2959),
  [5233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2960),
  [5235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2962),
  [5237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2963),
  [5239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2965),
  [5241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2967),
  [5243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2971),
  [5245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2972),
  [5247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2976),
  [5249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2984),
  [5251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2986),
  [5253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2996),
  [5255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3113),
  [5257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2791),
  [5259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8423),
  [5261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 8, 0, 26),
  [5263] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 8, 0, 26),
  [5265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_object, 8, 0, 0),
  [5267] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_object, 8, 0, 0),
  [5269] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 8, 0, 27),
  [5271] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 8, 0, 27),
  [5273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2862),
  [5275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pageextension_declaration, 8, 0, 15),
  [5277] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pageextension_declaration, 8, 0, 15),
  [5279] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reportextension_declaration, 8, 0, 15),
  [5281] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_reportextension_declaration, 8, 0, 15),
  [5283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumextension_declaration, 8, 0, 15),
  [5285] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enumextension_declaration, 8, 0, 15),
  [5287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_permissionsetextension_declaration, 8, 0, 15),
  [5289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_permissionsetextension_declaration, 8, 0, 15),
  [5291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3189),
  [5293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3190),
  [5295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3191),
  [5297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3194),
  [5299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3197),
  [5301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3198),
  [5303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3134),
  [5305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 9, 0, 65),
  [5307] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 9, 0, 65),
  [5309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 9, 0, 66),
  [5311] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 9, 0, 66),
  [5313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 9, 0, 47),
  [5315] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 9, 0, 47),
  [5317] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 10, 0, 65),
  [5319] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 10, 0, 65),
  [5321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 10, 0, 66),
  [5323] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 10, 0, 66),
  [5325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 10, 0, 87),
  [5327] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 10, 0, 87),
  [5329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 10, 0, 88),
  [5331] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 10, 0, 88),
  [5333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2866),
  [5335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2786),
  [5337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8399),
  [5339] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 11, 0, 120),
  [5341] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 11, 0, 120),
  [5343] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 11, 0, 87),
  [5345] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 11, 0, 87),
  [5347] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 11, 0, 88),
  [5349] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 11, 0, 88),
  [5351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 11, 0, 121),
  [5353] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 11, 0, 121),
  [5355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 12, 0, 120),
  [5357] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 12, 0, 120),
  [5359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 12, 0, 132),
  [5361] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 12, 0, 132),
  [5363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 12, 0, 133),
  [5365] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 12, 0, 133),
  [5367] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 12, 0, 121),
  [5369] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 12, 0, 121),
  [5371] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 13, 0, 132),
  [5373] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 13, 0, 132),
  [5375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 13, 0, 133),
  [5377] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 13, 0, 133),
  [5379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 13, 0, 156),
  [5381] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 13, 0, 156),
  [5383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_declaration, 14, 0, 156),
  [5385] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_declaration, 14, 0, 156),
  [5387] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tableextension_declaration, 8, 0, 15),
  [5389] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tableextension_declaration, 8, 0, 15),
  [5391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5930),
  [5393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2150),
  [5395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11601),
  [5397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5972),
  [5399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5840),
  [5401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5973),
  [5403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5929),
  [5405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5967),
  [5407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5969),
  [5409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5970),
  [5411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5930),
  [5413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1380),
  [5415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2137),
  [5417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8422),
  [5419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1379),
  [5421] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1380),
  [5424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2187),
  [5426] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1379),
  [5429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8398),
  [5431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2527),
  [5433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2886),
  [5435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11322),
  [5437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11323),
  [5439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1527),
  [5441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1527),
  [5443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11289),
  [5445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11290),
  [5447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_else, 1, 0, 0),
  [5449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else, 1, 0, 0),
  [5451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5908),
  [5453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6345),
  [5455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6213),
  [5457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6345),
  [5459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6198),
  [5461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6322),
  [5463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2767),
  [5465] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(5840),
  [5468] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(5930),
  [5471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2270),
  [5473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2285),
  [5475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2398),
  [5477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2278),
  [5479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2292),
  [5481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10011),
  [5483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2391),
  [5485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1694),
  [5487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1683),
  [5489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1933),
  [5491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1781),
  [5493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2295),
  [5495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10005),
  [5497] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat2, 2, 0, 0), SHIFT_REPEAT(2415),
  [5500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10763),
  [5502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5140),
  [5504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11138),
  [5506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10564),
  [5508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12338),
  [5510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12390),
  [5512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9878),
  [5514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5968),
  [5516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7622),
  [5518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8586),
  [5520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8287),
  [5522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2627),
  [5524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11148),
  [5526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12378),
  [5528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8577),
  [5530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11304),
  [5532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11305),
  [5534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11306),
  [5536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11309),
  [5538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11310),
  [5540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10599),
  [5542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11312),
  [5544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11314),
  [5546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11315),
  [5548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11321),
  [5550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11324),
  [5552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11325),
  [5554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10763),
  [5556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11302),
  [5558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11167),
  [5560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7554),
  [5562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3856),
  [5564] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_repeat_keyword, 1, 0, 0),
  [5566] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeat_keyword, 1, 0, 0),
  [5568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2973),
  [5570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5508),
  [5572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4760),
  [5574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5030),
  [5576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7050),
  [5578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6911),
  [5580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12342),
  [5582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12343),
  [5584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12344),
  [5586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12345),
  [5588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12346),
  [5590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12584),
  [5592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11150),
  [5594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12640),
  [5596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12347),
  [5598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12348),
  [5600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12349),
  [5602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4618),
  [5604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11180),
  [5606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12350),
  [5608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12351),
  [5610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2032),
  [5612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3167),
  [5614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2170),
  [5616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3132),
  [5618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3167),
  [5620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9744),
  [5622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4862),
  [5624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2105),
  [5626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2170),
  [5628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2112),
  [5630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6339),
  [5632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6979),
  [5634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5984),
  [5636] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_keyword, 1, 0, 0),
  [5638] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_keyword, 1, 0, 0),
  [5640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7264),
  [5642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5946),
  [5644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7317),
  [5646] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(4347),
  [5649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0),
  [5651] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12342),
  [5654] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12343),
  [5657] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11242),
  [5660] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12344),
  [5663] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12482),
  [5666] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12345),
  [5669] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12346),
  [5672] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12584),
  [5675] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11150),
  [5678] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12640),
  [5681] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12347),
  [5684] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12348),
  [5687] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12349),
  [5690] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12266),
  [5693] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(9836),
  [5696] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(8494),
  [5699] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(8323),
  [5702] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(4618),
  [5705] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11180),
  [5708] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12378),
  [5711] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(8383),
  [5714] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11402),
  [5717] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11410),
  [5720] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12203),
  [5723] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12217),
  [5726] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12241),
  [5729] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12350),
  [5732] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12351),
  [5735] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12263),
  [5738] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12326),
  [5741] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12477),
  [5744] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12491),
  [5747] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12498),
  [5750] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12507),
  [5753] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12515),
  [5756] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_action_group_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12502),
  [5759] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2406),
  [5762] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2888),
  [5765] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2159),
  [5768] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2430),
  [5771] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3097),
  [5774] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2098),
  [5777] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2808),
  [5780] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0),
  [5782] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9709),
  [5785] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2888),
  [5788] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2134),
  [5791] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2430),
  [5794] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2095),
  [5797] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2096),
  [5800] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2097),
  [5803] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2416),
  [5806] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6338),
  [5809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5843),
  [5811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11141),
  [5813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12648),
  [5815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12473),
  [5817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12368),
  [5819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12324),
  [5821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12447),
  [5823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9743),
  [5825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9710),
  [5827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6273),
  [5829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5512),
  [5831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8636),
  [5833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8299),
  [5835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3661),
  [5837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11246),
  [5839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8579),
  [5841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12108),
  [5843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12112),
  [5845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12113),
  [5847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12115),
  [5849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12116),
  [5851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11780),
  [5853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12117),
  [5855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12119),
  [5857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12121),
  [5859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12122),
  [5861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12123),
  [5863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12124),
  [5865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12590),
  [5867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8633),
  [5869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6550),
  [5871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12645),
  [5873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12330),
  [5875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12638),
  [5877] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_filter_value_repeat1, 1, 0, 0),
  [5879] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(aux_sym_filter_value_repeat1, 1, 0, 0),
  [5882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2794),
  [5884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_filter_value_repeat1, 1, 0, 0),
  [5886] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(aux_sym_filter_value_repeat1, 1, 0, 0),
  [5889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8374),
  [5891] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat2, 2, 0, 0), SHIFT_REPEAT(2527),
  [5894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8373),
  [5896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_case_patterns, 2, 0, 0),
  [5898] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_case, 2, 0, 0),
  [5900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6824),
  [5902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2553),
  [5904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12209),
  [5906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6808),
  [5908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6690),
  [5910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6828),
  [5912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6841),
  [5914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6835),
  [5916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6821),
  [5918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6837),
  [5920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6824),
  [5922] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_case_patterns, 3, 0, 0),
  [5924] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_case, 3, 0, 0),
  [5926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2716),
  [5928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2158),
  [5930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2158),
  [5932] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__literal_value, 1, 0, 0),
  [5934] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__literal_value, 1, 0, 0),
  [5936] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__literal_value, 1, 0, 0), REDUCE(aux_sym_filter_value_repeat1, 1, 0, 0),
  [5939] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__literal_value, 1, 0, 0), REDUCE(aux_sym_filter_value_repeat1, 1, 0, 0),
  [5942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12652),
  [5944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12635),
  [5946] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_case_branch_repeat2, 1, 0, 0),
  [5948] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_case_branch_repeat2, 2, 0, 29),
  [5950] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 52), SHIFT_REPEAT(2032),
  [5953] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 52), SHIFT_REPEAT(3167),
  [5956] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 52), SHIFT_REPEAT(2200),
  [5959] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 52), SHIFT_REPEAT(2170),
  [5962] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 52), SHIFT_REPEAT(3132),
  [5965] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 52), SHIFT_REPEAT(2124),
  [5968] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 52), SHIFT_REPEAT(2808),
  [5971] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 52), SHIFT_REPEAT(3167),
  [5974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 52),
  [5976] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 52), SHIFT_REPEAT(2105),
  [5979] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 52), SHIFT_REPEAT(2170),
  [5982] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 52), SHIFT_REPEAT(2121),
  [5985] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 52), SHIFT_REPEAT(2122),
  [5988] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 52), SHIFT_REPEAT(2123),
  [5991] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 52), SHIFT_REPEAT(2112),
  [5994] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 52), SHIFT_REPEAT(6339),
  [5997] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0),
  [5999] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__literal_value, 1, 0, 0), REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0),
  [6002] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0),
  [6004] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__literal_value, 1, 0, 0), REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0),
  [6007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8690),
  [6009] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(6690),
  [6012] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(6824),
  [6015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6228),
  [6017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4765),
  [6019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6228),
  [6021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6347),
  [6023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4916),
  [6025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6347),
  [6027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_var_repeat2, 2, 0, 0),
  [6029] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_var_repeat2, 1, 0, 0),
  [6031] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(10763),
  [6034] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(5140),
  [6037] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(3884),
  [6040] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(11138),
  [6043] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(10564),
  [6046] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(12338),
  [6049] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(12390),
  [6052] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(9836),
  [6055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0),
  [6057] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(8633),
  [6060] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(8287),
  [6063] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(2627),
  [6066] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(11148),
  [6069] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(12378),
  [6072] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(8577),
  [6075] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(11304),
  [6078] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(11305),
  [6081] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(11306),
  [6084] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(11309),
  [6087] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(11310),
  [6090] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(10599),
  [6093] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(11312),
  [6096] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(11314),
  [6099] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(11315),
  [6102] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(11321),
  [6105] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(11324),
  [6108] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(11325),
  [6111] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(10763),
  [6114] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(11302),
  [6117] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_var_repeat1, 2, 0, 0), SHIFT_REPEAT(11167),
  [6120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [6122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_case_patterns, 5, 0, 51),
  [6124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [6126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [6128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [6130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [6132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [6134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [6136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [6138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [6140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_case_patterns, 3, 0, 29),
  [6142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [6144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [6146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [6148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [6150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [6152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [6154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [6156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [6158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_case_patterns, 4, 0, 101),
  [6160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_case_patterns, 6, 0, 97),
  [6162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [6164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_case_patterns, 4, 0, 51),
  [6166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_case_patterns, 4, 0, 29),
  [6168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [6170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [6172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_case_patterns, 5, 0, 76),
  [6174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [6176] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__case_pattern, 2, 0, 52), SHIFT_REPEAT(2406),
  [6179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__case_pattern, 2, 0, 52),
  [6181] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__case_pattern, 2, 0, 52), SHIFT_REPEAT(2888),
  [6184] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__case_pattern, 2, 0, 52), SHIFT_REPEAT(2159),
  [6187] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__case_pattern, 2, 0, 52), SHIFT_REPEAT(2430),
  [6190] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__case_pattern, 2, 0, 52), SHIFT_REPEAT(3097),
  [6193] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__case_pattern, 2, 0, 52), SHIFT_REPEAT(2098),
  [6196] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__case_pattern, 2, 0, 52), SHIFT_REPEAT(2808),
  [6199] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__case_pattern, 2, 0, 52), SHIFT_REPEAT(9770),
  [6202] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__case_pattern, 2, 0, 52), SHIFT_REPEAT(2888),
  [6205] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__case_pattern, 2, 0, 52), SHIFT_REPEAT(2134),
  [6208] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__case_pattern, 2, 0, 52), SHIFT_REPEAT(2430),
  [6211] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__case_pattern, 2, 0, 52), SHIFT_REPEAT(2095),
  [6214] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__case_pattern, 2, 0, 52), SHIFT_REPEAT(2096),
  [6217] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__case_pattern, 2, 0, 52), SHIFT_REPEAT(2097),
  [6220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__case_pattern, 2, 0, 52), SHIFT_REPEAT(2416),
  [6223] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__case_pattern, 2, 0, 52), SHIFT_REPEAT(6338),
  [6226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [6228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [6230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [6232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [6234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [6236] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(10763),
  [6239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0),
  [6241] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(3884),
  [6244] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0),
  [6246] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(9873),
  [6249] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(10763),
  [6252] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11167),
  [6255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_section, 1, 0, 0),
  [6257] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_section, 1, 0, 0),
  [6259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9873),
  [6261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_section, 3, 0, 0),
  [6263] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_section, 3, 0, 0),
  [6265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_section, 2, 0, 0),
  [6267] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_section, 2, 0, 0),
  [6269] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_xmlport_repeat1, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_repeat1, 1, 0, 0),
  [6272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8695),
  [6274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_xmlport_repeat1, 2, 0, 0),
  [6276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6087),
  [6278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6087),
  [6280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4801),
  [6282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6283),
  [6284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6283),
  [6286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4872),
  [6288] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(5843),
  [6291] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11141),
  [6294] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12648),
  [6297] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12473),
  [6300] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12368),
  [6303] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12324),
  [6306] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12447),
  [6309] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(9743),
  [6312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0),
  [6314] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(8690),
  [6317] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(8299),
  [6320] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(3661),
  [6323] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11246),
  [6326] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12378),
  [6329] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(8579),
  [6332] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12108),
  [6335] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12112),
  [6338] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12113),
  [6341] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12115),
  [6344] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12116),
  [6347] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11780),
  [6350] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12117),
  [6353] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12119),
  [6356] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12121),
  [6359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12122),
  [6362] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12123),
  [6365] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12124),
  [6368] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12590),
  [6371] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_query_repeat1, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_repeat1, 1, 0, 0),
  [6374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_xmlport_repeat1, 1, 0, 0),
  [6376] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_query_repeat1, 1, 0, 0),
  [6378] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(3569),
  [6381] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11159),
  [6384] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12627),
  [6387] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12267),
  [6390] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12337),
  [6393] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(9836),
  [6396] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0),
  [6398] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(8583),
  [6401] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(8277),
  [6404] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(2627),
  [6407] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11148),
  [6410] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12378),
  [6413] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(8563),
  [6416] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11274),
  [6419] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11277),
  [6422] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11280),
  [6425] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11282),
  [6428] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11287),
  [6431] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11288),
  [6434] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11292),
  [6437] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12645),
  [6440] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12330),
  [6443] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12638),
  [6446] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11294),
  [6449] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11296),
  [6452] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11303),
  [6455] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11326),
  [6458] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11329),
  [6461] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12667),
  [6464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_query_repeat1, 2, 0, 0),
  [6466] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat2, 2, 0, 0), SHIFT_REPEAT(2716),
  [6469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_report_repeat1, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_repeat1, 1, 0, 0),
  [6472] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 52), SHIFT_REPEAT(4801),
  [6475] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 52), SHIFT_REPEAT(3142),
  [6478] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 52), SHIFT_REPEAT(4818),
  [6481] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 52), SHIFT_REPEAT(6283),
  [6484] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 52), SHIFT_REPEAT(2875),
  [6487] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 52), SHIFT_REPEAT(4642),
  [6490] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 52), SHIFT_REPEAT(2808),
  [6493] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 52), SHIFT_REPEAT(3142),
  [6496] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 52), SHIFT_REPEAT(4836),
  [6499] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 52), SHIFT_REPEAT(6283),
  [6502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 52),
  [6504] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 52), SHIFT_REPEAT(3353),
  [6507] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 52), SHIFT_REPEAT(3362),
  [6510] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 52), SHIFT_REPEAT(3350),
  [6513] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 52), SHIFT_REPEAT(4872),
  [6516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2526),
  [6518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2734),
  [6520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2556),
  [6522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2555),
  [6524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2727),
  [6526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2546),
  [6528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2547),
  [6530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2555),
  [6532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2543),
  [6534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2544),
  [6536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2545),
  [6538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2549),
  [6540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8562),
  [6542] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(2526),
  [6545] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(2734),
  [6548] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(2556),
  [6551] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(2555),
  [6554] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(2875),
  [6557] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(2723),
  [6560] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(2546),
  [6563] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(2808),
  [6566] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(2829),
  [6569] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(2547),
  [6572] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(2829),
  [6575] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(2555),
  [6578] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(2543),
  [6581] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(2544),
  [6584] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(2545),
  [6587] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(2549),
  [6590] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filter_value_repeat1, 2, 0, 0), SHIFT_REPEAT(6345),
  [6593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7263),
  [6595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2738),
  [6597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12539),
  [6599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7277),
  [6601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7240),
  [6603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7278),
  [6605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7267),
  [6607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7272),
  [6609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7274),
  [6611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7275),
  [6613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7263),
  [6615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filter_value, 1, 0, 0),
  [6617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2723),
  [6619] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(3569),
  [6622] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11159),
  [6625] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12627),
  [6628] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12267),
  [6631] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12337),
  [6634] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(9836),
  [6637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0),
  [6639] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(8583),
  [6642] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(8277),
  [6645] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(2627),
  [6648] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11148),
  [6651] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12378),
  [6654] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(8563),
  [6657] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11274),
  [6660] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11277),
  [6663] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11280),
  [6666] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11282),
  [6669] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11287),
  [6672] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11288),
  [6675] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11292),
  [6678] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12652),
  [6681] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12635),
  [6684] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11294),
  [6687] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11296),
  [6690] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11303),
  [6693] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11326),
  [6696] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11329),
  [6699] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12667),
  [6702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_report_repeat1, 2, 0, 0),
  [6704] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_report_repeat1, 1, 0, 0),
  [6706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4924),
  [6708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4924),
  [6710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2564),
  [6712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6219),
  [6714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11301),
  [6716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6275),
  [6718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6331),
  [6720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6331),
  [6722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3368),
  [6724] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(7263),
  [6727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6221),
  [6729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5988),
  [6731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6221),
  [6733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6236),
  [6735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5997),
  [6737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6236),
  [6739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6328),
  [6741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6328),
  [6743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6237),
  [6745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2178),
  [6747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6237),
  [6749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6234),
  [6751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [6753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6234),
  [6755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6291),
  [6757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2399),
  [6759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6291),
  [6761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6259),
  [6763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7276),
  [6765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6348),
  [6767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6377),
  [6769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6377),
  [6771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6227),
  [6773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [6775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6227),
  [6777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6206),
  [6779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [6781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6206),
  [6783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6267),
  [6785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7592),
  [6787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6349),
  [6789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6380),
  [6791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6380),
  [6793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6317),
  [6795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6317),
  [6797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6205),
  [6799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1132),
  [6801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6205),
  [6803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6297),
  [6805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1918),
  [6807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6297),
  [6809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6320),
  [6811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1676),
  [6813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6320),
  [6815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6208),
  [6817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1433),
  [6819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6208),
  [6821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6223),
  [6823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2147),
  [6825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6223),
  [6827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6244),
  [6829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2120),
  [6831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6244),
  [6833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6295),
  [6835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10178),
  [6837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6295),
  [6839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6245),
  [6841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2100),
  [6843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6245),
  [6845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6220),
  [6847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1220),
  [6849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6220),
  [6851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6241),
  [6853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1523),
  [6855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6241),
  [6857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6249),
  [6859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7623),
  [6861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6344),
  [6863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6376),
  [6865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6376),
  [6867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6262),
  [6869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7285),
  [6871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6357),
  [6873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6374),
  [6875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6374),
  [6877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6246),
  [6879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6315),
  [6881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6315),
  [6883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6353),
  [6885] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_controladdin_repeat1, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_repeat1, 1, 0, 0),
  [6888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6216),
  [6890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1204),
  [6892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6216),
  [6894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6225),
  [6896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4803),
  [6898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6225),
  [6900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6171),
  [6902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6171),
  [6904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6025),
  [6906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6025),
  [6908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6026),
  [6910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6026),
  [6912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6027),
  [6914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6027),
  [6916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6028),
  [6918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6028),
  [6920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6029),
  [6922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6029),
  [6924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6031),
  [6926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6031),
  [6928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6032),
  [6930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6032),
  [6932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6063),
  [6934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6063),
  [6936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6064),
  [6938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6064),
  [6940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6065),
  [6942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6065),
  [6944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6066),
  [6946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6066),
  [6948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6067),
  [6950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6067),
  [6952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6068),
  [6954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6068),
  [6956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6085),
  [6958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6085),
  [6960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6094),
  [6962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6094),
  [6964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6095),
  [6966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6095),
  [6968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6096),
  [6970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6096),
  [6972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6097),
  [6974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6097),
  [6976] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure, 6, 0, 24),
  [6978] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure, 6, 0, 24),
  [6980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4931),
  [6982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4931),
  [6984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6318),
  [6986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6318),
  [6988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4936),
  [6990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4936),
  [6992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6104),
  [6994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6104),
  [6996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6309),
  [6998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6309),
  [7000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4937),
  [7002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4937),
  [7004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1073),
  [7006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [7008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1074),
  [7010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [7012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4940),
  [7014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4940),
  [7016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4941),
  [7018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4941),
  [7020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4951),
  [7022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4951),
  [7024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1075),
  [7026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [7028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4952),
  [7030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4952),
  [7032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4953),
  [7034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4953),
  [7036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5592),
  [7038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2846),
  [7040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5893),
  [7042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3111),
  [7044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2762),
  [7046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2846),
  [7048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5909),
  [7050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5893),
  [7052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5926),
  [7054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4955),
  [7056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4955),
  [7058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4961),
  [7060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4961),
  [7062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4962),
  [7064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4962),
  [7066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4866),
  [7068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4866),
  [7070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4967),
  [7072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4967),
  [7074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4938),
  [7076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4938),
  [7078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4972),
  [7080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4972),
  [7082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4973),
  [7084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4973),
  [7086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4963),
  [7088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4963),
  [7090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4922),
  [7092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4922),
  [7094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5882),
  [7096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5882),
  [7098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5883),
  [7100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5883),
  [7102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5884),
  [7104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5884),
  [7106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4950),
  [7108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4950),
  [7110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4969),
  [7112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4969),
  [7114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2025),
  [7116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2025),
  [7118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5885),
  [7120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5885),
  [7122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5886),
  [7124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5886),
  [7126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5887),
  [7128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5887),
  [7130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2019),
  [7132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2042),
  [7134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2785),
  [7136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2042),
  [7138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2090),
  [7140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2033),
  [7142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2033),
  [7144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4870),
  [7146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4870),
  [7148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5888),
  [7150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5888),
  [7152] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure, 6, 0, 46),
  [7154] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure, 6, 0, 46),
  [7156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5889),
  [7158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5889),
  [7160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_controladdin_repeat1, 1, 0, 0),
  [7162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6292),
  [7164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6292),
  [7166] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure, 7, 0, 62),
  [7168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure, 7, 0, 62),
  [7170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5871),
  [7172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5871),
  [7174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5911),
  [7176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5911),
  [7178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5892),
  [7180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5892),
  [7182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1088),
  [7184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [7186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5894),
  [7188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5894),
  [7190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5895),
  [7192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5895),
  [7194] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(3569),
  [7197] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11159),
  [7200] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12627),
  [7203] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12267),
  [7206] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12337),
  [7209] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(9836),
  [7212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0),
  [7214] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(8562),
  [7217] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(8277),
  [7220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(2627),
  [7223] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11148),
  [7226] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12378),
  [7229] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(8563),
  [7232] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11274),
  [7235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11277),
  [7238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11280),
  [7241] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11282),
  [7244] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11287),
  [7247] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11288),
  [7250] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11292),
  [7253] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11294),
  [7256] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11296),
  [7259] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11303),
  [7262] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11326),
  [7265] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11329),
  [7268] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12667),
  [7271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2162),
  [7273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2162),
  [7275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2163),
  [7277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2163),
  [7279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2046),
  [7281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2046),
  [7283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5896),
  [7285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5896),
  [7287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5897),
  [7289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5897),
  [7291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5898),
  [7293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5898),
  [7295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5899),
  [7297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5899),
  [7299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5900),
  [7301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5900),
  [7303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5902),
  [7305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5902),
  [7307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5903),
  [7309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5903),
  [7311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5904),
  [7313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5904),
  [7315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1089),
  [7317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [7319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2165),
  [7321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2165),
  [7323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6272),
  [7325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6272),
  [7327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6304),
  [7329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6304),
  [7331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1090),
  [7333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1090),
  [7335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6290),
  [7337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6290),
  [7339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6319),
  [7341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6319),
  [7343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1070),
  [7345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [7347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1167),
  [7349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1167),
  [7351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(981),
  [7353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [7355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6326),
  [7357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6326),
  [7359] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_var, 2, 0, 0),
  [7361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_var, 2, 0, 0),
  [7363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(982),
  [7365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [7367] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure, 7, 0, 83),
  [7369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure, 7, 0, 83),
  [7371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure, 7, 0, 46),
  [7373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure, 7, 0, 46),
  [7375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure, 8, 0, 62),
  [7377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure, 8, 0, 62),
  [7379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6316),
  [7381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6316),
  [7383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2017),
  [7385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2017),
  [7387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2060),
  [7389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2060),
  [7391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6114),
  [7393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6114),
  [7395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2061),
  [7397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2061),
  [7399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2062),
  [7401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2062),
  [7403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5881),
  [7405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5881),
  [7407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(983),
  [7409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [7411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6116),
  [7413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6116),
  [7415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2063),
  [7417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2063),
  [7419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2064),
  [7421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2064),
  [7423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2065),
  [7425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2065),
  [7427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2066),
  [7429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2066),
  [7431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1495),
  [7433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1495),
  [7435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1497),
  [7437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1497),
  [7439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1499),
  [7441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1499),
  [7443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2067),
  [7445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2067),
  [7447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(992),
  [7449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [7451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1200),
  [7453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1200),
  [7455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1173),
  [7457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [7459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1174),
  [7461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [7463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1175),
  [7465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1175),
  [7467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1176),
  [7469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1176),
  [7471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1154),
  [7473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1154),
  [7475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1178),
  [7477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1178),
  [7479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1180),
  [7481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [7483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1181),
  [7485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1181),
  [7487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1182),
  [7489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1182),
  [7491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1183),
  [7493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1183),
  [7495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1184),
  [7497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1184),
  [7499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1171),
  [7501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1171),
  [7503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1172),
  [7505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1172),
  [7507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1177),
  [7509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [7511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1185),
  [7513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1185),
  [7515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1186),
  [7517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1186),
  [7519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1189),
  [7521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1189),
  [7523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1191),
  [7525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1191),
  [7527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1192),
  [7529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1192),
  [7531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1194),
  [7533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1194),
  [7535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1195),
  [7537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1195),
  [7539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_attribute_item, 3, 0, 12),
  [7541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_attribute_item, 3, 0, 12),
  [7543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_var, 3, 0, 0),
  [7545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_var, 3, 0, 0),
  [7547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2068),
  [7549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2068),
  [7551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2069),
  [7553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2069),
  [7555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1399),
  [7557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1399),
  [7559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2070),
  [7561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2070),
  [7563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2071),
  [7565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2071),
  [7567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1051),
  [7569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1051),
  [7571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2072),
  [7573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2072),
  [7575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure, 8, 0, 83),
  [7577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure, 8, 0, 83),
  [7579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2073),
  [7581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2073),
  [7583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6217),
  [7585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6217),
  [7587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2074),
  [7589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2074),
  [7591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2078),
  [7593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2078),
  [7595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1052),
  [7597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [7599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6019),
  [7601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6019),
  [7603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2079),
  [7605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2079),
  [7607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6020),
  [7609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6020),
  [7611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1053),
  [7613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [7615] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure, 9, 0, 83),
  [7617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure, 9, 0, 83),
  [7619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1054),
  [7621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [7623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1055),
  [7625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [7627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1056),
  [7629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [7631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2080),
  [7633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2080),
  [7635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1057),
  [7637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [7639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2081),
  [7641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2081),
  [7643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1401),
  [7645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1401),
  [7647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1402),
  [7649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1402),
  [7651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1403),
  [7653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1403),
  [7655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1405),
  [7657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1405),
  [7659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1406),
  [7661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1406),
  [7663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1407),
  [7665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1407),
  [7667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1408),
  [7669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1408),
  [7671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1409),
  [7673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1409),
  [7675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1058),
  [7677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1058),
  [7679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2082),
  [7681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2082),
  [7683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1410),
  [7685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1410),
  [7687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1411),
  [7689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1411),
  [7691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6152),
  [7693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6152),
  [7695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1412),
  [7697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1412),
  [7699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2083),
  [7701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2083),
  [7703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1413),
  [7705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1413),
  [7707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1190),
  [7709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1190),
  [7711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1158),
  [7713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1158),
  [7715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6327),
  [7717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6327),
  [7719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1059),
  [7721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [7723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6211),
  [7725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6211),
  [7727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6312),
  [7729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6312),
  [7731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6105),
  [7733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6105),
  [7735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6110),
  [7737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6110),
  [7739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1060),
  [7741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [7743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6118),
  [7745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6118),
  [7747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1061),
  [7749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [7751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1062),
  [7753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1062),
  [7755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1063),
  [7757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [7759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6060),
  [7761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6060),
  [7763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_controladdin_repeat1, 2, 0, 0),
  [7765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1414),
  [7767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1414),
  [7769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1064),
  [7771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [7773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1415),
  [7775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1415),
  [7777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1416),
  [7779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1416),
  [7781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6012),
  [7783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6012),
  [7785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6013),
  [7787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6013),
  [7789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1417),
  [7791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1417),
  [7793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1065),
  [7795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1065),
  [7797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6006),
  [7799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6006),
  [7801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6011),
  [7803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6011),
  [7805] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_var, 4, 0, 0),
  [7807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_var, 4, 0, 0),
  [7809] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 4, 0, 44),
  [7811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 4, 0, 44),
  [7813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1066),
  [7815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [7817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1418),
  [7819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1418),
  [7821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1419),
  [7823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1419),
  [7825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1420),
  [7827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1420),
  [7829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1396),
  [7831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1396),
  [7833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1421),
  [7835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1421),
  [7837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(972),
  [7839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [7841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1084),
  [7843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [7845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(953),
  [7847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [7849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(954),
  [7851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [7853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(956),
  [7855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [7857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6303),
  [7859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6303),
  [7861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6214),
  [7863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6214),
  [7865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6296),
  [7867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6296),
  [7869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(978),
  [7871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [7873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6100),
  [7875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6100),
  [7877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6101),
  [7879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6101),
  [7881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6279),
  [7883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6279),
  [7885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6103),
  [7887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6103),
  [7889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6270),
  [7891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6270),
  [7893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(959),
  [7895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [7897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6136),
  [7899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6136),
  [7901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6278),
  [7903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6278),
  [7905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(962),
  [7907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [7909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(963),
  [7911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [7913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6137),
  [7915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6137),
  [7917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6192),
  [7919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6192),
  [7921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(964),
  [7923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [7925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6294),
  [7927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6294),
  [7929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1156),
  [7931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1156),
  [7933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_var, 5, 0, 0),
  [7935] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_var, 5, 0, 0),
  [7937] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 5, 0, 59),
  [7939] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 5, 0, 59),
  [7941] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 5, 0, 60),
  [7943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 5, 0, 60),
  [7945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(965),
  [7947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [7949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(966),
  [7951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [7953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(967),
  [7955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [7957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(968),
  [7959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(968),
  [7961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6132),
  [7963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6132),
  [7965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6133),
  [7967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6133),
  [7969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6277),
  [7971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6277),
  [7973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6242),
  [7975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6242),
  [7977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6287),
  [7979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6287),
  [7981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6014),
  [7983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6014),
  [7985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6034),
  [7987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6034),
  [7989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6072),
  [7991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6072),
  [7993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6045),
  [7995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6045),
  [7997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6062),
  [7999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6062),
  [8001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6069),
  [8003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6069),
  [8005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(969),
  [8007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(969),
  [8009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(970),
  [8011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [8013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_var, 6, 0, 0),
  [8015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_var, 6, 0, 0),
  [8017] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 6, 0, 59),
  [8019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 6, 0, 59),
  [8021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6280),
  [8023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6280),
  [8025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6218),
  [8027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6218),
  [8029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6301),
  [8031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6301),
  [8033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5994),
  [8035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5994),
  [8037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5995),
  [8039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5995),
  [8041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5998),
  [8043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5998),
  [8045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6075),
  [8047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6075),
  [8049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(971),
  [8051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [8053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(997),
  [8055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [8057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6143),
  [8059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6143),
  [8061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6144),
  [8063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6144),
  [8065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(973),
  [8067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [8069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(974),
  [8071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [8073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(975),
  [8075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [8077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6293),
  [8079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6293),
  [8081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6222),
  [8083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6222),
  [8085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6311),
  [8087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6311),
  [8089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6051),
  [8091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6051),
  [8093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6052),
  [8095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6052),
  [8097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6053),
  [8099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6053),
  [8101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6055),
  [8103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6055),
  [8105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6175),
  [8107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6175),
  [8109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(976),
  [8111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [8113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(952),
  [8115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [8117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6057),
  [8119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6057),
  [8121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6058),
  [8123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6058),
  [8125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(977),
  [8127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [8129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3215),
  [8131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6321),
  [8133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6321),
  [8135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6061),
  [8137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6061),
  [8139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6209),
  [8141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6209),
  [8143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6299),
  [8145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6299),
  [8147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6178),
  [8149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6178),
  [8151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5993),
  [8153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5993),
  [8155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6288),
  [8157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6288),
  [8159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6226),
  [8161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6226),
  [8163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6285),
  [8165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6285),
  [8167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6247),
  [8169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6337),
  [8171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6337),
  [8173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6340),
  [8175] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 7, 0, 59),
  [8177] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 7, 0, 59),
  [8179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6071),
  [8181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6071),
  [8183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6286),
  [8185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6286),
  [8187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6010),
  [8189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6010),
  [8191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6135),
  [8193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6135),
  [8195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6306),
  [8197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6306),
  [8199] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure, 5, 0, 24),
  [8201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure, 5, 0, 24),
  [8203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6289),
  [8205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6289),
  [8207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1067),
  [8209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [8211] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 8, 0, 59),
  [8213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 8, 0, 59),
  [8215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4932),
  [8217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4932),
  [8219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5996),
  [8221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5996),
  [8223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6000),
  [8225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6000),
  [8227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6305),
  [8229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6305),
  [8231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6176),
  [8233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6176),
  [8235] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure, 5, 0, 46),
  [8237] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure, 5, 0, 46),
  [8239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5873),
  [8241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5873),
  [8243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6308),
  [8245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6308),
  [8247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6196),
  [8249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6196),
  [8251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6089),
  [8253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6089),
  [8255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6235),
  [8257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6235),
  [8259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4933),
  [8261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4933),
  [8263] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure, 4, 0, 24),
  [8265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure, 4, 0, 24),
  [8267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6324),
  [8269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6324),
  [8271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6282),
  [8273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6282),
  [8275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6313),
  [8277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6313),
  [8279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1404),
  [8281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1404),
  [8283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1422),
  [8285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1422),
  [8287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2018),
  [8289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2018),
  [8291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2030),
  [8293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2030),
  [8295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6298),
  [8297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6298),
  [8299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6146),
  [8301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6146),
  [8303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2031),
  [8305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2031),
  [8307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2037),
  [8309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2037),
  [8311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6005),
  [8313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6005),
  [8315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2043),
  [8317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2043),
  [8319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2044),
  [8321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2044),
  [8323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2045),
  [8325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2045),
  [8327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6307),
  [8329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6307),
  [8331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6274),
  [8333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6274),
  [8335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2052),
  [8337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2052),
  [8339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2053),
  [8341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2053),
  [8343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5443),
  [8345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5443),
  [8347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2058),
  [8349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2058),
  [8351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6314),
  [8353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6314),
  [8355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2059),
  [8357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2059),
  [8359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2085),
  [8361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2085),
  [8363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2086),
  [8365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2086),
  [8367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2087),
  [8369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2087),
  [8371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2023),
  [8373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2023),
  [8375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2024),
  [8377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2024),
  [8379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1949),
  [8381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1949),
  [8383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1954),
  [8385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1954),
  [8387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6284),
  [8389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6284),
  [8391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6310),
  [8393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6310),
  [8395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1975),
  [8397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1975),
  [8399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5444),
  [8401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5444),
  [8403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6323),
  [8405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6323),
  [8407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1976),
  [8409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1976),
  [8411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1977),
  [8413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1977),
  [8415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5445),
  [8417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5445),
  [8419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1981),
  [8421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1981),
  [8423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1087),
  [8425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [8427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5424),
  [8429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5424),
  [8431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5423),
  [8433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5423),
  [8435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1068),
  [8437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [8439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6142),
  [8441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6142),
  [8443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5438),
  [8445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5438),
  [8447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6018),
  [8449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6018),
  [8451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6148),
  [8453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6148),
  [8455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6149),
  [8457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6149),
  [8459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6150),
  [8461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6150),
  [8463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6151),
  [8465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6151),
  [8467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6154),
  [8469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6154),
  [8471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure, 6, 0, 62),
  [8473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure, 6, 0, 62),
  [8475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6081),
  [8477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6081),
  [8479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6156),
  [8481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6156),
  [8483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6157),
  [8485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6157),
  [8487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6158),
  [8489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6158),
  [8491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6159),
  [8493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6159),
  [8495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6160),
  [8497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6160),
  [8499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2903),
  [8501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6161),
  [8503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6161),
  [8505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6162),
  [8507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6162),
  [8509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6163),
  [8511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6163),
  [8513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6164),
  [8515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6164),
  [8517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6165),
  [8519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6165),
  [8521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2906),
  [8523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1166),
  [8525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [8527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6166),
  [8529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6166),
  [8531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6167),
  [8533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6167),
  [8535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6168),
  [8537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6168),
  [8539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6169),
  [8541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6169),
  [8543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6170),
  [8545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6170),
  [8547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6022),
  [8549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6022),
  [8551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6172),
  [8553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6172),
  [8555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6173),
  [8557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6173),
  [8559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6174),
  [8561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6174),
  [8563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6138),
  [8565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6138),
  [8567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6023),
  [8569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6023),
  [8571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6024),
  [8573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6024),
  [8575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6253),
  [8577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6359),
  [8579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6255),
  [8581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6360),
  [8583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6258),
  [8585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6361),
  [8587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6260),
  [8589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6362),
  [8591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6261),
  [8593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6363),
  [8595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6201),
  [8597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6201),
  [8599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6202),
  [8601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6202),
  [8603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6203),
  [8605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6203),
  [8607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6300),
  [8609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6300),
  [8611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10406),
  [8613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10406),
  [8615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11208),
  [8617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9908),
  [8619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11946),
  [8621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11946),
  [8623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8347),
  [8625] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(10406),
  [8628] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(10406),
  [8631] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11208),
  [8634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_repeat1, 1, 0, 0),
  [8636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3273),
  [8638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6769),
  [8640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5669),
  [8642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11127),
  [8644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12639),
  [8646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12467),
  [8648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12302),
  [8650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11362),
  [8652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12429),
  [8654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8669),
  [8656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8298),
  [8658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4812),
  [8660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11146),
  [8662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8578),
  [8664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11772),
  [8666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11773),
  [8668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11775),
  [8670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11778),
  [8672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11779),
  [8674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11311),
  [8676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11783),
  [8678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11785),
  [8680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11786),
  [8682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11791),
  [8684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11792),
  [8686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11793),
  [8688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12514),
  [8690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5713),
  [8692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5739),
  [8694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trigger_declaration, 5, 0, 2),
  [8696] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trigger_declaration, 5, 0, 2),
  [8698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5760),
  [8700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10053),
  [8702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3277),
  [8704] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(3569),
  [8707] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11159),
  [8710] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12627),
  [8713] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12267),
  [8716] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12337),
  [8719] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(9836),
  [8722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0),
  [8724] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(8583),
  [8727] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(8277),
  [8730] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(2627),
  [8733] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11148),
  [8736] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12378),
  [8739] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(8563),
  [8742] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11274),
  [8745] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11277),
  [8748] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11280),
  [8751] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11282),
  [8754] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11287),
  [8757] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11288),
  [8760] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11292),
  [8763] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11294),
  [8766] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11296),
  [8769] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11303),
  [8772] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11326),
  [8775] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11329),
  [8778] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12667),
  [8781] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trigger_declaration, 6, 0, 2),
  [8783] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trigger_declaration, 6, 0, 2),
  [8785] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trigger_declaration, 6, 0, 56),
  [8787] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trigger_declaration, 6, 0, 56),
  [8789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trigger_declaration, 6, 0, 57),
  [8791] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trigger_declaration, 6, 0, 57),
  [8793] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trigger_declaration, 7, 0, 2),
  [8795] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trigger_declaration, 7, 0, 2),
  [8797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trigger_declaration, 7, 0, 56),
  [8799] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trigger_declaration, 7, 0, 56),
  [8801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trigger_declaration, 7, 0, 57),
  [8803] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trigger_declaration, 7, 0, 57),
  [8805] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trigger_declaration, 7, 0, 73),
  [8807] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trigger_declaration, 7, 0, 73),
  [8809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trigger_declaration, 7, 0, 74),
  [8811] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trigger_declaration, 7, 0, 74),
  [8813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10007),
  [8815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 3, 0, 8),
  [8817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 3, 0, 8),
  [8819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trigger_declaration, 8, 0, 56),
  [8821] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trigger_declaration, 8, 0, 56),
  [8823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trigger_declaration, 8, 0, 57),
  [8825] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trigger_declaration, 8, 0, 57),
  [8827] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trigger_declaration, 8, 0, 2),
  [8829] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trigger_declaration, 8, 0, 2),
  [8831] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trigger_declaration, 8, 0, 73),
  [8833] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trigger_declaration, 8, 0, 73),
  [8835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trigger_declaration, 8, 0, 74),
  [8837] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trigger_declaration, 8, 0, 74),
  [8839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9958),
  [8841] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trigger_declaration, 9, 0, 73),
  [8843] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trigger_declaration, 9, 0, 73),
  [8845] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trigger_declaration, 9, 0, 74),
  [8847] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trigger_declaration, 9, 0, 74),
  [8849] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(6769),
  [8852] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11127),
  [8855] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12639),
  [8858] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12467),
  [8861] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12302),
  [8864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11362),
  [8867] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12429),
  [8870] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(8669),
  [8873] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(8298),
  [8876] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(4812),
  [8879] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11146),
  [8882] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(8578),
  [8885] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11772),
  [8888] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11773),
  [8891] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11775),
  [8894] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11778),
  [8897] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11779),
  [8900] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11311),
  [8903] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11783),
  [8906] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11785),
  [8909] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11786),
  [8912] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11791),
  [8915] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11792),
  [8918] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(11793),
  [8921] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_xmlport_element_repeat1, 2, 0, 0), SHIFT_REPEAT(12514),
  [8924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6611),
  [8926] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 4, 0, 22),
  [8928] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 4, 0, 22),
  [8930] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_repeat1, 2, 0, 0),
  [8932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6727),
  [8934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6629),
  [8936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10263),
  [8938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3313),
  [8940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6430),
  [8942] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_item, 3, 0, 12),
  [8944] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_item, 3, 0, 12),
  [8946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5925),
  [8948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12634),
  [8950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11962),
  [8952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11965),
  [8954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5937),
  [8956] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 108), REDUCE(sym__if_statement_no_else, 4, 10, 108),
  [8959] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 108), REDUCE(sym__if_statement_no_else, 4, 10, 108),
  [8962] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 108), REDUCE(sym__if_statement_no_else, 4, 10, 108), SHIFT(2427),
  [8966] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 107), REDUCE(sym__if_statement_no_else, 4, 10, 107),
  [8969] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 107), REDUCE(sym__if_statement_no_else, 4, 10, 107),
  [8972] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 107), REDUCE(sym__if_statement_no_else, 4, 10, 107), SHIFT(2427),
  [8976] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(4347),
  [8979] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11242),
  [8982] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12482),
  [8985] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12545),
  [8988] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12266),
  [8991] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(8494),
  [8994] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(8323),
  [8997] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(3253),
  [9000] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11124),
  [9003] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(8383),
  [9006] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11402),
  [9009] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11410),
  [9012] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12203),
  [9015] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12217),
  [9018] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12241),
  [9021] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12263),
  [9024] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12326),
  [9027] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12634),
  [9030] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11962),
  [9033] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11965),
  [9036] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12477),
  [9039] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12491),
  [9042] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12498),
  [9045] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12507),
  [9048] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12515),
  [9051] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_query_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12502),
  [9054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8393),
  [9056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3376),
  [9058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12235),
  [9060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8511),
  [9062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8512),
  [9064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8513),
  [9066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8508),
  [9068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8509),
  [9070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8510),
  [9072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8393),
  [9074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6804),
  [9076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11199),
  [9078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6832),
  [9080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11200),
  [9082] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat2, 2, 0, 0), SHIFT_REPEAT(3368),
  [9085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10300),
  [9087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11317),
  [9089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12289),
  [9091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12461),
  [9093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9573),
  [9095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9574),
  [9097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7025),
  [9099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10283),
  [9101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10320),
  [9103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4100),
  [9105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10185),
  [9107] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 8, 0, 234),
  [9109] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 8, 0, 234),
  [9111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6862),
  [9113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12644),
  [9115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12534),
  [9117] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 219),
  [9119] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 219),
  [9121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6054),
  [9123] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 6, 0, 209),
  [9125] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 6, 0, 209),
  [9127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6119),
  [9129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6366),
  [9131] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 6, 0, 208),
  [9133] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 6, 0, 208),
  [9135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6866),
  [9137] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 220),
  [9139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 220),
  [9141] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 221),
  [9143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 221),
  [9145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 222),
  [9147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 222),
  [9149] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 223),
  [9151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 223),
  [9153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_branch, 1, 0, 0),
  [9155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_branch, 1, 0, 0),
  [9157] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 6, 0, 210),
  [9159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 6, 0, 210),
  [9161] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 9, 0, 240),
  [9163] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 9, 0, 240),
  [9165] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 9, 0, 241),
  [9167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 9, 0, 241),
  [9169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9985),
  [9171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12286),
  [9173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10307),
  [9175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10250),
  [9177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9997),
  [9179] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 8, 0, 236),
  [9181] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 8, 0, 236),
  [9183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8227),
  [9185] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 6, 0, 206),
  [9187] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 6, 0, 206),
  [9189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8466),
  [9191] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_branch, 3, 0, 151),
  [9193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_branch, 3, 0, 151),
  [9195] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_branch, 3, 0, 152),
  [9197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_branch, 3, 0, 152),
  [9199] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 8, 0, 237),
  [9201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 8, 0, 237),
  [9203] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_branch, 3, 0, 153),
  [9205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_branch, 3, 0, 153),
  [9207] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 6, 0, 207),
  [9209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 6, 0, 207),
  [9211] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 218),
  [9213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 218),
  [9215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8483),
  [9217] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 224),
  [9219] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 224),
  [9221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8251),
  [9223] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(4347),
  [9226] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11242),
  [9229] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12482),
  [9232] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12545),
  [9235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12266),
  [9238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(8494),
  [9241] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(8323),
  [9244] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(3253),
  [9247] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11124),
  [9250] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(8383),
  [9253] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11402),
  [9256] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(11410),
  [9259] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12203),
  [9262] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12217),
  [9265] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12241),
  [9268] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12263),
  [9271] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12326),
  [9274] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12644),
  [9277] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12534),
  [9280] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12477),
  [9283] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12491),
  [9286] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12498),
  [9289] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12507),
  [9292] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12515),
  [9295] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_report_dataitem_repeat1, 2, 0, 0), SHIFT_REPEAT(12502),
  [9298] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 8, 0, 235),
  [9300] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 8, 0, 235),
  [9302] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 8, 0, 233),
  [9304] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 8, 0, 233),
  [9306] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 8, 0, 238),
  [9308] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 8, 0, 238),
  [9310] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 5, 0, 183),
  [9312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 5, 0, 183),
  [9314] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 5, 0, 184),
  [9316] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 5, 0, 184),
  [9318] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 5, 0, 185),
  [9320] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 5, 0, 185),
  [9322] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 9, 0, 242),
  [9324] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 9, 0, 242),
  [9326] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 225),
  [9328] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 225),
  [9330] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 226),
  [9332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 7, 0, 226),
  [9334] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_case_branch, 6, 0, 205),
  [9336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_case_branch, 6, 0, 205),
  [9338] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__case_pattern, 1, 0, 45), REDUCE(aux_sym_preproc_split_case_branch_repeat1, 1, 0, 45),
  [9341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3497),
  [9343] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__case_pattern, 1, 0, 45),
  [9345] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__case_pattern, 1, 0, 45), REDUCE(aux_sym_preproc_split_case_branch_repeat1, 1, 0, 45),
  [9348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 1, 0, 45),
  [9350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8843),
  [9352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3500),
  [9354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12611),
  [9356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8782),
  [9358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8294),
  [9360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8787),
  [9362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8804),
  [9364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8827),
  [9366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8831),
  [9368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8838),
  [9370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8843),
  [9372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8202),
  [9374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8197),
  [9376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8236),
  [9378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8256),
  [9380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8224),
  [9382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8229),
  [9384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8200),
  [9386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8221),
  [9388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8222),
  [9390] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(4347),
  [9393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0),
  [9395] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(11242),
  [9398] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12482),
  [9401] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12545),
  [9404] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12266),
  [9407] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(9836),
  [9410] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(8494),
  [9413] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(8323),
  [9416] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(3253),
  [9419] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(11124),
  [9422] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12378),
  [9425] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(8383),
  [9428] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(11402),
  [9431] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(11410),
  [9434] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12203),
  [9437] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12217),
  [9440] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12241),
  [9443] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12263),
  [9446] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12326),
  [9449] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12644),
  [9452] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12534),
  [9455] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12477),
  [9458] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12491),
  [9461] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12498),
  [9464] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12507),
  [9467] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12515),
  [9470] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_add_dataset_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12502),
  [9473] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__case_pattern, 2, 0, 45), REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 45),
  [9476] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__case_pattern, 2, 0, 45),
  [9478] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__case_pattern, 2, 0, 45), REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 45),
  [9481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 45),
  [9483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4669),
  [9485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8185),
  [9487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8240),
  [9489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8187),
  [9491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3542),
  [9493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 190),
  [9495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 190),
  [9497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 189),
  [9499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 189),
  [9501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 173),
  [9503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 173),
  [9505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fields_section, 3, 0, 0),
  [9507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fields_section, 3, 0, 0),
  [9509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_keys_section, 3, 0, 0),
  [9511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_keys_section, 3, 0, 0),
  [9513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fieldgroups_section, 3, 0, 0),
  [9515] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fieldgroups_section, 3, 0, 0),
  [9517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_actions_section, 3, 0, 0),
  [9519] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_actions_section, 3, 0, 0),
  [9521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_layout_section, 3, 0, 0),
  [9523] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_layout_section, 3, 0, 0),
  [9525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_value_declaration, 8, 0, 90),
  [9527] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_value_declaration, 8, 0, 90),
  [9529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 8, 0, 56),
  [9531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 8, 0, 56),
  [9533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 8, 0, 57),
  [9535] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 8, 0, 57),
  [9537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dataset_section, 3, 0, 0),
  [9539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dataset_section, 3, 0, 0),
  [9541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elements_section, 3, 0, 0),
  [9543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elements_section, 3, 0, 0),
  [9545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labels_section, 3, 0, 0),
  [9547] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labels_section, 3, 0, 0),
  [9549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 8, 0, 2),
  [9551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 8, 0, 2),
  [9553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 8, 0, 73),
  [9555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 8, 0, 73),
  [9557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 8, 0, 74),
  [9559] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 8, 0, 74),
  [9561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 190),
  [9563] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 190),
  [9565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_declaration, 5, 0, 2),
  [9567] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_declaration, 5, 0, 2),
  [9569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3572),
  [9571] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modify_modification, 6, 0, 49),
  [9573] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modify_modification, 6, 0, 49),
  [9575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 6, 0, 2),
  [9577] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 6, 0, 2),
  [9579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 6, 0, 56),
  [9581] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 6, 0, 56),
  [9583] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 6, 0, 57),
  [9585] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 6, 0, 57),
  [9587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rendering_section, 3, 0, 0),
  [9589] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rendering_section, 3, 0, 0),
  [9591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requestpage_section, 3, 0, 0),
  [9593] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_requestpage_section, 3, 0, 0),
  [9595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 8, 0, 61),
  [9597] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 8, 0, 61),
  [9599] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 8, 0, 79),
  [9601] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 8, 0, 79),
  [9603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 8, 0, 80),
  [9605] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 8, 0, 80),
  [9607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 8, 0, 99),
  [9609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 8, 0, 99),
  [9611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 8, 0, 100),
  [9613] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 8, 0, 100),
  [9615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_schema_section, 3, 0, 0),
  [9617] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_schema_section, 3, 0, 0),
  [9619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_views_section, 3, 0, 0),
  [9621] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_views_section, 3, 0, 0),
  [9623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional, 3, 0, 0),
  [9625] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional, 3, 0, 0),
  [9627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_declaration, 6, 0, 2),
  [9629] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_declaration, 6, 0, 2),
  [9631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 6, 0, 61),
  [9633] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 6, 0, 61),
  [9635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 11, 0, 212),
  [9637] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 11, 0, 212),
  [9639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 11, 0, 213),
  [9641] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 11, 0, 213),
  [9643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_value_declaration, 9, 0, 90),
  [9645] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_value_declaration, 9, 0, 90),
  [9647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 9, 0, 56),
  [9649] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 9, 0, 56),
  [9651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 9, 0, 57),
  [9653] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 9, 0, 57),
  [9655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 9, 0, 73),
  [9657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 9, 0, 73),
  [9659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 9, 0, 74),
  [9661] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 9, 0, 74),
  [9663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 191),
  [9665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 191),
  [9667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 9, 0, 79),
  [9669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 9, 0, 79),
  [9671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 9, 0, 80),
  [9673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 9, 0, 80),
  [9675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 9, 0, 61),
  [9677] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 9, 0, 61),
  [9679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 9, 0, 99),
  [9681] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 9, 0, 99),
  [9683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 9, 0, 100),
  [9685] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 9, 0, 100),
  [9687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3578),
  [9689] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 213),
  [9691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 213),
  [9693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 171),
  [9695] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 171),
  [9697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 12, 0, 227),
  [9699] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 12, 0, 227),
  [9701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3617),
  [9703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 194),
  [9705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 194),
  [9707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 11, 0, 214),
  [9709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 11, 0, 214),
  [9711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 173),
  [9713] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 173),
  [9715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3621),
  [9717] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 214),
  [9719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 214),
  [9721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 11, 0, 215),
  [9723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 11, 0, 215),
  [9725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3626),
  [9727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 11, 0, 195),
  [9729] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 11, 0, 195),
  [9731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3685),
  [9733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 6, 0, 0),
  [9735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 6, 0, 0),
  [9737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 10, 0, 73),
  [9739] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 10, 0, 73),
  [9741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 10, 0, 74),
  [9743] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 10, 0, 74),
  [9745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 10, 0, 79),
  [9747] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 10, 0, 79),
  [9749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional, 6, 0, 0),
  [9751] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional, 6, 0, 0),
  [9753] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 10, 0, 80),
  [9755] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 10, 0, 80),
  [9757] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 10, 0, 99),
  [9759] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 10, 0, 99),
  [9761] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 10, 0, 100),
  [9763] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 10, 0, 100),
  [9765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3575),
  [9767] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 212),
  [9769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 212),
  [9771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3615),
  [9773] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 11, 0, 227),
  [9775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 11, 0, 227),
  [9777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3761),
  [9779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3577),
  [9781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10847),
  [9783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10847),
  [9785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11234),
  [9787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modify_modification, 7, 0, 49),
  [9789] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modify_modification, 7, 0, 49),
  [9791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 7, 0, 2),
  [9793] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 7, 0, 2),
  [9795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 7, 0, 56),
  [9797] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 7, 0, 56),
  [9799] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(10847),
  [9802] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(10847),
  [9805] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11234),
  [9808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 7, 0, 57),
  [9810] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 7, 0, 57),
  [9812] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 7, 0, 73),
  [9814] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 7, 0, 73),
  [9816] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 7, 0, 74),
  [9818] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 7, 0, 74),
  [9820] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assembly_declaration, 7, 0, 48),
  [9822] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assembly_declaration, 7, 0, 48),
  [9824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3543),
  [9826] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_declaration, 4, 0, 2),
  [9828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_declaration, 4, 0, 2),
  [9830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fields_section, 4, 0, 0),
  [9832] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fields_section, 4, 0, 0),
  [9834] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_keys_section, 4, 0, 0),
  [9836] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_keys_section, 4, 0, 0),
  [9838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 195),
  [9840] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 195),
  [9842] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 7, 0, 0),
  [9844] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 7, 0, 0),
  [9846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3726),
  [9848] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 7, 0, 158),
  [9850] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 7, 0, 158),
  [9852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3727),
  [9854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3728),
  [9856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3733),
  [9858] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 7, 0, 159),
  [9860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 7, 0, 159),
  [9862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3734),
  [9864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3739),
  [9866] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 7, 0, 101),
  [9868] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 7, 0, 101),
  [9870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3740),
  [9872] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fieldgroups_section, 4, 0, 0),
  [9874] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fieldgroups_section, 4, 0, 0),
  [9876] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 11, 0, 99),
  [9878] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 11, 0, 99),
  [9880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3629),
  [9882] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 215),
  [9884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 215),
  [9886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3635),
  [9888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3636),
  [9890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3656),
  [9892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_actions_section, 4, 0, 0),
  [9894] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_actions_section, 4, 0, 0),
  [9896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 11, 0, 100),
  [9898] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 11, 0, 100),
  [9900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 7, 0, 61),
  [9902] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 7, 0, 61),
  [9904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional, 5, 0, 0),
  [9906] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional, 5, 0, 0),
  [9908] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 7, 0, 79),
  [9910] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 7, 0, 79),
  [9912] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 192),
  [9914] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 192),
  [9916] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_layout_section, 4, 0, 0),
  [9918] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_layout_section, 4, 0, 0),
  [9920] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dataset_section, 4, 0, 0),
  [9922] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dataset_section, 4, 0, 0),
  [9924] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elements_section, 4, 0, 0),
  [9926] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elements_section, 4, 0, 0),
  [9928] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 193),
  [9930] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 193),
  [9932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3782),
  [9934] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 172),
  [9936] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 172),
  [9938] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 7, 0, 80),
  [9940] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 7, 0, 80),
  [9942] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labels_section, 4, 0, 0),
  [9944] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labels_section, 4, 0, 0),
  [9946] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rendering_section, 4, 0, 0),
  [9948] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rendering_section, 4, 0, 0),
  [9950] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requestpage_section, 4, 0, 0),
  [9952] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_requestpage_section, 4, 0, 0),
  [9954] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_schema_section, 4, 0, 0),
  [9956] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_schema_section, 4, 0, 0),
  [9958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3619),
  [9960] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 194),
  [9962] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 194),
  [9964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__body_element, 1, 0, 0),
  [9966] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__body_element, 1, 0, 0),
  [9968] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__body_element, 1, 0, 0), REDUCE(aux_sym__procedure_header_repeat1, 1, 0, 0),
  [9971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_views_section, 4, 0, 0),
  [9973] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_views_section, 4, 0, 0),
  [9975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3778),
  [9977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3620),
  [9979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 158),
  [9981] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 158),
  [9983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 0),
  [9985] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 0),
  [9987] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional, 4, 0, 0),
  [9989] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional, 4, 0, 0),
  [9991] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_option_member_list_repeat1, 1, 0, 0), SHIFT_REPEAT(8843),
  [9994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3765),
  [9996] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 168),
  [9998] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 168),
  [10000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3766),
  [10002] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 159),
  [10004] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 159),
  [10006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3767),
  [10008] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 169),
  [10010] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 169),
  [10012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3768),
  [10014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3769),
  [10016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3770),
  [10018] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 101),
  [10020] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 101),
  [10022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3773),
  [10024] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 170),
  [10026] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 170),
  [10028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3777),
  [10030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3779),
  [10032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3781),
  [10034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3784),
  [10036] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 171),
  [10038] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 171),
  [10040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3785),
  [10042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3790),
  [10044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3793),
  [10046] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 172),
  [10048] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 172),
  [10050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3794),
  [10052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3511),
  [10054] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 173),
  [10056] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 8, 0, 173),
  [10058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3568),
  [10060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3622),
  [10062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3627),
  [10064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3684),
  [10066] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 195),
  [10068] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 195),
  [10070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3764),
  [10072] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 5, 0, 2),
  [10074] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 5, 0, 2),
  [10076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assembly_declaration, 6, 0, 48),
  [10078] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assembly_declaration, 6, 0, 48),
  [10080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 168),
  [10082] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 168),
  [10084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 169),
  [10086] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 169),
  [10088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 159),
  [10090] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 159),
  [10092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3776),
  [10094] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 189),
  [10096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 189),
  [10098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3510),
  [10100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 170),
  [10102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 170),
  [10104] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 172),
  [10106] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 10, 0, 172),
  [10108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 101),
  [10110] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 101),
  [10112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3570),
  [10114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 171),
  [10116] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 171),
  [10118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3592),
  [10120] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 191),
  [10122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 191),
  [10124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3593),
  [10126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3613),
  [10128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3633),
  [10130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 0),
  [10132] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 0),
  [10134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3706),
  [10136] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 192),
  [10138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 192),
  [10140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3707),
  [10142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3712),
  [10144] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 193),
  [10146] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_procedure_body, 9, 0, 193),
  [10148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3716),
  [10150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2513),
  [10152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8359),
  [10154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1960),
  [10156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1974),
  [10158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11219),
  [10160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5403),
  [10162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1296),
  [10164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_procedure, 4, -1, 2),
  [10166] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_procedure, 4, -1, 2),
  [10168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(229),
  [10170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9327),
  [10172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7116),
  [10174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11297),
  [10176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11219),
  [10178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [10180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3846),
  [10182] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 4, 0, 2),
  [10184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5411),
  [10186] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_procedure, 5, -1, 2),
  [10188] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_procedure, 5, -1, 2),
  [10190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 5, 0, 2),
  [10192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3812),
  [10194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0),
  [10196] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12286),
  [10199] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12287),
  [10202] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12288),
  [10205] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12289),
  [10208] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12290),
  [10211] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12291),
  [10214] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12461),
  [10217] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12292),
  [10220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12293),
  [10223] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12294),
  [10226] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12295),
  [10229] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(9573),
  [10232] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12296),
  [10235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12297),
  [10238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12298),
  [10241] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12299),
  [10244] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12300),
  [10247] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12301),
  [10250] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12630),
  [10253] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12631),
  [10256] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12632),
  [10259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3821),
  [10261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2529),
  [10263] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(4347),
  [10266] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11242),
  [10269] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12482),
  [10272] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12545),
  [10275] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12266),
  [10278] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(8359),
  [10281] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(8323),
  [10284] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(3253),
  [10287] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11124),
  [10290] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(8383),
  [10293] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11402),
  [10296] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11410),
  [10299] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12203),
  [10302] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12217),
  [10305] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12241),
  [10308] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12263),
  [10311] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12326),
  [10314] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12477),
  [10317] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12491),
  [10320] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12498),
  [10323] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12507),
  [10326] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12515),
  [10329] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_controladdin_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12502),
  [10332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2464),
  [10334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2507),
  [10336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2459),
  [10338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2038),
  [10340] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_field, 4, 0, 51),
  [10342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4452),
  [10344] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_field, 4, 0, 51),
  [10346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1988),
  [10348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1956),
  [10350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_page_field, 6, 0, 95),
  [10352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4465),
  [10354] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_page_field, 6, 0, 95),
  [10356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2528),
  [10358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2001),
  [10360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2458),
  [10362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_repeat1, 1, 0, 0),
  [10364] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_field, 5, 0, 76),
  [10366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4463),
  [10368] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_field, 5, 0, 76),
  [10370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1966),
  [10372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2034),
  [10374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_field, 3, 0, 29),
  [10376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4441),
  [10378] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_field, 3, 0, 29),
  [10380] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_field, 6, 0, 97),
  [10382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4470),
  [10384] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_field, 6, 0, 97),
  [10386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2504),
  [10388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2460),
  [10390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2000),
  [10392] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_repeat1, 2, 0, 0),
  [10394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2020),
  [10396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2523),
  [10398] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(4347),
  [10401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0),
  [10403] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11242),
  [10406] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12482),
  [10409] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12545),
  [10412] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12266),
  [10415] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(9836),
  [10418] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(8359),
  [10421] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(8323),
  [10424] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(3253),
  [10427] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11124),
  [10430] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12378),
  [10433] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(8383),
  [10436] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11402),
  [10439] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11410),
  [10442] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12203),
  [10445] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12217),
  [10448] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12241),
  [10451] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12263),
  [10454] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12326),
  [10457] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12477),
  [10460] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12491),
  [10463] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12498),
  [10466] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12507),
  [10469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12515),
  [10472] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12502),
  [10475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4036),
  [10477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_label_section, 6, 0, 48),
  [10479] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_label_section, 6, 0, 48),
  [10481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addafter_modification, 6, 0, 49),
  [10483] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addafter_modification, 6, 0, 49),
  [10485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addbefore_modification, 6, 0, 49),
  [10487] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addbefore_modification, 6, 0, 49),
  [10489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_movefirst_modification, 6, 0, 96),
  [10491] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_movefirst_modification, 6, 0, 96),
  [10493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_movelast_modification, 6, 0, 96),
  [10495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_movelast_modification, 6, 0, 96),
  [10497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_moveafter_modification, 6, 0, 96),
  [10499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_moveafter_modification, 6, 0, 96),
  [10501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_movebefore_modification, 6, 0, 96),
  [10503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_movebefore_modification, 6, 0, 96),
  [10505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_area_section, 6, 0, 94),
  [10507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_area_section, 6, 0, 94),
  [10509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_section, 6, 0, 48),
  [10511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_group_section, 6, 0, 48),
  [10513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeater_section, 6, 0, 48),
  [10515] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_repeater_section, 6, 0, 48),
  [10517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cuegroup_section, 6, 0, 48),
  [10519] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cuegroup_section, 6, 0, 48),
  [10521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fixed_section, 6, 0, 48),
  [10523] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fixed_section, 6, 0, 48),
  [10525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_grid_section, 6, 0, 48),
  [10527] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_grid_section, 6, 0, 48),
  [10529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_field, 6, 0, 29),
  [10531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_field, 6, 0, 29),
  [10533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_field, 6, 0, 51),
  [10535] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_field, 6, 0, 51),
  [10537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_layout, 6, 0, 0),
  [10539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_layout, 6, 0, 0),
  [10541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_label_section, 7, 0, 48),
  [10543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_label_section, 7, 0, 48),
  [10545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_area_section, 7, 0, 94),
  [10547] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_area_section, 7, 0, 94),
  [10549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_section, 7, 0, 48),
  [10551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_group_section, 7, 0, 48),
  [10553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeater_section, 7, 0, 48),
  [10555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_repeater_section, 7, 0, 48),
  [10557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cuegroup_section, 7, 0, 48),
  [10559] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cuegroup_section, 7, 0, 48),
  [10561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fixed_section, 7, 0, 48),
  [10563] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fixed_section, 7, 0, 48),
  [10565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_grid_section, 7, 0, 48),
  [10567] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_grid_section, 7, 0, 48),
  [10569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_field, 7, 0, 76),
  [10571] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_field, 7, 0, 76),
  [10573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_field, 7, 0, 51),
  [10575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_field, 7, 0, 51),
  [10577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_page_field, 8, 0, 95),
  [10579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_page_field, 8, 0, 95),
  [10581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_part_section, 8, 0, 138),
  [10583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_part_section, 8, 0, 138),
  [10585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_systempart_section, 8, 0, 138),
  [10587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_systempart_section, 8, 0, 138),
  [10589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_usercontrol_section, 8, 0, 138),
  [10591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_usercontrol_section, 8, 0, 138),
  [10593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_field, 8, 0, 76),
  [10595] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_field, 8, 0, 76),
  [10597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_field, 8, 0, 97),
  [10599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_field, 8, 0, 97),
  [10601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_page_field, 9, 0, 95),
  [10603] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_page_field, 9, 0, 95),
  [10605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_part_section, 9, 0, 138),
  [10607] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_part_section, 9, 0, 138),
  [10609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_systempart_section, 9, 0, 138),
  [10611] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_systempart_section, 9, 0, 138),
  [10613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_usercontrol_section, 9, 0, 138),
  [10615] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_usercontrol_section, 9, 0, 138),
  [10617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_field, 9, 0, 97),
  [10619] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_field, 9, 0, 97),
  [10621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_brace_close, 5, 0, 0),
  [10623] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_brace_close, 5, 0, 0),
  [10625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_brace_close, 6, 0, 0),
  [10627] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_brace_close, 6, 0, 0),
  [10629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_brace_close, 7, 0, 0),
  [10631] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_brace_close, 7, 0, 0),
  [10633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7339),
  [10635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7296),
  [10637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7299),
  [10639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7300),
  [10641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7302),
  [10643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7309),
  [10645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7312),
  [10647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7147),
  [10649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7153),
  [10651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7177),
  [10653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2535),
  [10655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11123),
  [10657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9035),
  [10659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addlast_modification, 6, 0, 49),
  [10661] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addlast_modification, 6, 0, 49),
  [10663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addfirst_modification, 6, 0, 49),
  [10665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addfirst_modification, 6, 0, 49),
  [10667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addlast_modification, 7, 0, 49),
  [10669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addlast_modification, 7, 0, 49),
  [10671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addfirst_modification, 7, 0, 49),
  [10673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addfirst_modification, 7, 0, 49),
  [10675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addafter_modification, 7, 0, 49),
  [10677] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addafter_modification, 7, 0, 49),
  [10679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addbefore_modification, 7, 0, 49),
  [10681] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addbefore_modification, 7, 0, 49),
  [10683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2519),
  [10685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2536),
  [10687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2540),
  [10689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2537),
  [10691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2470),
  [10693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2520),
  [10695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2506),
  [10697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2457),
  [10699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2508),
  [10701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2509),
  [10703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2465),
  [10705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2466),
  [10707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2510),
  [10709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2467),
  [10711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2471),
  [10713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2468),
  [10715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2511),
  [10717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9043),
  [10719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9011),
  [10721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7354),
  [10723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7206),
  [10725] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__body_element, 1, 0, 0), REDUCE(sym__layout_element, 1, 0, 0),
  [10728] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__body_element, 1, 0, 0), REDUCE(sym__layout_element, 1, 0, 0),
  [10731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2512),
  [10733] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 1, 0, 0),
  [10736] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 1, 0, 0),
  [10738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 1, 0, 0),
  [10740] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_layout_section_repeat1, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 1, 0, 0),
  [10743] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat1, 1, 0, 0),
  [10746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7185),
  [10748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7192),
  [10750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7195),
  [10752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7207),
  [10754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7099),
  [10756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4006),
  [10758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2498),
  [10760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2500),
  [10762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2502),
  [10764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4139),
  [10766] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional, 2, 0, 0),
  [10768] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_layout, 2, 0, 0),
  [10770] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_layout, 2, 0, 0),
  [10772] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_preproc_conditional, 2, 0, 0), REDUCE(sym_preproc_conditional_layout, 2, 0, 0),
  [10775] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat2, 2, 0, 0), SHIFT_REPEAT(4100),
  [10778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9052),
  [10780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9030),
  [10782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7336),
  [10784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7198),
  [10786] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_preproc_conditional, 2, 0, 0), REDUCE(sym_preproc_conditional_layout, 2, 0, 0),
  [10789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7140),
  [10791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7178),
  [10793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7179),
  [10795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7189),
  [10797] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_layout, 3, 0, 0),
  [10799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_layout, 3, 0, 0),
  [10801] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_preproc_conditional, 3, 0, 0), REDUCE(sym_preproc_conditional_layout, 3, 0, 0),
  [10804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4802),
  [10806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2530),
  [10808] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 1, 0, 45),
  [10810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4614),
  [10812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2472),
  [10814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4349),
  [10816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7304),
  [10818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2516),
  [10820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2538),
  [10822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4267),
  [10824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4272),
  [10826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4276),
  [10828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4285),
  [10830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4286),
  [10832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1957),
  [10834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1958),
  [10836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2473),
  [10838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1962),
  [10840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1963),
  [10842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1964),
  [10844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1965),
  [10846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4294),
  [10848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1967),
  [10850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1968),
  [10852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1970),
  [10854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1971),
  [10856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1972),
  [10858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1973),
  [10860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4295),
  [10862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1978),
  [10864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1979),
  [10866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1980),
  [10868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1985),
  [10870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1986),
  [10872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3552),
  [10874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4419),
  [10876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1990),
  [10878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1991),
  [10880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1992),
  [10882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1993),
  [10884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1994),
  [10886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9014),
  [10888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1995),
  [10890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1996),
  [10892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1997),
  [10894] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_preproc_conditional, 3, 0, 0), REDUCE(sym_preproc_conditional_layout, 3, 0, 0),
  [10897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3719),
  [10899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2003),
  [10901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2004),
  [10903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2005),
  [10905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2006),
  [10907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2007),
  [10909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2008),
  [10911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2009),
  [10913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2010),
  [10915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2011),
  [10917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2012),
  [10919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2013),
  [10921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6878),
  [10923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2517),
  [10925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2474),
  [10927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2463),
  [10929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7003),
  [10931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2482),
  [10933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2484),
  [10935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2022),
  [10937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1948),
  [10939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2088),
  [10941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2026),
  [10943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2027),
  [10945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2028),
  [10947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2485),
  [10949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2029),
  [10951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2486),
  [10953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3545),
  [10955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2487),
  [10957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4088),
  [10959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6950),
  [10961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2488),
  [10963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2489),
  [10965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2477),
  [10967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2035),
  [10969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2036),
  [10971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3664),
  [10973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6482),
  [10975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2518),
  [10977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2478),
  [10979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2039),
  [10981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2040),
  [10983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2041),
  [10985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2479),
  [10987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3521),
  [10989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6902),
  [10991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6905),
  [10993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6906),
  [10995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6907),
  [10997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6908),
  [10999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6909),
  [11001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6570),
  [11003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2524),
  [11005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2521),
  [11007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2525),
  [11009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2490),
  [11011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2532),
  [11013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6595),
  [11015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6598),
  [11017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2491),
  [11019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2492),
  [11021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2048),
  [11023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2049),
  [11025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2050),
  [11027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2051),
  [11029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3579),
  [11031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6967),
  [11033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6971),
  [11035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6974),
  [11037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6975),
  [11039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6976),
  [11041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6977),
  [11043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6677),
  [11045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6720),
  [11047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6721),
  [11049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10195),
  [11051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2054),
  [11053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2055),
  [11055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2056),
  [11057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2057),
  [11059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8463),
  [11061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7690),
  [11063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6888),
  [11065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6544),
  [11067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4352),
  [11069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6561),
  [11071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6567),
  [11073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6578),
  [11075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6580),
  [11077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6597),
  [11079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4353),
  [11081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4354),
  [11083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4355),
  [11085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4356),
  [11087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4357),
  [11089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2075),
  [11091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2076),
  [11093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2077),
  [11095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4360),
  [11097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8482),
  [11099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7710),
  [11101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6944),
  [11103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6397),
  [11105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4361),
  [11107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6409),
  [11109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6410),
  [11111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6417),
  [11113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6418),
  [11115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4362),
  [11117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4363),
  [11119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4366),
  [11121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4367),
  [11123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4372),
  [11125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2084),
  [11127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4376),
  [11129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4378),
  [11131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4383),
  [11133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8235),
  [11135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6016),
  [11137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4384),
  [11139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9024),
  [11141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5966),
  [11143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_layout, 5, 0, 0),
  [11145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_layout, 5, 0, 0),
  [11147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6850),
  [11149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8257),
  [11151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4848),
  [11153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6121),
  [11155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6383),
  [11157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4863),
  [11159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5733),
  [11161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5950),
  [11163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5775),
  [11165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4837),
  [11167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5989),
  [11169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5783),
  [11171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5953),
  [11173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5954),
  [11175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5956),
  [11177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5957),
  [11179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7111),
  [11181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10179),
  [11183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4442),
  [11185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4443),
  [11187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4446),
  [11189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4447),
  [11191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4448),
  [11193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4449),
  [11195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4450),
  [11197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4453),
  [11199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4456),
  [11201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5368),
  [11203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4459),
  [11205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5367),
  [11207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4460),
  [11209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4461),
  [11211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4462),
  [11213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4476),
  [11215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4479),
  [11217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4480),
  [11219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4481),
  [11221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4482),
  [11223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4486),
  [11225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4487),
  [11227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5987),
  [11229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5914),
  [11231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5105),
  [11233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5924),
  [11235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5118),
  [11237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5005),
  [11239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5213),
  [11241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5938),
  [11243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5941),
  [11245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5942),
  [11247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5943),
  [11249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5944),
  [11251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5009),
  [11253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6515),
  [11255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5021),
  [11257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5022),
  [11259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5148),
  [11261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5912),
  [11263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5979),
  [11265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5980),
  [11267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5981),
  [11269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5982),
  [11271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5040),
  [11273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5047),
  [11275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5048),
  [11277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5921),
  [11279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5058),
  [11281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5059),
  [11283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5060),
  [11285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5061),
  [11287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5062),
  [11289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5070),
  [11291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2493),
  [11293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5933),
  [11295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5075),
  [11297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5076),
  [11299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5077),
  [11301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5078),
  [11303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5079),
  [11305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6708),
  [11307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6745),
  [11309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7023),
  [11311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7027),
  [11313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4612),
  [11315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6395),
  [11317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3904),
  [11319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3917),
  [11321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3918),
  [11323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4524),
  [11325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4525),
  [11327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6732),
  [11329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3925),
  [11331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3932),
  [11333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3933),
  [11335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3935),
  [11337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3936),
  [11339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3937),
  [11341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3938),
  [11343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3939),
  [11345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3940),
  [11347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3943),
  [11349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3944),
  [11351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3945),
  [11353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3946),
  [11355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3947),
  [11357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4526),
  [11359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4527),
  [11361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4528),
  [11363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5662),
  [11365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4529),
  [11367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4530),
  [11369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5773),
  [11371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4531),
  [11373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4532),
  [11375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4533),
  [11377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4600),
  [11379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4601),
  [11381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9036),
  [11383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9051),
  [11385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5642),
  [11387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5796),
  [11389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6817),
  [11391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8219),
  [11393] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__layout_element, 1, 0, 0),
  [11395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__layout_element, 1, 0, 0),
  [11397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8242),
  [11399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6575),
  [11401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6588),
  [11403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6589),
  [11405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6691),
  [11407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6718),
  [11409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5804),
  [11411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5811),
  [11413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2531),
  [11415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4546),
  [11417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4547),
  [11419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6820),
  [11421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6619),
  [11423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2505),
  [11425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2499),
  [11427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2501),
  [11429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2462),
  [11431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6833),
  [11433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6839),
  [11435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6815),
  [11437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6816),
  [11439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2533),
  [11441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3895),
  [11443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7332),
  [11445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7342),
  [11447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7343),
  [11449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7345),
  [11451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7269),
  [11453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7382),
  [11455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7180),
  [11457] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(4347),
  [11460] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11242),
  [11463] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12482),
  [11466] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12545),
  [11469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12266),
  [11472] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(8494),
  [11475] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(8323),
  [11478] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(3253),
  [11481] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11124),
  [11484] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(8383),
  [11487] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11402),
  [11490] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(11410),
  [11493] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12203),
  [11496] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12217),
  [11499] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12241),
  [11502] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12263),
  [11505] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12326),
  [11508] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12477),
  [11511] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12491),
  [11514] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12498),
  [11517] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12507),
  [11520] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12515),
  [11523] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(12502),
  [11526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7183),
  [11528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7205),
  [11530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11149),
  [11532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9044),
  [11534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2515),
  [11536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11295),
  [11538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2476),
  [11540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2480),
  [11542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2481),
  [11544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2483),
  [11546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_layout, 4, 0, 0),
  [11548] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_layout, 4, 0, 0),
  [11550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4134),
  [11552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_split_field, 5, 0, 29),
  [11554] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_split_field, 5, 0, 29),
  [11556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5629),
  [11558] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_split_case_branch_repeat1, 2, 0, 45),
  [11560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10832),
  [11562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10832),
  [11564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11145),
  [11566] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(10832),
  [11569] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(10832),
  [11572] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11145),
  [11575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4956),
  [11577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_case, 3, 0, 0),
  [11579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_case, 5, 0, 0),
  [11581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_case, 5, 0, 0),
  [11583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_case, 7, 0, 0),
  [11585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_case, 7, 0, 0),
  [11587] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat2, 2, 0, 0), SHIFT_REPEAT(4669),
  [11590] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_of_keyword, 1, 0, 0),
  [11592] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_of_keyword, 1, 0, 0),
  [11594] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_case, 6, 0, 0),
  [11596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_case, 6, 0, 0),
  [11598] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_case, 8, 0, 0),
  [11600] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_case, 8, 0, 0),
  [11602] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_case, 4, 0, 0),
  [11604] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_case, 4, 0, 0),
  [11606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11233),
  [11608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12280),
  [11610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9497),
  [11612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9499),
  [11614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7214),
  [11616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7352),
  [11618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8295),
  [11620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12104),
  [11622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6998),
  [11624] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__namespaced_or_simple_ref_repeat1, 2, 0, 0), SHIFT_REPEAT(8525),
  [11627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4804),
  [11629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4739),
  [11631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4743),
  [11633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4744),
  [11635] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__case_pattern, 1, 0, 45),
  [11637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4833),
  [11639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8525),
  [11641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4762),
  [11643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11338),
  [11645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4762),
  [11647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11338),
  [11649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8392),
  [11651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11156),
  [11653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9053),
  [11655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12215),
  [11657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12228),
  [11659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12254),
  [11661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12459),
  [11663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12540),
  [11665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11810),
  [11667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12391),
  [11669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12056),
  [11671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12097),
  [11673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12106),
  [11675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12246),
  [11677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12248),
  [11679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12380),
  [11681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12478),
  [11683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12485),
  [11685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12493),
  [11687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12518),
  [11689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11531),
  [11691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12042),
  [11693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12125),
  [11695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12625),
  [11697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9034),
  [11699] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_case_patterns, 3, 0, 0),
  [11701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_case_patterns, 3, 0, 29),
  [11703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8395),
  [11705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_case_patterns, 4, 0, 101),
  [11707] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_case_patterns, 4, 0, 29),
  [11709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_case_patterns, 4, 0, 51),
  [11711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10843),
  [11713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10843),
  [11715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11115),
  [11717] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(10843),
  [11720] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(10843),
  [11723] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11115),
  [11726] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_case_patterns, 5, 0, 76),
  [11728] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_case_patterns, 5, 0, 51),
  [11730] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_case_patterns, 2, 0, 0),
  [11732] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_case_patterns, 6, 0, 97),
  [11734] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__case_pattern, 2, 0, 45),
  [11736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12471),
  [11738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12486),
  [11740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_table_relation, 1, 0, 10),
  [11742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11419),
  [11744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3911),
  [11746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6582),
  [11748] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modify_action_modification, 6, 0, 49),
  [11750] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_modify_modification, 6, 0, 49), REDUCE(sym_modify_action_modification, 6, 0, 49),
  [11753] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modify_action_modification, 6, 0, 49),
  [11755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7141),
  [11757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5041),
  [11759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3926),
  [11761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11638),
  [11763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11638),
  [11765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__action_element, 1, 0, 0),
  [11767] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym__body_element, 1, 0, 0), REDUCE(sym__action_element, 1, 0, 0), REDUCE(aux_sym__procedure_header_repeat1, 1, 0, 0),
  [11771] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__action_element, 1, 0, 0),
  [11773] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__body_element, 1, 0, 0), REDUCE(sym__action_element, 1, 0, 0),
  [11776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6693),
  [11778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7196),
  [11780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_actions, 3, 0, 0),
  [11782] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_preproc_conditional, 3, 0, 0), REDUCE(sym_preproc_conditional_actions, 3, 0, 0),
  [11785] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_actions, 3, 0, 0),
  [11787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11190),
  [11789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6341),
  [11791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1260),
  [11793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(209),
  [11795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11190),
  [11797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [11799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6334),
  [11801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__identifier_or_quoted, 1, 0, 0),
  [11803] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__identifier_or_quoted, 1, 0, 0),
  [11806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modify_action_modification, 7, 0, 49),
  [11808] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_modify_modification, 7, 0, 49), REDUCE(sym_modify_action_modification, 7, 0, 49),
  [11811] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modify_action_modification, 7, 0, 49),
  [11813] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_actions, 2, 0, 0),
  [11815] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_preproc_conditional, 2, 0, 0), REDUCE(sym_preproc_conditional_actions, 2, 0, 0),
  [11818] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_actions, 2, 0, 0),
  [11820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5016),
  [11822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8464),
  [11824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2831),
  [11826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3148),
  [11828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2833),
  [11830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3159),
  [11832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [11834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1298),
  [11836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2837),
  [11838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2840),
  [11840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2841),
  [11842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2842),
  [11844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2844),
  [11846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2845),
  [11848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2847),
  [11850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2848),
  [11852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12574),
  [11854] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__identifier_or_quoted, 1, 0, 0),
  [11857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9874),
  [11859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9536),
  [11861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9637),
  [11863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4396),
  [11865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9652),
  [11867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9687),
  [11869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6702),
  [11871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6740),
  [11873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4407),
  [11875] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12275),
  [11878] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12276),
  [11881] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11233),
  [11884] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12277),
  [11887] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12278),
  [11890] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12279),
  [11893] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12280),
  [11896] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11181),
  [11899] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12629),
  [11902] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12281),
  [11905] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12282),
  [11908] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12283),
  [11911] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(9497),
  [11914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0),
  [11916] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(8295),
  [11919] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12284),
  [11922] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12285),
  [11925] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12104),
  [11928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9047),
  [11930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9039),
  [11932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5087),
  [11934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4986),
  [11936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3905),
  [11938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3906),
  [11940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9041),
  [11942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9042),
  [11944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5067),
  [11946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5071),
  [11948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5085),
  [11950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5088),
  [11952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9037),
  [11954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9048),
  [11956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6571),
  [11958] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_actions_repeat1, 1, 0, 0),
  [11960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7121),
  [11962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9845),
  [11964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9852),
  [11966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4420),
  [11968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9856),
  [11970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5244),
  [11972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7124),
  [11974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_actions_repeat1, 2, 0, 0),
  [11976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5858),
  [11978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5764),
  [11980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3993),
  [11982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3994),
  [11984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3995),
  [11986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3996),
  [11988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3997),
  [11990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3998),
  [11992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4423),
  [11994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4428),
  [11996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5362),
  [11998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7138),
  [12000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7139),
  [12002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3520),
  [12004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2849),
  [12006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2850),
  [12008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2851),
  [12010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1485),
  [12012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9581),
  [12014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3708),
  [12016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6572),
  [12018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4033),
  [12020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9352),
  [12022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3160),
  [12024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2853),
  [12026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2854),
  [12028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2855),
  [12030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2856),
  [12032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2860),
  [12034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2861),
  [12036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3193),
  [12038] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 45),
  [12040] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__preproc_guard_block_repeat1, 2, 0, 45),
  [12042] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12215),
  [12045] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12228),
  [12048] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12254),
  [12051] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12459),
  [12054] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12540),
  [12057] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11810),
  [12060] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12391),
  [12063] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12056),
  [12066] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12097),
  [12069] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12106),
  [12072] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12246),
  [12075] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12248),
  [12078] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12380),
  [12081] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12478),
  [12084] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12485),
  [12087] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12493),
  [12090] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12518),
  [12093] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11531),
  [12096] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12042),
  [12099] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_layout_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12125),
  [12102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6493),
  [12104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6494),
  [12106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5010),
  [12108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7197),
  [12110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7114),
  [12112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5011),
  [12114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7186),
  [12116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7154),
  [12118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9465),
  [12120] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat2, 2, 0, 0), SHIFT_REPEAT(4956),
  [12123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3976),
  [12125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6553),
  [12127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6554),
  [12129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6555),
  [12131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6556),
  [12133] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1485),
  [12136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9372),
  [12138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4982),
  [12140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_layout_mixed, 5, -1, 0),
  [12142] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_layout_mixed, 5, -1, 0),
  [12144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4989),
  [12146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4990),
  [12148] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_preproc_conditional, 2, 0, 0), REDUCE(sym_preproc_conditional_layout, 2, 0, 0), REDUCE(sym_preproc_conditional_layout_mixed, 2, -1, 0),
  [12152] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_preproc_conditional, 2, 0, 0), REDUCE(sym_preproc_conditional_layout, 2, 0, 0), REDUCE(sym_preproc_conditional_layout_mixed, 2, -1, 0),
  [12156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_layout_mixed, 3, -1, 0),
  [12158] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_layout_mixed, 3, -1, 0),
  [12160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_layout_mixed, 6, -1, 0),
  [12162] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_layout_mixed, 6, -1, 0),
  [12164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_layout_mixed, 4, -1, 0),
  [12166] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_layout_mixed, 4, -1, 0),
  [12168] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_preproc_conditional, 3, 0, 0), REDUCE(sym_preproc_conditional_layout, 3, 0, 0), REDUCE(sym_preproc_conditional_layout_mixed, 3, -1, 0),
  [12172] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_preproc_conditional, 3, 0, 0), REDUCE(sym_preproc_conditional_layout, 3, 0, 0), REDUCE(sym_preproc_conditional_layout_mixed, 3, -1, 0),
  [12176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5195),
  [12178] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional, 2, 0, 0),
  [12180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5116),
  [12182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5233),
  [12184] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__body_element, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_var_repeat1, 1, 0, 0),
  [12187] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__body_element, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_var_repeat1, 1, 0, 0),
  [12190] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym__body_element, 1, 0, 0), REDUCE(aux_sym__procedure_header_repeat1, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_var_repeat1, 1, 0, 0),
  [12194] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym__body_element, 1, 0, 0), REDUCE(aux_sym__procedure_header_repeat1, 1, 0, 0), REDUCE(aux_sym_preproc_conditional_var_repeat1, 1, 0, 0),
  [12198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5250),
  [12200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5251),
  [12202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5252),
  [12204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5255),
  [12206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5256),
  [12208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5261),
  [12210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5388),
  [12212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5275),
  [12214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5276),
  [12216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5277),
  [12218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5278),
  [12220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5279),
  [12222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5280),
  [12224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5283),
  [12226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5284),
  [12228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5285),
  [12230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5286),
  [12232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5289),
  [12234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5290),
  [12236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5295),
  [12238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5298),
  [12240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5299),
  [12242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5304),
  [12244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5305),
  [12246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5313),
  [12248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5314),
  [12250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5315),
  [12252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5316),
  [12254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5317),
  [12256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5318),
  [12258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5319),
  [12260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5320),
  [12262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5323),
  [12264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5324),
  [12266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5325),
  [12268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5326),
  [12270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5327),
  [12272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5328),
  [12274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5331),
  [12276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5332),
  [12278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5333),
  [12280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5334),
  [12282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5337),
  [12284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5338),
  [12286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5346),
  [12288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5347),
  [12290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5348),
  [12292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5349),
  [12294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5350),
  [12296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5351),
  [12298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5352),
  [12300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5353),
  [12302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5354),
  [12304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5355),
  [12306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5360),
  [12308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5361),
  [12310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8432),
  [12312] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_keyword, 1, 0, 0),
  [12314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_keyword, 1, 0, 0),
  [12316] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_until_keyword, 1, 0, 0),
  [12318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_until_keyword, 1, 0, 0),
  [12320] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_keyword, 1, 0, 0),
  [12322] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_keyword, 1, 0, 0),
  [12324] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with_keyword, 1, 0, 0),
  [12326] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_keyword, 1, 0, 0),
  [12328] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_keyword, 1, 0, 0),
  [12330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_keyword, 1, 0, 0),
  [12332] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comparison_operator, 1, 0, 0),
  [12334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comparison_operator, 1, 0, 0),
  [12336] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_to_keyword, 1, 0, 0),
  [12338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_to_keyword, 1, 0, 0),
  [12340] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_downto_keyword, 1, 0, 0),
  [12342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_downto_keyword, 1, 0, 0),
  [12344] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_in_keyword, 1, 0, 0),
  [12346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_in_keyword, 1, 0, 0),
  [12348] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_keyword, 1, 0, 0),
  [12350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_keyword, 1, 0, 0),
  [12352] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__namespaced_or_simple_ref_repeat1, 2, 0, 0), SHIFT_REPEAT(8432),
  [12355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 0),
  [12357] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 0), SHIFT(9327),
  [12360] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 0), SHIFT(7116),
  [12363] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 0), SHIFT(11297),
  [12366] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 40), SHIFT(7812),
  [12369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 40),
  [12371] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 40), SHIFT(9327),
  [12374] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 40), SHIFT(7116),
  [12377] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 40), SHIFT(11297),
  [12380] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 41), SHIFT(7823),
  [12383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 41),
  [12385] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 41), SHIFT(9327),
  [12388] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 41), SHIFT(7116),
  [12391] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 41), SHIFT(11297),
  [12394] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 41), SHIFT(5416),
  [12397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 41),
  [12399] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 41), SHIFT(9327),
  [12402] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 41), REDUCE(sym__procedure_header, 5, 0, 57),
  [12405] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 41), SHIFT(7116),
  [12408] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 41), SHIFT(11297),
  [12411] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 40), SHIFT(5404),
  [12414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 40),
  [12416] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 40), SHIFT(9327),
  [12419] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 40), SHIFT(7116),
  [12422] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 40), SHIFT(11297),
  [12425] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 41), SHIFT(5413),
  [12428] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 41), REDUCE(sym__procedure_header, 7, 0, 74),
  [12431] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 41), SHIFT(5405),
  [12434] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 40), SHIFT(5415),
  [12437] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 40), REDUCE(sym__procedure_header, 5, 0, 56),
  [12440] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 41), SHIFT(7813),
  [12443] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 40), SHIFT(5420),
  [12446] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 40), REDUCE(sym__procedure_header, 6, 0, 56),
  [12449] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 41), REDUCE(sym__procedure_header, 6, 0, 57),
  [12452] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 40), SHIFT(5419),
  [12455] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 40), REDUCE(sym__procedure_header, 6, 0, 73),
  [12458] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 41), SHIFT(5409),
  [12461] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 41), REDUCE(sym__procedure_header, 6, 0, 74),
  [12464] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 40), SHIFT(7822),
  [12467] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 40), REDUCE(sym__procedure_header, 7, 0, 73),
  [12470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8415),
  [12472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2857),
  [12474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2858),
  [12476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2859),
  [12478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3112),
  [12480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2922),
  [12482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1327),
  [12484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1328),
  [12486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2863),
  [12488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2864),
  [12490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2865),
  [12492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2869),
  [12494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2873),
  [12496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2877),
  [12498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2878),
  [12500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2881),
  [12502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2883),
  [12504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2884),
  [12506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2889),
  [12508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2890),
  [12510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2891),
  [12512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2892),
  [12514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2893),
  [12516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2894),
  [12518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2895),
  [12520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3099),
  [12522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5397),
  [12524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5398),
  [12526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5740),
  [12528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5473),
  [12530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5476),
  [12532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5481),
  [12534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5482),
  [12536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5567),
  [12538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5593),
  [12540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5594),
  [12542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5596),
  [12544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5604),
  [12546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5605),
  [12548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5610),
  [12550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5611),
  [12552] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__xmlport_body_element, 1, 0, 0), REDUCE(aux_sym_preproc_split_declaration_repeat2, 1, 0, 0),
  [12555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__xmlport_body_element, 1, 0, 0),
  [12557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2760),
  [12559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8405),
  [12561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5640),
  [12563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5641),
  [12565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5643),
  [12567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5644),
  [12569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5645),
  [12571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5646),
  [12573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5649),
  [12575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5650),
  [12577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5651),
  [12579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5652),
  [12581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5666),
  [12583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8407),
  [12585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_xmlport_attribute, 6, 0, 196),
  [12587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_xmlport, 6, 0, 0),
  [12589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5667),
  [12591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5675),
  [12593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5679),
  [12595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5680),
  [12597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5689),
  [12599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5690),
  [12601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5870),
  [12603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5698),
  [12605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5699),
  [12607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5700),
  [12609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5701),
  [12611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_xmlport_element, 6, 0, 98),
  [12613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5702),
  [12615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5703),
  [12617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5705),
  [12619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5709),
  [12621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5710),
  [12623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5711),
  [12625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5712),
  [12627] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__namespaced_or_simple_ref_repeat1, 2, 0, 0), SHIFT_REPEAT(8407),
  [12630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5714),
  [12632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5715),
  [12634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5718),
  [12636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5719),
  [12638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5720),
  [12640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5721),
  [12642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5724),
  [12644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5725),
  [12646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5734),
  [12648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5735),
  [12650] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_xmlport_element, 7, 0, 98),
  [12652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5736),
  [12654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5737),
  [12656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5738),
  [12658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5741),
  [12660] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_preproc_conditional_xmlport, 2, 0, 0), REDUCE(sym_preproc_conditional, 2, 0, 0),
  [12663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5742),
  [12665] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_xmlport, 5, 0, 0),
  [12667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5743),
  [12669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5744),
  [12671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_xmlport_attribute, 7, 0, 196),
  [12673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_xmlport_element, 8, 0, 140),
  [12675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5747),
  [12677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5748),
  [12679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5454),
  [12681] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_xmlport_element, 9, 0, 140),
  [12683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_xmlport_attribute, 8, 0, 228),
  [12685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10239),
  [12687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10239),
  [12689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_xmlport_attribute, 9, 0, 228),
  [12691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_xmlport, 4, 0, 0),
  [12693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5828),
  [12695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5837),
  [12697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5838),
  [12699] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_preproc_conditional_xmlport, 3, 0, 0), REDUCE(sym_preproc_conditional, 3, 0, 0),
  [12702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_xmlport, 3, 0, 0),
  [12704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2229),
  [12706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1873),
  [12708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10960),
  [12710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10960),
  [12712] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2229),
  [12715] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1873),
  [12718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8404),
  [12720] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_action_declaration, 7, 0, 48),
  [12722] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_action_declaration, 7, 0, 48),
  [12724] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_preproc_conditional_query, 3, 0, 0), REDUCE(sym_preproc_conditional, 3, 0, 0),
  [12727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_separator_action, 3, 0, 0),
  [12729] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_separator_action, 3, 0, 0),
  [12731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7697),
  [12733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9632),
  [12735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9633),
  [12737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7077),
  [12739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8538),
  [12741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8539),
  [12743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_query, 3, 0, 0),
  [12745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6007),
  [12747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_actionref_declaration, 8, 0, 137),
  [12749] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_actionref_declaration, 8, 0, 137),
  [12751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_query, 5, 0, 0),
  [12753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8430),
  [12755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_separator_action, 4, 0, 0),
  [12757] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_separator_action, 4, 0, 0),
  [12759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_query_dataitem, 8, 0, 139),
  [12761] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_actions, 4, 0, 0),
  [12763] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_actions, 4, 0, 0),
  [12765] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__body_element, 1, 0, 0), REDUCE(sym__action_element, 1, 0, 0),
  [12768] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), SHIFT(5875),
  [12771] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_calc_field_reference, 1, 0, 0), REDUCE(sym__expression, 1, 0, 0),
  [12774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_calc_field_reference, 1, 0, 0),
  [12776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_actionref_declaration, 9, 0, 137),
  [12778] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_actionref_declaration, 9, 0, 137),
  [12780] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_preproc_conditional, 2, 0, 0), REDUCE(sym_preproc_conditional_actions, 2, 0, 0),
  [12783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addlast_action_modification, 6, 0, 49),
  [12785] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addlast_action_modification, 6, 0, 49),
  [12787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addfirst_action_modification, 6, 0, 49),
  [12789] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addfirst_action_modification, 6, 0, 49),
  [12791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_query_dataitem, 9, 0, 139),
  [12793] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_action_declaration, 6, 0, 48),
  [12795] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_action_declaration, 6, 0, 48),
  [12797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addafter_action_modification, 6, 0, 49),
  [12799] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addafter_action_modification, 6, 0, 49),
  [12801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addbefore_action_modification, 6, 0, 49),
  [12803] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addbefore_action_modification, 6, 0, 49),
  [12805] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_separator_action, 6, 0, 48),
  [12807] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_separator_action, 6, 0, 48),
  [12809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_systemaction_declaration, 6, 0, 48),
  [12811] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_systemaction_declaration, 6, 0, 48),
  [12813] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fileuploadaction_declaration, 6, 0, 48),
  [12815] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fileuploadaction_declaration, 6, 0, 48),
  [12817] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_customaction_declaration, 6, 0, 48),
  [12819] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_customaction_declaration, 6, 0, 48),
  [12821] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_action_area_section, 6, 0, 94),
  [12823] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_action_area_section, 6, 0, 94),
  [12825] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_action_group_section, 6, 0, 48),
  [12827] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_action_group_section, 6, 0, 48),
  [12829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_actions, 6, 0, 0),
  [12831] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_actions, 6, 0, 0),
  [12833] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_query_column, 6, 0, 48),
  [12835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_query, 6, 0, 0),
  [12837] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_query_column, 8, 0, 243),
  [12839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_query_filter, 8, 0, 243),
  [12841] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_query_column, 9, 0, 243),
  [12843] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_query_filter, 9, 0, 243),
  [12845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6086),
  [12847] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_actions, 5, 0, 0),
  [12849] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_actions, 5, 0, 0),
  [12851] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_preproc_conditional_query, 2, 0, 0), REDUCE(sym_preproc_conditional, 2, 0, 0),
  [12854] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__query_body_element, 1, 0, 0), REDUCE(aux_sym_preproc_split_declaration_repeat2, 1, 0, 0),
  [12857] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__query_body_element, 1, 0, 0),
  [12859] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_modify_modification, 6, 0, 49), REDUCE(sym_modify_action_modification, 6, 0, 49),
  [12862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_query, 4, 0, 0),
  [12864] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addlast_action_modification, 7, 0, 49),
  [12866] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addlast_action_modification, 7, 0, 49),
  [12868] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addfirst_action_modification, 7, 0, 49),
  [12870] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addfirst_action_modification, 7, 0, 49),
  [12872] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addafter_action_modification, 7, 0, 49),
  [12874] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addafter_action_modification, 7, 0, 49),
  [12876] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addbefore_action_modification, 7, 0, 49),
  [12878] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addbefore_action_modification, 7, 0, 49),
  [12880] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_separator_action, 7, 0, 48),
  [12882] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_separator_action, 7, 0, 48),
  [12884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_systemaction_declaration, 7, 0, 48),
  [12886] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_systemaction_declaration, 7, 0, 48),
  [12888] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fileuploadaction_declaration, 7, 0, 48),
  [12890] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fileuploadaction_declaration, 7, 0, 48),
  [12892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_customaction_declaration, 7, 0, 48),
  [12894] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_customaction_declaration, 7, 0, 48),
  [12896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_action_area_section, 7, 0, 94),
  [12898] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_action_area_section, 7, 0, 94),
  [12900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_action_group_section, 7, 0, 48),
  [12902] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_action_group_section, 7, 0, 48),
  [12904] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_preproc_conditional, 3, 0, 0), REDUCE(sym_preproc_conditional_actions, 3, 0, 0),
  [12907] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_modify_modification, 7, 0, 49), REDUCE(sym_modify_action_modification, 7, 0, 49),
  [12910] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_query_column, 7, 0, 48),
  [12912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3973),
  [12914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12576),
  [12916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12580),
  [12918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11183),
  [12920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12585),
  [12922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12587),
  [12924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12589),
  [12926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12593),
  [12928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11247),
  [12930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11991),
  [12932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11532),
  [12934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11533),
  [12936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11563),
  [12938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8291),
  [12940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11630),
  [12942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11639),
  [12944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11760),
  [12946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6969),
  [12948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4671),
  [12950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2374),
  [12952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2435),
  [12954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2417),
  [12956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6978),
  [12958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8930),
  [12960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4024),
  [12962] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_report, 5, 0, 0),
  [12964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_report, 6, 0, 0),
  [12966] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_report_column, 8, 0, 95),
  [12968] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_preproc_conditional_report, 3, 0, 0), REDUCE(sym_preproc_conditional, 3, 0, 0),
  [12971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11271),
  [12973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3239),
  [12975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3240),
  [12977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2811),
  [12979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2812),
  [12981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2813),
  [12983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2814),
  [12985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2815),
  [12987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2816),
  [12989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2817),
  [12991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3235),
  [12993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3241),
  [12995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1362),
  [12997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1336),
  [12999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2818),
  [13001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2819),
  [13003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2820),
  [13005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2821),
  [13007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2822),
  [13009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2823),
  [13011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2824),
  [13013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2825),
  [13015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2826),
  [13017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2827),
  [13019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3169),
  [13021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12441),
  [13023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12442),
  [13025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11272),
  [13027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_report, 3, 0, 0),
  [13029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8429),
  [13031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2109),
  [13033] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2109),
  [13036] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_report_dataitem, 8, 0, 139),
  [13038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5976),
  [13040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7298),
  [13042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5977),
  [13044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3518),
  [13046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5978),
  [13048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5945),
  [13050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3081),
  [13052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6965),
  [13054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6966),
  [13056] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__report_body_element, 1, 0, 0), REDUCE(aux_sym_preproc_split_declaration_repeat2, 1, 0, 0),
  [13059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__report_body_element, 1, 0, 0),
  [13061] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_preproc_conditional_report, 2, 0, 0), REDUCE(sym_preproc_conditional, 2, 0, 0),
  [13064] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym__property_value, 1, 0, 0), REDUCE(sym_option_member, 1, 0, 0), REDUCE(sym__identifier_or_quoted, 1, 0, 0),
  [13068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2567),
  [13070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7293),
  [13072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5983),
  [13074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6968),
  [13076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7326),
  [13078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7331),
  [13080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7335),
  [13082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7341),
  [13084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5935),
  [13086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5936),
  [13088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7281),
  [13090] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_report_dataitem, 9, 0, 139),
  [13092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5852),
  [13094] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_report_column, 9, 0, 95),
  [13096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6701),
  [13098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7297),
  [13100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6900),
  [13102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6901),
  [13104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6903),
  [13106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6904),
  [13108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5939),
  [13110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5940),
  [13112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5763),
  [13114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_report, 4, 0, 0),
  [13116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6910),
  [13118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1733),
  [13120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5211),
  [13122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7313),
  [13124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3699),
  [13126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5359),
  [13128] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12576),
  [13131] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12580),
  [13134] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11183),
  [13137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12585),
  [13140] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12587),
  [13143] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12589),
  [13146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12593),
  [13149] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11247),
  [13152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11991),
  [13155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11532),
  [13158] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11533),
  [13161] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11563),
  [13164] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(8291),
  [13167] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11630),
  [13170] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11639),
  [13173] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_actions_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11760),
  [13176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_return_specification, 2, 0, 55),
  [13178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_named_return, 2, 0, 58),
  [13180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6739),
  [13182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5975),
  [13184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7291),
  [13186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2968),
  [13188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1135),
  [13190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1100),
  [13192] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__property_value, 1, 0, 0), REDUCE(sym_option_member, 1, 0, 0),
  [13195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1434),
  [13197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1435),
  [13199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11171),
  [13201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7894),
  [13203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1318),
  [13205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(211),
  [13207] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 6, 0, 61),
  [13209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11171),
  [13211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [13213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1217),
  [13215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [13217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7995),
  [13219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(205),
  [13221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [13223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1216),
  [13225] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 29),
  [13227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2089),
  [13229] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__attribute_argument, 1, 0, 0),
  [13231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1222),
  [13233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5965),
  [13235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5879),
  [13237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2145),
  [13239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7800),
  [13241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4825),
  [13243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2129),
  [13245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [13247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4717),
  [13249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7887),
  [13251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7811),
  [13253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7998),
  [13255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 5, 0, 61),
  [13257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8001),
  [13259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7816),
  [13261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [13263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4688),
  [13265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6191),
  [13267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2186),
  [13269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7881),
  [13271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8004),
  [13273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7807),
  [13275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1526),
  [13277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1107),
  [13279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7877),
  [13281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2130),
  [13283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2126),
  [13285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3207),
  [13287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7580),
  [13289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_procedure, 6, -1, 2),
  [13291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_controladdin, 6, 0, 0),
  [13293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3181),
  [13295] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym__property_value, 1, 0, 0), REDUCE(sym_option_member, 1, 0, 0), REDUCE(sym__namespaced_or_simple_ref, 1, 0, 0),
  [13299] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__signed_integer, 1, 0, 0), REDUCE(sym_option_member, 1, 0, 0),
  [13302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11155),
  [13304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3195),
  [13306] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_controladdin, 4, 0, 0),
  [13308] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_controladdin, 5, 0, 0),
  [13310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3199),
  [13312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7286),
  [13314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3202),
  [13316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3203),
  [13318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7315),
  [13320] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_preproc_conditional_controladdin, 3, 0, 0), REDUCE(sym_preproc_conditional, 3, 0, 0),
  [13323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_controladdin, 3, 0, 0),
  [13325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_expression, 1, 0, 0),
  [13327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7626),
  [13329] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_preproc_conditional_controladdin, 2, 0, 0), REDUCE(sym_preproc_conditional, 2, 0, 0),
  [13332] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat2, 1, 0, 0), REDUCE(aux_sym_controladdin_declaration_repeat1, 1, 0, 0),
  [13335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3144),
  [13337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2832),
  [13339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3156),
  [13341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3163),
  [13343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3164),
  [13345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2899),
  [13347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2900),
  [13349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2904),
  [13351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2909),
  [13353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2916),
  [13355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3251),
  [13357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_permissions_repeat1, 2, 0, 0),
  [13359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3059),
  [13361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3061),
  [13363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3065),
  [13365] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_option_member, 1, 0, 0), SHIFT(11228),
  [13368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1134),
  [13370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2185),
  [13372] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_permissions_repeat1, 1, 0, 0),
  [13374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2835),
  [13376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3072),
  [13378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3138),
  [13380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3177),
  [13382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3178),
  [13384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3183),
  [13386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3192),
  [13388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3152),
  [13390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2867),
  [13392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3204),
  [13394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2215),
  [13396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2396),
  [13398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4824),
  [13400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6147),
  [13402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10220),
  [13404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3056),
  [13406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1941),
  [13408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2834),
  [13410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3166),
  [13412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3155),
  [13414] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tabledata_permission_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7697),
  [13417] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tabledata_permission_list_repeat1, 2, 0, 0), SHIFT_REPEAT(9632),
  [13420] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tabledata_permission_list_repeat1, 2, 0, 0),
  [13422] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tabledata_permission_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7697),
  [13425] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tabledata_permission_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8538),
  [13428] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tabledata_permission_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8539),
  [13431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [13433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2902),
  [13435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2852),
  [13437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2917),
  [13439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3073),
  [13441] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__field_source, 1, 0, 45), SHIFT(8915),
  [13444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1687),
  [13446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1525),
  [13448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8915),
  [13450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1221),
  [13452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__field_source, 1, 0, 45),
  [13454] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 40), SHIFT(8157),
  [13457] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 41), SHIFT(8160),
  [13460] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 40), SHIFT(6350),
  [13463] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 41), SHIFT(6351),
  [13466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8339),
  [13468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2927),
  [13470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2928),
  [13472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2929),
  [13474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2933),
  [13476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2959),
  [13478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2960),
  [13480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2963),
  [13482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2965),
  [13484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2967),
  [13486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2971),
  [13488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2972),
  [13490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2976),
  [13492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2984),
  [13494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2986),
  [13496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2996),
  [13498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3175),
  [13500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3176),
  [13502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3179),
  [13504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3180),
  [13506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3182),
  [13508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3184),
  [13510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3186),
  [13512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3187),
  [13514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3188),
  [13516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3189),
  [13518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3190),
  [13520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3191),
  [13522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3194),
  [13524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3197),
  [13526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3198),
  [13528] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 40), SHIFT(6332),
  [13531] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 1, 0, 41), SHIFT(6333),
  [13534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8515),
  [13536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8400),
  [13538] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 40), SHIFT(7839),
  [13541] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_interface_procedure_suffix, 2, 0, 41), SHIFT(7844),
  [13544] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__literal_value, 1, 0, 0), REDUCE(sym_option_member, 2, 0, 0),
  [13547] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__signed_integer, 2, 0, 0), REDUCE(sym_option_member, 2, 0, 0),
  [13550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2991),
  [13552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2992),
  [13554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2993),
  [13556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2994),
  [13558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2997),
  [13560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2998),
  [13562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3002),
  [13564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3020),
  [13566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3022),
  [13568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3023),
  [13570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3026),
  [13572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3043),
  [13574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3044),
  [13576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3045),
  [13578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3046),
  [13580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4228),
  [13582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__property_value, 1, 0, 0),
  [13584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4264),
  [13586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4277),
  [13588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4249),
  [13590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4283),
  [13592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6457),
  [13594] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__namespaced_or_simple_ref_repeat1, 2, 0, 0), SHIFT_REPEAT(8523),
  [13597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8523),
  [13599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6537),
  [13601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6538),
  [13603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6539),
  [13605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6542),
  [13607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6543),
  [13609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6551),
  [13611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6552),
  [13613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6512),
  [13615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6517),
  [13617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6518),
  [13619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6600),
  [13621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6601),
  [13623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6602),
  [13625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6603),
  [13627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6381),
  [13629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6605),
  [13631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6608),
  [13633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6609),
  [13635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6612),
  [13637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6613),
  [13639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6616),
  [13641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6617),
  [13643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6623),
  [13645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6626),
  [13647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6627),
  [13649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6634),
  [13651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6635),
  [13653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6647),
  [13655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6648),
  [13657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6649),
  [13659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6650),
  [13661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6651),
  [13663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6652),
  [13665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6653),
  [13667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6654),
  [13669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6659),
  [13671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6660),
  [13673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6661),
  [13675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6662),
  [13677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6663),
  [13679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6664),
  [13681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6667),
  [13683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6669),
  [13685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6670),
  [13687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6673),
  [13689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6676),
  [13691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6678),
  [13693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6707),
  [13695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6712),
  [13697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6713),
  [13699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6714),
  [13701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6715),
  [13703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6716),
  [13705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6719),
  [13707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6722),
  [13709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6723),
  [13711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6724),
  [13713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6730),
  [13715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6731),
  [13717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6758),
  [13719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6766),
  [13721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2566),
  [13723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10800),
  [13725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10800),
  [13727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11179),
  [13729] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2566),
  [13732] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(10800),
  [13735] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(10800),
  [13738] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11179),
  [13741] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_preproc_conditional_link_values, 3, 0, 0), REDUCE(sym_preproc_conditional_impl_values, 3, 0, 0),
  [13744] = {.entry = {.count = 4, .reusable = true}}, REDUCE(sym_preproc_conditional_link_values, 3, 0, 0), REDUCE(sym_preproc_conditional_table_relation, 3, 0, 0), REDUCE(sym_preproc_conditional_permissions, 3, 0, 0), REDUCE(sym_preproc_conditional_impl_values, 3, 0, 0),
  [13749] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_permissions, 3, 0, 0),
  [13751] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_preproc_conditional_link_values, 3, 0, 0), REDUCE(sym_preproc_conditional_permissions, 3, 0, 0), REDUCE(sym_preproc_conditional_impl_values, 3, 0, 0),
  [13755] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_preproc_conditional_link_values, 3, 0, 0), REDUCE(sym_preproc_conditional_impl_values, 3, 0, 0),
  [13758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6877),
  [13760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tabledata_permission, 4, 0, 50),
  [13762] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tabledata_permission, 4, 0, 50),
  [13764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6881),
  [13766] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tabledata_permission_list_repeat1, 1, 0, 0),
  [13768] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_tabledata_permission_list_repeat1, 1, 0, 0),
  [13770] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_table_relation, 2, 0, 0),
  [13772] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_permissions, 2, 0, 0),
  [13774] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_preproc_conditional_table_relation, 2, 0, 0), REDUCE(sym_preproc_conditional_permissions, 2, 0, 0),
  [13777] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_permissions, 2, 0, 0),
  [13779] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_preproc_conditional_link_values, 2, 0, 0), REDUCE(sym_preproc_conditional_impl_values, 2, 0, 0),
  [13782] = {.entry = {.count = 4, .reusable = true}}, REDUCE(sym_preproc_conditional_link_values, 2, 0, 0), REDUCE(sym_preproc_conditional_table_relation, 2, 0, 0), REDUCE(sym_preproc_conditional_permissions, 2, 0, 0), REDUCE(sym_preproc_conditional_impl_values, 2, 0, 0),
  [13787] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_preproc_conditional_link_values, 2, 0, 0), REDUCE(sym_preproc_conditional_permissions, 2, 0, 0), REDUCE(sym_preproc_conditional_impl_values, 2, 0, 0),
  [13791] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_preproc_conditional_link_values, 2, 0, 0), REDUCE(sym_preproc_conditional_impl_values, 2, 0, 0),
  [13794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_table_relation, 3, 0, 0),
  [13796] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_permissions, 3, 0, 0),
  [13798] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_preproc_conditional_table_relation, 3, 0, 0), REDUCE(sym_preproc_conditional_permissions, 3, 0, 0),
  [13801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_permissions, 6, 0, 0),
  [13803] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_permissions, 6, 0, 0),
  [13805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11753),
  [13807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11759),
  [13809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_permissions, 4, 0, 0),
  [13811] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_permissions, 4, 0, 0),
  [13813] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_tabledata_permission_list_repeat1, 2, 0, 0),
  [13815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_permissions, 5, 0, 0),
  [13817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_permissions, 5, 0, 0),
  [13819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6948),
  [13821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6930),
  [13823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6947),
  [13825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11151),
  [13827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1356),
  [13829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11151),
  [13831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7980),
  [13833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7815),
  [13835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8112),
  [13837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8134),
  [13839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7941),
  [13841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(194),
  [13843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [13845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7945),
  [13847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7950),
  [13849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7954),
  [13851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8233),
  [13853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8210),
  [13855] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tabledata_permission_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7742),
  [13858] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tabledata_permission_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7742),
  [13861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8183),
  [13863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8263),
  [13865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8273),
  [13867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tabledata_permission_list, 1, 0, 0),
  [13869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7742),
  [13871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8311),
  [13873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(183),
  [13875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [13877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8239),
  [13879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8297),
  [13881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(171),
  [13883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [13885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8305),
  [13887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8267),
  [13889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8266),
  [13891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8179),
  [13893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8316),
  [13895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8230),
  [13897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11955),
  [13899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9328),
  [13901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7388),
  [13903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11955),
  [13905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11655),
  [13907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11655),
  [13909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11648),
  [13911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11648),
  [13913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7062),
  [13915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7063),
  [13917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7058),
  [13919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4058),
  [13921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4350),
  [13923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3974),
  [13925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4586),
  [13927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4069),
  [13929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7897),
  [13931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 7, 0, 73),
  [13933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7116),
  [13935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11297),
  [13937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7898),
  [13939] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 7, 0, 74),
  [13941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7905),
  [13943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 7, 0, 79),
  [13945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7906),
  [13947] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 7, 0, 80),
  [13949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7130),
  [13951] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 7, 0, 99),
  [13953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7131),
  [13955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 7, 0, 100),
  [13957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7122),
  [13959] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 6, 0, 73),
  [13961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7123),
  [13963] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 6, 0, 74),
  [13965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10790),
  [13967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10790),
  [13969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11147),
  [13971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7824),
  [13973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8006),
  [13975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8007),
  [13977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8008),
  [13979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7812),
  [13981] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 6, 0, 56),
  [13983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7813),
  [13985] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 6, 0, 57),
  [13987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7911),
  [13989] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 8, 0, 99),
  [13991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7912),
  [13993] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 8, 0, 100),
  [13995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7187),
  [13997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7148),
  [13999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11214),
  [14001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1330),
  [14003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11214),
  [14005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8174),
  [14007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7188),
  [14009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7128),
  [14011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 5, 0, 56),
  [14013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7199),
  [14015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7129),
  [14017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 5, 0, 57),
  [14019] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(10790),
  [14022] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(10790),
  [14025] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11147),
  [14028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7823),
  [14030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7127),
  [14032] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 6, 0, 79),
  [14034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7825),
  [14036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7174),
  [14038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7889),
  [14040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7117),
  [14042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7151),
  [14044] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 6, 0, 80),
  [14046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7890),
  [14048] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 6, 0, 48),
  [14050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 6, 0, 86),
  [14052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7100),
  [14054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7101),
  [14056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7135),
  [14058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7200),
  [14060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7201),
  [14062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7828),
  [14064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7105),
  [14066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7106),
  [14068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7829),
  [14070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7822),
  [14072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8009),
  [14074] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 5, 0, 48),
  [14076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8010),
  [14078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8002),
  [14080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8003),
  [14082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7163),
  [14084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 7, 0, 86),
  [14086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7166),
  [14088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7182),
  [14090] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_where_repeat1, 2, 0, 0), SHIFT_REPEAT(11955),
  [14093] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_where_repeat1, 2, 0, 0), SHIFT_REPEAT(3884),
  [14096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_where_repeat1, 2, 0, 0),
  [14098] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_where_repeat1, 2, 0, 0), SHIFT_REPEAT(11955),
  [14101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10820),
  [14103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10820),
  [14105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11185),
  [14107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4057),
  [14109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12558),
  [14111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11177),
  [14113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11178),
  [14115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12599),
  [14117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12602),
  [14119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11254),
  [14121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11348),
  [14123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_where_repeat2, 2, 0, 0),
  [14125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5859),
  [14127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_link_values_repeat2, 2, 0, 0),
  [14129] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_impl_values_repeat2, 2, 0, 0),
  [14131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6703),
  [14133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7237),
  [14135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6741),
  [14137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(10820),
  [14140] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(10820),
  [14143] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11185),
  [14146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3979),
  [14148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5245),
  [14150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dataset_section_repeat1, 2, 0, 0),
  [14152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dataset_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12558),
  [14155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dataset_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11177),
  [14158] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dataset_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11178),
  [14161] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dataset_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12599),
  [14164] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dataset_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12602),
  [14167] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dataset_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12391),
  [14170] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_dataset_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11254),
  [14173] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dataset_section_repeat1, 2, 0, 0), SHIFT_REPEAT(9327),
  [14176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dataset_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11348),
  [14179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3529),
  [14181] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_where_repeat2, 1, 0, 0),
  [14183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_link_values_repeat2, 1, 0, 0),
  [14185] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_link_values_repeat1, 2, 0, 0), SHIFT_REPEAT(11648),
  [14188] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_link_values_repeat1, 2, 0, 0), SHIFT_REPEAT(3884),
  [14191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_link_values_repeat1, 2, 0, 0),
  [14193] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_link_values_repeat1, 2, 0, 0), SHIFT_REPEAT(11648),
  [14196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5766),
  [14198] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_impl_values_repeat2, 1, 0, 0),
  [14200] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_impl_values_repeat1, 2, 0, 0), SHIFT_REPEAT(11655),
  [14203] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_impl_values_repeat1, 2, 0, 0), SHIFT_REPEAT(3884),
  [14206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_impl_values_repeat1, 2, 0, 0),
  [14208] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_impl_values_repeat1, 2, 0, 0), SHIFT_REPEAT(11655),
  [14211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5363),
  [14213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3710),
  [14215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8075),
  [14217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8376),
  [14219] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__namespaced_or_simple_ref_repeat1, 2, 0, 0), SHIFT_REPEAT(8376),
  [14222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9019),
  [14224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12274),
  [14226] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2757),
  [14229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7357),
  [14231] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_implementation_value, 3, 0, 39),
  [14233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8421),
  [14235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implementation_value, 3, 0, 39),
  [14237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2757),
  [14239] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_link_value, 3, 0, 38),
  [14241] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_link_value, 3, 0, 38),
  [14243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7380),
  [14245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7355),
  [14247] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_link_value, 9, 0, 157),
  [14249] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_link_value, 9, 0, 157),
  [14251] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_impl_values_repeat1, 1, 0, 0),
  [14253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7390),
  [14255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_impl_values_repeat1, 1, 0, 0),
  [14257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12028),
  [14259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_where_conditions, 1, 0, 0),
  [14261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12028),
  [14263] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_link_value, 12, 0, 211),
  [14265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_link_value, 12, 0, 211),
  [14267] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_link_value, 5, 0, 70),
  [14269] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_link_value, 5, 0, 70),
  [14271] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_where_condition, 5, 0, 70),
  [14273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_where_condition, 5, 0, 70),
  [14275] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_link_value, 6, 0, 89),
  [14277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_link_value, 6, 0, 89),
  [14279] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_link_value, 5, 0, 71),
  [14281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_link_value, 5, 0, 71),
  [14283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12628),
  [14285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11187),
  [14287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12448),
  [14289] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_link_value_list_repeat1, 2, 0, 0), SHIFT_REPEAT(11278),
  [14292] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_link_value_list_repeat1, 2, 0, 0),
  [14294] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_link_value_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3884),
  [14297] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_link_value_list_repeat1, 2, 0, 0), SHIFT_REPEAT(9327),
  [14300] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_link_value_list_repeat1, 2, 0, 0), SHIFT_REPEAT(11278),
  [14303] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_where_condition, 6, 0, 89),
  [14305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_where_condition, 6, 0, 89),
  [14307] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_where_repeat1, 1, 0, 0),
  [14309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7395),
  [14311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_where_repeat1, 1, 0, 0),
  [14313] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_implementation_value_list_repeat1, 2, 0, 0), SHIFT_REPEAT(11284),
  [14316] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_implementation_value_list_repeat1, 2, 0, 0),
  [14318] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_implementation_value_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3884),
  [14321] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_implementation_value_list_repeat1, 2, 0, 0), SHIFT_REPEAT(9327),
  [14324] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_implementation_value_list_repeat1, 2, 0, 0), SHIFT_REPEAT(11284),
  [14327] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_link_values_repeat1, 1, 0, 0),
  [14329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7389),
  [14331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_link_values_repeat1, 1, 0, 0),
  [14333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11910),
  [14335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11911),
  [14337] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_where_conditions_repeat1, 2, 0, 0), SHIFT_REPEAT(12028),
  [14340] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_where_conditions_repeat1, 2, 0, 0),
  [14342] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_where_conditions_repeat1, 2, 0, 0), SHIFT_REPEAT(3884),
  [14345] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_where_conditions_repeat1, 2, 0, 0), SHIFT_REPEAT(9327),
  [14348] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_where_conditions_repeat1, 2, 0, 0), SHIFT_REPEAT(12028),
  [14351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11278),
  [14353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_link_value_list, 1, 0, 0),
  [14355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11278),
  [14357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11284),
  [14359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implementation_value_list, 1, 0, 0),
  [14361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11284),
  [14363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_where_condition, 9, 0, 157),
  [14365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_where_condition, 9, 0, 157),
  [14367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7394),
  [14369] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_where_condition, 12, 0, 211),
  [14371] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_where_condition, 12, 0, 211),
  [14373] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_link_values_repeat1, 2, 0, 0),
  [14375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_impl_values_repeat1, 2, 0, 0),
  [14377] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_conditional_where_repeat1, 2, 0, 0),
  [14379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11358),
  [14381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7007),
  [14383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11140),
  [14385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8540),
  [14387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11358),
  [14389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3681),
  [14391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5093),
  [14393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7134),
  [14395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6928),
  [14397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [14399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11119),
  [14401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6793),
  [14403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12421),
  [14405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7194),
  [14407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [14409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4611),
  [14411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12633),
  [14413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6932),
  [14415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [14417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4859),
  [14419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6243),
  [14421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7016),
  [14423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6892),
  [14425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12273),
  [14427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6238),
  [14429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7008),
  [14431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7191),
  [14433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6931),
  [14435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6215),
  [14437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6231),
  [14439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7168),
  [14441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7011),
  [14443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_fieldgroups_repeat2, 2, 0, 0),
  [14445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6999),
  [14447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6985),
  [14449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6899),
  [14451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5756),
  [14453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [14455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6224),
  [14457] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_fieldgroups_repeat2, 1, 0, 0),
  [14459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3813),
  [14461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7015),
  [14463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7002),
  [14465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6733),
  [14467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7019),
  [14469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3828),
  [14471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6897),
  [14473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [14475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6981),
  [14477] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_fieldgroups_repeat1, 2, 0, 0), SHIFT_REPEAT(9696),
  [14480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_fieldgroups_repeat1, 2, 0, 0),
  [14482] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_fieldgroups_repeat1, 2, 0, 0), SHIFT_REPEAT(12274),
  [14485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7004),
  [14487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6240),
  [14489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5115),
  [14491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11160),
  [14493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11162),
  [14495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12511),
  [14497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12520),
  [14499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12430),
  [14501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7511),
  [14503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5540),
  [14505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6710),
  [14507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7512),
  [14509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6747),
  [14511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_views_section_repeat1, 2, 0, 0),
  [14513] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_views_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11160),
  [14516] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_views_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11162),
  [14519] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_views_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12511),
  [14522] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_views_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12520),
  [14525] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_views_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12430),
  [14528] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_views_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12625),
  [14531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4008),
  [14533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8048),
  [14535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4125),
  [14537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3567),
  [14539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5776),
  [14541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7552),
  [14543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3723),
  [14545] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__procedure_header_repeat1, 2, 0, 0),
  [14547] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__procedure_header_repeat1, 2, 0, 0), SHIFT_REPEAT(11140),
  [14550] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__procedure_header_repeat1, 2, 0, 0),
  [14552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5370),
  [14554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7569),
  [14556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7596),
  [14558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7579),
  [14560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_fields_repeat2, 1, 0, 0),
  [14562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_fields_repeat2, 2, 0, 0),
  [14564] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_fields_repeat1, 2, 0, 0), SHIFT_REPEAT(12628),
  [14567] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_fields_repeat1, 2, 0, 0), SHIFT_REPEAT(11187),
  [14570] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_fields_repeat1, 2, 0, 0), SHIFT_REPEAT(12448),
  [14573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_fields_repeat1, 2, 0, 0),
  [14575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8428),
  [14577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7549),
  [14579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7480),
  [14581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12250),
  [14583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12257),
  [14585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7510),
  [14587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12261),
  [14589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7549),
  [14591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11212),
  [14593] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_implementation_value_list_repeat1, 1, 0, 0),
  [14595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_implementation_value_list_repeat1, 1, 0, 0),
  [14597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7766),
  [14599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_where_conditions_repeat1, 1, 0, 0),
  [14601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7773),
  [14603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_where_conditions_repeat1, 1, 0, 0),
  [14605] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_link_value_list_repeat1, 1, 0, 0),
  [14607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_link_value_list_repeat1, 1, 0, 0),
  [14609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7703),
  [14611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4274),
  [14613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fieldgroup_declaration, 6, 0, 92),
  [14615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7254),
  [14617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7238),
  [14619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11435),
  [14621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11739),
  [14623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11436),
  [14625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7254),
  [14627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [14629] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__namespaced_or_simple_ref_repeat1, 2, 0, 0), SHIFT_REPEAT(8533),
  [14632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7959),
  [14634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7960),
  [14636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7665),
  [14638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7743),
  [14640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7652),
  [14642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7259),
  [14644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7259),
  [14646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5389),
  [14648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5389),
  [14650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6004),
  [14652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8232),
  [14654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8232),
  [14656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8895),
  [14658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_fieldgroups, 4, 0, 0),
  [14660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(957),
  [14662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [14664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [14666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7724),
  [14668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7951),
  [14670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [14672] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_dataset_repeat2, 1, 0, 0),
  [14674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7683),
  [14676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7876),
  [14678] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_impl_values, 3, 0, 0),
  [14680] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_impl_values, 3, 0, 0),
  [14682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1083),
  [14684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1083),
  [14686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [14688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7952),
  [14690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [14692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7634),
  [14694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_fieldgroups, 5, 0, 0),
  [14696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7635),
  [14698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_keys_repeat2, 1, 0, 0),
  [14700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [14702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8340),
  [14704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7964),
  [14706] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_link_values, 4, 0, 0),
  [14708] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_link_values, 4, 0, 0),
  [14710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7847),
  [14712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7774),
  [14714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7775),
  [14716] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_where, 6, 0, 0),
  [14718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_where, 6, 0, 0),
  [14720] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_where, 2, 0, 0),
  [14722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_where, 2, 0, 0),
  [14724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7706),
  [14726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7706),
  [14728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8774),
  [14730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [14732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4828),
  [14734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7731),
  [14736] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_impl_values, 2, 0, 0),
  [14738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_impl_values, 2, 0, 0),
  [14740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7965),
  [14742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7739),
  [14744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7649),
  [14746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7694),
  [14748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1193),
  [14750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1193),
  [14752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [14754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7880),
  [14756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7966),
  [14758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fieldgroup_declaration, 8, 0, 92),
  [14760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7839),
  [14762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7239),
  [14764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7239),
  [14766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7393),
  [14768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7844),
  [14770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8157),
  [14772] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_link_values, 2, 0, 0),
  [14774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_link_values, 2, 0, 0),
  [14776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7777),
  [14778] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_impl_values, 4, 0, 0),
  [14780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_impl_values, 4, 0, 0),
  [14782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_dataset_repeat2, 2, 0, 0),
  [14784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_fieldgroups, 3, 0, 0),
  [14786] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_link_value_list_repeat1, 2, 0, 0),
  [14788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7768),
  [14790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8533),
  [14792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7708),
  [14794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5670),
  [14796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5670),
  [14798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6082),
  [14800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fieldgroup_declaration, 9, 0, 92),
  [14802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7631),
  [14804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7645),
  [14806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7961),
  [14808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6435),
  [14810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6435),
  [14812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6857),
  [14814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7770),
  [14816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7653),
  [14818] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_dataset_repeat1, 2, 0, 0), SHIFT_REPEAT(11187),
  [14821] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_dataset_repeat1, 2, 0, 0),
  [14823] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_dataset_repeat1, 2, 0, 0), SHIFT_REPEAT(12633),
  [14826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7735),
  [14828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1982),
  [14830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1982),
  [14832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2136),
  [14834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7663),
  [14836] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_link_values, 5, 0, 0),
  [14838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_link_values, 5, 0, 0),
  [14840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7556),
  [14842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7556),
  [14844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7748),
  [14846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7655),
  [14848] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_where, 4, 0, 0),
  [14850] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_where, 4, 0, 0),
  [14852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7757),
  [14854] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_fieldgroups, 6, 0, 0),
  [14856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7755),
  [14858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7691),
  [14860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7693),
  [14862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7786),
  [14864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__namespaced_or_simple_ref_repeat1, 2, 0, 0), SHIFT_REPEAT(8340),
  [14867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7682),
  [14869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7666),
  [14871] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_link_values, 3, 0, 0),
  [14873] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_link_values, 3, 0, 0),
  [14875] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_where, 3, 0, 0),
  [14877] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_where, 3, 0, 0),
  [14879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7713),
  [14881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_fieldgroups, 2, 0, 0),
  [14883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7962),
  [14885] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_where, 5, 0, 0),
  [14887] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_where, 5, 0, 0),
  [14889] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_keys_repeat2, 2, 0, 0),
  [14891] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(11187),
  [14894] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_keys_repeat1, 2, 0, 0),
  [14896] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(12273),
  [14899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1984),
  [14901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1984),
  [14903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2184),
  [14905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7715),
  [14907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7662),
  [14909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7686),
  [14911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7963),
  [14913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7679),
  [14915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7700),
  [14917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7704),
  [14919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7688),
  [14921] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_impl_values, 5, 0, 0),
  [14923] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_impl_values, 5, 0, 0),
  [14925] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_impl_values, 6, 0, 0),
  [14927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_impl_values, 6, 0, 0),
  [14929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7778),
  [14931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7767),
  [14933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_implementation_value_list_repeat1, 2, 0, 0),
  [14935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1423),
  [14937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1423),
  [14939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [14941] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_link_values, 6, 0, 0),
  [14943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_link_values, 6, 0, 0),
  [14945] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_where_conditions_repeat1, 2, 0, 0),
  [14947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7714),
  [14949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8160),
  [14951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8206),
  [14953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [14955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8262),
  [14957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8286),
  [14959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8841),
  [14961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8887),
  [14963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8276),
  [14965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8213),
  [14967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8246),
  [14969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8180),
  [14971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8175),
  [14973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11923),
  [14975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11723),
  [14977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11848),
  [14979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11923),
  [14981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12152),
  [14983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11765),
  [14985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12152),
  [14987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4325),
  [14989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12439),
  [14991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5960),
  [14993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6080),
  [14995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3964),
  [14997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12509),
  [14999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12512),
  [15001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12513),
  [15003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1429),
  [15005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1530),
  [15007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5208),
  [15009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5210),
  [15011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5344),
  [15013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5358),
  [15015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8327),
  [15017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8303),
  [15019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8308),
  [15021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8315),
  [15023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8207),
  [15025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8225),
  [15027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8228),
  [15029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6806),
  [15031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6856),
  [15033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8255),
  [15035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8205),
  [15037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8208),
  [15039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8285),
  [15041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8925),
  [15043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1003),
  [15045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [15047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2119),
  [15049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2183),
  [15051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6698),
  [15053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6700),
  [15055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6734),
  [15057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6738),
  [15059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8261),
  [15061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8284),
  [15063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8290),
  [15065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8293),
  [15067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8313),
  [15069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8193),
  [15071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8194),
  [15073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8253),
  [15075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8220),
  [15077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [15079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1141),
  [15081] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_var_block_repeat1, 1, 0, 0),
  [15083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7350),
  [15085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7392),
  [15087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5623),
  [15089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5638),
  [15091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5757),
  [15093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5762),
  [15095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8307),
  [15097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [15099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2615),
  [15101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8319),
  [15103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8259),
  [15105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8177),
  [15107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8186),
  [15109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8195),
  [15111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8196),
  [15113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8201),
  [15115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8409),
  [15117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8808),
  [15119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8226),
  [15121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [15123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8234),
  [15125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8237),
  [15127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8238),
  [15129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8243),
  [15131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8247),
  [15133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8248),
  [15135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8250),
  [15137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8260),
  [15139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8268),
  [15141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12142),
  [15143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8269),
  [15145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8272),
  [15147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8278),
  [15149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8280),
  [15151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8282),
  [15153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8283),
  [15155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8289),
  [15157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [15159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8301),
  [15161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12384),
  [15163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12382),
  [15165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12383),
  [15167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12384),
  [15169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8302),
  [15171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8304),
  [15173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8306),
  [15175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [15177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8309),
  [15179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8310),
  [15181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8312),
  [15183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8314),
  [15185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [15187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8317),
  [15189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8318),
  [15191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8320),
  [15193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8322),
  [15195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8325),
  [15197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8258),
  [15199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8176),
  [15201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8178),
  [15203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [15205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8181),
  [15207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8182),
  [15209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8184),
  [15211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4018),
  [15213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4022),
  [15215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12218),
  [15217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11971),
  [15219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11972),
  [15221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12218),
  [15223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5920),
  [15225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6003),
  [15227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4315),
  [15229] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 8, 0, 136),
  [15231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12202),
  [15233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11983),
  [15235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11984),
  [15237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12202),
  [15239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8326),
  [15241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8209),
  [15243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2104),
  [15245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2176),
  [15247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4736),
  [15249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4827),
  [15251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11491),
  [15253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12002),
  [15255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8274),
  [15257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11488),
  [15259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11489),
  [15261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11609),
  [15263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11610),
  [15265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11689),
  [15267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_fields_section_repeat1, 2, 0, 0),
  [15269] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fields_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12439),
  [15272] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fields_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11178),
  [15275] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fields_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12391),
  [15278] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fields_section_repeat1, 2, 0, 0), SHIFT_REPEAT(9327),
  [15281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3515),
  [15283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3517),
  [15285] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_fieldgroups_section_repeat1, 2, 0, 0),
  [15287] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fieldgroups_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12509),
  [15290] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fieldgroups_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12512),
  [15293] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fieldgroups_section_repeat1, 2, 0, 0), SHIFT_REPEAT(9696),
  [15296] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fieldgroups_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12513),
  [15299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [15301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1235),
  [15303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3682),
  [15305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3693),
  [15307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8191),
  [15309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addlast_dataset_modification, 7, 0, 49),
  [15311] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addlast_dataset_modification, 7, 0, 49),
  [15313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addfirst_dataset_modification, 7, 0, 49),
  [15315] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addfirst_dataset_modification, 7, 0, 49),
  [15317] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dotnet_keyword, 1, 0, 0),
  [15319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dotnet_keyword, 1, 0, 0),
  [15321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_dataset, 2, 0, 0),
  [15323] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_dataset, 2, 0, 0),
  [15325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3402),
  [15327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addafter_dataset_modification, 7, 0, 49),
  [15329] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addafter_dataset_modification, 7, 0, 49),
  [15331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10947),
  [15333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10947),
  [15335] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addbefore_dataset_modification, 7, 0, 49),
  [15337] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addbefore_dataset_modification, 7, 0, 49),
  [15339] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_add_dataset_modification, 7, 0, 49),
  [15341] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_add_dataset_modification, 7, 0, 49),
  [15343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3402),
  [15346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11939),
  [15348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11938),
  [15350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11939),
  [15352] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implements_clause, 3, 0, 16),
  [15354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8480),
  [15356] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addlast_dataset_modification, 6, 0, 49),
  [15358] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addlast_dataset_modification, 6, 0, 49),
  [15360] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addfirst_dataset_modification, 6, 0, 49),
  [15362] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addfirst_dataset_modification, 6, 0, 49),
  [15364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4156),
  [15366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_header, 3, 0, 5),
  [15368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8439),
  [15370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addafter_dataset_modification, 6, 0, 49),
  [15372] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addafter_dataset_modification, 6, 0, 49),
  [15374] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_report_dataitem, 9, 0, 139),
  [15376] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addbefore_dataset_modification, 6, 0, 49),
  [15378] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addbefore_dataset_modification, 6, 0, 49),
  [15380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4158),
  [15382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8436),
  [15384] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 10, 0, 136),
  [15386] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addfirst_dataset_modification, 4, 0, 0),
  [15388] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addfirst_dataset_modification, 4, 0, 0),
  [15390] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_add_dataset_modification, 6, 0, 49),
  [15392] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_add_dataset_modification, 6, 0, 49),
  [15394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_dataset, 4, 0, 0),
  [15396] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_dataset, 4, 0, 0),
  [15398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_implements_clause_repeat1, 2, 0, 28),
  [15400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_implements_clause_repeat1, 2, 0, 28), SHIFT_REPEAT(8480),
  [15403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_dataset, 6, 0, 0),
  [15405] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_dataset, 6, 0, 0),
  [15407] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_report_dataitem, 8, 0, 139),
  [15409] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implements_clause, 2, 0, 9),
  [15411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addfirst_dataset_modification, 3, 0, 0),
  [15413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_addfirst_dataset_modification, 3, 0, 0),
  [15415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 11, 0, 136),
  [15417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11731),
  [15419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11731),
  [15421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_dataset, 3, 0, 0),
  [15423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_dataset, 3, 0, 0),
  [15425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12210),
  [15427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12327),
  [15429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12210),
  [15431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12306),
  [15433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12331),
  [15435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12306),
  [15437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_dataset, 5, 0, 0),
  [15439] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_conditional_dataset, 5, 0, 0),
  [15441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11168),
  [15443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11168),
  [15445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4273),
  [15447] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_key_declaration, 6, 0, 92),
  [15449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11437),
  [15451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11437),
  [15453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11570),
  [15455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11570),
  [15457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11663),
  [15459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11663),
  [15461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11741),
  [15463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11741),
  [15465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3874),
  [15467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11900),
  [15469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_header, 2, 0, 4),
  [15471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8558),
  [15473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11269),
  [15475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11268),
  [15477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11269),
  [15479] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__namespaced_or_simple_ref_repeat1, 2, 0, 0), SHIFT_REPEAT(8436),
  [15482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11950),
  [15484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11950),
  [15486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11990),
  [15488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11990),
  [15490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11387),
  [15492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11387),
  [15494] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_fieldgroups_repeat2, 2, 0, 0), SHIFT_REPEAT(9715),
  [15497] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_statement_repeat1, 2, 0, 52), SHIFT_REPEAT(9686),
  [15500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_statement_repeat1, 2, 0, 52),
  [15502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11969),
  [15504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11969),
  [15506] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_actions_repeat1, 2, 0, 0), SHIFT_REPEAT(9499),
  [15509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_where_clause, 4, 0, 0),
  [15511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1136),
  [15513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1136),
  [15515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1113),
  [15517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1113),
  [15519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12223),
  [15521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12223),
  [15523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6329),
  [15525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6330),
  [15527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6329),
  [15529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7769),
  [15531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7769),
  [15533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8853),
  [15535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8853),
  [15537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6699),
  [15539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12497),
  [15541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12143),
  [15543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12143),
  [15545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11985),
  [15547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11985),
  [15549] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_repeat1, 2, 0, 0), SHIFT_REPEAT(9909),
  [15552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6736),
  [15554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8883),
  [15556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8883),
  [15558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12231),
  [15560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12231),
  [15562] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_repeat1, 2, 0, 0), SHIFT_REPEAT(9574),
  [15565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11389),
  [15567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11389),
  [15569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12180),
  [15571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12180),
  [15573] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_dataset_repeat2, 2, 0, 0), SHIFT_REPEAT(9328),
  [15576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_table_relation, 5, 0, 67),
  [15578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2231),
  [15580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11260),
  [15582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11260),
  [15584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12196),
  [15586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12196),
  [15588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11230),
  [15590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11230),
  [15592] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat1, 2, 0, 7), SHIFT_REPEAT(9837),
  [15595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat1, 2, 0, 7),
  [15597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12130),
  [15599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12130),
  [15601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12242),
  [15603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12242),
  [15605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11137),
  [15607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11137),
  [15609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3730),
  [15611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11422),
  [15613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11422),
  [15615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11430),
  [15617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11430),
  [15619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12579),
  [15621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12579),
  [15623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12148),
  [15625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12148),
  [15627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12567),
  [15629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12567),
  [15631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10784),
  [15633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10784),
  [15635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11543),
  [15637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11543),
  [15639] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_controladdin_repeat1, 2, 0, 0), SHIFT_REPEAT(9909),
  [15642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11373),
  [15644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11373),
  [15646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2563),
  [15648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2548),
  [15650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2563),
  [15652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2542),
  [15654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2542),
  [15656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1118),
  [15658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1118),
  [15660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7255),
  [15662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7255),
  [15664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5631),
  [15666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12144),
  [15668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12144),
  [15670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8300),
  [15672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8300),
  [15674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5761),
  [15676] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3730),
  [15679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12317),
  [15681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12317),
  [15683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10521),
  [15685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10521),
  [15687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12488),
  [15689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12488),
  [15691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10581),
  [15693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10581),
  [15695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11276),
  [15697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11276),
  [15699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10590),
  [15701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10590),
  [15703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4826),
  [15705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4826),
  [15707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11226),
  [15709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11226),
  [15711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4696),
  [15713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4696),
  [15715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12668),
  [15717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12057),
  [15719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2144),
  [15721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2144),
  [15723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2107),
  [15725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2107),
  [15727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4869),
  [15729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4869),
  [15731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1210),
  [15733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1210),
  [15735] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_layout_mixed_repeat2, 2, 0, 0), SHIFT_REPEAT(9909),
  [15738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6009),
  [15740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6009),
  [15742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5878),
  [15744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5878),
  [15746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2102),
  [15748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2102),
  [15750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5876),
  [15752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5876),
  [15754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8776),
  [15756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1027),
  [15758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [15760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(999),
  [15762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [15764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12243),
  [15766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12243),
  [15768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1513),
  [15770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1513),
  [15772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1448),
  [15774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1448),
  [15776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5401),
  [15778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5401),
  [15780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1006),
  [15782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [15784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_xmlport_repeat1, 2, 0, 0), SHIFT_REPEAT(9710),
  [15787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8231),
  [15789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8231),
  [15791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11403),
  [15793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11403),
  [15795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12453),
  [15797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12453),
  [15799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7292),
  [15801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7292),
  [15803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2146),
  [15805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2146),
  [15807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2106),
  [15809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2106),
  [15811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1436),
  [15813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1436),
  [15815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1114),
  [15817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1114),
  [15819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11203),
  [15821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11203),
  [15823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1209),
  [15825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1209),
  [15827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7607),
  [15829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7607),
  [15831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2099),
  [15833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2099),
  [15835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5421),
  [15837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5421),
  [15839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12328),
  [15841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12328),
  [15843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12417),
  [15845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12417),
  [15847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1000),
  [15849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [15851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8388),
  [15853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8388),
  [15855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2103),
  [15857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2103),
  [15859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12436),
  [15861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12436),
  [15863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8254),
  [15865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8254),
  [15867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1443),
  [15869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1443),
  [15871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12605),
  [15873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12605),
  [15875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11527),
  [15877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11527),
  [15879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3920),
  [15881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2116),
  [15883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2116),
  [15885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11625),
  [15887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11625),
  [15889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12069),
  [15891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12069),
  [15893] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_link_values_repeat2, 2, 0, 0), SHIFT_REPEAT(9328),
  [15896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4020),
  [15898] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_table_relation_repeat1, 2, 0, 0), SHIFT_REPEAT(9639),
  [15901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_table_relation_repeat1, 2, 0, 0),
  [15903] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_permissions_repeat1, 2, 0, 0), SHIFT_REPEAT(9633),
  [15906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12583),
  [15908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12583),
  [15910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8223),
  [15912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8223),
  [15914] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_impl_values_repeat2, 2, 0, 0), SHIFT_REPEAT(9328),
  [15917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11752),
  [15919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11752),
  [15921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12076),
  [15923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12076),
  [15925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12575),
  [15927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12575),
  [15929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12621),
  [15931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12621),
  [15933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11600),
  [15935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11600),
  [15937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11695),
  [15939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11695),
  [15941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11702),
  [15943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11702),
  [15945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11714),
  [15947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11714),
  [15949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5209),
  [15951] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_key_declaration, 8, 0, 92),
  [15953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4779),
  [15955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4779),
  [15957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10547),
  [15959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10547),
  [15961] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_case_repeat2, 2, 0, 0), SHIFT_REPEAT(9686),
  [15964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11800),
  [15966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11800),
  [15968] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_case_branch_repeat2, 2, 0, 52), SHIFT_REPEAT(9744),
  [15971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_case_branch_repeat2, 2, 0, 52),
  [15973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5345),
  [15975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11283),
  [15977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11283),
  [15979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11316),
  [15981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11316),
  [15983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8798),
  [15985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8798),
  [15987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11994),
  [15989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11994),
  [15991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10628),
  [15993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10628),
  [15995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11328),
  [15997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11328),
  [15999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12027),
  [16001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12027),
  [16003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8712),
  [16005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8712),
  [16007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8799),
  [16009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8799),
  [16011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_key_declaration, 9, 0, 92),
  [16013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12654),
  [16015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12654),
  [16017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1223),
  [16019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1223),
  [16021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12232),
  [16023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12232),
  [16025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12237),
  [16027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12237),
  [16029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12239),
  [16031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12239),
  [16033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12249),
  [16035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12249),
  [16037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12194),
  [16039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12194),
  [16041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1206),
  [16043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [16045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12126),
  [16047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12126),
  [16049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12001),
  [16051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12001),
  [16053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12186),
  [16055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12186),
  [16057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12036),
  [16059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12036),
  [16061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11189),
  [16063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11189),
  [16065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11500),
  [16067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11500),
  [16069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12085),
  [16071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12085),
  [16073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12092),
  [16075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12092),
  [16077] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_table_relation, 2, 0, 10),
  [16079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11470),
  [16081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11470),
  [16083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11535),
  [16085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11535),
  [16087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12137),
  [16089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12137),
  [16091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12150),
  [16093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12150),
  [16095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12189),
  [16097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12189),
  [16099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12201),
  [16101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12201),
  [16103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11473),
  [16105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11473),
  [16107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12661),
  [16109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12661),
  [16111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12483),
  [16113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12483),
  [16115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12410),
  [16117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12410),
  [16119] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_field_repeat1, 2, 0, 52), SHIFT_REPEAT(9837),
  [16122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_field_repeat1, 2, 0, 52),
  [16124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12164),
  [16126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12164),
  [16128] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_object_repeat1, 2, 0, 0), SHIFT_REPEAT(9715),
  [16131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12522),
  [16133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12522),
  [16135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12543),
  [16137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12543),
  [16139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6791),
  [16141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6791),
  [16143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7613),
  [16145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7613),
  [16147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4810),
  [16149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4810),
  [16151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7356),
  [16153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7356),
  [16155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8913),
  [16157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8913),
  [16159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12550),
  [16161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12550),
  [16163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12334),
  [16165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12334),
  [16167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11248),
  [16169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11248),
  [16171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12443),
  [16173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12443),
  [16175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8355),
  [16177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8355),
  [16179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11130),
  [16181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11130),
  [16183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11273),
  [16185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11273),
  [16187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8780),
  [16189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8780),
  [16191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8781),
  [16193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8781),
  [16195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12021),
  [16197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12021),
  [16199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8784),
  [16201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8784),
  [16203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8786),
  [16205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8786),
  [16207] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_var_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9328),
  [16210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_var_block_repeat1, 2, 0, 0),
  [16212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8788),
  [16214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8788),
  [16216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10423),
  [16218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10423),
  [16220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12582),
  [16222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12582),
  [16224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12598),
  [16226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12598),
  [16228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12601),
  [16230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12601),
  [16232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12604),
  [16234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12604),
  [16236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12607),
  [16238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12607),
  [16240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12610),
  [16242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12610),
  [16244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12613),
  [16246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12613),
  [16248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11400),
  [16250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11400),
  [16252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10424),
  [16254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10424),
  [16256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12626),
  [16258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12626),
  [16260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10425),
  [16262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10425),
  [16264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12663),
  [16266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12663),
  [16268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11164),
  [16270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11164),
  [16272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12553),
  [16274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12553),
  [16276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11346),
  [16278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11346),
  [16280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11365),
  [16282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11365),
  [16284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11366),
  [16286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11366),
  [16288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11399),
  [16290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11399),
  [16292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11433),
  [16294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11433),
  [16296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11472),
  [16298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11472),
  [16300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11505),
  [16302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11505),
  [16304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11507),
  [16306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11507),
  [16308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11567),
  [16310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11567),
  [16312] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_report_repeat1, 2, 0, 0), SHIFT_REPEAT(9909),
  [16315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11683),
  [16317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11683),
  [16319] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_var_repeat2, 2, 0, 0), SHIFT_REPEAT(9878),
  [16322] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_query_repeat1, 2, 0, 0), SHIFT_REPEAT(9909),
  [16325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12253),
  [16327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12253),
  [16329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11327),
  [16331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11327),
  [16333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11796),
  [16335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11796),
  [16337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12127),
  [16339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12127),
  [16341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8770),
  [16343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8770),
  [16345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8826),
  [16347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8826),
  [16349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11416),
  [16351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11416),
  [16353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11423),
  [16355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11423),
  [16357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11425),
  [16359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11425),
  [16361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11426),
  [16363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11426),
  [16365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11432),
  [16367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11432),
  [16369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11440),
  [16371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11440),
  [16373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11441),
  [16375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11441),
  [16377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11442),
  [16379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11442),
  [16381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11443),
  [16383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11443),
  [16385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11444),
  [16387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11444),
  [16389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11445),
  [16391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11445),
  [16393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11446),
  [16395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11446),
  [16397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11447),
  [16399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11447),
  [16401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11448),
  [16403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11448),
  [16405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11449),
  [16407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11449),
  [16409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11450),
  [16411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11450),
  [16413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11451),
  [16415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11451),
  [16417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11453),
  [16419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11453),
  [16421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11454),
  [16423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11454),
  [16425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11455),
  [16427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11455),
  [16429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11456),
  [16431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11456),
  [16433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11457),
  [16435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11457),
  [16437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11458),
  [16439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11458),
  [16441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11459),
  [16443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11459),
  [16445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11460),
  [16447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11460),
  [16449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11461),
  [16451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11461),
  [16453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11462),
  [16455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11462),
  [16457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11463),
  [16459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11463),
  [16461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11465),
  [16463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11465),
  [16465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11466),
  [16467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11466),
  [16469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11467),
  [16471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11467),
  [16473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11468),
  [16475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11468),
  [16477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11469),
  [16479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11469),
  [16481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11176),
  [16483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11176),
  [16485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11475),
  [16487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11475),
  [16489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11483),
  [16491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11483),
  [16493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11484),
  [16495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11484),
  [16497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11485),
  [16499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11485),
  [16501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11486),
  [16503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11486),
  [16505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11487),
  [16507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11487),
  [16509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12009),
  [16511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12009),
  [16513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11516),
  [16515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11516),
  [16517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11197),
  [16519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11197),
  [16521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12571),
  [16523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12571),
  [16525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11524),
  [16527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11524),
  [16529] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_if_else_statement_repeat1, 2, 0, 180), SHIFT_REPEAT(9837),
  [16532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_if_else_statement_repeat1, 2, 0, 180),
  [16534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11207),
  [16536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11207),
  [16538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11540),
  [16540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11540),
  [16542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11544),
  [16544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11544),
  [16546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11545),
  [16548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11545),
  [16550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11560),
  [16552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11560),
  [16554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11562),
  [16556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11562),
  [16558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11564),
  [16560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11564),
  [16562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11565),
  [16564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11565),
  [16566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11569),
  [16568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11569),
  [16570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11573),
  [16572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11573),
  [16574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11574),
  [16576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11574),
  [16578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11575),
  [16580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11575),
  [16582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11576),
  [16584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11576),
  [16586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11577),
  [16588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11577),
  [16590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11578),
  [16592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11578),
  [16594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11579),
  [16596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11579),
  [16598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11580),
  [16600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11580),
  [16602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11581),
  [16604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11581),
  [16606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11583),
  [16608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11583),
  [16610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11584),
  [16612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11584),
  [16614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11585),
  [16616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11585),
  [16618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11586),
  [16620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11586),
  [16622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11587),
  [16624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11587),
  [16626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11588),
  [16628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11588),
  [16630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11589),
  [16632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11589),
  [16634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11590),
  [16636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11590),
  [16638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11591),
  [16640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11591),
  [16642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11592),
  [16644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11592),
  [16646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11593),
  [16648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11593),
  [16650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11595),
  [16652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11595),
  [16654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11596),
  [16656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11596),
  [16658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11597),
  [16660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11597),
  [16662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11598),
  [16664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11598),
  [16666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11599),
  [16668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11599),
  [16670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11224),
  [16672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11224),
  [16674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11605),
  [16676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11605),
  [16678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11606),
  [16680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11606),
  [16682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11607),
  [16684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11607),
  [16686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11608),
  [16688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11608),
  [16690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12010),
  [16692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12010),
  [16694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11656),
  [16696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11656),
  [16698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11658),
  [16700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11658),
  [16702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11660),
  [16704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11660),
  [16706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11666),
  [16708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11666),
  [16710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11667),
  [16712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11667),
  [16714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11668),
  [16716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11668),
  [16718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11669),
  [16720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11669),
  [16722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11670),
  [16724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11670),
  [16726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11671),
  [16728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11671),
  [16730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11253),
  [16732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11253),
  [16734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11673),
  [16736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11673),
  [16738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11674),
  [16740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11674),
  [16742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11675),
  [16744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11675),
  [16746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11677),
  [16748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11677),
  [16750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11678),
  [16752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11678),
  [16754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11679),
  [16756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11679),
  [16758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11680),
  [16760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11680),
  [16762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11681),
  [16764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11681),
  [16766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11686),
  [16768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11686),
  [16770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11687),
  [16772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11687),
  [16774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11688),
  [16776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11688),
  [16778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11734),
  [16780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11734),
  [16782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11736),
  [16784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11736),
  [16786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11738),
  [16788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11738),
  [16790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11744),
  [16792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11744),
  [16794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11745),
  [16796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11745),
  [16798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12618),
  [16800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12618),
  [16802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8834),
  [16804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8834),
  [16806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8777),
  [16808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8777),
  [16810] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_where_repeat2, 2, 0, 0), SHIFT_REPEAT(9328),
  [16813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11777),
  [16815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11777),
  [16817] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_if_statement_repeat1, 2, 0, 105), SHIFT_REPEAT(9837),
  [16820] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_if_statement_repeat1, 2, 0, 105),
  [16822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11797),
  [16824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11797),
  [16826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11809),
  [16828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11809),
  [16830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11820),
  [16832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11820),
  [16834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11898),
  [16836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11898),
  [16838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11899),
  [16840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11899),
  [16842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11902),
  [16844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11902),
  [16846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11903),
  [16848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11903),
  [16850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11904),
  [16852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11904),
  [16854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11905),
  [16856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11905),
  [16858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11906),
  [16860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11906),
  [16862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_implements_clause_repeat1, 2, 0, 9),
  [16864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11404),
  [16866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11404),
  [16868] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_keys_section_repeat1, 2, 0, 0),
  [16870] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_keys_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11178),
  [16873] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_keys_section_repeat1, 2, 0, 0), SHIFT_REPEAT(9327),
  [16876] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_keys_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12497),
  [16879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11417),
  [16881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11417),
  [16883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11431),
  [16885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11431),
  [16887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11471),
  [16889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11471),
  [16891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12059),
  [16893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12059),
  [16895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3516),
  [16897] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_repeat1, 2, 0, 25), SHIFT_REPEAT(9837),
  [16900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_repeat1, 2, 0, 25),
  [16902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11557),
  [16904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11557),
  [16906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11566),
  [16908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11566),
  [16910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11568),
  [16912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11568),
  [16914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11613),
  [16916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11613),
  [16918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11645),
  [16920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11645),
  [16922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11636),
  [16924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11636),
  [16926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11653),
  [16928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11653),
  [16930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11693),
  [16932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11693),
  [16934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11708),
  [16936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11708),
  [16938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11717),
  [16940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11717),
  [16942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11925),
  [16944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11925),
  [16946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11927),
  [16948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11927),
  [16950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3683),
  [16952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11930),
  [16954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11930),
  [16956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12662),
  [16958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12662),
  [16960] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_fields_repeat2, 2, 0, 0), SHIFT_REPEAT(9328),
  [16963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11369),
  [16965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11369),
  [16967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11262),
  [16969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11262),
  [16971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11949),
  [16973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11949),
  [16975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11953),
  [16977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11953),
  [16979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12310),
  [16981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12310),
  [16983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12311),
  [16985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12311),
  [16987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12312),
  [16989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12312),
  [16991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12313),
  [16993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12313),
  [16995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12314),
  [16997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12314),
  [16999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12315),
  [17001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12315),
  [17003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11476),
  [17005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11476),
  [17007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12321),
  [17009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12321),
  [17011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12332),
  [17013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12332),
  [17015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12371),
  [17017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12371),
  [17019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12372),
  [17021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12372),
  [17023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12373),
  [17025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12373),
  [17027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12374),
  [17029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12374),
  [17031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12375),
  [17033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12375),
  [17035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12376),
  [17037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12376),
  [17039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12412),
  [17041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12412),
  [17043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12413),
  [17045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12413),
  [17047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12414),
  [17049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12414),
  [17051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12415),
  [17053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12415),
  [17055] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_keys_repeat2, 2, 0, 0), SHIFT_REPEAT(9328),
  [17058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11975),
  [17060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11975),
  [17062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11976),
  [17064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11976),
  [17066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11986),
  [17068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11986),
  [17070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11989),
  [17072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11989),
  [17074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11434),
  [17076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11434),
  [17078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11929),
  [17080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8892),
  [17082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4148),
  [17084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8893),
  [17086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8927),
  [17088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8871),
  [17090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11582),
  [17092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4151),
  [17094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8860),
  [17096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 7, 0, 118),
  [17098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4182),
  [17100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_header, 5, 0, 15),
  [17102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4183),
  [17104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4170),
  [17106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_header, 4, 0, 5),
  [17108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4185),
  [17110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4173),
  [17112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4187),
  [17114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4189),
  [17116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_table_relation, 5, 0, 0),
  [17118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11452),
  [17120] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_table_relation, 8, 0, 0),
  [17122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8861),
  [17124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 7, 0, 119),
  [17126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_relation_expression, 1, 0, 0),
  [17128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4157),
  [17130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4160),
  [17132] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_table_relation, 4, 0, 0),
  [17134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8858),
  [17136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 7, 0, 116),
  [17138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8937),
  [17140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8940),
  [17142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11353),
  [17144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8943),
  [17146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8944),
  [17148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8928),
  [17150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_table_relation, 7, 0, 122),
  [17152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_table_relation, 7, 0, 0),
  [17154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8859),
  [17156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 7, 0, 117),
  [17158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_table_relation, 6, 0, 0),
  [17160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8848),
  [17162] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 8, 0, 130),
  [17164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4149),
  [17166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8849),
  [17168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 8, 0, 131),
  [17170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8929),
  [17172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 6, 0, 84),
  [17174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8931),
  [17176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 6, 0, 85),
  [17178] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_controladdin_keyword, 1, 0, 0),
  [17180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_controladdin_keyword, 1, 0, 0),
  [17182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4150),
  [17184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8923),
  [17186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8867),
  [17188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8947),
  [17190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8890),
  [17192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11351),
  [17194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9634),
  [17196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11378),
  [17198] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_declaration_repeat1, 2, 0, 6),
  [17200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 9, 0, 130),
  [17202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 9, 0, 131),
  [17204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9859),
  [17206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9862),
  [17208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9891),
  [17210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9754),
  [17212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 8, 0, 116),
  [17214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 8, 0, 117),
  [17216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 8, 0, 118),
  [17218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 8, 0, 119),
  [17220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_field_repeat1, 2, 0, 29),
  [17222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9796),
  [17224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9797),
  [17226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9818),
  [17228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9329),
  [17230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9875),
  [17232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9896),
  [17234] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_profileextension_keyword, 1, 0, 0),
  [17236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_profileextension_keyword, 1, 0, 0),
  [17238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9361),
  [17240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9756),
  [17242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9338),
  [17244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_case_repeat2, 3, 0, 0),
  [17246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9340),
  [17248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_if_else_statement_repeat1, 6, 0, 166),
  [17250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_if_else_statement_repeat1, 6, 0, 167),
  [17252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9345),
  [17254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__field_header, 6, 0, 124),
  [17256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9537),
  [17258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9362),
  [17260] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pagecustomization_keyword, 1, 0, 0),
  [17262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pagecustomization_keyword, 1, 0, 0),
  [17264] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_procedure_repeat1, 2, 0, 24),
  [17266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9907),
  [17268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_conditional_table_relation_repeat1, 3, 0, 0),
  [17270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 7, 0, 84),
  [17272] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_header, 7, 0, 85),
  [17274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9697),
  [17276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9745),
  [17278] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_split_if_statement_repeat1, 2, 0, 102),
  [17280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9450),
  [17282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9502),
  [17284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9490),
  [17286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9503),
  [17288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9508),
  [17290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_else_branch, 2, 0, 0),
  [17292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9524),
  [17294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9531),
  [17296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9532),
  [17298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9563),
  [17300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9331),
  [17302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9344),
  [17304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8576),
  [17306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11464),
  [17308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4174),
  [17310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11594),
  [17312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12418),
  [17314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addlast_fieldgroup_modification, 6, 0, 93),
  [17316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12427),
  [17318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addfirst_fieldgroup_modification, 6, 0, 93),
  [17320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4055),
  [17322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11676),
  [17324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12013),
  [17326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10102),
  [17328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5791),
  [17330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12476),
  [17332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12265),
  [17334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3981),
  [17336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_fields, 4, 0, 0),
  [17338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6484),
  [17340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8333),
  [17342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11232),
  [17344] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_fields, 6, 0, 0),
  [17346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addlast_fieldgroup_modification, 8, 0, 93),
  [17348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addfirst_fieldgroup_modification, 8, 0, 93),
  [17350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4054),
  [17352] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_fields, 5, 0, 0),
  [17354] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_assembly_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(10102),
  [17357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_assembly_declaration_repeat1, 2, 0, 0),
  [17359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_assembly_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12476),
  [17362] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_assembly_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12265),
  [17365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4017),
  [17367] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_fields, 2, 0, 0),
  [17369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6442),
  [17371] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_fields, 3, 0, 0),
  [17373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5386),
  [17375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3680),
  [17377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5384),
  [17379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5795),
  [17381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3763),
  [17383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11125),
  [17385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addlast_views_modification, 3, 0, 0),
  [17387] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_addbefore_modification, 6, 0, 49), REDUCE(sym_addbefore_views_modification, 6, 0, 49),
  [17390] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_view_definition, 7, 0, 48),
  [17392] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_keys, 2, 0, 0),
  [17394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addfirst_views_modification, 3, 0, 0),
  [17396] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_view_definition, 6, 0, 48),
  [17398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_keys, 3, 0, 0),
  [17400] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addlast_views_modification, 4, 0, 0),
  [17402] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_keys, 4, 0, 0),
  [17404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_keys, 5, 0, 0),
  [17406] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_addafter_modification, 6, 0, 49), REDUCE(sym_addafter_views_modification, 6, 0, 49),
  [17409] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addafter_views_modification, 7, 0, 49),
  [17411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addbefore_views_modification, 7, 0, 49),
  [17413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_addfirst_views_modification, 4, 0, 0),
  [17415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_keys, 6, 0, 0),
  [17417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9596),
  [17419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9341),
  [17421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9911),
  [17423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9914),
  [17425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9931),
  [17427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9834),
  [17429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9760),
  [17431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9541),
  [17433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9681),
  [17435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9933),
  [17437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9542),
  [17439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9342),
  [17441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9405),
  [17443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9545),
  [17445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9893),
  [17447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9546),
  [17449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9548),
  [17451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9689),
  [17453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9691),
  [17455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9723),
  [17457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9555),
  [17459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9558),
  [17461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9561),
  [17463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9562),
  [17465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9564),
  [17467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9565),
  [17469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9567),
  [17471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9568),
  [17473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9727),
  [17475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9730),
  [17477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9735),
  [17479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9714),
  [17481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9700),
  [17483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9742),
  [17485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9746),
  [17487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9703),
  [17489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9332),
  [17491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_schema_section_repeat1, 2, 0, 0),
  [17493] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_schema_section_repeat1, 2, 0, 0), SHIFT_REPEAT(12204),
  [17496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9717),
  [17498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9589),
  [17500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9500),
  [17502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9751),
  [17504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9849),
  [17506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9550),
  [17508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9551),
  [17510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9635),
  [17512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9560),
  [17514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9595),
  [17516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9598),
  [17518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9602),
  [17520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9603),
  [17522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9606),
  [17524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9608),
  [17526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9618),
  [17528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9622),
  [17530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9343),
  [17532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9530),
  [17534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9364),
  [17536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9863),
  [17538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9572),
  [17540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9636),
  [17542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9365),
  [17544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5104),
  [17546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12204),
  [17548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9688),
  [17550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9663),
  [17552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9673),
  [17554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9675),
  [17556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9676),
  [17558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9677),
  [17560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9678),
  [17562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9679),
  [17564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9680),
  [17566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9716),
  [17568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9384),
  [17570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9346),
  [17572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9877),
  [17574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9404),
  [17576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9505),
  [17578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9514),
  [17580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9724),
  [17582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9516),
  [17584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9684),
  [17586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9410),
  [17588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9521),
  [17590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9695),
  [17592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9698),
  [17594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9701),
  [17596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9702),
  [17598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9704),
  [17600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9523),
  [17602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9705),
  [17604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9707),
  [17606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9708),
  [17608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9413),
  [17610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9407),
  [17612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9448),
  [17614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9412),
  [17616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9449),
  [17618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9451),
  [17620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9748),
  [17622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9899),
  [17624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9452),
  [17626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9455),
  [17628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9456),
  [17630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9720),
  [17632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9725),
  [17634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9728),
  [17636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9732),
  [17638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9733),
  [17640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9736),
  [17642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9737),
  [17644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9740),
  [17646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9741),
  [17648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9414),
  [17650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9631),
  [17652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9386),
  [17654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6709),
  [17656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9391),
  [17658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9902),
  [17660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9492),
  [17662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9495),
  [17664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9515),
  [17666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9501),
  [17668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9755),
  [17670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9903),
  [17672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9758),
  [17674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9761),
  [17676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9762),
  [17678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9764),
  [17680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9765),
  [17682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9767),
  [17684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9628),
  [17686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9884),
  [17688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9773),
  [17690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9776),
  [17692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9782),
  [17694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9783),
  [17696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4007),
  [17698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9785),
  [17700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9786),
  [17702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9788),
  [17704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9789),
  [17706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9792),
  [17708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9795),
  [17710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9798),
  [17712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9799),
  [17714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9801),
  [17716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9802),
  [17718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9804),
  [17720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9809),
  [17722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9339),
  [17724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9811),
  [17726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5532),
  [17728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9813),
  [17730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9816),
  [17732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9887),
  [17734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9817),
  [17736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9347),
  [17738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9820),
  [17740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9749),
  [17742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9890),
  [17744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5774),
  [17746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9821),
  [17748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9822),
  [17750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9823),
  [17752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9826),
  [17754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9828),
  [17756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9830),
  [17758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9739),
  [17760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9831),
  [17762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9833),
  [17764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9835),
  [17766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9865),
  [17768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9838),
  [17770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3566),
  [17772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9839),
  [17774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9363),
  [17776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9842),
  [17778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9844),
  [17780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9462),
  [17782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9847),
  [17784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9848),
  [17786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9850),
  [17788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9851),
  [17790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9854),
  [17792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9855),
  [17794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9858),
  [17796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9861),
  [17798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9549),
  [17800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9864),
  [17802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9866),
  [17804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9868),
  [17806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9415),
  [17808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9869),
  [17810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9871),
  [17812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9872),
  [17814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9527),
  [17816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9876),
  [17818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3720),
  [17820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9879),
  [17822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9880),
  [17824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9881),
  [17826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9726),
  [17828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9752),
  [17830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9895),
  [17832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9781),
  [17834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9672),
  [17836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9330),
  [17838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9883),
  [17840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9885),
  [17842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9888),
  [17844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9889),
  [17846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9674),
  [17848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9905),
  [17850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9520),
  [17852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9787),
  [17854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9528),
  [17856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4090),
  [17858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6746),
  [17860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9547),
  [17862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9553),
  [17864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9766),
  [17866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9566),
  [17868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9569),
  [17870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9571),
  [17872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9794),
  [17874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9580),
  [17876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9587),
  [17878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9590),
  [17880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9591),
  [17882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9592),
  [17884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9593),
  [17886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5369),
  [17888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9759),
  [17890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9411),
  [17892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9857),
  [17894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9601),
  [17896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9604),
  [17898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9611),
  [17900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9853),
  [17902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9626),
  [17904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9552),
  [17906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9768),
  [17908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4636),
  [17910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5400),
  [17912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7030),
  [17914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11515),
  [17916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7047),
  [17918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2427),
  [17920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4818),
  [17922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11191),
  [17924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9392),
  [17926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9402),
  [17928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9403),
  [17930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6918),
  [17932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11960),
  [17934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6927),
  [17936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10276),
  [17938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2447),
  [17940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6428),
  [17942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12095),
  [17944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6789),
  [17946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9303),
  [17948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7235),
  [17950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11291),
  [17952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9307),
  [17954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9308),
  [17956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9306),
  [17958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9312),
  [17960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9314),
  [17962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9315),
  [17964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9319),
  [17966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6867),
  [17968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12225),
  [17970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6869),
  [17972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2750),
  [17974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12005),
  [17976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2741),
  [17978] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_option_member_list_repeat1, 2, 0, 0), SHIFT_REPEAT(4636),
  [17981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9367),
  [17983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9370),
  [17985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9371),
  [17987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9369),
  [17989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9376),
  [17991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9378),
  [17993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9379),
  [17995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9383),
  [17997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9418),
  [17999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9422),
  [18001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9423),
  [18003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9421),
  [18005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9430),
  [18007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9432),
  [18009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9433),
  [18011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9438),
  [18013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9470),
  [18015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9473),
  [18017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9474),
  [18019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9472),
  [18021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9478),
  [18023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9480),
  [18025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9481),
  [18027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9486),
  [18029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1731),
  [18031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12521),
  [18033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11143),
  [18035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1762),
  [18037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11699),
  [18039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8525),
  [18041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7563),
  [18043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1622),
  [18045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5815),
  [18047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12591),
  [18049] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_option_member, 1, 0, 0), REDUCE(sym__identifier_or_quoted, 1, 0, 0),
  [18052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1750),
  [18054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5658),
  [18056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4625),
  [18058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11672),
  [18060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9774),
  [18062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4615),
  [18064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9882),
  [18066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2787),
  [18068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9757),
  [18070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3274),
  [18072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12255),
  [18074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3504),
  [18076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12320),
  [18078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9356),
  [18080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9763),
  [18082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5372),
  [18084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12335),
  [18086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5374),
  [18088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9791),
  [18090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9815),
  [18092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10275),
  [18094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9829),
  [18096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10289),
  [18098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4764),
  [18100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3332),
  [18102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10301),
  [18104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10308),
  [18106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10315),
  [18108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10321),
  [18110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10323),
  [18112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10325),
  [18114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10327),
  [18116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10329),
  [18118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10331),
  [18120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10333),
  [18122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10335),
  [18124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10337),
  [18126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10339),
  [18128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10341),
  [18130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10343),
  [18132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10345),
  [18134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1772),
  [18136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12424),
  [18138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8920),
  [18140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4003),
  [18142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11751),
  [18144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9040),
  [18146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11908),
  [18148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5312),
  [18150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9056),
  [18152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_elements_section_repeat1, 2, 0, 0),
  [18154] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_elements_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11751),
  [18157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11479),
  [18159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12094),
  [18161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11480),
  [18163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5399),
  [18165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4004),
  [18167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_addfirst_views_modification_repeat1, 2, 0, 0),
  [18169] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_addfirst_views_modification_repeat1, 2, 0, 0), SHIFT_REPEAT(12625),
  [18172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9054),
  [18174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9055),
  [18176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4005),
  [18178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11992),
  [18180] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_calc_field_reference_repeat1, 2, 0, 0), SHIFT_REPEAT(5875),
  [18183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_calc_field_reference_repeat1, 2, 0, 0),
  [18185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10274),
  [18187] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sorting_value, 5, 0, 0),
  [18189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11637),
  [18191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10290),
  [18193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__preproc_guard_block, 2, 0, 81),
  [18195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_declaration, 9, 0, 188),
  [18197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1955),
  [18199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12000),
  [18201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_declaration, 8, 0, 188),
  [18203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1961),
  [18205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5875),
  [18207] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_calc_field_reference, 2, 0, 0),
  [18209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3531),
  [18211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3532),
  [18213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3551),
  [18215] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_labels_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11908),
  [18218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_labels_section_repeat1, 2, 0, 0),
  [18220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12162),
  [18222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12169),
  [18224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12170),
  [18226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5619),
  [18228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5620),
  [18230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3711),
  [18232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3715),
  [18234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3717),
  [18236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sorting_value, 4, 0, 0),
  [18238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12176),
  [18240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9033),
  [18242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2503),
  [18244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5659),
  [18246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5343),
  [18248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2514),
  [18250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_rendering_section_repeat1, 2, 0, 0),
  [18252] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_rendering_section_repeat1, 2, 0, 0), SHIFT_REPEAT(11992),
  [18255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4087),
  [18257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6704),
  [18259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6705),
  [18261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6706),
  [18263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6742),
  [18265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5770),
  [18267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4063),
  [18269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5771),
  [18271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5772),
  [18273] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 52), SHIFT_REPEAT(2968),
  [18276] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 52),
  [18278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5365),
  [18280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6743),
  [18282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5366),
  [18284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6744),
  [18286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5274),
  [18288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5364),
  [18290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dotnet_declaration_repeat1, 2, 0, 0),
  [18292] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dotnet_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(12000),
  [18295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9046),
  [18297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4067),
  [18299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1109),
  [18301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [18303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12669),
  [18305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7035),
  [18307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12159),
  [18309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1201),
  [18311] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2761),
  [18314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attribute_argument_list_repeat1, 2, 0, 0),
  [18316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8426),
  [18318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1331),
  [18320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7051),
  [18322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11142),
  [18324] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_implements_clause_repeat1, 2, 0, 28), SHIFT_REPEAT(8361),
  [18327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8369),
  [18329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3136),
  [18331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7037),
  [18333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12659),
  [18335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12463),
  [18337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11940),
  [18339] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameter_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7495),
  [18342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameter_list_repeat1, 2, 0, 0),
  [18344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7495),
  [18346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 3, 0, 0),
  [18348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8361),
  [18350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12660),
  [18352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3834),
  [18354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sorting_value, 9, 0, 0),
  [18356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [18358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12079),
  [18360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11392),
  [18362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3869),
  [18364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11300),
  [18366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8534),
  [18368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12501),
  [18370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [18372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [18374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2761),
  [18376] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_argument_list, 2, 0, 0),
  [18378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7517),
  [18380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4137),
  [18382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11934),
  [18384] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_namespace_name_repeat1, 2, 0, 0),
  [18386] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_namespace_name_repeat1, 2, 0, 0), SHIFT_REPEAT(11521),
  [18389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11901),
  [18391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12547),
  [18393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12419),
  [18395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8394),
  [18397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10249),
  [18399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7533),
  [18401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11161),
  [18403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 2, 0, 0),
  [18405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6106),
  [18407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12637),
  [18409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7222),
  [18411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11313),
  [18413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2132),
  [18415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2133),
  [18417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4800),
  [18419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sorting_value, 8, 0, 0),
  [18421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7588),
  [18423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11821),
  [18425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11912),
  [18427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4229),
  [18429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12004),
  [18431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12026),
  [18433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12029),
  [18435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11129),
  [18437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10634),
  [18439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3096),
  [18441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12054),
  [18443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12066),
  [18445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12163),
  [18447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12181),
  [18449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7562),
  [18451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12259),
  [18453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12269),
  [18455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12465),
  [18457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12481),
  [18459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12556),
  [18461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12565),
  [18463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12622),
  [18465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12653),
  [18467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7578),
  [18469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12316),
  [18471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12551),
  [18473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_argument_list, 1, 0, 0),
  [18475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11258),
  [18477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11335),
  [18479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12149),
  [18481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12211),
  [18483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 1, 0, 0),
  [18485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7555),
  [18487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11621),
  [18489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10121),
  [18491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11424),
  [18493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11241),
  [18495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1277),
  [18497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [18499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11701),
  [18501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_name, 1, 0, 0),
  [18503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11521),
  [18505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_name, 2, 0, 0),
  [18507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1227),
  [18509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1255),
  [18511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1256),
  [18513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2211),
  [18515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caption_value, 2, 0, 0),
  [18517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11213),
  [18519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1309),
  [18521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1310),
  [18523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3845),
  [18525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4781),
  [18527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12193),
  [18529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5917),
  [18531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5890),
  [18533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1322),
  [18535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1323),
  [18537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5007),
  [18539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1350),
  [18541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1357),
  [18543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1261),
  [18545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1262),
  [18547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1279),
  [18549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1280),
  [18551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5024),
  [18553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11418),
  [18555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5032),
  [18557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_caption_value_repeat1, 2, 0, 0),
  [18559] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_caption_value_repeat1, 2, 0, 0), SHIFT_REPEAT(11684),
  [18562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3147),
  [18564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11330),
  [18566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12111),
  [18568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11198),
  [18570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1494),
  [18572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_signed_integer_list, 2, 0, 0),
  [18574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10880),
  [18576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ml_value_list, 2, 0, 0),
  [18578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7845),
  [18580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11561),
  [18582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1442),
  [18584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1445),
  [18586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2736),
  [18588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_content, 1, 0, 8),
  [18590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ml_value_list, 1, 0, 0),
  [18592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8036),
  [18594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5525),
  [18596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5555),
  [18598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5563),
  [18600] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_label_declaration_repeat1, 2, 0, 78),
  [18602] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_label_declaration_repeat1, 2, 0, 78), SHIFT_REPEAT(10634),
  [18605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11657),
  [18607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_list, 1, 0, 0),
  [18609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_by_list, 1, 0, 0),
  [18611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10948),
  [18613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_by_list, 2, 0, 0),
  [18615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4712),
  [18617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2203),
  [18619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_signed_integer_list_repeat1, 2, 0, 0),
  [18621] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_signed_integer_list_repeat1, 2, 0, 0), SHIFT_REPEAT(10880),
  [18624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11735),
  [18626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2091),
  [18628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2092),
  [18630] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat2, 2, 0, 23), SHIFT_REPEAT(8426),
  [18633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat2, 2, 0, 23),
  [18635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4776),
  [18637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11776),
  [18639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4777),
  [18641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_ml_value_list_repeat1, 2, 0, 0),
  [18643] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_ml_value_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8245),
  [18646] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sorting_value_repeat1, 2, 0, 0), SHIFT_REPEAT(8394),
  [18649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_sorting_value_repeat1, 2, 0, 0),
  [18651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4778),
  [18653] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_order_by_list_repeat1, 2, 0, 0),
  [18655] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_order_by_list_repeat1, 2, 0, 0), SHIFT_REPEAT(10948),
  [18658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1207),
  [18660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1259),
  [18662] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_type_repeat1, 2, 0, 0), SHIFT_REPEAT(12659),
  [18665] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_type_repeat1, 2, 0, 0),
  [18667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3824),
  [18669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat1, 2, 0, 0),
  [18671] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(11142),
  [18674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_list, 2, 0, 0),
  [18676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12039),
  [18678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1133),
  [18680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11175),
  [18682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12229),
  [18684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10898),
  [18686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_label_declaration_repeat1, 4, 0, 127),
  [18688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5002),
  [18690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10824),
  [18692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__signed_integer, 2, 0, 0),
  [18694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11217),
  [18696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rendering_layout, 7, 0, 48),
  [18698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure_modifier, 1, 0, 0),
  [18700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3265),
  [18702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10769),
  [18704] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_label_declaration, 5, 0, 77),
  [18706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3868),
  [18708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12184),
  [18710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11933),
  [18712] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_var_block, 2, 0, 0),
  [18714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreach_keyword, 1, 0, 0),
  [18716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10282),
  [18718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12051),
  [18720] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_var_block, 3, 0, 0),
  [18722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_label_attribute, 3, 0, 22),
  [18724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4814),
  [18726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2630),
  [18728] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rendering_layout, 6, 0, 48),
  [18730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4392),
  [18732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8643),
  [18734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10091),
  [18736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 3, 0, 44),
  [18738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11120),
  [18740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decimal_range_value, 2, 0, 21),
  [18742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12107),
  [18744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_reference_value, 2, 0, 0),
  [18746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12100),
  [18748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3865),
  [18750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10498),
  [18752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10251),
  [18754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8602),
  [18756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_by_item, 4, 0, 0),
  [18758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9966),
  [18760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8603),
  [18762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11211),
  [18764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3873),
  [18766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11914),
  [18768] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__trigger_name, 1, 0, 0),
  [18770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8372),
  [18772] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 4, 0, 72),
  [18774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_var_block, 6, 0, 0),
  [18776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_var_block, 5, 0, 0),
  [18778] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_label_declaration, 4, 0, 22),
  [18780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2782),
  [18782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12067),
  [18784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3471),
  [18786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8522),
  [18788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4620),
  [18790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4199),
  [18792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8596),
  [18794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameter_list_repeat1, 3, 0, 0),
  [18796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10184),
  [18798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8737),
  [18800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12496),
  [18802] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_caption_value_repeat1, 4, 0, 0),
  [18804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11231),
  [18806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2788),
  [18808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12438),
  [18810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11249),
  [18812] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat2, 2, 0, 2),
  [18814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4773),
  [18816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10972),
  [18818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12450),
  [18820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11244),
  [18822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8631),
  [18824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12519),
  [18826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10214),
  [18828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11158),
  [18830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7524),
  [18832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10545),
  [18834] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ml_value_pair, 3, 0, 37),
  [18836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caption_value, 3, 0, 0),
  [18838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11548),
  [18840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3075),
  [18842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10640),
  [18844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10018),
  [18846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_conditional_var_block, 4, 0, 0),
  [18848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2793),
  [18850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11421),
  [18852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10234),
  [18854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2796),
  [18856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11918),
  [18858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7085),
  [18860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10377),
  [18862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2218),
  [18864] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_label_declaration_repeat1, 4, 0, 125),
  [18866] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_by_item, 5, 0, 0),
  [18868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7595),
  [18870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10624),
  [18872] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_label_declaration_repeat1, 4, 0, 126),
  [18874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3663),
  [18876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3965),
  [18878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8729),
  [18880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2795),
  [18882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12533),
  [18884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5501),
  [18886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10907),
  [18888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11204),
  [18890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8503),
  [18892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8626),
  [18894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3424),
  [18896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8580),
  [18898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_content, 2, 0, 11),
  [18900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1335),
  [18902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7514),
  [18904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7435),
  [18906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [18908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3802),
  [18910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5196),
  [18912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [18914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7612),
  [18916] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sorting_value, 10, 0, 0),
  [18918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4266),
  [18920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8529),
  [18922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11265),
  [18924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12454),
  [18926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12455),
  [18928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4430),
  [18930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8154),
  [18932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12369),
  [18934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11275),
  [18936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8719),
  [18938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7726),
  [18940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3367),
  [18942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8155),
  [18944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4195),
  [18946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6076),
  [18948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7450),
  [18950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8524),
  [18952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9353),
  [18954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3805),
  [18956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4921),
  [18958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7224),
  [18960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12546),
  [18962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12549),
  [18964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7236),
  [18966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10215),
  [18968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_permissionsetextension_keyword, 1, 0, 0),
  [18970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10216),
  [18972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4799),
  [18974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10217),
  [18976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7126),
  [18978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11245),
  [18980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11116),
  [18982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10380),
  [18984] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_arguments, 2, 0, 0),
  [18986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [18988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4165),
  [18990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7861),
  [18992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8462),
  [18994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7862),
  [18996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12614),
  [18998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12615),
  [19000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6153),
  [19002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4904),
  [19004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7217),
  [19006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10322),
  [19008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1342),
  [19010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9989),
  [19012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10258),
  [19014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7454),
  [19016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8344),
  [19018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9355),
  [19020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8477),
  [19022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11624),
  [19024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4374),
  [19026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12214),
  [19028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12264),
  [19030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9121),
  [19032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7472),
  [19034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9233),
  [19036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7410),
  [19038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8379),
  [19040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7482),
  [19042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10808),
  [19044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4126),
  [19046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6108),
  [19048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8988),
  [19050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6109),
  [19052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [19054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4168),
  [19056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9029),
  [19058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4133),
  [19060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4577),
  [19062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4393),
  [19064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7018),
  [19066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6111),
  [19068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4175),
  [19070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8581),
  [19072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8365),
  [19074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6996),
  [19076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6112),
  [19078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11733),
  [19080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [19082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11737),
  [19084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7001),
  [19086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4860),
  [19088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6232),
  [19090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3282),
  [19092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1267),
  [19094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8264),
  [19096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9576),
  [19098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4578),
  [19100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8357),
  [19102] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reportextension_keyword, 1, 0, 0),
  [19104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4398),
  [19106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4177),
  [19108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7458),
  [19110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6113),
  [19112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8442),
  [19114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11412),
  [19116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8446),
  [19118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6115),
  [19120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7005),
  [19122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__trigger_name, 3, 0, 0),
  [19124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4399),
  [19126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6129),
  [19128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6130),
  [19130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4400),
  [19132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4401),
  [19134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4402),
  [19136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8452),
  [19138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8335),
  [19140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4403),
  [19142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6078),
  [19144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8455),
  [19146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2437),
  [19148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7441),
  [19150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4942),
  [19152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11477),
  [19154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4943),
  [19156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4404),
  [19158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [19160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4944),
  [19162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4548),
  [19164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8391),
  [19166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4947),
  [19168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2294),
  [19170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2194),
  [19172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7409),
  [19174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12559),
  [19176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8473),
  [19178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8068),
  [19180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11331),
  [19182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8215),
  [19184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4865),
  [19186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1464),
  [19188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1465),
  [19190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1466),
  [19192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8448),
  [19194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1467),
  [19196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4549),
  [19198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10252),
  [19200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7408),
  [19202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1468),
  [19204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7412),
  [19206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8216),
  [19208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11559),
  [19210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7287),
  [19212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7288),
  [19214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3276),
  [19216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4203),
  [19218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11659),
  [19220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3889),
  [19222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7421),
  [19224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7425),
  [19226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4180),
  [19228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6239),
  [19230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7043),
  [19232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4210),
  [19234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8217),
  [19236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7432),
  [19238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2730),
  [19240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11948),
  [19242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10444),
  [19244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1305),
  [19246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8198),
  [19248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8199),
  [19250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11996),
  [19252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12007),
  [19254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12011),
  [19256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12015),
  [19258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12016),
  [19260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12017),
  [19262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12020),
  [19264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12025),
  [19266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12031),
  [19268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12032),
  [19270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12040),
  [19272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12041),
  [19274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2772),
  [19276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12044),
  [19278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12045),
  [19280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12046),
  [19282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12047),
  [19284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12049),
  [19286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8458),
  [19288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8459),
  [19290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8460),
  [19292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8461),
  [19294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12060),
  [19296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12061),
  [19298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12062),
  [19300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12063),
  [19302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12064),
  [19304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12065),
  [19306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12052),
  [19308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8218),
  [19310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12072),
  [19312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11095),
  [19314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2775),
  [19316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7471),
  [19318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4319),
  [19320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4422),
  [19322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8080),
  [19324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2719),
  [19326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4424),
  [19328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1334),
  [19330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1337),
  [19332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12160),
  [19334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12161),
  [19336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12168),
  [19338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12172),
  [19340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12173),
  [19342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12178),
  [19344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12179),
  [19346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11255),
  [19348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4425),
  [19350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4426),
  [19352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3379),
  [19354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2495),
  [19356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3347),
  [19358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3279),
  [19360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7542),
  [19362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8739),
  [19364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9310),
  [19366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9311),
  [19368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2569),
  [19370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9313),
  [19372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6369),
  [19374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12262),
  [19376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [19378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6819),
  [19380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9031),
  [19382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9316),
  [19384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9317),
  [19386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9318),
  [19388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7031),
  [19390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12435),
  [19392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4579),
  [19394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [19396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [19398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6233),
  [19400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11252),
  [19402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4030),
  [19404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7167),
  [19406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12469),
  [19408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9325),
  [19410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [19412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8536),
  [19414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7573),
  [19416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4580),
  [19418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12503),
  [19420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8433),
  [19422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8731),
  [19424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8732),
  [19426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12535),
  [19428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12053),
  [19430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1780),
  [19432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10189),
  [19434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4977),
  [19436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5207),
  [19438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12560),
  [19440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [19442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7353),
  [19444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4214),
  [19446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12592),
  [19448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12596),
  [19450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [19452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [19454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9349),
  [19456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [19458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [19460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4205),
  [19462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4581),
  [19464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(647),
  [19466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [19468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [19470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11332),
  [19472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7428),
  [19474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9002),
  [19476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7430),
  [19478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11339),
  [19480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11342),
  [19482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8733),
  [19484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7437),
  [19486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7438),
  [19488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11334),
  [19490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12561),
  [19492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11341),
  [19494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7439),
  [19496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11364),
  [19498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10510),
  [19500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [19502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11367),
  [19504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11371),
  [19506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11374),
  [19508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11375),
  [19510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11376),
  [19512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11377),
  [19514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11379),
  [19516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11380),
  [19518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11383),
  [19520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11384),
  [19522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11386),
  [19524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2764),
  [19526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11388),
  [19528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11390),
  [19530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11391),
  [19532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11393),
  [19534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11396),
  [19536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8486),
  [19538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8487),
  [19540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8488),
  [19542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8489),
  [19544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11405),
  [19546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11406),
  [19548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11407),
  [19550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11409),
  [19552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11411),
  [19554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11415),
  [19556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6573),
  [19558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5959),
  [19560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8418),
  [19562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4582),
  [19564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1268),
  [19566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11478),
  [19568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11481),
  [19570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11492),
  [19572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11493),
  [19574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11495),
  [19576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11497),
  [19578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11498),
  [19580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11345),
  [19582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6117),
  [19584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4999),
  [19586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4606),
  [19588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12656),
  [19590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11261),
  [19592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9374),
  [19594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9375),
  [19596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_aggregate_formula, 4, 0, 53),
  [19598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9377),
  [19600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2436),
  [19602] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_arguments, 3, 0, 0),
  [19604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4545),
  [19606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(654),
  [19608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9380),
  [19610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9381),
  [19612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9382),
  [19614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8768),
  [19616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [19618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [19620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11264),
  [19622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9385),
  [19624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [19626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8343),
  [19628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11205),
  [19630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11510),
  [19632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8736),
  [19634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(664),
  [19636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12200),
  [19638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [19640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [19642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8846),
  [19644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11350),
  [19646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [19648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [19650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7639),
  [19652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4095),
  [19654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [19656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(674),
  [19658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(678),
  [19660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11361),
  [19662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7459),
  [19664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8526),
  [19666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7467),
  [19668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11812),
  [19670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11839),
  [19672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4213),
  [19674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7449),
  [19676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2497),
  [19678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7014),
  [19680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11931),
  [19682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10551),
  [19684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1315),
  [19686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2773),
  [19688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11941),
  [19690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11942),
  [19692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11943),
  [19694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11944),
  [19696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11947),
  [19698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4622),
  [19700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8504),
  [19702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8505),
  [19704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8506),
  [19706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11968),
  [19708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11973),
  [19710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11974),
  [19712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11978),
  [19714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11979),
  [19716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11980),
  [19718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4945),
  [19720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12562),
  [19722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1332),
  [19724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11997),
  [19726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11998),
  [19728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11999),
  [19730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12003),
  [19732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8481),
  [19734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5003),
  [19736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11517),
  [19738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8368),
  [19740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6574),
  [19742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4609),
  [19744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9428),
  [19746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9429),
  [19748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1764),
  [19750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9431),
  [19752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3882),
  [19754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6579),
  [19756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6933),
  [19758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [19760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9435),
  [19762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9436),
  [19764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9437),
  [19766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8490),
  [19768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [19770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [19772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4221),
  [19774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9443),
  [19776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [19778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6581),
  [19780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4946),
  [19782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4583),
  [19784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11529),
  [19786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [19788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4948),
  [19790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [19792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(691),
  [19794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4949),
  [19796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8321),
  [19798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [19800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [19802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7203),
  [19804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sorting_value, 6, 0, 0),
  [19806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(697),
  [19808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [19810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [19812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12566),
  [19814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7443),
  [19816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8864),
  [19818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7447),
  [19820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12138),
  [19822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12145),
  [19824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8865),
  [19826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7460),
  [19828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2768),
  [19830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7347),
  [19832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12171),
  [19834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10598),
  [19836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1325),
  [19838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12174),
  [19840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12175),
  [19842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6092),
  [19844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1333),
  [19846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6204),
  [19848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8441),
  [19850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8364),
  [19852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12319),
  [19854] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [19856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9476),
  [19858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9477),
  [19860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ml_value_list, 6, 0, 0),
  [19862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9479),
  [19864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12464),
  [19866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [19868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [19870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9483),
  [19872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9484),
  [19874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9485),
  [19876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10997),
  [19878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [19880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(707),
  [19882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9487),
  [19884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [19886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6938),
  [19888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3847),
  [19890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7925),
  [19892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8342),
  [19894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7462),
  [19896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7926),
  [19898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12379),
  [19900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12388),
  [19902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6122),
  [19904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4878),
  [19906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7213),
  [19908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10625),
  [19910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1253),
  [19912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10265),
  [19914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1254),
  [19916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10266),
  [19918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10269),
  [19920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [19922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [19924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [19926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [19928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4437),
  [19930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9175),
  [19932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7475),
  [19934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6229),
  [19936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7433),
  [19938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7461),
  [19940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12541),
  [19942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2180),
  [19944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1708),
  [19946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8370),
  [19948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10648),
  [19950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1263),
  [19952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1264),
  [19954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [19956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [19958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [19960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [19962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4857),
  [19964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12608),
  [19966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8766),
  [19968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1486),
  [19970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9027),
  [19972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10662),
  [19974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1282),
  [19976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [19978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [19980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [19982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(731),
  [19984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [19986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12664),
  [19988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [19990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6140),
  [19992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10671),
  [19994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1317),
  [19996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1326),
  [19998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [20000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [20002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [20004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [20006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1487),
  [20008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6898),
  [20010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10681),
  [20012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1351),
  [20014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [20016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [20018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [20020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [20022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [20024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4439),
  [20026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7013),
  [20028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10689),
  [20030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1363),
  [20032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1252),
  [20034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(752),
  [20036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [20038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [20040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [20042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8387),
  [20044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [20046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10700),
  [20048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1272),
  [20050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1307),
  [20052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [20054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [20056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [20058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [20060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10706),
  [20062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1265),
  [20064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1269),
  [20066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [20068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [20070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [20072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(773),
  [20074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10715),
  [20076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [20078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [20080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(779),
  [20082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [20084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10724),
  [20086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [20088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(785),
  [20090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [20092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [20094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [20096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [20098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [20100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [20102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [20104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [20106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [20108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [20110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [20112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [20114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(811),
  [20116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [20118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [20120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [20122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [20124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [20126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8549),
  [20128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8550),
  [20130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8551),
  [20132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8552),
  [20134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8554),
  [20136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8555),
  [20138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8556),
  [20140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8557),
  [20142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8560),
  [20144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8561),
  [20146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10761),
  [20148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1276),
  [20150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8564),
  [20152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8767),
  [20154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8566),
  [20156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8567),
  [20158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8568),
  [20160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1488),
  [20162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11474),
  [20164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6986),
  [20166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12445),
  [20168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12460),
  [20170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1358),
  [20172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6987),
  [20174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10766),
  [20176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4191),
  [20178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1489),
  [20180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4326),
  [20182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6187),
  [20184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11438),
  [20186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11439),
  [20188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1777),
  [20190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11553),
  [20192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1490),
  [20194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11603),
  [20196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4232),
  [20198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11614),
  [20200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11623),
  [20202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4444),
  [20204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4233),
  [20206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10623),
  [20208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1274),
  [20210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4032),
  [20212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8390),
  [20214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12475),
  [20216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1329),
  [20218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4884),
  [20220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4885),
  [20222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4445),
  [20224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4886),
  [20226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8330),
  [20228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8527),
  [20230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4887),
  [20232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4235),
  [20234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2780),
  [20236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4192),
  [20238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10723),
  [20240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9784),
  [20242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11682),
  [20244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8989),
  [20246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10017),
  [20248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9790),
  [20250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7398),
  [20252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5780),
  [20254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9812),
  [20256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6919),
  [20258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4934),
  [20260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8496),
  [20262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7689),
  [20264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4348),
  [20266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8497),
  [20268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6505),
  [20270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5470),
  [20272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4846),
  [20274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7415),
  [20276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8990),
  [20278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8270),
  [20280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8570),
  [20282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1474),
  [20284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1475),
  [20286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11715),
  [20288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11716),
  [20290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8420),
  [20292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1476),
  [20294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [20296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1478),
  [20298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1002),
  [20300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3076),
  [20302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8271),
  [20304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8573),
  [20306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2792),
  [20308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11719),
  [20310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [20312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5493),
  [20314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11722),
  [20316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8493),
  [20318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8730),
  [20320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8514),
  [20322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3875),
  [20324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8495),
  [20326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8457),
  [20328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6124),
  [20330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4466),
  [20332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4467),
  [20334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4468),
  [20336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10577),
  [20338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7102),
  [20340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11279),
  [20342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3381),
  [20344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10502),
  [20346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2744),
  [20348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7155),
  [20350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6125),
  [20352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5502),
  [20354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8498),
  [20356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8499),
  [20358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4236),
  [20360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7284),
  [20362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11808),
  [20364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7576),
  [20366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6126),
  [20368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6128),
  [20370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4237),
  [20372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8696),
  [20374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4194),
  [20376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4238),
  [20378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1353),
  [20380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11571),
  [20382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11572),
  [20384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3820),
  [20386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4239),
  [20388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11298),
  [20390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1301),
  [20392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10230),
  [20394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11299),
  [20396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8697),
  [20398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4240),
  [20400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4241),
  [20402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [20404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1037),
  [20406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7103),
  [20408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6997),
  [20410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7582),
  [20412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3892),
  [20414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6139),
  [20416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2428),
  [20418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8434),
  [20420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2358),
  [20422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4894),
  [20424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4895),
  [20426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4242),
  [20428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4896),
  [20430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumextension_keyword, 1, 0, 0),
  [20432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4928),
  [20434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_relation_value, 1, 0, 0),
  [20436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8367),
  [20438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4064),
  [20440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4065),
  [20442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1273),
  [20444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [20446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8329),
  [20448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12252),
  [20450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5135),
  [20452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11811),
  [20454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4847),
  [20456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1454),
  [20458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1455),
  [20460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1456),
  [20462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1491),
  [20464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1458),
  [20466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1345),
  [20468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3333),
  [20470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4544),
  [20472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8537),
  [20474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [20476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [20478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4066),
  [20480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6942),
  [20482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2568),
  [20484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1215),
  [20486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8541),
  [20488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [20490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6210),
  [20492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1316),
  [20494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8934),
  [20496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [20498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7574),
  [20500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5456),
  [20502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(628),
  [20504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7110),
  [20506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4252),
  [20508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4255),
  [20510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11664),
  [20512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11665),
  [20514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7156),
  [20516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9010),
  [20518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2804),
  [20520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6429),
  [20522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [20524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8474),
  [20526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6941),
  [20528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4598),
  [20530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7231),
  [20532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5599),
  [20534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4767),
  [20536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1693),
  [20538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [20540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7367),
  [20542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8623),
  [20544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decimal_range_value, 3, 0, 32),
  [20546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7981),
  [20548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11359),
  [20550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4243),
  [20552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11121),
  [20554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8378),
  [20556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7982),
  [20558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [20560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6120),
  [20562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4907),
  [20564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10242),
  [20566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4771),
  [20568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10245),
  [20570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lookup_formula, 5, 0, 49),
  [20572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10253),
  [20574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4484),
  [20576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9211),
  [20578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7474),
  [20580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8438),
  [20582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4523),
  [20584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7451),
  [20586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11357),
  [20588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4034),
  [20590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7423),
  [20592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4269),
  [20594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7184),
  [20596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8354),
  [20598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4774),
  [20600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4270),
  [20602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3039),
  [20604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3907),
  [20606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9022),
  [20608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11742),
  [20610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11743),
  [20612] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__calc_formula_expression, 2, 0, 0),
  [20614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10813),
  [20616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4219),
  [20618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4218),
  [20620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4495),
  [20622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7017),
  [20624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8516),
  [20626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3162),
  [20628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1341),
  [20630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3908),
  [20632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6889),
  [20634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11746),
  [20636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1144),
  [20638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1145),
  [20640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12385),
  [20642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8386),
  [20644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12437),
  [20646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6890),
  [20648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3870),
  [20650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4275),
  [20652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4279),
  [20654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7831),
  [20656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1281),
  [20658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2779),
  [20660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [20662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11781),
  [20664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11782),
  [20666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4280),
  [20668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2803),
  [20670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2720),
  [20672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4497),
  [20674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4281),
  [20676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3412),
  [20678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4909),
  [20680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4910),
  [20682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11131),
  [20684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3364),
  [20686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3337),
  [20688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4234),
  [20690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1285),
  [20692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11801),
  [20694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11802),
  [20696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11055),
  [20698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3837),
  [20700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7465),
  [20702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4915),
  [20704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1127),
  [20706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3909),
  [20708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11813),
  [20710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11814),
  [20712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7614),
  [20714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11267),
  [20716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12517),
  [20718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3544),
  [20720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8351),
  [20722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3488),
  [20724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11823),
  [20726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11824),
  [20728] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_aggregate_formula, 5, 0, 53),
  [20730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3910),
  [20732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8070),
  [20734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8530),
  [20736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11832),
  [20738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11833),
  [20740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4135),
  [20742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4293),
  [20744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6829),
  [20746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12624),
  [20748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1344),
  [20750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11841),
  [20752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11842),
  [20754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2188),
  [20756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8741),
  [20758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3839),
  [20760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6002),
  [20762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11850),
  [20764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11851),
  [20766] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ml_value_list, 5, 0, 0),
  [20768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6230),
  [20770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11830),
  [20772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6868),
  [20774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11857),
  [20776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11858),
  [20778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8742),
  [20780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1258),
  [20782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6779),
  [20784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11907),
  [20786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5012),
  [20788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11864),
  [20790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7470),
  [20792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8408),
  [20794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7515),
  [20796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5013),
  [20798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11869),
  [20800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5014),
  [20802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3489),
  [20804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4929),
  [20806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11917),
  [20808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11926),
  [20810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3478),
  [20812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3481),
  [20814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8668),
  [20816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4844),
  [20818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8993),
  [20820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5015),
  [20822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8795),
  [20824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8797),
  [20826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7411),
  [20828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8763),
  [20830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3331),
  [20832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10004),
  [20834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2774),
  [20836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7273),
  [20838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [20840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8801),
  [20842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2728),
  [20844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4316),
  [20846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7211),
  [20848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2189),
  [20850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [20852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10860),
  [20854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8584),
  [20856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8585),
  [20858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1306),
  [20860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8587),
  [20862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8281),
  [20864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8588),
  [20866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8589),
  [20868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8590),
  [20870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8591),
  [20872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8592),
  [20874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8593),
  [20876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8594),
  [20878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8595),
  [20880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8597),
  [20882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8598),
  [20884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8599),
  [20886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8790),
  [20888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8600),
  [20890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8601),
  [20892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8649),
  [20894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8650),
  [20896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8604),
  [20898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8605),
  [20900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8606),
  [20902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8607),
  [20904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8608),
  [20906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8609),
  [20908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8610),
  [20910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8984),
  [20912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8611),
  [20914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8612),
  [20916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8613),
  [20918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8614),
  [20920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8615),
  [20922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8616),
  [20924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11319),
  [20926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8617),
  [20928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4021),
  [20930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11740),
  [20932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8815),
  [20934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1270),
  [20936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8618),
  [20938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8619),
  [20940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8620),
  [20942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8621),
  [20944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8622),
  [20946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8141),
  [20948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8142),
  [20950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1320),
  [20952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7419),
  [20954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2190),
  [20956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6883),
  [20958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3495),
  [20960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2809),
  [20962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1951),
  [20964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8624),
  [20966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8625),
  [20968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1952),
  [20970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10286),
  [20972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8627),
  [20974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8501),
  [20976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6874),
  [20978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8629),
  [20980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8630),
  [20982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8632),
  [20984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8456),
  [20986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12492),
  [20988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5373),
  [20990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8079),
  [20992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10895),
  [20994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8634),
  [20996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8635),
  [20998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8637),
  [21000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8288),
  [21002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8638),
  [21004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8639),
  [21006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8640),
  [21008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8641),
  [21010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8642),
  [21012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8644),
  [21014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8645),
  [21016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8646),
  [21018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8775),
  [21020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8647),
  [21022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8648),
  [21024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8673),
  [21026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8674),
  [21028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8651),
  [21030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8652),
  [21032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8653),
  [21034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8654),
  [21036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8655),
  [21038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8656),
  [21040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8657),
  [21042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8987),
  [21044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8658),
  [21046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8659),
  [21048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8660),
  [21050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8661),
  [21052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8662),
  [21054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8663),
  [21056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7560),
  [21058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [21060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8664),
  [21062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8665),
  [21064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8666),
  [21066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8667),
  [21068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8145),
  [21070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8146),
  [21072] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pageextension_keyword, 1, 0, 0),
  [21074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9001),
  [21076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8718),
  [21078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7687),
  [21080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8211),
  [21082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8377),
  [21084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1238),
  [21086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [21088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8451),
  [21090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4500),
  [21092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8454),
  [21094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10943),
  [21096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8670),
  [21098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8671),
  [21100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8292),
  [21102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8672),
  [21104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8693),
  [21106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8694),
  [21108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8675),
  [21110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8676),
  [21112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8677),
  [21114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8678),
  [21116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8679),
  [21118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8680),
  [21120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8681),
  [21122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8991),
  [21124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8682),
  [21126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8683),
  [21128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8684),
  [21130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8685),
  [21132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8686),
  [21134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8385),
  [21136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1278),
  [21138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8687),
  [21140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8688),
  [21142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8689),
  [21144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8147),
  [21146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8986),
  [21148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8502),
  [21150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9008),
  [21152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11511),
  [21154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7012),
  [21156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6795),
  [21158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3344),
  [21160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8465),
  [21162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1744),
  [21164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7368),
  [21166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5847),
  [21168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9009),
  [21170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8468),
  [21172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10963),
  [21174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8691),
  [21176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8692),
  [21178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8296),
  [21180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5919),
  [21182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1283),
  [21184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4323),
  [21186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8507),
  [21188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1218),
  [21190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4613),
  [21192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12303),
  [21194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8492),
  [21196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11747),
  [21198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11750),
  [21200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8341),
  [21202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3502),
  [21204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7385),
  [21206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7321),
  [21208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10977),
  [21210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8699),
  [21212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1287),
  [21214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10499),
  [21216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7386),
  [21218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8279),
  [21220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8542),
  [21222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6177),
  [21224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6182),
  [21226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7060),
  [21228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4013),
  [21230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8764),
  [21232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7406),
  [21234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8701),
  [21236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1288),
  [21238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1338),
  [21240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6864),
  [21242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1347),
  [21244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3334),
  [21246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8702),
  [21248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1289),
  [21250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12258),
  [21252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6184),
  [21254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12537),
  [21256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2957),
  [21258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8703),
  [21260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1290),
  [21262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7564),
  [21264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10877),
  [21266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10354),
  [21268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8338),
  [21270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [21272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7629),
  [21274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1348),
  [21276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12109),
  [21278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8544),
  [21280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1292),
  [21282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8348),
  [21284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12544),
  [21286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5991),
  [21288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4250),
  [21290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1293),
  [21292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4587),
  [21294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10264),
  [21296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12014),
  [21298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8360),
  [21300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1294),
  [21302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8517),
  [21304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4499),
  [21306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8713),
  [21308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4215),
  [21310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8531),
  [21312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tableextension_keyword, 1, 0, 0),
  [21314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lookup_formula, 4, 0, 49),
  [21316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [21318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4506),
  [21320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [21322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8328),
  [21324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8475),
  [21326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9276),
  [21328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12120),
  [21330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8715),
  [21332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6861),
  [21334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8553),
  [21336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8716),
  [21338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8717),
  [21340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [21342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7481),
  [21344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8476),
  [21346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4056),
  [21348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8412),
  [21350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4330),
  [21352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8569),
  [21354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1623),
  [21356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12197),
  [21358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8706),
  [21360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8707),
  [21362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8708),
  [21364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8709),
  [21366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8710),
  [21368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12272),
  [21370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12308),
  [21372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12309),
  [21374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_permissionset_keyword, 1, 0, 0),
  [21376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2213),
  [21378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3309),
  [21380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8519),
  [21382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4331),
  [21384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11916),
  [21386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4838),
  [21388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8532),
  [21390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7348),
  [21392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8765),
  [21394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4503),
  [21396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7009),
  [21398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12240),
  [21400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4839),
  [21402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8419),
  [21404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2138),
  [21406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12341),
  [21408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12370),
  [21410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2139),
  [21412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12244),
  [21414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1321),
  [21416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12033),
  [21418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12245),
  [21420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12034),
  [21422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10194),
  [21424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1352),
  [21426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2140),
  [21428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8521),
  [21430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4785),
  [21432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11542),
  [21434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4786),
  [21436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4588),
  [21438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12393),
  [21440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12411),
  [21442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1354),
  [21444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4554),
  [21446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4597),
  [21448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2143),
  [21450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7070),
  [21452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6759),
  [21454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12444),
  [21456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [21458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8471),
  [21460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4009),
  [21462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8721),
  [21464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12432),
  [21466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12434),
  [21468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8105),
  [21470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8722),
  [21472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10255),
  [21474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4145),
  [21476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8363),
  [21478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8350),
  [21480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8723),
  [21482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12449),
  [21484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8724),
  [21486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8484),
  [21488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8725),
  [21490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [21492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5661),
  [21494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4336),
  [21496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8727),
  [21498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12462),
  [21500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1511),
  [21502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4337),
  [21504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12468),
  [21506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4146),
  [21508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8528),
  [21510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12474),
  [21512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3804),
  [21514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8559),
  [21516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12479),
  [21518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8108),
  [21520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12484),
  [21522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4511),
  [21524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12489),
  [21526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8836),
  [21528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12494),
  [21530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1516),
  [21532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1517),
  [21534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12153),
  [21536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12154),
  [21538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7463),
  [21540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7086),
  [21542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4155),
  [21544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4016),
  [21546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1299),
  [21548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1518),
  [21550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7265),
  [21552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8572),
  [21554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12528),
  [21556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12530),
  [21558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8743),
  [21560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8744),
  [21562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8745),
  [21564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8746),
  [21566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8747),
  [21568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8748),
  [21570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8750),
  [21572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [21574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1339),
  [21576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8751),
  [21578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12563),
  [21580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8752),
  [21582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8753),
  [21584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8754),
  [21586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8755),
  [21588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8756),
  [21590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8757),
  [21592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [21594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [21596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12577),
  [21598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8758),
  [21600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8759),
  [21602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8760),
  [21604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8761),
  [21606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1303),
  [21608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4244),
  [21610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9351),
  [21612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10491),
  [21614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8749),
  [21616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1521),
  [21618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11117),
  [21620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1297),
  [21622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12490),
  [21624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11394),
  [21626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4519),
  [21628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4811),
  [21630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1300),
  [21632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [21634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12251),
  [21636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9694),
  [21638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4543),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_property_name = 0,
  ts_external_token_continue_as_identifier = 1,
  ts_external_token_preproc_open = 2,
  ts_external_token_preproc_close = 3,
  ts_external_token_begin_keyword = 4,
  ts_external_token_end_keyword = 5,
  ts_external_token_preproc_split_begin = 6,
  ts_external_token_preproc_split_end = 7,
  ts_external_token_var_attribute_open = 8,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_property_name] = sym_property_name,
  [ts_external_token_continue_as_identifier] = sym_continue_as_identifier,
  [ts_external_token_preproc_open] = sym_preproc_open,
  [ts_external_token_preproc_close] = sym_preproc_close,
  [ts_external_token_begin_keyword] = sym_begin_keyword,
  [ts_external_token_end_keyword] = sym_end_keyword,
  [ts_external_token_preproc_split_begin] = sym_preproc_split_begin,
  [ts_external_token_preproc_split_end] = sym_preproc_split_end,
  [ts_external_token_var_attribute_open] = sym_var_attribute_open,
};

static const bool ts_external_scanner_states[30][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_property_name] = true,
    [ts_external_token_continue_as_identifier] = true,
    [ts_external_token_preproc_open] = true,
    [ts_external_token_preproc_close] = true,
    [ts_external_token_begin_keyword] = true,
    [ts_external_token_end_keyword] = true,
    [ts_external_token_preproc_split_begin] = true,
    [ts_external_token_preproc_split_end] = true,
    [ts_external_token_var_attribute_open] = true,
  },
  [2] = {
    [ts_external_token_preproc_open] = true,
  },
  [3] = {
    [ts_external_token_continue_as_identifier] = true,
    [ts_external_token_preproc_open] = true,
    [ts_external_token_preproc_close] = true,
  },
  [4] = {
    [ts_external_token_continue_as_identifier] = true,
    [ts_external_token_preproc_open] = true,
    [ts_external_token_preproc_close] = true,
    [ts_external_token_begin_keyword] = true,
    [ts_external_token_preproc_split_begin] = true,
  },
  [5] = {
    [ts_external_token_continue_as_identifier] = true,
    [ts_external_token_preproc_open] = true,
    [ts_external_token_preproc_close] = true,
    [ts_external_token_preproc_split_end] = true,
  },
  [6] = {
    [ts_external_token_continue_as_identifier] = true,
    [ts_external_token_preproc_open] = true,
    [ts_external_token_preproc_close] = true,
    [ts_external_token_begin_keyword] = true,
  },
  [7] = {
    [ts_external_token_continue_as_identifier] = true,
    [ts_external_token_preproc_open] = true,
  },
  [8] = {
    [ts_external_token_continue_as_identifier] = true,
    [ts_external_token_preproc_open] = true,
    [ts_external_token_begin_keyword] = true,
  },
  [9] = {
    [ts_external_token_continue_as_identifier] = true,
    [ts_external_token_preproc_open] = true,
    [ts_external_token_end_keyword] = true,
  },
  [10] = {
    [ts_external_token_continue_as_identifier] = true,
    [ts_external_token_preproc_open] = true,
    [ts_external_token_begin_keyword] = true,
    [ts_external_token_preproc_split_begin] = true,
  },
  [11] = {
    [ts_external_token_preproc_open] = true,
    [ts_external_token_preproc_close] = true,
  },
  [12] = {
    [ts_external_token_property_name] = true,
    [ts_external_token_preproc_open] = true,
    [ts_external_token_preproc_close] = true,
  },
  [13] = {
    [ts_external_token_continue_as_identifier] = true,
    [ts_external_token_preproc_open] = true,
    [ts_external_token_begin_keyword] = true,
    [ts_external_token_end_keyword] = true,
  },
  [14] = {
    [ts_external_token_continue_as_identifier] = true,
    [ts_external_token_preproc_close] = true,
  },
  [15] = {
    [ts_external_token_property_name] = true,
    [ts_external_token_preproc_open] = true,
  },
  [16] = {
    [ts_external_token_property_name] = true,
    [ts_external_token_preproc_open] = true,
    [ts_external_token_preproc_close] = true,
    [ts_external_token_begin_keyword] = true,
  },
  [17] = {
    [ts_external_token_property_name] = true,
    [ts_external_token_preproc_open] = true,
    [ts_external_token_preproc_close] = true,
    [ts_external_token_var_attribute_open] = true,
  },
  [18] = {
    [ts_external_token_continue_as_identifier] = true,
  },
  [19] = {
    [ts_external_token_property_name] = true,
    [ts_external_token_preproc_open] = true,
    [ts_external_token_begin_keyword] = true,
  },
  [20] = {
    [ts_external_token_continue_as_identifier] = true,
    [ts_external_token_begin_keyword] = true,
  },
  [21] = {
    [ts_external_token_preproc_open] = true,
    [ts_external_token_preproc_close] = true,
    [ts_external_token_begin_keyword] = true,
  },
  [22] = {
    [ts_external_token_property_name] = true,
    [ts_external_token_preproc_open] = true,
    [ts_external_token_var_attribute_open] = true,
  },
  [23] = {
    [ts_external_token_preproc_close] = true,
  },
  [24] = {
    [ts_external_token_preproc_open] = true,
    [ts_external_token_begin_keyword] = true,
  },
  [25] = {
    [ts_external_token_preproc_open] = true,
    [ts_external_token_preproc_close] = true,
    [ts_external_token_var_attribute_open] = true,
  },
  [26] = {
    [ts_external_token_preproc_open] = true,
    [ts_external_token_begin_keyword] = true,
    [ts_external_token_var_attribute_open] = true,
  },
  [27] = {
    [ts_external_token_preproc_open] = true,
    [ts_external_token_var_attribute_open] = true,
  },
  [28] = {
    [ts_external_token_property_name] = true,
  },
  [29] = {
    [ts_external_token_begin_keyword] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_al_external_scanner_create(void);
void tree_sitter_al_external_scanner_destroy(void *);
bool tree_sitter_al_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_al_external_scanner_serialize(void *, char *);
void tree_sitter_al_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_al(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_al_external_scanner_create,
      tree_sitter_al_external_scanner_destroy,
      tree_sitter_al_external_scanner_scan,
      tree_sitter_al_external_scanner_serialize,
      tree_sitter_al_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
    .name = "al",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 2,
      .minor_version = 3,
      .patch_version = 0,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
